#ifndef __VMLINUX_H__
#define __VMLINUX_H__

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute push (__attribute__((preserve_access_index)), apply_to = record)
#endif

typedef unsigned char __u8;

typedef short unsigned int __u16;

typedef int __s32;

typedef unsigned int __u32;

typedef long long unsigned int __u64;

typedef signed char s8;

typedef unsigned char u8;

typedef short int s16;

typedef short unsigned int u16;

typedef unsigned int u32;

typedef long long int s64;

typedef long long unsigned int u64;

typedef long int __kernel_long_t;

typedef long unsigned int __kernel_ulong_t;

typedef int __kernel_pid_t;

typedef unsigned int __kernel_uid32_t;

typedef unsigned int __kernel_gid32_t;

typedef __kernel_ulong_t __kernel_size_t;

typedef __kernel_long_t __kernel_time_t;

typedef __kernel_long_t __kernel_clock_t;

typedef int __kernel_timer_t;

typedef int __kernel_clockid_t;

typedef __kernel_pid_t pid_t;

typedef __kernel_clockid_t clockid_t;

typedef _Bool bool;

typedef __kernel_uid32_t uid_t;

typedef __kernel_gid32_t gid_t;

typedef __kernel_size_t size_t;

typedef __kernel_time_t time_t;

typedef __s32 int32_t;

typedef __u32 uint32_t;

typedef unsigned int gfp_t;

typedef unsigned int oom_flags_t;

typedef u64 phys_addr_t;

typedef phys_addr_t resource_size_t;

typedef struct {
	int counter;
} atomic_t;

typedef struct {
	long int counter;
} atomic64_t;

struct list_head {
	struct list_head *next;
	struct list_head *prev;
};

struct hlist_node;

struct hlist_head {
	struct hlist_node *first;
};

struct hlist_node {
	struct hlist_node *next;
	struct hlist_node **pprev;
};

struct callback_head {
	struct callback_head *next;
	void (*func)(struct callback_head *);
};

struct timespec {
	__kernel_time_t tv_sec;
	long int tv_nsec;
};

struct pt_regs {
	long unsigned int r15;
	long unsigned int r14;
	long unsigned int r13;
	long unsigned int r12;
	long unsigned int bp;
	long unsigned int bx;
	long unsigned int r11;
	long unsigned int r10;
	long unsigned int r9;
	long unsigned int r8;
	long unsigned int ax;
	long unsigned int cx;
	long unsigned int dx;
	long unsigned int si;
	long unsigned int di;
	long unsigned int orig_ax;
	long unsigned int ip;
	long unsigned int cs;
	long unsigned int flags;
	long unsigned int sp;
	long unsigned int ss;
};

struct desc_struct {
	union {
		struct {
			unsigned int a;
			unsigned int b;
		};
		struct {
			u16 limit0;
			u16 base0;
			unsigned int base1: 8;
			unsigned int type: 4;
			unsigned int s: 1;
			unsigned int dpl: 2;
			unsigned int p: 1;
			unsigned int limit: 4;
			unsigned int avl: 1;
			unsigned int l: 1;
			unsigned int d: 1;
			unsigned int g: 1;
			unsigned int base2: 8;
		};
	};
};

enum {
	GATE_INTERRUPT = 14,
	GATE_TRAP = 15,
	GATE_CALL = 12,
	GATE_TASK = 5,
};

struct gate_struct64 {
	u16 offset_low;
	u16 segment;
	unsigned int ist: 3;
	unsigned int zero0: 5;
	unsigned int type: 5;
	unsigned int dpl: 2;
	unsigned int p: 1;
	u16 offset_middle;
	u32 offset_high;
	u32 zero1;
};

typedef struct gate_struct64 gate_desc;

struct desc_ptr {
	short unsigned int size;
	long unsigned int address;
} __attribute__((packed));

typedef long unsigned int pteval_t;

typedef long unsigned int pmdval_t;

typedef long unsigned int pudval_t;

typedef long unsigned int pgdval_t;

typedef long unsigned int pgprotval_t;

typedef struct {
	pteval_t pte;
} pte_t;

struct pgprot {
	pgprotval_t pgprot;
};

typedef struct pgprot pgprot_t;

typedef struct {
	pgdval_t pgd;
} pgd_t;

typedef struct {
	pudval_t pud;
} pud_t;

typedef struct {
	pmdval_t pmd;
} pmd_t;

struct page;

typedef struct page *pgtable_t;

struct slab;

typedef u32 __ticketpair_t;

typedef u16 __ticket_t;

struct __raw_tickets {
	__ticket_t head;
	__ticket_t tail;
};

struct arch_spinlock {
	union {
		__ticketpair_t head_tail;
		struct __raw_tickets tickets;
	};
};

typedef struct arch_spinlock arch_spinlock_t;

struct raw_spinlock {
	arch_spinlock_t raw_lock;
};

struct spinlock {
	union {
		struct raw_spinlock rlock;
	};
};

typedef struct spinlock spinlock_t;

struct address_space;

struct kmem_cache;

struct page {
	long unsigned int flags;
	struct address_space *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page *first_page;
	};
	long: 64;
};

struct paravirt_callee_save {
	void *func;
};

struct pv_info {
	unsigned int kernel_rpl;
	int shared_kernel_pmd;
	u16 extra_user_64bit_cs;
	int paravirt_enabled;
	const char *name;
};

struct pv_lazy_ops {
	void (*enter)();
	void (*leave)();
	void (*flush)();
};

struct pv_time_ops {
	long long unsigned int (*sched_clock)();
	long long unsigned int (*steal_clock)(int);
	long unsigned int (*get_tsc_khz)();
};

struct thread_struct;

struct tss_struct;

struct task_struct;

struct pv_cpu_ops {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct *);
	void (*end_context_switch)(struct task_struct *);
};

union thread_xstate;

struct fpu {
	unsigned int last_cpu;
	unsigned int has_fpu;
	union thread_xstate *state;
};

struct perf_event;

struct thread_struct {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct x86_hw_tss {
	u32 reserved1;
	u64 sp0;
	u64 sp1;
	u64 sp2;
	u64 reserved2;
	u64 ist[7];
	u32 reserved3;
	u32 reserved4;
	u16 reserved5;
	u16 io_bitmap_base;
	long: 64;
	long: 64;
	long: 64;
} __attribute__((packed));

struct tss_struct {
	struct x86_hw_tss x86_tss;
	long unsigned int io_bitmap[1025];
	long unsigned int stack[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct llist_node {
	struct llist_node *next;
};

struct load_weight {
	long unsigned int weight;
	long unsigned int inv_weight;
};

struct rb_node {
	long unsigned int __rb_parent_color;
	struct rb_node *rb_right;
	struct rb_node *rb_left;
};

struct sched_statistics {
	u64 wait_start;
	u64 wait_max;
	u64 wait_count;
	u64 wait_sum;
	u64 iowait_count;
	u64 iowait_sum;
	u64 sleep_start;
	u64 sleep_max;
	s64 sum_sleep_runtime;
	u64 block_start;
	u64 block_max;
	u64 exec_max;
	u64 slice_max;
	u64 nr_migrations_cold;
	u64 nr_failed_migrations_affine;
	u64 nr_failed_migrations_running;
	u64 nr_failed_migrations_hot;
	u64 nr_forced_migrations;
	u64 nr_wakeups;
	u64 nr_wakeups_sync;
	u64 nr_wakeups_migrate;
	u64 nr_wakeups_local;
	u64 nr_wakeups_remote;
	u64 nr_wakeups_affine;
	u64 nr_wakeups_affine_attempts;
	u64 nr_wakeups_passive;
	u64 nr_wakeups_idle;
};

struct sched_avg {
	u32 runnable_avg_sum;
	u32 runnable_avg_period;
	u64 last_runnable_update;
	s64 decay_count;
	long unsigned int load_avg_contrib;
};

struct cfs_rq;

struct sched_entity {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity *parent;
	struct cfs_rq *cfs_rq;
	struct cfs_rq *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq;

struct sched_rt_entity {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity *back;
	struct sched_rt_entity *parent;
	struct rt_rq *rt_rq;
	struct rt_rq *my_q;
};

struct cpumask {
	long unsigned int bits[80];
};

typedef struct cpumask cpumask_t;

struct sched_info {
	long unsigned int pcount;
	long long unsigned int run_delay;
	long long unsigned int last_arrival;
	long long unsigned int last_queued;
};

struct plist_node {
	int prio;
	struct list_head prio_list;
	struct list_head node_list;
};

struct task_rss_stat {
	int events;
	int count[3];
};

struct pid;

struct pid_link {
	struct hlist_node node;
	struct pid *pid;
};

typedef u64 cputime_t;

typedef struct raw_spinlock raw_spinlock_t;

struct prev_cputime {
	cputime_t utime;
	cputime_t stime;
	raw_spinlock_t lock;
};

struct seqcount {
	unsigned int sequence;
};

typedef struct {
	struct seqcount seqcount;
	spinlock_t lock;
} seqlock_t;

struct task_cputime {
	cputime_t utime;
	cputime_t stime;
	long long unsigned int sum_exec_runtime;
};

struct sem_undo_list;

struct sysv_sem {
	struct sem_undo_list *undo_list;
};

typedef struct {
	long unsigned int sig[1];
} sigset_t;

struct sigpending {
	struct list_head list;
	sigset_t signal;
};

typedef struct {
	uid_t val;
} kuid_t;

struct seccomp_filter;

struct seccomp {
	int mode;
	struct seccomp_filter *filter;
};

struct wake_q_node {
	struct wake_q_node *next;
};

struct plist_head {
	struct list_head node_list;
};

struct task_io_accounting {
	u64 rchar;
	u64 wchar;
	u64 syscr;
	u64 syscw;
	u64 read_bytes;
	u64 write_bytes;
	u64 cancelled_write_bytes;
};

typedef struct {
	long unsigned int bits[16];
} nodemask_t;

typedef struct seqcount seqcount_t;

struct cpuacct;

struct optimistic_spin_queue;

struct mutex {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct numa_group;

struct page_frag {
	struct page *page;
	__u32 offset;
	__u32 size;
};

struct mem_cgroup;

struct memcg_batch_info {
	int do_batch;
	struct mem_cgroup *memcg;
	long unsigned int nr_pages;
	long unsigned int memsw_nr_pages;
};

struct memcg_oom_info {
	struct mem_cgroup *memcg;
	gfp_t gfp_mask;
	int order;
	unsigned int may_oom: 1;
};

struct sched_class;

struct task_group;

struct mm_struct;

struct completion;

struct cred;

struct fs_struct;

struct files_struct;

struct nsproxy;

struct signal_struct;

struct sighand_struct;

struct audit_context;

struct rt_mutex_waiter;

struct bio_list;

struct blk_plug;

struct reclaim_state;

struct backing_dev_info;

struct io_context;

struct siginfo;

typedef struct siginfo siginfo_t;

struct css_set;

struct robust_list_head;

struct compat_robust_list_head;

struct futex_pi_state;

struct perf_event_context;

struct mempolicy;

struct pipe_inode_info;

struct task_delay_info;

struct ftrace_ret_stack;

struct uprobe_task;

struct task_struct {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct *mm;
	struct mm_struct *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct *real_parent;
	struct task_struct *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING = 0,
		VTIME_USER = 1,
		VTIME_SYS = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_irq_ops {
	struct paravirt_callee_save save_fl;
	struct paravirt_callee_save restore_fl;
	struct paravirt_callee_save irq_disable;
	struct paravirt_callee_save irq_enable;
	void (*safe_halt)();
	void (*halt)();
	void (*adjust_exception_frame)();
};

struct pv_apic_ops {
	void (*startup_ipi_hook)(int, long unsigned int, long unsigned int);
};

struct pv_mmu_ops {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct *, struct mm_struct *);
	void (*dup_mmap)(struct mm_struct *, struct mm_struct *);
	void (*exit_mmap)(struct mm_struct *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct *);
	void (*pgd_free)(struct mm_struct *, pgd_t *);
	void (*alloc_pte)(struct mm_struct *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct *, long unsigned int);
	void (*alloc_pud)(struct mm_struct *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct rb_root {
	struct rb_node *rb_node;
};

typedef atomic64_t atomic_long_t;

struct rw_semaphore {
	long int count;
	raw_spinlock_t wait_lock;
	struct list_head wait_list;
};

struct mm_rss_stat {
	atomic_long_t count[3];
};

typedef struct cpumask *cpumask_var_t;

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex lock;
	void *vdso;
} mm_context_t;

struct xol_area;

struct uprobes_state {
	struct xol_area *xol_area;
};

struct vm_area_struct;

struct file;

struct linux_binfmt;

struct core_state;

struct mmu_notifier_mm;

struct mm_struct {
	struct vm_area_struct *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t context;
	long unsigned int flags;
	struct core_state *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pv_lock_ops {
	struct paravirt_callee_save lock_spinning;
	void (*unlock_kick)(struct arch_spinlock *, __ticket_t);
};

struct kernel_vm86_regs {
	struct pt_regs pt;
	short unsigned int es;
	short unsigned int __esh;
	short unsigned int ds;
	short unsigned int __dsh;
	short unsigned int fs;
	short unsigned int __fsh;
	short unsigned int gs;
	short unsigned int __gsh;
};

struct math_emu_info {
	long int ___orig_eip;
	union {
		struct pt_regs *regs;
		struct kernel_vm86_regs *vm86;
	};
};

struct cpuinfo_x86 {
	__u8 x86;
	__u8 x86_vendor;
	__u8 x86_model;
	__u8 x86_mask;
	int x86_tlbsize;
	__u8 x86_virt_bits;
	__u8 x86_phys_bits;
	__u8 x86_coreid_bits;
	__u32 extended_cpuid_level;
	int cpuid_level;
	__u32 x86_capability[30];
	char x86_vendor_id[16];
	char x86_model_id[64];
	int x86_cache_size;
	int x86_cache_alignment;
	int x86_power;
	long unsigned int loops_per_jiffy;
	u16 x86_max_cores;
	u16 apicid;
	u16 initial_apicid;
	u16 x86_clflush_size;
	u16 booted_cores;
	u16 phys_proc_id;
	u16 cpu_core_id;
	u8 compute_unit_id;
	u16 cpu_index;
	u32 microcode;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct i387_fsave_struct {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
	u32 status;
};

struct i387_fxsave_struct {
	u16 cwd;
	u16 swd;
	u16 twd;
	u16 fop;
	union {
		struct {
			u64 rip;
			u64 rdp;
		};
		struct {
			u32 fip;
			u32 fcs;
			u32 foo;
			u32 fos;
		};
	};
	u32 mxcsr;
	u32 mxcsr_mask;
	u32 st_space[32];
	u32 xmm_space[64];
	u32 padding[12];
	union {
		u32 padding1[12];
		u32 sw_reserved[12];
	};
};

struct i387_soft_struct {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
	u8 ftop;
	u8 changed;
	u8 lookahead;
	u8 no_update;
	u8 rm;
	u8 alimit;
	struct math_emu_info *info;
	u32 entry_eip;
};

struct ymmh_struct {
	u32 ymmh_space[64];
};

struct lwp_struct {
	u64 lwpcb_addr;
	u32 flags;
	u32 buf_head_offset;
	u64 buf_base;
	u32 buf_size;
	u32 filters;
	u64 saved_event_record[4];
	u32 event_counter[16];
};

struct bndreg {
	u64 lower_bound;
	u64 upper_bound;
};

struct bndcsr {
	u64 bndcfgu;
	u64 bndstatus;
};

struct xsave_hdr_struct {
	u64 xstate_bv;
	u64 xcomp_bv;
	u64 reserved[6];
};

struct xsave_struct {
	struct i387_fxsave_struct i387;
	struct xsave_hdr_struct xsave_hdr;
	struct ymmh_struct ymmh;
	struct lwp_struct lwp;
	struct bndreg bndreg[4];
	struct bndcsr bndcsr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union thread_xstate {
	struct i387_fsave_struct fsave;
	struct i387_fxsave_struct fxsave;
	struct i387_soft_struct soft;
	struct xsave_struct xsave;
};

union irq_stack_union {
	char irq_stack[16384];
	struct {
		char gs_base[40];
		long unsigned int stack_canary;
	};
};

struct mpc_table {
	char signature[4];
	short unsigned int length;
	char spec;
	char checksum;
	char oem[8];
	char productid[12];
	unsigned int oemptr;
	short unsigned int oemsize;
	short unsigned int oemcount;
	unsigned int lapic;
	unsigned int reserved;
};

struct mpc_cpu {
	unsigned char type;
	unsigned char apicid;
	unsigned char apicver;
	unsigned char cpuflag;
	unsigned int cpufeature;
	unsigned int featureflag;
	unsigned int reserved[2];
};

struct mpc_bus {
	unsigned char type;
	unsigned char busid;
	unsigned char bustype[6];
};

struct screen_info {
	__u8 orig_x;
	__u8 orig_y;
	__u16 ext_mem_k;
	__u16 orig_video_page;
	__u8 orig_video_mode;
	__u8 orig_video_cols;
	__u8 flags;
	__u8 unused2;
	__u16 orig_video_ega_bx;
	__u16 unused3;
	__u8 orig_video_lines;
	__u8 orig_video_isVGA;
	__u16 orig_video_points;
	__u16 lfb_width;
	__u16 lfb_height;
	__u16 lfb_depth;
	__u32 lfb_base;
	__u32 lfb_size;
	__u16 cl_magic;
	__u16 cl_offset;
	__u16 lfb_linelength;
	__u8 red_size;
	__u8 red_pos;
	__u8 green_size;
	__u8 green_pos;
	__u8 blue_size;
	__u8 blue_pos;
	__u8 rsvd_size;
	__u8 rsvd_pos;
	__u16 vesapm_seg;
	__u16 vesapm_off;
	__u16 pages;
	__u16 vesa_attributes;
	__u32 capabilities;
	__u8 _reserved[6];
} __attribute__((packed));

struct apm_bios_info {
	__u16 version;
	__u16 cseg;
	__u32 offset;
	__u16 cseg_16;
	__u16 dseg;
	__u16 flags;
	__u16 cseg_len;
	__u16 cseg_16_len;
	__u16 dseg_len;
};

struct edd_device_params {
	__u16 length;
	__u16 info_flags;
	__u32 num_default_cylinders;
	__u32 num_default_heads;
	__u32 sectors_per_track;
	__u64 number_of_sectors;
	__u16 bytes_per_sector;
	__u32 dpte_ptr;
	__u16 key;
	__u8 device_path_info_length;
	__u8 reserved2;
	__u16 reserved3;
	__u8 host_bus_type[4];
	__u8 interface_type[8];
	union {
		struct {
			__u16 base_address;
			__u16 reserved1;
			__u32 reserved2;
		} isa;
		struct {
			__u8 bus;
			__u8 slot;
			__u8 function;
			__u8 channel;
			__u32 reserved;
		} pci;
		struct {
			__u64 reserved;
		} ibnd;
		struct {
			__u64 reserved;
		} xprs;
		struct {
			__u64 reserved;
		} htpt;
		struct {
			__u64 reserved;
		} unknown;
	} interface_path;
	union {
		struct {
			__u8 device;
			__u8 reserved1;
			__u16 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} ata;
		struct {
			__u8 device;
			__u8 lun;
			__u8 reserved1;
			__u8 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} atapi;
		struct {
			__u16 id;
			__u64 lun;
			__u16 reserved1;
			__u32 reserved2;
		} __attribute__((packed)) scsi;
		struct {
			__u64 serial_number;
			__u64 reserved;
		} usb;
		struct {
			__u64 eui;
			__u64 reserved;
		} i1394;
		struct {
			__u64 wwid;
			__u64 lun;
		} fibre;
		struct {
			__u64 identity_tag;
			__u64 reserved;
		} i2o;
		struct {
			__u32 array_number;
			__u32 reserved1;
			__u64 reserved2;
		} raid;
		struct {
			__u8 device;
			__u8 reserved1;
			__u16 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} sata;
		struct {
			__u64 reserved1;
			__u64 reserved2;
		} unknown;
	} device_path;
	__u8 reserved4;
	__u8 checksum;
} __attribute__((packed));

struct edd_info {
	__u8 device;
	__u8 version;
	__u16 interface_support;
	__u16 legacy_max_cylinder;
	__u8 legacy_max_head;
	__u8 legacy_sectors_per_track;
	struct edd_device_params params;
} __attribute__((packed));

struct e820entry {
	__u64 addr;
	__u64 size;
	__u32 type;
} __attribute__((packed));

struct resource {
	resource_size_t start;
	resource_size_t end;
	const char *name;
	long unsigned int flags;
	struct resource *parent;
	struct resource *sibling;
	struct resource *child;
};

struct ist_info {
	__u32 signature;
	__u32 command;
	__u32 event;
	__u32 perf_level;
};

struct edid_info {
	unsigned char dummy[128];
};

struct setup_header {
	__u8 setup_sects;
	__u16 root_flags;
	__u32 syssize;
	__u16 ram_size;
	__u16 vid_mode;
	__u16 root_dev;
	__u16 boot_flag;
	__u16 jump;
	__u32 header;
	__u16 version;
	__u32 realmode_swtch;
	__u16 start_sys;
	__u16 kernel_version;
	__u8 type_of_loader;
	__u8 loadflags;
	__u16 setup_move_size;
	__u32 code32_start;
	__u32 ramdisk_image;
	__u32 ramdisk_size;
	__u32 bootsect_kludge;
	__u16 heap_end_ptr;
	__u8 ext_loader_ver;
	__u8 ext_loader_type;
	__u32 cmd_line_ptr;
	__u32 initrd_addr_max;
	__u32 kernel_alignment;
	__u8 relocatable_kernel;
	__u8 min_alignment;
	__u16 xloadflags;
	__u32 cmdline_size;
	__u32 hardware_subarch;
	__u64 hardware_subarch_data;
	__u32 payload_offset;
	__u32 payload_length;
	__u64 setup_data;
	__u64 pref_address;
	__u32 init_size;
	__u32 handover_offset;
} __attribute__((packed));

struct sys_desc_table {
	__u16 length;
	__u8 table[14];
};

struct olpc_ofw_header {
	__u32 ofw_magic;
	__u32 ofw_version;
	__u32 cif_handler;
	__u32 irq_desc_table;
};

struct efi_info {
	__u32 efi_loader_signature;
	__u32 efi_systab;
	__u32 efi_memdesc_size;
	__u32 efi_memdesc_version;
	__u32 efi_memmap;
	__u32 efi_memmap_size;
	__u32 efi_systab_hi;
	__u32 efi_memmap_hi;
};

struct boot_params {
	struct screen_info screen_info;
	struct apm_bios_info apm_bios_info;
	__u8 _pad2[4];
	__u64 tboot_addr;
	struct ist_info ist_info;
	__u8 _pad3[16];
	__u8 hd0_info[16];
	__u8 hd1_info[16];
	struct sys_desc_table sys_desc_table;
	struct olpc_ofw_header olpc_ofw_header;
	__u32 ext_ramdisk_image;
	__u32 ext_ramdisk_size;
	__u32 ext_cmd_line_ptr;
	__u8 _pad4[116];
	struct edid_info edid_info;
	struct efi_info efi_info;
	__u32 alt_mem_k;
	__u32 scratch;
	__u8 e820_entries;
	__u8 eddbuf_entries;
	__u8 edd_mbr_sig_buf_entries;
	__u8 kbd_status;
	__u8 secure_boot;
	__u8 _pad5[2];
	__u8 sentinel;
	__u8 _pad6[1];
	struct setup_header hdr;
	__u8 _pad7[40];
	__u32 edd_mbr_sig_buffer[16];
	struct e820entry e820_map[128];
	__u8 _pad8[48];
	struct edd_info eddbuf[6];
	__u8 _pad9[276];
} __attribute__((packed));

struct x86_init_mpparse {
	void (*mpc_record)(unsigned int);
	void (*setup_ioapic_ids)();
	int (*mpc_apic_id)(struct mpc_cpu *);
	void (*smp_read_mpc_oem)(struct mpc_table *);
	void (*mpc_oem_pci_bus)(struct mpc_bus *);
	void (*mpc_oem_bus_info)(struct mpc_bus *, char *);
	void (*find_smp_config)();
	void (*get_smp_config)(unsigned int);
};

struct x86_init_resources {
	void (*probe_roms)();
	void (*reserve_resources)();
	char * (*memory_setup)();
};

struct x86_init_irqs {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*trap_init)();
};

struct x86_init_oem {
	void (*arch_setup)();
	void (*banner)();
};

struct x86_init_paging {
	void (*pagetable_init)();
};

struct x86_init_timers {
	void (*setup_percpu_clockev)();
	void (*tsc_pre_init)();
	void (*timer_init)();
	void (*wallclock_init)();
};

struct x86_init_iommu {
	int (*iommu_init)();
};

struct x86_init_pci {
	int (*arch_init)();
	int (*init)();
	void (*init_irq)();
	void (*fixup_irqs)();
};

struct x86_init_ops {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
};

struct x86_platform_ops {
	long unsigned int (*calibrate_tsc)();
	void (*get_wallclock)(struct timespec *);
	int (*set_wallclock)(const struct timespec *);
	void (*iommu_shutdown)();
	bool (*is_untracked_pat_range)(u64, u64);
	void (*nmi_init)();
	unsigned char (*get_nmi_reason)();
	int (*i8042_detect)();
	void (*save_sched_clock_state)();
	void (*restore_sched_clock_state)();
	void (*apic_post_init)();
};

struct irq_data;

struct IO_APIC_route_entry;

struct io_apic_irq_attr;

struct x86_io_apic_ops {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct IO_APIC_route_entry {
	__u32 vector: 8;
	__u32 delivery_mode: 3;
	__u32 dest_mode: 1;
	__u32 delivery_status: 1;
	__u32 polarity: 1;
	__u32 irr: 1;
	__u32 trigger: 1;
	__u32 mask: 1;
	__u32 __reserved_2: 15;
	__u32 __reserved_3: 24;
	__u32 dest: 8;
};

struct physid_mask {
	long unsigned int mask[512];
};

typedef struct physid_mask physid_mask_t;

struct jump_entry;

struct static_key_mod;

struct static_key {
	atomic_t enabled;
	struct jump_entry *entries;
	struct static_key_mod *next;
};

typedef u64 jump_label_t;

struct jump_entry {
	jump_label_t code;
	jump_label_t target;
	jump_label_t key;
};

union ktime {
	s64 tv64;
};

typedef union ktime ktime_t;

struct __wait_queue_head {
	spinlock_t lock;
	struct list_head task_list;
};

typedef struct __wait_queue_head wait_queue_head_t;

struct completion {
	unsigned int done;
	wait_queue_head_t wait;
};

enum fixed_addresses {
	VSYSCALL_LAST_PAGE = 0,
	VSYSCALL_FIRST_PAGE = 2047,
	VVAR_PAGE = 2048,
	VSYSCALL_HPET = 2049,
	PVCLOCK_FIXMAP_BEGIN = 2050,
	PVCLOCK_FIXMAP_END = 2129,
	FIX_DBGP_BASE = 2130,
	FIX_EARLYCON_MEM_BASE = 2131,
	FIX_OHCI1394_BASE = 2132,
	FIX_APIC_BASE = 2133,
	FIX_IO_APIC_BASE_0 = 2134,
	FIX_IO_APIC_BASE_END = 2261,
	FIX_RO_IDT = 2262,
	FIX_PARAVIRT_BOOTMAP = 2263,
	FIX_TEXT_POKE1 = 2264,
	FIX_TEXT_POKE0 = 2265,
	__end_of_permanent_fixed_addresses = 2266,
	FIX_BTMAP_END = 2266,
	FIX_BTMAP_BEGIN = 2521,
	FIX_TBOOT_BASE = 2522,
	__end_of_fixed_addresses = 2523,
};

struct apic {
	char *name;
	int (*probe)();
	int (*acpi_madt_oem_check)(char *, char *);
	int (*apic_id_valid)(int);
	int (*apic_id_registered)();
	u32 irq_delivery_mode;
	u32 irq_dest_mode;
	const struct cpumask * (*target_cpus)();
	int disable_esr;
	int dest_logical;
	long unsigned int (*check_apicid_used)(physid_mask_t *, int);
	long unsigned int (*check_apicid_present)(int);
	void (*vector_allocation_domain)(int, struct cpumask *, const struct cpumask *);
	void (*init_apic_ldr)();
	void (*ioapic_phys_id_map)(physid_mask_t *, physid_mask_t *);
	void (*setup_apic_routing)();
	int (*multi_timer_check)(int, int);
	int (*cpu_present_to_apicid)(int);
	void (*apicid_to_cpu_present)(int, physid_mask_t *);
	void (*setup_portio_remap)();
	int (*check_phys_apicid_present)(int);
	void (*enable_apic_mode)();
	int (*phys_pkg_id)(int, int);
	int (*mps_oem_check)(struct mpc_table *, char *, char *);
	unsigned int (*get_apic_id)(long unsigned int);
	long unsigned int (*set_apic_id)(unsigned int);
	long unsigned int apic_id_mask;
	int (*cpu_mask_to_apicid_and)(const struct cpumask *, const struct cpumask *, unsigned int *);
	void (*send_IPI_mask)(const struct cpumask *, int);
	void (*send_IPI_mask_allbutself)(const struct cpumask *, int);
	void (*send_IPI_allbutself)(int);
	void (*send_IPI_all)(int);
	void (*send_IPI_self)(int);
	int (*wakeup_secondary_cpu)(int, long unsigned int);
	int trampoline_phys_low;
	int trampoline_phys_high;
	void (*wait_for_init_deassert)(atomic_t *);
	void (*smp_callin_clear_local_apic)();
	void (*inquire_remote_apic)(int);
	u32 (*read)(u32);
	void (*write)(u32, u32);
	void (*eoi_write)(u32, u32);
	u64 (*icr_read)();
	void (*icr_write)(u32, u32);
	void (*wait_icr_idle)();
	u32 (*safe_wait_icr_idle)();
};

struct smp_ops {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

enum pcpu_fc {
	PCPU_FC_AUTO = 0,
	PCPU_FC_EMBED = 1,
	PCPU_FC_PAGE = 2,
	PCPU_FC_NR = 3,
};

enum {
	MIGRATE_UNMOVABLE = 0,
	MIGRATE_RECLAIMABLE = 1,
	MIGRATE_MOVABLE = 2,
	MIGRATE_PCPTYPES = 3,
	MIGRATE_RESERVE = 3,
	MIGRATE_CMA = 4,
	MIGRATE_ISOLATE = 5,
	MIGRATE_TYPES = 6,
};

struct free_area {
	struct list_head free_list[6];
	long unsigned int nr_free;
};

struct zone_padding {
	char x[0];
};

enum zone_stat_item {
	NR_FREE_PAGES = 0,
	NR_ALLOC_BATCH = 1,
	NR_LRU_BASE = 2,
	NR_INACTIVE_ANON = 2,
	NR_ACTIVE_ANON = 3,
	NR_INACTIVE_FILE = 4,
	NR_ACTIVE_FILE = 5,
	NR_UNEVICTABLE = 6,
	NR_MLOCK = 7,
	NR_ANON_PAGES = 8,
	NR_FILE_MAPPED = 9,
	NR_FILE_PAGES = 10,
	NR_FILE_DIRTY = 11,
	NR_WRITEBACK = 12,
	NR_SLAB_RECLAIMABLE = 13,
	NR_SLAB_UNRECLAIMABLE = 14,
	NR_PAGETABLE = 15,
	NR_KERNEL_STACK = 16,
	NR_UNSTABLE_NFS = 17,
	NR_BOUNCE = 18,
	NR_VMSCAN_WRITE = 19,
	NR_VMSCAN_IMMEDIATE = 20,
	NR_WRITEBACK_TEMP = 21,
	NR_ISOLATED_ANON = 22,
	NR_ISOLATED_FILE = 23,
	NR_SHMEM = 24,
	NR_DIRTIED = 25,
	NR_WRITTEN = 26,
	NUMA_HIT = 27,
	NUMA_MISS = 28,
	NUMA_FOREIGN = 29,
	NUMA_INTERLEAVE_HIT = 30,
	NUMA_LOCAL = 31,
	NUMA_OTHER = 32,
	WORKINGSET_REFAULT = 33,
	WORKINGSET_ACTIVATE = 34,
	WORKINGSET_NODERECLAIM = 35,
	NR_ANON_TRANSPARENT_HUGEPAGES = 36,
	NR_FREE_CMA_PAGES = 37,
	NR_VM_ZONE_STAT_ITEMS = 38,
};

enum lru_list {
	LRU_INACTIVE_ANON = 0,
	LRU_ACTIVE_ANON = 1,
	LRU_INACTIVE_FILE = 2,
	LRU_ACTIVE_FILE = 3,
	LRU_UNEVICTABLE = 4,
	NR_LRU_LISTS = 5,
};

struct zone_reclaim_stat {
	long unsigned int recent_rotated[2];
	long unsigned int recent_scanned[2];
};

struct zone;

struct lruvec {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone *zone;
};

struct per_cpu_pageset;

struct pglist_data;

struct zone {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum zone_watermarks {
	WMARK_MIN = 0,
	WMARK_LOW = 1,
	WMARK_HIGH = 2,
	NR_WMARK = 3,
};

struct per_cpu_pages {
	int count;
	int high;
	int batch;
	struct list_head lists[3];
};

struct per_cpu_pageset {
	struct per_cpu_pages pcp;
	s8 expire;
	s8 stat_threshold;
	s8 vm_stat_diff[38];
};

enum zone_type {
	ZONE_DMA = 0,
	ZONE_DMA32 = 1,
	ZONE_NORMAL = 2,
	ZONE_MOVABLE = 3,
	__MAX_NR_ZONES = 4,
};

struct zoneref {
	struct zone *zone;
	int zone_idx;
};

struct zonelist_cache {
	short unsigned int z_to_n[4096];
	long unsigned int fullzones[64];
	long unsigned int last_full_zap;
};

struct zonelist {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data {
	struct zone node_zones[4];
	struct zonelist node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page_cgroup;

struct mem_section {
	long unsigned int section_mem_map;
	long unsigned int *pageblock_flags;
	struct page_cgroup *page_cgroup;
	long unsigned int pad;
};

struct arch_uprobe_task {
	long unsigned int saved_scratch_register;
	unsigned int saved_trap_nr;
	unsigned int saved_tf;
};

enum uprobe_task_state {
	UTASK_RUNNING = 0,
	UTASK_SSTEP = 1,
	UTASK_SSTEP_ACK = 2,
	UTASK_SSTEP_TRAPPED = 3,
};

struct return_instance;

struct uprobe;

struct uprobe_task {
	enum uprobe_task_state state;
	struct arch_uprobe_task autask;
	struct return_instance *return_instances;
	unsigned int depth;
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	long unsigned int vaddr;
};

struct return_instance {
	struct uprobe *uprobe;
	long unsigned int func;
	long unsigned int stack;
	long unsigned int orig_ret_vaddr;
	bool chained;
	struct return_instance *next;
};

struct xol_area {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page *page;
	long unsigned int vaddr;
};

struct userfaultfd_ctx;

struct vm_userfaultfd_ctx {
	struct userfaultfd_ctx *ctx;
};

struct anon_vma;

struct vm_operations_struct;

struct vm_area_struct {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct *vm_next;
	struct vm_area_struct *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault;

struct vm_operations_struct {
	void (*open)(struct vm_area_struct *);
	void (*close)(struct vm_area_struct *);
	int (*fault)(struct vm_area_struct *, struct vm_fault *);
	int (*page_mkwrite)(struct vm_area_struct *, struct vm_fault *);
	int (*access)(struct vm_area_struct *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct *, long unsigned int);
	int (*migrate)(struct vm_area_struct *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread {
	struct task_struct *task;
	struct core_thread *next;
};

struct core_state {
	atomic_t nr_threads;
	struct core_thread dumper;
	struct completion startup;
};

enum {
	MM_FILEPAGES = 0,
	MM_ANONPAGES = 1,
	MM_SWAPENTS = 2,
	NR_MM_COUNTERS = 3,
};

struct rlimit {
	long unsigned int rlim_cur;
	long unsigned int rlim_max;
};

struct mm_tracker {
	struct static_key active;
	atomic_t count;
	long unsigned int *vector;
	long unsigned int bitcnt;
};

struct vm_fault {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page *page;
};

enum vm_event_item {
	PGPGIN = 0,
	PGPGOUT = 1,
	PSWPIN = 2,
	PSWPOUT = 3,
	PGALLOC_DMA = 4,
	PGALLOC_DMA32 = 5,
	PGALLOC_NORMAL = 6,
	PGALLOC_MOVABLE = 7,
	PGFREE = 8,
	PGACTIVATE = 9,
	PGDEACTIVATE = 10,
	PGFAULT = 11,
	PGMAJFAULT = 12,
	PGREFILL_DMA = 13,
	PGREFILL_DMA32 = 14,
	PGREFILL_NORMAL = 15,
	PGREFILL_MOVABLE = 16,
	PGSTEAL_KSWAPD_DMA = 17,
	PGSTEAL_KSWAPD_DMA32 = 18,
	PGSTEAL_KSWAPD_NORMAL = 19,
	PGSTEAL_KSWAPD_MOVABLE = 20,
	PGSTEAL_DIRECT_DMA = 21,
	PGSTEAL_DIRECT_DMA32 = 22,
	PGSTEAL_DIRECT_NORMAL = 23,
	PGSTEAL_DIRECT_MOVABLE = 24,
	PGSCAN_KSWAPD_DMA = 25,
	PGSCAN_KSWAPD_DMA32 = 26,
	PGSCAN_KSWAPD_NORMAL = 27,
	PGSCAN_KSWAPD_MOVABLE = 28,
	PGSCAN_DIRECT_DMA = 29,
	PGSCAN_DIRECT_DMA32 = 30,
	PGSCAN_DIRECT_NORMAL = 31,
	PGSCAN_DIRECT_MOVABLE = 32,
	PGSCAN_DIRECT_THROTTLE = 33,
	PGSCAN_ZONE_RECLAIM_FAILED = 34,
	PGINODESTEAL = 35,
	SLABS_SCANNED = 36,
	KSWAPD_INODESTEAL = 37,
	KSWAPD_LOW_WMARK_HIT_QUICKLY = 38,
	KSWAPD_HIGH_WMARK_HIT_QUICKLY = 39,
	PAGEOUTRUN = 40,
	ALLOCSTALL = 41,
	PGROTATED = 42,
	DROP_PAGECACHE = 43,
	DROP_SLAB = 44,
	NUMA_PTE_UPDATES = 45,
	NUMA_HUGE_PTE_UPDATES = 46,
	NUMA_HINT_FAULTS = 47,
	NUMA_HINT_FAULTS_LOCAL = 48,
	NUMA_PAGE_MIGRATE = 49,
	PGMIGRATE_SUCCESS = 50,
	PGMIGRATE_FAIL = 51,
	COMPACTMIGRATE_SCANNED = 52,
	COMPACTFREE_SCANNED = 53,
	COMPACTISOLATED = 54,
	COMPACTSTALL = 55,
	COMPACTFAIL = 56,
	COMPACTSUCCESS = 57,
	HTLB_BUDDY_PGALLOC = 58,
	HTLB_BUDDY_PGALLOC_FAIL = 59,
	UNEVICTABLE_PGCULLED = 60,
	UNEVICTABLE_PGSCANNED = 61,
	UNEVICTABLE_PGRESCUED = 62,
	UNEVICTABLE_PGMLOCKED = 63,
	UNEVICTABLE_PGMUNLOCKED = 64,
	UNEVICTABLE_PGCLEARED = 65,
	UNEVICTABLE_PGSTRANDED = 66,
	THP_FAULT_ALLOC = 67,
	THP_FAULT_FALLBACK = 68,
	THP_COLLAPSE_ALLOC = 69,
	THP_COLLAPSE_ALLOC_FAILED = 70,
	THP_SPLIT = 71,
	THP_ZERO_PAGE_ALLOC = 72,
	THP_ZERO_PAGE_ALLOC_FAILED = 73,
	NR_VM_EVENT_ITEMS = 74,
};

struct vm_event_state {
	long unsigned int event[74];
};

struct memblock_region {
	phys_addr_t base;
	phys_addr_t size;
	long unsigned int flags;
	int nid;
};

struct memblock_type {
	long unsigned int cnt;
	long unsigned int max;
	phys_addr_t total_size;
	struct memblock_region *regions;
};

struct memblock {
	bool bottom_up;
	phys_addr_t current_limit;
	struct memblock_type memory;
	struct memblock_type reserved;
};

struct gdt_page {
	struct desc_struct gdt[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_cap_struct {
	__u32 cap[2];
};

typedef struct kernel_cap_struct kernel_cap_t;

typedef struct {
	gid_t val;
} kgid_t;

typedef void __signalfn_t(int);

typedef __signalfn_t *__sighandler_t;

typedef void __restorefn_t();

typedef __restorefn_t *__sigrestore_t;

union sigval {
	int sival_int;
	void *sival_ptr;
};

typedef union sigval sigval_t;

struct siginfo {
	int si_signo;
	int si_errno;
	int si_code;
	union {
		int _pad[28];
		struct {
			__kernel_pid_t _pid;
			__kernel_uid32_t _uid;
		} _kill;
		struct {
			__kernel_timer_t _tid;
			int _overrun;
			char _pad[0];
			sigval_t _sigval;
			int _sys_private;
		} _timer;
		struct {
			__kernel_pid_t _pid;
			__kernel_uid32_t _uid;
			sigval_t _sigval;
		} _rt;
		struct {
			__kernel_pid_t _pid;
			__kernel_uid32_t _uid;
			int _status;
			__kernel_clock_t _utime;
			__kernel_clock_t _stime;
		} _sigchld;
		struct {
			void *_addr;
			short int _addr_lsb;
			struct {
				void *_lower;
				void *_upper;
			} _addr_bnd;
		} _sigfault;
		struct {
			long int _band;
			int _fd;
		} _sigpoll;
		struct {
			void *_call_addr;
			int _syscall;
			unsigned int _arch;
		} _sigsys;
	} _sifields;
};

struct key;

struct user_struct {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key *uid_keyring;
	struct key *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct sigaction {
	__sighandler_t sa_handler;
	long unsigned int sa_flags;
	__sigrestore_t sa_restorer;
	sigset_t sa_mask;
};

struct k_sigaction {
	struct sigaction sa;
};

enum pid_type {
	PIDTYPE_PID = 0,
	PIDTYPE_PGID = 1,
	PIDTYPE_SID = 2,
	PIDTYPE_MAX = 3,
};

struct pid_namespace;

struct upid {
	int nr;
	struct pid_namespace *ns;
	struct hlist_node pid_chain;
};

struct pid {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid numbers[1];
};

struct timerqueue_node {
	struct rb_node node;
	ktime_t expires;
};

struct timerqueue_head {
	struct rb_root head;
	struct timerqueue_node *next;
};

enum hrtimer_restart {
	HRTIMER_NORESTART = 0,
	HRTIMER_RESTART = 1,
};

struct hrtimer_clock_base;

struct hrtimer {
	struct timerqueue_node node;
	ktime_t _softexpires;
	enum hrtimer_restart (*function)(struct hrtimer *);
	struct hrtimer_clock_base *base;
	long unsigned int state;
	int start_pid;
	void *start_site;
	char start_comm[16];
};

struct hrtimer_cpu_base;

struct hrtimer_clock_base {
	struct hrtimer_cpu_base *cpu_base;
	int index;
	clockid_t clockid;
	struct timerqueue_head active;
	ktime_t resolution;
	ktime_t (*get_time)();
	ktime_t rh_reserved_softirq_time;
	ktime_t offset;
};

struct hrtimer_cpu_base {
	raw_spinlock_t lock;
	unsigned int active_bases;
	unsigned int clock_was_set;
	ktime_t expires_next;
	int hres_active;
	int hang_detected;
	long unsigned int nr_events;
	long unsigned int nr_retries;
	long unsigned int nr_hangs;
	ktime_t max_hang_time;
	struct hrtimer_clock_base clock_base[4];
	int cpu;
	int in_hrtirq;
};

enum hrtimer_base_type {
	HRTIMER_BASE_MONOTONIC = 0,
	HRTIMER_BASE_REALTIME = 1,
	HRTIMER_BASE_BOOTTIME = 2,
	HRTIMER_BASE_TAI = 3,
	HRTIMER_MAX_CLOCK_BASES = 4,
};

struct assoc_array_ptr;

struct assoc_array {
	struct assoc_array_ptr *root;
	long unsigned int nr_leaves_on_tree;
};

typedef int32_t key_serial_t;

typedef uint32_t key_perm_t;

struct key_type;

struct keyring_index_key {
	struct key_type *type;
	const char *description;
	size_t desc_len;
};

struct key_user;

struct key {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct group_info {
	atomic_t usage;
	int ngroups;
	int nblocks;
	kgid_t small_block[32];
	kgid_t *blocks[0];
};

struct user_namespace;

struct cred {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct sighand_struct {
	atomic_t count;
	struct k_sigaction action[64];
	spinlock_t siglock;
	wait_queue_head_t signalfd_wqh;
};

struct pacct_struct {
	int ac_flag;
	long int ac_exitcode;
	long unsigned int ac_mem;
	cputime_t ac_utime;
	cputime_t ac_stime;
	long unsigned int ac_minflt;
	long unsigned int ac_majflt;
};

struct cpu_itimer {
	cputime_t expires;
	cputime_t incr;
	u32 error;
	u32 incr_error;
};

struct thread_group_cputimer {
	atomic64_t utime;
	atomic64_t stime;
	atomic64_t sum_exec_runtime;
	int running;
};

struct tty_struct;

struct autogroup;

struct taskstats;

struct tty_audit_buf;

struct signal_struct {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct task_delay_info {
	spinlock_t lock;
	unsigned int flags;
	struct timespec blkio_start;
	struct timespec blkio_end;
	u64 blkio_delay;
	u64 swapin_delay;
	u32 blkio_count;
	u32 swapin_count;
	struct timespec freepages_start;
	struct timespec freepages_end;
	u64 freepages_delay;
	u32 freepages_count;
};

enum cpu_idle_type {
	CPU_IDLE = 0,
	CPU_NOT_IDLE = 1,
	CPU_NEWLY_IDLE = 2,
	CPU_MAX_IDLE_TYPES = 3,
};

enum perf_event_task_context {
	perf_invalid_context = 4294967295,
	perf_hw_context = 0,
	perf_sw_context = 1,
	perf_nr_task_contexts = 2,
};

struct rq;

struct task_struct___2;

struct sched_class {
	const struct sched_class *next;
	void (*enqueue_task)(struct rq *, struct task_struct___2 *, int);
	void (*dequeue_task)(struct rq *, struct task_struct___2 *, int);
	void (*yield_task)(struct rq *);
	bool (*yield_to_task)(struct rq *, struct task_struct___2 *, bool);
	void (*check_preempt_curr)(struct rq *, struct task_struct___2 *, int);
	struct task_struct___2 * (*pick_next_task)(struct rq *);
	void (*put_prev_task)(struct rq *, struct task_struct___2 *);
	int (*select_task_rq)(struct task_struct___2 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___2 *, int);
	void (*pre_schedule)(struct rq *, struct task_struct___2 *);
	void (*post_schedule)(struct rq *);
	void (*task_waking)(struct task_struct___2 *);
	void (*task_woken)(struct rq *, struct task_struct___2 *);
	void (*set_cpus_allowed)(struct task_struct___2 *, const struct cpumask *);
	void (*rq_online)(struct rq *);
	void (*rq_offline)(struct rq *);
	void (*set_curr_task)(struct rq *);
	void (*task_tick)(struct rq *, struct task_struct___2 *, int);
	void (*task_fork)(struct task_struct___2 *);
	void (*switched_from)(struct rq *, struct task_struct___2 *);
	void (*switched_to)(struct rq *, struct task_struct___2 *);
	void (*prio_changed)(struct rq *, struct task_struct___2 *, int);
	unsigned int (*get_rr_interval)(struct rq *, struct task_struct___2 *);
	void (*task_move_group)(struct task_struct___2 *, int);
	void (*update_curr)(struct rq *);
};

struct tlb_state {
	struct mm_struct *active_mm;
	int state;
};

struct vsyscall_gtod_data;

struct mm_struct___2;

struct pv_mmu_ops___2 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___2 *, struct mm_struct___2 *);
	void (*dup_mmap)(struct mm_struct___2 *, struct mm_struct___2 *);
	void (*exit_mmap)(struct mm_struct___2 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___2 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___2 *);
	void (*pgd_free)(struct mm_struct___2 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___2 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___2 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___2 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___2 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___2 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___2 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___2 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___2 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___2 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___2 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___2 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct mutex___2 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___2 lock;
	void *vdso;
} mm_context_t___2;

struct vm_area_struct___2;

struct mm_struct___2 {
	struct vm_area_struct___2 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___2 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___2 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___2 context;
	long unsigned int flags;
	struct core_state *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct vm_operations_struct___2;

struct vm_area_struct___2 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___2 *vm_next;
	struct vm_area_struct___2 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___2 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___2 *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___2 {
	void (*open)(struct vm_area_struct___2 *);
	void (*close)(struct vm_area_struct___2 *);
	int (*fault)(struct vm_area_struct___2 *, struct vm_fault *);
	int (*page_mkwrite)(struct vm_area_struct___2 *, struct vm_fault *);
	int (*access)(struct vm_area_struct___2 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___2 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___2 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___2 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___2 *, long unsigned int, long unsigned int, long unsigned int);
};

typedef signed char __s8;

typedef short int __s16;

typedef int s32;

enum {
	false = 0,
	true = 1,
};

typedef __kernel_long_t __kernel_ssize_t;

typedef long long int __kernel_loff_t;

typedef __u32 __kernel_dev_t;

typedef __kernel_dev_t dev_t;

typedef short unsigned int umode_t;

typedef __kernel_loff_t loff_t;

typedef __kernel_ssize_t ssize_t;

typedef long unsigned int sector_t;

typedef long unsigned int blkcnt_t;

typedef unsigned int fmode_t;

struct kernel_symbol {
	long unsigned int value;
	const char *name;
};

typedef int (*initcall_t)();

struct obs_kernel_param {
	const char *str;
	int (*setup_func)(char *);
	int early;
};

struct _ddebug {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
};

enum system_states {
	SYSTEM_BOOTING = 0,
	SYSTEM_RUNNING = 1,
	SYSTEM_HALT = 2,
	SYSTEM_POWER_OFF = 3,
	SYSTEM_RESTART = 4,
};

struct bug_entry {
	int bug_addr_disp;
	int file_disp;
	short unsigned int line;
	short unsigned int flags;
};

typedef s32 compat_time_t;

struct compat_timespec {
	compat_time_t tv_sec;
	s32 tv_nsec;
};

struct pollfd {
	int fd;
	short int events;
	short int revents;
};

struct restart_block {
	long int (*fn)(struct restart_block *);
	union {
		struct {
			u32 *uaddr;
			u32 val;
			u32 flags;
			u32 bitset;
			u64 time;
			u32 *uaddr2;
		} futex;
		struct {
			clockid_t clockid;
			struct timespec *rmtp;
			struct compat_timespec *compat_rmtp;
			u64 expires;
		} nanosleep;
		struct {
			struct pollfd *ufds;
			int nfds;
			int has_timeout;
			long unsigned int tv_sec;
			long unsigned int tv_nsec;
		} poll;
	};
};

struct task_struct___3;

struct pv_cpu_ops___2 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___3 *);
	void (*end_context_switch)(struct task_struct___3 *);
};

struct mutex___3 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___3 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___3;

struct nsproxy___2;

struct signal_struct___2;

struct css_set___2;

struct perf_event_context___2;

struct task_struct___3 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___3 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___3 *mm;
	struct mm_struct___3 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___3 *real_parent;
	struct task_struct___3 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___3 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___2 = 0,
		VTIME_USER___2 = 1,
		VTIME_SYS___2 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___2 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex___3 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___3 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___3 *, struct mm_struct___3 *);
	void (*dup_mmap)(struct mm_struct___3 *, struct mm_struct___3 *);
	void (*exit_mmap)(struct mm_struct___3 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___3 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___3 *);
	void (*pgd_free)(struct mm_struct___3 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___3 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___3 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___3 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___3 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___3 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___3 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___3 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___3 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___3 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___3 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___3 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___3 lock;
	void *vdso;
} mm_context_t___3;

struct vm_area_struct___3;

struct file___2;

struct core_state___2;

struct mm_struct___3 {
	struct vm_area_struct___3 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___3 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___3 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___3 context;
	long unsigned int flags;
	struct core_state___2 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___3 *owner;
	struct file___2 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef union {
	s64 lock;
	struct {
		u32 read;
		s32 write;
	};
} arch_rwlock_t;

typedef void (*handler_t)(int, struct pt_regs *);

struct map_segment;

struct module;

struct exec_domain {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module *module;
	struct exec_domain *next;
};

enum module_state {
	MODULE_STATE_LIVE = 0,
	MODULE_STATE_COMING = 1,
	MODULE_STATE_GOING = 2,
	MODULE_STATE_UNFORMED = 3,
};

struct kref {
	atomic_t refcount;
};

struct kset;

struct kobj_type;

struct sysfs_dirent;

struct kobject {
	const char *name;
	struct list_head entry;
	struct kobject *parent;
	struct kset *kset;
	struct kobj_type *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_param_attrs;

struct module_kobject {
	struct kobject kobj;
	struct module *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct mod_arch_specific {};

struct module_attribute;

struct kernel_param;

struct exception_table_entry;

struct elf64_sym;

typedef struct elf64_sym Elf64_Sym;

struct module_sect_attrs;

struct module_notes_attrs;

struct tracepoint;

struct ftrace_event_call;

struct module_ref;

struct module {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject mkobj;
	struct module_attribute *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___3 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

enum perf_event_active_state {
	PERF_EVENT_STATE_EXIT = 4294967293,
	PERF_EVENT_STATE_ERROR = 4294967294,
	PERF_EVENT_STATE_OFF = 4294967295,
	PERF_EVENT_STATE_INACTIVE = 0,
	PERF_EVENT_STATE_ACTIVE = 1,
};

typedef struct {
	atomic_long_t a;
} local_t;

typedef struct {
	local_t a;
} local64_t;

struct perf_event_attr {
	__u32 type;
	__u32 size;
	__u64 config;
	union {
		__u64 sample_period;
		__u64 sample_freq;
	};
	__u64 sample_type;
	__u64 read_format;
	__u64 disabled: 1;
	__u64 inherit: 1;
	__u64 pinned: 1;
	__u64 exclusive: 1;
	__u64 exclude_user: 1;
	__u64 exclude_kernel: 1;
	__u64 exclude_hv: 1;
	__u64 exclude_idle: 1;
	__u64 mmap: 1;
	__u64 comm: 1;
	__u64 freq: 1;
	__u64 inherit_stat: 1;
	__u64 enable_on_exec: 1;
	__u64 task: 1;
	__u64 watermark: 1;
	__u64 precise_ip: 2;
	__u64 mmap_data: 1;
	__u64 sample_id_all: 1;
	__u64 exclude_host: 1;
	__u64 exclude_guest: 1;
	__u64 exclude_callchain_kernel: 1;
	__u64 exclude_callchain_user: 1;
	__u64 mmap2: 1;
	__u64 comm_exec: 1;
	__u64 __reserved_1: 39;
	union {
		__u32 wakeup_events;
		__u32 wakeup_watermark;
	};
	__u32 bp_type;
	union {
		__u64 bp_addr;
		__u64 config1;
	};
	union {
		__u64 bp_len;
		__u64 config2;
	};
	__u64 branch_sample_type;
	__u64 sample_regs_user;
	__u32 sample_stack_user;
	__u32 __reserved_2;
	__u64 sample_regs_intr;
};

struct hw_perf_event_extra {
	u64 config;
	unsigned int reg;
	int alloc;
	int idx;
};

struct arch_hw_breakpoint {
	long unsigned int address;
	u8 len;
	u8 type;
};

struct event_constraint;

struct hw_perf_event {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___3 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___3 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___3 *target;
};

struct irq_work {
	long unsigned int flags;
	struct llist_node llnode;
	void (*func)(struct irq_work *);
};

struct perf_sample_data;

typedef void (*perf_overflow_handler_t)(struct perf_event *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops;

typedef void (*ftrace_func_t)(long unsigned int, long unsigned int, struct ftrace_ops *, struct pt_regs *);

struct ftrace_hash;

struct ftrace_ops {
	ftrace_func_t func;
	struct ftrace_ops *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___3 regex_lock;
};

struct pmu;

struct ring_buffer;

struct fasync_struct;

struct event_filter;

struct perf_cgroup;

struct perf_event {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event *group_leader;
	struct pmu *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event hw;
	struct perf_event_context___2 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___3 child_mutex;
	struct list_head child_list;
	struct perf_event *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___3 *owner;
	struct mutex___3 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event *);
	struct callback_head callback_head;
	struct pid_namespace *ns;
	u64 id;
	perf_overflow_handler_t overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

typedef struct {
	long unsigned int seg;
} mm_segment_t;

struct thread_info {
	struct task_struct___3 *task;
	struct exec_domain *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct lock_class_key {};

typedef struct {
	arch_rwlock_t raw_lock;
} rwlock_t;

struct kstat {
	u64 ino;
	dev_t dev;
	umode_t mode;
	unsigned int nlink;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	loff_t size;
	struct timespec atime;
	struct timespec mtime;
	struct timespec ctime;
	long unsigned int blksize;
	long long unsigned int blocks;
};

enum node_states {
	N_POSSIBLE = 0,
	N_ONLINE = 1,
	N_NORMAL_MEMORY = 2,
	N_HIGH_MEMORY = 2,
	N_MEMORY = 3,
	N_CPU = 4,
	NR_NODE_STATES = 5,
};

struct zone___2;

struct lruvec___2 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___2 *zone;
};

struct pglist_data___2;

struct zone___2 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___2 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___2 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___2 {
	struct zone___2 *zone;
	int zone_idx;
};

struct zonelist___2 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___2 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___2 {
	struct zone___2 node_zones[4];
	struct zonelist___2 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___3 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct pglist_data___2 pg_data_t;

struct tvec_base;

struct timer_list {
	struct list_head entry;
	long unsigned int expires;
	struct tvec_base *base;
	void (*function)(long unsigned int);
	long unsigned int data;
	int slack;
	int start_pid;
	void *start_site;
	char start_comm[16];
};

struct work_struct;

typedef void (*work_func_t)(struct work_struct *);

struct work_struct {
	atomic_long_t data;
	struct list_head entry;
	work_func_t func;
};

struct workqueue_struct;

struct delayed_work {
	struct work_struct work;
	struct timer_list timer;
	struct workqueue_struct *wq;
	int cpu;
};

struct irq_chip;

struct irq_domain;

struct msi_desc;

struct irq_data {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct io_apic_irq_attr {
	int ioapic;
	int ioapic_pin;
	int trigger;
	int polarity;
};

struct pm_message {
	int event;
};

typedef struct pm_message pm_message_t;

struct device;

struct dev_pm_ops {
	int (*prepare)(struct device *);
	void (*complete)(struct device *);
	int (*suspend)(struct device *);
	int (*resume)(struct device *);
	int (*freeze)(struct device *);
	int (*thaw)(struct device *);
	int (*poweroff)(struct device *);
	int (*restore)(struct device *);
	int (*suspend_late)(struct device *);
	int (*resume_early)(struct device *);
	int (*freeze_late)(struct device *);
	int (*thaw_early)(struct device *);
	int (*poweroff_late)(struct device *);
	int (*restore_early)(struct device *);
	int (*suspend_noirq)(struct device *);
	int (*resume_noirq)(struct device *);
	int (*freeze_noirq)(struct device *);
	int (*thaw_noirq)(struct device *);
	int (*poweroff_noirq)(struct device *);
	int (*restore_noirq)(struct device *);
	int (*runtime_suspend)(struct device *);
	int (*runtime_resume)(struct device *);
	int (*runtime_idle)(struct device *);
};

enum rpm_request {
	RPM_REQ_NONE = 0,
	RPM_REQ_IDLE = 1,
	RPM_REQ_SUSPEND = 2,
	RPM_REQ_AUTOSUSPEND = 3,
	RPM_REQ_RESUME = 4,
};

enum rpm_status {
	RPM_ACTIVE = 0,
	RPM_RESUMING = 1,
	RPM_SUSPENDED = 2,
	RPM_SUSPENDING = 3,
};

struct wakeup_source;

struct pm_subsys_data;

struct dev_pm_qos;

struct dev_pm_info {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos *qos;
};

struct dma_coherent_mem;

struct dma_map_ops;

struct dev_archdata {
	struct dma_map_ops *dma_ops;
	void *iommu;
};

struct acpi_device;

struct acpi_dev_node {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct klist_node {
	void *n_klist;
	struct list_head n_node;
	struct kref n_ref;
};

struct device_private;

struct device_type;

struct bus_type;

struct device_driver;

struct dev_pm_domain;

struct device_dma_parameters;

struct device_node;

struct class;

struct attribute_group;

struct iommu_group;

struct device_rh;

struct device {
	struct device *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type *type;
	struct mutex___3 mutex;
	struct bus_type *bus;
	struct device_driver *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class *class;
	const struct attribute_group **groups;
	void (*release)(struct device *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh *device_rh;
};

struct pm_subsys_data {
	spinlock_t lock;
	unsigned int refcount;
};

struct wakeup_source {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct dev_pm_info_rh {
	void (*set_latency_tolerance)(struct device *, s32);
};

struct dev_pm_domain {
	struct dev_pm_ops ops;
};

struct smp_ops___2 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___3 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct page_cgroup {
	long unsigned int flags;
	struct mem_cgroup *mem_cgroup;
};

typedef void (*smp_call_func_t)(void *);

struct call_single_data {
	union {
		struct llist_node llist;
		struct {
			struct list_head list;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	smp_call_func_t func;
	void *info;
	u16 flags;
};

struct uts_namespace;

struct ipc_namespace;

struct mnt_namespace;

struct net;

struct nsproxy___2 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net *net_ns;
};

enum umh_disable_depth {
	UMH_ENABLED = 0,
	UMH_FREEZING = 1,
	UMH_DISABLED = 2,
};

typedef __u64 Elf64_Addr;

typedef __u16 Elf64_Half;

typedef __u32 Elf64_Word;

typedef __u64 Elf64_Xword;

struct elf64_sym {
	Elf64_Word st_name;
	unsigned char st_info;
	unsigned char st_other;
	Elf64_Half st_shndx;
	Elf64_Addr st_value;
	Elf64_Xword st_size;
};

enum kobj_ns_type {
	KOBJ_NS_TYPE_NONE = 0,
	KOBJ_NS_TYPE_NET = 1,
	KOBJ_NS_TYPES = 2,
};

struct sock;

struct kobj_ns_type_operations {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct attribute {
	const char *name;
	umode_t mode;
};

struct bin_attribute;

struct attribute_group {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute **bin_attrs;
};

struct bin_attribute {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___2 *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___2 *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	int (*mmap)(struct file___2 *, struct kobject *, struct bin_attribute *, struct vm_area_struct___3 *);
};

struct vfsmount;

struct dentry;

struct path {
	struct vfsmount *mnt;
	struct dentry *dentry;
};

struct fown_struct {
	rwlock_t lock;
	struct pid *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_ra_state {
	long unsigned int start;
	unsigned int size;
	unsigned int async_size;
	unsigned int ra_pages;
	unsigned int mmap_miss;
	loff_t prev_pos;
};

struct inode;

struct file_operations;

struct file___2 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path f_path;
	struct inode *f_inode;
	const struct file_operations *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space *f_mapping;
	struct mutex___3 f_pos_lock;
};

struct vm_operations_struct___3;

struct vm_area_struct___3 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___3 *vm_next;
	struct vm_area_struct___3 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___3 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___3 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___2 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops {
	ssize_t (*show)(struct kobject *, struct attribute *, char *);
	ssize_t (*store)(struct kobject *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject *, const struct attribute *);
};

struct kset_uevent_ops;

struct kset {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject kobj;
	const struct kset_uevent_ops *uevent_ops;
};

struct kobj_type {
	void (*release)(struct kobject *);
	const struct sysfs_ops *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject *);
	const void * (*namespace)(struct kobject *);
};

struct kobj_uevent_env {
	char *envp[32];
	int envp_idx;
	char buf[2048];
	int buflen;
};

struct kset_uevent_ops {
	int (* const filter)(struct kset *, struct kobject *);
	const char * (* const name)(struct kset *, struct kobject *);
	int (* const uevent)(struct kset *, struct kobject *, struct kobj_uevent_env *);
};

struct kernel_param_ops {
	int (*set)(const char *, const struct kernel_param *);
	int (*get)(char *, const struct kernel_param *);
	void (*free)(void *);
};

struct kparam_string;

struct kparam_array;

struct kernel_param {
	const char *name;
	const struct kernel_param_ops *ops;
	u16 perm;
	s16 level;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array *arr;
	};
};

struct kparam_string {
	unsigned int maxlen;
	char *string;
};

struct kparam_array {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops *ops;
	void *elem;
};

struct tracepoint_func {
	void *func;
	void *data;
};

struct tracepoint {
	const char *name;
	struct static_key key;
	void (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct module_attribute {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute *, struct module_kobject *, char *);
	ssize_t (*store)(struct module_attribute *, struct module_kobject *, const char *, size_t);
	void (*setup)(struct module *, const char *);
	int (*test)(struct module *);
	void (*free)(struct module *);
};

struct module_ref {
	long unsigned int incs;
	long unsigned int decs;
};

struct exception_table_entry {
	int insn;
	int fixup;
};

struct trace_event_functions;

struct trace_event {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions *funcs;
};

struct ftrace_event_class;

struct ftrace_event_call {
	struct list_head list;
	struct ftrace_event_class *class;
	char *name;
	struct trace_event event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct hlist_bl_node;

struct hlist_bl_head {
	struct hlist_bl_node *first;
};

struct hlist_bl_node {
	struct hlist_bl_node *next;
	struct hlist_bl_node **pprev;
};

struct lockref {
	union {
		__u64 lock_count;
		struct {
			spinlock_t lock;
			unsigned int count;
		};
	};
};

struct qstr {
	union {
		struct {
			u32 hash;
			u32 len;
		};
		u64 hash_len;
	};
	const unsigned char *name;
};

struct dentry_operations;

struct super_block;

struct dentry {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry *d_parent;
	struct qstr d_name;
	struct inode *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations *d_op;
	struct super_block *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct radix_tree_node;

struct radix_tree_root {
	unsigned int height;
	gfp_t gfp_mask;
	struct radix_tree_node *rnode;
};

struct address_space_operations;

struct address_space {
	struct inode *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___3 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct posix_acl;

struct inode_operations;

struct file_lock;

struct dquot;

struct block_device;

struct cdev;

struct inode {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations *i_op;
	struct super_block *i_sb;
	struct address_space *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___3 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations *i_fop;
	struct file_lock *i_flock;
	struct address_space i_data;
	struct dquot *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations {
	int (*d_revalidate)(struct dentry *, unsigned int);
	int (*d_weak_revalidate)(struct dentry *, unsigned int);
	int (*d_hash)(const struct dentry *, struct qstr *);
	int (*d_compare)(const struct dentry *, const struct dentry *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry *);
	void (*d_release)(struct dentry *);
	void (*d_prune)(struct dentry *);
	void (*d_iput)(struct dentry *, struct inode *);
	char * (*d_dname)(struct dentry *, char *, int);
	struct vfsmount * (*d_automount)(struct path *);
	int (*d_manage)(struct dentry *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mtd_info;

typedef long long int qsize_t;

struct quota_format_type;

struct mem_dqinfo {
	struct quota_format_type *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops;

struct quota_info {
	unsigned int flags;
	struct mutex___3 dqio_mutex;
	struct mutex___3 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode *files[2];
	struct mem_dqinfo info[2];
	const struct quota_format_ops *ops[2];
};

struct percpu_counter {
	raw_spinlock_t lock;
	s64 count;
	struct list_head list;
	s32 *counters;
};

struct sb_writers {
	struct percpu_counter counter[3];
	wait_queue_head_t wait;
	int frozen;
	wait_queue_head_t wait_unfrozen;
};

struct shrink_control;

struct shrinker {
	int (*shrink)(struct shrinker *, struct shrink_control *);
	int seeks;
	long int batch;
	struct list_head list;
	atomic_long_t nr_in_batch;
};

struct file_system_type;

struct super_operations;

struct dquot_operations;

struct quotactl_ops;

struct export_operations;

struct xattr_handler;

struct super_block {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type *s_type;
	const struct super_operations *s_op;
	const struct dquot_operations *dq_op;
	const struct quotactl_ops *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___3 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct radix_tree_node {
	unsigned int path;
	unsigned int count;
	union {
		struct {
			struct radix_tree_node *parent;
			void *private_data;
		};
		struct callback_head callback_head;
	};
	struct list_head private_list;
	void *slots[64];
	long unsigned int tags[3];
};

struct pidmap {
	atomic_t nr_free;
	void *page;
};

struct bsd_acct_struct;

struct pid_namespace {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___3 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace *parent;
	struct vfsmount *proc_mnt;
	struct dentry *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct fiemap_extent {
	__u64 fe_logical;
	__u64 fe_physical;
	__u64 fe_length;
	__u64 fe_reserved64[2];
	__u32 fe_flags;
	__u32 fe_reserved[3];
};

struct shrink_control {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
};

enum migrate_mode {
	MIGRATE_ASYNC = 0,
	MIGRATE_SYNC_LIGHT = 1,
	MIGRATE_SYNC = 2,
};

struct bio;

typedef void bio_end_io_t(struct bio *, int);

struct bio_vec {
	struct page *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state;

struct bio_integrity_payload;

struct bio_set;

struct bio_aux;

struct bio {
	sector_t bi_sector;
	struct bio *bi_next;
	struct block_device *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t *bi_end_io;
	void *bi_private;
	struct io_context *bi_ioc;
	struct cgroup_subsys_state *bi_css;
	struct bio_integrity_payload *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec *bi_io_vec;
	struct bio_set *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec bi_inline_vecs[0];
};

struct bio_aux {
	long unsigned int bi_flags;
	atomic_t __bi_remaining;
};

struct hd_struct;

struct gendisk;

struct request_queue;

struct block_device {
	dev_t bd_dev;
	int bd_openers;
	struct inode *bd_inode;
	struct super_block *bd_super;
	struct mutex___3 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___3 bd_fsfreeze_mutex;
};

struct io_cq;

struct io_context {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup;

struct css_id;

struct cgroup_subsys_state {
	struct cgroup *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload {
	struct bio *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec *bip_vec;
	struct bio_vec bip_inline_vecs[0];
};

struct bio_list {
	struct bio *head;
	struct bio *tail;
};

struct mempool_s;

typedef struct mempool_s mempool_t;

struct bio_set {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___2 *ia_file;
};

struct fs_disk_quota {
	__s8 d_version;
	__s8 d_flags;
	__u16 d_fieldmask;
	__u32 d_id;
	__u64 d_blk_hardlimit;
	__u64 d_blk_softlimit;
	__u64 d_ino_hardlimit;
	__u64 d_ino_softlimit;
	__u64 d_bcount;
	__u64 d_icount;
	__s32 d_itimer;
	__s32 d_btimer;
	__u16 d_iwarns;
	__u16 d_bwarns;
	__s32 d_padding2;
	__u64 d_rtb_hardlimit;
	__u64 d_rtb_softlimit;
	__u64 d_rtbcount;
	__s32 d_rtbtimer;
	__u16 d_rtbwarns;
	__s16 d_padding3;
	char d_padding4[8];
};

struct fs_qfilestat {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
};

typedef struct fs_qfilestat fs_qfilestat_t;

struct fs_quota_stat {
	__s8 qs_version;
	__u16 qs_flags;
	__s8 qs_pad;
	fs_qfilestat_t qs_uquota;
	fs_qfilestat_t qs_gquota;
	__u32 qs_incoredqs;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
};

struct fs_qfilestatv {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
	__u32 qfs_pad;
};

struct fs_quota_statv {
	__s8 qs_version;
	__u8 qs_pad1;
	__u16 qs_flags;
	__u32 qs_incoredqs;
	struct fs_qfilestatv qs_uquota;
	struct fs_qfilestatv qs_gquota;
	struct fs_qfilestatv qs_pquota;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
	__u64 qs_pad2[8];
};

typedef __kernel_uid32_t projid_t;

typedef struct {
	projid_t val;
} kprojid_t;

enum quota_type {
	USRQUOTA = 0,
	GRPQUOTA = 1,
	PRJQUOTA = 2,
};

struct kqid {
	union {
		kuid_t uid;
		kgid_t gid;
		kprojid_t projid;
	};
	enum quota_type type;
};

struct mem_dqblk {
	qsize_t dqb_bhardlimit;
	qsize_t dqb_bsoftlimit;
	qsize_t dqb_curspace;
	qsize_t dqb_rsvspace;
	qsize_t dqb_ihardlimit;
	qsize_t dqb_isoftlimit;
	qsize_t dqb_curinodes;
	time_t dqb_btime;
	time_t dqb_itime;
};

struct dquot {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___3 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct if_dqinfo {
	__u64 dqi_bgrace;
	__u64 dqi_igrace;
	__u32 dqi_flags;
	__u32 dqi_valid;
};

struct quota_format_type {
	int qf_fmt_id;
	const struct quota_format_ops *qf_ops;
	struct module *qf_owner;
	struct quota_format_type *qf_next;
};

enum {
	DQST_LOOKUPS = 0,
	DQST_DROPS = 1,
	DQST_READS = 2,
	DQST_WRITES = 3,
	DQST_CACHE_HITS = 4,
	DQST_ALLOC_DQUOTS = 5,
	DQST_FREE_DQUOTS = 6,
	DQST_SYNCS = 7,
	_DQST_DQSTAT_LAST = 8,
};

struct dqstats {
	int stat[8];
	struct percpu_counter counter[8];
};

struct quota_format_ops {
	int (*check_quota_file)(struct super_block *, int);
	int (*read_file_info)(struct super_block *, int);
	int (*write_file_info)(struct super_block *, int);
	int (*free_file_info)(struct super_block *, int);
	int (*read_dqblk)(struct dquot *);
	int (*commit_dqblk)(struct dquot *);
	int (*release_dqblk)(struct dquot *);
};

struct dquot_operations {
	int (*write_dquot)(struct dquot *);
	struct dquot * (*alloc_dquot)(struct super_block *, int);
	void (*destroy_dquot)(struct dquot *);
	int (*acquire_dquot)(struct dquot *);
	int (*release_dquot)(struct dquot *);
	int (*mark_dirty)(struct dquot *);
	int (*write_info)(struct super_block *, int);
	qsize_t * (*get_reserved_space)(struct inode *);
};

struct quotactl_ops {
	int (*quota_on)(struct super_block *, int, int, struct path *);
	int (*quota_on_meta)(struct super_block *, int, int);
	int (*quota_off)(struct super_block *, int);
	int (*quota_sync)(struct super_block *, int);
	int (*get_info)(struct super_block *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block *, unsigned int, int);
	int (*get_xstatev)(struct super_block *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block *, unsigned int);
};

struct iovec {
	void *iov_base;
	__kernel_size_t iov_len;
};

typedef struct {
	size_t written;
	size_t count;
	union {
		char *buf;
		void *data;
	} arg;
	int error;
} read_descriptor_t;

struct writeback_control;

struct kiocb;

struct swap_info_struct;

struct address_space_operations {
	int (*writepage)(struct page *, struct writeback_control *);
	int (*readpage)(struct file___2 *, struct page *);
	int (*writepages)(struct address_space *, struct writeback_control *);
	int (*set_page_dirty)(struct page *);
	int (*readpages)(struct file___2 *, struct address_space *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___2 *, struct address_space *, loff_t, unsigned int, unsigned int, struct page **, void **);
	int (*write_end)(struct file___2 *, struct address_space *, loff_t, unsigned int, unsigned int, struct page *, void *);
	sector_t (*bmap)(struct address_space *, sector_t);
	void (*invalidatepage)(struct page *, long unsigned int);
	int (*releasepage)(struct page *, gfp_t);
	void (*freepage)(struct page *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space *, struct page *, struct page *, enum migrate_mode);
	int (*launder_page)(struct page *);
	int (*is_partially_uptodate)(struct page *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page *, bool *, bool *);
	int (*error_remove_page)(struct address_space *, struct page *);
	int (*swap_activate)(struct swap_info_struct *, struct file___2 *, sector_t *);
	void (*swap_deactivate)(struct file___2 *);
	void (*invalidatepage_range)(struct page *, unsigned int, unsigned int);
};

enum writeback_sync_modes {
	WB_SYNC_NONE = 0,
	WB_SYNC_ALL = 1,
};

struct writeback_control {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_extent {
	struct list_head list;
	long unsigned int start_page;
	long unsigned int nr_pages;
	sector_t start_block;
};

struct swap_info_struct {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device *bdev;
	struct file___2 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

typedef int congested_fn(void *, int);

struct fprop_local_percpu {
	struct percpu_counter events;
	unsigned int period;
	raw_spinlock_t lock;
};

struct bdi_writeback {
	struct backing_dev_info *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry *debug_dir;
	struct dentry *debug_stats;
};

struct partition_meta_info;

struct disk_stats;

struct hd_struct {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct timer_rand_state;

struct disk_events;

struct disk_part_tbl;

struct block_device_operations;

struct blk_integrity;

struct gendisk {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl *part_tbl;
	struct hd_struct part0;
	const struct block_device_operations *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct device *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct blkcg_gq;

struct request_list {
	struct request_queue *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc(struct request_queue *);

typedef void make_request_fn(struct request_queue *, struct bio *);

struct request;

typedef int prep_rq_fn(struct request_queue *, struct request *);

struct bvec_merge_data;

typedef int merge_bvec_fn(struct request_queue *, struct bvec_merge_data *, struct bio_vec *);

typedef void softirq_done_fn(struct request *);

enum blk_eh_timer_return {
	BLK_EH_NOT_HANDLED = 0,
	BLK_EH_HANDLED = 1,
	BLK_EH_RESET_TIMER = 2,
};

typedef enum blk_eh_timer_return rq_timed_out_fn(struct request *);

typedef int dma_drain_needed_fn(struct request *);

typedef int lld_busy_fn(struct request_queue *);

struct queue_limits {
	long unsigned int bounce_pfn;
	long unsigned int seg_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	short unsigned int logical_block_size;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char cluster;
	unsigned char discard_zeroes_data;
	unsigned int xcopy_reserved;
	union {
		unsigned int chunk_sectors;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct bsg_job;

typedef int bsg_job_fn(struct bsg_job *);

struct bsg_class_device {
	struct device *class_dev;
	struct device *parent;
	int minor;
	struct request_queue *queue;
	struct kref ref;
	void (*release)(struct device *);
};

struct throtl_data;

typedef void unprep_rq_fn(struct request_queue *, struct request *);

struct percpu_ref;

typedef void percpu_ref_func_t(struct percpu_ref *);

struct percpu_ref {
	atomic_long_t count;
	long unsigned int percpu_count_ptr;
	percpu_ref_func_t *release;
	percpu_ref_func_t *confirm_switch;
	bool force_atomic: 1;
	struct callback_head rcu;
};

struct elevator_queue;

struct blk_mq_ops;

struct blk_mq_ctx;

struct blk_mq_hw_ctx;

struct blk_queue_tag;

struct blk_trace;

struct blk_mq_tag_set;

struct blk_flush_queue;

struct request_queue {
	struct list_head queue_head;
	struct request *last_merge;
	struct elevator_queue *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list root_rl;
	request_fn_proc *request_fn;
	make_request_fn *make_request_fn;
	prep_rq_fn *prep_rq_fn;
	merge_bvec_fn *merge_bvec_fn;
	softirq_done_fn *softirq_done_fn;
	rq_timed_out_fn *rq_timed_out_fn;
	dma_drain_needed_fn *dma_drain_needed;
	lld_busy_fn *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___3 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct nameidata;

struct fiemap_extent_info;

struct inode_operations {
	struct dentry * (*lookup)(struct inode *, struct dentry *, unsigned int);
	void * (*follow_link)(struct dentry *, struct nameidata *);
	int (*permission)(struct inode *, int);
	struct posix_acl * (*get_acl)(struct inode *, int);
	int (*readlink)(struct dentry *, char *, int);
	void (*put_link)(struct dentry *, struct nameidata *, void *);
	int (*create)(struct inode *, struct dentry *, umode_t, bool);
	int (*link)(struct dentry *, struct inode *, struct dentry *);
	int (*unlink)(struct inode *, struct dentry *);
	int (*symlink)(struct inode *, struct dentry *, const char *);
	int (*mkdir)(struct inode *, struct dentry *, umode_t);
	int (*rmdir)(struct inode *, struct dentry *);
	int (*mknod)(struct inode *, struct dentry *, umode_t, dev_t);
	int (*rename)(struct inode *, struct dentry *, struct inode *, struct dentry *);
	int (*setattr)(struct dentry *, struct iattr *);
	int (*getattr)(struct vfsmount *, struct dentry *, struct kstat *);
	int (*setxattr)(struct dentry *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry *, char *, size_t);
	int (*removexattr)(struct dentry *, const char *);
	int (*fiemap)(struct inode *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode *, struct timespec *, int);
	int (*atomic_open)(struct inode *, struct dentry *, struct file___2 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef int (*filldir_t)(void *, const char *, int, loff_t, u64, unsigned int);

typedef struct files_struct *fl_owner_t;

struct poll_table_struct;

struct seq_file;

struct file_operations {
	struct module *owner;
	loff_t (*llseek)(struct file___2 *, loff_t, int);
	ssize_t (*read)(struct file___2 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___2 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___2 *, void *, filldir_t);
	unsigned int (*poll)(struct file___2 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___2 *, struct vm_area_struct___3 *);
	int (*open)(struct inode *, struct file___2 *);
	int (*flush)(struct file___2 *, fl_owner_t);
	int (*release)(struct inode *, struct file___2 *);
	int (*fsync)(struct file___2 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___2 *, int);
	int (*lock)(struct file___2 *, int, struct file_lock *);
	ssize_t (*sendpage)(struct file___2 *, struct page *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___2 *, int, struct file_lock *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___2 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___2 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___2 *, long int, struct file_lock **, void **);
		struct {
			int (*setlease)(struct file___2 *, long int, struct file_lock **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___2 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file *, struct file___2 *);
};

struct nlm_lockowner;

struct nfs_lock_info {
	u32 state;
	struct nlm_lockowner *owner;
	struct list_head list;
};

struct nfs4_lock_state;

struct nfs4_lock_info {
	struct nfs4_lock_state *owner;
};

struct file_lock_operations;

struct lock_manager_operations;

struct file_lock {
	struct file_lock *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___2 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations *fl_ops;
	const struct lock_manager_operations *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations {
	void (*fl_copy_lock)(struct file_lock *, struct file_lock *);
	void (*fl_release_private)(struct file_lock *);
};

struct lock_manager_operations {
	int (*lm_compare_owner)(struct file_lock *, struct file_lock *);
	long unsigned int (*lm_owner_key)(struct file_lock *);
	void (*lm_notify)(struct file_lock *);
	int (*lm_grant)(struct file_lock *, struct file_lock *, int);
	void (*lm_break)(struct file_lock *);
	int (*lm_change)(struct file_lock **, int);
};

struct fasync_struct {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct *fa_next;
	struct file___2 *fa_file;
	struct callback_head fa_rcu;
};

enum {
	SB_UNFROZEN = 0,
	SB_FREEZE_WRITE = 1,
	SB_FREEZE_PAGEFAULT = 2,
	SB_FREEZE_FS = 3,
	SB_FREEZE_COMPLETE = 4,
};

struct file_system_type {
	const char *name;
	int fs_flags;
	struct dentry * (*mount)(struct file_system_type *, int, const char *, void *);
	void (*kill_sb)(struct super_block *);
	struct module *owner;
	struct file_system_type *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kstatfs;

struct super_operations {
	struct inode * (*alloc_inode)(struct super_block *);
	void (*destroy_inode)(struct inode *);
	void (*dirty_inode)(struct inode *, int);
	int (*write_inode)(struct inode *, struct writeback_control *);
	int (*drop_inode)(struct inode *);
	void (*evict_inode)(struct inode *);
	void (*put_super)(struct super_block *);
	int (*sync_fs)(struct super_block *, int);
	int (*freeze_fs)(struct super_block *);
	int (*unfreeze_fs)(struct super_block *);
	int (*statfs)(struct dentry *, struct kstatfs *);
	int (*remount_fs)(struct super_block *, int *, char *);
	void (*umount_begin)(struct super_block *);
	int (*show_options)(struct seq_file *, struct dentry *);
	int (*show_devname)(struct seq_file *, struct dentry *);
	int (*show_path)(struct seq_file *, struct dentry *);
	int (*show_stats)(struct seq_file *, struct dentry *);
	ssize_t (*quota_read)(struct super_block *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode *);
	int (*bdev_try_to_free_page)(struct super_block *, struct page *, gfp_t);
	int (*nr_cached_objects)(struct super_block *);
	void (*free_cached_objects)(struct super_block *, int);
};

struct inode___2;

struct dentry___2;

struct super_block___2;

struct fid;

struct iomap;

struct iattr___2;

struct export_operations {
	int (*encode_fh)(struct inode___2 *, __u32 *, int *, struct inode___2 *);
	struct dentry___2 * (*fh_to_dentry)(struct super_block___2 *, struct fid *, int, int);
	struct dentry___2 * (*fh_to_parent)(struct super_block___2 *, struct fid *, int, int);
	int (*get_name)(struct dentry___2 *, char *, struct dentry___2 *);
	struct dentry___2 * (*get_parent)(struct dentry___2 *);
	int (*commit_metadata)(struct inode___2 *);
	int (*get_uuid)(struct super_block___2 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___2 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___2 *, struct iomap *, int, struct iattr___2 *);
};

struct xattr_handler {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry *, const char *, void *, size_t, int);
	int (*set)(struct dentry *, const char *, const void *, size_t, int, int);
};

struct fiemap_extent_info {
	unsigned int fi_flags;
	unsigned int fi_extents_mapped;
	unsigned int fi_extents_max;
	struct fiemap_extent *fi_extents_start;
};

typedef void (*poll_queue_proc)(struct file___2 *, wait_queue_head_t *, struct poll_table_struct *);

struct poll_table_struct {
	poll_queue_proc _qproc;
	long unsigned int _key;
};

struct seq_operations;

struct seq_file {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___3 lock;
	const struct seq_operations *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct audit_names;

struct filename {
	const char *name;
	const char *uptr;
	struct audit_names *aname;
	bool separate;
	int refcnt;
};

struct kmem_cache_order_objects {
	long unsigned int x;
};

struct kmem_cache_cpu;

struct memcg_cache_params;

struct kmem_cache_node;

struct kmem_cache {
	struct kmem_cache_cpu *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct anon_vma {
	struct anon_vma *root;
	struct rw_semaphore rwsem;
	atomic_t refcount;
	struct rb_root rb_root;
};

struct vm_operations_struct___3 {
	void (*open)(struct vm_area_struct___3 *);
	void (*close)(struct vm_area_struct___3 *);
	int (*fault)(struct vm_area_struct___3 *, struct vm_fault *);
	int (*page_mkwrite)(struct vm_area_struct___3 *, struct vm_fault *);
	int (*access)(struct vm_area_struct___3 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___3 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___3 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___3 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___3 *, long unsigned int, long unsigned int, long unsigned int);
};

struct mempolicy {
	atomic_t refcnt;
	short unsigned int mode;
	short unsigned int flags;
	union {
		short int preferred_node;
		nodemask_t nodes;
	} v;
	union {
		nodemask_t cpuset_mems_allowed;
		nodemask_t user_nodemask;
	} w;
};

struct core_thread___2 {
	struct task_struct___3 *task;
	struct core_thread___2 *next;
};

struct core_state___2 {
	atomic_t nr_threads;
	struct core_thread___2 dumper;
	struct completion startup;
};

struct seq_operations {
	void * (*start)(struct seq_file *, loff_t *);
	void (*stop)(struct seq_file *, void *);
	void * (*next)(struct seq_file *, void *, loff_t *);
	int (*show)(struct seq_file *, void *);
};

struct trace_seq {
	unsigned char buffer[4096];
	unsigned int len;
	unsigned int readpos;
	int full;
};

struct irq_chip {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data *);
	void (*irq_shutdown)(struct irq_data *);
	void (*irq_enable)(struct irq_data *);
	void (*irq_disable)(struct irq_data *);
	void (*irq_ack)(struct irq_data *);
	void (*irq_mask)(struct irq_data *);
	void (*irq_mask_ack)(struct irq_data *);
	void (*irq_unmask)(struct irq_data *);
	void (*irq_eoi)(struct irq_data *);
	int (*irq_set_affinity)(struct irq_data *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data *);
	int (*irq_set_type)(struct irq_data *, unsigned int);
	int (*irq_set_wake)(struct irq_data *, unsigned int);
	void (*irq_bus_lock)(struct irq_data *);
	void (*irq_bus_sync_unlock)(struct irq_data *);
	void (*irq_cpu_online)(struct irq_data *);
	void (*irq_cpu_offline)(struct irq_data *);
	void (*irq_suspend)(struct irq_data *);
	void (*irq_resume)(struct irq_data *);
	void (*irq_pm_shutdown)(struct irq_data *);
	void (*irq_print_chip)(struct irq_data *, struct seq_file *);
	int (*irq_set_vcpu_affinity)(struct irq_data *, void *);
	long unsigned int flags;
};

enum ctx_state {
	CONTEXT_KERNEL = 0,
	CONTEXT_USER = 1,
	CONTEXT_GUEST = 2,
};

struct context_tracking {
	bool active;
	enum ctx_state state;
};

enum perf_sw_ids {
	PERF_COUNT_SW_CPU_CLOCK = 0,
	PERF_COUNT_SW_TASK_CLOCK = 1,
	PERF_COUNT_SW_PAGE_FAULTS = 2,
	PERF_COUNT_SW_CONTEXT_SWITCHES = 3,
	PERF_COUNT_SW_CPU_MIGRATIONS = 4,
	PERF_COUNT_SW_PAGE_FAULTS_MIN = 5,
	PERF_COUNT_SW_PAGE_FAULTS_MAJ = 6,
	PERF_COUNT_SW_ALIGNMENT_FAULTS = 7,
	PERF_COUNT_SW_EMULATION_FAULTS = 8,
	PERF_COUNT_SW_DUMMY = 9,
	PERF_COUNT_SW_MAX = 10,
};

enum perf_branch_sample_type_shift {
	PERF_SAMPLE_BRANCH_USER_SHIFT = 0,
	PERF_SAMPLE_BRANCH_KERNEL_SHIFT = 1,
	PERF_SAMPLE_BRANCH_HV_SHIFT = 2,
	PERF_SAMPLE_BRANCH_ANY_SHIFT = 3,
	PERF_SAMPLE_BRANCH_ANY_CALL_SHIFT = 4,
	PERF_SAMPLE_BRANCH_ANY_RETURN_SHIFT = 5,
	PERF_SAMPLE_BRANCH_IND_CALL_SHIFT = 6,
	PERF_SAMPLE_BRANCH_ABORT_TX_SHIFT = 7,
	PERF_SAMPLE_BRANCH_IN_TX_SHIFT = 8,
	PERF_SAMPLE_BRANCH_NO_TX_SHIFT = 9,
	PERF_SAMPLE_BRANCH_COND_SHIFT = 10,
	PERF_SAMPLE_BRANCH_CALL_STACK_SHIFT = 11,
	PERF_SAMPLE_BRANCH_MAX_SHIFT = 12,
};

union perf_mem_data_src {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_rsvd: 31;
	};
};

struct signal_struct___2 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___3 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___3 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___3 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef unsigned int tcflag_t;

typedef unsigned char cc_t;

typedef unsigned int speed_t;

struct ktermios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct winsize {
	short unsigned int ws_row;
	short unsigned int ws_col;
	short unsigned int ws_xpixel;
	short unsigned int ws_ypixel;
};

struct ld_semaphore {
	long int count;
	raw_spinlock_t wait_lock;
	unsigned int wait_readers;
	struct list_head read_wait;
	struct list_head write_wait;
};

struct tty_driver;

struct tty_operations;

struct tty_ldisc;

struct termiox;

struct tty_port;

struct tty_struct {
	int magic;
	struct kref kref;
	struct device *dev;
	struct tty_driver *driver;
	const struct tty_operations *ops;
	int index;
	struct mutex___3 ldisc_mutex;
	struct tty_ldisc *ldisc;
	struct mutex___3 atomic_write_lock;
	struct mutex___3 legacy_mutex;
	struct mutex___3 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid *pgrp;
	struct pid *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct *link;
	struct fasync_struct *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port *port;
	struct ld_semaphore ldisc_sem;
};

struct taskstats {
	__u16 version;
	__u32 ac_exitcode;
	__u8 ac_flag;
	__u8 ac_nice;
	__u64 cpu_count;
	__u64 cpu_delay_total;
	__u64 blkio_count;
	__u64 blkio_delay_total;
	__u64 swapin_count;
	__u64 swapin_delay_total;
	__u64 cpu_run_real_total;
	__u64 cpu_run_virtual_total;
	char ac_comm[32];
	__u8 ac_sched;
	__u8 ac_pad[3];
	int: 32;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u64 ac_etime;
	__u64 ac_utime;
	__u64 ac_stime;
	__u64 ac_minflt;
	__u64 ac_majflt;
	__u64 coremem;
	__u64 virtmem;
	__u64 hiwater_rss;
	__u64 hiwater_vm;
	__u64 read_char;
	__u64 write_char;
	__u64 read_syscalls;
	__u64 write_syscalls;
	__u64 read_bytes;
	__u64 write_bytes;
	__u64 cancelled_write_bytes;
	__u64 nvcsw;
	__u64 nivcsw;
	__u64 ac_utimescaled;
	__u64 ac_stimescaled;
	__u64 cpu_scaled_run_real_total;
	__u64 freepages_count;
	__u64 freepages_delay_total;
};

struct blk_plug {
	long unsigned int magic;
	struct list_head list;
	struct list_head mq_list;
	struct list_head cb_list;
};

struct reclaim_state {
	long unsigned int reclaimed_slab;
};

struct css_set___2 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state *subsys[11];
	struct callback_head callback_head;
};

enum perf_event_context_type {
	task_context = 0,
	cpu_context = 1,
};

struct perf_event_context___2 {
	struct pmu *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___3 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___3 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___2 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct ftrace_ret_stack {
	long unsigned int ret;
	long unsigned int func;
	long long unsigned int calltime;
	long long unsigned int subtime;
	long unsigned int fp;
};

enum {
	TSK_TRACE_FL_TRACE_BIT = 0,
	TSK_TRACE_FL_GRAPH_BIT = 1,
};

struct bus_attribute {
	struct attribute attr;
	ssize_t (*show)(struct bus_type *, char *);
	ssize_t (*store)(struct bus_type *, const char *, size_t);
};

struct device_attribute;

struct driver_attribute;

struct iommu_ops;

struct subsys_private;

struct bus_type {
	const char *name;
	const char *dev_name;
	struct device *dev_root;
	struct bus_attribute *bus_attrs;
	struct device_attribute *dev_attrs;
	struct driver_attribute *drv_attrs;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device *, struct device_driver *);
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	int (*probe)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*online)(struct device *);
	int (*offline)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct dev_pm_ops *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device *, struct device_attribute *, char *);
	ssize_t (*store)(struct device *, struct device_attribute *, const char *, size_t);
};

struct driver_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device_driver *, char *);
	ssize_t (*store)(struct device_driver *, const char *, size_t);
};

struct of_device_id;

struct acpi_device_id;

struct driver_private;

struct device_driver_rh;

struct device_driver {
	const char *name;
	struct bus_type *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct attribute_group **groups;
	const struct dev_pm_ops *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device *);
	const struct dev_pm_ops *pm;
};

struct of_device_id {
	char name[32];
	char type[32];
	char compatible[128];
	const void *data;
};

typedef long unsigned int kernel_ulong_t;

struct acpi_device_id {
	__u8 id[9];
	kernel_ulong_t driver_data;
};

struct device_driver_rh {};

struct class_attribute;

struct class {
	const char *name;
	struct module *owner;
	struct class_attribute *class_attrs;
	struct device_attribute *dev_attrs;
	const struct attribute_group **dev_groups;
	struct bin_attribute *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *);
	void (*class_release)(struct class *);
	void (*dev_release)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device *);
	const struct dev_pm_ops *pm;
	struct subsys_private *p;
};

struct class_attribute {
	struct attribute attr;
	ssize_t (*show)(struct class *, struct class_attribute *, char *);
	ssize_t (*store)(struct class *, struct class_attribute *, const char *, size_t);
	const void * (*namespace)(struct class *, const struct class_attribute *);
};

struct device_dma_parameters {
	unsigned int max_segment_size;
	long unsigned int segment_boundary_mask;
};

typedef void *acpi_handle;

struct acpi_device_status {
	u32 present: 1;
	u32 enabled: 1;
	u32 show_in_ui: 1;
	u32 functional: 1;
	u32 battery_present: 1;
	u32 reserved: 27;
};

struct acpi_device_flags {
	u32 dynamic_status: 1;
	u32 removable: 1;
	u32 ejectable: 1;
	u32 power_manageable: 1;
	u32 match_driver: 1;
	u32 initialized: 1;
	u32 visited: 1;
	u32 hotplug_notify: 1;
	u32 is_dock_station: 1;
	u32 reserved: 23;
};

typedef char acpi_bus_id[8];

struct acpi_pnp_type {
	u32 hardware_id: 1;
	u32 bus_address: 1;
	u32 reserved: 30;
};

typedef long unsigned int acpi_bus_address;

typedef char acpi_device_name[40];

typedef char acpi_device_class[20];

union acpi_object;

struct acpi_device_pnp {
	acpi_bus_id bus_id;
	struct acpi_pnp_type type;
	acpi_bus_address bus_address;
	char *unique_id;
	struct list_head ids;
	acpi_device_name device_name;
	acpi_device_class device_class;
	union acpi_object *str_obj;
};

struct acpi_device_power_flags {
	u32 explicit_get: 1;
	u32 power_resources: 1;
	u32 inrush_current: 1;
	u32 power_removed: 1;
	u32 reserved: 28;
};

struct acpi_device_power_state {
	struct {
		u8 valid: 1;
		u8 os_accessible: 1;
		u8 explicit_set: 1;
		char: 5;
		u8 reserved: 6;
	} flags;
	int power;
	int latency;
	struct list_head resources;
};

struct acpi_device_power {
	int state;
	struct acpi_device_power_flags flags;
	struct acpi_device_power_state states[5];
};

struct acpi_device_wakeup_flags {
	u8 valid: 1;
	u8 run_wake: 1;
	u8 notifier_present: 1;
};

struct acpi_device_wakeup {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	int prepare_count;
};

struct acpi_device_perf_flags {
	u8 reserved: 8;
};

struct acpi_device_perf_state;

struct acpi_device_perf {
	int state;
	struct acpi_device_perf_flags flags;
	int state_count;
	struct acpi_device_perf_state *states;
};

struct proc_dir_entry;

struct acpi_device_dir {
	struct proc_dir_entry *entry;
};

struct acpi_scan_handler;

struct acpi_hotplug_context;

struct acpi_driver;

struct acpi_device {
	int device_type;
	acpi_handle handle;
	struct acpi_device *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler *handler;
	struct acpi_hotplug_context *hp;
	struct acpi_driver *driver;
	void *driver_data;
	struct device dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___3 physical_node_lock;
	void (*remove)(struct acpi_device *);
};

struct device_rh {
	struct dev_pm_info_rh power;
};

enum cpuhp_state {
	CPUHP_OFFLINE = 0,
	CPUHP_ONLINE = 1,
};

struct static_key_deferred {
	struct static_key key;
	long unsigned int timeout;
	struct delayed_work work;
};

struct perf_regs {
	__u64 abi;
	struct pt_regs *regs;
};

enum {
	TASKSTATS_CMD_UNSPEC = 0,
	TASKSTATS_CMD_GET = 1,
	TASKSTATS_CMD_NEW = 2,
	__TASKSTATS_CMD_MAX = 3,
};

struct idr_layer {
	int prefix;
	long unsigned int bitmap[4];
	struct idr_layer *ary[256];
	int count;
	int layer;
	struct callback_head callback_head;
};

struct idr {
	struct idr_layer *hint;
	struct idr_layer *top;
	struct idr_layer *id_free;
	int layers;
	int id_free_cnt;
	int cur;
	spinlock_t lock;
};

struct ida_bitmap {
	long int nr_busy;
	long unsigned int bitmap[15];
};

struct ida {
	struct idr idr;
	struct ida_bitmap *free_bitmap;
};

struct kmem_cache_cpu {
	void **freelist;
	long unsigned int tid;
	struct page *page;
	struct page *partial;
};

struct memcg_cache_params {
	bool is_root_cache;
	union {
		struct kmem_cache *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct simple_xattrs {
	struct list_head head;
	spinlock_t lock;
};

enum cgroup_subsys_id {
	cpuset_subsys_id = 0,
	cpu_cgroup_subsys_id = 1,
	cpuacct_subsys_id = 2,
	mem_cgroup_subsys_id = 3,
	devices_subsys_id = 4,
	freezer_subsys_id = 5,
	net_cls_subsys_id = 6,
	blkio_subsys_id = 7,
	perf_subsys_id = 8,
	hugetlb_subsys_id = 9,
	CGROUP_BUILTIN_SUBSYS_COUNT = 10,
	__CGROUP_SUBSYS_TEMP_PLACEHOLDER = 9,
	net_prio_subsys_id = 10,
	CGROUP_SUBSYS_COUNT = 11,
};

struct cgroup_name;

struct cgroupfs_root;

struct cgroup {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup *parent;
	struct dentry *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state *subsys[11];
	struct cgroupfs_root *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___3 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroup_name {
	struct callback_head callback_head;
	char name[0];
};

struct cgroupfs_root {
	struct super_block *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cgroup_map_cb {
	int (*fill)(struct cgroup_map_cb *, const char *, u64);
	void *state;
};

struct eventfd_ctx;

struct cftype {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode *, struct file___2 *);
	ssize_t (*read)(struct cgroup *, struct cftype *, struct file___2 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup *, struct cftype *);
	s64 (*read_s64)(struct cgroup *, struct cftype *);
	int (*read_map)(struct cgroup *, struct cftype *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup *, struct cftype *, struct seq_file *);
	ssize_t (*write)(struct cgroup *, struct cftype *, struct file___2 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup *, struct cftype *, u64);
	int (*write_s64)(struct cgroup *, struct cftype *, s64);
	int (*write_string)(struct cgroup *, struct cftype *, const char *);
	int (*trigger)(struct cgroup *, unsigned int);
	int (*release)(struct inode *, struct file___2 *);
	int (*register_event)(struct cgroup *, struct cftype *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup *, struct cftype *, struct eventfd_ctx *);
};

struct cftype_set {
	struct list_head node;
	struct cftype *cfts;
};

struct task_and_cgroup {
	struct task_struct___3 *task;
	struct cgroup *cgrp;
	struct css_set___2 *cg;
};

struct flex_array;

struct cgroup_taskset {
	struct task_and_cgroup single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup *cur_cgrp;
};

struct cgroup_subsys {
	struct cgroup_subsys_state * (*css_alloc)(struct cgroup *);
	int (*css_online)(struct cgroup *);
	void (*css_offline)(struct cgroup *);
	void (*css_free)(struct cgroup *);
	int (*can_attach)(struct cgroup *, struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup *, struct cgroup_taskset *);
	void (*attach)(struct cgroup *, struct cgroup_taskset *);
	void (*fork)(struct task_struct___3 *);
	void (*exit)(struct cgroup *, struct cgroup *, struct task_struct___3 *);
	void (*bind)(struct cgroup *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype *base_cftypes;
	struct cftype_set base_cftset;
	struct module *module;
};

struct perf_callchain_entry {
	__u64 nr;
	__u64 ip[127];
};

struct perf_raw_record {
	u32 size;
	void *data;
};

struct perf_branch_entry {
	__u64 from;
	__u64 to;
	__u64 mispred: 1;
	__u64 predicted: 1;
	__u64 in_tx: 1;
	__u64 abort: 1;
	__u64 cycles: 16;
	__u64 reserved: 44;
};

struct perf_branch_stack {
	__u64 nr;
	struct perf_branch_entry entries[0];
};

struct perf_cpu_context;

struct pmu {
	struct list_head entry;
	struct device *dev;
	const struct attribute_group **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu *);
	void (*pmu_disable)(struct pmu *);
	int (*event_init)(struct perf_event *);
	int (*add)(struct perf_event *, int);
	void (*del)(struct perf_event *, int);
	void (*start)(struct perf_event *, int);
	void (*stop)(struct perf_event *, int);
	void (*read)(struct perf_event *);
	void (*start_txn)(struct pmu *);
	int (*commit_txn)(struct pmu *);
	void (*cancel_txn)(struct pmu *);
	int (*event_idx)(struct perf_event *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___2 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event *);
};

struct perf_cpu_context {
	struct perf_event_context___2 ctx;
	struct perf_event_context___2 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu *unique_pmu;
	struct perf_cgroup *cgrp;
};

struct perf_regs_user {
	__u64 abi;
	struct pt_regs *regs;
};

struct perf_sample_data {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup_info;

struct perf_cgroup {
	struct cgroup_subsys_state css;
	struct perf_cgroup_info *info;
};

struct perf_cgroup_info {
	u64 time;
	u64 timestamp;
};

struct trace_entry {
	short unsigned int type;
	unsigned char flags;
	unsigned char preempt_count;
	int pid;
};

struct ring_buffer_iter;

struct trace_array;

struct tracer;

struct trace_buffer;

struct trace_iterator {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___3 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

enum print_line_t {
	TRACE_TYPE_PARTIAL_LINE = 0,
	TRACE_TYPE_HANDLED = 1,
	TRACE_TYPE_UNHANDLED = 2,
	TRACE_TYPE_NO_CONSUME = 3,
};

typedef enum print_line_t (*trace_print_func)(struct trace_iterator *, int, struct trace_event *);

struct trace_event_functions {
	trace_print_func trace;
	trace_print_func raw;
	trace_print_func hex;
	trace_print_func binary;
};

enum trace_reg {
	TRACE_REG_REGISTER = 0,
	TRACE_REG_UNREGISTER = 1,
	TRACE_REG_PERF_REGISTER = 2,
	TRACE_REG_PERF_UNREGISTER = 3,
	TRACE_REG_PERF_OPEN = 4,
	TRACE_REG_PERF_CLOSE = 5,
	TRACE_REG_PERF_ADD = 6,
	TRACE_REG_PERF_DEL = 7,
};

struct ftrace_event_class {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call *);
	struct list_head * (*get_fields)(struct ftrace_event_call *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call *);
};

enum {
	TRACE_EVENT_FL_FILTERED_BIT = 0,
	TRACE_EVENT_FL_CAP_ANY_BIT = 1,
	TRACE_EVENT_FL_NO_SET_FILTER_BIT = 2,
	TRACE_EVENT_FL_IGNORE_ENABLE_BIT = 3,
	TRACE_EVENT_FL_WAS_ENABLED_BIT = 4,
};

enum {
	FTRACE_EVENT_FL_ENABLED_BIT = 0,
	FTRACE_EVENT_FL_RECORDED_CMD_BIT = 1,
	FTRACE_EVENT_FL_SOFT_MODE_BIT = 2,
	FTRACE_EVENT_FL_SOFT_DISABLED_BIT = 3,
};

typedef u64 acpi_io_address;

typedef u32 acpi_object_type;

union acpi_object {
	acpi_object_type type;
	struct {
		acpi_object_type type;
		u64 value;
	} integer;
	struct {
		acpi_object_type type;
		u32 length;
		char *pointer;
	} string;
	struct {
		acpi_object_type type;
		u32 length;
		u8 *pointer;
	} buffer;
	struct {
		acpi_object_type type;
		u32 count;
		union acpi_object *elements;
	} package;
	struct {
		acpi_object_type type;
		acpi_object_type actual_type;
		acpi_handle handle;
	} reference;
	struct {
		acpi_object_type type;
		u32 proc_id;
		acpi_io_address pblk_address;
		u32 pblk_length;
	} processor;
	struct {
		acpi_object_type type;
		u32 system_level;
		u32 resource_order;
	} power_resource;
};

struct acpi_hotplug_profile {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device *);
	void (*notify_online)(struct acpi_device *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device *);
	void (*bind)(struct device *);
	void (*unbind)(struct device *);
	struct acpi_hotplug_profile hotplug;
};

struct acpi_hotplug_context {
	struct acpi_device *self;
	int (*notify)(struct acpi_device *, u32);
	void (*uevent)(struct acpi_device *, u32);
	void (*fixup)(struct acpi_device *);
};

typedef int (*acpi_op_add)(struct acpi_device *);

typedef int (*acpi_op_remove)(struct acpi_device *);

typedef void (*acpi_op_notify)(struct acpi_device *, u32);

struct acpi_device_ops {
	acpi_op_add add;
	acpi_op_remove remove;
	acpi_op_notify notify;
};

struct acpi_driver {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops ops;
	struct device_driver drv;
	struct module *owner;
};

struct acpi_device_perf_state {
	struct {
		u8 valid: 1;
		u8 reserved: 7;
	} flags;
	u8 power;
	u8 performance;
	int latency;
};

struct termiox {
	__u16 x_hflag;
	__u16 x_cflag;
	__u16 x_rflag[5];
	__u16 x_sflag;
};

struct serial_icounter_struct;

struct tty_operations {
	struct tty_struct * (*lookup)(struct tty_driver *, struct inode *, int);
	int (*install)(struct tty_driver *, struct tty_struct *);
	void (*remove)(struct tty_driver *, struct tty_struct *);
	int (*open)(struct tty_struct *, struct file___2 *);
	void (*close)(struct tty_struct *, struct file___2 *);
	void (*shutdown)(struct tty_struct *);
	void (*cleanup)(struct tty_struct *);
	int (*write)(struct tty_struct *, const unsigned char *, int);
	int (*put_char)(struct tty_struct *, unsigned char);
	void (*flush_chars)(struct tty_struct *);
	int (*write_room)(struct tty_struct *);
	int (*chars_in_buffer)(struct tty_struct *);
	int (*ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	void (*throttle)(struct tty_struct *);
	void (*unthrottle)(struct tty_struct *);
	void (*stop)(struct tty_struct *);
	void (*start)(struct tty_struct *);
	void (*hangup)(struct tty_struct *);
	int (*break_ctl)(struct tty_struct *, int);
	void (*flush_buffer)(struct tty_struct *);
	void (*set_ldisc)(struct tty_struct *);
	void (*wait_until_sent)(struct tty_struct *, int);
	void (*send_xchar)(struct tty_struct *, char);
	int (*tiocmget)(struct tty_struct *);
	int (*tiocmset)(struct tty_struct *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct *, struct winsize *);
	int (*set_termiox)(struct tty_struct *, struct termiox *);
	int (*get_icount)(struct tty_struct *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver *, int, char *);
	int (*poll_get_char)(struct tty_driver *, int);
	void (*poll_put_char)(struct tty_driver *, int, char);
	const struct file_operations *proc_fops;
};

struct tty_driver {
	int magic;
	struct kref kref;
	struct cdev *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver *other;
	struct tty_struct **ttys;
	struct tty_port **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations *ops;
	struct list_head tty_drivers;
};

struct tty_buffer;

struct tty_bufhead {
	struct work_struct work;
	spinlock_t lock;
	struct tty_buffer *head;
	struct tty_buffer *tail;
	struct tty_buffer *free;
	int memory_used;
};

struct tty_port_operations;

struct tty_port {
	struct tty_bufhead buf;
	struct tty_struct *tty;
	struct tty_struct *itty;
	const struct tty_port_operations *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___3 mutex;
	struct mutex___3 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct *);
	void (*close)(struct tty_struct *);
	void (*flush_buffer)(struct tty_struct *);
	ssize_t (*chars_in_buffer)(struct tty_struct *);
	ssize_t (*read)(struct tty_struct *, struct file___2 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct *, struct file___2 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct *, struct file___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, struct file___2 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct *, struct file___2 *, struct poll_table_struct *);
	int (*hangup)(struct tty_struct *);
	void (*receive_buf)(struct tty_struct *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct *);
	void (*dcd_change)(struct tty_struct *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct *, int);
};

struct tty_ldisc {
	struct tty_ldisc_ops *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct *tty;
};

struct tty_buffer {
	struct tty_buffer *next;
	char *char_buf_ptr;
	unsigned char *flag_buf_ptr;
	int used;
	int size;
	int commit;
	int read;
	long unsigned int data[0];
};

struct tty_port_operations {
	int (*carrier_raised)(struct tty_port *);
	void (*dtr_rts)(struct tty_port *, int);
	void (*shutdown)(struct tty_port *);
	void (*drop)(struct tty_port *);
	int (*activate)(struct tty_port *, struct tty_struct *);
	void (*destruct)(struct tty_port *);
};

enum {
	HI_SOFTIRQ = 0,
	TIMER_SOFTIRQ = 1,
	NET_TX_SOFTIRQ = 2,
	NET_RX_SOFTIRQ = 3,
	BLOCK_SOFTIRQ = 4,
	BLOCK_IOPOLL_SOFTIRQ = 5,
	TASKLET_SOFTIRQ = 6,
	SCHED_SOFTIRQ = 7,
	HRTIMER_SOFTIRQ = 8,
	RCU_SOFTIRQ = 9,
	NR_SOFTIRQS = 10,
};

enum cpu_usage_stat {
	CPUTIME_USER = 0,
	CPUTIME_NICE = 1,
	CPUTIME_SYSTEM = 2,
	CPUTIME_SOFTIRQ = 3,
	CPUTIME_IRQ = 4,
	CPUTIME_IDLE = 5,
	CPUTIME_IDLE_BASE = 6,
	CPUTIME_IOWAIT = 7,
	CPUTIME_IOWAIT_BASE = 8,
	CPUTIME_STEAL = 9,
	CPUTIME_STEAL_BASE = 10,
	CPUTIME_GUEST = 11,
	CPUTIME_GUEST_NICE = 12,
	NR_STATS = 13,
};

struct kernel_stat {
	long unsigned int irqs_sum;
	unsigned int softirqs[10];
};

enum tick_nohz_mode {
	NOHZ_MODE_INACTIVE = 0,
	NOHZ_MODE_LOWRES = 1,
	NOHZ_MODE_HIGHRES = 2,
};

struct tick_sched {
	struct hrtimer sched_timer;
	long unsigned int check_clocks;
	enum tick_nohz_mode nohz_mode;
	ktime_t last_tick;
	int inidle;
	int tick_stopped;
	long unsigned int idle_jiffies;
	long unsigned int idle_calls;
	long unsigned int idle_sleeps;
	int idle_active;
	ktime_t idle_entrytime;
	ktime_t idle_waketime;
	ktime_t idle_exittime;
	ktime_t idle_sleeptime;
	ktime_t iowait_sleeptime;
	ktime_t sleep_length;
	long unsigned int last_jiffies;
	u64 next_timer;
	ktime_t idle_expires;
	int do_timer_last;
};

struct disk_stats {
	long unsigned int sectors[2];
	long unsigned int ios[2];
	long unsigned int merges[2];
	long unsigned int ticks[2];
	long unsigned int io_ticks;
	long unsigned int time_in_queue;
};

struct partition_meta_info {
	char uuid[37];
	u8 volname[64];
};

struct disk_part_tbl {
	struct callback_head callback_head;
	int len;
	struct hd_struct *last_lookup;
	struct hd_struct *part[0];
};

struct hd_geometry;

struct block_device_operations {
	int (*open)(struct block_device *, fmode_t);
	void (*release)(struct gendisk *, fmode_t);
	int (*ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk *, unsigned int);
	int (*media_changed)(struct gendisk *);
	void (*unlock_native_capacity)(struct gendisk *);
	int (*revalidate_disk)(struct gendisk *);
	int (*getgeo)(struct block_device *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct blk_integrity_exchg;

typedef void integrity_gen_fn(struct blk_integrity_exchg *);

typedef int integrity_vrfy_fn(struct blk_integrity_exchg *);

typedef void integrity_set_tag_fn(void *, void *, unsigned int);

typedef void integrity_get_tag_fn(void *, void *, unsigned int);

struct blk_integrity {
	integrity_gen_fn *generate_fn;
	integrity_vrfy_fn *verify_fn;
	integrity_set_tag_fn *set_tag_fn;
	integrity_get_tag_fn *get_tag_fn;
	short unsigned int flags;
	short unsigned int tuple_size;
	short unsigned int sector_size;
	short unsigned int tag_size;
	const char *name;
	struct kobject kobj;
};

enum bdi_stat_item {
	BDI_RECLAIMABLE = 0,
	BDI_WRITEBACK = 1,
	BDI_DIRTIED = 2,
	BDI_WRITTEN = 3,
	NR_BDI_STAT_ITEMS = 4,
};

typedef void *mempool_alloc_t(gfp_t, void *);

typedef void mempool_free_t(void *, void *);

struct mempool_s {
	spinlock_t lock;
	int min_nr;
	int curr_nr;
	void **elements;
	void *pool_data;
	mempool_alloc_t *alloc;
	mempool_free_t *free;
	wait_queue_head_t wait;
};

struct io_cq {
	struct request_queue *q;
	struct io_context *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn(struct request *, int);

enum rq_cmd_type_bits {
	REQ_TYPE_FS = 1,
	REQ_TYPE_BLOCK_PC = 2,
	REQ_TYPE_SENSE = 3,
	REQ_TYPE_PM_SUSPEND = 4,
	REQ_TYPE_PM_RESUME = 5,
	REQ_TYPE_PM_SHUTDOWN = 6,
	REQ_TYPE_SPECIAL = 7,
	REQ_TYPE_ATA_TASKFILE = 8,
	REQ_TYPE_ATA_PC = 9,
};

struct request {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio *bio;
	struct bio *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn *saved_end_io;
		} flush;
	};
	struct gendisk *rq_disk;
	struct hd_struct *part;
	long unsigned int start_time;
	struct request_list *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn *end_io;
	void *end_io_data;
	struct request *next_rq;
};

typedef int elevator_merge_fn(struct request_queue *, struct request **, struct bio *);

typedef void elevator_merge_req_fn(struct request_queue *, struct request *, struct request *);

typedef void elevator_merged_fn(struct request_queue *, struct request *, int);

typedef int elevator_allow_merge_fn(struct request_queue *, struct request *, struct bio *);

typedef void elevator_bio_merged_fn(struct request_queue *, struct request *, struct bio *);

typedef int elevator_dispatch_fn(struct request_queue *, int);

typedef void elevator_add_req_fn(struct request_queue *, struct request *);

typedef struct request *elevator_request_list_fn(struct request_queue *, struct request *);

typedef void elevator_completed_req_fn(struct request_queue *, struct request *);

typedef int elevator_may_queue_fn(struct request_queue *, int);

typedef void elevator_init_icq_fn(struct io_cq *);

typedef void elevator_exit_icq_fn(struct io_cq *);

typedef int elevator_set_req_fn(struct request_queue *, struct request *, struct bio *, gfp_t);

typedef void elevator_put_req_fn(struct request *);

typedef void elevator_activate_req_fn(struct request_queue *, struct request *);

typedef void elevator_deactivate_req_fn(struct request_queue *, struct request *);

struct elevator_type;

typedef int elevator_init_fn(struct request_queue *, struct elevator_type *);

typedef void elevator_exit_fn(struct elevator_queue *);

struct elevator_ops {
	elevator_merge_fn *elevator_merge_fn;
	elevator_merged_fn *elevator_merged_fn;
	elevator_merge_req_fn *elevator_merge_req_fn;
	elevator_allow_merge_fn *elevator_allow_merge_fn;
	elevator_bio_merged_fn *elevator_bio_merged_fn;
	elevator_dispatch_fn *elevator_dispatch_fn;
	elevator_add_req_fn *elevator_add_req_fn;
	elevator_activate_req_fn *elevator_activate_req_fn;
	elevator_deactivate_req_fn *elevator_deactivate_req_fn;
	elevator_completed_req_fn *elevator_completed_req_fn;
	elevator_request_list_fn *elevator_former_req_fn;
	elevator_request_list_fn *elevator_latter_req_fn;
	elevator_init_icq_fn *elevator_init_icq_fn;
	elevator_exit_icq_fn *elevator_exit_icq_fn;
	elevator_set_req_fn *elevator_set_req_fn;
	elevator_put_req_fn *elevator_put_req_fn;
	elevator_may_queue_fn *elevator_may_queue_fn;
	elevator_init_fn *elevator_init_fn;
	elevator_exit_fn *elevator_exit_fn;
};

struct elv_fs_entry;

struct elevator_type {
	struct kmem_cache *icq_cache;
	struct elevator_ops ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue {
	struct elevator_type *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___3 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue *, char *);
	ssize_t (*store)(struct elevator_queue *, const char *, size_t);
};

struct bvec_merge_data {
	struct block_device *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag {
	struct request **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_integrity_exchg {
	void *prot_buf;
	void *data_buf;
	sector_t sector;
	unsigned int data_size;
	short unsigned int sector_size;
	const char *disk_name;
};

struct blacklist_entry {
	struct list_head next;
	char *buf;
};

struct task_struct___4;

struct pv_cpu_ops___3 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___4 *);
	void (*end_context_switch)(struct task_struct___4 *);
};

struct mutex___4 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___4 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___4;

struct signal_struct___3;

struct task_struct___4 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___4 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___4 *mm;
	struct mm_struct___4 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___4 *real_parent;
	struct task_struct___4 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___4 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___3 = 0,
		VTIME_USER___3 = 1,
		VTIME_SYS___3 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___2 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___4 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___4 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___4 *, struct mm_struct___4 *);
	void (*dup_mmap)(struct mm_struct___4 *, struct mm_struct___4 *);
	void (*exit_mmap)(struct mm_struct___4 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___4 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___4 *);
	void (*pgd_free)(struct mm_struct___4 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___4 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___4 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___4 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___4 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___4 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___4 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___4 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___4 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___4 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___4 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___4 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___4 lock;
	void *vdso;
} mm_context_t___4;

struct vm_area_struct___4;

struct core_state___3;

struct mm_struct___4 {
	struct vm_area_struct___4 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___4 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___4 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___4 context;
	long unsigned int flags;
	struct core_state___3 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___4 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___3;

struct lruvec___3 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___3 *zone;
};

struct pglist_data___3;

struct zone___3 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___3 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___3 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___3 {
	struct zone___3 *zone;
	int zone_idx;
};

struct zonelist___3 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___3 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___3 {
	struct zone___3 node_zones[4];
	struct zonelist___3 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___4 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___3 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___4 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vm_area_struct___4 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___4 *vm_next;
	struct vm_area_struct___4 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___4 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___3 {
	struct task_struct___4 *task;
	struct core_thread___3 *next;
};

struct core_state___3 {
	atomic_t nr_threads;
	struct core_thread___3 dumper;
	struct completion startup;
};

struct signal_struct___3 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___4 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___4 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___4 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct new_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
	char domainname[65];
};

struct uts_namespace {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

enum {
	PROC_ROOT_INO = 1,
	PROC_IPC_INIT_INO = 4026531839,
	PROC_UTS_INIT_INO = 4026531838,
	PROC_USER_INIT_INO = 4026531837,
	PROC_PID_INIT_INO = 4026531836,
};

typedef long long int __s64;

typedef __u16 __le16;

typedef __u16 __be16;

typedef __u32 __be32;

typedef __u16 __sum16;

typedef __u32 __wsum;

typedef __u8 u_int8_t;

typedef u64 dma_addr_t;

struct page___2;

typedef struct page___2 *pgtable_t___2;

struct address_space___2;

struct kmem_cache___2;

struct page___2 {
	long unsigned int flags;
	struct address_space___2 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___2 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___2 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___2 *slab_cache;
		struct page___2 *first_page;
	};
	long: 64;
};

struct thread_struct___2;

struct task_struct___5;

struct pv_cpu_ops___4 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___2 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___2 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___5 *);
	void (*end_context_switch)(struct task_struct___5 *);
};

struct perf_event___2;

struct thread_struct___2 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___2 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___2;

struct pid_link___2 {
	struct hlist_node node;
	struct pid___2 *pid;
};

struct mutex___5 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___5 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___2 {
	struct page___2 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___5;

struct signal_struct___4;

struct bio_list___2;

struct backing_dev_info___2;

struct io_context___2;

struct task_struct___5 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___5 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___5 *mm;
	struct mm_struct___5 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___5 *real_parent;
	struct task_struct___5 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___5 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___2 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___4 = 0,
		VTIME_USER___4 = 1,
		VTIME_SYS___4 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___2 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___4 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___5 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___2 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___5 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___5 *, struct mm_struct___5 *);
	void (*dup_mmap)(struct mm_struct___5 *, struct mm_struct___5 *);
	void (*exit_mmap)(struct mm_struct___5 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___5 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___5 *);
	void (*pgd_free)(struct mm_struct___5 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___5 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___5 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___5 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___5 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___5 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___5 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___5 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___5 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___5 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___5 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___5 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___5 lock;
	void *vdso;
} mm_context_t___5;

struct xol_area___2;

struct uprobes_state___2 {
	struct xol_area___2 *xol_area;
};

struct vm_area_struct___5;

struct core_state___4;

struct mm_struct___5 {
	struct vm_area_struct___5 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___5 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___5 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___5 context;
	long unsigned int flags;
	struct core_state___4 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___5 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___2 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___2;

struct module_kobject___2 {
	struct kobject kobj;
	struct module___2 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___2;

struct ftrace_event_call___2;

struct module___2 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___2 mkobj;
	struct module_attribute___2 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___5 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___2 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___5 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___5 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___5 *target;
};

struct perf_sample_data___2;

typedef void (*perf_overflow_handler_t___2)(struct perf_event___2 *, struct perf_sample_data___2 *, struct pt_regs *);

struct ftrace_ops___2;

typedef void (*ftrace_func_t___2)(long unsigned int, long unsigned int, struct ftrace_ops___2 *, struct pt_regs *);

struct ftrace_ops___2 {
	ftrace_func_t___2 func;
	struct ftrace_ops___2 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___5 regex_lock;
};

struct pmu___2;

struct fasync_struct___2;

struct pid_namespace___2;

struct perf_cgroup___2;

struct perf_event___2 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___2 *group_leader;
	struct pmu___2 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___2 hw;
	struct perf_event_context *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___5 child_mutex;
	struct list_head child_list;
	struct perf_event___2 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___5 *owner;
	struct mutex___5 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___2 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___2 *);
	struct callback_head callback_head;
	struct pid_namespace___2 *ns;
	u64 id;
	perf_overflow_handler_t___2 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___2 ftrace_ops;
	struct perf_cgroup___2 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___4;

struct lruvec___4 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___4 *zone;
};

struct pglist_data___4;

struct zone___4 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___4 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___4 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___4 {
	struct zone___4 *zone;
	int zone_idx;
};

struct zonelist___4 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___4 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___4 {
	struct zone___4 node_zones[4];
	struct zonelist___4 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___5 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct notifier_block;

typedef int (*notifier_fn_t)(struct notifier_block *, long unsigned int, void *);

struct notifier_block {
	notifier_fn_t notifier_call;
	struct notifier_block *next;
	int priority;
};

struct blocking_notifier_head {
	struct rw_semaphore rwsem;
	struct notifier_block *head;
};

struct irq_data___2;

struct x86_io_apic_ops___2 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___2 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___2;

struct irq_data___2 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___2 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___2;

struct dev_pm_ops___2 {
	int (*prepare)(struct device___2 *);
	void (*complete)(struct device___2 *);
	int (*suspend)(struct device___2 *);
	int (*resume)(struct device___2 *);
	int (*freeze)(struct device___2 *);
	int (*thaw)(struct device___2 *);
	int (*poweroff)(struct device___2 *);
	int (*restore)(struct device___2 *);
	int (*suspend_late)(struct device___2 *);
	int (*resume_early)(struct device___2 *);
	int (*freeze_late)(struct device___2 *);
	int (*thaw_early)(struct device___2 *);
	int (*poweroff_late)(struct device___2 *);
	int (*restore_early)(struct device___2 *);
	int (*suspend_noirq)(struct device___2 *);
	int (*resume_noirq)(struct device___2 *);
	int (*freeze_noirq)(struct device___2 *);
	int (*thaw_noirq)(struct device___2 *);
	int (*poweroff_noirq)(struct device___2 *);
	int (*restore_noirq)(struct device___2 *);
	int (*runtime_suspend)(struct device___2 *);
	int (*runtime_resume)(struct device___2 *);
	int (*runtime_idle)(struct device___2 *);
};

struct device_type___2;

struct bus_type___2;

struct device_driver___2;

struct dev_pm_domain___2;

struct class___2;

struct attribute_group___2;

struct device_rh___2;

struct device___2 {
	struct device___2 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___2 *type;
	struct mutex___5 mutex;
	struct bus_type___2 *bus;
	struct device_driver___2 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___2 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___2 *class;
	const struct attribute_group___2 **groups;
	void (*release)(struct device___2 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___2 *device_rh;
};

enum pm_qos_type {
	PM_QOS_UNITIALIZED = 0,
	PM_QOS_MAX = 1,
	PM_QOS_MIN = 2,
};

struct pm_qos_constraints {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	enum pm_qos_type type;
	struct blocking_notifier_head *notifiers;
};

struct pm_qos_flags {
	struct list_head list;
	s32 effective_flags;
};

struct dev_pm_qos_request;

struct dev_pm_qos {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request *latency_req;
	struct dev_pm_qos_request *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request *latency_tolerance_req;
};

struct dev_pm_info_rh___2 {
	void (*set_latency_tolerance)(struct device___2 *, s32);
};

struct dev_pm_domain___2 {
	struct dev_pm_ops___2 ops;
};

struct smp_ops___4 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___5 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table;

typedef int proc_handler(struct ctl_table *, int, void *, size_t *, loff_t *);

struct ctl_table_poll;

struct ctl_table {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table *child;
	proc_handler *proc_handler;
	struct ctl_table_poll *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll {
	atomic_t event;
	wait_queue_head_t wait;
};

struct ctl_table_header;

struct ctl_node {
	struct rb_node node;
	struct ctl_table_header *header;
};

struct ctl_table_root;

struct ctl_table_set;

struct ctl_dir;

struct ctl_table_header {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root *root;
	struct ctl_table_set *set;
	struct ctl_dir *parent;
	struct ctl_node *node;
};

struct ctl_dir {
	struct ctl_table_header header;
	struct rb_root root;
};

struct ctl_table_set {
	int (*is_seen)(struct ctl_table_set *);
	struct ctl_dir dir;
};

struct ctl_table_root {
	struct ctl_table_set default_set;
	struct ctl_table_set * (*lookup)(struct ctl_table_root *, struct nsproxy *);
	int (*permissions)(struct ctl_table_header *, struct ctl_table *);
};

struct nsproxy {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___2 *pid_ns;
	struct net *net_ns;
};

typedef __u64 __addrpair;

typedef __u32 __portpair;

struct hlist_nulls_node {
	struct hlist_nulls_node *next;
	struct hlist_nulls_node **pprev;
};

struct in6_addr {
	union {
		__u8 u6_addr8[16];
		__be16 u6_addr16[8];
		__be32 u6_addr32[4];
	} in6_u;
};

struct proto;

struct sock_common {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto *skc_prot;
	struct net *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

typedef struct {
	spinlock_t slock;
	int owned;
	wait_queue_head_t wq;
} socket_lock_t;

struct sk_buff;

struct sk_buff_head {
	struct sk_buff *next;
	struct sk_buff *prev;
	__u32 qlen;
	spinlock_t lock;
};

typedef u64 netdev_features_t;

struct sk_filter;

struct socket_wq;

struct xfrm_policy;

struct dst_entry;

struct socket;

struct cg_proto;

struct sock {
	struct sock_common __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff *head;
		struct sk_buff *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter *sk_filter;
	struct socket_wq *sk_wq;
	struct sk_buff_head rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry *sk_rx_dst;
	struct dst_entry *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head sk_error_queue;
	struct proto *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___2 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket *sk_socket;
	void *sk_user_data;
	struct page_frag___2 sk_frag;
	struct sk_buff *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto *sk_cgrp;
	void (*sk_state_change)(struct sock *);
	void (*sk_data_ready)(struct sock *, int);
	void (*sk_write_space)(struct sock *);
	void (*sk_error_report)(struct sock *);
	int (*sk_backlog_rcv)(struct sock *, struct sk_buff *);
	void (*sk_destruct)(struct sock *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___2;

struct attribute_group___2 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___2 **bin_attrs;
};

struct bin_attribute___2 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file *, struct kobject *, struct bin_attribute___2 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file *, struct kobject *, struct bin_attribute___2 *, char *, loff_t, size_t);
	int (*mmap)(struct file *, struct kobject *, struct bin_attribute___2 *, struct vm_area_struct___5 *);
};

struct dentry___3;

struct path___2 {
	struct vfsmount *mnt;
	struct dentry___3 *dentry;
};

struct fown_struct___2 {
	rwlock_t lock;
	struct pid___2 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___3;

struct file_operations___2;

struct file {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___2 f_path;
	struct inode___3 *f_inode;
	const struct file_operations___2 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___2 *f_mapping;
	struct mutex___5 f_pos_lock;
};

struct vm_operations_struct___4;

struct vm_area_struct___5 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___5 *vm_next;
	struct vm_area_struct___5 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___5 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___4 *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___2 *, struct module_kobject___2 *, char *);
	ssize_t (*store)(struct module_attribute___2 *, struct module_kobject___2 *, const char *, size_t);
	void (*setup)(struct module___2 *, const char *);
	int (*test)(struct module___2 *);
	void (*free)(struct module___2 *);
};

struct trace_event_functions___2;

struct trace_event___2 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___2 *funcs;
};

struct ftrace_event_class___2;

struct ftrace_event_call___2 {
	struct list_head list;
	struct ftrace_event_class___2 *class;
	char *name;
	struct trace_event___2 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct xol_area___2 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___2 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___2;

struct memcg_cache_params___2;

struct kmem_cache___2 {
	struct kmem_cache_cpu___2 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___2 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___2;

struct address_space___2 {
	struct inode___3 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___5 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___2 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___2 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___2;

struct vm_operations_struct___4 {
	void (*open)(struct vm_area_struct___5 *);
	void (*close)(struct vm_area_struct___5 *);
	int (*fault)(struct vm_area_struct___5 *, struct vm_fault___2 *);
	int (*page_mkwrite)(struct vm_area_struct___5 *, struct vm_fault___2 *);
	int (*access)(struct vm_area_struct___5 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___5 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___5 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___5 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___5 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___4 {
	struct task_struct___5 *task;
	struct core_thread___4 *next;
};

struct core_state___4 {
	atomic_t nr_threads;
	struct core_thread___4 dumper;
	struct completion startup;
};

struct upid___2 {
	int nr;
	struct pid_namespace___2 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___2 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___5 *child_reaper;
	struct kmem_cache___2 *pid_cachep;
	unsigned int level;
	struct pid_namespace___2 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___3 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___2 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___2 numbers[1];
};

struct tty_struct___2;

struct signal_struct___4 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___5 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___5 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___2 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___2 *tty_old_pgrp;
	int leader;
	struct tty_struct___2 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___5 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___2;

struct tty_operations___2;

struct tty_ldisc___2;

struct tty_port___2;

struct tty_struct___2 {
	int magic;
	struct kref kref;
	struct device___2 *dev;
	struct tty_driver___2 *driver;
	const struct tty_operations___2 *ops;
	int index;
	struct mutex___5 ldisc_mutex;
	struct tty_ldisc___2 *ldisc;
	struct mutex___5 atomic_write_lock;
	struct mutex___5 legacy_mutex;
	struct mutex___5 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___2 *pgrp;
	struct pid___2 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___2 *link;
	struct fasync_struct___2 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___2 *port;
	struct ld_semaphore ldisc_sem;
};

struct fs_struct {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___2 root;
	struct path___2 pwd;
};

struct bio___2;

struct bio_list___2 {
	struct bio___2 *head;
	struct bio___2 *tail;
};

struct bdi_writeback___2 {
	struct backing_dev_info___2 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___2 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___2 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___2 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___3 *debug_dir;
	struct dentry___3 *debug_stats;
};

struct io_cq___2;

struct io_context___2 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___2 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___2;

struct css_set {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___2 *subsys[11];
	struct callback_head callback_head;
};

typedef u32 compat_uptr_t;

struct compat_robust_list {
	compat_uptr_t next;
};

typedef s32 compat_long_t;

struct compat_robust_list_head {
	struct compat_robust_list list;
	compat_long_t futex_offset;
	compat_uptr_t list_op_pending;
};

struct perf_event_context {
	struct pmu___2 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___5 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___5 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

typedef short unsigned int __kernel_sa_family_t;

typedef __kernel_sa_family_t sa_family_t;

struct sockaddr {
	sa_family_t sa_family;
	char sa_data[14];
};

struct msghdr {
	void *msg_name;
	int msg_namelen;
	struct iovec *msg_iov;
	__kernel_size_t msg_iovlen;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
};

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
} sync_serial_settings;

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
	unsigned int slot_map;
} te1_settings;

typedef struct {
	short unsigned int encoding;
	short unsigned int parity;
} raw_hdlc_proto;

typedef struct {
	unsigned int t391;
	unsigned int t392;
	unsigned int n391;
	unsigned int n392;
	unsigned int n393;
	short unsigned int lmi;
	short unsigned int dce;
} fr_proto;

typedef struct {
	unsigned int dlci;
} fr_proto_pvc;

typedef struct {
	unsigned int dlci;
	char master[16];
} fr_proto_pvc_info;

typedef struct {
	unsigned int interval;
	unsigned int timeout;
} cisco_proto;

struct ifmap {
	long unsigned int mem_start;
	long unsigned int mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct if_settings {
	unsigned int type;
	unsigned int size;
	union {
		raw_hdlc_proto *raw_hdlc;
		cisco_proto *cisco;
		fr_proto *fr;
		fr_proto_pvc *fr_pvc;
		fr_proto_pvc_info *fr_pvc_info;
		sync_serial_settings *sync;
		te1_settings *te1;
	} ifs_ifsu;
};

struct ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		int ifru_ivalue;
		int ifru_mtu;
		struct ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		void *ifru_data;
		struct if_settings ifru_settings;
	} ifr_ifru;
};

struct dentry_operations___2;

struct super_block___3;

struct dentry___3 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___3 *d_parent;
	struct qstr d_name;
	struct inode___3 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___2 *d_op;
	struct super_block___3 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___2;

struct file_lock___2;

struct dquot___2;

struct block_device___2;

struct cdev___2;

struct inode___3 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___2 *i_op;
	struct super_block___3 *i_sb;
	struct address_space___2 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___5 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___2 *i_fop;
	struct file_lock___2 *i_flock;
	struct address_space___2 i_data;
	struct dquot___2 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___2 *i_bdev;
		struct cdev___2 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___2 {
	int (*d_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_hash)(const struct dentry___3 *, struct qstr *);
	int (*d_compare)(const struct dentry___3 *, const struct dentry___3 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___3 *);
	void (*d_release)(struct dentry___3 *);
	void (*d_prune)(struct dentry___3 *);
	void (*d_iput)(struct dentry___3 *, struct inode___3 *);
	char * (*d_dname)(struct dentry___3 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___2 *);
	int (*d_manage)(struct dentry___3 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___2;

struct mem_dqinfo___2 {
	struct quota_format_type___2 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___2;

struct quota_info___2 {
	unsigned int flags;
	struct mutex___5 dqio_mutex;
	struct mutex___5 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___3 *files[2];
	struct mem_dqinfo___2 info[2];
	const struct quota_format_ops___2 *ops[2];
};

struct file_system_type___2;

struct super_operations___2;

struct dquot_operations___2;

struct quotactl_ops___2;

struct xattr_handler___2;

struct super_block___3 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___2 *s_type;
	const struct super_operations___2 *s_op;
	const struct dquot_operations___2 *dq_op;
	const struct quotactl_ops___2 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___3 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___2 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___2 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___5 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___2 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount {
	struct dentry___3 *mnt_root;
	struct super_block___3 *mnt_sb;
	int mnt_flags;
};

typedef void bio_end_io_t___2(struct bio___2 *, int);

struct bio_vec___2 {
	struct page___2 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___2;

struct bio_set___2;

struct bio___2 {
	sector_t bi_sector;
	struct bio___2 *bi_next;
	struct block_device___2 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___2 *bi_end_io;
	void *bi_private;
	struct io_context___2 *bi_ioc;
	struct cgroup_subsys_state___2 *bi_css;
	struct bio_integrity_payload___2 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___2 *bi_io_vec;
	struct bio_set___2 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	struct bio_vec___2 bi_inline_vecs[0];
};

struct hd_struct___2;

struct gendisk___2;

struct request_queue___2;

struct block_device___2 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___3 *bd_inode;
	struct super_block___3 *bd_super;
	struct mutex___5 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___2 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___2 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___2 *bd_disk;
	struct request_queue___2 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___5 bd_fsfreeze_mutex;
};

struct cgroup___2;

struct cgroup_subsys_state___2 {
	struct cgroup___2 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___2 {
	struct bio___2 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___2 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___2 *bip_vec;
	struct bio_vec___2 bip_inline_vecs[0];
};

struct bio_set___2 {
	struct kmem_cache___2 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___2 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct io_event;

typedef int kiocb_cancel_fn(struct kiocb *, struct io_event *);

struct kioctx;

struct kiocb {
	atomic_t ki_users;
	struct file *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn *ki_cancel;
	void (*ki_dtor)(struct kiocb *);
	union {
		void *user;
		struct task_struct___5 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___3 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file *ia_file;
};

struct dquot___2 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___5 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___3 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___2 {
	int qf_fmt_id;
	const struct quota_format_ops___2 *qf_ops;
	struct module___2 *qf_owner;
	struct quota_format_type___2 *qf_next;
};

struct quota_format_ops___2 {
	int (*check_quota_file)(struct super_block___3 *, int);
	int (*read_file_info)(struct super_block___3 *, int);
	int (*write_file_info)(struct super_block___3 *, int);
	int (*free_file_info)(struct super_block___3 *, int);
	int (*read_dqblk)(struct dquot___2 *);
	int (*commit_dqblk)(struct dquot___2 *);
	int (*release_dqblk)(struct dquot___2 *);
};

struct dquot_operations___2 {
	int (*write_dquot)(struct dquot___2 *);
	struct dquot___2 * (*alloc_dquot)(struct super_block___3 *, int);
	void (*destroy_dquot)(struct dquot___2 *);
	int (*acquire_dquot)(struct dquot___2 *);
	int (*release_dquot)(struct dquot___2 *);
	int (*mark_dirty)(struct dquot___2 *);
	int (*write_info)(struct super_block___3 *, int);
	qsize_t * (*get_reserved_space)(struct inode___3 *);
};

struct quotactl_ops___2 {
	int (*quota_on)(struct super_block___3 *, int, int, struct path___2 *);
	int (*quota_on_meta)(struct super_block___3 *, int, int);
	int (*quota_off)(struct super_block___3 *, int);
	int (*quota_sync)(struct super_block___3 *, int);
	int (*get_info)(struct super_block___3 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___3 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___3 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___3 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___3 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___3 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___3 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___3 *, unsigned int);
};

struct swap_info_struct___2;

struct address_space_operations___2 {
	int (*writepage)(struct page___2 *, struct writeback_control *);
	int (*readpage)(struct file *, struct page___2 *);
	int (*writepages)(struct address_space___2 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___2 *);
	int (*readpages)(struct file *, struct address_space___2 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___2 **, void **);
	int (*write_end)(struct file *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___2 *, void *);
	sector_t (*bmap)(struct address_space___2 *, sector_t);
	void (*invalidatepage)(struct page___2 *, long unsigned int);
	int (*releasepage)(struct page___2 *, gfp_t);
	void (*freepage)(struct page___2 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___2 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___2 *, struct page___2 *, struct page___2 *, enum migrate_mode);
	int (*launder_page)(struct page___2 *);
	int (*is_partially_uptodate)(struct page___2 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___2 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___2 *, struct page___2 *);
	int (*swap_activate)(struct swap_info_struct___2 *, struct file *, sector_t *);
	void (*swap_deactivate)(struct file *);
	void (*invalidatepage_range)(struct page___2 *, unsigned int, unsigned int);
};

struct swap_info_struct___2 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___2 *bdev;
	struct file *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___2 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___2 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___2;

struct block_device_operations___2;

struct gendisk___2 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___2 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___2 *part_tbl;
	struct hd_struct___2 part0;
	const struct block_device_operations___2 *fops;
	struct request_queue___2 *queue;
	void *private_data;
	int flags;
	struct device___2 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___2 {
	struct request_queue___2 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___2(struct request_queue___2 *);

typedef void make_request_fn___2(struct request_queue___2 *, struct bio___2 *);

struct request___2;

typedef int prep_rq_fn___2(struct request_queue___2 *, struct request___2 *);

struct bvec_merge_data___2;

typedef int merge_bvec_fn___2(struct request_queue___2 *, struct bvec_merge_data___2 *, struct bio_vec___2 *);

typedef void softirq_done_fn___2(struct request___2 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___2(struct request___2 *);

typedef int dma_drain_needed_fn___2(struct request___2 *);

typedef int lld_busy_fn___2(struct request_queue___2 *);

struct queue_limits___2 {
	long unsigned int bounce_pfn;
	long unsigned int seg_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	short unsigned int logical_block_size;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char cluster;
	unsigned char discard_zeroes_data;
	unsigned int xcopy_reserved;
	union {
		unsigned int chunk_sectors;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct bsg_class_device___2 {
	struct device___2 *class_dev;
	struct device___2 *parent;
	int minor;
	struct request_queue___2 *queue;
	struct kref ref;
	void (*release)(struct device___2 *);
};

typedef void unprep_rq_fn___2(struct request_queue___2 *, struct request___2 *);

struct elevator_queue___2;

struct blk_queue_tag___2;

struct request_queue___2 {
	struct list_head queue_head;
	struct request___2 *last_merge;
	struct elevator_queue___2 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___2 root_rl;
	request_fn_proc___2 *request_fn;
	make_request_fn___2 *make_request_fn;
	prep_rq_fn___2 *prep_rq_fn;
	merge_bvec_fn___2 *merge_bvec_fn;
	softirq_done_fn___2 *softirq_done_fn;
	rq_timed_out_fn___2 *rq_timed_out_fn;
	dma_drain_needed_fn___2 *dma_drain_needed;
	lld_busy_fn___2 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___2 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___2 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___2 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___2 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___2 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___2 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___5 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___2 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___2 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___2 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___2 {
	struct kobject kobj;
	struct module___2 *owner;
	const struct file_operations___2 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct posix_acl_entry {
	short int e_tag;
	short unsigned int e_perm;
	union {
		kuid_t e_uid;
		kgid_t e_gid;
	};
};

struct posix_acl {
	union {
		atomic_t a_refcount;
		struct callback_head a_rcu;
	};
	unsigned int a_count;
	struct posix_acl_entry a_entries[0];
};

struct inode_operations___2 {
	struct dentry___3 * (*lookup)(struct inode___3 *, struct dentry___3 *, unsigned int);
	void * (*follow_link)(struct dentry___3 *, struct nameidata *);
	int (*permission)(struct inode___3 *, int);
	struct posix_acl * (*get_acl)(struct inode___3 *, int);
	int (*readlink)(struct dentry___3 *, char *, int);
	void (*put_link)(struct dentry___3 *, struct nameidata *, void *);
	int (*create)(struct inode___3 *, struct dentry___3 *, umode_t, bool);
	int (*link)(struct dentry___3 *, struct inode___3 *, struct dentry___3 *);
	int (*unlink)(struct inode___3 *, struct dentry___3 *);
	int (*symlink)(struct inode___3 *, struct dentry___3 *, const char *);
	int (*mkdir)(struct inode___3 *, struct dentry___3 *, umode_t);
	int (*rmdir)(struct inode___3 *, struct dentry___3 *);
	int (*mknod)(struct inode___3 *, struct dentry___3 *, umode_t, dev_t);
	int (*rename)(struct inode___3 *, struct dentry___3 *, struct inode___3 *, struct dentry___3 *);
	int (*setattr)(struct dentry___3 *, struct iattr___3 *);
	int (*getattr)(struct vfsmount *, struct dentry___3 *, struct kstat *);
	int (*setxattr)(struct dentry___3 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___3 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___3 *, char *, size_t);
	int (*removexattr)(struct dentry___3 *, const char *);
	int (*fiemap)(struct inode___3 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___3 *, struct timespec *, int);
	int (*atomic_open)(struct inode___3 *, struct dentry___3 *, struct file *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___2;

struct seq_file___2;

struct file_operations___2 {
	struct module___2 *owner;
	loff_t (*llseek)(struct file *, loff_t, int);
	ssize_t (*read)(struct file *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file *, void *, filldir_t);
	unsigned int (*poll)(struct file *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file *, unsigned int, long unsigned int);
	int (*mmap)(struct file *, struct vm_area_struct___5 *);
	int (*open)(struct inode___3 *, struct file *);
	int (*flush)(struct file *, fl_owner_t);
	int (*release)(struct inode___3 *, struct file *);
	int (*fsync)(struct file *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file *, int);
	int (*lock)(struct file *, int, struct file_lock___2 *);
	ssize_t (*sendpage)(struct file *, struct page___2 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file *, int, struct file_lock___2 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file *, long int, struct file_lock___2 **, void **);
		struct {
			int (*setlease)(struct file *, long int, struct file_lock___2 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___2 *, struct file *);
};

struct file_lock_operations___2;

struct lock_manager_operations___2;

struct file_lock___2 {
	struct file_lock___2 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___2 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___2 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___2 *fl_ops;
	const struct lock_manager_operations___2 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___2 {
	void (*fl_copy_lock)(struct file_lock___2 *, struct file_lock___2 *);
	void (*fl_release_private)(struct file_lock___2 *);
};

struct lock_manager_operations___2 {
	int (*lm_compare_owner)(struct file_lock___2 *, struct file_lock___2 *);
	long unsigned int (*lm_owner_key)(struct file_lock___2 *);
	void (*lm_notify)(struct file_lock___2 *);
	int (*lm_grant)(struct file_lock___2 *, struct file_lock___2 *, int);
	void (*lm_break)(struct file_lock___2 *);
	int (*lm_change)(struct file_lock___2 **, int);
};

struct fasync_struct___2 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___2 *fa_next;
	struct file *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___2 {
	const char *name;
	int fs_flags;
	struct dentry___3 * (*mount)(struct file_system_type___2 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___3 *);
	struct module___2 *owner;
	struct file_system_type___2 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___2 {
	struct inode___3 * (*alloc_inode)(struct super_block___3 *);
	void (*destroy_inode)(struct inode___3 *);
	void (*dirty_inode)(struct inode___3 *, int);
	int (*write_inode)(struct inode___3 *, struct writeback_control *);
	int (*drop_inode)(struct inode___3 *);
	void (*evict_inode)(struct inode___3 *);
	void (*put_super)(struct super_block___3 *);
	int (*sync_fs)(struct super_block___3 *, int);
	int (*freeze_fs)(struct super_block___3 *);
	int (*unfreeze_fs)(struct super_block___3 *);
	int (*statfs)(struct dentry___3 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___3 *, int *, char *);
	void (*umount_begin)(struct super_block___3 *);
	int (*show_options)(struct seq_file___2 *, struct dentry___3 *);
	int (*show_devname)(struct seq_file___2 *, struct dentry___3 *);
	int (*show_path)(struct seq_file___2 *, struct dentry___3 *);
	int (*show_stats)(struct seq_file___2 *, struct dentry___3 *);
	ssize_t (*quota_read)(struct super_block___3 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___3 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___3 *);
	int (*bdev_try_to_free_page)(struct super_block___3 *, struct page___2 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___3 *);
	void (*free_cached_objects)(struct super_block___3 *, int);
};

struct xattr_handler___2 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___3 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___3 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___3 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___2)(struct file *, wait_queue_head_t *, struct poll_table_struct___2 *);

struct poll_table_struct___2 {
	poll_queue_proc___2 _qproc;
	long unsigned int _key;
};

struct seq_operations___2;

struct seq_file___2 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___5 lock;
	const struct seq_operations___2 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct io_event {
	__u64 data;
	__u64 obj;
	__s64 res;
	__s64 res2;
};

struct tty_operations___2 {
	struct tty_struct___2 * (*lookup)(struct tty_driver___2 *, struct inode___3 *, int);
	int (*install)(struct tty_driver___2 *, struct tty_struct___2 *);
	void (*remove)(struct tty_driver___2 *, struct tty_struct___2 *);
	int (*open)(struct tty_struct___2 *, struct file *);
	void (*close)(struct tty_struct___2 *, struct file *);
	void (*shutdown)(struct tty_struct___2 *);
	void (*cleanup)(struct tty_struct___2 *);
	int (*write)(struct tty_struct___2 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___2 *, unsigned char);
	void (*flush_chars)(struct tty_struct___2 *);
	int (*write_room)(struct tty_struct___2 *);
	int (*chars_in_buffer)(struct tty_struct___2 *);
	int (*ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	void (*throttle)(struct tty_struct___2 *);
	void (*unthrottle)(struct tty_struct___2 *);
	void (*stop)(struct tty_struct___2 *);
	void (*start)(struct tty_struct___2 *);
	void (*hangup)(struct tty_struct___2 *);
	int (*break_ctl)(struct tty_struct___2 *, int);
	void (*flush_buffer)(struct tty_struct___2 *);
	void (*set_ldisc)(struct tty_struct___2 *);
	void (*wait_until_sent)(struct tty_struct___2 *, int);
	void (*send_xchar)(struct tty_struct___2 *, char);
	int (*tiocmget)(struct tty_struct___2 *);
	int (*tiocmset)(struct tty_struct___2 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___2 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___2 *, struct termiox *);
	int (*get_icount)(struct tty_struct___2 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___2 *, int, char *);
	int (*poll_get_char)(struct tty_driver___2 *, int);
	void (*poll_put_char)(struct tty_driver___2 *, int, char);
	const struct file_operations___2 *proc_fops;
};

struct tty_driver___2 {
	int magic;
	struct kref kref;
	struct cdev___2 *cdevs;
	struct module___2 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___2 *other;
	struct tty_struct___2 **ttys;
	struct tty_port___2 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___2 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___2;

struct tty_port___2 {
	struct tty_bufhead buf;
	struct tty_struct___2 *tty;
	struct tty_struct___2 *itty;
	const struct tty_port_operations___2 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___5 mutex;
	struct mutex___5 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___2 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___2 *);
	void (*close)(struct tty_struct___2 *);
	void (*flush_buffer)(struct tty_struct___2 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___2 *);
	ssize_t (*read)(struct tty_struct___2 *, struct file *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___2 *, struct file *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___2 *, struct file *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, struct file *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___2 *, struct file *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___2 *);
	void (*receive_buf)(struct tty_struct___2 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___2 *);
	void (*dcd_change)(struct tty_struct___2 *, unsigned int);
	struct module___2 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___2 *, int);
};

struct tty_ldisc___2 {
	struct tty_ldisc_ops___2 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___2 *tty;
};

struct tty_port_operations___2 {
	int (*carrier_raised)(struct tty_port___2 *);
	void (*dtr_rts)(struct tty_port___2 *, int);
	void (*shutdown)(struct tty_port___2 *);
	void (*drop)(struct tty_port___2 *);
	int (*activate)(struct tty_port___2 *, struct tty_struct___2 *);
	void (*destruct)(struct tty_port___2 *);
};

struct kmem_cache_cpu___2 {
	void **freelist;
	long unsigned int tid;
	struct page___2 *page;
	struct page___2 *partial;
};

struct memcg_cache_params___2 {
	bool is_root_cache;
	union {
		struct kmem_cache___2 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___2 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___2;

struct cgroup___2 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___2 *parent;
	struct dentry___3 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___2 *subsys[11];
	struct cgroupfs_root___2 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___5 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___2 {
	struct super_block___3 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___2 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___2 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___3 *, struct file *);
	ssize_t (*read)(struct cgroup___2 *, struct cftype___2 *, struct file *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___2 *, struct cftype___2 *);
	s64 (*read_s64)(struct cgroup___2 *, struct cftype___2 *);
	int (*read_map)(struct cgroup___2 *, struct cftype___2 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___2 *, struct cftype___2 *, struct seq_file___2 *);
	ssize_t (*write)(struct cgroup___2 *, struct cftype___2 *, struct file *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___2 *, struct cftype___2 *, u64);
	int (*write_s64)(struct cgroup___2 *, struct cftype___2 *, s64);
	int (*write_string)(struct cgroup___2 *, struct cftype___2 *, const char *);
	int (*trigger)(struct cgroup___2 *, unsigned int);
	int (*release)(struct inode___3 *, struct file *);
	int (*register_event)(struct cgroup___2 *, struct cftype___2 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___2 *, struct cftype___2 *, struct eventfd_ctx *);
};

struct cftype_set___2 {
	struct list_head node;
	struct cftype___2 *cfts;
};

struct task_and_cgroup___2 {
	struct task_struct___5 *task;
	struct cgroup___2 *cgrp;
	struct css_set *cg;
};

struct cgroup_taskset___2 {
	struct task_and_cgroup___2 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___2 *cur_cgrp;
};

struct cgroup_subsys___2 {
	struct cgroup_subsys_state___2 * (*css_alloc)(struct cgroup___2 *);
	int (*css_online)(struct cgroup___2 *);
	void (*css_offline)(struct cgroup___2 *);
	void (*css_free)(struct cgroup___2 *);
	int (*can_attach)(struct cgroup___2 *, struct cgroup_taskset___2 *);
	void (*cancel_attach)(struct cgroup___2 *, struct cgroup_taskset___2 *);
	void (*attach)(struct cgroup___2 *, struct cgroup_taskset___2 *);
	void (*fork)(struct task_struct___5 *);
	void (*exit)(struct cgroup___2 *, struct cgroup___2 *, struct task_struct___5 *);
	void (*bind)(struct cgroup___2 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___2 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___2 *base_cftypes;
	struct cftype_set___2 base_cftset;
	struct module___2 *module;
};

struct irq_chip___2 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___2 *);
	void (*irq_shutdown)(struct irq_data___2 *);
	void (*irq_enable)(struct irq_data___2 *);
	void (*irq_disable)(struct irq_data___2 *);
	void (*irq_ack)(struct irq_data___2 *);
	void (*irq_mask)(struct irq_data___2 *);
	void (*irq_mask_ack)(struct irq_data___2 *);
	void (*irq_unmask)(struct irq_data___2 *);
	void (*irq_eoi)(struct irq_data___2 *);
	int (*irq_set_affinity)(struct irq_data___2 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___2 *);
	int (*irq_set_type)(struct irq_data___2 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___2 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___2 *);
	void (*irq_bus_sync_unlock)(struct irq_data___2 *);
	void (*irq_cpu_online)(struct irq_data___2 *);
	void (*irq_cpu_offline)(struct irq_data___2 *);
	void (*irq_suspend)(struct irq_data___2 *);
	void (*irq_resume)(struct irq_data___2 *);
	void (*irq_pm_shutdown)(struct irq_data___2 *);
	void (*irq_print_chip)(struct irq_data___2 *, struct seq_file___2 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___2 *, void *);
	long unsigned int flags;
};

enum dma_data_direction {
	DMA_BIDIRECTIONAL = 0,
	DMA_TO_DEVICE = 1,
	DMA_FROM_DEVICE = 2,
	DMA_NONE = 3,
};

struct dma_attrs;

struct sg_table;

struct scatterlist;

struct dma_map_ops {
	void * (*alloc)(struct device___2 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___2 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___2 *, struct vm_area_struct___5 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___2 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___2 *, struct page___2 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___2 *, dma_addr_t);
	int (*dma_supported)(struct device___2 *, u64);
	int (*set_dma_mask)(struct device___2 *, u64);
	int is_phys;
};

struct bus_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___2 *, char *);
	ssize_t (*store)(struct bus_type___2 *, const char *, size_t);
};

struct device_attribute___2;

struct driver_attribute___2;

struct bus_type___2 {
	const char *name;
	const char *dev_name;
	struct device___2 *dev_root;
	struct bus_attribute___2 *bus_attrs;
	struct device_attribute___2 *dev_attrs;
	struct driver_attribute___2 *drv_attrs;
	const struct attribute_group___2 **bus_groups;
	const struct attribute_group___2 **dev_groups;
	const struct attribute_group___2 **drv_groups;
	int (*match)(struct device___2 *, struct device_driver___2 *);
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	int (*probe)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*online)(struct device___2 *);
	int (*offline)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct dev_pm_ops___2 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device___2 *, struct device_attribute___2 *, char *);
	ssize_t (*store)(struct device___2 *, struct device_attribute___2 *, const char *, size_t);
};

struct driver_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___2 *, char *);
	ssize_t (*store)(struct device_driver___2 *, const char *, size_t);
};

struct device_driver___2 {
	const char *name;
	struct bus_type___2 *bus;
	struct module___2 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct attribute_group___2 **groups;
	const struct dev_pm_ops___2 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___2 {
	const char *name;
	const struct attribute_group___2 **groups;
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___2 *);
	const struct dev_pm_ops___2 *pm;
};

struct class_attribute___2;

struct class___2 {
	const char *name;
	struct module___2 *owner;
	struct class_attribute___2 *class_attrs;
	struct device_attribute___2 *dev_attrs;
	const struct attribute_group___2 **dev_groups;
	struct bin_attribute___2 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *);
	void (*class_release)(struct class___2 *);
	void (*dev_release)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___2 *);
	const struct dev_pm_ops___2 *pm;
	struct subsys_private *p;
};

struct class_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct class___2 *, struct class_attribute___2 *, char *);
	ssize_t (*store)(struct class___2 *, struct class_attribute___2 *, const char *, size_t);
	const void * (*namespace)(struct class___2 *, const struct class_attribute___2 *);
};

struct device_rh___2 {
	struct dev_pm_info_rh___2 power;
};

struct vm_fault___2 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___2 *page;
};

enum suspend_stat_step {
	SUSPEND_FREEZE = 1,
	SUSPEND_PREPARE = 2,
	SUSPEND_SUSPEND = 3,
	SUSPEND_SUSPEND_LATE = 4,
	SUSPEND_SUSPEND_NOIRQ = 5,
	SUSPEND_RESUME_NOIRQ = 6,
	SUSPEND_RESUME_EARLY = 7,
	SUSPEND_RESUME = 8,
};

struct suspend_stats {
	int success;
	int fail;
	int failed_freeze;
	int failed_prepare;
	int failed_suspend;
	int failed_suspend_late;
	int failed_suspend_noirq;
	int failed_resume;
	int failed_resume_early;
	int failed_resume_noirq;
	int last_failed_dev;
	char failed_devs[80];
	int last_failed_errno;
	int errno[2];
	int last_failed_step;
	enum suspend_stat_step failed_steps[2];
};

enum {
	Root_NFS = 255,
	Root_RAM0 = 1048576,
	Root_RAM1 = 1048577,
	Root_FD0 = 2097152,
	Root_HDA1 = 3145729,
	Root_HDA2 = 3145730,
	Root_SDA1 = 8388609,
	Root_SDA2 = 8388610,
	Root_HDC1 = 23068673,
	Root_SR0 = 11534336,
};

struct skb_mstamp {
	union {
		u64 v64;
		struct {
			u32 stamp_us;
			u32 stamp_jiffies;
		};
	};
};

typedef s32 dma_cookie_t;

typedef unsigned int sk_buff_data_t;

struct net_device;

struct sec_path;

struct nf_conntrack;

struct nf_bridge_info;

struct sk_buff {
	struct sk_buff *next;
	struct sk_buff *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

typedef enum {
	SS_FREE = 0,
	SS_UNCONNECTED = 1,
	SS_CONNECTING = 2,
	SS_CONNECTED = 3,
	SS_DISCONNECTING = 4,
} socket_state;

struct proto_ops;

struct socket {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq *wq;
	struct file *file;
	struct sock *sk;
	const struct proto_ops *ops;
};

struct request_sock_ops;

struct request_sock {
	struct sock_common __req_common;
	struct request_sock *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops *rsk_ops;
	struct sock *sk;
	u32 secid;
	u32 peer_secid;
};

struct flowi_common {
	int flowic_oif;
	int flowic_iif;
	__u32 flowic_mark;
	__u8 flowic_tos;
	__u8 flowic_scope;
	__u8 flowic_proto;
	__u8 flowic_flags;
	__u32 flowic_secid;
};

union flowi_uli {
	struct {
		__be16 dport;
		__be16 sport;
	} ports;
	struct {
		__u8 type;
		__u8 code;
	} icmpt;
	struct {
		__le16 dport;
		__le16 sport;
	} dnports;
	__be32 spi;
	__be32 gre_key;
	struct {
		__u8 type;
	} mht;
};

struct flowi4 {
	struct flowi_common __fl_common;
	__be32 saddr;
	__be32 daddr;
	union flowi_uli uli;
};

struct flowi6 {
	struct flowi_common __fl_common;
	struct in6_addr daddr;
	struct in6_addr saddr;
	__be32 flowlabel;
	union flowi_uli uli;
	int: 32;
};

struct flowidn {
	struct flowi_common __fl_common;
	__le16 daddr;
	__le16 saddr;
	union flowi_uli uli;
	int: 32;
};

struct flowi {
	union {
		struct flowi_common __fl_common;
		struct flowi4 ip4;
		struct flowi6 ip6;
		struct flowidn dn;
	} u;
};

struct disk_part_tbl___2 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___2 *last_lookup;
	struct hd_struct___2 *part[0];
};

struct block_device_operations___2 {
	int (*open)(struct block_device___2 *, fmode_t);
	void (*release)(struct gendisk___2 *, fmode_t);
	int (*ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___2 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___2 *, unsigned int);
	int (*media_changed)(struct gendisk___2 *);
	void (*unlock_native_capacity)(struct gendisk___2 *);
	int (*revalidate_disk)(struct gendisk___2 *);
	int (*getgeo)(struct block_device___2 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___2 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___2 *owner;
};

struct scatterlist {
	long unsigned int page_link;
	unsigned int offset;
	unsigned int length;
	dma_addr_t dma_address;
	unsigned int dma_length;
};

struct sg_table {
	struct scatterlist *sgl;
	unsigned int nents;
	unsigned int orig_nents;
};

struct prot_inuse;

struct netns_core {
	struct ctl_table_header *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct tcp_mib;

struct ipstats_mib;

struct linux_mib;

struct udp_mib;

struct icmp_mib;

struct icmpmsg_mib;

struct icmpv6_mib;

struct icmpv6msg_mib;

struct linux_xfrm_mib;

struct netns_mib {
	struct tcp_mib *tcp_statistics[1];
	struct ipstats_mib *ip_statistics[1];
	struct linux_mib *net_statistics[1];
	struct udp_mib *udp_statistics[1];
	struct udp_mib *udplite_statistics[1];
	struct icmp_mib *icmp_statistics[1];
	struct icmpmsg_mib *icmpmsg_statistics;
	struct proc_dir_entry *proc_net_devsnmp6;
	struct udp_mib *udp_stats_in6[1];
	struct udp_mib *udplite_stats_in6[1];
	struct ipstats_mib *ipv6_statistics[1];
	struct icmpv6_mib *icmpv6_statistics[1];
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct linux_xfrm_mib *xfrm_statistics[1];
};

struct netns_packet {
	struct mutex___5 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header *ctl;
};

struct netns_frags {
	int nqueues;
	struct list_head lru_list;
	spinlock_t lru_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct percpu_counter mem;
	int timeout;
	int high_thresh;
	int low_thresh;
	long: 32;
	long: 64;
};

struct ipv4_devconf;

struct fib_rules_ops;

struct fib_table;

struct inet_peer_base;

struct tcpm_hash_bucket;

struct xt_table;

struct netns_ipv4 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6 {
	struct ctl_table_header *hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *icmp_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour;

struct dst_ops {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff *, u32);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff *);
	int (*local_out)(struct sk_buff *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff *, const void *);
	struct kmem_cache___2 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct ipv6_devconf;

struct rt6_info;

struct rt6_statistics;

struct fib6_table;

struct netns_ipv6 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct sctp_mib;

struct netns_sctp {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp {
	struct sock *v4_ctl_sk;
	struct sock *v6_ctl_sk;
};

struct nf_logger;

struct netns_nf {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
};

struct ebt_table;

struct netns_xt {
	struct list_head tables[13];
	bool notrack_deprecated_warning;
	struct ebt_table *broute_table;
	struct ebt_table *frame_filter;
	struct ebt_table *frame_nat;
};

struct hlist_nulls_head {
	struct hlist_nulls_node *first;
};

struct nf_ct_event_notifier;

struct nf_exp_event_notifier;

struct nf_proto_net {
	struct ctl_table_header *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net {
	struct nf_proto_net pn;
	unsigned int timeout;
};

struct nf_tcp_net {
	struct nf_proto_net pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net {
	struct nf_proto_net pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net {
	struct nf_proto_net pn;
	unsigned int timeout;
};

struct nf_ip_net {
	struct nf_generic_net generic;
	struct nf_tcp_net tcp;
	struct nf_udp_net udp;
	struct nf_icmp_net icmp;
	struct nf_icmp_net icmpv6;
};

struct ct_pcpu;

struct ip_conntrack_stat;

struct netns_ct {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header *sysctl_header;
	struct ctl_table_header *acct_sysctl_header;
	struct ctl_table_header *tstamp_sysctl_header;
	struct ctl_table_header *event_sysctl_header;
	struct ctl_table_header *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___2 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct nft_af_info;

struct netns_nftables {
	struct list_head af_info;
	struct list_head commit_list;
	struct nft_af_info *ipv4;
	struct nft_af_info *ipv6;
	struct nft_af_info *inet;
	struct nft_af_info *arp;
	struct nft_af_info *bridge;
	u8 gencursor;
	u8 genctr;
	unsigned int base_seq;
	unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct netns_nf_frag {
	struct netns_sysctl_ipv6 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct xfrm_policy_hash {
	struct hlist_head *table;
	unsigned int hmask;
};

struct netns_xfrm {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops xfrm4_dst_ops;
	struct dst_ops xfrm6_dst_ops;
};

struct local_ports {
	seqlock_t lock;
	int range[2];
};

struct flow_cache_percpu;

struct flow_cache {
	u32 hash_shift;
	struct flow_cache_percpu *percpu;
	struct notifier_block hotcpu_notifier;
	int low_watermark;
	int high_watermark;
	struct timer_list rnd_timer;
};

struct net_generic;

struct netns_ipvs;

struct net {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4 ipv4;
	struct netns_ipv6 ipv6;
	struct netns_sctp sctp;
	struct netns_dccp dccp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___5 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___5 flow_flush_sem;
	long: 64;
	long: 64;
};

struct ipv6_devconf {
	__s32 forwarding;
	__s32 hop_limit;
	__s32 mtu6;
	__s32 accept_ra;
	__s32 accept_redirects;
	__s32 autoconf;
	__s32 dad_transmits;
	__s32 rtr_solicits;
	__s32 rtr_solicit_interval;
	__s32 rtr_solicit_delay;
	__s32 force_mld_version;
	__s32 mldv1_unsolicited_report_interval;
	__s32 mldv2_unsolicited_report_interval;
	__s32 use_tempaddr;
	__s32 temp_valid_lft;
	__s32 temp_prefered_lft;
	__s32 regen_max_retry;
	__s32 max_desync_factor;
	__s32 max_addresses;
	__s32 accept_ra_defrtr;
	__s32 accept_ra_pinfo;
	__s32 accept_ra_rtr_pref;
	__s32 rtr_probe_interval;
	__s32 accept_ra_rt_info_max_plen;
	__s32 proxy_ndp;
	__s32 accept_source_route;
	__s32 optimistic_dad;
	__s32 mc_forwarding;
	__s32 disable_ipv6;
	__s32 accept_dad;
	__s32 force_tllao;
	__s32 ndisc_notify;
	void *sysctl;
};

struct socket_wq {
	wait_queue_head_t wait;
	struct fasync_struct___2 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops {
	int family;
	struct module___2 *owner;
	int (*release)(struct socket *);
	int (*bind)(struct socket *, struct sockaddr *, int);
	int (*connect)(struct socket *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket *, struct socket *);
	int (*accept)(struct socket *, struct socket *, int);
	int (*getname)(struct socket *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file *, struct socket *, struct poll_table_struct___2 *);
	int (*ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*listen)(struct socket *, int);
	int (*shutdown)(struct socket *, int);
	int (*setsockopt)(struct socket *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb *, struct socket *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb *, struct socket *, struct msghdr *, size_t, int);
	int (*mmap)(struct file *, struct socket *, struct vm_area_struct___5 *);
	ssize_t (*sendpage)(struct socket *, struct page___2 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock *, int);
		struct {
			void (*set_peek_off)(struct sock *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct dma_attrs {
	long unsigned int flags[1];
};

struct nf_conntrack {
	atomic_t use;
};

struct nf_bridge_info {
	atomic_t use;
	unsigned int mask;
	struct net_device *physindev;
	struct net_device *physoutdev;
	long unsigned int data[4];
};

struct net_device_stats {
	long unsigned int rx_packets;
	long unsigned int tx_packets;
	long unsigned int rx_bytes;
	long unsigned int tx_bytes;
	long unsigned int rx_errors;
	long unsigned int tx_errors;
	long unsigned int rx_dropped;
	long unsigned int tx_dropped;
	long unsigned int multicast;
	long unsigned int collisions;
	long unsigned int rx_length_errors;
	long unsigned int rx_over_errors;
	long unsigned int rx_crc_errors;
	long unsigned int rx_frame_errors;
	long unsigned int rx_fifo_errors;
	long unsigned int rx_missed_errors;
	long unsigned int tx_aborted_errors;
	long unsigned int tx_carrier_errors;
	long unsigned int tx_fifo_errors;
	long unsigned int tx_heartbeat_errors;
	long unsigned int tx_window_errors;
	long unsigned int rx_compressed;
	long unsigned int tx_compressed;
};

struct netdev_hw_addr_list {
	struct list_head list;
	int count;
};

struct vlan_info;

struct dn_dev;

enum rx_handler_result {
	RX_HANDLER_CONSUMED = 0,
	RX_HANDLER_ANOTHER = 1,
	RX_HANDLER_EXACT = 2,
	RX_HANDLER_PASS = 3,
};

typedef enum rx_handler_result rx_handler_result_t;

typedef rx_handler_result_t rx_handler_func_t(struct sk_buff **);

struct cpu_rmap;

struct pcpu_tstats;

struct pcpu_dstats;

struct pcpu_vstats;

struct garp_port;

struct mrp_port;

struct netdev_tc_txq {
	u16 count;
	u16 offset;
};

struct pm_qos_request {
	struct plist_node node;
	int pm_qos_class;
	struct delayed_work work;
};

struct iw_handler_def;

struct iw_public_data;

struct net_device_ops;

struct ethtool_ops;

struct header_ops;

struct in_device;

struct inet6_dev;

struct wireless_dev;

struct netdev_rx_queue;

struct netdev_queue;

struct Qdisc;

struct xps_dev_maps;

struct netpoll_info;

struct pcpu_lstats;

struct pcpu_sw_netstats;

struct rtnl_link_ops;

struct dcbnl_rtnl_ops;

struct netprio_map;

struct phy_device;

struct net_device {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops *netdev_ops;
	const struct ethtool_ops *ethtool_ops;
	const struct header_ops *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t *rx_handler;
	void *rx_handler_data;
	struct netdev_queue *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED = 0,
		NETREG_REGISTERED = 1,
		NETREG_UNREGISTERING = 2,
		NETREG_UNREGISTERED = 3,
		NETREG_RELEASED = 4,
		NETREG_DUMMY = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED = 0,
		RTNL_LINK_INITIALIZING = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device *);
	struct netpoll_info *npinfo;
	struct net *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___2 dev;
	const struct attribute_group___2 *sysfs_groups[4];
	const struct rtnl_link_ops *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pm_qos_flags_request {
	struct list_head node;
	s32 flags;
};

enum dev_pm_qos_req_type {
	DEV_PM_QOS_LATENCY = 1,
	DEV_PM_QOS_FLAGS = 2,
	DEV_PM_QOS_LATENCY_TOLERANCE = 3,
};

struct dev_pm_qos_request {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___2 *dev;
};

struct dql {
	unsigned int num_queued;
	unsigned int adj_limit;
	unsigned int last_obj_cnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int limit;
	unsigned int num_completed;
	unsigned int prev_ovlimit;
	unsigned int prev_num_queued;
	unsigned int prev_last_obj_cnt;
	unsigned int lowest_slack;
	long unsigned int slack_start_time;
	unsigned int max_limit;
	unsigned int min_limit;
	unsigned int slack_hold_time;
	long: 32;
	long: 64;
	long: 64;
};

struct ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_proto;
};

struct ethtool_cmd {
	__u32 cmd;
	__u32 supported;
	__u32 advertising;
	__u16 speed;
	__u8 duplex;
	__u8 port;
	__u8 phy_address;
	__u8 transceiver;
	__u8 autoneg;
	__u8 mdio_support;
	__u32 maxtxpkt;
	__u32 maxrxpkt;
	__u16 speed_hi;
	__u8 eth_tp_mdix;
	__u8 eth_tp_mdix_ctrl;
	__u32 lp_advertising;
	__u32 reserved[2];
};

struct ethtool_drvinfo {
	__u32 cmd;
	char driver[32];
	char version[32];
	char fw_version[32];
	char bus_info[32];
	char reserved1[32];
	char reserved2[12];
	__u32 n_priv_flags;
	__u32 n_stats;
	__u32 testinfo_len;
	__u32 eedump_len;
	__u32 regdump_len;
};

struct ethtool_wolinfo {
	__u32 cmd;
	__u32 supported;
	__u32 wolopts;
	__u8 sopass[6];
};

struct ethtool_regs {
	__u32 cmd;
	__u32 version;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eeprom {
	__u32 cmd;
	__u32 magic;
	__u32 offset;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eee {
	__u32 cmd;
	__u32 supported;
	__u32 advertised;
	__u32 lp_advertised;
	__u32 eee_active;
	__u32 eee_enabled;
	__u32 tx_lpi_enabled;
	__u32 tx_lpi_timer;
	__u32 reserved[2];
};

struct ethtool_modinfo {
	__u32 cmd;
	__u32 type;
	__u32 eeprom_len;
	__u32 reserved[8];
};

struct ethtool_coalesce {
	__u32 cmd;
	__u32 rx_coalesce_usecs;
	__u32 rx_max_coalesced_frames;
	__u32 rx_coalesce_usecs_irq;
	__u32 rx_max_coalesced_frames_irq;
	__u32 tx_coalesce_usecs;
	__u32 tx_max_coalesced_frames;
	__u32 tx_coalesce_usecs_irq;
	__u32 tx_max_coalesced_frames_irq;
	__u32 stats_block_coalesce_usecs;
	__u32 use_adaptive_rx_coalesce;
	__u32 use_adaptive_tx_coalesce;
	__u32 pkt_rate_low;
	__u32 rx_coalesce_usecs_low;
	__u32 rx_max_coalesced_frames_low;
	__u32 tx_coalesce_usecs_low;
	__u32 tx_max_coalesced_frames_low;
	__u32 pkt_rate_high;
	__u32 rx_coalesce_usecs_high;
	__u32 rx_max_coalesced_frames_high;
	__u32 tx_coalesce_usecs_high;
	__u32 tx_max_coalesced_frames_high;
	__u32 rate_sample_interval;
};

struct ethtool_ringparam {
	__u32 cmd;
	__u32 rx_max_pending;
	__u32 rx_mini_max_pending;
	__u32 rx_jumbo_max_pending;
	__u32 tx_max_pending;
	__u32 rx_pending;
	__u32 rx_mini_pending;
	__u32 rx_jumbo_pending;
	__u32 tx_pending;
};

struct ethtool_channels {
	__u32 cmd;
	__u32 max_rx;
	__u32 max_tx;
	__u32 max_other;
	__u32 max_combined;
	__u32 rx_count;
	__u32 tx_count;
	__u32 other_count;
	__u32 combined_count;
};

struct ethtool_pauseparam {
	__u32 cmd;
	__u32 autoneg;
	__u32 rx_pause;
	__u32 tx_pause;
};

struct ethtool_test {
	__u32 cmd;
	__u32 flags;
	__u32 reserved;
	__u32 len;
	__u64 data[0];
};

struct ethtool_stats {
	__u32 cmd;
	__u32 n_stats;
	__u64 data[0];
};

struct ethtool_tcpip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be16 psrc;
	__be16 pdst;
	__u8 tos;
};

struct ethtool_ah_espip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 spi;
	__u8 tos;
};

struct ethtool_usrip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 l4_4_bytes;
	__u8 tos;
	__u8 ip_ver;
	__u8 proto;
};

union ethtool_flow_union {
	struct ethtool_tcpip4_spec tcp_ip4_spec;
	struct ethtool_tcpip4_spec udp_ip4_spec;
	struct ethtool_tcpip4_spec sctp_ip4_spec;
	struct ethtool_ah_espip4_spec ah_ip4_spec;
	struct ethtool_ah_espip4_spec esp_ip4_spec;
	struct ethtool_usrip4_spec usr_ip4_spec;
	struct ethhdr ether_spec;
	__u8 hdata[52];
};

struct ethtool_flow_ext {
	__u8 padding[2];
	unsigned char h_dest[6];
	__be16 vlan_etype;
	__be16 vlan_tci;
	__be32 data[2];
};

struct ethtool_rx_flow_spec {
	__u32 flow_type;
	union ethtool_flow_union h_u;
	struct ethtool_flow_ext h_ext;
	union ethtool_flow_union m_u;
	struct ethtool_flow_ext m_ext;
	__u64 ring_cookie;
	__u32 location;
};

struct ethtool_rxnfc {
	__u32 cmd;
	__u32 flow_type;
	__u64 data;
	struct ethtool_rx_flow_spec fs;
	__u32 rule_cnt;
	__u32 rule_locs[0];
};

struct ethtool_flash {
	__u32 cmd;
	__u32 region;
	char data[128];
};

struct ethtool_dump {
	__u32 cmd;
	__u32 version;
	__u32 flag;
	__u32 len;
	__u8 data[0];
};

struct ethtool_ts_info {
	__u32 cmd;
	__u32 so_timestamping;
	__s32 phc_index;
	__u32 tx_types;
	__u32 tx_reserved[3];
	__u32 rx_filters;
	__u32 rx_reserved[3];
};

enum ethtool_phys_id_state {
	ETHTOOL_ID_INACTIVE = 0,
	ETHTOOL_ID_ACTIVE = 1,
	ETHTOOL_ID_ON = 2,
	ETHTOOL_ID_OFF = 3,
};

struct ethtool_ops {
	int (*get_settings)(struct net_device *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device *);
	void (*get_regs)(struct net_device *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device *);
	void (*set_msglevel)(struct net_device *, u32);
	int (*nway_reset)(struct net_device *);
	u32 (*get_link)(struct net_device *);
	int (*get_eeprom_len)(struct net_device *);
	int (*get_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device *, u32, u8 *);
	int (*set_phys_id)(struct net_device *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device *);
	void (*complete)(struct net_device *);
	u32 (*get_priv_flags)(struct net_device *);
	int (*set_priv_flags)(struct net_device *, u32);
	int (*get_sset_count)(struct net_device *, int);
	int (*get_rxnfc)(struct net_device *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device *, struct ethtool_flash *);
	int (*reset)(struct net_device *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device *);
	int (*get_rxfh_indir)(struct net_device *, u32 *);
	int (*set_rxfh_indir)(struct net_device *, const u32 *);
	void (*get_channels)(struct net_device *, struct ethtool_channels *);
	int (*set_channels)(struct net_device *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device *, struct ethtool_eee *);
	int (*set_eee)(struct net_device *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct u64_stats_sync {};

struct ipstats_mib {
	u64 mibs[36];
	struct u64_stats_sync syncp;
};

struct icmp_mib {
	long unsigned int mibs[28];
};

struct icmpmsg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6_mib {
	long unsigned int mibs[6];
};

struct icmpv6_mib_device {
	atomic_long_t mibs[6];
};

struct icmpv6msg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6msg_mib_device {
	atomic_long_t mibs[512];
};

struct tcp_mib {
	long unsigned int mibs[16];
};

struct udp_mib {
	long unsigned int mibs[8];
};

struct linux_mib {
	long unsigned int mibs[113];
};

struct linux_xfrm_mib {
	long unsigned int mibs[28];
};

struct dn_route;

struct xfrm_state;

struct rtable;

struct dst_entry {
	struct callback_head callback_head;
	struct dst_entry *child;
	struct net_device *dev;
	struct dst_ops *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry *path;
	struct dst_entry *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff *);
	union {
		int (*output)(struct sock *, struct sk_buff *);
		struct {
			int (*output)(struct sk_buff *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct hh_cache {
	u16 hh_len;
	u16 __pad;
	seqlock_t hh_lock;
	long unsigned int hh_data[12];
};

struct neigh_table;

struct neigh_parms;

struct neigh_ops;

struct neighbour {
	struct neighbour *next;
	struct neigh_table *tbl;
	struct neigh_parms *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour *, struct sk_buff *);
	const struct neigh_ops *ops;
	struct callback_head rcu;
	struct net_device *dev;
	u8 primary_key[0];
};

enum {
	NFPROTO_UNSPEC = 0,
	NFPROTO_INET = 1,
	NFPROTO_IPV4 = 2,
	NFPROTO_ARP = 3,
	NFPROTO_BRIDGE = 7,
	NFPROTO_IPV6 = 10,
	NFPROTO_DECNET = 12,
	NFPROTO_NUMPROTO = 13,
};

struct nf_queue_entry;

struct nf_afinfo {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net *, struct dst_entry **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff *, const struct nf_queue_entry *);
	int route_key_size;
};

struct net_device___2;

struct sock___2;

struct sk_buff___2;

struct nf_hook_state {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___2 *in;
	struct net_device___2 *out;
	struct sock___2 *sk;
	int (*okfn)(struct sock___2 *, struct sk_buff___2 *);
};

struct nf_hook_ops;

struct nf_queue_entry {
	struct list_head list;
	struct sk_buff___2 *skb;
	unsigned int id;
	struct nf_hook_ops *elem;
	struct nf_hook_state state;
	u16 size;
};

struct nlattr {
	__u16 nla_len;
	__u16 nla_type;
};

enum nf_log_type {
	NF_LOG_TYPE_LOG = 0,
	NF_LOG_TYPE_ULOG = 1,
	NF_LOG_TYPE_MAX = 2,
};

struct net___2;

struct nf_loginfo;

typedef void nf_logfn(struct net___2 *, u_int8_t, unsigned int, const struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *, const struct nf_loginfo *, const char *);

struct module___3;

struct nf_logger {
	char *name;
	enum nf_log_type type;
	nf_logfn *logfn;
	struct module___3 *me;
};

enum tcp_conntrack {
	TCP_CONNTRACK_NONE = 0,
	TCP_CONNTRACK_SYN_SENT = 1,
	TCP_CONNTRACK_SYN_RECV = 2,
	TCP_CONNTRACK_ESTABLISHED = 3,
	TCP_CONNTRACK_FIN_WAIT = 4,
	TCP_CONNTRACK_CLOSE_WAIT = 5,
	TCP_CONNTRACK_LAST_ACK = 6,
	TCP_CONNTRACK_TIME_WAIT = 7,
	TCP_CONNTRACK_CLOSE = 8,
	TCP_CONNTRACK_LISTEN = 9,
	TCP_CONNTRACK_MAX = 10,
	TCP_CONNTRACK_IGNORE = 11,
	TCP_CONNTRACK_RETRANS = 12,
	TCP_CONNTRACK_UNACK = 13,
	TCP_CONNTRACK_TIMEOUT_MAX = 14,
};

enum udp_conntrack {
	UDP_CT_UNREPLIED = 0,
	UDP_CT_REPLIED = 1,
	UDP_CT_MAX = 2,
};

struct ct_pcpu {
	spinlock_t lock;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
};

enum {
	XFRM_POLICY_IN = 0,
	XFRM_POLICY_OUT = 1,
	XFRM_POLICY_FWD = 2,
	XFRM_POLICY_MASK = 3,
	XFRM_POLICY_MAX = 3,
};

struct tasklet_struct {
	struct tasklet_struct *next;
	long unsigned int state;
	atomic_t count;
	void (*func)(long unsigned int);
	long unsigned int data;
};

struct flow_cache_percpu {
	struct hlist_head *hash_table;
	int hash_count;
	u32 hash_rnd;
	int hash_rnd_recalc;
	struct tasklet_struct flush_tasklet;
};

struct seq_operations___2 {
	void * (*start)(struct seq_file___2 *, loff_t *);
	void (*stop)(struct seq_file___2 *, void *);
	void * (*next)(struct seq_file___2 *, void *, loff_t *);
	int (*show)(struct seq_file___2 *, void *);
};

struct ieee_ets {
	__u8 willing;
	__u8 ets_cap;
	__u8 cbs;
	__u8 tc_tx_bw[8];
	__u8 tc_rx_bw[8];
	__u8 tc_tsa[8];
	__u8 prio_tc[8];
	__u8 tc_reco_bw[8];
	__u8 tc_reco_tsa[8];
	__u8 reco_prio_tc[8];
};

struct ieee_maxrate {
	__u64 tc_maxrate[8];
};

struct ieee_pfc {
	__u8 pfc_cap;
	__u8 pfc_en;
	__u8 mbc;
	__u16 delay;
	__u64 requests[8];
	__u64 indications[8];
};

struct cee_pg {
	__u8 willing;
	__u8 error;
	__u8 pg_en;
	__u8 tcs_supported;
	__u8 pg_bw[8];
	__u8 prio_pg[8];
};

struct cee_pfc {
	__u8 willing;
	__u8 error;
	__u8 pfc_en;
	__u8 tcs_supported;
};

struct dcb_app {
	__u8 selector;
	__u8 priority;
	__u16 protocol;
};

struct dcb_peer_app_info {
	__u8 willing;
	__u8 error;
};

struct dcbnl_rtnl_ops {
	int (*ieee_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device *);
	u8 (*setstate)(struct net_device *, u8);
	void (*getpermhwaddr)(struct net_device *, u8 *);
	void (*setpgtccfgtx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device *, int, u8);
	void (*setpgtccfgrx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device *, int, u8);
	void (*getpgtccfgtx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device *, int, u8 *);
	void (*setpfccfg)(struct net_device *, int, u8);
	void (*getpfccfg)(struct net_device *, int, u8 *);
	u8 (*setall)(struct net_device *);
	u8 (*getcap)(struct net_device *, int, u8 *);
	int (*getnumtcs)(struct net_device *, int, u8 *);
	int (*setnumtcs)(struct net_device *, int, u8);
	u8 (*getpfcstate)(struct net_device *);
	void (*setpfcstate)(struct net_device *, u8);
	void (*getbcncfg)(struct net_device *, int, u32 *);
	void (*setbcncfg)(struct net_device *, int, u32);
	void (*getbcnrp)(struct net_device *, int, u8 *);
	void (*setbcnrp)(struct net_device *, int, u8);
	u8 (*setapp)(struct net_device *, u8, u16, u8);
	u8 (*getapp)(struct net_device *, u8, u16);
	u8 (*getfeatcfg)(struct net_device *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device *, int, u8);
	u8 (*getdcbx)(struct net_device *);
	u8 (*setdcbx)(struct net_device *, u8);
	int (*peer_getappinfo)(struct net_device *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device *, struct cee_pfc *);
};

struct netprio_map {
	struct callback_head rcu;
	u32 priomap_len;
	u32 priomap[0];
};

struct nlmsghdr {
	__u32 nlmsg_len;
	__u16 nlmsg_type;
	__u16 nlmsg_flags;
	__u32 nlmsg_seq;
	__u32 nlmsg_pid;
};

struct netlink_callback {
	struct sk_buff *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff *, struct netlink_callback *);
	int (*done)(struct netlink_callback *);
	void *data;
	struct module___2 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct ndmsg {
	__u8 ndm_family;
	__u8 ndm_pad1;
	__u16 ndm_pad2;
	__s32 ndm_ifindex;
	__u16 ndm_state;
	__u8 ndm_flags;
	__u8 ndm_type;
};

struct rtnl_link_stats64 {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 rx_errors;
	__u64 tx_errors;
	__u64 rx_dropped;
	__u64 tx_dropped;
	__u64 multicast;
	__u64 collisions;
	__u64 rx_length_errors;
	__u64 rx_over_errors;
	__u64 rx_crc_errors;
	__u64 rx_frame_errors;
	__u64 rx_fifo_errors;
	__u64 rx_missed_errors;
	__u64 tx_aborted_errors;
	__u64 tx_carrier_errors;
	__u64 tx_fifo_errors;
	__u64 tx_heartbeat_errors;
	__u64 tx_window_errors;
	__u64 rx_compressed;
	__u64 tx_compressed;
};

struct ifla_vf_stats {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 broadcast;
	__u64 multicast;
};

struct ifla_vf_info {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	union {
		__u32 max_tx_rate;
		struct {
			__u32 tx_rate;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 rss_query_en;
};

enum netdev_tx {
	__NETDEV_TX_MIN = 2147483648,
	NETDEV_TX_OK = 0,
	NETDEV_TX_BUSY = 16,
	NETDEV_TX_LOCKED = 32,
};

typedef enum netdev_tx netdev_tx_t;

struct header_ops {
	int (*create)(struct sk_buff *, struct net_device *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff *, unsigned char *);
	int (*rebuild)(struct sk_buff *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device *, const unsigned char *);
};

struct napi_struct {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device *dev;
	struct sk_buff *gro_list;
	struct sk_buff *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue {
	struct net_device *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct rps_map {
	unsigned int len;
	struct callback_head rcu;
	u16 cpus[0];
};

struct rps_dev_flow {
	u16 cpu;
	u16 filter;
	unsigned int last_qtail;
};

struct rps_dev_flow_table {
	unsigned int mask;
	struct callback_head rcu;
	struct rps_dev_flow flows[0];
};

struct rps_sock_flow_table {
	unsigned int mask;
	u16 ents[0];
};

struct netdev_rx_queue {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject kobj;
	struct net_device *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xps_map {
	unsigned int len;
	unsigned int alloc_len;
	struct callback_head rcu;
	u16 queues[0];
};

struct xps_dev_maps {
	struct callback_head rcu;
	struct xps_map *cpu_map[0];
};

struct netdev_fcoe_hbainfo {
	char manufacturer[64];
	char serial_number[64];
	char hardware_version[64];
	char driver_version[64];
	char optionrom_version[64];
	char firmware_version[64];
	char model[256];
	char model_description[256];
};

struct netdev_phys_port_id {
	unsigned char id[32];
	unsigned char id_len;
};

struct net_device_ops {
	int (*ndo_init)(struct net_device *);
	void (*ndo_uninit)(struct net_device *);
	int (*ndo_open)(struct net_device *);
	int (*ndo_stop)(struct net_device *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff *, struct net_device *);
	u16 (*ndo_select_queue)(struct net_device *, struct sk_buff *);
	void (*ndo_change_rx_flags)(struct net_device *, int);
	void (*ndo_set_rx_mode)(struct net_device *);
	int (*ndo_set_mac_address)(struct net_device *, void *);
	int (*ndo_validate_addr)(struct net_device *);
	int (*ndo_do_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device *, int);
	int (*ndo_neigh_setup)(struct net_device *, struct neigh_parms *);
	void (*ndo_tx_timeout)(struct net_device *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device *);
	int (*ndo_vlan_rx_add_vid)(struct net_device *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device *);
	int (*ndo_netpoll_setup)(struct net_device *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device *);
	int (*ndo_busy_poll)(struct napi_struct *);
	int (*ndo_set_vf_mac)(struct net_device *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device *, int, bool);
	int (*ndo_get_vf_config)(struct net_device *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device *, int, int);
	int (*ndo_set_vf_port)(struct net_device *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device *, int, struct sk_buff *);
	int (*ndo_setup_tc)(struct net_device *, u8);
	int (*ndo_fcoe_enable)(struct net_device *);
	int (*ndo_fcoe_disable)(struct net_device *);
	int (*ndo_fcoe_ddp_setup)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device *, const struct sk_buff *, u16, u32);
	int (*ndo_add_slave)(struct net_device *, struct net_device *);
	int (*ndo_del_slave)(struct net_device *, struct net_device *);
	netdev_features_t (*ndo_fix_features)(struct net_device *, netdev_features_t);
	int (*ndo_set_features)(struct net_device *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour *);
	void (*ndo_neigh_destroy)(struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff *, struct netlink_callback *, struct net_device *, int);
	int (*ndo_bridge_setlink)(struct net_device *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff *, u32, u32, struct net_device *, u32);
	int (*ndo_bridge_dellink)(struct net_device *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device *, bool);
	int (*ndo_get_phys_port_id)(struct net_device *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff *, struct net_device *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms {
	struct net *net;
	struct net_device *dev;
	struct neigh_parms *next;
	int (*neigh_setup)(struct neighbour *);
	void (*neigh_cleanup)(struct neighbour *);
	struct neigh_table *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct pcpu_sw_netstats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
};

struct net_device___3;

struct iw_request_info;

union iwreq_data;

typedef int (*iw_handler)(struct net_device___3 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_priv_args;

struct iw_statistics;

struct iw_handler_def {
	const iw_handler *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___3 *);
};

struct ipv6_devstat {
	struct proc_dir_entry *proc_dir_entry;
	struct ipstats_mib *ipv6[1];
	struct icmpv6_mib_device *icmpv6dev;
	struct icmpv6msg_mib_device *icmpv6msgdev;
};

struct ifmcaddr6;

struct ifacaddr6;

struct inet6_dev {
	struct net_device *dev;
	struct list_head addr_list;
	struct ifmcaddr6 *mc_list;
	struct ifmcaddr6 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms *nd_parms;
	struct inet6_dev *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct nla_policy;

struct rtnl_link_ops {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net *, struct net_device *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device *, struct list_head *);
	size_t (*get_size)(const struct net_device *);
	int (*fill_info)(struct sk_buff *, const struct net_device *);
	size_t (*get_xstats_size)(const struct net_device *);
	int (*fill_xstats)(struct sk_buff *, const struct net_device *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net * (*get_link_net)(const struct net_device *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device *, struct net_device *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device *, const struct net_device *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff *, const struct net_device *, const struct net_device *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct res_counter {
	long long unsigned int usage;
	long long unsigned int max_usage;
	long long unsigned int limit;
	long long unsigned int soft_limit;
	long long unsigned int failcnt;
	spinlock_t lock;
	struct res_counter *parent;
};

struct sock_filter {
	__u16 code;
	__u8 jt;
	__u8 jf;
	__u32 k;
};

struct sk_filter {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct nla_policy {
	u16 type;
	u16 len;
};

enum {
	NEIGH_VAR_MCAST_PROBES = 0,
	NEIGH_VAR_UCAST_PROBES = 1,
	NEIGH_VAR_APP_PROBES = 2,
	NEIGH_VAR_RETRANS_TIME = 3,
	NEIGH_VAR_BASE_REACHABLE_TIME = 4,
	NEIGH_VAR_DELAY_PROBE_TIME = 5,
	NEIGH_VAR_GC_STALETIME = 6,
	NEIGH_VAR_QUEUE_LEN_BYTES = 7,
	NEIGH_VAR_PROXY_QLEN = 8,
	NEIGH_VAR_ANYCAST_DELAY = 9,
	NEIGH_VAR_PROXY_DELAY = 10,
	NEIGH_VAR_LOCKTIME = 11,
	NEIGH_VAR_QUEUE_LEN = 12,
	NEIGH_VAR_RETRANS_TIME_MS = 13,
	NEIGH_VAR_BASE_REACHABLE_TIME_MS = 14,
	NEIGH_VAR_GC_INTERVAL = 15,
	NEIGH_VAR_GC_THRESH1 = 16,
	NEIGH_VAR_GC_THRESH2 = 17,
	NEIGH_VAR_GC_THRESH3 = 18,
	NEIGH_VAR_MAX = 19,
};

struct pneigh_entry;

struct neigh_statistics;

struct neigh_hash_table;

struct neigh_table {
	struct neigh_table *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device *, __u32 *);
	int (*constructor)(struct neighbour *);
	int (*pconstructor)(struct pneigh_entry *);
	void (*pdestructor)(struct pneigh_entry *);
	void (*proxy_redo)(struct sk_buff *);
	char *id;
	struct neigh_parms parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table *nht;
	struct pneigh_entry **phash_buckets;
};

struct neigh_statistics {
	long unsigned int allocs;
	long unsigned int destroys;
	long unsigned int hash_grows;
	long unsigned int res_failed;
	long unsigned int lookups;
	long unsigned int hits;
	long unsigned int rcv_probes_mcast;
	long unsigned int rcv_probes_ucast;
	long unsigned int periodic_gc_runs;
	long unsigned int forced_gc_runs;
	long unsigned int unres_discards;
	long unsigned int table_fulls;
};

struct neigh_ops {
	int family;
	void (*solicit)(struct neighbour *, struct sk_buff *);
	void (*error_report)(struct neighbour *, struct sk_buff *);
	int (*output)(struct neighbour *, struct sk_buff *);
	int (*connected_output)(struct neighbour *, struct sk_buff *);
};

struct pneigh_entry {
	struct pneigh_entry *next;
	struct net *net;
	struct net_device *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table {
	struct neighbour **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops;

struct inet_hashinfo;

struct udp_table;

struct raw_hashinfo;

struct proto {
	void (*close)(struct sock *, long int);
	int (*connect)(struct sock *, struct sockaddr *, int);
	int (*disconnect)(struct sock *, int);
	struct sock * (*accept)(struct sock *, int, int *);
	int (*ioctl)(struct sock *, int, long unsigned int);
	int (*init)(struct sock *);
	void (*destroy)(struct sock *);
	void (*shutdown)(struct sock *, int);
	int (*setsockopt)(struct sock *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb *, struct sock *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb *, struct sock *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock *, struct page___2 *, int, size_t, int);
	int (*bind)(struct sock *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock *, struct sk_buff *);
	void (*release_cb)(struct sock *);
	void (*mtu_reduced)(struct sock *);
	void (*hash)(struct sock *);
	void (*unhash)(struct sock *);
	void (*rehash)(struct sock *);
	int (*get_port)(struct sock *, short unsigned int);
	void (*clear_sk)(struct sock *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock *);
	void (*enter_memory_pressure)(struct sock *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___2 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops *rsk_prot;
	struct timewait_sock_ops *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___2 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___2 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto {
	void (*enter_memory_pressure)(struct sock *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops {
	int family;
	int obj_size;
	struct kmem_cache___2 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock *, struct request_sock *);
	void (*send_ack)(struct sock *, struct sk_buff *, struct request_sock *);
	void (*send_reset)(struct sock *, struct sk_buff *);
	void (*destructor)(struct request_sock *);
	void (*syn_ack_timeout)(struct sock *, struct request_sock *);
};

struct timewait_sock_ops {
	struct kmem_cache___2 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock *, struct sock *, void *);
	void (*twsk_destructor)(struct sock *);
};

struct ip6_sf_list {
	struct ip6_sf_list *sf_next;
	struct in6_addr sf_addr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
};

struct ifmcaddr6 {
	struct in6_addr mca_addr;
	struct inet6_dev *idev;
	struct ifmcaddr6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6 {
	struct in6_addr aca_addr;
	struct inet6_dev *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

enum {
	__ND_OPT_PREFIX_INFO_END = 0,
	ND_OPT_SOURCE_LL_ADDR = 1,
	ND_OPT_TARGET_LL_ADDR = 2,
	ND_OPT_PREFIX_INFO = 3,
	ND_OPT_REDIRECT_HDR = 4,
	ND_OPT_MTU = 5,
	__ND_OPT_ARRAY_MAX = 6,
	ND_OPT_ROUTE_INFO = 24,
	ND_OPT_RDNSS = 25,
	ND_OPT_DNSSL = 31,
	__ND_OPT_MAX = 32,
};

enum nfs_opnum4 {
	OP_ACCESS = 3,
	OP_CLOSE = 4,
	OP_COMMIT = 5,
	OP_CREATE = 6,
	OP_DELEGPURGE = 7,
	OP_DELEGRETURN = 8,
	OP_GETATTR = 9,
	OP_GETFH = 10,
	OP_LINK = 11,
	OP_LOCK = 12,
	OP_LOCKT = 13,
	OP_LOCKU = 14,
	OP_LOOKUP = 15,
	OP_LOOKUPP = 16,
	OP_NVERIFY = 17,
	OP_OPEN = 18,
	OP_OPENATTR = 19,
	OP_OPEN_CONFIRM = 20,
	OP_OPEN_DOWNGRADE = 21,
	OP_PUTFH = 22,
	OP_PUTPUBFH = 23,
	OP_PUTROOTFH = 24,
	OP_READ = 25,
	OP_READDIR = 26,
	OP_READLINK = 27,
	OP_REMOVE = 28,
	OP_RENAME = 29,
	OP_RENEW = 30,
	OP_RESTOREFH = 31,
	OP_SAVEFH = 32,
	OP_SECINFO = 33,
	OP_SETATTR = 34,
	OP_SETCLIENTID = 35,
	OP_SETCLIENTID_CONFIRM = 36,
	OP_VERIFY = 37,
	OP_WRITE = 38,
	OP_RELEASE_LOCKOWNER = 39,
	OP_BACKCHANNEL_CTL = 40,
	OP_BIND_CONN_TO_SESSION = 41,
	OP_EXCHANGE_ID = 42,
	OP_CREATE_SESSION = 43,
	OP_DESTROY_SESSION = 44,
	OP_FREE_STATEID = 45,
	OP_GET_DIR_DELEGATION = 46,
	OP_GETDEVICEINFO = 47,
	OP_GETDEVICELIST = 48,
	OP_LAYOUTCOMMIT = 49,
	OP_LAYOUTGET = 50,
	OP_LAYOUTRETURN = 51,
	OP_SECINFO_NO_NAME = 52,
	OP_SEQUENCE = 53,
	OP_SET_SSV = 54,
	OP_TEST_STATEID = 55,
	OP_WANT_DELEGATION = 56,
	OP_DESTROY_CLIENTID = 57,
	OP_RECLAIM_COMPLETE = 58,
	OP_ALLOCATE = 59,
	OP_COPY = 60,
	OP_COPY_NOTIFY = 61,
	OP_DEALLOCATE = 62,
	OP_IO_ADVISE = 63,
	OP_LAYOUTERROR = 64,
	OP_LAYOUTSTATS = 65,
	OP_OFFLOAD_CANCEL = 66,
	OP_OFFLOAD_STATUS = 67,
	OP_READ_PLUS = 68,
	OP_SEEK = 69,
	OP_WRITE_SAME = 70,
	OP_ILLEGAL = 10044,
};

struct io_cq___2 {
	struct request_queue___2 *q;
	struct io_context___2 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___2(struct request___2 *, int);

struct request___2 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide32;
			union {			};
		};
	};
	struct request_queue___2 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___2 *bio;
	struct bio___2 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___2 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___2 *saved_end_io;
		} flush;
	};
	struct gendisk___2 *rq_disk;
	struct hd_struct___2 *part;
	long unsigned int start_time;
	struct request_list___2 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___2 *end_io;
	void *end_io_data;
	struct request___2 *next_rq;
};

typedef int elevator_merge_fn___2(struct request_queue___2 *, struct request___2 **, struct bio___2 *);

typedef void elevator_merge_req_fn___2(struct request_queue___2 *, struct request___2 *, struct request___2 *);

typedef void elevator_merged_fn___2(struct request_queue___2 *, struct request___2 *, int);

typedef int elevator_allow_merge_fn___2(struct request_queue___2 *, struct request___2 *, struct bio___2 *);

typedef void elevator_bio_merged_fn___2(struct request_queue___2 *, struct request___2 *, struct bio___2 *);

typedef int elevator_dispatch_fn___2(struct request_queue___2 *, int);

typedef void elevator_add_req_fn___2(struct request_queue___2 *, struct request___2 *);

typedef struct request___2 *elevator_request_list_fn___2(struct request_queue___2 *, struct request___2 *);

typedef void elevator_completed_req_fn___2(struct request_queue___2 *, struct request___2 *);

typedef int elevator_may_queue_fn___2(struct request_queue___2 *, int);

typedef void elevator_init_icq_fn___2(struct io_cq___2 *);

typedef void elevator_exit_icq_fn___2(struct io_cq___2 *);

typedef int elevator_set_req_fn___2(struct request_queue___2 *, struct request___2 *, struct bio___2 *, gfp_t);

typedef void elevator_put_req_fn___2(struct request___2 *);

typedef void elevator_activate_req_fn___2(struct request_queue___2 *, struct request___2 *);

typedef void elevator_deactivate_req_fn___2(struct request_queue___2 *, struct request___2 *);

struct elevator_type___2;

typedef int elevator_init_fn___2(struct request_queue___2 *, struct elevator_type___2 *);

typedef void elevator_exit_fn___2(struct elevator_queue___2 *);

struct elevator_ops___2 {
	elevator_merge_fn___2 *elevator_merge_fn;
	elevator_merged_fn___2 *elevator_merged_fn;
	elevator_merge_req_fn___2 *elevator_merge_req_fn;
	elevator_allow_merge_fn___2 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___2 *elevator_bio_merged_fn;
	elevator_dispatch_fn___2 *elevator_dispatch_fn;
	elevator_add_req_fn___2 *elevator_add_req_fn;
	elevator_activate_req_fn___2 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___2 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___2 *elevator_completed_req_fn;
	elevator_request_list_fn___2 *elevator_former_req_fn;
	elevator_request_list_fn___2 *elevator_latter_req_fn;
	elevator_init_icq_fn___2 *elevator_init_icq_fn;
	elevator_exit_icq_fn___2 *elevator_exit_icq_fn;
	elevator_set_req_fn___2 *elevator_set_req_fn;
	elevator_put_req_fn___2 *elevator_put_req_fn;
	elevator_may_queue_fn___2 *elevator_may_queue_fn;
	elevator_init_fn___2 *elevator_init_fn;
	elevator_exit_fn___2 *elevator_exit_fn;
};

struct elv_fs_entry___2;

struct elevator_type___2 {
	struct kmem_cache___2 *icq_cache;
	struct elevator_ops___2 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___2 *elevator_attrs;
	char elevator_name[16];
	struct module___2 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___2 {
	struct elevator_type___2 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___5 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___2 *, char *);
	ssize_t (*store)(struct elevator_queue___2 *, const char *, size_t);
};

struct bvec_merge_data___2 {
	struct block_device___2 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___2 {
	struct request___2 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct perf_cpu_context___2;

struct pmu___2 {
	struct list_head entry;
	struct device___2 *dev;
	const struct attribute_group___2 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___2 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___2 *);
	void (*pmu_disable)(struct pmu___2 *);
	int (*event_init)(struct perf_event___2 *);
	int (*add)(struct perf_event___2 *, int);
	void (*del)(struct perf_event___2 *, int);
	void (*start)(struct perf_event___2 *, int);
	void (*stop)(struct perf_event___2 *, int);
	void (*read)(struct perf_event___2 *);
	void (*start_txn)(struct pmu___2 *);
	int (*commit_txn)(struct pmu___2 *);
	void (*cancel_txn)(struct pmu___2 *);
	int (*event_idx)(struct perf_event___2 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___2 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___2 *);
};

struct perf_cpu_context___2 {
	struct perf_event_context ctx;
	struct perf_event_context *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___2 *unique_pmu;
	struct perf_cgroup___2 *cgrp;
};

struct perf_sample_data___2 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___2 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___5 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___2)(struct trace_iterator___2 *, int, struct trace_event___2 *);

struct trace_event_functions___2 {
	trace_print_func___2 trace;
	trace_print_func___2 raw;
	trace_print_func___2 hex;
	trace_print_func___2 binary;
};

struct ftrace_event_class___2 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___2 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___2 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___2 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___2 *);
};

struct uuidcmp {
	const char *uuid;
	int len;
};

struct page___3;

typedef struct page___3 *pgtable_t___3;

struct address_space___3;

struct kmem_cache___3;

struct page___3 {
	long unsigned int flags;
	struct address_space___3 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___3 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___3 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___3 *slab_cache;
		struct page___3 *first_page;
	};
	long: 64;
};

struct thread_struct___3;

struct task_struct___6;

struct pv_cpu_ops___5 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___3 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___3 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___6 *);
	void (*end_context_switch)(struct task_struct___6 *);
};

struct perf_event___3;

struct thread_struct___3 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___3 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___3;

struct pid_link___3 {
	struct hlist_node node;
	struct pid___3 *pid;
};

struct mutex___6 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___6 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___3 {
	struct page___3 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___6;

struct nsproxy___3;

struct signal_struct___5;

struct bio_list___3;

struct backing_dev_info___3;

struct io_context___3;

struct css_set___3;

struct perf_event_context___3;

struct task_struct___6 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___6 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___6 *mm;
	struct mm_struct___6 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___6 *real_parent;
	struct task_struct___6 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___6 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___3 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___5 = 0,
		VTIME_USER___5 = 1,
		VTIME_SYS___5 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___3 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___3 *nsproxy;
	struct signal_struct___5 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___3 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___3 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___3 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___3 *perf_event_ctxp[2];
	struct mutex___6 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___3 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___6 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___6 *, struct mm_struct___6 *);
	void (*dup_mmap)(struct mm_struct___6 *, struct mm_struct___6 *);
	void (*exit_mmap)(struct mm_struct___6 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___6 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___6 *);
	void (*pgd_free)(struct mm_struct___6 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___6 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___6 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___6 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___6 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___6 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___6 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___6 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___6 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___6 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___6 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___6 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___6 lock;
	void *vdso;
} mm_context_t___6;

struct xol_area___3;

struct uprobes_state___3 {
	struct xol_area___3 *xol_area;
};

struct vm_area_struct___6;

struct file___3;

struct core_state___5;

struct mm_struct___6 {
	struct vm_area_struct___6 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___6 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___6 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___6 context;
	long unsigned int flags;
	struct core_state___5 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___6 *owner;
	struct file___3 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___3 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___3 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___6 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___6 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___6 *target;
};

struct perf_sample_data___3;

typedef void (*perf_overflow_handler_t___3)(struct perf_event___3 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___3;

typedef void (*ftrace_func_t___3)(long unsigned int, long unsigned int, struct ftrace_ops___3 *, struct pt_regs *);

struct ftrace_ops___3 {
	ftrace_func_t___3 func;
	struct ftrace_ops___3 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___6 regex_lock;
};

struct pmu___3;

struct fasync_struct___3;

struct pid_namespace___3;

struct ftrace_event_call___3;

struct perf_cgroup___3;

struct perf_event___3 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___3 *group_leader;
	struct pmu___3 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___3 hw;
	struct perf_event_context___3 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___6 child_mutex;
	struct list_head child_list;
	struct perf_event___3 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___6 *owner;
	struct mutex___6 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___3 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___3 *);
	struct callback_head callback_head;
	struct pid_namespace___3 *ns;
	u64 id;
	perf_overflow_handler_t___3 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___3 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___3 ftrace_ops;
	struct perf_cgroup___3 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct inode___4;

struct dentry_operations___3;

struct super_block___4;

struct dentry___4 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___4 *d_parent;
	struct qstr d_name;
	struct inode___4 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___3 *d_op;
	struct super_block___4 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___3;

struct address_space___3 {
	struct inode___4 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___6 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___3 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___3 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___3;

struct file_operations___3;

struct file_lock___3;

struct dquot___3;

struct block_device___3;

struct inode___4 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___3 *i_op;
	struct super_block___4 *i_sb;
	struct address_space___3 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___6 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___3 *i_fop;
	struct file_lock___3 *i_flock;
	struct address_space___3 i_data;
	struct dquot___3 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___3 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___2;

struct path___3;

struct dentry_operations___3 {
	int (*d_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_hash)(const struct dentry___4 *, struct qstr *);
	int (*d_compare)(const struct dentry___4 *, const struct dentry___4 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___4 *);
	void (*d_release)(struct dentry___4 *);
	void (*d_prune)(struct dentry___4 *);
	void (*d_iput)(struct dentry___4 *, struct inode___4 *);
	char * (*d_dname)(struct dentry___4 *, char *, int);
	struct vfsmount___2 * (*d_automount)(struct path___3 *);
	int (*d_manage)(struct dentry___4 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___3;

struct mem_dqinfo___3 {
	struct quota_format_type___3 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___3;

struct quota_info___3 {
	unsigned int flags;
	struct mutex___6 dqio_mutex;
	struct mutex___6 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___4 *files[2];
	struct mem_dqinfo___3 info[2];
	const struct quota_format_ops___3 *ops[2];
};

struct file_system_type___3;

struct super_operations___3;

struct dquot_operations___3;

struct quotactl_ops___3;

struct xattr_handler___3;

struct super_block___4 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___3 *s_type;
	const struct super_operations___3 *s_op;
	const struct dquot_operations___3 *dq_op;
	const struct quotactl_ops___3 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___4 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___3 *s_bdev;
	struct backing_dev_info___3 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___3 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___6 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___3 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___2 {
	struct dentry___4 *mnt_root;
	struct super_block___4 *mnt_sb;
	int mnt_flags;
};

struct path___3 {
	struct vfsmount___2 *mnt;
	struct dentry___4 *dentry;
};

struct upid___3 {
	int nr;
	struct pid_namespace___3 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___3 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___6 *child_reaper;
	struct kmem_cache___3 *pid_cachep;
	unsigned int level;
	struct pid_namespace___3 *parent;
	struct vfsmount___2 *proc_mnt;
	struct dentry___4 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___3 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___3 numbers[1];
};

struct irq_data___3;

struct x86_io_apic_ops___3 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___3 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___3;

struct irq_data___3 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___3 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___3;

struct dev_pm_ops___3 {
	int (*prepare)(struct device___3 *);
	void (*complete)(struct device___3 *);
	int (*suspend)(struct device___3 *);
	int (*resume)(struct device___3 *);
	int (*freeze)(struct device___3 *);
	int (*thaw)(struct device___3 *);
	int (*poweroff)(struct device___3 *);
	int (*restore)(struct device___3 *);
	int (*suspend_late)(struct device___3 *);
	int (*resume_early)(struct device___3 *);
	int (*freeze_late)(struct device___3 *);
	int (*thaw_early)(struct device___3 *);
	int (*poweroff_late)(struct device___3 *);
	int (*restore_early)(struct device___3 *);
	int (*suspend_noirq)(struct device___3 *);
	int (*resume_noirq)(struct device___3 *);
	int (*freeze_noirq)(struct device___3 *);
	int (*thaw_noirq)(struct device___3 *);
	int (*poweroff_noirq)(struct device___3 *);
	int (*restore_noirq)(struct device___3 *);
	int (*runtime_suspend)(struct device___3 *);
	int (*runtime_resume)(struct device___3 *);
	int (*runtime_idle)(struct device___3 *);
};

struct device_type___3;

struct bus_type___3;

struct device_driver___3;

struct dev_pm_domain___3;

struct class___3;

struct attribute_group___3;

struct device_rh___3;

struct device___3 {
	struct device___3 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___3 *type;
	struct mutex___6 mutex;
	struct bus_type___3 *bus;
	struct device_driver___3 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___3 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___3 *class;
	const struct attribute_group___3 **groups;
	void (*release)(struct device___3 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___3 *device_rh;
};

struct dev_pm_info_rh___3 {
	void (*set_latency_tolerance)(struct device___3 *, s32);
};

struct dev_pm_domain___3 {
	struct dev_pm_ops___3 ops;
};

struct smp_ops___5 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___6 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___3;

typedef void bio_end_io_t___3(struct bio___3 *, int);

struct bio_vec___3 {
	struct page___3 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___3;

struct bio_integrity_payload___3;

struct bio_set___3;

struct bio___3 {
	sector_t bi_sector;
	struct bio___3 *bi_next;
	struct block_device___3 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___3 *bi_end_io;
	void *bi_private;
	struct io_context___3 *bi_ioc;
	struct cgroup_subsys_state___3 *bi_css;
	struct bio_integrity_payload___3 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___3 *bi_io_vec;
	struct bio_set___3 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___3 bi_inline_vecs[0];
};

struct hd_struct___3;

struct gendisk___3;

struct request_queue___3;

struct block_device___3 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___4 *bd_inode;
	struct super_block___4 *bd_super;
	struct mutex___6 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___3 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___3 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___3 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___6 bd_fsfreeze_mutex;
};

struct io_cq___3;

struct io_context___3 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___3 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___3;

struct cgroup_subsys_state___3 {
	struct cgroup___3 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___3 {
	struct bio___3 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___3 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___3 *bip_vec;
	struct bio_vec___3 bip_inline_vecs[0];
};

struct bio_list___3 {
	struct bio___3 *head;
	struct bio___3 *tail;
};

struct bio_set___3 {
	struct kmem_cache___3 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___3 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___4 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___3 *ia_file;
};

struct fown_struct___3 {
	rwlock_t lock;
	struct pid___3 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___3 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___3 f_path;
	struct inode___4 *f_inode;
	const struct file_operations___3 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___3 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___3 *f_mapping;
	struct mutex___6 f_pos_lock;
};

struct zone___5;

struct lruvec___5 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___5 *zone;
};

struct pglist_data___5;

struct zone___5 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___5 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___5 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___5 {
	struct zone___5 *zone;
	int zone_idx;
};

struct zonelist___5 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___5 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___5 {
	struct zone___5 node_zones[4];
	struct zonelist___5 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___6 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___3 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___6 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___4 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___3 {
	int qf_fmt_id;
	const struct quota_format_ops___3 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___3 *qf_next;
};

struct quota_format_ops___3 {
	int (*check_quota_file)(struct super_block___4 *, int);
	int (*read_file_info)(struct super_block___4 *, int);
	int (*write_file_info)(struct super_block___4 *, int);
	int (*free_file_info)(struct super_block___4 *, int);
	int (*read_dqblk)(struct dquot___3 *);
	int (*commit_dqblk)(struct dquot___3 *);
	int (*release_dqblk)(struct dquot___3 *);
};

struct dquot_operations___3 {
	int (*write_dquot)(struct dquot___3 *);
	struct dquot___3 * (*alloc_dquot)(struct super_block___4 *, int);
	void (*destroy_dquot)(struct dquot___3 *);
	int (*acquire_dquot)(struct dquot___3 *);
	int (*release_dquot)(struct dquot___3 *);
	int (*mark_dirty)(struct dquot___3 *);
	int (*write_info)(struct super_block___4 *, int);
	qsize_t * (*get_reserved_space)(struct inode___4 *);
};

struct quotactl_ops___3 {
	int (*quota_on)(struct super_block___4 *, int, int, struct path___3 *);
	int (*quota_on_meta)(struct super_block___4 *, int, int);
	int (*quota_off)(struct super_block___4 *, int);
	int (*quota_sync)(struct super_block___4 *, int);
	int (*get_info)(struct super_block___4 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___4 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___4 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___4 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___4 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___4 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___4 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___4 *, unsigned int);
};

struct address_space_operations___3 {
	int (*writepage)(struct page___3 *, struct writeback_control *);
	int (*readpage)(struct file___3 *, struct page___3 *);
	int (*writepages)(struct address_space___3 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___3 *);
	int (*readpages)(struct file___3 *, struct address_space___3 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___3 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___3 **, void **);
	int (*write_end)(struct file___3 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___3 *, void *);
	sector_t (*bmap)(struct address_space___3 *, sector_t);
	void (*invalidatepage)(struct page___3 *, long unsigned int);
	int (*releasepage)(struct page___3 *, gfp_t);
	void (*freepage)(struct page___3 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___3 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___3 *, struct page___3 *, struct page___3 *, enum migrate_mode);
	int (*launder_page)(struct page___3 *);
	int (*is_partially_uptodate)(struct page___3 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___3 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___3 *, struct page___3 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___3 *, sector_t *);
	void (*swap_deactivate)(struct file___3 *);
	void (*invalidatepage_range)(struct page___3 *, unsigned int, unsigned int);
};

struct bdi_writeback___3 {
	struct backing_dev_info___3 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___3 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___3 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___3 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___4 *debug_dir;
	struct dentry___4 *debug_stats;
};

struct hd_struct___3 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___3 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___3;

struct block_device_operations___3;

struct gendisk___3 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___3 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___3 *part_tbl;
	struct hd_struct___3 part0;
	const struct block_device_operations___3 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct device___3 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___3 {
	struct request_queue___3 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___3(struct request_queue___3 *);

typedef void make_request_fn___3(struct request_queue___3 *, struct bio___3 *);

struct request___3;

typedef int prep_rq_fn___3(struct request_queue___3 *, struct request___3 *);

struct bvec_merge_data___3;

typedef int merge_bvec_fn___3(struct request_queue___3 *, struct bvec_merge_data___3 *, struct bio_vec___3 *);

typedef void softirq_done_fn___3(struct request___3 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___3(struct request___3 *);

typedef int dma_drain_needed_fn___3(struct request___3 *);

typedef int lld_busy_fn___3(struct request_queue___3 *);

struct queue_limits___3 {
	long unsigned int bounce_pfn;
	long unsigned int seg_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	short unsigned int logical_block_size;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char cluster;
	unsigned char discard_zeroes_data;
	unsigned int xcopy_reserved;
	union {
		unsigned int chunk_sectors;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct bsg_class_device___3 {
	struct device___3 *class_dev;
	struct device___3 *parent;
	int minor;
	struct request_queue___3 *queue;
	struct kref ref;
	void (*release)(struct device___3 *);
};

typedef void unprep_rq_fn___3(struct request_queue___3 *, struct request___3 *);

struct elevator_queue___3;

struct blk_queue_tag___3;

struct request_queue___3 {
	struct list_head queue_head;
	struct request___3 *last_merge;
	struct elevator_queue___3 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___3 root_rl;
	request_fn_proc___3 *request_fn;
	make_request_fn___3 *make_request_fn;
	prep_rq_fn___3 *prep_rq_fn;
	merge_bvec_fn___3 *merge_bvec_fn;
	softirq_done_fn___3 *softirq_done_fn;
	rq_timed_out_fn___3 *rq_timed_out_fn;
	dma_drain_needed_fn___3 *dma_drain_needed;
	lld_busy_fn___3 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___3 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___3 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___3 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___3 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___3 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___6 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___3 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___3 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___3 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___3 {
	struct dentry___4 * (*lookup)(struct inode___4 *, struct dentry___4 *, unsigned int);
	void * (*follow_link)(struct dentry___4 *, struct nameidata *);
	int (*permission)(struct inode___4 *, int);
	struct posix_acl * (*get_acl)(struct inode___4 *, int);
	int (*readlink)(struct dentry___4 *, char *, int);
	void (*put_link)(struct dentry___4 *, struct nameidata *, void *);
	int (*create)(struct inode___4 *, struct dentry___4 *, umode_t, bool);
	int (*link)(struct dentry___4 *, struct inode___4 *, struct dentry___4 *);
	int (*unlink)(struct inode___4 *, struct dentry___4 *);
	int (*symlink)(struct inode___4 *, struct dentry___4 *, const char *);
	int (*mkdir)(struct inode___4 *, struct dentry___4 *, umode_t);
	int (*rmdir)(struct inode___4 *, struct dentry___4 *);
	int (*mknod)(struct inode___4 *, struct dentry___4 *, umode_t, dev_t);
	int (*rename)(struct inode___4 *, struct dentry___4 *, struct inode___4 *, struct dentry___4 *);
	int (*setattr)(struct dentry___4 *, struct iattr___4 *);
	int (*getattr)(struct vfsmount___2 *, struct dentry___4 *, struct kstat *);
	int (*setxattr)(struct dentry___4 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___4 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___4 *, char *, size_t);
	int (*removexattr)(struct dentry___4 *, const char *);
	int (*fiemap)(struct inode___4 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___4 *, struct timespec *, int);
	int (*atomic_open)(struct inode___4 *, struct dentry___4 *, struct file___3 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___3;

struct seq_file___3;

struct file_operations___3 {
	struct module *owner;
	loff_t (*llseek)(struct file___3 *, loff_t, int);
	ssize_t (*read)(struct file___3 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___3 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___3 *, void *, filldir_t);
	unsigned int (*poll)(struct file___3 *, struct poll_table_struct___3 *);
	long int (*unlocked_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___3 *, struct vm_area_struct___6 *);
	int (*open)(struct inode___4 *, struct file___3 *);
	int (*flush)(struct file___3 *, fl_owner_t);
	int (*release)(struct inode___4 *, struct file___3 *);
	int (*fsync)(struct file___3 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___3 *, int);
	int (*lock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*sendpage)(struct file___3 *, struct page___3 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___3 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___3 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___3 *, long int, struct file_lock___3 **, void **);
		struct {
			int (*setlease)(struct file___3 *, long int, struct file_lock___3 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___3 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___3 *, struct file___3 *);
};

struct file_lock_operations___3;

struct lock_manager_operations___3;

struct file_lock___3 {
	struct file_lock___3 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___3 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___3 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___3 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___3 *fl_ops;
	const struct lock_manager_operations___3 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___3 {
	void (*fl_copy_lock)(struct file_lock___3 *, struct file_lock___3 *);
	void (*fl_release_private)(struct file_lock___3 *);
};

struct lock_manager_operations___3 {
	int (*lm_compare_owner)(struct file_lock___3 *, struct file_lock___3 *);
	long unsigned int (*lm_owner_key)(struct file_lock___3 *);
	void (*lm_notify)(struct file_lock___3 *);
	int (*lm_grant)(struct file_lock___3 *, struct file_lock___3 *, int);
	void (*lm_break)(struct file_lock___3 *);
	int (*lm_change)(struct file_lock___3 **, int);
};

struct fasync_struct___3 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___3 *fa_next;
	struct file___3 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___3 {
	const char *name;
	int fs_flags;
	struct dentry___4 * (*mount)(struct file_system_type___3 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___4 *);
	struct module *owner;
	struct file_system_type___3 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___3 {
	struct inode___4 * (*alloc_inode)(struct super_block___4 *);
	void (*destroy_inode)(struct inode___4 *);
	void (*dirty_inode)(struct inode___4 *, int);
	int (*write_inode)(struct inode___4 *, struct writeback_control *);
	int (*drop_inode)(struct inode___4 *);
	void (*evict_inode)(struct inode___4 *);
	void (*put_super)(struct super_block___4 *);
	int (*sync_fs)(struct super_block___4 *, int);
	int (*freeze_fs)(struct super_block___4 *);
	int (*unfreeze_fs)(struct super_block___4 *);
	int (*statfs)(struct dentry___4 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___4 *, int *, char *);
	void (*umount_begin)(struct super_block___4 *);
	int (*show_options)(struct seq_file___3 *, struct dentry___4 *);
	int (*show_devname)(struct seq_file___3 *, struct dentry___4 *);
	int (*show_path)(struct seq_file___3 *, struct dentry___4 *);
	int (*show_stats)(struct seq_file___3 *, struct dentry___4 *);
	ssize_t (*quota_read)(struct super_block___4 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___4 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___4 *);
	int (*bdev_try_to_free_page)(struct super_block___4 *, struct page___3 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___4 *);
	void (*free_cached_objects)(struct super_block___4 *, int);
};

struct xattr_handler___3 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___4 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___4 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___4 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___3)(struct file___3 *, wait_queue_head_t *, struct poll_table_struct___3 *);

struct poll_table_struct___3 {
	poll_queue_proc___3 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___5;

struct vm_area_struct___6 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___6 *vm_next;
	struct vm_area_struct___6 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___6 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___5 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___3 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___3;

struct seq_file___3 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___6 lock;
	const struct seq_operations___3 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___3 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___3 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___3;

struct memcg_cache_params___3;

struct kmem_cache___3 {
	struct kmem_cache_cpu___3 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___3 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___3;

struct vm_operations_struct___5 {
	void (*open)(struct vm_area_struct___6 *);
	void (*close)(struct vm_area_struct___6 *);
	int (*fault)(struct vm_area_struct___6 *, struct vm_fault___3 *);
	int (*page_mkwrite)(struct vm_area_struct___6 *, struct vm_fault___3 *);
	int (*access)(struct vm_area_struct___6 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___6 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___6 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___6 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___6 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___5 {
	struct task_struct___6 *task;
	struct core_thread___5 *next;
};

struct core_state___5 {
	atomic_t nr_threads;
	struct core_thread___5 dumper;
	struct completion startup;
};

struct nsproxy___3 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___3 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___5 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___6 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___6 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___3 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___3 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___6 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___3 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___3 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___3 {
	struct pmu___3 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___6 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___6 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___3 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___3;

struct attribute_group___3 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___3 **bin_attrs;
};

struct bin_attribute___3 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___3 *, struct kobject *, struct bin_attribute___3 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___3 *, struct kobject *, struct bin_attribute___3 *, char *, loff_t, size_t);
	int (*mmap)(struct file___3 *, struct kobject *, struct bin_attribute___3 *, struct vm_area_struct___6 *);
};

struct kmem_cache_cpu___3 {
	void **freelist;
	long unsigned int tid;
	struct page___3 *page;
	struct page___3 *partial;
};

struct memcg_cache_params___3 {
	bool is_root_cache;
	union {
		struct kmem_cache___3 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___3 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___3 *, char *);
	ssize_t (*store)(struct bus_type___3 *, const char *, size_t);
};

struct device_attribute___3;

struct driver_attribute___3;

struct bus_type___3 {
	const char *name;
	const char *dev_name;
	struct device___3 *dev_root;
	struct bus_attribute___3 *bus_attrs;
	struct device_attribute___3 *dev_attrs;
	struct driver_attribute___3 *drv_attrs;
	const struct attribute_group___3 **bus_groups;
	const struct attribute_group___3 **dev_groups;
	const struct attribute_group___3 **drv_groups;
	int (*match)(struct device___3 *, struct device_driver___3 *);
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	int (*probe)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*online)(struct device___3 *);
	int (*offline)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct dev_pm_ops___3 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device___3 *, struct device_attribute___3 *, char *);
	ssize_t (*store)(struct device___3 *, struct device_attribute___3 *, const char *, size_t);
};

struct driver_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___3 *, char *);
	ssize_t (*store)(struct device_driver___3 *, const char *, size_t);
};

struct device_driver___3 {
	const char *name;
	struct bus_type___3 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct attribute_group___3 **groups;
	const struct dev_pm_ops___3 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___3 {
	const char *name;
	const struct attribute_group___3 **groups;
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___3 *);
	const struct dev_pm_ops___3 *pm;
};

struct class_attribute___3;

struct class___3 {
	const char *name;
	struct module *owner;
	struct class_attribute___3 *class_attrs;
	struct device_attribute___3 *dev_attrs;
	const struct attribute_group___3 **dev_groups;
	struct bin_attribute___3 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *);
	void (*class_release)(struct class___3 *);
	void (*dev_release)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___3 *);
	const struct dev_pm_ops___3 *pm;
	struct subsys_private *p;
};

struct class_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct class___3 *, struct class_attribute___3 *, char *);
	ssize_t (*store)(struct class___3 *, struct class_attribute___3 *, const char *, size_t);
	const void * (*namespace)(struct class___3 *, const struct class_attribute___3 *);
};

struct device_rh___3 {
	struct dev_pm_info_rh___3 power;
};

struct disk_part_tbl___3 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___3 *last_lookup;
	struct hd_struct___3 *part[0];
};

struct block_device_operations___3 {
	int (*open)(struct block_device___3 *, fmode_t);
	void (*release)(struct gendisk___3 *, fmode_t);
	int (*ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___3 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___3 *, unsigned int);
	int (*media_changed)(struct gendisk___3 *);
	void (*unlock_native_capacity)(struct gendisk___3 *);
	int (*revalidate_disk)(struct gendisk___3 *);
	int (*getgeo)(struct block_device___3 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___3 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___3 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___3 *page;
};

struct irq_chip___3 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___3 *);
	void (*irq_shutdown)(struct irq_data___3 *);
	void (*irq_enable)(struct irq_data___3 *);
	void (*irq_disable)(struct irq_data___3 *);
	void (*irq_ack)(struct irq_data___3 *);
	void (*irq_mask)(struct irq_data___3 *);
	void (*irq_mask_ack)(struct irq_data___3 *);
	void (*irq_unmask)(struct irq_data___3 *);
	void (*irq_eoi)(struct irq_data___3 *);
	int (*irq_set_affinity)(struct irq_data___3 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___3 *);
	int (*irq_set_type)(struct irq_data___3 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___3 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___3 *);
	void (*irq_bus_sync_unlock)(struct irq_data___3 *);
	void (*irq_cpu_online)(struct irq_data___3 *);
	void (*irq_cpu_offline)(struct irq_data___3 *);
	void (*irq_suspend)(struct irq_data___3 *);
	void (*irq_resume)(struct irq_data___3 *);
	void (*irq_pm_shutdown)(struct irq_data___3 *);
	void (*irq_print_chip)(struct irq_data___3 *, struct seq_file___3 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___3 *, void *);
	long unsigned int flags;
};

struct io_cq___3 {
	struct request_queue___3 *q;
	struct io_context___3 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___3 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___3(struct request___3 *, int);

struct request___3 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___3 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___3 *bio;
	struct bio___3 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___3 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___3 *saved_end_io;
		} flush;
	};
	struct gendisk___3 *rq_disk;
	struct hd_struct___3 *part;
	long unsigned int start_time;
	struct request_list___3 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___3 *end_io;
	void *end_io_data;
	struct request___3 *next_rq;
};

typedef int elevator_merge_fn___3(struct request_queue___3 *, struct request___3 **, struct bio___3 *);

typedef void elevator_merge_req_fn___3(struct request_queue___3 *, struct request___3 *, struct request___3 *);

typedef void elevator_merged_fn___3(struct request_queue___3 *, struct request___3 *, int);

typedef int elevator_allow_merge_fn___3(struct request_queue___3 *, struct request___3 *, struct bio___3 *);

typedef void elevator_bio_merged_fn___3(struct request_queue___3 *, struct request___3 *, struct bio___3 *);

typedef int elevator_dispatch_fn___3(struct request_queue___3 *, int);

typedef void elevator_add_req_fn___3(struct request_queue___3 *, struct request___3 *);

typedef struct request___3 *elevator_request_list_fn___3(struct request_queue___3 *, struct request___3 *);

typedef void elevator_completed_req_fn___3(struct request_queue___3 *, struct request___3 *);

typedef int elevator_may_queue_fn___3(struct request_queue___3 *, int);

typedef void elevator_init_icq_fn___3(struct io_cq___3 *);

typedef void elevator_exit_icq_fn___3(struct io_cq___3 *);

typedef int elevator_set_req_fn___3(struct request_queue___3 *, struct request___3 *, struct bio___3 *, gfp_t);

typedef void elevator_put_req_fn___3(struct request___3 *);

typedef void elevator_activate_req_fn___3(struct request_queue___3 *, struct request___3 *);

typedef void elevator_deactivate_req_fn___3(struct request_queue___3 *, struct request___3 *);

struct elevator_type___3;

typedef int elevator_init_fn___3(struct request_queue___3 *, struct elevator_type___3 *);

typedef void elevator_exit_fn___3(struct elevator_queue___3 *);

struct elevator_ops___3 {
	elevator_merge_fn___3 *elevator_merge_fn;
	elevator_merged_fn___3 *elevator_merged_fn;
	elevator_merge_req_fn___3 *elevator_merge_req_fn;
	elevator_allow_merge_fn___3 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___3 *elevator_bio_merged_fn;
	elevator_dispatch_fn___3 *elevator_dispatch_fn;
	elevator_add_req_fn___3 *elevator_add_req_fn;
	elevator_activate_req_fn___3 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___3 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___3 *elevator_completed_req_fn;
	elevator_request_list_fn___3 *elevator_former_req_fn;
	elevator_request_list_fn___3 *elevator_latter_req_fn;
	elevator_init_icq_fn___3 *elevator_init_icq_fn;
	elevator_exit_icq_fn___3 *elevator_exit_icq_fn;
	elevator_set_req_fn___3 *elevator_set_req_fn;
	elevator_put_req_fn___3 *elevator_put_req_fn;
	elevator_may_queue_fn___3 *elevator_may_queue_fn;
	elevator_init_fn___3 *elevator_init_fn;
	elevator_exit_fn___3 *elevator_exit_fn;
};

struct elv_fs_entry___3;

struct elevator_type___3 {
	struct kmem_cache___3 *icq_cache;
	struct elevator_ops___3 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___3 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___3 {
	struct elevator_type___3 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___6 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___3 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___3 *, char *);
	ssize_t (*store)(struct elevator_queue___3 *, const char *, size_t);
};

struct bvec_merge_data___3 {
	struct block_device___3 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___3 {
	struct request___3 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___3 {
	void * (*start)(struct seq_file___3 *, loff_t *);
	void (*stop)(struct seq_file___3 *, void *);
	void * (*next)(struct seq_file___3 *, void *, loff_t *);
	int (*show)(struct seq_file___3 *, void *);
};

struct cgroupfs_root___3;

struct cgroup___3 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___3 *parent;
	struct dentry___4 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___3 *subsys[11];
	struct cgroupfs_root___3 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___6 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___3 {
	struct super_block___4 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___3 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___3;

struct pmu___3 {
	struct list_head entry;
	struct device___3 *dev;
	const struct attribute_group___3 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___3 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___3 *);
	void (*pmu_disable)(struct pmu___3 *);
	int (*event_init)(struct perf_event___3 *);
	int (*add)(struct perf_event___3 *, int);
	void (*del)(struct perf_event___3 *, int);
	void (*start)(struct perf_event___3 *, int);
	void (*stop)(struct perf_event___3 *, int);
	void (*read)(struct perf_event___3 *);
	void (*start_txn)(struct pmu___3 *);
	int (*commit_txn)(struct pmu___3 *);
	void (*cancel_txn)(struct pmu___3 *);
	int (*event_idx)(struct perf_event___3 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___3 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___3 *);
};

struct perf_cpu_context___3 {
	struct perf_event_context___3 ctx;
	struct perf_event_context___3 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___3 *unique_pmu;
	struct perf_cgroup___3 *cgrp;
};

struct perf_sample_data___3 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_functions___3;

struct trace_event___3 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___3 *funcs;
};

struct ftrace_event_class___3;

struct ftrace_event_call___3 {
	struct list_head list;
	struct ftrace_event_class___3 *class;
	char *name;
	struct trace_event___3 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___3 {
	struct cgroup_subsys_state___3 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___3 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___6 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___3)(struct trace_iterator___3 *, int, struct trace_event___3 *);

struct trace_event_functions___3 {
	trace_print_func___3 trace;
	trace_print_func___3 raw;
	trace_print_func___3 hex;
	trace_print_func___3 binary;
};

struct ftrace_event_class___3 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___3 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___3 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___3 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___3 *);
};

struct mdu_array_info_s {
	int major_version;
	int minor_version;
	int patch_version;
	int ctime;
	int level;
	int size;
	int nr_disks;
	int raid_disks;
	int md_minor;
	int not_persistent;
	int utime;
	int state;
	int active_disks;
	int working_disks;
	int failed_disks;
	int spare_disks;
	int layout;
	int chunk_size;
};

typedef struct mdu_array_info_s mdu_array_info_t;

struct mdu_disk_info_s {
	int number;
	int major;
	int minor;
	int raid_disk;
	int state;
};

typedef struct mdu_disk_info_s mdu_disk_info_t;

struct page___4;

typedef struct page___4 *pgtable_t___4;

struct address_space___4;

struct kmem_cache___4;

struct page___4 {
	long unsigned int flags;
	struct address_space___4 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___4 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___4 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___4 *slab_cache;
		struct page___4 *first_page;
	};
	long: 64;
};

struct thread_struct___4;

struct task_struct___7;

struct pv_cpu_ops___6 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___4 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___4 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___7 *);
	void (*end_context_switch)(struct task_struct___7 *);
};

struct perf_event___4;

struct thread_struct___4 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___4 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___4;

struct pid_link___4 {
	struct hlist_node node;
	struct pid___4 *pid;
};

struct mutex___7 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___7 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___4 {
	struct page___4 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___7;

struct nsproxy___4;

struct signal_struct___6;

struct bio_list___4;

struct backing_dev_info___4;

struct io_context___4;

struct css_set___4;

struct perf_event_context___4;

struct task_struct___7 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___7 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___7 *mm;
	struct mm_struct___7 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___7 *real_parent;
	struct task_struct___7 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___7 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___4 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___6 = 0,
		VTIME_USER___6 = 1,
		VTIME_SYS___6 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___4 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___4 *nsproxy;
	struct signal_struct___6 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___4 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___4 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___4 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___4 *perf_event_ctxp[2];
	struct mutex___7 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___4 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___7 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___7 *, struct mm_struct___7 *);
	void (*dup_mmap)(struct mm_struct___7 *, struct mm_struct___7 *);
	void (*exit_mmap)(struct mm_struct___7 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___7 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___7 *);
	void (*pgd_free)(struct mm_struct___7 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___7 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___7 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___7 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___7 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___7 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___7 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___7 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___7 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___7 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___7 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___7 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___7 lock;
	void *vdso;
} mm_context_t___7;

struct xol_area___4;

struct uprobes_state___4 {
	struct xol_area___4 *xol_area;
};

struct vm_area_struct___7;

struct file___4;

struct core_state___6;

struct mm_struct___7 {
	struct vm_area_struct___7 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___7 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___7 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___7 context;
	long unsigned int flags;
	struct core_state___6 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___7 *owner;
	struct file___4 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___4 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___4 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___7 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___7 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___7 *target;
};

typedef void (*perf_overflow_handler_t___4)(struct perf_event___4 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___4;

typedef void (*ftrace_func_t___4)(long unsigned int, long unsigned int, struct ftrace_ops___4 *, struct pt_regs *);

struct ftrace_ops___4 {
	ftrace_func_t___4 func;
	struct ftrace_ops___4 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___7 regex_lock;
};

struct pmu___4;

struct fasync_struct___4;

struct pid_namespace___4;

struct ftrace_event_call___4;

struct perf_cgroup___4;

struct perf_event___4 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___4 *group_leader;
	struct pmu___4 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___4 hw;
	struct perf_event_context___4 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___7 child_mutex;
	struct list_head child_list;
	struct perf_event___4 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___7 *owner;
	struct mutex___7 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___4 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___4 *);
	struct callback_head callback_head;
	struct pid_namespace___4 *ns;
	u64 id;
	perf_overflow_handler_t___4 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___4 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___4 ftrace_ops;
	struct perf_cgroup___4 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___4 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___4 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___4;

struct memcg_cache_params___4;

struct kmem_cache___4 {
	struct kmem_cache_cpu___4 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___4 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___5;

struct address_space_operations___4;

struct address_space___4 {
	struct inode___5 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___7 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___4 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___4 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___3;

struct dentry___5;

struct path___4 {
	struct vfsmount___3 *mnt;
	struct dentry___5 *dentry;
};

struct fown_struct___4 {
	rwlock_t lock;
	struct pid___4 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___4;

struct file___4 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___4 f_path;
	struct inode___5 *f_inode;
	const struct file_operations___4 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___4 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___4 *f_mapping;
	struct mutex___7 f_pos_lock;
};

struct vm_operations_struct___6;

struct vm_area_struct___7 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___7 *vm_next;
	struct vm_area_struct___7 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___7 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___4 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___4;

struct vm_operations_struct___6 {
	void (*open)(struct vm_area_struct___7 *);
	void (*close)(struct vm_area_struct___7 *);
	int (*fault)(struct vm_area_struct___7 *, struct vm_fault___4 *);
	int (*page_mkwrite)(struct vm_area_struct___7 *, struct vm_fault___4 *);
	int (*access)(struct vm_area_struct___7 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___7 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___7 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___7 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___7 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___6 {
	struct task_struct___7 *task;
	struct core_thread___6 *next;
};

struct core_state___6 {
	atomic_t nr_threads;
	struct core_thread___6 dumper;
	struct completion startup;
};

struct call_single_data___2 {
	union {
		struct llist_node llist;
		struct {
			struct list_head list;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	smp_call_func_t func;
	void *info;
	u16 flags;
};

struct irq_data___4;

struct x86_io_apic_ops___4 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___4 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___4;

struct irq_data___4 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___4 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___4;

struct dev_pm_ops___4 {
	int (*prepare)(struct device___4 *);
	void (*complete)(struct device___4 *);
	int (*suspend)(struct device___4 *);
	int (*resume)(struct device___4 *);
	int (*freeze)(struct device___4 *);
	int (*thaw)(struct device___4 *);
	int (*poweroff)(struct device___4 *);
	int (*restore)(struct device___4 *);
	int (*suspend_late)(struct device___4 *);
	int (*resume_early)(struct device___4 *);
	int (*freeze_late)(struct device___4 *);
	int (*thaw_early)(struct device___4 *);
	int (*poweroff_late)(struct device___4 *);
	int (*restore_early)(struct device___4 *);
	int (*suspend_noirq)(struct device___4 *);
	int (*resume_noirq)(struct device___4 *);
	int (*freeze_noirq)(struct device___4 *);
	int (*thaw_noirq)(struct device___4 *);
	int (*poweroff_noirq)(struct device___4 *);
	int (*restore_noirq)(struct device___4 *);
	int (*runtime_suspend)(struct device___4 *);
	int (*runtime_resume)(struct device___4 *);
	int (*runtime_idle)(struct device___4 *);
};

struct acpi_dev_node___2 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___4;

struct bus_type___4;

struct device_driver___4;

struct dev_pm_domain___4;

struct class___4;

struct attribute_group___4;

struct device_rh___4;

struct device___4 {
	struct device___4 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___4 *type;
	struct mutex___7 mutex;
	struct bus_type___4 *bus;
	struct device_driver___4 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___4 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___4 *class;
	const struct attribute_group___4 **groups;
	void (*release)(struct device___4 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___4 *device_rh;
};

struct dev_pm_info_rh___4 {
	void (*set_latency_tolerance)(struct device___4 *, s32);
};

struct dev_pm_domain___4 {
	struct dev_pm_ops___4 ops;
};

struct smp_ops___6 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___7 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___4 {
	int nr;
	struct pid_namespace___4 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___4 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___7 *child_reaper;
	struct kmem_cache___4 *pid_cachep;
	unsigned int level;
	struct pid_namespace___4 *parent;
	struct vfsmount___3 *proc_mnt;
	struct dentry___5 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___4 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___4 numbers[1];
};

struct zone___6;

struct lruvec___6 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___6 *zone;
};

struct pglist_data___6;

struct zone___6 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___6 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___6 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___6 {
	struct zone___6 *zone;
	int zone_idx;
};

struct zonelist___6 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___6 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___6 {
	struct zone___6 node_zones[4];
	struct zonelist___6 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___7 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___4 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___4 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___6 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___7 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___7 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___4 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___4 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___7 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___4;

struct bio_list___4 {
	struct bio___4 *head;
	struct bio___4 *tail;
};

struct bdi_writeback___4 {
	struct backing_dev_info___4 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___4 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___4 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___4 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___5 *debug_dir;
	struct dentry___5 *debug_stats;
};

struct io_cq___4;

struct io_context___4 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___4 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___4;

struct css_set___4 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___4 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___4 {
	struct pmu___4 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___7 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___7 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___4 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct stat {
	long unsigned int st_dev;
	long unsigned int st_ino;
	long unsigned int st_nlink;
	unsigned int st_mode;
	unsigned int st_uid;
	unsigned int st_gid;
	unsigned int __pad0;
	long unsigned int st_rdev;
	long int st_size;
	long int st_blksize;
	long int st_blocks;
	long unsigned int st_atime;
	long unsigned int st_atime_nsec;
	long unsigned int st_mtime;
	long unsigned int st_mtime_nsec;
	long unsigned int st_ctime;
	long unsigned int st_ctime_nsec;
	long int __unused[3];
};

struct bin_attribute___4;

struct attribute_group___4 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___4 **bin_attrs;
};

struct bin_attribute___4 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___4 *, struct kobject *, struct bin_attribute___4 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___4 *, struct kobject *, struct bin_attribute___4 *, char *, loff_t, size_t);
	int (*mmap)(struct file___4 *, struct kobject *, struct bin_attribute___4 *, struct vm_area_struct___7 *);
};

struct kmem_cache_cpu___4 {
	void **freelist;
	long unsigned int tid;
	struct page___4 *page;
	struct page___4 *partial;
};

struct memcg_cache_params___4 {
	bool is_root_cache;
	union {
		struct kmem_cache___4 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___4 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___4 *, char *);
	ssize_t (*store)(struct bus_type___4 *, const char *, size_t);
};

struct device_attribute___4;

struct driver_attribute___4;

struct bus_type___4 {
	const char *name;
	const char *dev_name;
	struct device___4 *dev_root;
	struct bus_attribute___4 *bus_attrs;
	struct device_attribute___4 *dev_attrs;
	struct driver_attribute___4 *drv_attrs;
	const struct attribute_group___4 **bus_groups;
	const struct attribute_group___4 **dev_groups;
	const struct attribute_group___4 **drv_groups;
	int (*match)(struct device___4 *, struct device_driver___4 *);
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	int (*probe)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*online)(struct device___4 *);
	int (*offline)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct dev_pm_ops___4 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device___4 *, struct device_attribute___4 *, char *);
	ssize_t (*store)(struct device___4 *, struct device_attribute___4 *, const char *, size_t);
};

struct driver_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___4 *, char *);
	ssize_t (*store)(struct device_driver___4 *, const char *, size_t);
};

struct device_driver___4 {
	const char *name;
	struct bus_type___4 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct attribute_group___4 **groups;
	const struct dev_pm_ops___4 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___4 {
	const char *name;
	const struct attribute_group___4 **groups;
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___4 *);
	const struct dev_pm_ops___4 *pm;
};

struct class_attribute___4;

struct class___4 {
	const char *name;
	struct module *owner;
	struct class_attribute___4 *class_attrs;
	struct device_attribute___4 *dev_attrs;
	const struct attribute_group___4 **dev_groups;
	struct bin_attribute___4 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *);
	void (*class_release)(struct class___4 *);
	void (*dev_release)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___4 *);
	const struct dev_pm_ops___4 *pm;
	struct subsys_private *p;
};

struct class_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct class___4 *, struct class_attribute___4 *, char *);
	ssize_t (*store)(struct class___4 *, struct class_attribute___4 *, const char *, size_t);
	const void * (*namespace)(struct class___4 *, const struct class_attribute___4 *);
};

struct device_rh___4 {
	struct dev_pm_info_rh___4 power;
};

struct dentry_operations___4;

struct super_block___5;

struct dentry___5 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___5 *d_parent;
	struct qstr d_name;
	struct inode___5 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___4 *d_op;
	struct super_block___5 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___4;

struct file_lock___4;

struct dquot___4;

struct block_device___4;

struct inode___5 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___4 *i_op;
	struct super_block___5 *i_sb;
	struct address_space___4 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___7 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___4 *i_fop;
	struct file_lock___4 *i_flock;
	struct address_space___4 i_data;
	struct dquot___4 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___4 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___4 {
	int (*d_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_hash)(const struct dentry___5 *, struct qstr *);
	int (*d_compare)(const struct dentry___5 *, const struct dentry___5 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___5 *);
	void (*d_release)(struct dentry___5 *);
	void (*d_prune)(struct dentry___5 *);
	void (*d_iput)(struct dentry___5 *, struct inode___5 *);
	char * (*d_dname)(struct dentry___5 *, char *, int);
	struct vfsmount___3 * (*d_automount)(struct path___4 *);
	int (*d_manage)(struct dentry___5 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___4;

struct mem_dqinfo___4 {
	struct quota_format_type___4 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___4;

struct quota_info___4 {
	unsigned int flags;
	struct mutex___7 dqio_mutex;
	struct mutex___7 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___5 *files[2];
	struct mem_dqinfo___4 info[2];
	const struct quota_format_ops___4 *ops[2];
};

struct file_system_type___4;

struct super_operations___4;

struct dquot_operations___4;

struct quotactl_ops___4;

struct xattr_handler___4;

struct super_block___5 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___4 *s_type;
	const struct super_operations___4 *s_op;
	const struct dquot_operations___4 *dq_op;
	const struct quotactl_ops___4 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___5 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___4 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___4 *s_bdev;
	struct backing_dev_info___4 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___4 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___7 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___4 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___3 {
	struct dentry___5 *mnt_root;
	struct super_block___5 *mnt_sb;
	int mnt_flags;
};

typedef void bio_end_io_t___4(struct bio___4 *, int);

struct bio_vec___4 {
	struct page___4 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___4;

struct bio_set___4;

struct bio___4 {
	sector_t bi_sector;
	struct bio___4 *bi_next;
	struct block_device___4 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___4 *bi_end_io;
	void *bi_private;
	struct io_context___4 *bi_ioc;
	struct cgroup_subsys_state___4 *bi_css;
	struct bio_integrity_payload___4 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___4 *bi_io_vec;
	struct bio_set___4 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___4 bi_inline_vecs[0];
};

struct hd_struct___4;

struct gendisk___4;

struct request_queue___4;

struct block_device___4 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___5 *bd_inode;
	struct super_block___5 *bd_super;
	struct mutex___7 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___4 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___4 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___7 bd_fsfreeze_mutex;
};

struct cgroup___4;

struct cgroup_subsys_state___4 {
	struct cgroup___4 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___4 {
	struct bio___4 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___4 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___4 *bip_vec;
	struct bio_vec___4 bip_inline_vecs[0];
};

struct bio_set___4 {
	struct kmem_cache___4 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___4 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___5 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___4 *ia_file;
};

struct dquot___4 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___7 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___5 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___4 {
	int qf_fmt_id;
	const struct quota_format_ops___4 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___4 *qf_next;
};

struct quota_format_ops___4 {
	int (*check_quota_file)(struct super_block___5 *, int);
	int (*read_file_info)(struct super_block___5 *, int);
	int (*write_file_info)(struct super_block___5 *, int);
	int (*free_file_info)(struct super_block___5 *, int);
	int (*read_dqblk)(struct dquot___4 *);
	int (*commit_dqblk)(struct dquot___4 *);
	int (*release_dqblk)(struct dquot___4 *);
};

struct dquot_operations___4 {
	int (*write_dquot)(struct dquot___4 *);
	struct dquot___4 * (*alloc_dquot)(struct super_block___5 *, int);
	void (*destroy_dquot)(struct dquot___4 *);
	int (*acquire_dquot)(struct dquot___4 *);
	int (*release_dquot)(struct dquot___4 *);
	int (*mark_dirty)(struct dquot___4 *);
	int (*write_info)(struct super_block___5 *, int);
	qsize_t * (*get_reserved_space)(struct inode___5 *);
};

struct quotactl_ops___4 {
	int (*quota_on)(struct super_block___5 *, int, int, struct path___4 *);
	int (*quota_on_meta)(struct super_block___5 *, int, int);
	int (*quota_off)(struct super_block___5 *, int);
	int (*quota_sync)(struct super_block___5 *, int);
	int (*get_info)(struct super_block___5 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___5 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___5 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___5 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___5 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___5 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___5 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___5 *, unsigned int);
};

struct address_space_operations___4 {
	int (*writepage)(struct page___4 *, struct writeback_control *);
	int (*readpage)(struct file___4 *, struct page___4 *);
	int (*writepages)(struct address_space___4 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___4 *);
	int (*readpages)(struct file___4 *, struct address_space___4 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___4 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___4 **, void **);
	int (*write_end)(struct file___4 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___4 *, void *);
	sector_t (*bmap)(struct address_space___4 *, sector_t);
	void (*invalidatepage)(struct page___4 *, long unsigned int);
	int (*releasepage)(struct page___4 *, gfp_t);
	void (*freepage)(struct page___4 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___4 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___4 *, struct page___4 *, struct page___4 *, enum migrate_mode);
	int (*launder_page)(struct page___4 *);
	int (*is_partially_uptodate)(struct page___4 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___4 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___4 *, struct page___4 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___4 *, sector_t *);
	void (*swap_deactivate)(struct file___4 *);
	void (*invalidatepage_range)(struct page___4 *, unsigned int, unsigned int);
};

struct hd_struct___4 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___4 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___4;

struct block_device_operations___4;

struct gendisk___4 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___4 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___4 *part_tbl;
	struct hd_struct___4 part0;
	const struct block_device_operations___4 *fops;
	struct request_queue___4 *queue;
	void *private_data;
	int flags;
	struct device___4 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___4 {
	struct request_queue___4 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___4(struct request_queue___4 *);

typedef void make_request_fn___4(struct request_queue___4 *, struct bio___4 *);

struct request___4;

typedef int prep_rq_fn___4(struct request_queue___4 *, struct request___4 *);

struct bvec_merge_data___4;

typedef int merge_bvec_fn___4(struct request_queue___4 *, struct bvec_merge_data___4 *, struct bio_vec___4 *);

typedef void softirq_done_fn___4(struct request___4 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___4(struct request___4 *);

typedef int dma_drain_needed_fn___4(struct request___4 *);

typedef int lld_busy_fn___4(struct request_queue___4 *);

struct bsg_class_device___4 {
	struct device___4 *class_dev;
	struct device___4 *parent;
	int minor;
	struct request_queue___4 *queue;
	struct kref ref;
	void (*release)(struct device___4 *);
};

typedef void unprep_rq_fn___4(struct request_queue___4 *, struct request___4 *);

struct elevator_queue___4;

struct blk_queue_tag___4;

struct request_queue___4 {
	struct list_head queue_head;
	struct request___4 *last_merge;
	struct elevator_queue___4 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___4 root_rl;
	request_fn_proc___4 *request_fn;
	make_request_fn___4 *make_request_fn;
	prep_rq_fn___4 *prep_rq_fn;
	merge_bvec_fn___4 *merge_bvec_fn;
	softirq_done_fn___4 *softirq_done_fn;
	rq_timed_out_fn___4 *rq_timed_out_fn;
	dma_drain_needed_fn___4 *dma_drain_needed;
	lld_busy_fn___4 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___4 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___4 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___4 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___4 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___4 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___7 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___4 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___4 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___4 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___4 {
	struct dentry___5 * (*lookup)(struct inode___5 *, struct dentry___5 *, unsigned int);
	void * (*follow_link)(struct dentry___5 *, struct nameidata *);
	int (*permission)(struct inode___5 *, int);
	struct posix_acl * (*get_acl)(struct inode___5 *, int);
	int (*readlink)(struct dentry___5 *, char *, int);
	void (*put_link)(struct dentry___5 *, struct nameidata *, void *);
	int (*create)(struct inode___5 *, struct dentry___5 *, umode_t, bool);
	int (*link)(struct dentry___5 *, struct inode___5 *, struct dentry___5 *);
	int (*unlink)(struct inode___5 *, struct dentry___5 *);
	int (*symlink)(struct inode___5 *, struct dentry___5 *, const char *);
	int (*mkdir)(struct inode___5 *, struct dentry___5 *, umode_t);
	int (*rmdir)(struct inode___5 *, struct dentry___5 *);
	int (*mknod)(struct inode___5 *, struct dentry___5 *, umode_t, dev_t);
	int (*rename)(struct inode___5 *, struct dentry___5 *, struct inode___5 *, struct dentry___5 *);
	int (*setattr)(struct dentry___5 *, struct iattr___5 *);
	int (*getattr)(struct vfsmount___3 *, struct dentry___5 *, struct kstat *);
	int (*setxattr)(struct dentry___5 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___5 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___5 *, char *, size_t);
	int (*removexattr)(struct dentry___5 *, const char *);
	int (*fiemap)(struct inode___5 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___5 *, struct timespec *, int);
	int (*atomic_open)(struct inode___5 *, struct dentry___5 *, struct file___4 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___4;

struct seq_file___4;

struct file_operations___4 {
	struct module *owner;
	loff_t (*llseek)(struct file___4 *, loff_t, int);
	ssize_t (*read)(struct file___4 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___4 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___4 *, void *, filldir_t);
	unsigned int (*poll)(struct file___4 *, struct poll_table_struct___4 *);
	long int (*unlocked_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___4 *, struct vm_area_struct___7 *);
	int (*open)(struct inode___5 *, struct file___4 *);
	int (*flush)(struct file___4 *, fl_owner_t);
	int (*release)(struct inode___5 *, struct file___4 *);
	int (*fsync)(struct file___4 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___4 *, int);
	int (*lock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*sendpage)(struct file___4 *, struct page___4 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___4 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___4 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___4 *, long int, struct file_lock___4 **, void **);
		struct {
			int (*setlease)(struct file___4 *, long int, struct file_lock___4 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___4 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___4 *, struct file___4 *);
};

struct file_lock_operations___4;

struct lock_manager_operations___4;

struct file_lock___4 {
	struct file_lock___4 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___4 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___4 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___4 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___4 *fl_ops;
	const struct lock_manager_operations___4 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___4 {
	void (*fl_copy_lock)(struct file_lock___4 *, struct file_lock___4 *);
	void (*fl_release_private)(struct file_lock___4 *);
};

struct lock_manager_operations___4 {
	int (*lm_compare_owner)(struct file_lock___4 *, struct file_lock___4 *);
	long unsigned int (*lm_owner_key)(struct file_lock___4 *);
	void (*lm_notify)(struct file_lock___4 *);
	int (*lm_grant)(struct file_lock___4 *, struct file_lock___4 *, int);
	void (*lm_break)(struct file_lock___4 *);
	int (*lm_change)(struct file_lock___4 **, int);
};

struct fasync_struct___4 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___4 *fa_next;
	struct file___4 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___4 {
	const char *name;
	int fs_flags;
	struct dentry___5 * (*mount)(struct file_system_type___4 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___5 *);
	struct module *owner;
	struct file_system_type___4 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___4 {
	struct inode___5 * (*alloc_inode)(struct super_block___5 *);
	void (*destroy_inode)(struct inode___5 *);
	void (*dirty_inode)(struct inode___5 *, int);
	int (*write_inode)(struct inode___5 *, struct writeback_control *);
	int (*drop_inode)(struct inode___5 *);
	void (*evict_inode)(struct inode___5 *);
	void (*put_super)(struct super_block___5 *);
	int (*sync_fs)(struct super_block___5 *, int);
	int (*freeze_fs)(struct super_block___5 *);
	int (*unfreeze_fs)(struct super_block___5 *);
	int (*statfs)(struct dentry___5 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___5 *, int *, char *);
	void (*umount_begin)(struct super_block___5 *);
	int (*show_options)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_devname)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_path)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_stats)(struct seq_file___4 *, struct dentry___5 *);
	ssize_t (*quota_read)(struct super_block___5 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___5 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___5 *);
	int (*bdev_try_to_free_page)(struct super_block___5 *, struct page___4 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___5 *);
	void (*free_cached_objects)(struct super_block___5 *, int);
};

struct xattr_handler___4 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___5 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___5 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___5 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___4)(struct file___4 *, wait_queue_head_t *, struct poll_table_struct___4 *);

struct poll_table_struct___4 {
	poll_queue_proc___4 _qproc;
	long unsigned int _key;
};

struct seq_operations___4;

struct seq_file___4 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___7 lock;
	const struct seq_operations___4 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___4 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___4 *last_lookup;
	struct hd_struct___4 *part[0];
};

struct block_device_operations___4 {
	int (*open)(struct block_device___4 *, fmode_t);
	void (*release)(struct gendisk___4 *, fmode_t);
	int (*ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___4 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___4 *, unsigned int);
	int (*media_changed)(struct gendisk___4 *);
	void (*unlock_native_capacity)(struct gendisk___4 *);
	int (*revalidate_disk)(struct gendisk___4 *);
	int (*getgeo)(struct block_device___4 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___4 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___4 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___4 *page;
};

struct irq_chip___4 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___4 *);
	void (*irq_shutdown)(struct irq_data___4 *);
	void (*irq_enable)(struct irq_data___4 *);
	void (*irq_disable)(struct irq_data___4 *);
	void (*irq_ack)(struct irq_data___4 *);
	void (*irq_mask)(struct irq_data___4 *);
	void (*irq_mask_ack)(struct irq_data___4 *);
	void (*irq_unmask)(struct irq_data___4 *);
	void (*irq_eoi)(struct irq_data___4 *);
	int (*irq_set_affinity)(struct irq_data___4 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___4 *);
	int (*irq_set_type)(struct irq_data___4 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___4 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___4 *);
	void (*irq_bus_sync_unlock)(struct irq_data___4 *);
	void (*irq_cpu_online)(struct irq_data___4 *);
	void (*irq_cpu_offline)(struct irq_data___4 *);
	void (*irq_suspend)(struct irq_data___4 *);
	void (*irq_resume)(struct irq_data___4 *);
	void (*irq_pm_shutdown)(struct irq_data___4 *);
	void (*irq_print_chip)(struct irq_data___4 *, struct seq_file___4 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___4 *, void *);
	long unsigned int flags;
};

struct io_cq___4 {
	struct request_queue___4 *q;
	struct io_context___4 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___4(struct request___4 *, int);

struct request___4 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___4 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___4 *bio;
	struct bio___4 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___4 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___4 *saved_end_io;
		} flush;
	};
	struct gendisk___4 *rq_disk;
	struct hd_struct___4 *part;
	long unsigned int start_time;
	struct request_list___4 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___4 *end_io;
	void *end_io_data;
	struct request___4 *next_rq;
};

typedef int elevator_merge_fn___4(struct request_queue___4 *, struct request___4 **, struct bio___4 *);

typedef void elevator_merge_req_fn___4(struct request_queue___4 *, struct request___4 *, struct request___4 *);

typedef void elevator_merged_fn___4(struct request_queue___4 *, struct request___4 *, int);

typedef int elevator_allow_merge_fn___4(struct request_queue___4 *, struct request___4 *, struct bio___4 *);

typedef void elevator_bio_merged_fn___4(struct request_queue___4 *, struct request___4 *, struct bio___4 *);

typedef int elevator_dispatch_fn___4(struct request_queue___4 *, int);

typedef void elevator_add_req_fn___4(struct request_queue___4 *, struct request___4 *);

typedef struct request___4 *elevator_request_list_fn___4(struct request_queue___4 *, struct request___4 *);

typedef void elevator_completed_req_fn___4(struct request_queue___4 *, struct request___4 *);

typedef int elevator_may_queue_fn___4(struct request_queue___4 *, int);

typedef void elevator_init_icq_fn___4(struct io_cq___4 *);

typedef void elevator_exit_icq_fn___4(struct io_cq___4 *);

typedef int elevator_set_req_fn___4(struct request_queue___4 *, struct request___4 *, struct bio___4 *, gfp_t);

typedef void elevator_put_req_fn___4(struct request___4 *);

typedef void elevator_activate_req_fn___4(struct request_queue___4 *, struct request___4 *);

typedef void elevator_deactivate_req_fn___4(struct request_queue___4 *, struct request___4 *);

struct elevator_type___4;

typedef int elevator_init_fn___4(struct request_queue___4 *, struct elevator_type___4 *);

typedef void elevator_exit_fn___4(struct elevator_queue___4 *);

struct elevator_ops___4 {
	elevator_merge_fn___4 *elevator_merge_fn;
	elevator_merged_fn___4 *elevator_merged_fn;
	elevator_merge_req_fn___4 *elevator_merge_req_fn;
	elevator_allow_merge_fn___4 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___4 *elevator_bio_merged_fn;
	elevator_dispatch_fn___4 *elevator_dispatch_fn;
	elevator_add_req_fn___4 *elevator_add_req_fn;
	elevator_activate_req_fn___4 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___4 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___4 *elevator_completed_req_fn;
	elevator_request_list_fn___4 *elevator_former_req_fn;
	elevator_request_list_fn___4 *elevator_latter_req_fn;
	elevator_init_icq_fn___4 *elevator_init_icq_fn;
	elevator_exit_icq_fn___4 *elevator_exit_icq_fn;
	elevator_set_req_fn___4 *elevator_set_req_fn;
	elevator_put_req_fn___4 *elevator_put_req_fn;
	elevator_may_queue_fn___4 *elevator_may_queue_fn;
	elevator_init_fn___4 *elevator_init_fn;
	elevator_exit_fn___4 *elevator_exit_fn;
};

struct elv_fs_entry___4;

struct elevator_type___4 {
	struct kmem_cache___4 *icq_cache;
	struct elevator_ops___4 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___4 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___4 {
	struct elevator_type___4 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___7 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___4 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___4 *, char *);
	ssize_t (*store)(struct elevator_queue___4 *, const char *, size_t);
};

struct bvec_merge_data___4 {
	struct block_device___4 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___4 {
	struct request___4 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___4 {
	void * (*start)(struct seq_file___4 *, loff_t *);
	void (*stop)(struct seq_file___4 *, void *);
	void * (*next)(struct seq_file___4 *, void *, loff_t *);
	int (*show)(struct seq_file___4 *, void *);
};

struct cgroupfs_root___4;

struct cgroup___4 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___4 *parent;
	struct dentry___5 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___4 *subsys[11];
	struct cgroupfs_root___4 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___7 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___4 {
	struct super_block___5 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___4 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___4;

struct pmu___4 {
	struct list_head entry;
	struct device___4 *dev;
	const struct attribute_group___4 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___4 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___4 *);
	void (*pmu_disable)(struct pmu___4 *);
	int (*event_init)(struct perf_event___4 *);
	int (*add)(struct perf_event___4 *, int);
	void (*del)(struct perf_event___4 *, int);
	void (*start)(struct perf_event___4 *, int);
	void (*stop)(struct perf_event___4 *, int);
	void (*read)(struct perf_event___4 *);
	void (*start_txn)(struct pmu___4 *);
	int (*commit_txn)(struct pmu___4 *);
	void (*cancel_txn)(struct pmu___4 *);
	int (*event_idx)(struct perf_event___4 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___4 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___4 *);
};

struct perf_cpu_context___4 {
	struct perf_event_context___4 ctx;
	struct perf_event_context___4 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___4 *unique_pmu;
	struct perf_cgroup___4 *cgrp;
};

struct trace_event_functions___4;

struct trace_event___4 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___4 *funcs;
};

struct ftrace_event_class___4;

struct ftrace_event_call___4 {
	struct list_head list;
	struct ftrace_event_class___4 *class;
	char *name;
	struct trace_event___4 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___4 {
	struct cgroup_subsys_state___4 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___4 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___7 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___4)(struct trace_iterator___4 *, int, struct trace_event___4 *);

struct trace_event_functions___4 {
	trace_print_func___4 trace;
	trace_print_func___4 raw;
	trace_print_func___4 hex;
	trace_print_func___4 binary;
};

struct ftrace_event_class___4 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___4 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___4 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___4 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___4 *);
};

struct hash {
	int ino;
	int minor;
	int major;
	umode_t mode;
	struct hash *next;
	char name[4098];
};

struct dir_entry {
	struct list_head list;
	char *name;
	time_t mtime;
};

enum state {
	Start = 0,
	Collect = 1,
	GotHeader = 2,
	SkipIt = 3,
	GotName = 4,
	CopyFile = 5,
	GotSymlink = 6,
	Reset = 7,
};

typedef int (*decompress_fn)(unsigned char *, int, int (*)(void *, unsigned int), int (*)(void *, unsigned int), unsigned char *, int *, void (*)(char *));

struct page___5;

typedef struct page___5 *pgtable_t___5;

struct address_space___5;

struct kmem_cache___5;

struct page___5 {
	long unsigned int flags;
	struct address_space___5 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___5 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___5 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___5 *slab_cache;
		struct page___5 *first_page;
	};
	long: 64;
};

struct task_struct___8;

struct pv_cpu_ops___7 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___4 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___4 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___8 *);
	void (*end_context_switch)(struct task_struct___8 *);
};

struct pid___5;

struct pid_link___5 {
	struct hlist_node node;
	struct pid___5 *pid;
};

struct mutex___8 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___8 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___5 {
	struct page___5 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___8;

struct nsproxy___5;

struct signal_struct___7;

struct task_struct___8 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___8 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___8 *mm;
	struct mm_struct___8 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___8 *real_parent;
	struct task_struct___8 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___8 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___5 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___7 = 0,
		VTIME_USER___7 = 1,
		VTIME_SYS___7 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___4 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___5 *nsproxy;
	struct signal_struct___7 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___8 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___5 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___8 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___8 *, struct mm_struct___8 *);
	void (*dup_mmap)(struct mm_struct___8 *, struct mm_struct___8 *);
	void (*exit_mmap)(struct mm_struct___8 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___8 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___8 *);
	void (*pgd_free)(struct mm_struct___8 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___8 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___8 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___8 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___8 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___8 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___8 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___8 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___8 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___8 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___8 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___8 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___8 lock;
	void *vdso;
} mm_context_t___8;

struct xol_area___5;

struct uprobes_state___5 {
	struct xol_area___5 *xol_area;
};

struct vm_area_struct___8;

struct file___5;

struct core_state___7;

struct mm_struct___8 {
	struct vm_area_struct___8 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___8 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___8 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___8 context;
	long unsigned int flags;
	struct core_state___7 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___8 *owner;
	struct file___5 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___5 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___2 {
	struct task_struct___8 *task;
	struct exec_domain *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___5 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___5 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___5;

struct memcg_cache_params___5;

struct kmem_cache___5 {
	struct kmem_cache_cpu___5 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___5 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___6;

struct address_space_operations___5;

struct address_space___5 {
	struct inode___6 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___8 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___5 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___6;

struct path___5 {
	struct vfsmount *mnt;
	struct dentry___6 *dentry;
};

struct fown_struct___5 {
	rwlock_t lock;
	struct pid___5 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___5;

struct file___5 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___5 f_path;
	struct inode___6 *f_inode;
	const struct file_operations___5 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___5 *f_mapping;
	struct mutex___8 f_pos_lock;
};

struct vm_operations_struct___7;

struct vm_area_struct___8 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___8 *vm_next;
	struct vm_area_struct___8 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___8 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___7 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___5 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___5;

struct vm_operations_struct___7 {
	void (*open)(struct vm_area_struct___8 *);
	void (*close)(struct vm_area_struct___8 *);
	int (*fault)(struct vm_area_struct___8 *, struct vm_fault___5 *);
	int (*page_mkwrite)(struct vm_area_struct___8 *, struct vm_fault___5 *);
	int (*access)(struct vm_area_struct___8 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___8 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___8 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___8 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___8 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___7 {
	struct task_struct___8 *task;
	struct core_thread___7 *next;
};

struct core_state___7 {
	atomic_t nr_threads;
	struct core_thread___7 dumper;
	struct completion startup;
};

struct irq_data___5;

struct x86_io_apic_ops___5 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___5 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___5;

struct irq_data___5 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___5 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___5;

struct dev_pm_ops___5 {
	int (*prepare)(struct device___5 *);
	void (*complete)(struct device___5 *);
	int (*suspend)(struct device___5 *);
	int (*resume)(struct device___5 *);
	int (*freeze)(struct device___5 *);
	int (*thaw)(struct device___5 *);
	int (*poweroff)(struct device___5 *);
	int (*restore)(struct device___5 *);
	int (*suspend_late)(struct device___5 *);
	int (*resume_early)(struct device___5 *);
	int (*freeze_late)(struct device___5 *);
	int (*thaw_early)(struct device___5 *);
	int (*poweroff_late)(struct device___5 *);
	int (*restore_early)(struct device___5 *);
	int (*suspend_noirq)(struct device___5 *);
	int (*resume_noirq)(struct device___5 *);
	int (*freeze_noirq)(struct device___5 *);
	int (*thaw_noirq)(struct device___5 *);
	int (*poweroff_noirq)(struct device___5 *);
	int (*restore_noirq)(struct device___5 *);
	int (*runtime_suspend)(struct device___5 *);
	int (*runtime_resume)(struct device___5 *);
	int (*runtime_idle)(struct device___5 *);
};

struct dma_map_ops___2;

struct dev_archdata___2 {
	struct dma_map_ops___2 *dma_ops;
	void *iommu;
};

struct acpi_dev_node___3 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct device_type___5;

struct bus_type___5;

struct device_driver___5;

struct dev_pm_domain___5;

struct class___5;

struct attribute_group___5;

struct device_rh___5;

struct device___5 {
	struct device___5 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___5 *type;
	struct mutex___8 mutex;
	struct bus_type___5 *bus;
	struct device_driver___5 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___5 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___2 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___5 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___5 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___5 *device_rh;
};

struct dev_pm_info_rh___5 {
	void (*set_latency_tolerance)(struct device___5 *, s32);
};

struct dev_pm_domain___5 {
	struct dev_pm_ops___5 ops;
};

struct smp_ops___7 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___8 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___5;

struct upid___5 {
	int nr;
	struct pid_namespace___5 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___5 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___8 *child_reaper;
	struct kmem_cache___5 *pid_cachep;
	unsigned int level;
	struct pid_namespace___5 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___6 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___5 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___5 numbers[1];
};

struct zone___7;

struct lruvec___7 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___7 *zone;
};

struct pglist_data___7;

struct zone___7 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___7 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___7 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___7 {
	struct zone___7 *zone;
	int zone_idx;
};

struct zonelist___7 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___7 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___7 {
	struct zone___7 node_zones[4];
	struct zonelist___7 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___8 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___2;

struct ctl_node___2 {
	struct rb_node node;
	struct ctl_table_header___2 *header;
};

struct ctl_table_root___2;

struct ctl_table_set___2;

struct ctl_dir___2;

struct ctl_table_header___2 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___2 *root;
	struct ctl_table_set___2 *set;
	struct ctl_dir___2 *parent;
	struct ctl_node___2 *node;
};

struct ctl_dir___2 {
	struct ctl_table_header___2 header;
	struct rb_root root;
};

struct ctl_table_set___2 {
	int (*is_seen)(struct ctl_table_set___2 *);
	struct ctl_dir___2 dir;
};

struct ctl_table_root___2 {
	struct ctl_table_set___2 default_set;
	struct ctl_table_set___2 * (*lookup)(struct ctl_table_root___2 *, struct nsproxy___5 *);
	int (*permissions)(struct ctl_table_header___2 *, struct ctl_table *);
};

struct net___3;

struct nsproxy___5 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___5 *pid_ns;
	struct net___3 *net_ns;
};

struct uid_gid_extent {
	u32 first;
	u32 lower_first;
	u32 count;
};

struct uid_gid_map {
	u32 nr_extents;
	struct uid_gid_extent extent[5];
};

struct user_namespace {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace *parent;
	kuid_t owner;
	kgid_t group;
	unsigned int proc_inum;
	bool may_mount_sysfs;
	bool may_mount_proc;
	struct key *persistent_keyring_register;
	struct rw_semaphore persistent_keyring_register_sem;
	int level;
	long unsigned int flags;
};

struct signal_struct___7 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___8 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___8 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___5 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___8 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union {
	struct thread_info___2 thread_info;
	long unsigned int stack[2048];
};

struct netns_core___2 {
	struct ctl_table_header___2 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___2 {
	struct mutex___8 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___2 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___2 *ctl;
};

struct netns_ipv4___2 {
	struct ctl_table_header___2 *forw_hdr;
	struct ctl_table_header___2 *frags_hdr;
	struct ctl_table_header___2 *ipv4_hdr;
	struct ctl_table_header___2 *route_hdr;
	struct ctl_table_header___2 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___2 {
	struct ctl_table_header___2 *hdr;
	struct ctl_table_header___2 *route_hdr;
	struct ctl_table_header___2 *icmp_hdr;
	struct ctl_table_header___2 *frags_hdr;
	struct ctl_table_header___2 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_entry___2;

struct neighbour___2;

struct dst_ops___2 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___2 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff *);
	int (*local_out)(struct sk_buff *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff *, const void *);
	struct kmem_cache___5 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___2 {
	struct netns_sysctl_ipv6___2 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___2 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___2 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___2 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___2 *nf_log_dir_header;
};

struct nf_proto_net___2 {
	struct ctl_table_header___2 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___2 {
	struct nf_proto_net___2 pn;
	unsigned int timeout;
};

struct nf_tcp_net___2 {
	struct nf_proto_net___2 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___2 {
	struct nf_proto_net___2 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___2 {
	struct nf_proto_net___2 pn;
	unsigned int timeout;
};

struct nf_ip_net___2 {
	struct nf_generic_net___2 generic;
	struct nf_tcp_net___2 tcp;
	struct nf_udp_net___2 udp;
	struct nf_icmp_net___2 icmp;
	struct nf_icmp_net___2 icmpv6;
};

struct netns_ct___2 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___2 *sysctl_header;
	struct ctl_table_header___2 *acct_sysctl_header;
	struct ctl_table_header___2 *tstamp_sysctl_header;
	struct ctl_table_header___2 *event_sysctl_header;
	struct ctl_table_header___2 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___5 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___2 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___2 {
	struct netns_sysctl_ipv6___2 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___2 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___2 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 xfrm4_dst_ops;
	struct dst_ops___2 xfrm6_dst_ops;
};

struct net___3 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___2 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___2 core;
	struct netns_mib mib;
	struct netns_packet___2 packet;
	struct netns_unix___2 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___2 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_dccp dccp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct___2 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___2 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___2 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___8 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___8 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___5;

struct super_block___6;

struct dentry___6 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___6 *d_parent;
	struct qstr d_name;
	struct inode___6 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___5 *d_op;
	struct super_block___6 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___5;

struct file_lock___5;

struct dquot___5;

struct block_device___5;

struct inode___6 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___5 *i_op;
	struct super_block___6 *i_sb;
	struct address_space___5 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___8 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___5 *i_fop;
	struct file_lock___5 *i_flock;
	struct address_space___5 i_data;
	struct dquot___5 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___5 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___5 {
	int (*d_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_hash)(const struct dentry___6 *, struct qstr *);
	int (*d_compare)(const struct dentry___6 *, const struct dentry___6 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___6 *);
	void (*d_release)(struct dentry___6 *);
	void (*d_prune)(struct dentry___6 *);
	void (*d_iput)(struct dentry___6 *, struct inode___6 *);
	char * (*d_dname)(struct dentry___6 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___5 *);
	int (*d_manage)(struct dentry___6 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___5;

struct mem_dqinfo___5 {
	struct quota_format_type___5 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___5;

struct quota_info___5 {
	unsigned int flags;
	struct mutex___8 dqio_mutex;
	struct mutex___8 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___6 *files[2];
	struct mem_dqinfo___5 info[2];
	const struct quota_format_ops___5 *ops[2];
};

struct file_system_type___5;

struct super_operations___5;

struct dquot_operations___5;

struct quotactl_ops___5;

struct super_block___6 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___5 *s_type;
	const struct super_operations___5 *s_op;
	const struct dquot_operations___5 *dq_op;
	const struct quotactl_ops___5 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___6 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___5 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___5 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___8 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___5 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___5 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___6 *bd_inode;
	struct super_block___6 *bd_super;
	struct mutex___8 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___5 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___8 bd_fsfreeze_mutex;
};

struct iattr___6 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___5 *ia_file;
};

struct dquot___5 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___8 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___6 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___5 {
	int qf_fmt_id;
	const struct quota_format_ops___5 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___5 *qf_next;
};

struct quota_format_ops___5 {
	int (*check_quota_file)(struct super_block___6 *, int);
	int (*read_file_info)(struct super_block___6 *, int);
	int (*write_file_info)(struct super_block___6 *, int);
	int (*free_file_info)(struct super_block___6 *, int);
	int (*read_dqblk)(struct dquot___5 *);
	int (*commit_dqblk)(struct dquot___5 *);
	int (*release_dqblk)(struct dquot___5 *);
};

struct dquot_operations___5 {
	int (*write_dquot)(struct dquot___5 *);
	struct dquot___5 * (*alloc_dquot)(struct super_block___6 *, int);
	void (*destroy_dquot)(struct dquot___5 *);
	int (*acquire_dquot)(struct dquot___5 *);
	int (*release_dquot)(struct dquot___5 *);
	int (*mark_dirty)(struct dquot___5 *);
	int (*write_info)(struct super_block___6 *, int);
	qsize_t * (*get_reserved_space)(struct inode___6 *);
};

struct quotactl_ops___5 {
	int (*quota_on)(struct super_block___6 *, int, int, struct path___5 *);
	int (*quota_on_meta)(struct super_block___6 *, int, int);
	int (*quota_off)(struct super_block___6 *, int);
	int (*quota_sync)(struct super_block___6 *, int);
	int (*get_info)(struct super_block___6 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___6 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___6 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___6 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___6 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___6 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___6 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___6 *, unsigned int);
};

struct address_space_operations___5 {
	int (*writepage)(struct page___5 *, struct writeback_control *);
	int (*readpage)(struct file___5 *, struct page___5 *);
	int (*writepages)(struct address_space___5 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___5 *);
	int (*readpages)(struct file___5 *, struct address_space___5 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___5 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___5 **, void **);
	int (*write_end)(struct file___5 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___5 *, void *);
	sector_t (*bmap)(struct address_space___5 *, sector_t);
	void (*invalidatepage)(struct page___5 *, long unsigned int);
	int (*releasepage)(struct page___5 *, gfp_t);
	void (*freepage)(struct page___5 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___5 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___5 *, struct page___5 *, struct page___5 *, enum migrate_mode);
	int (*launder_page)(struct page___5 *);
	int (*is_partially_uptodate)(struct page___5 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___5 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___5 *, struct page___5 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___5 *, sector_t *);
	void (*swap_deactivate)(struct file___5 *);
	void (*invalidatepage_range)(struct page___5 *, unsigned int, unsigned int);
};

struct inode_operations___5 {
	struct dentry___6 * (*lookup)(struct inode___6 *, struct dentry___6 *, unsigned int);
	void * (*follow_link)(struct dentry___6 *, struct nameidata *);
	int (*permission)(struct inode___6 *, int);
	struct posix_acl * (*get_acl)(struct inode___6 *, int);
	int (*readlink)(struct dentry___6 *, char *, int);
	void (*put_link)(struct dentry___6 *, struct nameidata *, void *);
	int (*create)(struct inode___6 *, struct dentry___6 *, umode_t, bool);
	int (*link)(struct dentry___6 *, struct inode___6 *, struct dentry___6 *);
	int (*unlink)(struct inode___6 *, struct dentry___6 *);
	int (*symlink)(struct inode___6 *, struct dentry___6 *, const char *);
	int (*mkdir)(struct inode___6 *, struct dentry___6 *, umode_t);
	int (*rmdir)(struct inode___6 *, struct dentry___6 *);
	int (*mknod)(struct inode___6 *, struct dentry___6 *, umode_t, dev_t);
	int (*rename)(struct inode___6 *, struct dentry___6 *, struct inode___6 *, struct dentry___6 *);
	int (*setattr)(struct dentry___6 *, struct iattr___6 *);
	int (*getattr)(struct vfsmount *, struct dentry___6 *, struct kstat *);
	int (*setxattr)(struct dentry___6 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___6 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___6 *, char *, size_t);
	int (*removexattr)(struct dentry___6 *, const char *);
	int (*fiemap)(struct inode___6 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___6 *, struct timespec *, int);
	int (*atomic_open)(struct inode___6 *, struct dentry___6 *, struct file___5 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___5;

struct file_operations___5 {
	struct module *owner;
	loff_t (*llseek)(struct file___5 *, loff_t, int);
	ssize_t (*read)(struct file___5 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___5 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___5 *, void *, filldir_t);
	unsigned int (*poll)(struct file___5 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___5 *, struct vm_area_struct___8 *);
	int (*open)(struct inode___6 *, struct file___5 *);
	int (*flush)(struct file___5 *, fl_owner_t);
	int (*release)(struct inode___6 *, struct file___5 *);
	int (*fsync)(struct file___5 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___5 *, int);
	int (*lock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*sendpage)(struct file___5 *, struct page___5 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___5 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___5 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___5 *, long int, struct file_lock___5 **, void **);
		struct {
			int (*setlease)(struct file___5 *, long int, struct file_lock___5 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___5 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___5 *);
};

struct fasync_struct___5;

struct file_lock_operations___5;

struct lock_manager_operations___5;

struct file_lock___5 {
	struct file_lock___5 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___5 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___5 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___5 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___5 *fl_ops;
	const struct lock_manager_operations___5 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___5 {
	void (*fl_copy_lock)(struct file_lock___5 *, struct file_lock___5 *);
	void (*fl_release_private)(struct file_lock___5 *);
};

struct lock_manager_operations___5 {
	int (*lm_compare_owner)(struct file_lock___5 *, struct file_lock___5 *);
	long unsigned int (*lm_owner_key)(struct file_lock___5 *);
	void (*lm_notify)(struct file_lock___5 *);
	int (*lm_grant)(struct file_lock___5 *, struct file_lock___5 *, int);
	void (*lm_break)(struct file_lock___5 *);
	int (*lm_change)(struct file_lock___5 **, int);
};

struct fasync_struct___5 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___5 *fa_next;
	struct file___5 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___5 {
	const char *name;
	int fs_flags;
	struct dentry___6 * (*mount)(struct file_system_type___5 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___6 *);
	struct module *owner;
	struct file_system_type___5 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___5 {
	struct inode___6 * (*alloc_inode)(struct super_block___6 *);
	void (*destroy_inode)(struct inode___6 *);
	void (*dirty_inode)(struct inode___6 *, int);
	int (*write_inode)(struct inode___6 *, struct writeback_control *);
	int (*drop_inode)(struct inode___6 *);
	void (*evict_inode)(struct inode___6 *);
	void (*put_super)(struct super_block___6 *);
	int (*sync_fs)(struct super_block___6 *, int);
	int (*freeze_fs)(struct super_block___6 *);
	int (*unfreeze_fs)(struct super_block___6 *);
	int (*statfs)(struct dentry___6 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___6 *, int *, char *);
	void (*umount_begin)(struct super_block___6 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___6 *);
	ssize_t (*quota_read)(struct super_block___6 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___6 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___6 *);
	int (*bdev_try_to_free_page)(struct super_block___6 *, struct page___5 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___6 *);
	void (*free_cached_objects)(struct super_block___6 *, int);
};

struct seq_operations___5;

struct seq_file___5 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___8 lock;
	const struct seq_operations___5 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___5 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___5 *page;
};

struct net_device___4;

struct dst_ops___3;

struct sk_buff___3;

struct sock___3;

struct dst_entry___2 {
	struct callback_head callback_head;
	struct dst_entry___2 *child;
	struct net_device___4 *dev;
	struct dst_ops___3 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___2 *path;
	struct dst_entry___2 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___3 *);
	union {
		int (*output)(struct sock___3 *, struct sk_buff___3 *);
		struct {
			int (*output)(struct sk_buff___3 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___2 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct bin_attribute___5;

struct attribute_group___5 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___5 **bin_attrs;
};

struct bin_attribute___5 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___5 *, struct kobject *, struct bin_attribute___5 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___5 *, struct kobject *, struct bin_attribute___5 *, char *, loff_t, size_t);
	int (*mmap)(struct file___5 *, struct kobject *, struct bin_attribute___5 *, struct vm_area_struct___8 *);
};

struct kmem_cache_cpu___5 {
	void **freelist;
	long unsigned int tid;
	struct page___5 *page;
	struct page___5 *partial;
};

struct memcg_cache_params___5 {
	bool is_root_cache;
	union {
		struct kmem_cache___5 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___5 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___2 {
	void * (*alloc)(struct device___5 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___5 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___5 *, struct vm_area_struct___8 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___5 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___5 *, struct page___5 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___5 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___5 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___5 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___5 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___5 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___5 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___5 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___5 *, dma_addr_t);
	int (*dma_supported)(struct device___5 *, u64);
	int (*set_dma_mask)(struct device___5 *, u64);
	int is_phys;
};

struct bus_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___5 *, char *);
	ssize_t (*store)(struct bus_type___5 *, const char *, size_t);
};

struct device_attribute___5;

struct driver_attribute___5;

struct bus_type___5 {
	const char *name;
	const char *dev_name;
	struct device___5 *dev_root;
	struct bus_attribute___5 *bus_attrs;
	struct device_attribute___5 *dev_attrs;
	struct driver_attribute___5 *drv_attrs;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___5 *, struct device_driver___5 *);
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	int (*probe)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*online)(struct device___5 *);
	int (*offline)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct dev_pm_ops___5 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device___5 *, struct device_attribute___5 *, char *);
	ssize_t (*store)(struct device___5 *, struct device_attribute___5 *, const char *, size_t);
};

struct driver_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___5 *, char *);
	ssize_t (*store)(struct device_driver___5 *, const char *, size_t);
};

struct device_driver___5 {
	const char *name;
	struct bus_type___5 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct attribute_group___5 **groups;
	const struct dev_pm_ops___5 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___5 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___5 *);
	const struct dev_pm_ops___5 *pm;
};

struct class_attribute___5;

struct class___5 {
	const char *name;
	struct module *owner;
	struct class_attribute___5 *class_attrs;
	struct device_attribute___5 *dev_attrs;
	const struct attribute_group___5 **dev_groups;
	struct bin_attribute___5 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *);
	void (*class_release)(struct class___5 *);
	void (*dev_release)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___5 *);
	const struct dev_pm_ops___5 *pm;
	struct subsys_private *p;
};

struct class_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct class___5 *, struct class_attribute___5 *, char *);
	ssize_t (*store)(struct class___5 *, struct class_attribute___5 *, const char *, size_t);
	const void * (*namespace)(struct class___5 *, const struct class_attribute___5 *);
};

struct device_rh___5 {
	struct dev_pm_info_rh___5 power;
};

enum dma_transaction_type {
	DMA_MEMCPY = 0,
	DMA_XOR = 1,
	DMA_PQ = 2,
	DMA_XOR_VAL = 3,
	DMA_PQ_VAL = 4,
	DMA_MEMSET = 5,
	DMA_INTERRUPT = 6,
	DMA_SG = 7,
	DMA_PRIVATE = 8,
	DMA_ASYNC_TX = 9,
	DMA_SLAVE = 10,
	DMA_CYCLIC = 11,
	DMA_INTERLEAVE = 12,
	DMA_TX_TYPE_END = 13,
};

enum sum_check_bits {
	SUM_CHECK_P = 0,
	SUM_CHECK_Q = 1,
};

enum dma_attr {
	DMA_ATTR_WRITE_BARRIER = 0,
	DMA_ATTR_WEAK_ORDERING = 1,
	DMA_ATTR_WRITE_COMBINE = 2,
	DMA_ATTR_NON_CONSISTENT = 3,
	DMA_ATTR_NO_KERNEL_MAPPING = 4,
	DMA_ATTR_SKIP_CPU_SYNC = 5,
	DMA_ATTR_FORCE_CONTIGUOUS = 6,
	DMA_ATTR_MAX = 7,
};

struct nf_afinfo___2 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___3 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___5 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___5 *);
	void (*irq_shutdown)(struct irq_data___5 *);
	void (*irq_enable)(struct irq_data___5 *);
	void (*irq_disable)(struct irq_data___5 *);
	void (*irq_ack)(struct irq_data___5 *);
	void (*irq_mask)(struct irq_data___5 *);
	void (*irq_mask_ack)(struct irq_data___5 *);
	void (*irq_unmask)(struct irq_data___5 *);
	void (*irq_eoi)(struct irq_data___5 *);
	int (*irq_set_affinity)(struct irq_data___5 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___5 *);
	int (*irq_set_type)(struct irq_data___5 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___5 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___5 *);
	void (*irq_bus_sync_unlock)(struct irq_data___5 *);
	void (*irq_cpu_online)(struct irq_data___5 *);
	void (*irq_cpu_offline)(struct irq_data___5 *);
	void (*irq_suspend)(struct irq_data___5 *);
	void (*irq_resume)(struct irq_data___5 *);
	void (*irq_pm_shutdown)(struct irq_data___5 *);
	void (*irq_print_chip)(struct irq_data___5 *, struct seq_file___5 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___5 *, void *);
	long unsigned int flags;
};

struct seq_operations___5 {
	void * (*start)(struct seq_file___5 *, loff_t *);
	void (*stop)(struct seq_file___5 *, void *);
	void * (*next)(struct seq_file___5 *, void *, loff_t *);
	int (*show)(struct seq_file___5 *, void *);
};

typedef __s8 int8_t;

typedef __u8 uint8_t;

typedef __u16 uint16_t;

typedef __u64 uint64_t;

enum {
	DESC_TSS = 9,
	DESC_LDT = 2,
	DESCTYPE_S = 16,
};

struct page___6;

typedef struct page___6 *pgtable_t___6;

struct address_space___6;

struct kmem_cache___6;

struct page___6 {
	long unsigned int flags;
	struct address_space___6 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___6 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___6 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___6 *slab_cache;
		struct page___6 *first_page;
	};
	long: 64;
};

struct pv_init_ops {
	unsigned int (*patch)(u8, u16, void *, long unsigned int, unsigned int);
};

struct task_struct___9;

struct pv_cpu_ops___8 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___4 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___4 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___9 *);
	void (*end_context_switch)(struct task_struct___9 *);
};

struct mutex___9 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___9 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___6 {
	struct page___6 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___9;

struct signal_struct___8;

struct task_struct___9 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___9 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___9 *mm;
	struct mm_struct___9 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___9 *real_parent;
	struct task_struct___9 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___9 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___5 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___8 = 0,
		VTIME_USER___8 = 1,
		VTIME_SYS___8 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___4 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___8 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___9 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___6 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___9 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___9 *, struct mm_struct___9 *);
	void (*dup_mmap)(struct mm_struct___9 *, struct mm_struct___9 *);
	void (*exit_mmap)(struct mm_struct___9 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___9 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___9 *);
	void (*pgd_free)(struct mm_struct___9 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___9 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___9 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___9 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___9 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___9 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___9 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___9 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___9 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___9 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___9 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___9 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___9 lock;
	void *vdso;
} mm_context_t___9;

struct xol_area___6;

struct uprobes_state___6 {
	struct xol_area___6 *xol_area;
};

struct vm_area_struct___9;

struct file___6;

struct core_state___8;

struct mm_struct___9 {
	struct vm_area_struct___9 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___9 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___9 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___9 context;
	long unsigned int flags;
	struct core_state___8 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___9 *owner;
	struct file___6 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___6 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

enum paravirt_lazy_mode {
	PARAVIRT_LAZY_NONE = 0,
	PARAVIRT_LAZY_MMU = 1,
	PARAVIRT_LAZY_CPU = 2,
};

struct module___4;

struct module_kobject___3 {
	struct kobject kobj;
	struct module___4 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___3;

struct module___4 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___3 mkobj;
	struct module_attribute___3 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___9 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct bin_attribute___6;

struct attribute_group___6 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___6 **bin_attrs;
};

struct bin_attribute___6 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___6 *, struct kobject *, struct bin_attribute___6 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___6 *, struct kobject *, struct bin_attribute___6 *, char *, loff_t, size_t);
	int (*mmap)(struct file___6 *, struct kobject *, struct bin_attribute___6 *, struct vm_area_struct___9 *);
};

struct dentry___7;

struct path___6 {
	struct vfsmount *mnt;
	struct dentry___7 *dentry;
};

struct inode___7;

struct file_operations___6;

struct file___6 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___6 f_path;
	struct inode___7 *f_inode;
	const struct file_operations___6 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___6 *f_mapping;
	struct mutex___9 f_pos_lock;
};

struct vm_operations_struct___8;

struct vm_area_struct___9 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___9 *vm_next;
	struct vm_area_struct___9 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___9 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___6 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___6;

struct dev_pm_ops___6 {
	int (*prepare)(struct device___6 *);
	void (*complete)(struct device___6 *);
	int (*suspend)(struct device___6 *);
	int (*resume)(struct device___6 *);
	int (*freeze)(struct device___6 *);
	int (*thaw)(struct device___6 *);
	int (*poweroff)(struct device___6 *);
	int (*restore)(struct device___6 *);
	int (*suspend_late)(struct device___6 *);
	int (*resume_early)(struct device___6 *);
	int (*freeze_late)(struct device___6 *);
	int (*thaw_early)(struct device___6 *);
	int (*poweroff_late)(struct device___6 *);
	int (*restore_early)(struct device___6 *);
	int (*suspend_noirq)(struct device___6 *);
	int (*resume_noirq)(struct device___6 *);
	int (*freeze_noirq)(struct device___6 *);
	int (*thaw_noirq)(struct device___6 *);
	int (*poweroff_noirq)(struct device___6 *);
	int (*restore_noirq)(struct device___6 *);
	int (*runtime_suspend)(struct device___6 *);
	int (*runtime_resume)(struct device___6 *);
	int (*runtime_idle)(struct device___6 *);
};

struct dma_map_ops___3;

struct dev_archdata___3 {
	struct dma_map_ops___3 *dma_ops;
	void *iommu;
};

struct acpi_device___2;

struct acpi_dev_node___4 {
	union {
		struct acpi_device___2 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___6;

struct bus_type___6;

struct device_driver___6;

struct dev_pm_domain___6;

struct class___6;

struct device_rh___6;

struct device___6 {
	struct device___6 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___6 *type;
	struct mutex___9 mutex;
	struct bus_type___6 *bus;
	struct device_driver___6 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___6 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___3 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___6 *class;
	const struct attribute_group___6 **groups;
	void (*release)(struct device___6 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___6 *device_rh;
};

struct dev_pm_info_rh___6 {
	void (*set_latency_tolerance)(struct device___6 *, s32);
};

struct dev_pm_domain___6 {
	struct dev_pm_ops___6 ops;
};

struct zone___8;

struct lruvec___8 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___8 *zone;
};

struct pglist_data___8;

struct zone___8 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___8 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___8 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___8 {
	struct zone___8 *zone;
	int zone_idx;
};

struct zonelist___8 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___8 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___8 {
	struct zone___8 node_zones[4];
	struct zonelist___8 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___9 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct atomic_notifier_head {
	spinlock_t lock;
	struct notifier_block *head;
};

typedef int pci_power_t;

typedef unsigned int pci_channel_state_t;

typedef short unsigned int pci_dev_flags_t;

struct pci_bus;

struct pci_slot;

struct pci_driver;

struct pcie_link_state;

struct pci_vpd;

struct pci_sriov;

struct pci_ats;

struct pci_dev_rh;

struct pci_dev {
	struct list_head bus_list;
	struct pci_bus *bus;
	struct pci_bus *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___6 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___6 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___6 *res_attr[17];
	struct bin_attribute___6 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___6 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

enum xen_domain_type {
	XEN_NATIVE = 0,
	XEN_PV_DOMAIN = 1,
	XEN_HVM_DOMAIN = 2,
};

struct pvclock_vcpu_time_info {
	u32 version;
	u32 pad0;
	u64 tsc_timestamp;
	u64 system_time;
	u32 tsc_to_system_mul;
	s8 tsc_shift;
	u8 flags;
	u8 pad[2];
};

struct pvclock_wall_clock {
	u32 version;
	u32 sec;
	u32 nsec;
};

struct smp_ops___8 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___9 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___3 {
	void * (*alloc)(struct device___6 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___6 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___6 *, struct vm_area_struct___9 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___6 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___6 *, struct page___6 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___6 *, dma_addr_t);
	int (*dma_supported)(struct device___6 *, u64);
	int (*set_dma_mask)(struct device___6 *, u64);
	int is_phys;
};

struct bus_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___6 *, char *);
	ssize_t (*store)(struct bus_type___6 *, const char *, size_t);
};

struct device_attribute___6;

struct driver_attribute___6;

struct bus_type___6 {
	const char *name;
	const char *dev_name;
	struct device___6 *dev_root;
	struct bus_attribute___6 *bus_attrs;
	struct device_attribute___6 *dev_attrs;
	struct driver_attribute___6 *drv_attrs;
	const struct attribute_group___6 **bus_groups;
	const struct attribute_group___6 **dev_groups;
	const struct attribute_group___6 **drv_groups;
	int (*match)(struct device___6 *, struct device_driver___6 *);
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	int (*probe)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*online)(struct device___6 *);
	int (*offline)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct dev_pm_ops___6 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device___6 *, struct device_attribute___6 *, char *);
	ssize_t (*store)(struct device___6 *, struct device_attribute___6 *, const char *, size_t);
};

struct driver_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___6 *, char *);
	ssize_t (*store)(struct device_driver___6 *, const char *, size_t);
};

struct device_driver___6 {
	const char *name;
	struct bus_type___6 *bus;
	struct module___4 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct attribute_group___6 **groups;
	const struct dev_pm_ops___6 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___6 {
	const char *name;
	const struct attribute_group___6 **groups;
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___6 *);
	const struct dev_pm_ops___6 *pm;
};

struct class_attribute___6;

struct class___6 {
	const char *name;
	struct module___4 *owner;
	struct class_attribute___6 *class_attrs;
	struct device_attribute___6 *dev_attrs;
	const struct attribute_group___6 **dev_groups;
	struct bin_attribute___6 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *);
	void (*class_release)(struct class___6 *);
	void (*dev_release)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___6 *);
	const struct dev_pm_ops___6 *pm;
	struct subsys_private *p;
};

struct class_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct class___6 *, struct class_attribute___6 *, char *);
	ssize_t (*store)(struct class___6 *, struct class_attribute___6 *, const char *, size_t);
	const void * (*namespace)(struct class___6 *, const struct class_attribute___6 *);
};

struct acpi_scan_handler___2;

struct acpi_hotplug_context___2;

struct acpi_driver___2;

struct acpi_device___2 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___2 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___2 *handler;
	struct acpi_hotplug_context___2 *hp;
	struct acpi_driver___2 *driver;
	void *driver_data;
	struct device___6 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___9 physical_node_lock;
	void (*remove)(struct acpi_device___2 *);
};

struct device_rh___6 {
	struct dev_pm_info_rh___6 power;
};

struct xol_area___6 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___6 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___6;

struct memcg_cache_params___6;

struct kmem_cache___6 {
	struct kmem_cache_cpu___6 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___6 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___6;

struct address_space___6 {
	struct inode___7 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___9 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___6 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___6;

struct vm_operations_struct___8 {
	void (*open)(struct vm_area_struct___9 *);
	void (*close)(struct vm_area_struct___9 *);
	int (*fault)(struct vm_area_struct___9 *, struct vm_fault___6 *);
	int (*page_mkwrite)(struct vm_area_struct___9 *, struct vm_fault___6 *);
	int (*access)(struct vm_area_struct___9 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___9 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___9 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___9 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___9 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___8 {
	struct task_struct___9 *task;
	struct core_thread___8 *next;
};

struct core_state___8 {
	atomic_t nr_threads;
	struct core_thread___8 dumper;
	struct completion startup;
};

struct signal_struct___8 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___9 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___9 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___5 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___9 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___6;

struct super_block___7;

struct dentry___7 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___7 *d_parent;
	struct qstr d_name;
	struct inode___7 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___6 *d_op;
	struct super_block___7 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___6;

struct file_lock___6;

struct dquot___6;

struct block_device___6;

struct inode___7 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___6 *i_op;
	struct super_block___7 *i_sb;
	struct address_space___6 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___9 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___6 *i_fop;
	struct file_lock___6 *i_flock;
	struct address_space___6 i_data;
	struct dquot___6 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___6 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___6 {
	int (*d_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_hash)(const struct dentry___7 *, struct qstr *);
	int (*d_compare)(const struct dentry___7 *, const struct dentry___7 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___7 *);
	void (*d_release)(struct dentry___7 *);
	void (*d_prune)(struct dentry___7 *);
	void (*d_iput)(struct dentry___7 *, struct inode___7 *);
	char * (*d_dname)(struct dentry___7 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___6 *);
	int (*d_manage)(struct dentry___7 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___6;

struct mem_dqinfo___6 {
	struct quota_format_type___6 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___6;

struct quota_info___6 {
	unsigned int flags;
	struct mutex___9 dqio_mutex;
	struct mutex___9 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___7 *files[2];
	struct mem_dqinfo___6 info[2];
	const struct quota_format_ops___6 *ops[2];
};

struct file_system_type___6;

struct super_operations___6;

struct dquot_operations___6;

struct quotactl_ops___6;

struct super_block___7 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___6 *s_type;
	const struct super_operations___6 *s_op;
	const struct dquot_operations___6 *dq_op;
	const struct quotactl_ops___6 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___7 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___6 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___6 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___9 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___6 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___6 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___7 *bd_inode;
	struct super_block___7 *bd_super;
	struct mutex___9 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___6 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___9 bd_fsfreeze_mutex;
};

struct iattr___7 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___6 *ia_file;
};

struct dquot___6 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___9 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___7 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___6 {
	int qf_fmt_id;
	const struct quota_format_ops___6 *qf_ops;
	struct module___4 *qf_owner;
	struct quota_format_type___6 *qf_next;
};

struct quota_format_ops___6 {
	int (*check_quota_file)(struct super_block___7 *, int);
	int (*read_file_info)(struct super_block___7 *, int);
	int (*write_file_info)(struct super_block___7 *, int);
	int (*free_file_info)(struct super_block___7 *, int);
	int (*read_dqblk)(struct dquot___6 *);
	int (*commit_dqblk)(struct dquot___6 *);
	int (*release_dqblk)(struct dquot___6 *);
};

struct dquot_operations___6 {
	int (*write_dquot)(struct dquot___6 *);
	struct dquot___6 * (*alloc_dquot)(struct super_block___7 *, int);
	void (*destroy_dquot)(struct dquot___6 *);
	int (*acquire_dquot)(struct dquot___6 *);
	int (*release_dquot)(struct dquot___6 *);
	int (*mark_dirty)(struct dquot___6 *);
	int (*write_info)(struct super_block___7 *, int);
	qsize_t * (*get_reserved_space)(struct inode___7 *);
};

struct quotactl_ops___6 {
	int (*quota_on)(struct super_block___7 *, int, int, struct path___6 *);
	int (*quota_on_meta)(struct super_block___7 *, int, int);
	int (*quota_off)(struct super_block___7 *, int);
	int (*quota_sync)(struct super_block___7 *, int);
	int (*get_info)(struct super_block___7 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___7 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___7 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___7 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___7 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___7 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___7 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___7 *, unsigned int);
};

struct address_space_operations___6 {
	int (*writepage)(struct page___6 *, struct writeback_control *);
	int (*readpage)(struct file___6 *, struct page___6 *);
	int (*writepages)(struct address_space___6 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___6 *);
	int (*readpages)(struct file___6 *, struct address_space___6 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___6 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___6 **, void **);
	int (*write_end)(struct file___6 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___6 *, void *);
	sector_t (*bmap)(struct address_space___6 *, sector_t);
	void (*invalidatepage)(struct page___6 *, long unsigned int);
	int (*releasepage)(struct page___6 *, gfp_t);
	void (*freepage)(struct page___6 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___6 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___6 *, struct page___6 *, struct page___6 *, enum migrate_mode);
	int (*launder_page)(struct page___6 *);
	int (*is_partially_uptodate)(struct page___6 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___6 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___6 *, struct page___6 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___6 *, sector_t *);
	void (*swap_deactivate)(struct file___6 *);
	void (*invalidatepage_range)(struct page___6 *, unsigned int, unsigned int);
};

struct inode_operations___6 {
	struct dentry___7 * (*lookup)(struct inode___7 *, struct dentry___7 *, unsigned int);
	void * (*follow_link)(struct dentry___7 *, struct nameidata *);
	int (*permission)(struct inode___7 *, int);
	struct posix_acl * (*get_acl)(struct inode___7 *, int);
	int (*readlink)(struct dentry___7 *, char *, int);
	void (*put_link)(struct dentry___7 *, struct nameidata *, void *);
	int (*create)(struct inode___7 *, struct dentry___7 *, umode_t, bool);
	int (*link)(struct dentry___7 *, struct inode___7 *, struct dentry___7 *);
	int (*unlink)(struct inode___7 *, struct dentry___7 *);
	int (*symlink)(struct inode___7 *, struct dentry___7 *, const char *);
	int (*mkdir)(struct inode___7 *, struct dentry___7 *, umode_t);
	int (*rmdir)(struct inode___7 *, struct dentry___7 *);
	int (*mknod)(struct inode___7 *, struct dentry___7 *, umode_t, dev_t);
	int (*rename)(struct inode___7 *, struct dentry___7 *, struct inode___7 *, struct dentry___7 *);
	int (*setattr)(struct dentry___7 *, struct iattr___7 *);
	int (*getattr)(struct vfsmount *, struct dentry___7 *, struct kstat *);
	int (*setxattr)(struct dentry___7 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___7 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___7 *, char *, size_t);
	int (*removexattr)(struct dentry___7 *, const char *);
	int (*fiemap)(struct inode___7 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___7 *, struct timespec *, int);
	int (*atomic_open)(struct inode___7 *, struct dentry___7 *, struct file___6 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___6 {
	struct module___4 *owner;
	loff_t (*llseek)(struct file___6 *, loff_t, int);
	ssize_t (*read)(struct file___6 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___6 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___6 *, void *, filldir_t);
	unsigned int (*poll)(struct file___6 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___6 *, struct vm_area_struct___9 *);
	int (*open)(struct inode___7 *, struct file___6 *);
	int (*flush)(struct file___6 *, fl_owner_t);
	int (*release)(struct inode___7 *, struct file___6 *);
	int (*fsync)(struct file___6 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___6 *, int);
	int (*lock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*sendpage)(struct file___6 *, struct page___6 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___6 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___6 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___6 *, long int, struct file_lock___6 **, void **);
		struct {
			int (*setlease)(struct file___6 *, long int, struct file_lock___6 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___6 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___6 *);
};

struct fasync_struct___6;

struct file_lock_operations___6;

struct lock_manager_operations___6;

struct file_lock___6 {
	struct file_lock___6 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___5 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___6 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___6 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___6 *fl_ops;
	const struct lock_manager_operations___6 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___6 {
	void (*fl_copy_lock)(struct file_lock___6 *, struct file_lock___6 *);
	void (*fl_release_private)(struct file_lock___6 *);
};

struct lock_manager_operations___6 {
	int (*lm_compare_owner)(struct file_lock___6 *, struct file_lock___6 *);
	long unsigned int (*lm_owner_key)(struct file_lock___6 *);
	void (*lm_notify)(struct file_lock___6 *);
	int (*lm_grant)(struct file_lock___6 *, struct file_lock___6 *, int);
	void (*lm_break)(struct file_lock___6 *);
	int (*lm_change)(struct file_lock___6 **, int);
};

struct fasync_struct___6 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___6 *fa_next;
	struct file___6 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___6 {
	const char *name;
	int fs_flags;
	struct dentry___7 * (*mount)(struct file_system_type___6 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___7 *);
	struct module___4 *owner;
	struct file_system_type___6 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___6 {
	struct inode___7 * (*alloc_inode)(struct super_block___7 *);
	void (*destroy_inode)(struct inode___7 *);
	void (*dirty_inode)(struct inode___7 *, int);
	int (*write_inode)(struct inode___7 *, struct writeback_control *);
	int (*drop_inode)(struct inode___7 *);
	void (*evict_inode)(struct inode___7 *);
	void (*put_super)(struct super_block___7 *);
	int (*sync_fs)(struct super_block___7 *, int);
	int (*freeze_fs)(struct super_block___7 *);
	int (*unfreeze_fs)(struct super_block___7 *);
	int (*statfs)(struct dentry___7 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___7 *, int *, char *);
	void (*umount_begin)(struct super_block___7 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___7 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___7 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___7 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___7 *);
	ssize_t (*quota_read)(struct super_block___7 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___7 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___7 *);
	int (*bdev_try_to_free_page)(struct super_block___7 *, struct page___6 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___7 *);
	void (*free_cached_objects)(struct super_block___7 *, int);
};

typedef u8 kprobe_opcode_t;

struct arch_specific_insn {
	kprobe_opcode_t *insn;
	int boostable;
	bool if_modifier;
};

struct kprobe;

struct prev_kprobe {
	struct kprobe *kp;
	long unsigned int status;
	long unsigned int old_flags;
	long unsigned int saved_flags;
};

typedef int (*kprobe_pre_handler_t)(struct kprobe *, struct pt_regs *);

typedef void (*kprobe_post_handler_t)(struct kprobe *, struct pt_regs *, long unsigned int);

typedef int (*kprobe_fault_handler_t)(struct kprobe *, struct pt_regs *, int);

typedef int (*kprobe_break_handler_t)(struct kprobe *, struct pt_regs *);

struct kprobe {
	struct hlist_node hlist;
	struct list_head list;
	long unsigned int nmissed;
	kprobe_opcode_t *addr;
	const char *symbol_name;
	unsigned int offset;
	kprobe_pre_handler_t pre_handler;
	kprobe_post_handler_t post_handler;
	kprobe_fault_handler_t fault_handler;
	kprobe_break_handler_t break_handler;
	kprobe_opcode_t opcode;
	struct arch_specific_insn ainsn;
	u32 flags;
};

struct kprobe_ctlblk {
	long unsigned int kprobe_status;
	long unsigned int kprobe_old_flags;
	long unsigned int kprobe_saved_flags;
	long unsigned int *jprobe_saved_sp;
	struct pt_regs jprobe_saved_regs;
	kprobe_opcode_t jprobes_stack[64];
	struct prev_kprobe prev_kprobe;
};

struct kprobe_insn_cache {
	struct mutex___9 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct module_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___3 *, struct module_kobject___3 *, char *);
	ssize_t (*store)(struct module_attribute___3 *, struct module_kobject___3 *, const char *, size_t);
	void (*setup)(struct module___4 *, const char *);
	int (*test)(struct module___4 *);
	void (*free)(struct module___4 *);
};

struct vm_fault___6 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___6 *page;
};

struct pci_device_id {
	__u32 vendor;
	__u32 device;
	__u32 subvendor;
	__u32 subdevice;
	__u32 class;
	__u32 class_mask;
	kernel_ulong_t driver_data;
};

struct hotplug_slot;

struct pci_slot {
	struct pci_bus *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

typedef short unsigned int pci_bus_flags_t;

struct pci_ops;

struct msi_chip;

struct pci_bus_rh;

struct pci_bus {
	struct list_head node;
	struct pci_bus *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___6 *bridge;
	struct device___6 dev;
	struct bin_attribute___6 *legacy_io;
	struct bin_attribute___6 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

enum {
	PCI_STD_RESOURCES = 0,
	PCI_STD_RESOURCE_END = 5,
	PCI_ROM_RESOURCE = 6,
	PCI_IOV_RESOURCES = 7,
	PCI_IOV_RESOURCE_END = 12,
	PCI_BRIDGE_RESOURCES = 13,
	PCI_BRIDGE_RESOURCE_END = 16,
	PCI_NUM_RESOURCES = 17,
	DEVICE_COUNT_RESOURCE = 17,
};

enum pci_channel_state {
	pci_channel_io_normal = 1,
	pci_channel_io_frozen = 2,
	pci_channel_io_perm_failure = 3,
};

typedef unsigned int pcie_reset_state_t;

struct pci_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct pci_error_handlers;

struct pci_driver_rh;

struct pci_driver {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev *, const struct pci_device_id *);
	void (*remove)(struct pci_dev *);
	int (*suspend)(struct pci_dev *, pm_message_t);
	int (*suspend_late)(struct pci_dev *, pm_message_t);
	int (*resume_early)(struct pci_dev *);
	int (*resume)(struct pci_dev *);
	void (*shutdown)(struct pci_dev *);
	int (*sriov_configure)(struct pci_dev *, int);
	const struct pci_error_handlers *err_handler;
	struct device_driver___6 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh *pci_driver_rh;
};

struct pci_dev_rh {
	u8 dma_alias_devfn;
	char *driver_override;
};

struct pci_ops {
	int (*read)(struct pci_bus *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus *, unsigned int, int, int, u32);
};

struct pci_bus_rh {};

typedef unsigned int pci_ers_result_t;

struct pci_error_handlers {
	pci_ers_result_t (*error_detected)(struct pci_dev *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev *);
	pci_ers_result_t (*link_reset)(struct pci_dev *);
	pci_ers_result_t (*slot_reset)(struct pci_dev *);
	void (*resume)(struct pci_dev *);
};

struct pci_driver_rh {
	unsigned int size;
	void (*reset_notify)(struct pci_dev *, bool);
};

struct kmem_cache_cpu___6 {
	void **freelist;
	long unsigned int tid;
	struct page___6 *page;
	struct page___6 *partial;
};

struct memcg_cache_params___6 {
	bool is_root_cache;
	union {
		struct kmem_cache___6 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___6 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef long unsigned int xen_pfn_t;

typedef long unsigned int xen_ulong_t;

typedef unsigned char *__guest_handle_uchar;

typedef void *__guest_handle_void;

typedef uint64_t *__guest_handle_uint64_t;

typedef uint32_t *__guest_handle_uint32_t;

struct trap_info {
	uint8_t vector;
	uint8_t flags;
	uint16_t cs;
	long unsigned int address;
};

struct arch_shared_info {
	long unsigned int max_pfn;
	long unsigned int pfn_to_mfn_frame_list_list;
	long unsigned int nmi_reason;
};

struct arch_vcpu_info {
	long unsigned int cr2;
	long unsigned int pad;
};

struct mmuext_op {
	unsigned int cmd;
	union {
		xen_pfn_t mfn;
		long unsigned int linear_addr;
	} arg1;
	union {
		unsigned int nr_ents;
		void *vcpumask;
	} arg2;
};

typedef uint16_t domid_t;

struct multicall_entry {
	long unsigned int op;
	long int result;
	long unsigned int args[6];
};

struct vcpu_info {
	uint8_t evtchn_upcall_pending;
	uint8_t evtchn_upcall_mask;
	xen_ulong_t evtchn_pending_sel;
	struct arch_vcpu_info arch;
	struct pvclock_vcpu_time_info time;
};

struct shared_info {
	struct vcpu_info vcpu_info[32];
	xen_ulong_t evtchn_pending[64];
	xen_ulong_t evtchn_mask[64];
	struct pvclock_wall_clock wc;
	struct arch_shared_info arch;
};

struct start_info {
	char magic[32];
	long unsigned int nr_pages;
	long unsigned int shared_info;
	uint32_t flags;
	xen_pfn_t store_mfn;
	uint32_t store_evtchn;
	union {
		struct {
			xen_pfn_t mfn;
			uint32_t evtchn;
		} domU;
		struct {
			uint32_t info_off;
			uint32_t info_size;
		} dom0;
	} console;
	long unsigned int pt_base;
	long unsigned int nr_pt_frames;
	long unsigned int mfn_list;
	long unsigned int mod_start;
	long unsigned int mod_len;
	int8_t cmd_line[1024];
};

struct sched_shutdown {
	unsigned int reason;
};

struct physdev_set_iopl {
	uint32_t iopl;
};

struct xenpf_settime {
	uint32_t secs;
	uint32_t nsecs;
	uint64_t system_time;
};

struct xenpf_add_memtype {
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_del_memtype {
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_read_memtype {
	uint32_t reg;
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
};

struct xenpf_microcode_update {
	__guest_handle_void data;
	uint32_t length;
};

struct xenpf_platform_quirk {
	uint32_t quirk_id;
};

struct xenpf_firmware_info {
	uint32_t type;
	uint32_t index;
	union {
		struct {
			uint8_t device;
			uint8_t version;
			uint16_t interface_support;
			uint16_t legacy_max_cylinder;
			uint8_t legacy_max_head;
			uint8_t legacy_sectors_per_track;
			__guest_handle_void edd_params;
		} disk_info;
		struct {
			uint8_t device;
			uint32_t mbr_signature;
		} disk_mbr_signature;
		struct {
			uint8_t capabilities;
			uint8_t edid_transfer_time;
			__guest_handle_uchar edid;
		} vbeddc_info;
		uint8_t kbd_shift_flags;
	} u;
};

struct xenpf_enter_acpi_sleep {
	uint16_t pm1a_cnt_val;
	uint16_t pm1b_cnt_val;
	uint32_t sleep_state;
	uint32_t flags;
};

struct xenpf_change_freq {
	uint32_t flags;
	uint32_t cpu;
	uint64_t freq;
};

struct xenpf_getidletime {
	__guest_handle_uchar cpumap_bitmap;
	uint32_t cpumap_nr_cpus;
	__guest_handle_uint64_t idletime;
	uint64_t now;
};

struct xen_power_register {
	uint32_t space_id;
	uint32_t bit_width;
	uint32_t bit_offset;
	uint32_t access_size;
	uint64_t address;
};

struct xen_processor_csd {
	uint32_t domain;
	uint32_t coord_type;
	uint32_t num;
};

typedef struct xen_processor_csd *__guest_handle_xen_processor_csd;

struct xen_processor_cx {
	struct xen_power_register reg;
	uint8_t type;
	uint32_t latency;
	uint32_t power;
	uint32_t dpcnt;
	__guest_handle_xen_processor_csd dp;
};

typedef struct xen_processor_cx *__guest_handle_xen_processor_cx;

struct xen_processor_flags {
	uint32_t bm_control: 1;
	uint32_t bm_check: 1;
	uint32_t has_cst: 1;
	uint32_t power_setup_done: 1;
	uint32_t bm_rld_set: 1;
};

struct xen_processor_power {
	uint32_t count;
	struct xen_processor_flags flags;
	__guest_handle_xen_processor_cx states;
};

struct xen_pct_register {
	uint8_t descriptor;
	uint16_t length;
	uint8_t space_id;
	uint8_t bit_width;
	uint8_t bit_offset;
	uint8_t reserved;
	uint64_t address;
};

struct xen_processor_px {
	uint64_t core_frequency;
	uint64_t power;
	uint64_t transition_latency;
	uint64_t bus_master_latency;
	uint64_t control;
	uint64_t status;
};

typedef struct xen_processor_px *__guest_handle_xen_processor_px;

struct xen_psd_package {
	uint64_t num_entries;
	uint64_t revision;
	uint64_t domain;
	uint64_t coord_type;
	uint64_t num_processors;
};

struct xen_processor_performance {
	uint32_t flags;
	uint32_t platform_limit;
	struct xen_pct_register control_register;
	struct xen_pct_register status_register;
	uint32_t state_count;
	__guest_handle_xen_processor_px states;
	struct xen_psd_package domain_info;
	uint32_t shared_type;
};

struct xenpf_set_processor_pminfo {
	uint32_t id;
	uint32_t type;
	union {
		struct xen_processor_power power;
		struct xen_processor_performance perf;
		__guest_handle_uint32_t pdc;
	};
};

struct xenpf_pcpuinfo {
	uint32_t xen_cpuid;
	uint32_t max_present;
	uint32_t flags;
	uint32_t apic_id;
	uint32_t acpi_id;
};

struct xenpf_cpu_ol {
	uint32_t cpuid;
};

struct xenpf_cpu_hotadd {
	uint32_t apic_id;
	uint32_t acpi_id;
	uint32_t pxm;
};

struct xenpf_mem_hotadd {
	uint64_t spfn;
	uint64_t epfn;
	uint32_t pxm;
	uint32_t flags;
};

struct xenpf_core_parking {
	uint32_t type;
	uint32_t idle_nums;
};

struct xen_platform_op {
	uint32_t cmd;
	uint32_t interface_version;
	union {
		struct xenpf_settime settime;
		struct xenpf_add_memtype add_memtype;
		struct xenpf_del_memtype del_memtype;
		struct xenpf_read_memtype read_memtype;
		struct xenpf_microcode_update microcode;
		struct xenpf_platform_quirk platform_quirk;
		struct xenpf_firmware_info firmware_info;
		struct xenpf_enter_acpi_sleep enter_acpi_sleep;
		struct xenpf_change_freq change_freq;
		struct xenpf_getidletime getidletime;
		struct xenpf_set_processor_pminfo set_pminfo;
		struct xenpf_pcpuinfo pcpu_info;
		struct xenpf_cpu_ol cpu_ol;
		struct xenpf_cpu_hotadd cpu_add;
		struct xenpf_mem_hotadd mem_add;
		struct xenpf_core_parking core_parking;
		uint8_t pad[128];
	} u;
};

struct xen_extraversion {
	char extraversion[16];
};

struct vcpu_register_vcpu_info {
	uint64_t mfn;
	uint32_t offset;
	uint32_t rsvd;
};

struct xen_add_to_physmap {
	domid_t domid;
	uint16_t size;
	unsigned int space;
	xen_ulong_t idx;
	xen_pfn_t gpfn;
};

struct xmaddr {
	phys_addr_t maddr;
};

typedef struct xmaddr xmaddr_t;

struct xpaddr {
	phys_addr_t paddr;
};

typedef struct xpaddr xpaddr_t;

struct xen_pci_frontend_ops {
	int (*enable_msi)(struct pci_dev *, int *);
	void (*disable_msi)(struct pci_dev *);
	int (*enable_msix)(struct pci_dev *, int *, int);
	void (*disable_msix)(struct pci_dev *);
};

struct tlb_state___2 {
	struct mm_struct___9 *active_mm;
	int state;
};

struct machine_ops {
	void (*restart)(char *);
	void (*halt)();
	void (*power_off)();
	void (*shutdown)();
	void (*crash_shutdown)(struct pt_regs *);
	void (*emergency_restart)();
};

struct hypervisor_x86 {
	const char *name;
	uint32_t (*detect)();
	void (*set_cpu_features)(struct cpuinfo_x86 *);
	void (*init_platform)();
	bool (*x2apic_available)();
};

struct acpi_hotplug_profile___2 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___2 *);
	void (*notify_online)(struct acpi_device___2 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___2 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___2 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___2 *);
	void (*bind)(struct device___6 *);
	void (*unbind)(struct device___6 *);
	struct acpi_hotplug_profile___2 hotplug;
};

struct acpi_hotplug_context___2 {
	struct acpi_device___2 *self;
	int (*notify)(struct acpi_device___2 *, u32);
	void (*uevent)(struct acpi_device___2 *, u32);
	void (*fixup)(struct acpi_device___2 *);
};

typedef int (*acpi_op_add___2)(struct acpi_device___2 *);

typedef int (*acpi_op_remove___2)(struct acpi_device___2 *);

typedef void (*acpi_op_notify___2)(struct acpi_device___2 *, u32);

struct acpi_device_ops___2 {
	acpi_op_add___2 add;
	acpi_op_remove___2 remove;
	acpi_op_notify___2 notify;
};

struct acpi_driver___2 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___2 ops;
	struct device_driver___6 drv;
	struct module___4 *owner;
};

struct multicall_space {
	struct multicall_entry *mc;
	void *args;
};

struct tls_descs {
	struct desc_struct desc[3];
};

typedef long unsigned int pto_T__;

struct e820map {
	__u32 nr_map;
	struct e820entry map[3200];
} __attribute__((packed));

typedef xen_pfn_t *__guest_handle_xen_pfn_t;

typedef long unsigned int xen_callback_t;

struct __large_struct {
	long unsigned int buf[100];
};

struct xen_memory_region {
	phys_addr_t start;
	phys_addr_t size;
};

struct callback_register {
	uint16_t type;
	uint16_t flags;
	xen_callback_t address;
};

struct xen_memory_reservation {
	__guest_handle_xen_pfn_t extent_start;
	xen_ulong_t nr_extents;
	unsigned int extent_order;
	unsigned int address_bits;
	domid_t domid;
};

struct xen_memory_map {
	unsigned int nr_entries;
	__guest_handle_void buffer;
};

struct page___7;

typedef struct page___7 *pgtable_t___7;

struct address_space___7;

struct page___7 {
	long unsigned int flags;
	struct address_space___7 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___7 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___7 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___7 *first_page;
	};
	long: 64;
};

struct mm_struct___10;

struct pv_mmu_ops___10 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___10 *, struct mm_struct___10 *);
	void (*dup_mmap)(struct mm_struct___10 *, struct mm_struct___10 *);
	void (*exit_mmap)(struct mm_struct___10 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___10 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___10 *);
	void (*pgd_free)(struct mm_struct___10 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___10 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___10 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___10 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___10 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___10 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___10 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___10 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___10 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___10 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___10 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___10 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct xol_area___7;

struct uprobes_state___7 {
	struct xol_area___7 *xol_area;
};

struct vm_area_struct___10;

struct file___7;

struct mm_struct___10 {
	struct vm_area_struct___10 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___10 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___10 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t context;
	long unsigned int flags;
	struct core_state___8 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file___7 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___7 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct irq_data___6;

struct x86_io_apic_ops___6 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___6 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___6;

struct irq_data___6 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___6 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct seq_file___6;

struct irq_chip___6 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___6 *);
	void (*irq_shutdown)(struct irq_data___6 *);
	void (*irq_enable)(struct irq_data___6 *);
	void (*irq_disable)(struct irq_data___6 *);
	void (*irq_ack)(struct irq_data___6 *);
	void (*irq_mask)(struct irq_data___6 *);
	void (*irq_mask_ack)(struct irq_data___6 *);
	void (*irq_unmask)(struct irq_data___6 *);
	void (*irq_eoi)(struct irq_data___6 *);
	int (*irq_set_affinity)(struct irq_data___6 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___6 *);
	int (*irq_set_type)(struct irq_data___6 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___6 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___6 *);
	void (*irq_bus_sync_unlock)(struct irq_data___6 *);
	void (*irq_cpu_online)(struct irq_data___6 *);
	void (*irq_cpu_offline)(struct irq_data___6 *);
	void (*irq_suspend)(struct irq_data___6 *);
	void (*irq_resume)(struct irq_data___6 *);
	void (*irq_pm_shutdown)(struct irq_data___6 *);
	void (*irq_print_chip)(struct irq_data___6 *, struct seq_file___6 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___6 *, void *);
	long unsigned int flags;
};

struct seq_operations___6;

struct seq_file___6 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___6 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct inode___8;

struct dentry_operations___7;

struct super_block___8;

struct dentry___8 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___8 *d_parent;
	struct qstr d_name;
	struct inode___8 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___7 *d_op;
	struct super_block___8 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___7;

struct address_space___7 {
	struct inode___8 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___7 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___7;

struct file_operations___7;

struct file_lock___7;

struct dquot___7;

struct block_device___7;

struct inode___8 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___7 *i_op;
	struct super_block___8 *i_sb;
	struct address_space___7 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___7 *i_fop;
	struct file_lock___7 *i_flock;
	struct address_space___7 i_data;
	struct dquot___7 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___7 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___7;

struct dentry_operations___7 {
	int (*d_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_hash)(const struct dentry___8 *, struct qstr *);
	int (*d_compare)(const struct dentry___8 *, const struct dentry___8 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___8 *);
	void (*d_release)(struct dentry___8 *);
	void (*d_prune)(struct dentry___8 *);
	void (*d_iput)(struct dentry___8 *, struct inode___8 *);
	char * (*d_dname)(struct dentry___8 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___7 *);
	int (*d_manage)(struct dentry___8 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___7;

struct mem_dqinfo___7 {
	struct quota_format_type___7 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___7;

struct quota_info___7 {
	unsigned int flags;
	struct mutex dqio_mutex;
	struct mutex dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___8 *files[2];
	struct mem_dqinfo___7 info[2];
	const struct quota_format_ops___7 *ops[2];
};

struct file_system_type___7;

struct super_operations___7;

struct dquot_operations___7;

struct quotactl_ops___7;

struct super_block___8 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___7 *s_type;
	const struct super_operations___7 *s_op;
	const struct dquot_operations___7 *dq_op;
	const struct quotactl_ops___7 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___8 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___7 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___7 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___7 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___7 {
	struct vfsmount *mnt;
	struct dentry___8 *dentry;
};

struct block_device___7 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___8 *bd_inode;
	struct super_block___8 *bd_super;
	struct mutex bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___7 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
};

struct iattr___8 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___7 *ia_file;
};

struct file___7 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___7 f_path;
	struct inode___8 *f_inode;
	const struct file_operations___7 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___7 *f_mapping;
	struct mutex f_pos_lock;
};

struct dquot___7 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___8 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___7 {
	int qf_fmt_id;
	const struct quota_format_ops___7 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___7 *qf_next;
};

struct quota_format_ops___7 {
	int (*check_quota_file)(struct super_block___8 *, int);
	int (*read_file_info)(struct super_block___8 *, int);
	int (*write_file_info)(struct super_block___8 *, int);
	int (*free_file_info)(struct super_block___8 *, int);
	int (*read_dqblk)(struct dquot___7 *);
	int (*commit_dqblk)(struct dquot___7 *);
	int (*release_dqblk)(struct dquot___7 *);
};

struct dquot_operations___7 {
	int (*write_dquot)(struct dquot___7 *);
	struct dquot___7 * (*alloc_dquot)(struct super_block___8 *, int);
	void (*destroy_dquot)(struct dquot___7 *);
	int (*acquire_dquot)(struct dquot___7 *);
	int (*release_dquot)(struct dquot___7 *);
	int (*mark_dirty)(struct dquot___7 *);
	int (*write_info)(struct super_block___8 *, int);
	qsize_t * (*get_reserved_space)(struct inode___8 *);
};

struct quotactl_ops___7 {
	int (*quota_on)(struct super_block___8 *, int, int, struct path___7 *);
	int (*quota_on_meta)(struct super_block___8 *, int, int);
	int (*quota_off)(struct super_block___8 *, int);
	int (*quota_sync)(struct super_block___8 *, int);
	int (*get_info)(struct super_block___8 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___8 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___8 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___8 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___8 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___8 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___8 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___8 *, unsigned int);
};

struct address_space_operations___7 {
	int (*writepage)(struct page___7 *, struct writeback_control *);
	int (*readpage)(struct file___7 *, struct page___7 *);
	int (*writepages)(struct address_space___7 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___7 *);
	int (*readpages)(struct file___7 *, struct address_space___7 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___7 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___7 **, void **);
	int (*write_end)(struct file___7 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___7 *, void *);
	sector_t (*bmap)(struct address_space___7 *, sector_t);
	void (*invalidatepage)(struct page___7 *, long unsigned int);
	int (*releasepage)(struct page___7 *, gfp_t);
	void (*freepage)(struct page___7 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___7 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___7 *, struct page___7 *, struct page___7 *, enum migrate_mode);
	int (*launder_page)(struct page___7 *);
	int (*is_partially_uptodate)(struct page___7 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___7 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___7 *, struct page___7 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___7 *, sector_t *);
	void (*swap_deactivate)(struct file___7 *);
	void (*invalidatepage_range)(struct page___7 *, unsigned int, unsigned int);
};

struct inode_operations___7 {
	struct dentry___8 * (*lookup)(struct inode___8 *, struct dentry___8 *, unsigned int);
	void * (*follow_link)(struct dentry___8 *, struct nameidata *);
	int (*permission)(struct inode___8 *, int);
	struct posix_acl * (*get_acl)(struct inode___8 *, int);
	int (*readlink)(struct dentry___8 *, char *, int);
	void (*put_link)(struct dentry___8 *, struct nameidata *, void *);
	int (*create)(struct inode___8 *, struct dentry___8 *, umode_t, bool);
	int (*link)(struct dentry___8 *, struct inode___8 *, struct dentry___8 *);
	int (*unlink)(struct inode___8 *, struct dentry___8 *);
	int (*symlink)(struct inode___8 *, struct dentry___8 *, const char *);
	int (*mkdir)(struct inode___8 *, struct dentry___8 *, umode_t);
	int (*rmdir)(struct inode___8 *, struct dentry___8 *);
	int (*mknod)(struct inode___8 *, struct dentry___8 *, umode_t, dev_t);
	int (*rename)(struct inode___8 *, struct dentry___8 *, struct inode___8 *, struct dentry___8 *);
	int (*setattr)(struct dentry___8 *, struct iattr___8 *);
	int (*getattr)(struct vfsmount *, struct dentry___8 *, struct kstat *);
	int (*setxattr)(struct dentry___8 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___8 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___8 *, char *, size_t);
	int (*removexattr)(struct dentry___8 *, const char *);
	int (*fiemap)(struct inode___8 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___8 *, struct timespec *, int);
	int (*atomic_open)(struct inode___8 *, struct dentry___8 *, struct file___7 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___7 {
	struct module *owner;
	loff_t (*llseek)(struct file___7 *, loff_t, int);
	ssize_t (*read)(struct file___7 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___7 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___7 *, void *, filldir_t);
	unsigned int (*poll)(struct file___7 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___7 *, struct vm_area_struct___10 *);
	int (*open)(struct inode___8 *, struct file___7 *);
	int (*flush)(struct file___7 *, fl_owner_t);
	int (*release)(struct inode___8 *, struct file___7 *);
	int (*fsync)(struct file___7 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___7 *, int);
	int (*lock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*sendpage)(struct file___7 *, struct page___7 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___7 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___7 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___7 *, long int, struct file_lock___7 **, void **);
		struct {
			int (*setlease)(struct file___7 *, long int, struct file_lock___7 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___7 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___6 *, struct file___7 *);
};

struct fasync_struct___7;

struct file_lock_operations___7;

struct lock_manager_operations___7;

struct file_lock___7 {
	struct file_lock___7 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___5 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___7 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___7 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___7 *fl_ops;
	const struct lock_manager_operations___7 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___7 {
	void (*fl_copy_lock)(struct file_lock___7 *, struct file_lock___7 *);
	void (*fl_release_private)(struct file_lock___7 *);
};

struct lock_manager_operations___7 {
	int (*lm_compare_owner)(struct file_lock___7 *, struct file_lock___7 *);
	long unsigned int (*lm_owner_key)(struct file_lock___7 *);
	void (*lm_notify)(struct file_lock___7 *);
	int (*lm_grant)(struct file_lock___7 *, struct file_lock___7 *, int);
	void (*lm_break)(struct file_lock___7 *);
	int (*lm_change)(struct file_lock___7 **, int);
};

struct fasync_struct___7 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___7 *fa_next;
	struct file___7 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___7 {
	const char *name;
	int fs_flags;
	struct dentry___8 * (*mount)(struct file_system_type___7 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___8 *);
	struct module *owner;
	struct file_system_type___7 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___7 {
	struct inode___8 * (*alloc_inode)(struct super_block___8 *);
	void (*destroy_inode)(struct inode___8 *);
	void (*dirty_inode)(struct inode___8 *, int);
	int (*write_inode)(struct inode___8 *, struct writeback_control *);
	int (*drop_inode)(struct inode___8 *);
	void (*evict_inode)(struct inode___8 *);
	void (*put_super)(struct super_block___8 *);
	int (*sync_fs)(struct super_block___8 *, int);
	int (*freeze_fs)(struct super_block___8 *);
	int (*unfreeze_fs)(struct super_block___8 *);
	int (*statfs)(struct dentry___8 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___8 *, int *, char *);
	void (*umount_begin)(struct super_block___8 *);
	int (*show_options)(struct seq_file___6 *, struct dentry___8 *);
	int (*show_devname)(struct seq_file___6 *, struct dentry___8 *);
	int (*show_path)(struct seq_file___6 *, struct dentry___8 *);
	int (*show_stats)(struct seq_file___6 *, struct dentry___8 *);
	ssize_t (*quota_read)(struct super_block___8 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___8 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___8 *);
	int (*bdev_try_to_free_page)(struct super_block___8 *, struct page___7 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___8 *);
	void (*free_cached_objects)(struct super_block___8 *, int);
};

struct vm_area_struct___10 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___10 *vm_next;
	struct vm_area_struct___10 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___10 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___6 {
	void * (*start)(struct seq_file___6 *, loff_t *);
	void (*stop)(struct seq_file___6 *, void *);
	void * (*next)(struct seq_file___6 *, void *, loff_t *);
	int (*show)(struct seq_file___6 *, void *);
};

enum xen_mc_flush_reason {
	XEN_MC_FL_NONE = 0,
	XEN_MC_FL_BATCH = 1,
	XEN_MC_FL_ARGS = 2,
	XEN_MC_FL_CALLBACK = 3,
};

enum xen_mc_extend_args {
	XEN_MC_XE_OK = 0,
	XEN_MC_XE_BAD_OP = 1,
	XEN_MC_XE_NO_SPACE = 2,
};

typedef void (*xen_mc_callback_fn_t)(void *);

struct xol_area___7 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___7 *page;
	long unsigned int vaddr;
};

struct callback {
	void (*fn)(void *);
	void *data;
};

struct mc_buffer {
	unsigned int mcidx;
	unsigned int argidx;
	unsigned int cbidx;
	struct multicall_entry entries[32];
	unsigned char args[512];
	struct callback callbacks[32];
};

struct page___8;

typedef struct page___8 *pgtable_t___8;

struct address_space___8;

struct page___8 {
	long unsigned int flags;
	struct address_space___8 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___8 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___8 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___8 *first_page;
	};
	long: 64;
};

struct task_struct___10;

struct pv_cpu_ops___9 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___4 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___4 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___10 *);
	void (*end_context_switch)(struct task_struct___10 *);
};

struct mutex___10 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___10 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___7 {
	struct page___8 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___11;

struct signal_struct___9;

struct task_struct___10 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___10 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___11 *mm;
	struct mm_struct___11 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___10 *real_parent;
	struct task_struct___10 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___10 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___5 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___9 = 0,
		VTIME_USER___9 = 1,
		VTIME_SYS___9 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___4 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___9 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___10 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___7 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___11 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___11 *, struct mm_struct___11 *);
	void (*dup_mmap)(struct mm_struct___11 *, struct mm_struct___11 *);
	void (*exit_mmap)(struct mm_struct___11 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___11 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___11 *);
	void (*pgd_free)(struct mm_struct___11 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___11 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___11 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___11 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___11 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___11 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___11 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___11 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___11 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___11 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___11 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___11 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___10 lock;
	void *vdso;
} mm_context_t___10;

struct xol_area___8;

struct uprobes_state___8 {
	struct xol_area___8 *xol_area;
};

struct vm_area_struct___11;

struct file___8;

struct core_state___9;

struct mm_struct___11 {
	struct vm_area_struct___11 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___11 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___11 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___10 context;
	long unsigned int flags;
	struct core_state___9 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___10 *owner;
	struct file___8 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___8 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___5;

struct module_kobject___4 {
	struct kobject kobj;
	struct module___5 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___4;

struct module___5 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___4 mkobj;
	struct module_attribute___4 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___10 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___8 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___8 *page;
	long unsigned int vaddr;
};

struct inode___9;

struct address_space_operations___8;

struct address_space___8 {
	struct inode___9 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___10 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___8 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___9;

struct path___8 {
	struct vfsmount *mnt;
	struct dentry___9 *dentry;
};

struct file_operations___8;

struct file___8 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___8 f_path;
	struct inode___9 *f_inode;
	const struct file_operations___8 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___8 *f_mapping;
	struct mutex___10 f_pos_lock;
};

struct vm_operations_struct___9;

struct vm_area_struct___11 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___11 *vm_next;
	struct vm_area_struct___11 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___11 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___9 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___8 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___7;

struct vm_operations_struct___9 {
	void (*open)(struct vm_area_struct___11 *);
	void (*close)(struct vm_area_struct___11 *);
	int (*fault)(struct vm_area_struct___11 *, struct vm_fault___7 *);
	int (*page_mkwrite)(struct vm_area_struct___11 *, struct vm_fault___7 *);
	int (*access)(struct vm_area_struct___11 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___11 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___11 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___11 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___11 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___9 {
	struct task_struct___10 *task;
	struct core_thread___9 *next;
};

struct core_state___9 {
	atomic_t nr_threads;
	struct core_thread___9 dumper;
	struct completion startup;
};

struct irq_data___7;

struct x86_io_apic_ops___7 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___7 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___7;

struct irq_data___7 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___7 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___9 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___10 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___9;

struct lruvec___9 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___9 *zone;
};

struct pglist_data___9;

struct zone___9 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___9 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___9 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___9 {
	struct zone___9 *zone;
	int zone_idx;
};

struct zonelist___9 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___9 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___9 {
	struct zone___9 node_zones[4];
	struct zonelist___9 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___10 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___9 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___10 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___10 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___5 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___10 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___8;

struct super_block___9;

struct dentry___9 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___9 *d_parent;
	struct qstr d_name;
	struct inode___9 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___8 *d_op;
	struct super_block___9 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___8;

struct file_lock___8;

struct dquot___8;

struct block_device___8;

struct inode___9 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___8 *i_op;
	struct super_block___9 *i_sb;
	struct address_space___8 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___10 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___8 *i_fop;
	struct file_lock___8 *i_flock;
	struct address_space___8 i_data;
	struct dquot___8 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___8 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___8 {
	int (*d_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_hash)(const struct dentry___9 *, struct qstr *);
	int (*d_compare)(const struct dentry___9 *, const struct dentry___9 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___9 *);
	void (*d_release)(struct dentry___9 *);
	void (*d_prune)(struct dentry___9 *);
	void (*d_iput)(struct dentry___9 *, struct inode___9 *);
	char * (*d_dname)(struct dentry___9 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___8 *);
	int (*d_manage)(struct dentry___9 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___8;

struct mem_dqinfo___8 {
	struct quota_format_type___8 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___8;

struct quota_info___8 {
	unsigned int flags;
	struct mutex___10 dqio_mutex;
	struct mutex___10 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___9 *files[2];
	struct mem_dqinfo___8 info[2];
	const struct quota_format_ops___8 *ops[2];
};

struct file_system_type___8;

struct super_operations___8;

struct dquot_operations___8;

struct quotactl_ops___8;

struct super_block___9 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___8 *s_type;
	const struct super_operations___8 *s_op;
	const struct dquot_operations___8 *dq_op;
	const struct quotactl_ops___8 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___9 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___8 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___8 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___10 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___8 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___8 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___9 *bd_inode;
	struct super_block___9 *bd_super;
	struct mutex___10 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___8 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___10 bd_fsfreeze_mutex;
};

struct iattr___9 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___8 *ia_file;
};

struct dquot___8 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___10 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___9 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___8 {
	int qf_fmt_id;
	const struct quota_format_ops___8 *qf_ops;
	struct module___5 *qf_owner;
	struct quota_format_type___8 *qf_next;
};

struct quota_format_ops___8 {
	int (*check_quota_file)(struct super_block___9 *, int);
	int (*read_file_info)(struct super_block___9 *, int);
	int (*write_file_info)(struct super_block___9 *, int);
	int (*free_file_info)(struct super_block___9 *, int);
	int (*read_dqblk)(struct dquot___8 *);
	int (*commit_dqblk)(struct dquot___8 *);
	int (*release_dqblk)(struct dquot___8 *);
};

struct dquot_operations___8 {
	int (*write_dquot)(struct dquot___8 *);
	struct dquot___8 * (*alloc_dquot)(struct super_block___9 *, int);
	void (*destroy_dquot)(struct dquot___8 *);
	int (*acquire_dquot)(struct dquot___8 *);
	int (*release_dquot)(struct dquot___8 *);
	int (*mark_dirty)(struct dquot___8 *);
	int (*write_info)(struct super_block___9 *, int);
	qsize_t * (*get_reserved_space)(struct inode___9 *);
};

struct quotactl_ops___8 {
	int (*quota_on)(struct super_block___9 *, int, int, struct path___8 *);
	int (*quota_on_meta)(struct super_block___9 *, int, int);
	int (*quota_off)(struct super_block___9 *, int);
	int (*quota_sync)(struct super_block___9 *, int);
	int (*get_info)(struct super_block___9 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___9 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___9 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___9 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___9 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___9 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___9 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___9 *, unsigned int);
};

struct address_space_operations___8 {
	int (*writepage)(struct page___8 *, struct writeback_control *);
	int (*readpage)(struct file___8 *, struct page___8 *);
	int (*writepages)(struct address_space___8 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___8 *);
	int (*readpages)(struct file___8 *, struct address_space___8 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___8 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___8 **, void **);
	int (*write_end)(struct file___8 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___8 *, void *);
	sector_t (*bmap)(struct address_space___8 *, sector_t);
	void (*invalidatepage)(struct page___8 *, long unsigned int);
	int (*releasepage)(struct page___8 *, gfp_t);
	void (*freepage)(struct page___8 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___8 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___8 *, struct page___8 *, struct page___8 *, enum migrate_mode);
	int (*launder_page)(struct page___8 *);
	int (*is_partially_uptodate)(struct page___8 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___8 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___8 *, struct page___8 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___8 *, sector_t *);
	void (*swap_deactivate)(struct file___8 *);
	void (*invalidatepage_range)(struct page___8 *, unsigned int, unsigned int);
};

struct inode_operations___8 {
	struct dentry___9 * (*lookup)(struct inode___9 *, struct dentry___9 *, unsigned int);
	void * (*follow_link)(struct dentry___9 *, struct nameidata *);
	int (*permission)(struct inode___9 *, int);
	struct posix_acl * (*get_acl)(struct inode___9 *, int);
	int (*readlink)(struct dentry___9 *, char *, int);
	void (*put_link)(struct dentry___9 *, struct nameidata *, void *);
	int (*create)(struct inode___9 *, struct dentry___9 *, umode_t, bool);
	int (*link)(struct dentry___9 *, struct inode___9 *, struct dentry___9 *);
	int (*unlink)(struct inode___9 *, struct dentry___9 *);
	int (*symlink)(struct inode___9 *, struct dentry___9 *, const char *);
	int (*mkdir)(struct inode___9 *, struct dentry___9 *, umode_t);
	int (*rmdir)(struct inode___9 *, struct dentry___9 *);
	int (*mknod)(struct inode___9 *, struct dentry___9 *, umode_t, dev_t);
	int (*rename)(struct inode___9 *, struct dentry___9 *, struct inode___9 *, struct dentry___9 *);
	int (*setattr)(struct dentry___9 *, struct iattr___9 *);
	int (*getattr)(struct vfsmount *, struct dentry___9 *, struct kstat *);
	int (*setxattr)(struct dentry___9 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___9 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___9 *, char *, size_t);
	int (*removexattr)(struct dentry___9 *, const char *);
	int (*fiemap)(struct inode___9 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___9 *, struct timespec *, int);
	int (*atomic_open)(struct inode___9 *, struct dentry___9 *, struct file___8 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___7;

struct file_operations___8 {
	struct module___5 *owner;
	loff_t (*llseek)(struct file___8 *, loff_t, int);
	ssize_t (*read)(struct file___8 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___8 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___8 *, void *, filldir_t);
	unsigned int (*poll)(struct file___8 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___8 *, struct vm_area_struct___11 *);
	int (*open)(struct inode___9 *, struct file___8 *);
	int (*flush)(struct file___8 *, fl_owner_t);
	int (*release)(struct inode___9 *, struct file___8 *);
	int (*fsync)(struct file___8 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___8 *, int);
	int (*lock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*sendpage)(struct file___8 *, struct page___8 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___8 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___8 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___8 *, long int, struct file_lock___8 **, void **);
		struct {
			int (*setlease)(struct file___8 *, long int, struct file_lock___8 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___8 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___7 *, struct file___8 *);
};

struct fasync_struct___8;

struct file_lock_operations___8;

struct lock_manager_operations___8;

struct file_lock___8 {
	struct file_lock___8 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___5 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___8 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___8 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___8 *fl_ops;
	const struct lock_manager_operations___8 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___8 {
	void (*fl_copy_lock)(struct file_lock___8 *, struct file_lock___8 *);
	void (*fl_release_private)(struct file_lock___8 *);
};

struct lock_manager_operations___8 {
	int (*lm_compare_owner)(struct file_lock___8 *, struct file_lock___8 *);
	long unsigned int (*lm_owner_key)(struct file_lock___8 *);
	void (*lm_notify)(struct file_lock___8 *);
	int (*lm_grant)(struct file_lock___8 *, struct file_lock___8 *, int);
	void (*lm_break)(struct file_lock___8 *);
	int (*lm_change)(struct file_lock___8 **, int);
};

struct fasync_struct___8 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___8 *fa_next;
	struct file___8 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___8 {
	const char *name;
	int fs_flags;
	struct dentry___9 * (*mount)(struct file_system_type___8 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___9 *);
	struct module___5 *owner;
	struct file_system_type___8 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___8 {
	struct inode___9 * (*alloc_inode)(struct super_block___9 *);
	void (*destroy_inode)(struct inode___9 *);
	void (*dirty_inode)(struct inode___9 *, int);
	int (*write_inode)(struct inode___9 *, struct writeback_control *);
	int (*drop_inode)(struct inode___9 *);
	void (*evict_inode)(struct inode___9 *);
	void (*put_super)(struct super_block___9 *);
	int (*sync_fs)(struct super_block___9 *, int);
	int (*freeze_fs)(struct super_block___9 *);
	int (*unfreeze_fs)(struct super_block___9 *);
	int (*statfs)(struct dentry___9 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___9 *, int *, char *);
	void (*umount_begin)(struct super_block___9 *);
	int (*show_options)(struct seq_file___7 *, struct dentry___9 *);
	int (*show_devname)(struct seq_file___7 *, struct dentry___9 *);
	int (*show_path)(struct seq_file___7 *, struct dentry___9 *);
	int (*show_stats)(struct seq_file___7 *, struct dentry___9 *);
	ssize_t (*quota_read)(struct super_block___9 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___9 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___9 *);
	int (*bdev_try_to_free_page)(struct super_block___9 *, struct page___8 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___9 *);
	void (*free_cached_objects)(struct super_block___9 *, int);
};

struct seq_operations___7;

struct seq_file___7 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___10 lock;
	const struct seq_operations___7 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___7 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___8 *page;
};

enum pageflags {
	PG_locked = 0,
	PG_error = 1,
	PG_referenced = 2,
	PG_uptodate = 3,
	PG_dirty = 4,
	PG_lru = 5,
	PG_active = 6,
	PG_slab = 7,
	PG_owner_priv_1 = 8,
	PG_arch_1 = 9,
	PG_reserved = 10,
	PG_private = 11,
	PG_private_2 = 12,
	PG_writeback = 13,
	PG_head = 14,
	PG_tail = 15,
	PG_swapcache = 16,
	PG_mappedtodisk = 17,
	PG_reclaim = 18,
	PG_swapbacked = 19,
	PG_unevictable = 20,
	PG_mlocked = 21,
	PG_uncached = 22,
	PG_hwpoison = 23,
	PG_compound_lock = 24,
	__NR_PAGEFLAGS = 25,
	PG_checked = 8,
	PG_fscache = 12,
	PG_pinned = 8,
	PG_savepinned = 4,
	PG_slob_free = 11,
};

typedef int (*pte_fn_t)(pte_t *, pgtable_t___8, long unsigned int, void *);

struct irq_chip___7 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___7 *);
	void (*irq_shutdown)(struct irq_data___7 *);
	void (*irq_enable)(struct irq_data___7 *);
	void (*irq_disable)(struct irq_data___7 *);
	void (*irq_ack)(struct irq_data___7 *);
	void (*irq_mask)(struct irq_data___7 *);
	void (*irq_mask_ack)(struct irq_data___7 *);
	void (*irq_unmask)(struct irq_data___7 *);
	void (*irq_eoi)(struct irq_data___7 *);
	int (*irq_set_affinity)(struct irq_data___7 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___7 *);
	int (*irq_set_type)(struct irq_data___7 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___7 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___7 *);
	void (*irq_bus_sync_unlock)(struct irq_data___7 *);
	void (*irq_cpu_online)(struct irq_data___7 *);
	void (*irq_cpu_offline)(struct irq_data___7 *);
	void (*irq_suspend)(struct irq_data___7 *);
	void (*irq_resume)(struct irq_data___7 *);
	void (*irq_pm_shutdown)(struct irq_data___7 *);
	void (*irq_print_chip)(struct irq_data___7 *, struct seq_file___7 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___7 *, void *);
	long unsigned int flags;
};

struct seq_operations___7 {
	void * (*start)(struct seq_file___7 *, loff_t *);
	void (*stop)(struct seq_file___7 *, void *);
	void * (*next)(struct seq_file___7 *, void *, loff_t *);
	int (*show)(struct seq_file___7 *, void *);
};

struct module_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___4 *, struct module_kobject___4 *, char *);
	ssize_t (*store)(struct module_attribute___4 *, struct module_kobject___4 *, const char *, size_t);
	void (*setup)(struct module___5 *, const char *);
	int (*test)(struct module___5 *);
	void (*free)(struct module___5 *);
};

struct tlb_state___3 {
	struct mm_struct___11 *active_mm;
	int state;
};

struct mmu_update {
	uint64_t ptr;
	uint64_t val;
};

struct xen_hvm_pagetable_dying {
	domid_t domid;
	__u64 gpa;
};

enum hvmmem_type_t {
	HVMMEM_ram_rw = 0,
	HVMMEM_ram_ro = 1,
	HVMMEM_mmio_dm = 2,
};

struct xen_hvm_get_mem_type {
	domid_t domid;
	uint16_t mem_type;
	uint16_t pad[2];
	uint64_t pfn;
};

struct xen_memory_exchange {
	struct xen_memory_reservation in;
	struct xen_memory_reservation out;
	xen_ulong_t nr_exchanged;
};

struct xen_machphys_mapping {
	xen_ulong_t v_start;
	xen_ulong_t v_end;
	xen_ulong_t max_mfn;
};

enum pt_level {
	PT_PGD = 0,
	PT_PUD = 1,
	PT_PMD = 2,
	PT_PTE = 3,
};

struct remap_data {
	long unsigned int mfn;
	pgprot_t prot;
	struct mmu_update *mmu_update;
};

typedef u64 cycle_t;

enum irqreturn {
	IRQ_NONE = 0,
	IRQ_HANDLED = 1,
	IRQ_WAKE_THREAD = 2,
};

typedef enum irqreturn irqreturn_t;

struct x86_cpuinit_ops {
	void (*setup_percpu_clockev)();
	void (*early_percpu_clock_init)();
	void (*fixup_cpu_id)(struct cpuinfo_x86 *, int);
};

struct arch_clocksource_data {
	int vclock_mode;
};

struct clocksource {
	cycle_t (*read)(struct clocksource *);
	cycle_t cycle_last;
	cycle_t mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	struct arch_clocksource_data archdata;
	const char *name;
	struct list_head list;
	int rating;
	int (*enable)(struct clocksource *);
	void (*disable)(struct clocksource *);
	long unsigned int flags;
	void (*suspend)(struct clocksource *);
	void (*resume)(struct clocksource *);
	long: 64;
};

typedef irqreturn_t (*irq_handler_t)(int, void *);

enum clock_event_mode {
	CLOCK_EVT_MODE_UNUSED = 0,
	CLOCK_EVT_MODE_SHUTDOWN = 1,
	CLOCK_EVT_MODE_PERIODIC = 2,
	CLOCK_EVT_MODE_ONESHOT = 3,
	CLOCK_EVT_MODE_RESUME = 4,
};

struct clock_event_device {
	void (*event_handler)(struct clock_event_device *);
	int (*set_next_event)(long unsigned int, struct clock_event_device *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_mode mode;
	unsigned int features;
	long unsigned int retries;
	void (*broadcast)(const struct cpumask *);
	void (*set_mode)(enum clock_event_mode, struct clock_event_device *);
	void (*suspend)(struct clock_event_device *);
	void (*resume)(struct clock_event_device *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module *owner;
	long: 64;
	long: 64;
};

struct vcpu_runstate_info {
	int state;
	uint64_t state_entry_time;
	uint64_t time[4];
};

typedef struct vcpu_runstate_info *__guest_handle_vcpu_runstate_info;

struct vcpu_register_runstate_memory_area {
	union {
		__guest_handle_vcpu_runstate_info h;
		struct vcpu_runstate_info *v;
		uint64_t p;
	} addr;
};

struct vcpu_set_singleshot_timer {
	uint64_t timeout_abs_ns;
	uint32_t flags;
};

struct xen_clock_event_device {
	struct clock_event_device evt;
	char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_struct {
	struct vm_struct *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___8 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

typedef uint16_t grant_status_t;

enum clock_event_nofitiers {
	CLOCK_EVT_NOTIFY_ADD = 0,
	CLOCK_EVT_NOTIFY_BROADCAST_ON = 1,
	CLOCK_EVT_NOTIFY_BROADCAST_OFF = 2,
	CLOCK_EVT_NOTIFY_BROADCAST_FORCE = 3,
	CLOCK_EVT_NOTIFY_BROADCAST_ENTER = 4,
	CLOCK_EVT_NOTIFY_BROADCAST_EXIT = 5,
	CLOCK_EVT_NOTIFY_SUSPEND = 6,
	CLOCK_EVT_NOTIFY_RESUME = 7,
	CLOCK_EVT_NOTIFY_CPU_DYING = 8,
	CLOCK_EVT_NOTIFY_CPU_DEAD = 9,
};

typedef __s16 int16_t;

enum pg_level {
	PG_LEVEL_NONE = 0,
	PG_LEVEL_4K = 1,
	PG_LEVEL_2M = 2,
	PG_LEVEL_1G = 3,
	PG_LEVEL_NUM = 4,
};

typedef uint32_t grant_ref_t;

typedef uint32_t grant_handle_t;

struct gnttab_map_grant_ref {
	uint64_t host_addr;
	uint32_t flags;
	grant_ref_t ref;
	domid_t dom;
	int16_t status;
	grant_handle_t handle;
	uint64_t dev_bus_addr;
};

struct gnttab_unmap_grant_ref {
	uint64_t host_addr;
	uint64_t dev_bus_addr;
	grant_handle_t handle;
	int16_t status;
};

struct page___9;

typedef struct page___9 *pgtable_t___9;

struct address_space___9;

struct kmem_cache___7;

struct page___9 {
	long unsigned int flags;
	struct address_space___9 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___9 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___9 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___7 *slab_cache;
		struct page___9 *first_page;
	};
	long: 64;
};

struct thread_struct___5;

struct task_struct___11;

struct pv_cpu_ops___10 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___11 *);
	void (*end_context_switch)(struct task_struct___11 *);
};

struct perf_event___5;

struct thread_struct___5 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___5 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___6;

struct pid_link___6 {
	struct hlist_node node;
	struct pid___6 *pid;
};

struct mutex___11 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___11 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___8 {
	struct page___9 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___12;

struct nsproxy___6;

struct signal_struct___10;

struct css_set___5;

struct perf_event_context___5;

struct task_struct___11 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___11 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___12 *mm;
	struct mm_struct___12 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___11 *real_parent;
	struct task_struct___11 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___11 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___10 = 0,
		VTIME_USER___10 = 1,
		VTIME_SYS___10 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___6 *nsproxy;
	struct signal_struct___10 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___5 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___5 *perf_event_ctxp[2];
	struct mutex___11 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___8 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___12 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___12 *, struct mm_struct___12 *);
	void (*dup_mmap)(struct mm_struct___12 *, struct mm_struct___12 *);
	void (*exit_mmap)(struct mm_struct___12 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___12 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___12 *);
	void (*pgd_free)(struct mm_struct___12 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___12 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___12 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___12 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___12 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___12 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___12 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___12 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___12 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___12 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___12 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___12 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___11 lock;
	void *vdso;
} mm_context_t___11;

struct xol_area___9;

struct uprobes_state___9 {
	struct xol_area___9 *xol_area;
};

struct vm_area_struct___12;

struct file___9;

struct core_state___10;

struct mm_struct___12 {
	struct vm_area_struct___12 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___12 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___12 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___11 context;
	long unsigned int flags;
	struct core_state___10 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___11 *owner;
	struct file___9 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___9 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___5 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___11 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___11 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___11 *target;
};

typedef void (*perf_overflow_handler_t___5)(struct perf_event___5 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___5;

typedef void (*ftrace_func_t___5)(long unsigned int, long unsigned int, struct ftrace_ops___5 *, struct pt_regs *);

struct ftrace_ops___5 {
	ftrace_func_t___5 func;
	struct ftrace_ops___5 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___11 regex_lock;
};

struct pmu___5;

struct fasync_struct___9;

struct pid_namespace___6;

struct ftrace_event_call___5;

struct perf_cgroup___5;

struct perf_event___5 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___5 *group_leader;
	struct pmu___5 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___5 hw;
	struct perf_event_context___5 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___11 child_mutex;
	struct list_head child_list;
	struct perf_event___5 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___11 *owner;
	struct mutex___11 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___9 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___5 *);
	struct callback_head callback_head;
	struct pid_namespace___6 *ns;
	u64 id;
	perf_overflow_handler_t___5 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___5 ftrace_ops;
	struct perf_cgroup___5 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___3 {
	struct task_struct___11 *task;
	struct exec_domain *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___9 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___9 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___7;

struct memcg_cache_params___7;

struct kmem_cache___7 {
	struct kmem_cache_cpu___7 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___7 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___10;

struct address_space_operations___9;

struct address_space___9 {
	struct inode___10 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___11 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___9 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___10;

struct path___9 {
	struct vfsmount *mnt;
	struct dentry___10 *dentry;
};

struct fown_struct___6 {
	rwlock_t lock;
	struct pid___6 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___9;

struct file___9 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___9 f_path;
	struct inode___10 *f_inode;
	const struct file_operations___9 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___9 *f_mapping;
	struct mutex___11 f_pos_lock;
};

struct vm_operations_struct___10;

struct vm_area_struct___12 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___12 *vm_next;
	struct vm_area_struct___12 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___12 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___10 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___9 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___8;

struct vm_operations_struct___10 {
	void (*open)(struct vm_area_struct___12 *);
	void (*close)(struct vm_area_struct___12 *);
	int (*fault)(struct vm_area_struct___12 *, struct vm_fault___8 *);
	int (*page_mkwrite)(struct vm_area_struct___12 *, struct vm_fault___8 *);
	int (*access)(struct vm_area_struct___12 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___12 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___12 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___12 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___12 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___10 {
	struct task_struct___11 *task;
	struct core_thread___10 *next;
};

struct core_state___10 {
	atomic_t nr_threads;
	struct core_thread___10 dumper;
	struct completion startup;
};

struct irq_data___8;

struct x86_io_apic_ops___8 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___8 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___8;

struct irq_data___8 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___8 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___7;

struct dev_pm_ops___7 {
	int (*prepare)(struct device___7 *);
	void (*complete)(struct device___7 *);
	int (*suspend)(struct device___7 *);
	int (*resume)(struct device___7 *);
	int (*freeze)(struct device___7 *);
	int (*thaw)(struct device___7 *);
	int (*poweroff)(struct device___7 *);
	int (*restore)(struct device___7 *);
	int (*suspend_late)(struct device___7 *);
	int (*resume_early)(struct device___7 *);
	int (*freeze_late)(struct device___7 *);
	int (*thaw_early)(struct device___7 *);
	int (*poweroff_late)(struct device___7 *);
	int (*restore_early)(struct device___7 *);
	int (*suspend_noirq)(struct device___7 *);
	int (*resume_noirq)(struct device___7 *);
	int (*freeze_noirq)(struct device___7 *);
	int (*thaw_noirq)(struct device___7 *);
	int (*poweroff_noirq)(struct device___7 *);
	int (*restore_noirq)(struct device___7 *);
	int (*runtime_suspend)(struct device___7 *);
	int (*runtime_resume)(struct device___7 *);
	int (*runtime_idle)(struct device___7 *);
};

struct device_type___7;

struct bus_type___7;

struct device_driver___7;

struct dev_pm_domain___7;

struct class___7;

struct attribute_group___7;

struct device_rh___7;

struct device___7 {
	struct device___7 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___7 *type;
	struct mutex___11 mutex;
	struct bus_type___7 *bus;
	struct device_driver___7 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___7 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___3 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___7 *class;
	const struct attribute_group___7 **groups;
	void (*release)(struct device___7 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___7 *device_rh;
};

struct dev_pm_info_rh___7 {
	void (*set_latency_tolerance)(struct device___7 *, s32);
};

struct dev_pm_domain___7 {
	struct dev_pm_ops___7 ops;
};

struct smp_ops___10 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___11 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___6 {
	int nr;
	struct pid_namespace___6 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___6 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___11 *child_reaper;
	struct kmem_cache___7 *pid_cachep;
	unsigned int level;
	struct pid_namespace___6 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___10 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___6 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___6 numbers[1];
};

struct zone___10;

struct lruvec___10 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___10 *zone;
};

struct pglist_data___10;

struct zone___10 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___10 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___10 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___10 {
	struct zone___10 *zone;
	int zone_idx;
};

struct zonelist___10 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___10 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___10 {
	struct zone___10 node_zones[4];
	struct zonelist___10 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___11 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___6 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___6 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___10 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___11 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___11 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___11 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___5;

struct css_set___5 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___5 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___5 {
	struct pmu___5 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___11 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___11 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___5 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___9;

struct super_block___10;

struct dentry___10 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___10 *d_parent;
	struct qstr d_name;
	struct inode___10 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___9 *d_op;
	struct super_block___10 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___9;

struct file_lock___9;

struct dquot___9;

struct block_device___9;

struct inode___10 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___9 *i_op;
	struct super_block___10 *i_sb;
	struct address_space___9 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___11 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___9 *i_fop;
	struct file_lock___9 *i_flock;
	struct address_space___9 i_data;
	struct dquot___9 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___9 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___9 {
	int (*d_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_hash)(const struct dentry___10 *, struct qstr *);
	int (*d_compare)(const struct dentry___10 *, const struct dentry___10 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___10 *);
	void (*d_release)(struct dentry___10 *);
	void (*d_prune)(struct dentry___10 *);
	void (*d_iput)(struct dentry___10 *, struct inode___10 *);
	char * (*d_dname)(struct dentry___10 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___9 *);
	int (*d_manage)(struct dentry___10 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___9;

struct mem_dqinfo___9 {
	struct quota_format_type___9 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___9;

struct quota_info___9 {
	unsigned int flags;
	struct mutex___11 dqio_mutex;
	struct mutex___11 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___10 *files[2];
	struct mem_dqinfo___9 info[2];
	const struct quota_format_ops___9 *ops[2];
};

struct file_system_type___9;

struct super_operations___9;

struct dquot_operations___9;

struct quotactl_ops___9;

struct xattr_handler___5;

struct super_block___10 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___9 *s_type;
	const struct super_operations___9 *s_op;
	const struct dquot_operations___9 *dq_op;
	const struct quotactl_ops___9 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___10 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___5 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___9 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___9 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___11 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___9 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___9 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___10 *bd_inode;
	struct super_block___10 *bd_super;
	struct mutex___11 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___9 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___11 bd_fsfreeze_mutex;
};

struct cgroup___5;

struct cgroup_subsys_state___5 {
	struct cgroup___5 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___10 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___9 *ia_file;
};

struct dquot___9 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___11 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___10 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___9 {
	int qf_fmt_id;
	const struct quota_format_ops___9 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___9 *qf_next;
};

struct quota_format_ops___9 {
	int (*check_quota_file)(struct super_block___10 *, int);
	int (*read_file_info)(struct super_block___10 *, int);
	int (*write_file_info)(struct super_block___10 *, int);
	int (*free_file_info)(struct super_block___10 *, int);
	int (*read_dqblk)(struct dquot___9 *);
	int (*commit_dqblk)(struct dquot___9 *);
	int (*release_dqblk)(struct dquot___9 *);
};

struct dquot_operations___9 {
	int (*write_dquot)(struct dquot___9 *);
	struct dquot___9 * (*alloc_dquot)(struct super_block___10 *, int);
	void (*destroy_dquot)(struct dquot___9 *);
	int (*acquire_dquot)(struct dquot___9 *);
	int (*release_dquot)(struct dquot___9 *);
	int (*mark_dirty)(struct dquot___9 *);
	int (*write_info)(struct super_block___10 *, int);
	qsize_t * (*get_reserved_space)(struct inode___10 *);
};

struct quotactl_ops___9 {
	int (*quota_on)(struct super_block___10 *, int, int, struct path___9 *);
	int (*quota_on_meta)(struct super_block___10 *, int, int);
	int (*quota_off)(struct super_block___10 *, int);
	int (*quota_sync)(struct super_block___10 *, int);
	int (*get_info)(struct super_block___10 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___10 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___10 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___10 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___10 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___10 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___10 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___10 *, unsigned int);
};

struct address_space_operations___9 {
	int (*writepage)(struct page___9 *, struct writeback_control *);
	int (*readpage)(struct file___9 *, struct page___9 *);
	int (*writepages)(struct address_space___9 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___9 *);
	int (*readpages)(struct file___9 *, struct address_space___9 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___9 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___9 **, void **);
	int (*write_end)(struct file___9 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___9 *, void *);
	sector_t (*bmap)(struct address_space___9 *, sector_t);
	void (*invalidatepage)(struct page___9 *, long unsigned int);
	int (*releasepage)(struct page___9 *, gfp_t);
	void (*freepage)(struct page___9 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___9 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___9 *, struct page___9 *, struct page___9 *, enum migrate_mode);
	int (*launder_page)(struct page___9 *);
	int (*is_partially_uptodate)(struct page___9 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___9 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___9 *, struct page___9 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___9 *, sector_t *);
	void (*swap_deactivate)(struct file___9 *);
	void (*invalidatepage_range)(struct page___9 *, unsigned int, unsigned int);
};

struct inode_operations___9 {
	struct dentry___10 * (*lookup)(struct inode___10 *, struct dentry___10 *, unsigned int);
	void * (*follow_link)(struct dentry___10 *, struct nameidata *);
	int (*permission)(struct inode___10 *, int);
	struct posix_acl * (*get_acl)(struct inode___10 *, int);
	int (*readlink)(struct dentry___10 *, char *, int);
	void (*put_link)(struct dentry___10 *, struct nameidata *, void *);
	int (*create)(struct inode___10 *, struct dentry___10 *, umode_t, bool);
	int (*link)(struct dentry___10 *, struct inode___10 *, struct dentry___10 *);
	int (*unlink)(struct inode___10 *, struct dentry___10 *);
	int (*symlink)(struct inode___10 *, struct dentry___10 *, const char *);
	int (*mkdir)(struct inode___10 *, struct dentry___10 *, umode_t);
	int (*rmdir)(struct inode___10 *, struct dentry___10 *);
	int (*mknod)(struct inode___10 *, struct dentry___10 *, umode_t, dev_t);
	int (*rename)(struct inode___10 *, struct dentry___10 *, struct inode___10 *, struct dentry___10 *);
	int (*setattr)(struct dentry___10 *, struct iattr___10 *);
	int (*getattr)(struct vfsmount *, struct dentry___10 *, struct kstat *);
	int (*setxattr)(struct dentry___10 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___10 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___10 *, char *, size_t);
	int (*removexattr)(struct dentry___10 *, const char *);
	int (*fiemap)(struct inode___10 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___10 *, struct timespec *, int);
	int (*atomic_open)(struct inode___10 *, struct dentry___10 *, struct file___9 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___5;

struct seq_file___8;

struct file_operations___9 {
	struct module *owner;
	loff_t (*llseek)(struct file___9 *, loff_t, int);
	ssize_t (*read)(struct file___9 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___9 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___9 *, void *, filldir_t);
	unsigned int (*poll)(struct file___9 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___9 *, struct vm_area_struct___12 *);
	int (*open)(struct inode___10 *, struct file___9 *);
	int (*flush)(struct file___9 *, fl_owner_t);
	int (*release)(struct inode___10 *, struct file___9 *);
	int (*fsync)(struct file___9 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___9 *, int);
	int (*lock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*sendpage)(struct file___9 *, struct page___9 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___9 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___9 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___9 *, long int, struct file_lock___9 **, void **);
		struct {
			int (*setlease)(struct file___9 *, long int, struct file_lock___9 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___9 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___8 *, struct file___9 *);
};

struct file_lock_operations___9;

struct lock_manager_operations___9;

struct file_lock___9 {
	struct file_lock___9 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___9 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___9 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___9 *fl_ops;
	const struct lock_manager_operations___9 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___9 {
	void (*fl_copy_lock)(struct file_lock___9 *, struct file_lock___9 *);
	void (*fl_release_private)(struct file_lock___9 *);
};

struct lock_manager_operations___9 {
	int (*lm_compare_owner)(struct file_lock___9 *, struct file_lock___9 *);
	long unsigned int (*lm_owner_key)(struct file_lock___9 *);
	void (*lm_notify)(struct file_lock___9 *);
	int (*lm_grant)(struct file_lock___9 *, struct file_lock___9 *, int);
	void (*lm_break)(struct file_lock___9 *);
	int (*lm_change)(struct file_lock___9 **, int);
};

struct fasync_struct___9 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___9 *fa_next;
	struct file___9 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___9 {
	const char *name;
	int fs_flags;
	struct dentry___10 * (*mount)(struct file_system_type___9 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___10 *);
	struct module *owner;
	struct file_system_type___9 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___9 {
	struct inode___10 * (*alloc_inode)(struct super_block___10 *);
	void (*destroy_inode)(struct inode___10 *);
	void (*dirty_inode)(struct inode___10 *, int);
	int (*write_inode)(struct inode___10 *, struct writeback_control *);
	int (*drop_inode)(struct inode___10 *);
	void (*evict_inode)(struct inode___10 *);
	void (*put_super)(struct super_block___10 *);
	int (*sync_fs)(struct super_block___10 *, int);
	int (*freeze_fs)(struct super_block___10 *);
	int (*unfreeze_fs)(struct super_block___10 *);
	int (*statfs)(struct dentry___10 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___10 *, int *, char *);
	void (*umount_begin)(struct super_block___10 *);
	int (*show_options)(struct seq_file___8 *, struct dentry___10 *);
	int (*show_devname)(struct seq_file___8 *, struct dentry___10 *);
	int (*show_path)(struct seq_file___8 *, struct dentry___10 *);
	int (*show_stats)(struct seq_file___8 *, struct dentry___10 *);
	ssize_t (*quota_read)(struct super_block___10 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___10 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___10 *);
	int (*bdev_try_to_free_page)(struct super_block___10 *, struct page___9 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___10 *);
	void (*free_cached_objects)(struct super_block___10 *, int);
};

struct xattr_handler___5 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___10 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___10 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___10 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___5)(struct file___9 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct poll_table_struct___5 {
	poll_queue_proc___5 _qproc;
	long unsigned int _key;
};

struct seq_operations___8;

struct seq_file___8 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___11 lock;
	const struct seq_operations___8 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___8 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___9 *page;
};

struct seq_operations___8 {
	void * (*start)(struct seq_file___8 *, loff_t *);
	void (*stop)(struct seq_file___8 *, void *);
	void * (*next)(struct seq_file___8 *, void *, loff_t *);
	int (*show)(struct seq_file___8 *, void *);
};

struct ring_buffer_event {
	u32 type_len: 5;
	u32 time_delta: 27;
	u32 array[0];
};

struct irq_chip___8 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___8 *);
	void (*irq_shutdown)(struct irq_data___8 *);
	void (*irq_enable)(struct irq_data___8 *);
	void (*irq_disable)(struct irq_data___8 *);
	void (*irq_ack)(struct irq_data___8 *);
	void (*irq_mask)(struct irq_data___8 *);
	void (*irq_mask_ack)(struct irq_data___8 *);
	void (*irq_unmask)(struct irq_data___8 *);
	void (*irq_eoi)(struct irq_data___8 *);
	int (*irq_set_affinity)(struct irq_data___8 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___8 *);
	int (*irq_set_type)(struct irq_data___8 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___8 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___8 *);
	void (*irq_bus_sync_unlock)(struct irq_data___8 *);
	void (*irq_cpu_online)(struct irq_data___8 *);
	void (*irq_cpu_offline)(struct irq_data___8 *);
	void (*irq_suspend)(struct irq_data___8 *);
	void (*irq_resume)(struct irq_data___8 *);
	void (*irq_pm_shutdown)(struct irq_data___8 *);
	void (*irq_print_chip)(struct irq_data___8 *, struct seq_file___8 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___8 *, void *);
	long unsigned int flags;
};

struct stack_frame {
	struct stack_frame *next_frame;
	long unsigned int return_address;
};

struct bin_attribute___7;

struct attribute_group___7 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___7 **bin_attrs;
};

struct bin_attribute___7 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___9 *, struct kobject *, struct bin_attribute___7 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___9 *, struct kobject *, struct bin_attribute___7 *, char *, loff_t, size_t);
	int (*mmap)(struct file___9 *, struct kobject *, struct bin_attribute___7 *, struct vm_area_struct___12 *);
};

struct bus_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___7 *, char *);
	ssize_t (*store)(struct bus_type___7 *, const char *, size_t);
};

struct device_attribute___7;

struct driver_attribute___7;

struct bus_type___7 {
	const char *name;
	const char *dev_name;
	struct device___7 *dev_root;
	struct bus_attribute___7 *bus_attrs;
	struct device_attribute___7 *dev_attrs;
	struct driver_attribute___7 *drv_attrs;
	const struct attribute_group___7 **bus_groups;
	const struct attribute_group___7 **dev_groups;
	const struct attribute_group___7 **drv_groups;
	int (*match)(struct device___7 *, struct device_driver___7 *);
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	int (*probe)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*online)(struct device___7 *);
	int (*offline)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct dev_pm_ops___7 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct device___7 *, struct device_attribute___7 *, char *);
	ssize_t (*store)(struct device___7 *, struct device_attribute___7 *, const char *, size_t);
};

struct driver_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___7 *, char *);
	ssize_t (*store)(struct device_driver___7 *, const char *, size_t);
};

struct device_driver___7 {
	const char *name;
	struct bus_type___7 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct attribute_group___7 **groups;
	const struct dev_pm_ops___7 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___7 {
	const char *name;
	const struct attribute_group___7 **groups;
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___7 *);
	const struct dev_pm_ops___7 *pm;
};

struct class_attribute___7;

struct class___7 {
	const char *name;
	struct module *owner;
	struct class_attribute___7 *class_attrs;
	struct device_attribute___7 *dev_attrs;
	const struct attribute_group___7 **dev_groups;
	struct bin_attribute___7 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *);
	void (*class_release)(struct class___7 *);
	void (*dev_release)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___7 *);
	const struct dev_pm_ops___7 *pm;
	struct subsys_private *p;
};

struct class_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct class___7 *, struct class_attribute___7 *, char *);
	ssize_t (*store)(struct class___7 *, struct class_attribute___7 *, const char *, size_t);
	const void * (*namespace)(struct class___7 *, const struct class_attribute___7 *);
};

struct device_rh___7 {
	struct dev_pm_info_rh___7 power;
};

struct kmem_cache_cpu___7 {
	void **freelist;
	long unsigned int tid;
	struct page___9 *page;
	struct page___9 *partial;
};

struct memcg_cache_params___7 {
	bool is_root_cache;
	union {
		struct kmem_cache___7 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___7 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___5;

struct cgroup___5 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___5 *parent;
	struct dentry___10 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___5 *subsys[11];
	struct cgroupfs_root___5 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___11 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___5 {
	struct super_block___10 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___5 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___5;

struct pmu___5 {
	struct list_head entry;
	struct device___7 *dev;
	const struct attribute_group___7 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___5 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___5 *);
	void (*pmu_disable)(struct pmu___5 *);
	int (*event_init)(struct perf_event___5 *);
	int (*add)(struct perf_event___5 *, int);
	void (*del)(struct perf_event___5 *, int);
	void (*start)(struct perf_event___5 *, int);
	void (*stop)(struct perf_event___5 *, int);
	void (*read)(struct perf_event___5 *);
	void (*start_txn)(struct pmu___5 *);
	int (*commit_txn)(struct pmu___5 *);
	void (*cancel_txn)(struct pmu___5 *);
	int (*event_idx)(struct perf_event___5 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___5 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___5 *);
};

struct perf_cpu_context___5 {
	struct perf_event_context___5 ctx;
	struct perf_event_context___5 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___5 *unique_pmu;
	struct perf_cgroup___5 *cgrp;
};

struct trace_event_functions___5;

struct trace_event___5 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___5 *funcs;
};

struct ftrace_event_class___5;

struct ftrace_event_call___5 {
	struct list_head list;
	struct ftrace_event_class___5 *class;
	char *name;
	struct trace_event___5 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___5 {
	struct cgroup_subsys_state___5 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___5 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___11 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___5)(struct trace_iterator___5 *, int, struct trace_event___5 *);

struct trace_event_functions___5 {
	trace_print_func___5 trace;
	trace_print_func___5 raw;
	trace_print_func___5 hex;
	trace_print_func___5 binary;
};

struct ftrace_event_class___5 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___5 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___5 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___5 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___5 *);
};

struct ftrace_subsystem_dir;

struct ftrace_event_file {
	struct list_head list;
	struct ftrace_event_call___5 *event_call;
	struct dentry___10 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

enum {
	FILTER_OTHER = 0,
	FILTER_STATIC_STRING = 1,
	FILTER_DYN_STRING = 2,
	FILTER_PTR_STRING = 3,
	FILTER_TRACE_FN = 4,
};

struct ftrace_raw_xen_mc__batch {
	struct trace_entry ent;
	enum paravirt_lazy_mode mode;
	char __data[0];
};

struct ftrace_raw_xen_mc_entry {
	struct trace_entry ent;
	unsigned int op;
	unsigned int nargs;
	long unsigned int args[6];
	char __data[0];
};

struct ftrace_raw_xen_mc_entry_alloc {
	struct trace_entry ent;
	size_t args;
	char __data[0];
};

struct ftrace_raw_xen_mc_callback {
	struct trace_entry ent;
	xen_mc_callback_fn_t fn;
	void *data;
	char __data[0];
};

struct ftrace_raw_xen_mc_flush_reason {
	struct trace_entry ent;
	enum xen_mc_flush_reason reason;
	char __data[0];
};

struct ftrace_raw_xen_mc_flush {
	struct trace_entry ent;
	unsigned int mcidx;
	unsigned int argidx;
	unsigned int cbidx;
	char __data[0];
};

struct ftrace_raw_xen_mc_extend_args {
	struct trace_entry ent;
	unsigned int op;
	size_t args;
	enum xen_mc_extend_args res;
	char __data[0];
};

struct ftrace_raw_xen_mmu__set_pte {
	struct trace_entry ent;
	pte_t *ptep;
	pteval_t pteval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_set_domain_pte {
	struct trace_entry ent;
	pte_t *ptep;
	pteval_t pteval;
	unsigned int domid;
	char __data[0];
};

struct ftrace_raw_xen_mmu_set_pte_at {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	pte_t *ptep;
	pteval_t pteval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_pte_clear {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	pte_t *ptep;
	char __data[0];
};

struct ftrace_raw_xen_mmu_set_pmd {
	struct trace_entry ent;
	pmd_t *pmdp;
	pmdval_t pmdval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_pmd_clear {
	struct trace_entry ent;
	pmd_t *pmdp;
	char __data[0];
};

struct ftrace_raw_xen_mmu_set_pud {
	struct trace_entry ent;
	pud_t *pudp;
	pudval_t pudval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_set_pgd {
	struct trace_entry ent;
	pgd_t *pgdp;
	pgd_t *user_pgdp;
	pgdval_t pgdval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_pud_clear {
	struct trace_entry ent;
	pud_t *pudp;
	char __data[0];
};

struct ftrace_raw_xen_mmu_pgd_clear {
	struct trace_entry ent;
	pgd_t *pgdp;
	char __data[0];
};

struct ftrace_raw_xen_mmu_ptep_modify_prot {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	pte_t *ptep;
	pteval_t pteval;
	char __data[0];
};

struct ftrace_raw_xen_mmu_alloc_ptpage {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int pfn;
	unsigned int level;
	bool pinned;
	char __data[0];
};

struct ftrace_raw_xen_mmu_release_ptpage {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int level;
	bool pinned;
	char __data[0];
};

struct ftrace_raw_xen_mmu_pgd {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	pgd_t *pgd;
	char __data[0];
};

struct ftrace_raw_xen_mmu_flush_tlb_all {
	struct trace_entry ent;
	char x[0];
	char __data[0];
};

struct ftrace_raw_xen_mmu_flush_tlb {
	struct trace_entry ent;
	char x[0];
	char __data[0];
};

struct ftrace_raw_xen_mmu_flush_tlb_single {
	struct trace_entry ent;
	long unsigned int addr;
	char __data[0];
};

struct ftrace_raw_xen_mmu_flush_tlb_others {
	struct trace_entry ent;
	unsigned int ncpus;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	long unsigned int end;
	char __data[0];
};

struct ftrace_raw_xen_mmu_write_cr3 {
	struct trace_entry ent;
	bool kernel;
	long unsigned int cr3;
	char __data[0];
};

struct ftrace_raw_xen_cpu_write_ldt_entry {
	struct trace_entry ent;
	struct desc_struct *dt;
	int entrynum;
	u64 desc;
	char __data[0];
};

struct ftrace_raw_xen_cpu_write_idt_entry {
	struct trace_entry ent;
	gate_desc *dt;
	int entrynum;
	char __data[0];
};

struct ftrace_raw_xen_cpu_load_idt {
	struct trace_entry ent;
	long unsigned int addr;
	char __data[0];
};

struct ftrace_raw_xen_cpu_write_gdt_entry {
	struct trace_entry ent;
	u64 desc;
	struct desc_struct *dt;
	int entrynum;
	int type;
	char __data[0];
};

struct ftrace_raw_xen_cpu_set_ldt {
	struct trace_entry ent;
	const void *addr;
	unsigned int entries;
	char __data[0];
};

struct ftrace_data_offsets_xen_mc__batch {};

struct ftrace_data_offsets_xen_mc_entry {};

struct ftrace_data_offsets_xen_mc_entry_alloc {};

struct ftrace_data_offsets_xen_mc_callback {};

struct ftrace_data_offsets_xen_mc_flush_reason {};

struct ftrace_data_offsets_xen_mc_flush {};

struct ftrace_data_offsets_xen_mc_extend_args {};

struct ftrace_data_offsets_xen_mmu__set_pte {};

struct ftrace_data_offsets_xen_mmu_set_domain_pte {};

struct ftrace_data_offsets_xen_mmu_set_pte_at {};

struct ftrace_data_offsets_xen_mmu_pte_clear {};

struct ftrace_data_offsets_xen_mmu_set_pmd {};

struct ftrace_data_offsets_xen_mmu_pmd_clear {};

struct ftrace_data_offsets_xen_mmu_set_pud {};

struct ftrace_data_offsets_xen_mmu_set_pgd {};

struct ftrace_data_offsets_xen_mmu_pud_clear {};

struct ftrace_data_offsets_xen_mmu_pgd_clear {};

struct ftrace_data_offsets_xen_mmu_ptep_modify_prot {};

struct ftrace_data_offsets_xen_mmu_alloc_ptpage {};

struct ftrace_data_offsets_xen_mmu_release_ptpage {};

struct ftrace_data_offsets_xen_mmu_pgd {};

struct ftrace_data_offsets_xen_mmu_flush_tlb_all {};

struct ftrace_data_offsets_xen_mmu_flush_tlb {};

struct ftrace_data_offsets_xen_mmu_flush_tlb_single {};

struct ftrace_data_offsets_xen_mmu_flush_tlb_others {};

struct ftrace_data_offsets_xen_mmu_write_cr3 {};

struct ftrace_data_offsets_xen_cpu_write_ldt_entry {};

struct ftrace_data_offsets_xen_cpu_write_idt_entry {};

struct ftrace_data_offsets_xen_cpu_load_idt {};

struct ftrace_data_offsets_xen_cpu_write_gdt_entry {};

struct ftrace_data_offsets_xen_cpu_set_ldt {};

struct cpu_user_regs {
	uint64_t r15;
	uint64_t r14;
	uint64_t r13;
	uint64_t r12;
	union {
		uint64_t rbp;
		uint64_t ebp;
		uint32_t _ebp;
	};
	union {
		uint64_t rbx;
		uint64_t ebx;
		uint32_t _ebx;
	};
	uint64_t r11;
	uint64_t r10;
	uint64_t r9;
	uint64_t r8;
	union {
		uint64_t rax;
		uint64_t eax;
		uint32_t _eax;
	};
	union {
		uint64_t rcx;
		uint64_t ecx;
		uint32_t _ecx;
	};
	union {
		uint64_t rdx;
		uint64_t edx;
		uint32_t _edx;
	};
	union {
		uint64_t rsi;
		uint64_t esi;
		uint32_t _esi;
	};
	union {
		uint64_t rdi;
		uint64_t edi;
		uint32_t _edi;
	};
	uint32_t error_code;
	uint32_t entry_vector;
	union {
		uint64_t rip;
		uint64_t eip;
		uint32_t _eip;
	};
	uint16_t cs;
	uint16_t _pad0[1];
	uint8_t saved_upcall_mask;
	uint8_t _pad1[3];
	union {
		uint64_t rflags;
		uint64_t eflags;
		uint32_t _eflags;
	};
	union {
		uint64_t rsp;
		uint64_t esp;
		uint32_t _esp;
	};
	uint16_t ss;
	uint16_t _pad2[3];
	uint16_t es;
	uint16_t _pad3[3];
	uint16_t ds;
	uint16_t _pad4[3];
	uint16_t fs;
	uint16_t _pad5[3];
	uint16_t gs;
	uint16_t _pad6[3];
};

struct vcpu_guest_context {
	struct {
		char x[512];
	} fpu_ctxt;
	long unsigned int flags;
	struct cpu_user_regs user_regs;
	struct trap_info trap_ctxt[256];
	long unsigned int ldt_base;
	long unsigned int ldt_ents;
	long unsigned int gdt_frames[16];
	long unsigned int gdt_ents;
	long unsigned int kernel_ss;
	long unsigned int kernel_sp;
	long unsigned int ctrlreg[8];
	long unsigned int debugreg[8];
	long unsigned int event_callback_eip;
	long unsigned int failsafe_callback_eip;
	long unsigned int syscall_callback_eip;
	long unsigned int vm_assist;
	uint64_t fs_base;
	uint64_t gs_base_kernel;
	uint64_t gs_base_user;
};

typedef struct {
	unsigned int __softirq_pending;
	unsigned int __nmi_count;
	unsigned int apic_timer_irqs;
	unsigned int irq_spurious_count;
	unsigned int icr_read_retry_count;
	unsigned int kvm_posted_intr_ipis;
	unsigned int kvm_posted_intr_wakeup_ipis;
	unsigned int x86_platform_ipis;
	unsigned int apic_perf_irqs;
	unsigned int apic_irq_work_irqs;
	unsigned int irq_resched_count;
	unsigned int irq_call_count;
	unsigned int irq_tlb_count;
	unsigned int irq_thermal_count;
	unsigned int irq_threshold_count;
	int: 32;
} irq_cpustat_t;

enum ipi_vector {
	XEN_RESCHEDULE_VECTOR = 0,
	XEN_CALL_FUNCTION_VECTOR = 1,
	XEN_CALL_FUNCTION_SINGLE_VECTOR = 2,
	XEN_SPIN_UNLOCK_VECTOR = 3,
	XEN_IRQ_WORK_VECTOR = 4,
	XEN_NR_IPIS = 5,
};

struct xen_common_irq {
	int irq;
	char *name;
};

struct page___10;

typedef struct page___10 *pgtable_t___10;

struct address_space___10;

struct kmem_cache___8;

struct page___10 {
	long unsigned int flags;
	struct address_space___10 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___10 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___10 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___8 *slab_cache;
		struct page___10 *first_page;
	};
	long: 64;
};

struct task_struct___12;

struct pv_cpu_ops___11 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___12 *);
	void (*end_context_switch)(struct task_struct___12 *);
};

struct mutex___12 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___12 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___9 {
	struct page___10 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___13;

struct signal_struct___11;

struct task_struct___12 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___12 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___13 *mm;
	struct mm_struct___13 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___12 *real_parent;
	struct task_struct___12 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___12 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___11 = 0,
		VTIME_USER___11 = 1,
		VTIME_SYS___11 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___11 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___12 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___9 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___13 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___13 *, struct mm_struct___13 *);
	void (*dup_mmap)(struct mm_struct___13 *, struct mm_struct___13 *);
	void (*exit_mmap)(struct mm_struct___13 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___13 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___13 *);
	void (*pgd_free)(struct mm_struct___13 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___13 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___13 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___13 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___13 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___13 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___13 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___13 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___13 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___13 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___13 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___13 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___12 lock;
	void *vdso;
} mm_context_t___12;

struct xol_area___10;

struct uprobes_state___10 {
	struct xol_area___10 *xol_area;
};

struct vm_area_struct___13;

struct file___10;

struct core_state___11;

struct mm_struct___13 {
	struct vm_area_struct___13 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___13 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___13 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___12 context;
	long unsigned int flags;
	struct core_state___11 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___12 *owner;
	struct file___10 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___10 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct irq_data___9;

struct x86_io_apic_ops___9 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___9 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___9;

struct irq_data___9 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___9 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___11 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___12 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___11;

struct lruvec___11 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___11 *zone;
};

struct pglist_data___11;

struct zone___11 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___11 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___11 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___11 {
	struct zone___11 *zone;
	int zone_idx;
};

struct zonelist___11 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___11 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___11 {
	struct zone___11 node_zones[4];
	struct zonelist___11 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___12 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc;

typedef void (*irq_flow_handler_t)(unsigned int, struct irq_desc *);

struct irqaction;

struct irq_affinity_notify;

struct irq_desc {
	struct irq_data___9 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct seq_file___9;

struct irq_chip___9 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___9 *);
	void (*irq_shutdown)(struct irq_data___9 *);
	void (*irq_enable)(struct irq_data___9 *);
	void (*irq_disable)(struct irq_data___9 *);
	void (*irq_ack)(struct irq_data___9 *);
	void (*irq_mask)(struct irq_data___9 *);
	void (*irq_mask_ack)(struct irq_data___9 *);
	void (*irq_unmask)(struct irq_data___9 *);
	void (*irq_eoi)(struct irq_data___9 *);
	int (*irq_set_affinity)(struct irq_data___9 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___9 *);
	int (*irq_set_type)(struct irq_data___9 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___9 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___9 *);
	void (*irq_bus_sync_unlock)(struct irq_data___9 *);
	void (*irq_cpu_online)(struct irq_data___9 *);
	void (*irq_cpu_offline)(struct irq_data___9 *);
	void (*irq_suspend)(struct irq_data___9 *);
	void (*irq_resume)(struct irq_data___9 *);
	void (*irq_pm_shutdown)(struct irq_data___9 *);
	void (*irq_print_chip)(struct irq_data___9 *, struct seq_file___9 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___9 *, void *);
	long unsigned int flags;
};

struct seq_operations___9;

struct seq_file___9 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___12 lock;
	const struct seq_operations___9 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irqaction {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction *next;
	irq_handler_t thread_fn;
	struct task_struct___12 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_affinity_notify {
	unsigned int irq;
	struct kref kref;
	struct work_struct work;
	void (*notify)(struct irq_affinity_notify *, const cpumask_t *);
	void (*release)(struct kref *);
};

struct xol_area___10 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___10 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___8;

struct memcg_cache_params___8;

struct kmem_cache___8 {
	struct kmem_cache_cpu___8 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___8 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___11;

struct address_space_operations___10;

struct address_space___10 {
	struct inode___11 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___12 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___10 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___11;

struct path___10 {
	struct vfsmount *mnt;
	struct dentry___11 *dentry;
};

struct file_operations___10;

struct file___10 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___10 f_path;
	struct inode___11 *f_inode;
	const struct file_operations___10 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___10 *f_mapping;
	struct mutex___12 f_pos_lock;
};

struct vm_area_struct___13 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___13 *vm_next;
	struct vm_area_struct___13 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___13 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___10 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___11 {
	struct task_struct___12 *task;
	struct core_thread___11 *next;
};

struct core_state___11 {
	atomic_t nr_threads;
	struct core_thread___11 dumper;
	struct completion startup;
};

struct signal_struct___11 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___12 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___12 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___12 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___10;

struct super_block___11;

struct dentry___11 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___11 *d_parent;
	struct qstr d_name;
	struct inode___11 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___10 *d_op;
	struct super_block___11 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___10;

struct file_lock___10;

struct dquot___10;

struct block_device___10;

struct inode___11 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___10 *i_op;
	struct super_block___11 *i_sb;
	struct address_space___10 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___12 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___10 *i_fop;
	struct file_lock___10 *i_flock;
	struct address_space___10 i_data;
	struct dquot___10 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___10 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___10 {
	int (*d_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_hash)(const struct dentry___11 *, struct qstr *);
	int (*d_compare)(const struct dentry___11 *, const struct dentry___11 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___11 *);
	void (*d_release)(struct dentry___11 *);
	void (*d_prune)(struct dentry___11 *);
	void (*d_iput)(struct dentry___11 *, struct inode___11 *);
	char * (*d_dname)(struct dentry___11 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___10 *);
	int (*d_manage)(struct dentry___11 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___10;

struct mem_dqinfo___10 {
	struct quota_format_type___10 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___10;

struct quota_info___10 {
	unsigned int flags;
	struct mutex___12 dqio_mutex;
	struct mutex___12 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___11 *files[2];
	struct mem_dqinfo___10 info[2];
	const struct quota_format_ops___10 *ops[2];
};

struct file_system_type___10;

struct super_operations___10;

struct dquot_operations___10;

struct quotactl_ops___10;

struct super_block___11 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___10 *s_type;
	const struct super_operations___10 *s_op;
	const struct dquot_operations___10 *dq_op;
	const struct quotactl_ops___10 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___11 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___10 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___10 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___12 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___10 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___10 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___11 *bd_inode;
	struct super_block___11 *bd_super;
	struct mutex___12 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___10 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___12 bd_fsfreeze_mutex;
};

struct iattr___11 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___10 *ia_file;
};

struct dquot___10 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___12 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___11 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___10 {
	int qf_fmt_id;
	const struct quota_format_ops___10 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___10 *qf_next;
};

struct quota_format_ops___10 {
	int (*check_quota_file)(struct super_block___11 *, int);
	int (*read_file_info)(struct super_block___11 *, int);
	int (*write_file_info)(struct super_block___11 *, int);
	int (*free_file_info)(struct super_block___11 *, int);
	int (*read_dqblk)(struct dquot___10 *);
	int (*commit_dqblk)(struct dquot___10 *);
	int (*release_dqblk)(struct dquot___10 *);
};

struct dquot_operations___10 {
	int (*write_dquot)(struct dquot___10 *);
	struct dquot___10 * (*alloc_dquot)(struct super_block___11 *, int);
	void (*destroy_dquot)(struct dquot___10 *);
	int (*acquire_dquot)(struct dquot___10 *);
	int (*release_dquot)(struct dquot___10 *);
	int (*mark_dirty)(struct dquot___10 *);
	int (*write_info)(struct super_block___11 *, int);
	qsize_t * (*get_reserved_space)(struct inode___11 *);
};

struct quotactl_ops___10 {
	int (*quota_on)(struct super_block___11 *, int, int, struct path___10 *);
	int (*quota_on_meta)(struct super_block___11 *, int, int);
	int (*quota_off)(struct super_block___11 *, int);
	int (*quota_sync)(struct super_block___11 *, int);
	int (*get_info)(struct super_block___11 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___11 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___11 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___11 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___11 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___11 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___11 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___11 *, unsigned int);
};

struct address_space_operations___10 {
	int (*writepage)(struct page___10 *, struct writeback_control *);
	int (*readpage)(struct file___10 *, struct page___10 *);
	int (*writepages)(struct address_space___10 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___10 *);
	int (*readpages)(struct file___10 *, struct address_space___10 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___10 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___10 **, void **);
	int (*write_end)(struct file___10 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___10 *, void *);
	sector_t (*bmap)(struct address_space___10 *, sector_t);
	void (*invalidatepage)(struct page___10 *, long unsigned int);
	int (*releasepage)(struct page___10 *, gfp_t);
	void (*freepage)(struct page___10 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___10 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___10 *, struct page___10 *, struct page___10 *, enum migrate_mode);
	int (*launder_page)(struct page___10 *);
	int (*is_partially_uptodate)(struct page___10 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___10 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___10 *, struct page___10 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___10 *, sector_t *);
	void (*swap_deactivate)(struct file___10 *);
	void (*invalidatepage_range)(struct page___10 *, unsigned int, unsigned int);
};

struct inode_operations___10 {
	struct dentry___11 * (*lookup)(struct inode___11 *, struct dentry___11 *, unsigned int);
	void * (*follow_link)(struct dentry___11 *, struct nameidata *);
	int (*permission)(struct inode___11 *, int);
	struct posix_acl * (*get_acl)(struct inode___11 *, int);
	int (*readlink)(struct dentry___11 *, char *, int);
	void (*put_link)(struct dentry___11 *, struct nameidata *, void *);
	int (*create)(struct inode___11 *, struct dentry___11 *, umode_t, bool);
	int (*link)(struct dentry___11 *, struct inode___11 *, struct dentry___11 *);
	int (*unlink)(struct inode___11 *, struct dentry___11 *);
	int (*symlink)(struct inode___11 *, struct dentry___11 *, const char *);
	int (*mkdir)(struct inode___11 *, struct dentry___11 *, umode_t);
	int (*rmdir)(struct inode___11 *, struct dentry___11 *);
	int (*mknod)(struct inode___11 *, struct dentry___11 *, umode_t, dev_t);
	int (*rename)(struct inode___11 *, struct dentry___11 *, struct inode___11 *, struct dentry___11 *);
	int (*setattr)(struct dentry___11 *, struct iattr___11 *);
	int (*getattr)(struct vfsmount *, struct dentry___11 *, struct kstat *);
	int (*setxattr)(struct dentry___11 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___11 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___11 *, char *, size_t);
	int (*removexattr)(struct dentry___11 *, const char *);
	int (*fiemap)(struct inode___11 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___11 *, struct timespec *, int);
	int (*atomic_open)(struct inode___11 *, struct dentry___11 *, struct file___10 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___10 {
	struct module *owner;
	loff_t (*llseek)(struct file___10 *, loff_t, int);
	ssize_t (*read)(struct file___10 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___10 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___10 *, void *, filldir_t);
	unsigned int (*poll)(struct file___10 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___10 *, struct vm_area_struct___13 *);
	int (*open)(struct inode___11 *, struct file___10 *);
	int (*flush)(struct file___10 *, fl_owner_t);
	int (*release)(struct inode___11 *, struct file___10 *);
	int (*fsync)(struct file___10 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___10 *, int);
	int (*lock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*sendpage)(struct file___10 *, struct page___10 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___10 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___10 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___10 *, long int, struct file_lock___10 **, void **);
		struct {
			int (*setlease)(struct file___10 *, long int, struct file_lock___10 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___10 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___9 *, struct file___10 *);
};

struct fasync_struct___10;

struct file_lock_operations___10;

struct lock_manager_operations___10;

struct file_lock___10 {
	struct file_lock___10 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___10 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___10 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___10 *fl_ops;
	const struct lock_manager_operations___10 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___10 {
	void (*fl_copy_lock)(struct file_lock___10 *, struct file_lock___10 *);
	void (*fl_release_private)(struct file_lock___10 *);
};

struct lock_manager_operations___10 {
	int (*lm_compare_owner)(struct file_lock___10 *, struct file_lock___10 *);
	long unsigned int (*lm_owner_key)(struct file_lock___10 *);
	void (*lm_notify)(struct file_lock___10 *);
	int (*lm_grant)(struct file_lock___10 *, struct file_lock___10 *, int);
	void (*lm_break)(struct file_lock___10 *);
	int (*lm_change)(struct file_lock___10 **, int);
};

struct fasync_struct___10 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___10 *fa_next;
	struct file___10 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___10 {
	const char *name;
	int fs_flags;
	struct dentry___11 * (*mount)(struct file_system_type___10 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___11 *);
	struct module *owner;
	struct file_system_type___10 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___10 {
	struct inode___11 * (*alloc_inode)(struct super_block___11 *);
	void (*destroy_inode)(struct inode___11 *);
	void (*dirty_inode)(struct inode___11 *, int);
	int (*write_inode)(struct inode___11 *, struct writeback_control *);
	int (*drop_inode)(struct inode___11 *);
	void (*evict_inode)(struct inode___11 *);
	void (*put_super)(struct super_block___11 *);
	int (*sync_fs)(struct super_block___11 *, int);
	int (*freeze_fs)(struct super_block___11 *);
	int (*unfreeze_fs)(struct super_block___11 *);
	int (*statfs)(struct dentry___11 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___11 *, int *, char *);
	void (*umount_begin)(struct super_block___11 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___11 *);
	ssize_t (*quota_read)(struct super_block___11 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___11 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___11 *);
	int (*bdev_try_to_free_page)(struct super_block___11 *, struct page___10 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___11 *);
	void (*free_cached_objects)(struct super_block___11 *, int);
};

struct seq_operations___9 {
	void * (*start)(struct seq_file___9 *, loff_t *);
	void (*stop)(struct seq_file___9 *, void *);
	void * (*next)(struct seq_file___9 *, void *, loff_t *);
	int (*show)(struct seq_file___9 *, void *);
};

struct kmem_cache_cpu___8 {
	void **freelist;
	long unsigned int tid;
	struct page___10 *page;
	struct page___10 *partial;
};

struct memcg_cache_params___8 {
	bool is_root_cache;
	union {
		struct kmem_cache___8 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___8 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

enum xen_contention_stat {
	TAKEN_SLOW = 0,
	TAKEN_SLOW_PICKUP = 1,
	TAKEN_SLOW_SPURIOUS = 2,
	RELEASED_SLOW = 3,
	RELEASED_SLOW_KICKED = 4,
	NR_CONTENTION_STATS = 5,
};

struct xen_lock_waiting {
	struct arch_spinlock *lock;
	__ticket_t want;
};

struct iommu_table_entry {
	initcall_t detect;
	initcall_t depend;
	void (*early_init)();
	void (*late_init)();
	int flags;
};

struct real_mode_header {
	u32 text_start;
	u32 ro_end;
	u32 trampoline_start;
	u32 trampoline_status;
	u32 trampoline_header;
	u32 trampoline_pgd;
	u32 wakeup_start;
	u32 wakeup_header;
	u32 machine_real_restart_asm;
	u32 machine_real_restart_seg;
};

struct trampoline_header {
	u64 start;
	u64 efer;
	u32 cr4;
};

enum {
	UNAME26 = 131072,
	ADDR_NO_RANDOMIZE = 262144,
	FDPIC_FUNCPTRS = 524288,
	MMAP_PAGE_ZERO = 1048576,
	ADDR_COMPAT_LAYOUT = 2097152,
	READ_IMPLIES_EXEC = 4194304,
	ADDR_LIMIT_32BIT = 8388608,
	SHORT_INODE = 16777216,
	WHOLE_SECONDS = 33554432,
	STICKY_TIMEOUTS = 67108864,
	ADDR_LIMIT_3GB = 134217728,
};

struct exec_domain___2 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___4 *module;
	struct exec_domain___2 *next;
};

struct thread_info___4 {
	struct task_struct___9 *task;
	struct exec_domain___2 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

typedef struct {
	int preload;
} fpu_switch_t;

struct user_desc {
	unsigned int entry_number;
	unsigned int base_addr;
	unsigned int limit;
	unsigned int seg_32bit: 1;
	unsigned int contents: 2;
	unsigned int read_exec_only: 1;
	unsigned int limit_in_pages: 1;
	unsigned int seg_not_present: 1;
	unsigned int useable: 1;
	unsigned int lm: 1;
};

struct sigcontext {
	long unsigned int r8;
	long unsigned int r9;
	long unsigned int r10;
	long unsigned int r11;
	long unsigned int r12;
	long unsigned int r13;
	long unsigned int r14;
	long unsigned int r15;
	long unsigned int di;
	long unsigned int si;
	long unsigned int bp;
	long unsigned int bx;
	long unsigned int dx;
	long unsigned int ax;
	long unsigned int cx;
	long unsigned int sp;
	long unsigned int ip;
	long unsigned int flags;
	short unsigned int cs;
	short unsigned int gs;
	short unsigned int fs;
	short unsigned int __pad0;
	long unsigned int err;
	long unsigned int trapno;
	long unsigned int oldmask;
	long unsigned int cr2;
	void *fpstate;
	long unsigned int reserved1[8];
};

struct sigaltstack {
	void *ss_sp;
	int ss_flags;
	size_t ss_size;
};

typedef struct sigaltstack stack_t;

struct ksignal {
	struct k_sigaction ka;
	siginfo_t info;
	int sig;
};

struct ucontext {
	long unsigned int uc_flags;
	struct ucontext *uc_link;
	stack_t uc_stack;
	struct sigcontext uc_mcontext;
	sigset_t uc_sigmask;
};

typedef u32 compat_sigset_word;

typedef struct {
	compat_sigset_word sig[2];
} compat_sigset_t;

struct rt_sigframe {
	char *pretcode;
	struct ucontext uc;
	struct siginfo info;
};

struct page___11;

typedef struct page___11 *pgtable_t___11;

struct address_space___11;

struct kmem_cache___9;

struct page___11 {
	long unsigned int flags;
	struct address_space___11 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___11 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___11 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___9 *slab_cache;
		struct page___11 *first_page;
	};
	long: 64;
};

struct task_struct___13;

struct pv_cpu_ops___12 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___13 *);
	void (*end_context_switch)(struct task_struct___13 *);
};

struct mutex___13 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___13 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___10 {
	struct page___11 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___14;

struct signal_struct___12;

struct task_struct___13 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___13 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___14 *mm;
	struct mm_struct___14 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___13 *real_parent;
	struct task_struct___13 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___13 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___12 = 0,
		VTIME_USER___12 = 1,
		VTIME_SYS___12 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___12 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___13 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___10 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___14 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___14 *, struct mm_struct___14 *);
	void (*dup_mmap)(struct mm_struct___14 *, struct mm_struct___14 *);
	void (*exit_mmap)(struct mm_struct___14 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___14 *);
	void (*pgd_free)(struct mm_struct___14 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___14 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___14 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___14 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___14 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___14 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___14 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___14 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___14 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___14 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___14 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___14 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___13 lock;
	void *vdso;
} mm_context_t___13;

struct xol_area___11;

struct uprobes_state___11 {
	struct xol_area___11 *xol_area;
};

struct vm_area_struct___14;

struct file___11;

struct core_state___12;

struct mm_struct___14 {
	struct vm_area_struct___14 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___14 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___14 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___13 context;
	long unsigned int flags;
	struct core_state___12 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___13 *owner;
	struct file___11 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___11 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___6;

struct exec_domain___3 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___6 *module;
	struct exec_domain___3 *next;
};

struct module_kobject___5 {
	struct kobject kobj;
	struct module___6 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___5;

struct module___6 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___5 mkobj;
	struct module_attribute___5 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___13 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___5 {
	struct task_struct___13 *task;
	struct exec_domain___3 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___11 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___11 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___9;

struct memcg_cache_params___9;

struct kmem_cache___9 {
	struct kmem_cache_cpu___9 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___9 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___12;

struct address_space_operations___11;

struct address_space___11 {
	struct inode___12 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___13 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___11 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___12;

struct path___11 {
	struct vfsmount *mnt;
	struct dentry___12 *dentry;
};

struct file_operations___11;

struct file___11 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___11 f_path;
	struct inode___12 *f_inode;
	const struct file_operations___11 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___11 *f_mapping;
	struct mutex___13 f_pos_lock;
};

struct vm_operations_struct___11;

struct vm_area_struct___14 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___14 *vm_next;
	struct vm_area_struct___14 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___14 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___11 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___11 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___9;

struct vm_operations_struct___11 {
	void (*open)(struct vm_area_struct___14 *);
	void (*close)(struct vm_area_struct___14 *);
	int (*fault)(struct vm_area_struct___14 *, struct vm_fault___9 *);
	int (*page_mkwrite)(struct vm_area_struct___14 *, struct vm_fault___9 *);
	int (*access)(struct vm_area_struct___14 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___14 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___14 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___14 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___14 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___12 {
	struct task_struct___13 *task;
	struct core_thread___12 *next;
};

struct core_state___12 {
	atomic_t nr_threads;
	struct core_thread___12 dumper;
	struct completion startup;
};

struct irq_data___10;

struct x86_io_apic_ops___10 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___10 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___10;

struct irq_data___10 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___10 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___12 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___13 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___12;

struct lruvec___12 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___12 *zone;
};

struct pglist_data___12;

struct zone___12 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___12 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___12 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___12 {
	struct zone___12 *zone;
	int zone_idx;
};

struct zonelist___12 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___12 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___12 {
	struct zone___12 node_zones[4];
	struct zonelist___12 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___13 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___12 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___13 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___13 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___13 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_file___10;

struct irq_chip___10 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___10 *);
	void (*irq_shutdown)(struct irq_data___10 *);
	void (*irq_enable)(struct irq_data___10 *);
	void (*irq_disable)(struct irq_data___10 *);
	void (*irq_ack)(struct irq_data___10 *);
	void (*irq_mask)(struct irq_data___10 *);
	void (*irq_mask_ack)(struct irq_data___10 *);
	void (*irq_unmask)(struct irq_data___10 *);
	void (*irq_eoi)(struct irq_data___10 *);
	int (*irq_set_affinity)(struct irq_data___10 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___10 *);
	int (*irq_set_type)(struct irq_data___10 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___10 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___10 *);
	void (*irq_bus_sync_unlock)(struct irq_data___10 *);
	void (*irq_cpu_online)(struct irq_data___10 *);
	void (*irq_cpu_offline)(struct irq_data___10 *);
	void (*irq_suspend)(struct irq_data___10 *);
	void (*irq_resume)(struct irq_data___10 *);
	void (*irq_pm_shutdown)(struct irq_data___10 *);
	void (*irq_print_chip)(struct irq_data___10 *, struct seq_file___10 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___10 *, void *);
	long unsigned int flags;
};

struct seq_operations___10;

struct seq_file___10 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___13 lock;
	const struct seq_operations___10 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___11;

struct super_block___12;

struct dentry___12 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___12 *d_parent;
	struct qstr d_name;
	struct inode___12 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___11 *d_op;
	struct super_block___12 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___11;

struct file_lock___11;

struct dquot___11;

struct block_device___11;

struct cdev___3;

struct inode___12 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___11 *i_op;
	struct super_block___12 *i_sb;
	struct address_space___11 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___13 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___11 *i_fop;
	struct file_lock___11 *i_flock;
	struct address_space___11 i_data;
	struct dquot___11 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___11 *i_bdev;
		struct cdev___3 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___11 {
	int (*d_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_hash)(const struct dentry___12 *, struct qstr *);
	int (*d_compare)(const struct dentry___12 *, const struct dentry___12 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___12 *);
	void (*d_release)(struct dentry___12 *);
	void (*d_prune)(struct dentry___12 *);
	void (*d_iput)(struct dentry___12 *, struct inode___12 *);
	char * (*d_dname)(struct dentry___12 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___11 *);
	int (*d_manage)(struct dentry___12 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___11;

struct mem_dqinfo___11 {
	struct quota_format_type___11 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___11;

struct quota_info___11 {
	unsigned int flags;
	struct mutex___13 dqio_mutex;
	struct mutex___13 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___12 *files[2];
	struct mem_dqinfo___11 info[2];
	const struct quota_format_ops___11 *ops[2];
};

struct file_system_type___11;

struct super_operations___11;

struct dquot_operations___11;

struct quotactl_ops___11;

struct super_block___12 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___11 *s_type;
	const struct super_operations___11 *s_op;
	const struct dquot_operations___11 *dq_op;
	const struct quotactl_ops___11 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___12 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___11 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___11 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___13 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___11 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___11 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___12 *bd_inode;
	struct super_block___12 *bd_super;
	struct mutex___13 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___11 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___13 bd_fsfreeze_mutex;
};

struct iattr___12 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___11 *ia_file;
};

struct dquot___11 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___13 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___12 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___11 {
	int qf_fmt_id;
	const struct quota_format_ops___11 *qf_ops;
	struct module___6 *qf_owner;
	struct quota_format_type___11 *qf_next;
};

struct quota_format_ops___11 {
	int (*check_quota_file)(struct super_block___12 *, int);
	int (*read_file_info)(struct super_block___12 *, int);
	int (*write_file_info)(struct super_block___12 *, int);
	int (*free_file_info)(struct super_block___12 *, int);
	int (*read_dqblk)(struct dquot___11 *);
	int (*commit_dqblk)(struct dquot___11 *);
	int (*release_dqblk)(struct dquot___11 *);
};

struct dquot_operations___11 {
	int (*write_dquot)(struct dquot___11 *);
	struct dquot___11 * (*alloc_dquot)(struct super_block___12 *, int);
	void (*destroy_dquot)(struct dquot___11 *);
	int (*acquire_dquot)(struct dquot___11 *);
	int (*release_dquot)(struct dquot___11 *);
	int (*mark_dirty)(struct dquot___11 *);
	int (*write_info)(struct super_block___12 *, int);
	qsize_t * (*get_reserved_space)(struct inode___12 *);
};

struct quotactl_ops___11 {
	int (*quota_on)(struct super_block___12 *, int, int, struct path___11 *);
	int (*quota_on_meta)(struct super_block___12 *, int, int);
	int (*quota_off)(struct super_block___12 *, int);
	int (*quota_sync)(struct super_block___12 *, int);
	int (*get_info)(struct super_block___12 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___12 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___12 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___12 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___12 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___12 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___12 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___12 *, unsigned int);
};

struct address_space_operations___11 {
	int (*writepage)(struct page___11 *, struct writeback_control *);
	int (*readpage)(struct file___11 *, struct page___11 *);
	int (*writepages)(struct address_space___11 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___11 *);
	int (*readpages)(struct file___11 *, struct address_space___11 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___11 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___11 **, void **);
	int (*write_end)(struct file___11 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___11 *, void *);
	sector_t (*bmap)(struct address_space___11 *, sector_t);
	void (*invalidatepage)(struct page___11 *, long unsigned int);
	int (*releasepage)(struct page___11 *, gfp_t);
	void (*freepage)(struct page___11 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___11 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___11 *, struct page___11 *, struct page___11 *, enum migrate_mode);
	int (*launder_page)(struct page___11 *);
	int (*is_partially_uptodate)(struct page___11 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___11 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___11 *, struct page___11 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___11 *, sector_t *);
	void (*swap_deactivate)(struct file___11 *);
	void (*invalidatepage_range)(struct page___11 *, unsigned int, unsigned int);
};

struct cdev___3 {
	struct kobject kobj;
	struct module___6 *owner;
	const struct file_operations___11 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___11 {
	struct dentry___12 * (*lookup)(struct inode___12 *, struct dentry___12 *, unsigned int);
	void * (*follow_link)(struct dentry___12 *, struct nameidata *);
	int (*permission)(struct inode___12 *, int);
	struct posix_acl * (*get_acl)(struct inode___12 *, int);
	int (*readlink)(struct dentry___12 *, char *, int);
	void (*put_link)(struct dentry___12 *, struct nameidata *, void *);
	int (*create)(struct inode___12 *, struct dentry___12 *, umode_t, bool);
	int (*link)(struct dentry___12 *, struct inode___12 *, struct dentry___12 *);
	int (*unlink)(struct inode___12 *, struct dentry___12 *);
	int (*symlink)(struct inode___12 *, struct dentry___12 *, const char *);
	int (*mkdir)(struct inode___12 *, struct dentry___12 *, umode_t);
	int (*rmdir)(struct inode___12 *, struct dentry___12 *);
	int (*mknod)(struct inode___12 *, struct dentry___12 *, umode_t, dev_t);
	int (*rename)(struct inode___12 *, struct dentry___12 *, struct inode___12 *, struct dentry___12 *);
	int (*setattr)(struct dentry___12 *, struct iattr___12 *);
	int (*getattr)(struct vfsmount *, struct dentry___12 *, struct kstat *);
	int (*setxattr)(struct dentry___12 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___12 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___12 *, char *, size_t);
	int (*removexattr)(struct dentry___12 *, const char *);
	int (*fiemap)(struct inode___12 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___12 *, struct timespec *, int);
	int (*atomic_open)(struct inode___12 *, struct dentry___12 *, struct file___11 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___6;

struct file_operations___11 {
	struct module___6 *owner;
	loff_t (*llseek)(struct file___11 *, loff_t, int);
	ssize_t (*read)(struct file___11 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___11 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___11 *, void *, filldir_t);
	unsigned int (*poll)(struct file___11 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___11 *, struct vm_area_struct___14 *);
	int (*open)(struct inode___12 *, struct file___11 *);
	int (*flush)(struct file___11 *, fl_owner_t);
	int (*release)(struct inode___12 *, struct file___11 *);
	int (*fsync)(struct file___11 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___11 *, int);
	int (*lock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*sendpage)(struct file___11 *, struct page___11 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___11 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___11 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___11 *, long int, struct file_lock___11 **, void **);
		struct {
			int (*setlease)(struct file___11 *, long int, struct file_lock___11 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___11 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___10 *, struct file___11 *);
};

struct fasync_struct___11;

struct file_lock_operations___11;

struct lock_manager_operations___11;

struct file_lock___11 {
	struct file_lock___11 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___11 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___11 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___11 *fl_ops;
	const struct lock_manager_operations___11 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___11 {
	void (*fl_copy_lock)(struct file_lock___11 *, struct file_lock___11 *);
	void (*fl_release_private)(struct file_lock___11 *);
};

struct lock_manager_operations___11 {
	int (*lm_compare_owner)(struct file_lock___11 *, struct file_lock___11 *);
	long unsigned int (*lm_owner_key)(struct file_lock___11 *);
	void (*lm_notify)(struct file_lock___11 *);
	int (*lm_grant)(struct file_lock___11 *, struct file_lock___11 *, int);
	void (*lm_break)(struct file_lock___11 *);
	int (*lm_change)(struct file_lock___11 **, int);
};

struct fasync_struct___11 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___11 *fa_next;
	struct file___11 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___11 {
	const char *name;
	int fs_flags;
	struct dentry___12 * (*mount)(struct file_system_type___11 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___12 *);
	struct module___6 *owner;
	struct file_system_type___11 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___11 {
	struct inode___12 * (*alloc_inode)(struct super_block___12 *);
	void (*destroy_inode)(struct inode___12 *);
	void (*dirty_inode)(struct inode___12 *, int);
	int (*write_inode)(struct inode___12 *, struct writeback_control *);
	int (*drop_inode)(struct inode___12 *);
	void (*evict_inode)(struct inode___12 *);
	void (*put_super)(struct super_block___12 *);
	int (*sync_fs)(struct super_block___12 *, int);
	int (*freeze_fs)(struct super_block___12 *);
	int (*unfreeze_fs)(struct super_block___12 *);
	int (*statfs)(struct dentry___12 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___12 *, int *, char *);
	void (*umount_begin)(struct super_block___12 *);
	int (*show_options)(struct seq_file___10 *, struct dentry___12 *);
	int (*show_devname)(struct seq_file___10 *, struct dentry___12 *);
	int (*show_path)(struct seq_file___10 *, struct dentry___12 *);
	int (*show_stats)(struct seq_file___10 *, struct dentry___12 *);
	ssize_t (*quota_read)(struct super_block___12 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___12 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___12 *);
	int (*bdev_try_to_free_page)(struct super_block___12 *, struct page___11 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___12 *);
	void (*free_cached_objects)(struct super_block___12 *, int);
};

typedef void (*poll_queue_proc___6)(struct file___11 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct poll_table_struct___6 {
	poll_queue_proc___6 _qproc;
	long unsigned int _key;
};

struct kprobe_insn_cache___2 {
	struct mutex___13 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

enum die_val {
	DIE_OOPS = 1,
	DIE_INT3 = 2,
	DIE_DEBUG = 3,
	DIE_PANIC = 4,
	DIE_NMI = 5,
	DIE_DIE = 6,
	DIE_KERNELDEBUG = 7,
	DIE_TRAP = 8,
	DIE_GPF = 9,
	DIE_CALL = 10,
	DIE_PAGE_FAULT = 11,
	DIE_NMIUNKNOWN = 12,
};

struct module_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___5 *, struct module_kobject___5 *, char *);
	ssize_t (*store)(struct module_attribute___5 *, struct module_kobject___5 *, const char *, size_t);
	void (*setup)(struct module___6 *, const char *);
	int (*test)(struct module___6 *);
	void (*free)(struct module___6 *);
};

struct vm_fault___9 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___11 *page;
};

struct seq_operations___10 {
	void * (*start)(struct seq_file___10 *, loff_t *);
	void (*stop)(struct seq_file___10 *, void *);
	void * (*next)(struct seq_file___10 *, void *, loff_t *);
	int (*show)(struct seq_file___10 *, void *);
};

enum {
	X86_TRAP_DE = 0,
	X86_TRAP_DB = 1,
	X86_TRAP_NMI = 2,
	X86_TRAP_BP = 3,
	X86_TRAP_OF = 4,
	X86_TRAP_BR = 5,
	X86_TRAP_UD = 6,
	X86_TRAP_NM = 7,
	X86_TRAP_DF = 8,
	X86_TRAP_OLD_MF = 9,
	X86_TRAP_TS = 10,
	X86_TRAP_NP = 11,
	X86_TRAP_SS = 12,
	X86_TRAP_GP = 13,
	X86_TRAP_PF = 14,
	X86_TRAP_SPURIOUS = 15,
	X86_TRAP_MF = 16,
	X86_TRAP_AC = 17,
	X86_TRAP_MC = 18,
	X86_TRAP_XF = 19,
	X86_TRAP_IRET = 32,
};

struct kmem_cache_cpu___9 {
	void **freelist;
	long unsigned int tid;
	struct page___11 *page;
	struct page___11 *partial;
};

struct memcg_cache_params___9 {
	bool is_root_cache;
	union {
		struct kmem_cache___9 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___9 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct page___12;

typedef struct page___12 *pgtable_t___12;

struct address_space___12;

struct kmem_cache___10;

struct page___12 {
	long unsigned int flags;
	struct address_space___12 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___12 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___12 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___10 *slab_cache;
		struct page___12 *first_page;
	};
	long: 64;
};

struct thread_struct___6;

struct task_struct___14;

struct pv_cpu_ops___13 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___6 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___6 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___14 *);
	void (*end_context_switch)(struct task_struct___14 *);
};

struct perf_event___6;

struct thread_struct___6 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___6 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___7;

struct pid_link___7 {
	struct hlist_node node;
	struct pid___7 *pid;
};

struct mutex___14 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___14 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___11 {
	struct page___12 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___15;

struct nsproxy___7;

struct signal_struct___13;

struct css_set___6;

struct perf_event_context___6;

struct task_struct___14 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___14 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___15 *mm;
	struct mm_struct___15 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___14 *real_parent;
	struct task_struct___14 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___14 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___7 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___13 = 0,
		VTIME_USER___13 = 1,
		VTIME_SYS___13 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___6 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___7 *nsproxy;
	struct signal_struct___13 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___6 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___6 *perf_event_ctxp[2];
	struct mutex___14 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___11 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___15 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___15 *, struct mm_struct___15 *);
	void (*dup_mmap)(struct mm_struct___15 *, struct mm_struct___15 *);
	void (*exit_mmap)(struct mm_struct___15 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___15 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___15 *);
	void (*pgd_free)(struct mm_struct___15 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___15 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___15 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___15 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___15 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___15 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___15 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___15 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___15 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___15 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___15 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___15 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___14 lock;
	void *vdso;
} mm_context_t___14;

struct xol_area___12;

struct uprobes_state___12 {
	struct xol_area___12 *xol_area;
};

struct vm_area_struct___15;

struct file___12;

struct core_state___13;

struct mm_struct___15 {
	struct vm_area_struct___15 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___15 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___15 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___14 context;
	long unsigned int flags;
	struct core_state___13 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___14 *owner;
	struct file___12 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___12 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___6 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___14 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___14 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___14 *target;
};

typedef void (*perf_overflow_handler_t___6)(struct perf_event___6 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___6;

typedef void (*ftrace_func_t___6)(long unsigned int, long unsigned int, struct ftrace_ops___6 *, struct pt_regs *);

struct ftrace_ops___6 {
	ftrace_func_t___6 func;
	struct ftrace_ops___6 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___14 regex_lock;
};

struct pmu___6;

struct fasync_struct___12;

struct pid_namespace___7;

struct ftrace_event_call___6;

struct perf_cgroup___6;

struct perf_event___6 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___6 *group_leader;
	struct pmu___6 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___6 hw;
	struct perf_event_context___6 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___14 child_mutex;
	struct list_head child_list;
	struct perf_event___6 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___14 *owner;
	struct mutex___14 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___12 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___6 *);
	struct callback_head callback_head;
	struct pid_namespace___7 *ns;
	u64 id;
	perf_overflow_handler_t___6 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___6 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___6 ftrace_ops;
	struct perf_cgroup___6 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___6 {
	struct task_struct___14 *task;
	struct exec_domain___3 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___8;

struct attribute_group___8 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___8 **bin_attrs;
};

struct bin_attribute___8 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___12 *, struct kobject *, struct bin_attribute___8 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___12 *, struct kobject *, struct bin_attribute___8 *, char *, loff_t, size_t);
	int (*mmap)(struct file___12 *, struct kobject *, struct bin_attribute___8 *, struct vm_area_struct___15 *);
};

struct dentry___13;

struct path___12 {
	struct vfsmount *mnt;
	struct dentry___13 *dentry;
};

struct fown_struct___7 {
	rwlock_t lock;
	struct pid___7 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___13;

struct file_operations___12;

struct file___12 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___12 f_path;
	struct inode___13 *f_inode;
	const struct file_operations___12 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___12 *f_mapping;
	struct mutex___14 f_pos_lock;
};

struct vm_operations_struct___12;

struct vm_area_struct___15 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___15 *vm_next;
	struct vm_area_struct___15 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___15 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___12 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___12 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___8;

struct dev_pm_ops___8 {
	int (*prepare)(struct device___8 *);
	void (*complete)(struct device___8 *);
	int (*suspend)(struct device___8 *);
	int (*resume)(struct device___8 *);
	int (*freeze)(struct device___8 *);
	int (*thaw)(struct device___8 *);
	int (*poweroff)(struct device___8 *);
	int (*restore)(struct device___8 *);
	int (*suspend_late)(struct device___8 *);
	int (*resume_early)(struct device___8 *);
	int (*freeze_late)(struct device___8 *);
	int (*thaw_early)(struct device___8 *);
	int (*poweroff_late)(struct device___8 *);
	int (*restore_early)(struct device___8 *);
	int (*suspend_noirq)(struct device___8 *);
	int (*resume_noirq)(struct device___8 *);
	int (*freeze_noirq)(struct device___8 *);
	int (*thaw_noirq)(struct device___8 *);
	int (*poweroff_noirq)(struct device___8 *);
	int (*restore_noirq)(struct device___8 *);
	int (*runtime_suspend)(struct device___8 *);
	int (*runtime_resume)(struct device___8 *);
	int (*runtime_idle)(struct device___8 *);
};

struct device_type___8;

struct bus_type___8;

struct device_driver___8;

struct dev_pm_domain___8;

struct device_node___2;

struct class___8;

struct device_rh___8;

struct device___8 {
	struct device___8 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___8 *type;
	struct mutex___14 mutex;
	struct bus_type___8 *bus;
	struct device_driver___8 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___8 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___8 *class;
	const struct attribute_group___8 **groups;
	void (*release)(struct device___8 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___8 *device_rh;
};

struct dev_pm_info_rh___8 {
	void (*set_latency_tolerance)(struct device___8 *, s32);
};

struct dev_pm_domain___8 {
	struct dev_pm_ops___8 ops;
};

struct ratelimit_state {
	raw_spinlock_t lock;
	int interval;
	int burst;
	int printed;
	int missed;
	long unsigned int begin;
};

struct zone___13;

struct lruvec___13 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___13 *zone;
};

struct pglist_data___13;

struct zone___13 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___13 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___13 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___13 {
	struct zone___13 *zone;
	int zone_idx;
};

struct zonelist___13 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___13 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___13 {
	struct zone___13 node_zones[4];
	struct zonelist___13 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___14 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___11;

struct x86_io_apic_ops___11 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___11 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___11;

struct irq_data___11 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___11 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

typedef u32 phandle;

struct property;

struct device_node___2 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property *properties;
	struct property *deadprops;
	struct device_node___2 *parent;
	struct device_node___2 *child;
	struct device_node___2 *sibling;
	struct device_node___2 *next;
	struct device_node___2 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct smp_ops___13 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___14 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___8 *, char *);
	ssize_t (*store)(struct bus_type___8 *, const char *, size_t);
};

struct device_attribute___8;

struct driver_attribute___8;

struct bus_type___8 {
	const char *name;
	const char *dev_name;
	struct device___8 *dev_root;
	struct bus_attribute___8 *bus_attrs;
	struct device_attribute___8 *dev_attrs;
	struct driver_attribute___8 *drv_attrs;
	const struct attribute_group___8 **bus_groups;
	const struct attribute_group___8 **dev_groups;
	const struct attribute_group___8 **drv_groups;
	int (*match)(struct device___8 *, struct device_driver___8 *);
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	int (*probe)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*online)(struct device___8 *);
	int (*offline)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct dev_pm_ops___8 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct device___8 *, struct device_attribute___8 *, char *);
	ssize_t (*store)(struct device___8 *, struct device_attribute___8 *, const char *, size_t);
};

struct driver_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___8 *, char *);
	ssize_t (*store)(struct device_driver___8 *, const char *, size_t);
};

struct device_driver___8 {
	const char *name;
	struct bus_type___8 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct attribute_group___8 **groups;
	const struct dev_pm_ops___8 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___8 {
	const char *name;
	const struct attribute_group___8 **groups;
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___8 *);
	const struct dev_pm_ops___8 *pm;
};

struct class_attribute___8;

struct class___8 {
	const char *name;
	struct module *owner;
	struct class_attribute___8 *class_attrs;
	struct device_attribute___8 *dev_attrs;
	const struct attribute_group___8 **dev_groups;
	struct bin_attribute___8 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *);
	void (*class_release)(struct class___8 *);
	void (*dev_release)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___8 *);
	const struct dev_pm_ops___8 *pm;
	struct subsys_private *p;
};

struct class_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct class___8 *, struct class_attribute___8 *, char *);
	ssize_t (*store)(struct class___8 *, struct class_attribute___8 *, const char *, size_t);
	const void * (*namespace)(struct class___8 *, const struct class_attribute___8 *);
};

struct device_rh___8 {
	struct dev_pm_info_rh___8 power;
};

struct irq_desc___2;

typedef void (*irq_flow_handler_t___2)(unsigned int, struct irq_desc___2 *);

struct irqaction___2;

struct irq_desc___2 {
	struct irq_data___11 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___2 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct seq_file___11;

struct irq_chip___11 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___11 *);
	void (*irq_shutdown)(struct irq_data___11 *);
	void (*irq_enable)(struct irq_data___11 *);
	void (*irq_disable)(struct irq_data___11 *);
	void (*irq_ack)(struct irq_data___11 *);
	void (*irq_mask)(struct irq_data___11 *);
	void (*irq_mask_ack)(struct irq_data___11 *);
	void (*irq_unmask)(struct irq_data___11 *);
	void (*irq_eoi)(struct irq_data___11 *);
	int (*irq_set_affinity)(struct irq_data___11 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___11 *);
	int (*irq_set_type)(struct irq_data___11 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___11 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___11 *);
	void (*irq_bus_sync_unlock)(struct irq_data___11 *);
	void (*irq_cpu_online)(struct irq_data___11 *);
	void (*irq_cpu_offline)(struct irq_data___11 *);
	void (*irq_suspend)(struct irq_data___11 *);
	void (*irq_resume)(struct irq_data___11 *);
	void (*irq_pm_shutdown)(struct irq_data___11 *);
	void (*irq_print_chip)(struct irq_data___11 *, struct seq_file___11 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___11 *, void *);
	long unsigned int flags;
};

enum {
	IRQD_TRIGGER_MASK = 15,
	IRQD_SETAFFINITY_PENDING = 256,
	IRQD_NO_BALANCING = 1024,
	IRQD_PER_CPU = 2048,
	IRQD_AFFINITY_SET = 4096,
	IRQD_LEVEL = 8192,
	IRQD_WAKEUP_STATE = 16384,
	IRQD_MOVE_PCNTXT = 32768,
	IRQD_IRQ_DISABLED = 65536,
	IRQD_IRQ_MASKED = 131072,
	IRQD_IRQ_INPROGRESS = 262144,
};

struct seq_operations___11;

struct seq_file___11 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___14 lock;
	const struct seq_operations___11 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irqaction___2 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___2 *next;
	irq_handler_t thread_fn;
	struct task_struct___14 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int vector_irq_t[256];

typedef struct {
	unsigned int irq_hv_callback_count;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
} rh_irq_cpustat_t;

struct xol_area___12 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___12 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___10;

struct memcg_cache_params___10;

struct kmem_cache___10 {
	struct kmem_cache_cpu___10 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___10 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___12;

struct address_space___12 {
	struct inode___13 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___14 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___12 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___10;

struct vm_operations_struct___12 {
	void (*open)(struct vm_area_struct___15 *);
	void (*close)(struct vm_area_struct___15 *);
	int (*fault)(struct vm_area_struct___15 *, struct vm_fault___10 *);
	int (*page_mkwrite)(struct vm_area_struct___15 *, struct vm_fault___10 *);
	int (*access)(struct vm_area_struct___15 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___15 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___15 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___15 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___15 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___13 {
	struct task_struct___14 *task;
	struct core_thread___13 *next;
};

struct core_state___13 {
	atomic_t nr_threads;
	struct core_thread___13 dumper;
	struct completion startup;
};

struct upid___7 {
	int nr;
	struct pid_namespace___7 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___7 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___14 *child_reaper;
	struct kmem_cache___10 *pid_cachep;
	unsigned int level;
	struct pid_namespace___7 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___13 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___7 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___7 numbers[1];
};

struct nsproxy___7 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___7 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___13 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___14 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___14 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___7 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___14 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___6;

struct css_set___6 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___6 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___6 {
	struct pmu___6 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___14 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___14 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___6 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct property {
	char *name;
	int length;
	void *value;
	struct property *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___8 attr;
};

struct seq_operations___11 {
	void * (*start)(struct seq_file___11 *, loff_t *);
	void (*stop)(struct seq_file___11 *, void *);
	void * (*next)(struct seq_file___11 *, void *, loff_t *);
	int (*show)(struct seq_file___11 *, void *);
};

struct dentry_operations___12;

struct super_block___13;

struct dentry___13 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___13 *d_parent;
	struct qstr d_name;
	struct inode___13 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___12 *d_op;
	struct super_block___13 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___12;

struct file_lock___12;

struct dquot___12;

struct block_device___12;

struct inode___13 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___12 *i_op;
	struct super_block___13 *i_sb;
	struct address_space___12 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___14 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___12 *i_fop;
	struct file_lock___12 *i_flock;
	struct address_space___12 i_data;
	struct dquot___12 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___12 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___12 {
	int (*d_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_hash)(const struct dentry___13 *, struct qstr *);
	int (*d_compare)(const struct dentry___13 *, const struct dentry___13 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___13 *);
	void (*d_release)(struct dentry___13 *);
	void (*d_prune)(struct dentry___13 *);
	void (*d_iput)(struct dentry___13 *, struct inode___13 *);
	char * (*d_dname)(struct dentry___13 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___12 *);
	int (*d_manage)(struct dentry___13 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___12;

struct mem_dqinfo___12 {
	struct quota_format_type___12 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___12;

struct quota_info___12 {
	unsigned int flags;
	struct mutex___14 dqio_mutex;
	struct mutex___14 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___13 *files[2];
	struct mem_dqinfo___12 info[2];
	const struct quota_format_ops___12 *ops[2];
};

struct file_system_type___12;

struct super_operations___12;

struct dquot_operations___12;

struct quotactl_ops___12;

struct xattr_handler___6;

struct super_block___13 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___12 *s_type;
	const struct super_operations___12 *s_op;
	const struct dquot_operations___12 *dq_op;
	const struct quotactl_ops___12 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___13 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___6 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___12 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___12 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___14 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___12 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___12 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___13 *bd_inode;
	struct super_block___13 *bd_super;
	struct mutex___14 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___12 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___14 bd_fsfreeze_mutex;
};

struct cgroup___6;

struct cgroup_subsys_state___6 {
	struct cgroup___6 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___13 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___12 *ia_file;
};

struct dquot___12 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___14 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___13 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___12 {
	int qf_fmt_id;
	const struct quota_format_ops___12 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___12 *qf_next;
};

struct quota_format_ops___12 {
	int (*check_quota_file)(struct super_block___13 *, int);
	int (*read_file_info)(struct super_block___13 *, int);
	int (*write_file_info)(struct super_block___13 *, int);
	int (*free_file_info)(struct super_block___13 *, int);
	int (*read_dqblk)(struct dquot___12 *);
	int (*commit_dqblk)(struct dquot___12 *);
	int (*release_dqblk)(struct dquot___12 *);
};

struct dquot_operations___12 {
	int (*write_dquot)(struct dquot___12 *);
	struct dquot___12 * (*alloc_dquot)(struct super_block___13 *, int);
	void (*destroy_dquot)(struct dquot___12 *);
	int (*acquire_dquot)(struct dquot___12 *);
	int (*release_dquot)(struct dquot___12 *);
	int (*mark_dirty)(struct dquot___12 *);
	int (*write_info)(struct super_block___13 *, int);
	qsize_t * (*get_reserved_space)(struct inode___13 *);
};

struct quotactl_ops___12 {
	int (*quota_on)(struct super_block___13 *, int, int, struct path___12 *);
	int (*quota_on_meta)(struct super_block___13 *, int, int);
	int (*quota_off)(struct super_block___13 *, int);
	int (*quota_sync)(struct super_block___13 *, int);
	int (*get_info)(struct super_block___13 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___13 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___13 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___13 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___13 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___13 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___13 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___13 *, unsigned int);
};

struct address_space_operations___12 {
	int (*writepage)(struct page___12 *, struct writeback_control *);
	int (*readpage)(struct file___12 *, struct page___12 *);
	int (*writepages)(struct address_space___12 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___12 *);
	int (*readpages)(struct file___12 *, struct address_space___12 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___12 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___12 **, void **);
	int (*write_end)(struct file___12 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___12 *, void *);
	sector_t (*bmap)(struct address_space___12 *, sector_t);
	void (*invalidatepage)(struct page___12 *, long unsigned int);
	int (*releasepage)(struct page___12 *, gfp_t);
	void (*freepage)(struct page___12 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___12 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___12 *, struct page___12 *, struct page___12 *, enum migrate_mode);
	int (*launder_page)(struct page___12 *);
	int (*is_partially_uptodate)(struct page___12 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___12 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___12 *, struct page___12 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___12 *, sector_t *);
	void (*swap_deactivate)(struct file___12 *);
	void (*invalidatepage_range)(struct page___12 *, unsigned int, unsigned int);
};

struct inode_operations___12 {
	struct dentry___13 * (*lookup)(struct inode___13 *, struct dentry___13 *, unsigned int);
	void * (*follow_link)(struct dentry___13 *, struct nameidata *);
	int (*permission)(struct inode___13 *, int);
	struct posix_acl * (*get_acl)(struct inode___13 *, int);
	int (*readlink)(struct dentry___13 *, char *, int);
	void (*put_link)(struct dentry___13 *, struct nameidata *, void *);
	int (*create)(struct inode___13 *, struct dentry___13 *, umode_t, bool);
	int (*link)(struct dentry___13 *, struct inode___13 *, struct dentry___13 *);
	int (*unlink)(struct inode___13 *, struct dentry___13 *);
	int (*symlink)(struct inode___13 *, struct dentry___13 *, const char *);
	int (*mkdir)(struct inode___13 *, struct dentry___13 *, umode_t);
	int (*rmdir)(struct inode___13 *, struct dentry___13 *);
	int (*mknod)(struct inode___13 *, struct dentry___13 *, umode_t, dev_t);
	int (*rename)(struct inode___13 *, struct dentry___13 *, struct inode___13 *, struct dentry___13 *);
	int (*setattr)(struct dentry___13 *, struct iattr___13 *);
	int (*getattr)(struct vfsmount *, struct dentry___13 *, struct kstat *);
	int (*setxattr)(struct dentry___13 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___13 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___13 *, char *, size_t);
	int (*removexattr)(struct dentry___13 *, const char *);
	int (*fiemap)(struct inode___13 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___13 *, struct timespec *, int);
	int (*atomic_open)(struct inode___13 *, struct dentry___13 *, struct file___12 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___7;

struct file_operations___12 {
	struct module *owner;
	loff_t (*llseek)(struct file___12 *, loff_t, int);
	ssize_t (*read)(struct file___12 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___12 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___12 *, void *, filldir_t);
	unsigned int (*poll)(struct file___12 *, struct poll_table_struct___7 *);
	long int (*unlocked_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___12 *, struct vm_area_struct___15 *);
	int (*open)(struct inode___13 *, struct file___12 *);
	int (*flush)(struct file___12 *, fl_owner_t);
	int (*release)(struct inode___13 *, struct file___12 *);
	int (*fsync)(struct file___12 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___12 *, int);
	int (*lock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*sendpage)(struct file___12 *, struct page___12 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___12 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___12 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___12 *, long int, struct file_lock___12 **, void **);
		struct {
			int (*setlease)(struct file___12 *, long int, struct file_lock___12 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___12 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___11 *, struct file___12 *);
};

struct file_lock_operations___12;

struct lock_manager_operations___12;

struct file_lock___12 {
	struct file_lock___12 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___7 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___12 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___12 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___12 *fl_ops;
	const struct lock_manager_operations___12 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___12 {
	void (*fl_copy_lock)(struct file_lock___12 *, struct file_lock___12 *);
	void (*fl_release_private)(struct file_lock___12 *);
};

struct lock_manager_operations___12 {
	int (*lm_compare_owner)(struct file_lock___12 *, struct file_lock___12 *);
	long unsigned int (*lm_owner_key)(struct file_lock___12 *);
	void (*lm_notify)(struct file_lock___12 *);
	int (*lm_grant)(struct file_lock___12 *, struct file_lock___12 *, int);
	void (*lm_break)(struct file_lock___12 *);
	int (*lm_change)(struct file_lock___12 **, int);
};

struct fasync_struct___12 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___12 *fa_next;
	struct file___12 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___12 {
	const char *name;
	int fs_flags;
	struct dentry___13 * (*mount)(struct file_system_type___12 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___13 *);
	struct module *owner;
	struct file_system_type___12 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___12 {
	struct inode___13 * (*alloc_inode)(struct super_block___13 *);
	void (*destroy_inode)(struct inode___13 *);
	void (*dirty_inode)(struct inode___13 *, int);
	int (*write_inode)(struct inode___13 *, struct writeback_control *);
	int (*drop_inode)(struct inode___13 *);
	void (*evict_inode)(struct inode___13 *);
	void (*put_super)(struct super_block___13 *);
	int (*sync_fs)(struct super_block___13 *, int);
	int (*freeze_fs)(struct super_block___13 *);
	int (*unfreeze_fs)(struct super_block___13 *);
	int (*statfs)(struct dentry___13 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___13 *, int *, char *);
	void (*umount_begin)(struct super_block___13 *);
	int (*show_options)(struct seq_file___11 *, struct dentry___13 *);
	int (*show_devname)(struct seq_file___11 *, struct dentry___13 *);
	int (*show_path)(struct seq_file___11 *, struct dentry___13 *);
	int (*show_stats)(struct seq_file___11 *, struct dentry___13 *);
	ssize_t (*quota_read)(struct super_block___13 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___13 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___13 *);
	int (*bdev_try_to_free_page)(struct super_block___13 *, struct page___12 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___13 *);
	void (*free_cached_objects)(struct super_block___13 *, int);
};

struct xattr_handler___6 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___13 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___13 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___13 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___7)(struct file___12 *, wait_queue_head_t *, struct poll_table_struct___7 *);

struct poll_table_struct___7 {
	poll_queue_proc___7 _qproc;
	long unsigned int _key;
};

struct vm_fault___10 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___12 *page;
};

struct kmem_cache_cpu___10 {
	void **freelist;
	long unsigned int tid;
	struct page___12 *page;
	struct page___12 *partial;
};

struct memcg_cache_params___10 {
	bool is_root_cache;
	union {
		struct kmem_cache___10 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___10 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___6;

struct cgroup___6 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___6 *parent;
	struct dentry___13 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___6 *subsys[11];
	struct cgroupfs_root___6 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___14 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___6 {
	struct super_block___13 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___6 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___6;

struct pmu___6 {
	struct list_head entry;
	struct device___8 *dev;
	const struct attribute_group___8 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___6 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___6 *);
	void (*pmu_disable)(struct pmu___6 *);
	int (*event_init)(struct perf_event___6 *);
	int (*add)(struct perf_event___6 *, int);
	void (*del)(struct perf_event___6 *, int);
	void (*start)(struct perf_event___6 *, int);
	void (*stop)(struct perf_event___6 *, int);
	void (*read)(struct perf_event___6 *);
	void (*start_txn)(struct pmu___6 *);
	int (*commit_txn)(struct pmu___6 *);
	void (*cancel_txn)(struct pmu___6 *);
	int (*event_idx)(struct perf_event___6 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___6 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___6 *);
};

struct perf_cpu_context___6 {
	struct perf_event_context___6 ctx;
	struct perf_event_context___6 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___6 *unique_pmu;
	struct perf_cgroup___6 *cgrp;
};

struct trace_event_functions___6;

struct trace_event___6 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___6 *funcs;
};

struct ftrace_event_class___6;

struct ftrace_event_call___6 {
	struct list_head list;
	struct ftrace_event_class___6 *class;
	char *name;
	struct trace_event___6 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___6 {
	struct cgroup_subsys_state___6 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___6 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___14 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___6)(struct trace_iterator___6 *, int, struct trace_event___6 *);

struct trace_event_functions___6 {
	trace_print_func___6 trace;
	trace_print_func___6 raw;
	trace_print_func___6 hex;
	trace_print_func___6 binary;
};

struct ftrace_event_class___6 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___6 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___6 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___6 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___6 *);
};

struct ftrace_event_file___2 {
	struct list_head list;
	struct ftrace_event_call___6 *event_call;
	struct dentry___13 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_x86_irq_vector {
	struct trace_entry ent;
	int vector;
	char __data[0];
};

struct ftrace_data_offsets_x86_irq_vector {};

typedef unsigned int pao_T__;

struct page___13;

typedef struct page___13 *pgtable_t___13;

struct address_space___13;

struct page___13 {
	long unsigned int flags;
	struct address_space___13 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___13 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___13 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___13 *first_page;
	};
	long: 64;
};

struct task_struct___15;

struct pv_cpu_ops___14 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___6 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___6 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___15 *);
	void (*end_context_switch)(struct task_struct___15 *);
};

struct mutex___15 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___15 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___12 {
	struct page___13 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___16;

struct signal_struct___14;

struct task_struct___15 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___15 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___16 *mm;
	struct mm_struct___16 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___15 *real_parent;
	struct task_struct___15 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___15 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___7 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___14 = 0,
		VTIME_USER___14 = 1,
		VTIME_SYS___14 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___6 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___14 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___15 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___12 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___16 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___16 *, struct mm_struct___16 *);
	void (*dup_mmap)(struct mm_struct___16 *, struct mm_struct___16 *);
	void (*exit_mmap)(struct mm_struct___16 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___16 *);
	void (*pgd_free)(struct mm_struct___16 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___16 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___16 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___16 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___16 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___16 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___16 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___16 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___16 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___16 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___16 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___16 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___15 lock;
	void *vdso;
} mm_context_t___15;

struct xol_area___13;

struct uprobes_state___13 {
	struct xol_area___13 *xol_area;
};

struct vm_area_struct___16;

struct file___13;

struct core_state___14;

struct mm_struct___16 {
	struct vm_area_struct___16 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___16 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___16 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___15 context;
	long unsigned int flags;
	struct core_state___14 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___15 *owner;
	struct file___13 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___13 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___7;

struct exec_domain___4 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___7 *module;
	struct exec_domain___4 *next;
};

struct module_kobject___6 {
	struct kobject kobj;
	struct module___7 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___6;

struct module___7 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___6 mkobj;
	struct module_attribute___6 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___15 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct orig_ist {
	long unsigned int ist[7];
};

struct thread_info___7 {
	struct task_struct___15 *task;
	struct exec_domain___4 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___12;

struct x86_io_apic_ops___12 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___12 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___12;

struct irq_data___12 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___12 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___14 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___15 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___14;

struct lruvec___14 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___14 *zone;
};

struct pglist_data___14;

struct zone___14 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___14 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___14 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___14 {
	struct zone___14 *zone;
	int zone_idx;
};

struct zonelist___14 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___14 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___14 {
	struct zone___14 node_zones[4];
	struct zonelist___14 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___15 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___3;

typedef void (*irq_flow_handler_t___3)(unsigned int, struct irq_desc___3 *);

struct irqaction___3;

struct irq_desc___3 {
	struct irq_data___12 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___3 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module___7 *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct seq_file___12;

struct irq_chip___12 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___12 *);
	void (*irq_shutdown)(struct irq_data___12 *);
	void (*irq_enable)(struct irq_data___12 *);
	void (*irq_disable)(struct irq_data___12 *);
	void (*irq_ack)(struct irq_data___12 *);
	void (*irq_mask)(struct irq_data___12 *);
	void (*irq_mask_ack)(struct irq_data___12 *);
	void (*irq_unmask)(struct irq_data___12 *);
	void (*irq_eoi)(struct irq_data___12 *);
	int (*irq_set_affinity)(struct irq_data___12 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___12 *);
	int (*irq_set_type)(struct irq_data___12 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___12 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___12 *);
	void (*irq_bus_sync_unlock)(struct irq_data___12 *);
	void (*irq_cpu_online)(struct irq_data___12 *);
	void (*irq_cpu_offline)(struct irq_data___12 *);
	void (*irq_suspend)(struct irq_data___12 *);
	void (*irq_resume)(struct irq_data___12 *);
	void (*irq_pm_shutdown)(struct irq_data___12 *);
	void (*irq_print_chip)(struct irq_data___12 *, struct seq_file___12 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___12 *, void *);
	long unsigned int flags;
};

struct seq_operations___12;

struct seq_file___12 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___15 lock;
	const struct seq_operations___12 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irqaction___3 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___3 *next;
	irq_handler_t thread_fn;
	struct task_struct___15 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xol_area___13 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___13 *page;
	long unsigned int vaddr;
};

struct inode___14;

struct address_space_operations___13;

struct address_space___13 {
	struct inode___14 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___15 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___13 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___14;

struct path___13 {
	struct vfsmount *mnt;
	struct dentry___14 *dentry;
};

struct file_operations___13;

struct file___13 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___13 f_path;
	struct inode___14 *f_inode;
	const struct file_operations___13 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___13 *f_mapping;
	struct mutex___15 f_pos_lock;
};

struct vm_area_struct___16 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___16 *vm_next;
	struct vm_area_struct___16 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___16 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___13 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___14 {
	struct task_struct___15 *task;
	struct core_thread___14 *next;
};

struct core_state___14 {
	atomic_t nr_threads;
	struct core_thread___14 dumper;
	struct completion startup;
};

struct signal_struct___14 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___15 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___15 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___7 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___15 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___12 {
	void * (*start)(struct seq_file___12 *, loff_t *);
	void (*stop)(struct seq_file___12 *, void *);
	void * (*next)(struct seq_file___12 *, void *, loff_t *);
	int (*show)(struct seq_file___12 *, void *);
};

struct module_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___6 *, struct module_kobject___6 *, char *);
	ssize_t (*store)(struct module_attribute___6 *, struct module_kobject___6 *, const char *, size_t);
	void (*setup)(struct module___7 *, const char *);
	int (*test)(struct module___7 *);
	void (*free)(struct module___7 *);
};

struct dentry_operations___13;

struct super_block___14;

struct dentry___14 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___14 *d_parent;
	struct qstr d_name;
	struct inode___14 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___13 *d_op;
	struct super_block___14 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___13;

struct file_lock___13;

struct dquot___13;

struct block_device___13;

struct inode___14 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___13 *i_op;
	struct super_block___14 *i_sb;
	struct address_space___13 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___15 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___13 *i_fop;
	struct file_lock___13 *i_flock;
	struct address_space___13 i_data;
	struct dquot___13 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___13 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___13 {
	int (*d_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_hash)(const struct dentry___14 *, struct qstr *);
	int (*d_compare)(const struct dentry___14 *, const struct dentry___14 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___14 *);
	void (*d_release)(struct dentry___14 *);
	void (*d_prune)(struct dentry___14 *);
	void (*d_iput)(struct dentry___14 *, struct inode___14 *);
	char * (*d_dname)(struct dentry___14 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___13 *);
	int (*d_manage)(struct dentry___14 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___13;

struct mem_dqinfo___13 {
	struct quota_format_type___13 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___13;

struct quota_info___13 {
	unsigned int flags;
	struct mutex___15 dqio_mutex;
	struct mutex___15 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___14 *files[2];
	struct mem_dqinfo___13 info[2];
	const struct quota_format_ops___13 *ops[2];
};

struct file_system_type___13;

struct super_operations___13;

struct dquot_operations___13;

struct quotactl_ops___13;

struct super_block___14 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___13 *s_type;
	const struct super_operations___13 *s_op;
	const struct dquot_operations___13 *dq_op;
	const struct quotactl_ops___13 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___14 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___13 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___13 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___15 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___13 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___13 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___14 *bd_inode;
	struct super_block___14 *bd_super;
	struct mutex___15 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___13 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___15 bd_fsfreeze_mutex;
};

struct iattr___14 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___13 *ia_file;
};

struct dquot___13 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___15 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___14 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___13 {
	int qf_fmt_id;
	const struct quota_format_ops___13 *qf_ops;
	struct module___7 *qf_owner;
	struct quota_format_type___13 *qf_next;
};

struct quota_format_ops___13 {
	int (*check_quota_file)(struct super_block___14 *, int);
	int (*read_file_info)(struct super_block___14 *, int);
	int (*write_file_info)(struct super_block___14 *, int);
	int (*free_file_info)(struct super_block___14 *, int);
	int (*read_dqblk)(struct dquot___13 *);
	int (*commit_dqblk)(struct dquot___13 *);
	int (*release_dqblk)(struct dquot___13 *);
};

struct dquot_operations___13 {
	int (*write_dquot)(struct dquot___13 *);
	struct dquot___13 * (*alloc_dquot)(struct super_block___14 *, int);
	void (*destroy_dquot)(struct dquot___13 *);
	int (*acquire_dquot)(struct dquot___13 *);
	int (*release_dquot)(struct dquot___13 *);
	int (*mark_dirty)(struct dquot___13 *);
	int (*write_info)(struct super_block___14 *, int);
	qsize_t * (*get_reserved_space)(struct inode___14 *);
};

struct quotactl_ops___13 {
	int (*quota_on)(struct super_block___14 *, int, int, struct path___13 *);
	int (*quota_on_meta)(struct super_block___14 *, int, int);
	int (*quota_off)(struct super_block___14 *, int);
	int (*quota_sync)(struct super_block___14 *, int);
	int (*get_info)(struct super_block___14 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___14 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___14 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___14 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___14 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___14 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___14 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___14 *, unsigned int);
};

struct address_space_operations___13 {
	int (*writepage)(struct page___13 *, struct writeback_control *);
	int (*readpage)(struct file___13 *, struct page___13 *);
	int (*writepages)(struct address_space___13 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___13 *);
	int (*readpages)(struct file___13 *, struct address_space___13 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___13 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___13 **, void **);
	int (*write_end)(struct file___13 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___13 *, void *);
	sector_t (*bmap)(struct address_space___13 *, sector_t);
	void (*invalidatepage)(struct page___13 *, long unsigned int);
	int (*releasepage)(struct page___13 *, gfp_t);
	void (*freepage)(struct page___13 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___13 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___13 *, struct page___13 *, struct page___13 *, enum migrate_mode);
	int (*launder_page)(struct page___13 *);
	int (*is_partially_uptodate)(struct page___13 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___13 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___13 *, struct page___13 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___13 *, sector_t *);
	void (*swap_deactivate)(struct file___13 *);
	void (*invalidatepage_range)(struct page___13 *, unsigned int, unsigned int);
};

struct inode_operations___13 {
	struct dentry___14 * (*lookup)(struct inode___14 *, struct dentry___14 *, unsigned int);
	void * (*follow_link)(struct dentry___14 *, struct nameidata *);
	int (*permission)(struct inode___14 *, int);
	struct posix_acl * (*get_acl)(struct inode___14 *, int);
	int (*readlink)(struct dentry___14 *, char *, int);
	void (*put_link)(struct dentry___14 *, struct nameidata *, void *);
	int (*create)(struct inode___14 *, struct dentry___14 *, umode_t, bool);
	int (*link)(struct dentry___14 *, struct inode___14 *, struct dentry___14 *);
	int (*unlink)(struct inode___14 *, struct dentry___14 *);
	int (*symlink)(struct inode___14 *, struct dentry___14 *, const char *);
	int (*mkdir)(struct inode___14 *, struct dentry___14 *, umode_t);
	int (*rmdir)(struct inode___14 *, struct dentry___14 *);
	int (*mknod)(struct inode___14 *, struct dentry___14 *, umode_t, dev_t);
	int (*rename)(struct inode___14 *, struct dentry___14 *, struct inode___14 *, struct dentry___14 *);
	int (*setattr)(struct dentry___14 *, struct iattr___14 *);
	int (*getattr)(struct vfsmount *, struct dentry___14 *, struct kstat *);
	int (*setxattr)(struct dentry___14 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___14 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___14 *, char *, size_t);
	int (*removexattr)(struct dentry___14 *, const char *);
	int (*fiemap)(struct inode___14 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___14 *, struct timespec *, int);
	int (*atomic_open)(struct inode___14 *, struct dentry___14 *, struct file___13 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___13 {
	struct module___7 *owner;
	loff_t (*llseek)(struct file___13 *, loff_t, int);
	ssize_t (*read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___13 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___13 *, void *, filldir_t);
	unsigned int (*poll)(struct file___13 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___13 *, struct vm_area_struct___16 *);
	int (*open)(struct inode___14 *, struct file___13 *);
	int (*flush)(struct file___13 *, fl_owner_t);
	int (*release)(struct inode___14 *, struct file___13 *);
	int (*fsync)(struct file___13 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___13 *, int);
	int (*lock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*sendpage)(struct file___13 *, struct page___13 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___13 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___13 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___13 *, long int, struct file_lock___13 **, void **);
		struct {
			int (*setlease)(struct file___13 *, long int, struct file_lock___13 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___13 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___12 *, struct file___13 *);
};

struct fasync_struct___13;

struct file_lock_operations___13;

struct lock_manager_operations___13;

struct file_lock___13 {
	struct file_lock___13 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___7 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___13 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___13 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___13 *fl_ops;
	const struct lock_manager_operations___13 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___13 {
	void (*fl_copy_lock)(struct file_lock___13 *, struct file_lock___13 *);
	void (*fl_release_private)(struct file_lock___13 *);
};

struct lock_manager_operations___13 {
	int (*lm_compare_owner)(struct file_lock___13 *, struct file_lock___13 *);
	long unsigned int (*lm_owner_key)(struct file_lock___13 *);
	void (*lm_notify)(struct file_lock___13 *);
	int (*lm_grant)(struct file_lock___13 *, struct file_lock___13 *, int);
	void (*lm_break)(struct file_lock___13 *);
	int (*lm_change)(struct file_lock___13 **, int);
};

struct fasync_struct___13 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___13 *fa_next;
	struct file___13 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___13 {
	const char *name;
	int fs_flags;
	struct dentry___14 * (*mount)(struct file_system_type___13 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___14 *);
	struct module___7 *owner;
	struct file_system_type___13 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___13 {
	struct inode___14 * (*alloc_inode)(struct super_block___14 *);
	void (*destroy_inode)(struct inode___14 *);
	void (*dirty_inode)(struct inode___14 *, int);
	int (*write_inode)(struct inode___14 *, struct writeback_control *);
	int (*drop_inode)(struct inode___14 *);
	void (*evict_inode)(struct inode___14 *);
	void (*put_super)(struct super_block___14 *);
	int (*sync_fs)(struct super_block___14 *, int);
	int (*freeze_fs)(struct super_block___14 *);
	int (*unfreeze_fs)(struct super_block___14 *);
	int (*statfs)(struct dentry___14 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___14 *, int *, char *);
	void (*umount_begin)(struct super_block___14 *);
	int (*show_options)(struct seq_file___12 *, struct dentry___14 *);
	int (*show_devname)(struct seq_file___12 *, struct dentry___14 *);
	int (*show_path)(struct seq_file___12 *, struct dentry___14 *);
	int (*show_stats)(struct seq_file___12 *, struct dentry___14 *);
	ssize_t (*quota_read)(struct super_block___14 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___14 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___14 *);
	int (*bdev_try_to_free_page)(struct super_block___14 *, struct page___13 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___14 *);
	void (*free_cached_objects)(struct super_block___14 *, int);
};

struct exec_domain___5 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___2 *module;
	struct exec_domain___5 *next;
};

struct thread_info___8 {
	struct task_struct___5 *task;
	struct exec_domain___5 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct kprobe_insn_cache___3 {
	struct mutex___5 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct stacktrace_ops;

typedef long unsigned int (*walk_stack_t)(struct thread_info___8 *, long unsigned int *, long unsigned int, const struct stacktrace_ops *, void *, long unsigned int *, int *);

struct stacktrace_ops {
	void (*address)(void *, long unsigned int, int);
	int (*stack)(void *, char *);
	walk_stack_t walk_stack;
};

struct msi_msg {
	u32 address_lo;
	u32 address_hi;
	u32 data;
};

struct pci_dev___2;

struct msi_desc {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___2 *dev;
	struct msi_msg msg;
	struct kobject kobj;
};

struct legacy_pic {
	int nr_legacy_irqs;
	struct irq_chip___11 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

enum {
	TRACE_EVENT_FL_FILTERED = 1,
	TRACE_EVENT_FL_CAP_ANY = 2,
	TRACE_EVENT_FL_NO_SET_FILTER = 4,
	TRACE_EVENT_FL_IGNORE_ENABLE = 8,
	TRACE_EVENT_FL_WAS_ENABLED = 16,
};

struct syscall_metadata {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___5 *enter_event;
	struct ftrace_event_call___5 *exit_event;
};

struct tlb_state___4 {
	struct mm_struct___5 *active_mm;
	int state;
};

enum lockdep_ok {
	LOCKDEP_STILL_OK = 0,
	LOCKDEP_NOW_UNRELIABLE = 1,
};

enum bug_trap_type {
	BUG_TRAP_TYPE_NONE = 0,
	BUG_TRAP_TYPE_WARN = 1,
	BUG_TRAP_TYPE_BUG = 2,
};

enum {
	NMI_LOCAL = 0,
	NMI_UNKNOWN = 1,
	NMI_SERR = 2,
	NMI_IO_CHECK = 3,
	NMI_MAX = 4,
};

typedef int (*nmi_handler_t)(unsigned int, struct pt_regs *);

struct nmiaction {
	struct list_head list;
	nmi_handler_t handler;
	long unsigned int flags;
	const char *name;
};

struct nmi_desc {
	spinlock_t lock;
	struct list_head head;
};

struct nmi_stats {
	unsigned int normal;
	unsigned int unknown;
	unsigned int external;
	unsigned int swallow;
};

struct page___14;

typedef struct page___14 *pgtable_t___14;

struct address_space___14;

struct kmem_cache___11;

struct page___14 {
	long unsigned int flags;
	struct address_space___14 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___14 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___14 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___11 *slab_cache;
		struct page___14 *first_page;
	};
	long: 64;
};

struct task_struct___16;

struct pv_cpu_ops___15 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___6 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___6 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___16 *);
	void (*end_context_switch)(struct task_struct___16 *);
};

struct mutex___16 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___16 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___13 {
	struct page___14 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___17;

struct signal_struct___15;

struct task_struct___16 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___16 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___17 *mm;
	struct mm_struct___17 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___16 *real_parent;
	struct task_struct___16 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___16 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___7 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___15 = 0,
		VTIME_USER___15 = 1,
		VTIME_SYS___15 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___6 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___15 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___16 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___13 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___17 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___17 *, struct mm_struct___17 *);
	void (*dup_mmap)(struct mm_struct___17 *, struct mm_struct___17 *);
	void (*exit_mmap)(struct mm_struct___17 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___17 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___17 *);
	void (*pgd_free)(struct mm_struct___17 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___17 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___17 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___17 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___17 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___17 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___17 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___17 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___17 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___17 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___17 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___17 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___16 lock;
	void *vdso;
} mm_context_t___16;

struct xol_area___14;

struct uprobes_state___14 {
	struct xol_area___14 *xol_area;
};

struct vm_area_struct___17;

struct file___14;

struct core_state___15;

struct mm_struct___17 {
	struct vm_area_struct___17 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___17 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___17 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___16 context;
	long unsigned int flags;
	struct core_state___15 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___16 *owner;
	struct file___14 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___14 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___8;

struct module_kobject___7 {
	struct kobject kobj;
	struct module___8 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___7;

struct module___8 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___7 mkobj;
	struct module_attribute___7 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___16 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct rh_cpuinfo_x86 {
	int x86_cache_max_rmid;
	int x86_cache_occ_scale;
};

struct xol_area___14 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___14 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___11;

struct memcg_cache_params___11;

struct kmem_cache___11 {
	struct kmem_cache_cpu___11 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___11 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___15;

struct address_space_operations___14;

struct address_space___14 {
	struct inode___15 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___16 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___14 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___15;

struct path___14 {
	struct vfsmount *mnt;
	struct dentry___15 *dentry;
};

struct file_operations___14;

struct file___14 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___14 f_path;
	struct inode___15 *f_inode;
	const struct file_operations___14 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___14 *f_mapping;
	struct mutex___16 f_pos_lock;
};

struct vm_operations_struct___13;

struct vm_area_struct___17 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___17 *vm_next;
	struct vm_area_struct___17 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___17 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___14 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___11;

struct vm_operations_struct___13 {
	void (*open)(struct vm_area_struct___17 *);
	void (*close)(struct vm_area_struct___17 *);
	int (*fault)(struct vm_area_struct___17 *, struct vm_fault___11 *);
	int (*page_mkwrite)(struct vm_area_struct___17 *, struct vm_fault___11 *);
	int (*access)(struct vm_area_struct___17 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___17 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___17 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___17 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___17 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___15 {
	struct task_struct___16 *task;
	struct core_thread___15 *next;
};

struct core_state___15 {
	atomic_t nr_threads;
	struct core_thread___15 dumper;
	struct completion startup;
};

struct edd {
	unsigned int mbr_signature[16];
	struct edd_info edd_info[6];
	unsigned char mbr_signature_nr;
	unsigned char edd_info_nr;
};

struct setup_data {
	__u64 next;
	__u32 type;
	__u32 len;
	__u8 data[0];
};

struct dma_map_ops___4;

struct dev_archdata___4 {
	struct dma_map_ops___4 *dma_ops;
	void *iommu;
};

struct acpi_device___3;

struct acpi_dev_node___5 {
	union {
		struct acpi_device___3 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___9;

struct bus_type___9;

struct device_driver___9;

struct dev_pm_domain___9;

struct class___9;

struct attribute_group___9;

struct device_rh___9;

struct device___9 {
	struct device___9 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___9 *type;
	struct mutex___16 mutex;
	struct bus_type___9 *bus;
	struct device_driver___9 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___9 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___4 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___5 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___9 *class;
	const struct attribute_group___9 **groups;
	void (*release)(struct device___9 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___9 *device_rh;
};

struct pci_bus___2;

struct pci_slot___2;

struct pci_driver___2;

struct bin_attribute___9;

struct pci_dev___3 {
	struct list_head bus_list;
	struct pci_bus___2 *bus;
	struct pci_bus___2 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___2 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___2 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___9 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___9 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___9 *res_attr[17];
	struct bin_attribute___9 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___9 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___3 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct irq_data___13;

struct x86_io_apic_ops___13 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___13 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___13;

struct irq_data___13 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___13 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct dev_pm_ops___9 {
	int (*prepare)(struct device___9 *);
	void (*complete)(struct device___9 *);
	int (*suspend)(struct device___9 *);
	int (*resume)(struct device___9 *);
	int (*freeze)(struct device___9 *);
	int (*thaw)(struct device___9 *);
	int (*poweroff)(struct device___9 *);
	int (*restore)(struct device___9 *);
	int (*suspend_late)(struct device___9 *);
	int (*resume_early)(struct device___9 *);
	int (*freeze_late)(struct device___9 *);
	int (*thaw_early)(struct device___9 *);
	int (*poweroff_late)(struct device___9 *);
	int (*restore_early)(struct device___9 *);
	int (*suspend_noirq)(struct device___9 *);
	int (*resume_noirq)(struct device___9 *);
	int (*freeze_noirq)(struct device___9 *);
	int (*thaw_noirq)(struct device___9 *);
	int (*poweroff_noirq)(struct device___9 *);
	int (*restore_noirq)(struct device___9 *);
	int (*runtime_suspend)(struct device___9 *);
	int (*runtime_resume)(struct device___9 *);
	int (*runtime_idle)(struct device___9 *);
};

struct dev_pm_info_rh___9 {
	void (*set_latency_tolerance)(struct device___9 *, s32);
};

struct dev_pm_domain___9 {
	struct dev_pm_ops___9 ops;
};

struct property___2;

struct device_node {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___2 *properties;
	struct property___2 *deadprops;
	struct device_node *parent;
	struct device_node *child;
	struct device_node *sibling;
	struct device_node *next;
	struct device_node *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct smp_ops___15 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___16 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___15;

struct lruvec___15 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___15 *zone;
};

struct pglist_data___15;

struct zone___15 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___15 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___15 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___15 {
	struct zone___15 *zone;
	int zone_idx;
};

struct zonelist___15 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___15 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___15 {
	struct zone___15 node_zones[4];
	struct zonelist___15 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___16 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___15 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___16 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___16 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___7 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___16 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___11 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___14 *page;
};

struct attribute_group___9 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___9 **bin_attrs;
};

struct bin_attribute___9 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___14 *, struct kobject *, struct bin_attribute___9 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___14 *, struct kobject *, struct bin_attribute___9 *, char *, loff_t, size_t);
	int (*mmap)(struct file___14 *, struct kobject *, struct bin_attribute___9 *, struct vm_area_struct___17 *);
};

struct dma_map_ops___4 {
	void * (*alloc)(struct device___9 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___9 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___9 *, struct vm_area_struct___17 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___9 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___9 *, struct page___14 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___9 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___9 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___9 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___9 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___9 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___9 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___9 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___9 *, dma_addr_t);
	int (*dma_supported)(struct device___9 *, u64);
	int (*set_dma_mask)(struct device___9 *, u64);
	int is_phys;
};

struct bus_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___9 *, char *);
	ssize_t (*store)(struct bus_type___9 *, const char *, size_t);
};

struct device_attribute___9;

struct driver_attribute___9;

struct bus_type___9 {
	const char *name;
	const char *dev_name;
	struct device___9 *dev_root;
	struct bus_attribute___9 *bus_attrs;
	struct device_attribute___9 *dev_attrs;
	struct driver_attribute___9 *drv_attrs;
	const struct attribute_group___9 **bus_groups;
	const struct attribute_group___9 **dev_groups;
	const struct attribute_group___9 **drv_groups;
	int (*match)(struct device___9 *, struct device_driver___9 *);
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	int (*probe)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*online)(struct device___9 *);
	int (*offline)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct dev_pm_ops___9 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct device___9 *, struct device_attribute___9 *, char *);
	ssize_t (*store)(struct device___9 *, struct device_attribute___9 *, const char *, size_t);
};

struct driver_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___9 *, char *);
	ssize_t (*store)(struct device_driver___9 *, const char *, size_t);
};

struct device_driver___9 {
	const char *name;
	struct bus_type___9 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct attribute_group___9 **groups;
	const struct dev_pm_ops___9 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___9 {
	const char *name;
	const struct attribute_group___9 **groups;
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___9 *);
	const struct dev_pm_ops___9 *pm;
};

struct class_attribute___9;

struct class___9 {
	const char *name;
	struct module___8 *owner;
	struct class_attribute___9 *class_attrs;
	struct device_attribute___9 *dev_attrs;
	const struct attribute_group___9 **dev_groups;
	struct bin_attribute___9 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *);
	void (*class_release)(struct class___9 *);
	void (*dev_release)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___9 *);
	const struct dev_pm_ops___9 *pm;
	struct subsys_private *p;
};

struct class_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct class___9 *, struct class_attribute___9 *, char *);
	ssize_t (*store)(struct class___9 *, struct class_attribute___9 *, const char *, size_t);
	const void * (*namespace)(struct class___9 *, const struct class_attribute___9 *);
};

struct acpi_scan_handler___3;

struct acpi_hotplug_context___3;

struct acpi_driver___3;

struct acpi_device___3 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___3 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___3 *handler;
	struct acpi_hotplug_context___3 *hp;
	struct acpi_driver___3 *driver;
	void *driver_data;
	struct device___9 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___16 physical_node_lock;
	void (*remove)(struct acpi_device___3 *);
};

struct device_rh___9 {
	struct dev_pm_info_rh___9 power;
};

struct kmem_cache_cpu___11 {
	void **freelist;
	long unsigned int tid;
	struct page___14 *page;
	struct page___14 *partial;
};

struct memcg_cache_params___11 {
	bool is_root_cache;
	union {
		struct kmem_cache___11 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___11 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___14;

struct super_block___15;

struct dentry___15 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___15 *d_parent;
	struct qstr d_name;
	struct inode___15 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___14 *d_op;
	struct super_block___15 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___14;

struct file_lock___14;

struct dquot___14;

struct block_device___14;

struct cdev___4;

struct inode___15 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___14 *i_op;
	struct super_block___15 *i_sb;
	struct address_space___14 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___16 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___14 *i_fop;
	struct file_lock___14 *i_flock;
	struct address_space___14 i_data;
	struct dquot___14 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___14 *i_bdev;
		struct cdev___4 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___14 {
	int (*d_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_hash)(const struct dentry___15 *, struct qstr *);
	int (*d_compare)(const struct dentry___15 *, const struct dentry___15 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___15 *);
	void (*d_release)(struct dentry___15 *);
	void (*d_prune)(struct dentry___15 *);
	void (*d_iput)(struct dentry___15 *, struct inode___15 *);
	char * (*d_dname)(struct dentry___15 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___14 *);
	int (*d_manage)(struct dentry___15 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___14;

struct mem_dqinfo___14 {
	struct quota_format_type___14 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___14;

struct quota_info___14 {
	unsigned int flags;
	struct mutex___16 dqio_mutex;
	struct mutex___16 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___15 *files[2];
	struct mem_dqinfo___14 info[2];
	const struct quota_format_ops___14 *ops[2];
};

struct file_system_type___14;

struct super_operations___14;

struct dquot_operations___14;

struct quotactl_ops___14;

struct super_block___15 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___14 *s_type;
	const struct super_operations___14 *s_op;
	const struct dquot_operations___14 *dq_op;
	const struct quotactl_ops___14 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___15 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___14 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___14 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___16 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___14 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___14 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___15 *bd_inode;
	struct super_block___15 *bd_super;
	struct mutex___16 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___14 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___16 bd_fsfreeze_mutex;
};

struct iattr___15 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___14 *ia_file;
};

struct dquot___14 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___16 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___15 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___14 {
	int qf_fmt_id;
	const struct quota_format_ops___14 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___14 *qf_next;
};

struct quota_format_ops___14 {
	int (*check_quota_file)(struct super_block___15 *, int);
	int (*read_file_info)(struct super_block___15 *, int);
	int (*write_file_info)(struct super_block___15 *, int);
	int (*free_file_info)(struct super_block___15 *, int);
	int (*read_dqblk)(struct dquot___14 *);
	int (*commit_dqblk)(struct dquot___14 *);
	int (*release_dqblk)(struct dquot___14 *);
};

struct dquot_operations___14 {
	int (*write_dquot)(struct dquot___14 *);
	struct dquot___14 * (*alloc_dquot)(struct super_block___15 *, int);
	void (*destroy_dquot)(struct dquot___14 *);
	int (*acquire_dquot)(struct dquot___14 *);
	int (*release_dquot)(struct dquot___14 *);
	int (*mark_dirty)(struct dquot___14 *);
	int (*write_info)(struct super_block___15 *, int);
	qsize_t * (*get_reserved_space)(struct inode___15 *);
};

struct quotactl_ops___14 {
	int (*quota_on)(struct super_block___15 *, int, int, struct path___14 *);
	int (*quota_on_meta)(struct super_block___15 *, int, int);
	int (*quota_off)(struct super_block___15 *, int);
	int (*quota_sync)(struct super_block___15 *, int);
	int (*get_info)(struct super_block___15 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___15 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___15 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___15 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___15 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___15 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___15 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___15 *, unsigned int);
};

struct address_space_operations___14 {
	int (*writepage)(struct page___14 *, struct writeback_control *);
	int (*readpage)(struct file___14 *, struct page___14 *);
	int (*writepages)(struct address_space___14 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___14 *);
	int (*readpages)(struct file___14 *, struct address_space___14 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___14 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___14 **, void **);
	int (*write_end)(struct file___14 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___14 *, void *);
	sector_t (*bmap)(struct address_space___14 *, sector_t);
	void (*invalidatepage)(struct page___14 *, long unsigned int);
	int (*releasepage)(struct page___14 *, gfp_t);
	void (*freepage)(struct page___14 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___14 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___14 *, struct page___14 *, struct page___14 *, enum migrate_mode);
	int (*launder_page)(struct page___14 *);
	int (*is_partially_uptodate)(struct page___14 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___14 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___14 *, struct page___14 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___14 *, sector_t *);
	void (*swap_deactivate)(struct file___14 *);
	void (*invalidatepage_range)(struct page___14 *, unsigned int, unsigned int);
};

struct cdev___4 {
	struct kobject kobj;
	struct module___8 *owner;
	const struct file_operations___14 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___14 {
	struct dentry___15 * (*lookup)(struct inode___15 *, struct dentry___15 *, unsigned int);
	void * (*follow_link)(struct dentry___15 *, struct nameidata *);
	int (*permission)(struct inode___15 *, int);
	struct posix_acl * (*get_acl)(struct inode___15 *, int);
	int (*readlink)(struct dentry___15 *, char *, int);
	void (*put_link)(struct dentry___15 *, struct nameidata *, void *);
	int (*create)(struct inode___15 *, struct dentry___15 *, umode_t, bool);
	int (*link)(struct dentry___15 *, struct inode___15 *, struct dentry___15 *);
	int (*unlink)(struct inode___15 *, struct dentry___15 *);
	int (*symlink)(struct inode___15 *, struct dentry___15 *, const char *);
	int (*mkdir)(struct inode___15 *, struct dentry___15 *, umode_t);
	int (*rmdir)(struct inode___15 *, struct dentry___15 *);
	int (*mknod)(struct inode___15 *, struct dentry___15 *, umode_t, dev_t);
	int (*rename)(struct inode___15 *, struct dentry___15 *, struct inode___15 *, struct dentry___15 *);
	int (*setattr)(struct dentry___15 *, struct iattr___15 *);
	int (*getattr)(struct vfsmount *, struct dentry___15 *, struct kstat *);
	int (*setxattr)(struct dentry___15 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___15 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___15 *, char *, size_t);
	int (*removexattr)(struct dentry___15 *, const char *);
	int (*fiemap)(struct inode___15 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___15 *, struct timespec *, int);
	int (*atomic_open)(struct inode___15 *, struct dentry___15 *, struct file___14 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___8;

struct seq_file___13;

struct file_operations___14 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___14 *, loff_t, int);
	ssize_t (*read)(struct file___14 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___14 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___14 *, void *, filldir_t);
	unsigned int (*poll)(struct file___14 *, struct poll_table_struct___8 *);
	long int (*unlocked_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___14 *, struct vm_area_struct___17 *);
	int (*open)(struct inode___15 *, struct file___14 *);
	int (*flush)(struct file___14 *, fl_owner_t);
	int (*release)(struct inode___15 *, struct file___14 *);
	int (*fsync)(struct file___14 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___14 *, int);
	int (*lock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*sendpage)(struct file___14 *, struct page___14 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___14 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___14 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___14 *, long int, struct file_lock___14 **, void **);
		struct {
			int (*setlease)(struct file___14 *, long int, struct file_lock___14 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___14 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___13 *, struct file___14 *);
};

struct fasync_struct___14;

struct file_lock_operations___14;

struct lock_manager_operations___14;

struct file_lock___14 {
	struct file_lock___14 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___7 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___14 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___14 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___14 *fl_ops;
	const struct lock_manager_operations___14 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___14 {
	void (*fl_copy_lock)(struct file_lock___14 *, struct file_lock___14 *);
	void (*fl_release_private)(struct file_lock___14 *);
};

struct lock_manager_operations___14 {
	int (*lm_compare_owner)(struct file_lock___14 *, struct file_lock___14 *);
	long unsigned int (*lm_owner_key)(struct file_lock___14 *);
	void (*lm_notify)(struct file_lock___14 *);
	int (*lm_grant)(struct file_lock___14 *, struct file_lock___14 *, int);
	void (*lm_break)(struct file_lock___14 *);
	int (*lm_change)(struct file_lock___14 **, int);
};

struct fasync_struct___14 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___14 *fa_next;
	struct file___14 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___14 {
	const char *name;
	int fs_flags;
	struct dentry___15 * (*mount)(struct file_system_type___14 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___15 *);
	struct module___8 *owner;
	struct file_system_type___14 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___14 {
	struct inode___15 * (*alloc_inode)(struct super_block___15 *);
	void (*destroy_inode)(struct inode___15 *);
	void (*dirty_inode)(struct inode___15 *, int);
	int (*write_inode)(struct inode___15 *, struct writeback_control *);
	int (*drop_inode)(struct inode___15 *);
	void (*evict_inode)(struct inode___15 *);
	void (*put_super)(struct super_block___15 *);
	int (*sync_fs)(struct super_block___15 *, int);
	int (*freeze_fs)(struct super_block___15 *);
	int (*unfreeze_fs)(struct super_block___15 *);
	int (*statfs)(struct dentry___15 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___15 *, int *, char *);
	void (*umount_begin)(struct super_block___15 *);
	int (*show_options)(struct seq_file___13 *, struct dentry___15 *);
	int (*show_devname)(struct seq_file___13 *, struct dentry___15 *);
	int (*show_path)(struct seq_file___13 *, struct dentry___15 *);
	int (*show_stats)(struct seq_file___13 *, struct dentry___15 *);
	ssize_t (*quota_read)(struct super_block___15 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___15 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___15 *);
	int (*bdev_try_to_free_page)(struct super_block___15 *, struct page___14 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___15 *);
	void (*free_cached_objects)(struct super_block___15 *, int);
};

typedef void (*poll_queue_proc___8)(struct file___14 *, wait_queue_head_t *, struct poll_table_struct___8 *);

struct poll_table_struct___8 {
	poll_queue_proc___8 _qproc;
	long unsigned int _key;
};

struct seq_operations___13;

struct seq_file___13 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___16 lock;
	const struct seq_operations___13 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct acpi_hotplug_profile___3 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___3 *);
	void (*notify_online)(struct acpi_device___3 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___3 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___3 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___3 *);
	void (*bind)(struct device___9 *);
	void (*unbind)(struct device___9 *);
	struct acpi_hotplug_profile___3 hotplug;
};

struct acpi_hotplug_context___3 {
	struct acpi_device___3 *self;
	int (*notify)(struct acpi_device___3 *, u32);
	void (*uevent)(struct acpi_device___3 *, u32);
	void (*fixup)(struct acpi_device___3 *);
};

typedef int (*acpi_op_add___3)(struct acpi_device___3 *);

typedef int (*acpi_op_remove___3)(struct acpi_device___3 *);

typedef void (*acpi_op_notify___3)(struct acpi_device___3 *, u32);

struct acpi_device_ops___3 {
	acpi_op_add___3 add;
	acpi_op_remove___3 remove;
	acpi_op_notify___3 notify;
};

struct acpi_driver___3 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___3 ops;
	struct device_driver___9 drv;
	struct module___8 *owner;
};

struct pci_ops___2;

struct pci_bus___2 {
	struct list_head node;
	struct pci_bus___2 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___3 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___2 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___9 *bridge;
	struct device___9 dev;
	struct bin_attribute___9 *legacy_io;
	struct bin_attribute___9 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct seq_operations___13 {
	void * (*start)(struct seq_file___13 *, loff_t *);
	void (*stop)(struct seq_file___13 *, void *);
	void * (*next)(struct seq_file___13 *, void *, loff_t *);
	int (*show)(struct seq_file___13 *, void *);
};

struct vc_data;

struct console_font;

struct consw {
	struct module___8 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	int (*con_scroll)(struct vc_data *, int, int, int, int);
	void (*con_bmove)(struct vc_data *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct irq_chip___13 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___13 *);
	void (*irq_shutdown)(struct irq_data___13 *);
	void (*irq_enable)(struct irq_data___13 *);
	void (*irq_disable)(struct irq_data___13 *);
	void (*irq_ack)(struct irq_data___13 *);
	void (*irq_mask)(struct irq_data___13 *);
	void (*irq_mask_ack)(struct irq_data___13 *);
	void (*irq_unmask)(struct irq_data___13 *);
	void (*irq_eoi)(struct irq_data___13 *);
	int (*irq_set_affinity)(struct irq_data___13 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___13 *);
	int (*irq_set_type)(struct irq_data___13 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___13 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___13 *);
	void (*irq_bus_sync_unlock)(struct irq_data___13 *);
	void (*irq_cpu_online)(struct irq_data___13 *);
	void (*irq_cpu_offline)(struct irq_data___13 *);
	void (*irq_suspend)(struct irq_data___13 *);
	void (*irq_resume)(struct irq_data___13 *);
	void (*irq_pm_shutdown)(struct irq_data___13 *);
	void (*irq_print_chip)(struct irq_data___13 *, struct seq_file___13 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___13 *, void *);
	long unsigned int flags;
};

struct module_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___7 *, struct module_kobject___7 *, char *);
	ssize_t (*store)(struct module_attribute___7 *, struct module_kobject___7 *, const char *, size_t);
	void (*setup)(struct module___8 *, const char *);
	int (*test)(struct module___8 *);
	void (*free)(struct module___8 *);
};

struct pci_slot___2 {
	struct pci_bus___2 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_error_handlers___2;

struct pci_driver_rh___2;

struct pci_driver___2 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___3 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___3 *);
	int (*suspend)(struct pci_dev___3 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___3 *, pm_message_t);
	int (*resume_early)(struct pci_dev___3 *);
	int (*resume)(struct pci_dev___3 *);
	void (*shutdown)(struct pci_dev___3 *);
	int (*sriov_configure)(struct pci_dev___3 *, int);
	const struct pci_error_handlers___2 *err_handler;
	struct device_driver___9 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___2 *pci_driver_rh;
};

struct pci_ops___2 {
	int (*read)(struct pci_bus___2 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___2 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___2 {
	pci_ers_result_t (*error_detected)(struct pci_dev___3 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___3 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___3 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___3 *);
	void (*resume)(struct pci_dev___3 *);
};

struct pci_driver_rh___2 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___3 *, bool);
};

struct tboot_mac_region {
	u64 start;
	u32 size;
} __attribute__((packed));

struct tboot_acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct tboot_acpi_sleep_info {
	struct tboot_acpi_generic_address pm1a_cnt_blk;
	struct tboot_acpi_generic_address pm1b_cnt_blk;
	struct tboot_acpi_generic_address pm1a_evt_blk;
	struct tboot_acpi_generic_address pm1b_evt_blk;
	u16 pm1a_cnt_val;
	u16 pm1b_cnt_val;
	u64 wakeup_vector;
	u32 vector_width;
	u64 kernel_s3_resume_vector;
} __attribute__((packed));

struct tboot {
	u8 uuid[16];
	u32 version;
	u32 log_addr;
	u32 shutdown_entry;
	u32 shutdown_type;
	struct tboot_acpi_sleep_info acpi_sinfo;
	u32 tboot_base;
	u32 tboot_size;
	u8 num_mac_regions;
	struct tboot_mac_region mac_regions[32];
	u8 s3_key[64];
	u8 reserved_align[3];
	u32 num_in_wfs;
} __attribute__((packed));

struct legacy_pic___2 {
	int nr_legacy_irqs;
	struct irq_chip___13 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

struct tlb_state___5 {
	struct mm_struct___17 *active_mm;
	int state;
};

struct amd_l3_cache {
	unsigned int indices;
	u8 subcaches[4];
};

struct threshold_block {
	unsigned int block;
	unsigned int bank;
	unsigned int cpu;
	u32 address;
	u16 interrupt_enable;
	bool interrupt_capable;
	u16 threshold_limit;
	struct kobject kobj;
	struct list_head miscj;
};

struct threshold_bank {
	struct kobject *kobj;
	struct threshold_block *blocks;
	atomic_t cpus;
};

struct amd_northbridge {
	struct pci_dev___3 *misc;
	struct pci_dev___3 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info {
	u16 num;
	u64 flags;
	struct amd_northbridge *nb;
};

struct property___2 {
	char *name;
	int length;
	void *value;
	struct property___2 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___9 attr;
};

struct page___15;

typedef struct page___15 *pgtable_t___15;

struct address_space___15;

struct kmem_cache___12;

struct page___15 {
	long unsigned int flags;
	struct address_space___15 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___15 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___15 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___12 *slab_cache;
		struct page___15 *first_page;
	};
	long: 64;
};

struct mm_struct___18;

struct pv_mmu_ops___18 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___18 *, struct mm_struct___18 *);
	void (*dup_mmap)(struct mm_struct___18 *, struct mm_struct___18 *);
	void (*exit_mmap)(struct mm_struct___18 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___18 *);
	void (*pgd_free)(struct mm_struct___18 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___18 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___18 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___18 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___18 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___18 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___18 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___18 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___18 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___18 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___18 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___18 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct xol_area___15;

struct uprobes_state___15 {
	struct xol_area___15 *xol_area;
};

struct vm_area_struct___18;

struct file___15;

struct mm_struct___18 {
	struct vm_area_struct___18 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___18 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___18 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___16 context;
	long unsigned int flags;
	struct core_state___15 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file___15 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___15 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct x86_msi_ops {
	int (*setup_msi_irqs)(struct pci_dev___2 *, int, int);
	void (*compose_msi_msg)(struct pci_dev___2 *, unsigned int, unsigned int, struct msi_msg *, u8);
	void (*teardown_msi_irq)(unsigned int);
	void (*teardown_msi_irqs)(struct pci_dev___2 *);
	void (*restore_msi_irqs)(struct pci_dev___2 *);
	int (*setup_hpet_msi)(unsigned int, unsigned int);
	u32 (*msi_mask_irq)(struct msi_desc *, u32, u32);
	u32 (*msix_mask_irq)(struct msi_desc *, u32);
};

struct dma_map_ops___5;

struct dev_archdata___5 {
	struct dma_map_ops___5 *dma_ops;
	void *iommu;
};

struct device_type___10;

struct bus_type___10;

struct device_driver___10;

struct dev_pm_domain___10;

struct class___10;

struct attribute_group___10;

struct device_rh___10;

struct device___10 {
	struct device___10 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___10 *type;
	struct mutex___16 mutex;
	struct bus_type___10 *bus;
	struct device_driver___10 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___10 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___5 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___10 *class;
	const struct attribute_group___10 **groups;
	void (*release)(struct device___10 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___10 *device_rh;
};

struct pci_bus___3;

struct pci_slot___3;

struct pci_driver___3;

struct bin_attribute___10;

struct pci_dev___2 {
	struct list_head bus_list;
	struct pci_bus___3 *bus;
	struct pci_bus___3 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___3 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___3 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___10 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___10 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___10 *res_attr[17];
	struct bin_attribute___10 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___10 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___2 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___10 {
	int (*prepare)(struct device___10 *);
	void (*complete)(struct device___10 *);
	int (*suspend)(struct device___10 *);
	int (*resume)(struct device___10 *);
	int (*freeze)(struct device___10 *);
	int (*thaw)(struct device___10 *);
	int (*poweroff)(struct device___10 *);
	int (*restore)(struct device___10 *);
	int (*suspend_late)(struct device___10 *);
	int (*resume_early)(struct device___10 *);
	int (*freeze_late)(struct device___10 *);
	int (*thaw_early)(struct device___10 *);
	int (*poweroff_late)(struct device___10 *);
	int (*restore_early)(struct device___10 *);
	int (*suspend_noirq)(struct device___10 *);
	int (*resume_noirq)(struct device___10 *);
	int (*freeze_noirq)(struct device___10 *);
	int (*thaw_noirq)(struct device___10 *);
	int (*poweroff_noirq)(struct device___10 *);
	int (*restore_noirq)(struct device___10 *);
	int (*runtime_suspend)(struct device___10 *);
	int (*runtime_resume)(struct device___10 *);
	int (*runtime_idle)(struct device___10 *);
};

struct dev_pm_info_rh___10 {
	void (*set_latency_tolerance)(struct device___10 *, s32);
};

struct dev_pm_domain___10 {
	struct dev_pm_ops___10 ops;
};

struct attribute_group___10 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___10 **bin_attrs;
};

struct bin_attribute___10 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___15 *, struct kobject *, struct bin_attribute___10 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___15 *, struct kobject *, struct bin_attribute___10 *, char *, loff_t, size_t);
	int (*mmap)(struct file___15 *, struct kobject *, struct bin_attribute___10 *, struct vm_area_struct___18 *);
};

struct dentry___16;

struct path___15 {
	struct vfsmount *mnt;
	struct dentry___16 *dentry;
};

struct inode___16;

struct file_operations___15;

struct file___15 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___15 f_path;
	struct inode___16 *f_inode;
	const struct file_operations___15 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___15 *f_mapping;
	struct mutex___16 f_pos_lock;
};

struct vm_operations_struct___14;

struct vm_area_struct___18 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___18 *vm_next;
	struct vm_area_struct___18 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___18 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___14 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___15 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dma_map_ops___5 {
	void * (*alloc)(struct device___10 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___10 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___10 *, struct vm_area_struct___18 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___10 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___10 *, struct page___15 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___10 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___10 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___10 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___10 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___10 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___10 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___10 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___10 *, dma_addr_t);
	int (*dma_supported)(struct device___10 *, u64);
	int (*set_dma_mask)(struct device___10 *, u64);
	int is_phys;
};

struct bus_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___10 *, char *);
	ssize_t (*store)(struct bus_type___10 *, const char *, size_t);
};

struct device_attribute___10;

struct driver_attribute___10;

struct bus_type___10 {
	const char *name;
	const char *dev_name;
	struct device___10 *dev_root;
	struct bus_attribute___10 *bus_attrs;
	struct device_attribute___10 *dev_attrs;
	struct driver_attribute___10 *drv_attrs;
	const struct attribute_group___10 **bus_groups;
	const struct attribute_group___10 **dev_groups;
	const struct attribute_group___10 **drv_groups;
	int (*match)(struct device___10 *, struct device_driver___10 *);
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	int (*probe)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*online)(struct device___10 *);
	int (*offline)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct dev_pm_ops___10 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct device___10 *, struct device_attribute___10 *, char *);
	ssize_t (*store)(struct device___10 *, struct device_attribute___10 *, const char *, size_t);
};

struct driver_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___10 *, char *);
	ssize_t (*store)(struct device_driver___10 *, const char *, size_t);
};

struct device_driver___10 {
	const char *name;
	struct bus_type___10 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct attribute_group___10 **groups;
	const struct dev_pm_ops___10 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___10 {
	const char *name;
	const struct attribute_group___10 **groups;
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___10 *);
	const struct dev_pm_ops___10 *pm;
};

struct class_attribute___10;

struct class___10 {
	const char *name;
	struct module___8 *owner;
	struct class_attribute___10 *class_attrs;
	struct device_attribute___10 *dev_attrs;
	const struct attribute_group___10 **dev_groups;
	struct bin_attribute___10 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *);
	void (*class_release)(struct class___10 *);
	void (*dev_release)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___10 *);
	const struct dev_pm_ops___10 *pm;
	struct subsys_private *p;
};

struct class_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct class___10 *, struct class_attribute___10 *, char *);
	ssize_t (*store)(struct class___10 *, struct class_attribute___10 *, const char *, size_t);
	const void * (*namespace)(struct class___10 *, const struct class_attribute___10 *);
};

struct device_rh___10 {
	struct dev_pm_info_rh___10 power;
};

struct pci_slot___3 {
	struct pci_bus___3 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___3;

struct msi_chip___2;

struct pci_bus___3 {
	struct list_head node;
	struct pci_bus___3 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___2 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___3 *ops;
	struct msi_chip___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___10 *bridge;
	struct device___10 dev;
	struct bin_attribute___10 *legacy_io;
	struct bin_attribute___10 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___3;

struct pci_driver_rh___3;

struct pci_driver___3 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___2 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___2 *);
	int (*suspend)(struct pci_dev___2 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___2 *, pm_message_t);
	int (*resume_early)(struct pci_dev___2 *);
	int (*resume)(struct pci_dev___2 *);
	void (*shutdown)(struct pci_dev___2 *);
	int (*sriov_configure)(struct pci_dev___2 *, int);
	const struct pci_error_handlers___3 *err_handler;
	struct device_driver___10 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___3 *pci_driver_rh;
};

struct pci_ops___3 {
	int (*read)(struct pci_bus___3 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___3 *, unsigned int, int, int, u32);
};

struct msi_chip___2 {
	struct module___8 *owner;
	struct device___10 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___2 *, struct pci_dev___2 *, struct msi_desc *);
	void (*teardown_irq)(struct msi_chip___2 *, unsigned int);
	int (*check_device)(struct msi_chip___2 *, struct pci_dev___2 *, int, int);
};

struct pci_error_handlers___3 {
	pci_ers_result_t (*error_detected)(struct pci_dev___2 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___2 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___2 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___2 *);
	void (*resume)(struct pci_dev___2 *);
};

struct pci_driver_rh___3 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___2 *, bool);
};

struct xol_area___15 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___15 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___12;

struct memcg_cache_params___12;

struct kmem_cache___12 {
	struct kmem_cache_cpu___12 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___12 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___15;

struct address_space___15 {
	struct inode___16 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___16 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___15 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___12;

struct vm_operations_struct___14 {
	void (*open)(struct vm_area_struct___18 *);
	void (*close)(struct vm_area_struct___18 *);
	int (*fault)(struct vm_area_struct___18 *, struct vm_fault___12 *);
	int (*page_mkwrite)(struct vm_area_struct___18 *, struct vm_fault___12 *);
	int (*access)(struct vm_area_struct___18 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___18 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___18 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___18 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___18 *, long unsigned int, long unsigned int, long unsigned int);
};

struct vm_fault___12 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___15 *page;
};

struct kmem_cache_cpu___12 {
	void **freelist;
	long unsigned int tid;
	struct page___15 *page;
	struct page___15 *partial;
};

struct memcg_cache_params___12 {
	bool is_root_cache;
	union {
		struct kmem_cache___12 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___12 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cdev___5 {
	struct kobject kobj;
	struct module___8 *owner;
	const struct file_operations___15 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___9;

struct file_lock___15;

struct file_operations___15 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___15 *, loff_t, int);
	ssize_t (*read)(struct file___15 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___15 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___15 *, void *, filldir_t);
	unsigned int (*poll)(struct file___15 *, struct poll_table_struct___9 *);
	long int (*unlocked_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___15 *, struct vm_area_struct___18 *);
	int (*open)(struct inode___16 *, struct file___15 *);
	int (*flush)(struct file___15 *, fl_owner_t);
	int (*release)(struct inode___16 *, struct file___15 *);
	int (*fsync)(struct file___15 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___15 *, int);
	int (*lock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*sendpage)(struct file___15 *, struct page___15 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___15 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___15 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___15 *, long int, struct file_lock___15 **, void **);
		struct {
			int (*setlease)(struct file___15 *, long int, struct file_lock___15 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___15 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___13 *, struct file___15 *);
};

struct dentry_operations___15;

struct super_block___16;

struct dentry___16 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___16 *d_parent;
	struct qstr d_name;
	struct inode___16 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___15 *d_op;
	struct super_block___16 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___15;

struct dquot___15;

struct block_device___15;

struct inode___16 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___15 *i_op;
	struct super_block___16 *i_sb;
	struct address_space___15 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___16 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___15 *i_fop;
	struct file_lock___15 *i_flock;
	struct address_space___15 i_data;
	struct dquot___15 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___15 *i_bdev;
		struct cdev___5 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___15 {
	int (*d_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_hash)(const struct dentry___16 *, struct qstr *);
	int (*d_compare)(const struct dentry___16 *, const struct dentry___16 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___16 *);
	void (*d_release)(struct dentry___16 *);
	void (*d_prune)(struct dentry___16 *);
	void (*d_iput)(struct dentry___16 *, struct inode___16 *);
	char * (*d_dname)(struct dentry___16 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___15 *);
	int (*d_manage)(struct dentry___16 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___15;

struct mem_dqinfo___15 {
	struct quota_format_type___15 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___15;

struct quota_info___15 {
	unsigned int flags;
	struct mutex___16 dqio_mutex;
	struct mutex___16 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___16 *files[2];
	struct mem_dqinfo___15 info[2];
	const struct quota_format_ops___15 *ops[2];
};

struct file_system_type___15;

struct super_operations___15;

struct dquot_operations___15;

struct quotactl_ops___15;

struct super_block___16 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___15 *s_type;
	const struct super_operations___15 *s_op;
	const struct dquot_operations___15 *dq_op;
	const struct quotactl_ops___15 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___16 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___15 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___15 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___16 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___15 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___15 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___16 *bd_inode;
	struct super_block___16 *bd_super;
	struct mutex___16 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___15 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___16 bd_fsfreeze_mutex;
};

struct iattr___16 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___15 *ia_file;
};

struct dquot___15 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___16 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___16 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___15 {
	int qf_fmt_id;
	const struct quota_format_ops___15 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___15 *qf_next;
};

struct quota_format_ops___15 {
	int (*check_quota_file)(struct super_block___16 *, int);
	int (*read_file_info)(struct super_block___16 *, int);
	int (*write_file_info)(struct super_block___16 *, int);
	int (*free_file_info)(struct super_block___16 *, int);
	int (*read_dqblk)(struct dquot___15 *);
	int (*commit_dqblk)(struct dquot___15 *);
	int (*release_dqblk)(struct dquot___15 *);
};

struct dquot_operations___15 {
	int (*write_dquot)(struct dquot___15 *);
	struct dquot___15 * (*alloc_dquot)(struct super_block___16 *, int);
	void (*destroy_dquot)(struct dquot___15 *);
	int (*acquire_dquot)(struct dquot___15 *);
	int (*release_dquot)(struct dquot___15 *);
	int (*mark_dirty)(struct dquot___15 *);
	int (*write_info)(struct super_block___16 *, int);
	qsize_t * (*get_reserved_space)(struct inode___16 *);
};

struct quotactl_ops___15 {
	int (*quota_on)(struct super_block___16 *, int, int, struct path___15 *);
	int (*quota_on_meta)(struct super_block___16 *, int, int);
	int (*quota_off)(struct super_block___16 *, int);
	int (*quota_sync)(struct super_block___16 *, int);
	int (*get_info)(struct super_block___16 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___16 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___16 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___16 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___16 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___16 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___16 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___16 *, unsigned int);
};

struct address_space_operations___15 {
	int (*writepage)(struct page___15 *, struct writeback_control *);
	int (*readpage)(struct file___15 *, struct page___15 *);
	int (*writepages)(struct address_space___15 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___15 *);
	int (*readpages)(struct file___15 *, struct address_space___15 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___15 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___15 **, void **);
	int (*write_end)(struct file___15 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___15 *, void *);
	sector_t (*bmap)(struct address_space___15 *, sector_t);
	void (*invalidatepage)(struct page___15 *, long unsigned int);
	int (*releasepage)(struct page___15 *, gfp_t);
	void (*freepage)(struct page___15 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___15 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___15 *, struct page___15 *, struct page___15 *, enum migrate_mode);
	int (*launder_page)(struct page___15 *);
	int (*is_partially_uptodate)(struct page___15 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___15 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___15 *, struct page___15 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___15 *, sector_t *);
	void (*swap_deactivate)(struct file___15 *);
	void (*invalidatepage_range)(struct page___15 *, unsigned int, unsigned int);
};

struct inode_operations___15 {
	struct dentry___16 * (*lookup)(struct inode___16 *, struct dentry___16 *, unsigned int);
	void * (*follow_link)(struct dentry___16 *, struct nameidata *);
	int (*permission)(struct inode___16 *, int);
	struct posix_acl * (*get_acl)(struct inode___16 *, int);
	int (*readlink)(struct dentry___16 *, char *, int);
	void (*put_link)(struct dentry___16 *, struct nameidata *, void *);
	int (*create)(struct inode___16 *, struct dentry___16 *, umode_t, bool);
	int (*link)(struct dentry___16 *, struct inode___16 *, struct dentry___16 *);
	int (*unlink)(struct inode___16 *, struct dentry___16 *);
	int (*symlink)(struct inode___16 *, struct dentry___16 *, const char *);
	int (*mkdir)(struct inode___16 *, struct dentry___16 *, umode_t);
	int (*rmdir)(struct inode___16 *, struct dentry___16 *);
	int (*mknod)(struct inode___16 *, struct dentry___16 *, umode_t, dev_t);
	int (*rename)(struct inode___16 *, struct dentry___16 *, struct inode___16 *, struct dentry___16 *);
	int (*setattr)(struct dentry___16 *, struct iattr___16 *);
	int (*getattr)(struct vfsmount *, struct dentry___16 *, struct kstat *);
	int (*setxattr)(struct dentry___16 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___16 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___16 *, char *, size_t);
	int (*removexattr)(struct dentry___16 *, const char *);
	int (*fiemap)(struct inode___16 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___16 *, struct timespec *, int);
	int (*atomic_open)(struct inode___16 *, struct dentry___16 *, struct file___15 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___15;

struct file_lock_operations___15;

struct lock_manager_operations___15;

struct file_lock___15 {
	struct file_lock___15 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___7 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___15 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___15 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___15 *fl_ops;
	const struct lock_manager_operations___15 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___15 {
	void (*fl_copy_lock)(struct file_lock___15 *, struct file_lock___15 *);
	void (*fl_release_private)(struct file_lock___15 *);
};

struct lock_manager_operations___15 {
	int (*lm_compare_owner)(struct file_lock___15 *, struct file_lock___15 *);
	long unsigned int (*lm_owner_key)(struct file_lock___15 *);
	void (*lm_notify)(struct file_lock___15 *);
	int (*lm_grant)(struct file_lock___15 *, struct file_lock___15 *, int);
	void (*lm_break)(struct file_lock___15 *);
	int (*lm_change)(struct file_lock___15 **, int);
};

struct fasync_struct___15 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___15 *fa_next;
	struct file___15 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___15 {
	const char *name;
	int fs_flags;
	struct dentry___16 * (*mount)(struct file_system_type___15 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___16 *);
	struct module___8 *owner;
	struct file_system_type___15 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___15 {
	struct inode___16 * (*alloc_inode)(struct super_block___16 *);
	void (*destroy_inode)(struct inode___16 *);
	void (*dirty_inode)(struct inode___16 *, int);
	int (*write_inode)(struct inode___16 *, struct writeback_control *);
	int (*drop_inode)(struct inode___16 *);
	void (*evict_inode)(struct inode___16 *);
	void (*put_super)(struct super_block___16 *);
	int (*sync_fs)(struct super_block___16 *, int);
	int (*freeze_fs)(struct super_block___16 *);
	int (*unfreeze_fs)(struct super_block___16 *);
	int (*statfs)(struct dentry___16 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___16 *, int *, char *);
	void (*umount_begin)(struct super_block___16 *);
	int (*show_options)(struct seq_file___13 *, struct dentry___16 *);
	int (*show_devname)(struct seq_file___13 *, struct dentry___16 *);
	int (*show_path)(struct seq_file___13 *, struct dentry___16 *);
	int (*show_stats)(struct seq_file___13 *, struct dentry___16 *);
	ssize_t (*quota_read)(struct super_block___16 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___16 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___16 *);
	int (*bdev_try_to_free_page)(struct super_block___16 *, struct page___15 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___16 *);
	void (*free_cached_objects)(struct super_block___16 *, int);
};

typedef void (*poll_queue_proc___9)(struct file___15 *, wait_queue_head_t *, struct poll_table_struct___9 *);

struct poll_table_struct___9 {
	poll_queue_proc___9 _qproc;
	long unsigned int _key;
};

struct irq_desc___4;

typedef void (*irq_flow_handler_t___4)(unsigned int, struct irq_desc___4 *);

struct irqaction___4;

struct irq_desc___4 {
	struct irq_data___13 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___4 handle_irq;
	struct irqaction___4 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct irqaction___4 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___4 *next;
	irq_handler_t thread_fn;
	struct task_struct___16 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct syscore_ops {
	struct list_head node;
	int (*suspend)();
	void (*resume)();
	void (*shutdown)();
};

struct device___11;

struct dev_pm_ops___11 {
	int (*prepare)(struct device___11 *);
	void (*complete)(struct device___11 *);
	int (*suspend)(struct device___11 *);
	int (*resume)(struct device___11 *);
	int (*freeze)(struct device___11 *);
	int (*thaw)(struct device___11 *);
	int (*poweroff)(struct device___11 *);
	int (*restore)(struct device___11 *);
	int (*suspend_late)(struct device___11 *);
	int (*resume_early)(struct device___11 *);
	int (*freeze_late)(struct device___11 *);
	int (*thaw_early)(struct device___11 *);
	int (*poweroff_late)(struct device___11 *);
	int (*restore_early)(struct device___11 *);
	int (*suspend_noirq)(struct device___11 *);
	int (*resume_noirq)(struct device___11 *);
	int (*freeze_noirq)(struct device___11 *);
	int (*thaw_noirq)(struct device___11 *);
	int (*poweroff_noirq)(struct device___11 *);
	int (*restore_noirq)(struct device___11 *);
	int (*runtime_suspend)(struct device___11 *);
	int (*runtime_resume)(struct device___11 *);
	int (*runtime_idle)(struct device___11 *);
};

struct dma_map_ops___6;

struct dev_archdata___6 {
	struct dma_map_ops___6 *dma_ops;
	void *iommu;
};

struct acpi_device___4;

struct acpi_dev_node___6 {
	union {
		struct acpi_device___4 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct device_type___11;

struct bus_type___11;

struct device_driver___11;

struct dev_pm_domain___11;

struct device_node___3;

struct class___11;

struct device_rh___11;

struct device___11 {
	struct device___11 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___11 *type;
	struct mutex___13 mutex;
	struct bus_type___11 *bus;
	struct device_driver___11 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___11 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___6 archdata;
	struct device_node___3 *of_node;
	struct acpi_dev_node___6 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___11 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___11 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___11 *device_rh;
};

struct dev_pm_info_rh___11 {
	void (*set_latency_tolerance)(struct device___11 *, s32);
};

struct dev_pm_domain___11 {
	struct dev_pm_ops___11 ops;
};

struct property___3;

struct device_node___3 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___3 *properties;
	struct property___3 *deadprops;
	struct device_node___3 *parent;
	struct device_node___3 *child;
	struct device_node___3 *sibling;
	struct device_node___3 *next;
	struct device_node___3 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct irq_desc___5;

typedef void (*irq_flow_handler_t___5)(unsigned int, struct irq_desc___5 *);

struct irqaction___5;

struct irq_desc___5 {
	struct irq_data___13 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___5 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct irqaction___5 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___5 *next;
	irq_handler_t thread_fn;
	struct task_struct___13 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___6 {
	void * (*alloc)(struct device___11 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___11 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___11 *, struct vm_area_struct___14 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___11 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___11 *, struct page___11 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___11 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___11 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___11 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___11 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___11 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___11 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___11 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___11 *, dma_addr_t);
	int (*dma_supported)(struct device___11 *, u64);
	int (*set_dma_mask)(struct device___11 *, u64);
	int is_phys;
};

struct bus_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___11 *, char *);
	ssize_t (*store)(struct bus_type___11 *, const char *, size_t);
};

struct device_attribute___11;

struct driver_attribute___11;

struct bus_type___11 {
	const char *name;
	const char *dev_name;
	struct device___11 *dev_root;
	struct bus_attribute___11 *bus_attrs;
	struct device_attribute___11 *dev_attrs;
	struct driver_attribute___11 *drv_attrs;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___11 *, struct device_driver___11 *);
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	int (*probe)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*online)(struct device___11 *);
	int (*offline)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct dev_pm_ops___11 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct device___11 *, struct device_attribute___11 *, char *);
	ssize_t (*store)(struct device___11 *, struct device_attribute___11 *, const char *, size_t);
};

struct driver_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___11 *, char *);
	ssize_t (*store)(struct device_driver___11 *, const char *, size_t);
};

struct device_driver___11 {
	const char *name;
	struct bus_type___11 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct attribute_group___5 **groups;
	const struct dev_pm_ops___11 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___11 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___11 *);
	const struct dev_pm_ops___11 *pm;
};

struct class_attribute___11;

struct class___11 {
	const char *name;
	struct module *owner;
	struct class_attribute___11 *class_attrs;
	struct device_attribute___11 *dev_attrs;
	const struct attribute_group___5 **dev_groups;
	struct bin_attribute___5 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *);
	void (*class_release)(struct class___11 *);
	void (*dev_release)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___11 *);
	const struct dev_pm_ops___11 *pm;
	struct subsys_private *p;
};

struct class_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct class___11 *, struct class_attribute___11 *, char *);
	ssize_t (*store)(struct class___11 *, struct class_attribute___11 *, const char *, size_t);
	const void * (*namespace)(struct class___11 *, const struct class_attribute___11 *);
};

struct acpi_scan_handler___4;

struct acpi_hotplug_context___4;

struct acpi_driver___4;

struct acpi_device___4 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___4 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___4 *handler;
	struct acpi_hotplug_context___4 *hp;
	struct acpi_driver___4 *driver;
	void *driver_data;
	struct device___11 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___13 physical_node_lock;
	void (*remove)(struct acpi_device___4 *);
};

struct device_rh___11 {
	struct dev_pm_info_rh___11 power;
};

struct acpi_hotplug_profile___4 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___4 *);
	void (*notify_online)(struct acpi_device___4 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___4 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___4 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___4 *);
	void (*bind)(struct device___11 *);
	void (*unbind)(struct device___11 *);
	struct acpi_hotplug_profile___4 hotplug;
};

struct acpi_hotplug_context___4 {
	struct acpi_device___4 *self;
	int (*notify)(struct acpi_device___4 *, u32);
	void (*uevent)(struct acpi_device___4 *, u32);
	void (*fixup)(struct acpi_device___4 *);
};

typedef int (*acpi_op_add___4)(struct acpi_device___4 *);

typedef int (*acpi_op_remove___4)(struct acpi_device___4 *);

typedef void (*acpi_op_notify___4)(struct acpi_device___4 *, u32);

struct acpi_device_ops___4 {
	acpi_op_add___4 add;
	acpi_op_remove___4 remove;
	acpi_op_notify___4 notify;
};

struct acpi_driver___4 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___4 ops;
	struct device_driver___11 drv;
	struct module *owner;
};

struct property___3 {
	char *name;
	int length;
	void *value;
	struct property___3 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___5 attr;
};

enum jump_label_type {
	JUMP_LABEL_DISABLE = 0,
	JUMP_LABEL_ENABLE = 1,
};

union jump_code_union {
	char code[5];
	struct {
		char jump;
		int offset;
	} __attribute__((packed));
};

struct vm_unmapped_area_info {
	long unsigned int flags;
	long unsigned int length;
	long unsigned int low_limit;
	long unsigned int high_limit;
	long unsigned int align_mask;
	long unsigned int align_offset;
};

enum align_flags {
	ALIGN_VA_32 = 1,
	ALIGN_VA_64 = 2,
};

struct va_alignment {
	int flags;
	long unsigned int mask;
	long unsigned int bits;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*sys_call_ptr_t)();

typedef __kernel_long_t __kernel_suseconds_t;

struct page___16;

typedef struct page___16 *pgtable_t___16;

struct address_space___16;

struct kmem_cache___13;

struct page___16 {
	long unsigned int flags;
	struct address_space___16 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___16 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___16 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___13 *slab_cache;
		struct page___16 *first_page;
	};
	long: 64;
};

struct thread_struct___7;

struct task_struct___17;

struct pv_cpu_ops___16 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___7 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___7 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___17 *);
	void (*end_context_switch)(struct task_struct___17 *);
};

struct perf_event___7;

struct thread_struct___7 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___7 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___8;

struct pid_link___8 {
	struct hlist_node node;
	struct pid___8 *pid;
};

struct mutex___17 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___17 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___14 {
	struct page___16 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___19;

struct nsproxy___8;

struct signal_struct___16;

struct css_set___7;

struct perf_event_context___7;

struct task_struct___17 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___17 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___19 *mm;
	struct mm_struct___19 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___17 *real_parent;
	struct task_struct___17 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___17 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___8 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___16 = 0,
		VTIME_USER___16 = 1,
		VTIME_SYS___16 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___7 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___16 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___7 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___7 *perf_event_ctxp[2];
	struct mutex___17 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___14 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___19 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___19 *, struct mm_struct___19 *);
	void (*dup_mmap)(struct mm_struct___19 *, struct mm_struct___19 *);
	void (*exit_mmap)(struct mm_struct___19 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___19 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___19 *);
	void (*pgd_free)(struct mm_struct___19 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___19 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___19 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___19 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___19 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___19 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___19 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___19 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___19 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___19 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___19 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___19 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___17 lock;
	void *vdso;
} mm_context_t___17;

struct xol_area___16;

struct uprobes_state___16 {
	struct xol_area___16 *xol_area;
};

struct vm_area_struct___19;

struct file___16;

struct core_state___16;

struct mm_struct___19 {
	struct vm_area_struct___19 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___19 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___19 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___17 context;
	long unsigned int flags;
	struct core_state___16 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___17 *owner;
	struct file___16 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___16 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___7 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___17 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___17 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___17 *target;
};

typedef void (*perf_overflow_handler_t___7)(struct perf_event___7 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___7;

typedef void (*ftrace_func_t___7)(long unsigned int, long unsigned int, struct ftrace_ops___7 *, struct pt_regs *);

struct ftrace_ops___7 {
	ftrace_func_t___7 func;
	struct ftrace_ops___7 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___17 regex_lock;
};

struct pmu___7;

struct fasync_struct___16;

struct pid_namespace___8;

struct ftrace_event_call___7;

struct perf_cgroup___7;

struct perf_event___7 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___7 *group_leader;
	struct pmu___7 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___7 hw;
	struct perf_event_context___7 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___17 child_mutex;
	struct list_head child_list;
	struct perf_event___7 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___17 *owner;
	struct mutex___17 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___16 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___7 *);
	struct callback_head callback_head;
	struct pid_namespace___8 *ns;
	u64 id;
	perf_overflow_handler_t___7 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___7 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___7 ftrace_ops;
	struct perf_cgroup___7 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___9 {
	struct task_struct___17 *task;
	struct exec_domain___5 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct timeval {
	__kernel_time_t tv_sec;
	__kernel_suseconds_t tv_usec;
};

struct timezone {
	int tz_minuteswest;
	int tz_dsttime;
};

struct nsproxy___8 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___8 *pid_ns;
	struct net *net_ns;
};

struct zone___16;

struct lruvec___16 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___16 *zone;
};

struct pglist_data___16;

struct zone___16 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___16 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___16 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___16 {
	struct zone___16 *zone;
	int zone_idx;
};

struct zonelist___16 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___16 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___16 {
	struct zone___16 node_zones[4];
	struct zonelist___16 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___17 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___14;

struct x86_io_apic_ops___14 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___14 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___14;

struct irq_data___14 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___14 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___12;

struct dev_pm_ops___12 {
	int (*prepare)(struct device___12 *);
	void (*complete)(struct device___12 *);
	int (*suspend)(struct device___12 *);
	int (*resume)(struct device___12 *);
	int (*freeze)(struct device___12 *);
	int (*thaw)(struct device___12 *);
	int (*poweroff)(struct device___12 *);
	int (*restore)(struct device___12 *);
	int (*suspend_late)(struct device___12 *);
	int (*resume_early)(struct device___12 *);
	int (*freeze_late)(struct device___12 *);
	int (*thaw_early)(struct device___12 *);
	int (*poweroff_late)(struct device___12 *);
	int (*restore_early)(struct device___12 *);
	int (*suspend_noirq)(struct device___12 *);
	int (*resume_noirq)(struct device___12 *);
	int (*freeze_noirq)(struct device___12 *);
	int (*thaw_noirq)(struct device___12 *);
	int (*poweroff_noirq)(struct device___12 *);
	int (*restore_noirq)(struct device___12 *);
	int (*runtime_suspend)(struct device___12 *);
	int (*runtime_resume)(struct device___12 *);
	int (*runtime_idle)(struct device___12 *);
};

struct device_type___12;

struct bus_type___12;

struct device_driver___12;

struct dev_pm_domain___12;

struct class___12;

struct attribute_group___11;

struct device_rh___12;

struct device___12 {
	struct device___12 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___12 *type;
	struct mutex___17 mutex;
	struct bus_type___12 *bus;
	struct device_driver___12 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___12 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___6 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___12 *class;
	const struct attribute_group___11 **groups;
	void (*release)(struct device___12 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___12 *device_rh;
};

struct dev_pm_info_rh___12 {
	void (*set_latency_tolerance)(struct device___12 *, s32);
};

struct dev_pm_domain___12 {
	struct dev_pm_ops___12 ops;
};

struct smp_ops___16 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___17 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct timekeeper {
	struct clocksource *clock;
	u32 mult;
	u32 shift;
	cycle_t cycle_interval;
	cycle_t cycle_last;
	u64 xtime_interval;
	s64 xtime_remainder;
	u32 raw_interval;
	u64 xtime_sec;
	u64 xtime_nsec;
	ktime_t base_mono;
	s64 ntp_error;
	u32 ntp_error_shift;
	struct timespec wall_to_monotonic;
	ktime_t offs_real;
	struct timespec total_sleep_time;
	ktime_t offs_boot;
	struct timespec raw_time;
	s32 tai_offset;
	ktime_t offs_tai;
	u64 ntp_tick;
	u32 ntp_err_mult;
	unsigned int clock_was_set_seq;
	ktime_t next_leap_ktime;
};

struct getcpu_cache {
	long unsigned int blob[16];
};

struct bin_attribute___11;

struct attribute_group___11 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___11 **bin_attrs;
};

struct bin_attribute___11 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___16 *, struct kobject *, struct bin_attribute___11 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___16 *, struct kobject *, struct bin_attribute___11 *, char *, loff_t, size_t);
	int (*mmap)(struct file___16 *, struct kobject *, struct bin_attribute___11 *, struct vm_area_struct___19 *);
};

struct dentry___17;

struct path___16 {
	struct vfsmount *mnt;
	struct dentry___17 *dentry;
};

struct fown_struct___8 {
	rwlock_t lock;
	struct pid___8 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___17;

struct file_operations___16;

struct file___16 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___16 f_path;
	struct inode___17 *f_inode;
	const struct file_operations___16 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___8 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___16 *f_mapping;
	struct mutex___17 f_pos_lock;
};

struct vm_operations_struct___15;

struct vm_area_struct___19 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___19 *vm_next;
	struct vm_area_struct___19 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___19 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___15 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___16 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___12 *, char *);
	ssize_t (*store)(struct bus_type___12 *, const char *, size_t);
};

struct device_attribute___12;

struct driver_attribute___12;

struct bus_type___12 {
	const char *name;
	const char *dev_name;
	struct device___12 *dev_root;
	struct bus_attribute___12 *bus_attrs;
	struct device_attribute___12 *dev_attrs;
	struct driver_attribute___12 *drv_attrs;
	const struct attribute_group___11 **bus_groups;
	const struct attribute_group___11 **dev_groups;
	const struct attribute_group___11 **drv_groups;
	int (*match)(struct device___12 *, struct device_driver___12 *);
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	int (*probe)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*online)(struct device___12 *);
	int (*offline)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct dev_pm_ops___12 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct device___12 *, struct device_attribute___12 *, char *);
	ssize_t (*store)(struct device___12 *, struct device_attribute___12 *, const char *, size_t);
};

struct driver_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___12 *, char *);
	ssize_t (*store)(struct device_driver___12 *, const char *, size_t);
};

struct device_driver___12 {
	const char *name;
	struct bus_type___12 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct attribute_group___11 **groups;
	const struct dev_pm_ops___12 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___12 {
	const char *name;
	const struct attribute_group___11 **groups;
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___12 *);
	const struct dev_pm_ops___12 *pm;
};

struct class_attribute___12;

struct class___12 {
	const char *name;
	struct module *owner;
	struct class_attribute___12 *class_attrs;
	struct device_attribute___12 *dev_attrs;
	const struct attribute_group___11 **dev_groups;
	struct bin_attribute___11 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *);
	void (*class_release)(struct class___12 *);
	void (*dev_release)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___12 *);
	const struct dev_pm_ops___12 *pm;
	struct subsys_private *p;
};

struct class_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct class___12 *, struct class_attribute___12 *, char *);
	ssize_t (*store)(struct class___12 *, struct class_attribute___12 *, const char *, size_t);
	const void * (*namespace)(struct class___12 *, const struct class_attribute___12 *);
};

struct device_rh___12 {
	struct dev_pm_info_rh___12 power;
};

struct super_block___17;

struct dquot___16 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___17 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___17 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___16;

struct mem_dqinfo___16 {
	struct quota_format_type___16 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___16;

struct quota_info___16 {
	unsigned int flags;
	struct mutex___17 dqio_mutex;
	struct mutex___17 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___17 *files[2];
	struct mem_dqinfo___16 info[2];
	const struct quota_format_ops___16 *ops[2];
};

struct file_system_type___16;

struct super_operations___16;

struct dquot_operations___16;

struct quotactl_ops___16;

struct xattr_handler___7;

struct block_device___16;

struct dentry_operations___16;

struct super_block___17 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___16 *s_type;
	const struct super_operations___16 *s_op;
	const struct dquot_operations___16 *dq_op;
	const struct quotactl_ops___16 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___17 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___7 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___16 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___16 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___17 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___16 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___16 {
	int qf_fmt_id;
	const struct quota_format_ops___16 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___16 *qf_next;
};

struct quota_format_ops___16 {
	int (*check_quota_file)(struct super_block___17 *, int);
	int (*read_file_info)(struct super_block___17 *, int);
	int (*write_file_info)(struct super_block___17 *, int);
	int (*free_file_info)(struct super_block___17 *, int);
	int (*read_dqblk)(struct dquot___16 *);
	int (*commit_dqblk)(struct dquot___16 *);
	int (*release_dqblk)(struct dquot___16 *);
};

struct dquot_operations___16 {
	int (*write_dquot)(struct dquot___16 *);
	struct dquot___16 * (*alloc_dquot)(struct super_block___17 *, int);
	void (*destroy_dquot)(struct dquot___16 *);
	int (*acquire_dquot)(struct dquot___16 *);
	int (*release_dquot)(struct dquot___16 *);
	int (*mark_dirty)(struct dquot___16 *);
	int (*write_info)(struct super_block___17 *, int);
	qsize_t * (*get_reserved_space)(struct inode___17 *);
};

struct address_space_operations___16;

struct address_space___16 {
	struct inode___17 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___17 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___16 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___16;

struct file_lock___16;

struct inode___17 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___16 *i_op;
	struct super_block___17 *i_sb;
	struct address_space___16 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___17 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___16 *i_fop;
	struct file_lock___16 *i_flock;
	struct address_space___16 i_data;
	struct dquot___16 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___16 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___16 {
	int (*quota_on)(struct super_block___17 *, int, int, struct path___16 *);
	int (*quota_on_meta)(struct super_block___17 *, int, int);
	int (*quota_off)(struct super_block___17 *, int);
	int (*quota_sync)(struct super_block___17 *, int);
	int (*get_info)(struct super_block___17 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___17 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___17 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___17 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___17 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___17 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___17 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___17 *, unsigned int);
};

struct xol_area___16 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___16 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___13;

struct memcg_cache_params___13;

struct kmem_cache___13 {
	struct kmem_cache_cpu___13 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___13 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___13;

struct vm_operations_struct___15 {
	void (*open)(struct vm_area_struct___19 *);
	void (*close)(struct vm_area_struct___19 *);
	int (*fault)(struct vm_area_struct___19 *, struct vm_fault___13 *);
	int (*page_mkwrite)(struct vm_area_struct___19 *, struct vm_fault___13 *);
	int (*access)(struct vm_area_struct___19 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___19 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___19 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___19 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___19 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___16 {
	struct task_struct___17 *task;
	struct core_thread___16 *next;
};

struct core_state___16 {
	atomic_t nr_threads;
	struct core_thread___16 dumper;
	struct completion startup;
};

struct vm_fault___13 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___16 *page;
};

struct seq_operations___14;

struct seq_file___14 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___17 lock;
	const struct seq_operations___14 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___14 {
	void * (*start)(struct seq_file___14 *, loff_t *);
	void (*stop)(struct seq_file___14 *, void *);
	void * (*next)(struct seq_file___14 *, void *, loff_t *);
	int (*show)(struct seq_file___14 *, void *);
};

struct dentry___17 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___17 *d_parent;
	struct qstr d_name;
	struct inode___17 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___16 *d_op;
	struct super_block___17 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___16 {
	int (*d_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_hash)(const struct dentry___17 *, struct qstr *);
	int (*d_compare)(const struct dentry___17 *, const struct dentry___17 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___17 *);
	void (*d_release)(struct dentry___17 *);
	void (*d_prune)(struct dentry___17 *);
	void (*d_iput)(struct dentry___17 *, struct inode___17 *);
	char * (*d_dname)(struct dentry___17 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___16 *);
	int (*d_manage)(struct dentry___17 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___8 {
	int nr;
	struct pid_namespace___8 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___8 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___17 *child_reaper;
	struct kmem_cache___13 *pid_cachep;
	unsigned int level;
	struct pid_namespace___8 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___17 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___8 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___8 numbers[1];
};

struct block_device___16 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___17 *bd_inode;
	struct super_block___17 *bd_super;
	struct mutex___17 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___16 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___17 bd_fsfreeze_mutex;
};

struct cgroup___7;

struct cgroup_subsys_state___7 {
	struct cgroup___7 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___17 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___16 *ia_file;
};

struct address_space_operations___16 {
	int (*writepage)(struct page___16 *, struct writeback_control *);
	int (*readpage)(struct file___16 *, struct page___16 *);
	int (*writepages)(struct address_space___16 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___16 *);
	int (*readpages)(struct file___16 *, struct address_space___16 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___16 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___16 **, void **);
	int (*write_end)(struct file___16 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___16 *, void *);
	sector_t (*bmap)(struct address_space___16 *, sector_t);
	void (*invalidatepage)(struct page___16 *, long unsigned int);
	int (*releasepage)(struct page___16 *, gfp_t);
	void (*freepage)(struct page___16 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___16 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___16 *, struct page___16 *, struct page___16 *, enum migrate_mode);
	int (*launder_page)(struct page___16 *);
	int (*is_partially_uptodate)(struct page___16 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___16 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___16 *, struct page___16 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___16 *, sector_t *);
	void (*swap_deactivate)(struct file___16 *);
	void (*invalidatepage_range)(struct page___16 *, unsigned int, unsigned int);
};

struct inode_operations___16 {
	struct dentry___17 * (*lookup)(struct inode___17 *, struct dentry___17 *, unsigned int);
	void * (*follow_link)(struct dentry___17 *, struct nameidata *);
	int (*permission)(struct inode___17 *, int);
	struct posix_acl * (*get_acl)(struct inode___17 *, int);
	int (*readlink)(struct dentry___17 *, char *, int);
	void (*put_link)(struct dentry___17 *, struct nameidata *, void *);
	int (*create)(struct inode___17 *, struct dentry___17 *, umode_t, bool);
	int (*link)(struct dentry___17 *, struct inode___17 *, struct dentry___17 *);
	int (*unlink)(struct inode___17 *, struct dentry___17 *);
	int (*symlink)(struct inode___17 *, struct dentry___17 *, const char *);
	int (*mkdir)(struct inode___17 *, struct dentry___17 *, umode_t);
	int (*rmdir)(struct inode___17 *, struct dentry___17 *);
	int (*mknod)(struct inode___17 *, struct dentry___17 *, umode_t, dev_t);
	int (*rename)(struct inode___17 *, struct dentry___17 *, struct inode___17 *, struct dentry___17 *);
	int (*setattr)(struct dentry___17 *, struct iattr___17 *);
	int (*getattr)(struct vfsmount *, struct dentry___17 *, struct kstat *);
	int (*setxattr)(struct dentry___17 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___17 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___17 *, char *, size_t);
	int (*removexattr)(struct dentry___17 *, const char *);
	int (*fiemap)(struct inode___17 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___17 *, struct timespec *, int);
	int (*atomic_open)(struct inode___17 *, struct dentry___17 *, struct file___16 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___10;

struct file_operations___16 {
	struct module *owner;
	loff_t (*llseek)(struct file___16 *, loff_t, int);
	ssize_t (*read)(struct file___16 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___16 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___16 *, void *, filldir_t);
	unsigned int (*poll)(struct file___16 *, struct poll_table_struct___10 *);
	long int (*unlocked_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___16 *, struct vm_area_struct___19 *);
	int (*open)(struct inode___17 *, struct file___16 *);
	int (*flush)(struct file___16 *, fl_owner_t);
	int (*release)(struct inode___17 *, struct file___16 *);
	int (*fsync)(struct file___16 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___16 *, int);
	int (*lock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*sendpage)(struct file___16 *, struct page___16 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___16 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___16 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___16 *, long int, struct file_lock___16 **, void **);
		struct {
			int (*setlease)(struct file___16 *, long int, struct file_lock___16 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___16 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___14 *, struct file___16 *);
};

struct file_lock_operations___16;

struct lock_manager_operations___16;

struct file_lock___16 {
	struct file_lock___16 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___8 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___16 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___16 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___16 *fl_ops;
	const struct lock_manager_operations___16 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___16 {
	void (*fl_copy_lock)(struct file_lock___16 *, struct file_lock___16 *);
	void (*fl_release_private)(struct file_lock___16 *);
};

struct lock_manager_operations___16 {
	int (*lm_compare_owner)(struct file_lock___16 *, struct file_lock___16 *);
	long unsigned int (*lm_owner_key)(struct file_lock___16 *);
	void (*lm_notify)(struct file_lock___16 *);
	int (*lm_grant)(struct file_lock___16 *, struct file_lock___16 *, int);
	void (*lm_break)(struct file_lock___16 *);
	int (*lm_change)(struct file_lock___16 **, int);
};

struct fasync_struct___16 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___16 *fa_next;
	struct file___16 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___16 {
	const char *name;
	int fs_flags;
	struct dentry___17 * (*mount)(struct file_system_type___16 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___17 *);
	struct module *owner;
	struct file_system_type___16 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___16 {
	struct inode___17 * (*alloc_inode)(struct super_block___17 *);
	void (*destroy_inode)(struct inode___17 *);
	void (*dirty_inode)(struct inode___17 *, int);
	int (*write_inode)(struct inode___17 *, struct writeback_control *);
	int (*drop_inode)(struct inode___17 *);
	void (*evict_inode)(struct inode___17 *);
	void (*put_super)(struct super_block___17 *);
	int (*sync_fs)(struct super_block___17 *, int);
	int (*freeze_fs)(struct super_block___17 *);
	int (*unfreeze_fs)(struct super_block___17 *);
	int (*statfs)(struct dentry___17 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___17 *, int *, char *);
	void (*umount_begin)(struct super_block___17 *);
	int (*show_options)(struct seq_file___14 *, struct dentry___17 *);
	int (*show_devname)(struct seq_file___14 *, struct dentry___17 *);
	int (*show_path)(struct seq_file___14 *, struct dentry___17 *);
	int (*show_stats)(struct seq_file___14 *, struct dentry___17 *);
	ssize_t (*quota_read)(struct super_block___17 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___17 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___17 *);
	int (*bdev_try_to_free_page)(struct super_block___17 *, struct page___16 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___17 *);
	void (*free_cached_objects)(struct super_block___17 *, int);
};

struct xattr_handler___7 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___17 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___17 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___17 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___10)(struct file___16 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct poll_table_struct___10 {
	poll_queue_proc___10 _qproc;
	long unsigned int _key;
};

struct irq_chip___14 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___14 *);
	void (*irq_shutdown)(struct irq_data___14 *);
	void (*irq_enable)(struct irq_data___14 *);
	void (*irq_disable)(struct irq_data___14 *);
	void (*irq_ack)(struct irq_data___14 *);
	void (*irq_mask)(struct irq_data___14 *);
	void (*irq_mask_ack)(struct irq_data___14 *);
	void (*irq_unmask)(struct irq_data___14 *);
	void (*irq_eoi)(struct irq_data___14 *);
	int (*irq_set_affinity)(struct irq_data___14 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___14 *);
	int (*irq_set_type)(struct irq_data___14 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___14 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___14 *);
	void (*irq_bus_sync_unlock)(struct irq_data___14 *);
	void (*irq_cpu_online)(struct irq_data___14 *);
	void (*irq_cpu_offline)(struct irq_data___14 *);
	void (*irq_suspend)(struct irq_data___14 *);
	void (*irq_resume)(struct irq_data___14 *);
	void (*irq_pm_shutdown)(struct irq_data___14 *);
	void (*irq_print_chip)(struct irq_data___14 *, struct seq_file___14 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___14 *, void *);
	long unsigned int flags;
};

struct signal_struct___16 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___17 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___17 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___8 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___8 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___17 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___7 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___7 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___7 {
	struct pmu___7 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___17 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___17 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___7 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct kmem_cache_cpu___13 {
	void **freelist;
	long unsigned int tid;
	struct page___16 *page;
	struct page___16 *partial;
};

struct memcg_cache_params___13 {
	bool is_root_cache;
	union {
		struct kmem_cache___13 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___13 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___7;

struct cgroup___7 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___7 *parent;
	struct dentry___17 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___7 *subsys[11];
	struct cgroupfs_root___7 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___17 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___7 {
	struct super_block___17 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___7 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___7;

struct pmu___7 {
	struct list_head entry;
	struct device___12 *dev;
	const struct attribute_group___11 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___7 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___7 *);
	void (*pmu_disable)(struct pmu___7 *);
	int (*event_init)(struct perf_event___7 *);
	int (*add)(struct perf_event___7 *, int);
	void (*del)(struct perf_event___7 *, int);
	void (*start)(struct perf_event___7 *, int);
	void (*stop)(struct perf_event___7 *, int);
	void (*read)(struct perf_event___7 *);
	void (*start_txn)(struct pmu___7 *);
	int (*commit_txn)(struct pmu___7 *);
	void (*cancel_txn)(struct pmu___7 *);
	int (*event_idx)(struct perf_event___7 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___7 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___7 *);
};

struct perf_cpu_context___7 {
	struct perf_event_context___7 ctx;
	struct perf_event_context___7 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___7 *unique_pmu;
	struct perf_cgroup___7 *cgrp;
};

struct trace_event_functions___7;

struct trace_event___7 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___7 *funcs;
};

struct ftrace_event_class___7;

struct ftrace_event_call___7 {
	struct list_head list;
	struct ftrace_event_class___7 *class;
	char *name;
	struct trace_event___7 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___7 {
	struct cgroup_subsys_state___7 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___7 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___17 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___7)(struct trace_iterator___7 *, int, struct trace_event___7 *);

struct trace_event_functions___7 {
	trace_print_func___7 trace;
	trace_print_func___7 raw;
	trace_print_func___7 hex;
	trace_print_func___7 binary;
};

struct ftrace_event_class___7 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___7 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___7 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___7 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___7 *);
};

struct ftrace_event_file___3 {
	struct list_head list;
	struct ftrace_event_call___7 *event_call;
	struct dentry___17 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct vsyscall_gtod_data___2 {
	seqcount_t seq;
	struct {
		int vclock_mode;
		cycle_t cycle_last;
		cycle_t mask;
		u32 mult;
		u32 shift;
	} clock;
	time_t wall_time_sec;
	u64 wall_time_snsec;
	u64 monotonic_time_snsec;
	time_t monotonic_time_sec;
	struct timezone sys_tz;
	struct timespec wall_time_coarse;
	struct timespec monotonic_time_coarse;
};

struct kprobe_insn_cache___4 {
	struct mutex___17 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct ftrace_raw_emulate_vsyscall {
	struct trace_entry ent;
	int nr;
	char __data[0];
};

struct ftrace_data_offsets_emulate_vsyscall {};

enum {
	EMULATE = 0,
	NATIVE = 1,
	NONE = 2,
};

struct kobj_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject *, struct kobj_attribute *, char *);
	ssize_t (*store)(struct kobject *, struct kobj_attribute *, const char *, size_t);
};

struct page___17;

typedef struct page___17 *pgtable_t___17;

struct address_space___17;

struct kmem_cache___14;

struct page___17 {
	long unsigned int flags;
	struct address_space___17 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___17 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___17 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___14 *slab_cache;
		struct page___17 *first_page;
	};
	long: 64;
};

struct task_struct___18;

struct pv_cpu_ops___17 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___7 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___7 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___18 *);
	void (*end_context_switch)(struct task_struct___18 *);
};

struct mutex___18 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___18 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___15 {
	struct page___17 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___20;

struct signal_struct___17;

struct task_struct___18 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___18 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___20 *mm;
	struct mm_struct___20 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___18 *real_parent;
	struct task_struct___18 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___18 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___8 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___17 = 0,
		VTIME_USER___17 = 1,
		VTIME_SYS___17 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___7 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___17 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___18 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___15 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___20 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___20 *, struct mm_struct___20 *);
	void (*dup_mmap)(struct mm_struct___20 *, struct mm_struct___20 *);
	void (*exit_mmap)(struct mm_struct___20 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___20 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___20 *);
	void (*pgd_free)(struct mm_struct___20 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___20 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___20 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___20 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___20 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___20 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___20 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___20 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___20 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___20 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___18 lock;
	void *vdso;
} mm_context_t___18;

struct xol_area___17;

struct uprobes_state___17 {
	struct xol_area___17 *xol_area;
};

struct vm_area_struct___20;

struct file___17;

struct core_state___17;

struct mm_struct___20 {
	struct vm_area_struct___20 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___20 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___20 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___18 context;
	long unsigned int flags;
	struct core_state___17 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___18 *owner;
	struct file___17 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___17 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct dentry___18;

struct path___17 {
	struct vfsmount *mnt;
	struct dentry___18 *dentry;
};

struct inode___18;

struct file_operations___17;

struct file___17 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___17 f_path;
	struct inode___18 *f_inode;
	const struct file_operations___17 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___8 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___17 *f_mapping;
	struct mutex___18 f_pos_lock;
};

struct vm_area_struct___20 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___20 *vm_next;
	struct vm_area_struct___20 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___20 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___17 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct zone___17;

struct lruvec___17 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___17 *zone;
};

struct pglist_data___17;

struct zone___17 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___17 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___17 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___17 {
	struct zone___17 *zone;
	int zone_idx;
};

struct zonelist___17 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___17 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___17 {
	struct zone___17 node_zones[4];
	struct zonelist___17 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___18 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___15;

struct x86_io_apic_ops___15 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___15 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___15;

struct irq_data___15 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___15 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___17 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___18 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___17 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___17 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___14;

struct memcg_cache_params___14;

struct kmem_cache___14 {
	struct kmem_cache_cpu___14 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___14 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___17;

struct address_space___17 {
	struct inode___18 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___18 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___17 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct core_thread___17 {
	struct task_struct___18 *task;
	struct core_thread___17 *next;
};

struct core_state___17 {
	atomic_t nr_threads;
	struct core_thread___17 dumper;
	struct completion startup;
};

struct signal_struct___17 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___18 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___18 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___8 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___8 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___18 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___14 {
	void **freelist;
	long unsigned int tid;
	struct page___17 *page;
	struct page___17 *partial;
};

struct memcg_cache_params___14 {
	bool is_root_cache;
	union {
		struct kmem_cache___14 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___14 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___17;

struct super_block___18;

struct dentry___18 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___18 *d_parent;
	struct qstr d_name;
	struct inode___18 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___17 *d_op;
	struct super_block___18 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___17;

struct file_lock___17;

struct dquot___17;

struct block_device___17;

struct cdev___6;

struct inode___18 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___17 *i_op;
	struct super_block___18 *i_sb;
	struct address_space___17 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___18 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___17 *i_fop;
	struct file_lock___17 *i_flock;
	struct address_space___17 i_data;
	struct dquot___17 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___17 *i_bdev;
		struct cdev___6 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___17 {
	int (*d_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_hash)(const struct dentry___18 *, struct qstr *);
	int (*d_compare)(const struct dentry___18 *, const struct dentry___18 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___18 *);
	void (*d_release)(struct dentry___18 *);
	void (*d_prune)(struct dentry___18 *);
	void (*d_iput)(struct dentry___18 *, struct inode___18 *);
	char * (*d_dname)(struct dentry___18 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___17 *);
	int (*d_manage)(struct dentry___18 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___17;

struct mem_dqinfo___17 {
	struct quota_format_type___17 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___17;

struct quota_info___17 {
	unsigned int flags;
	struct mutex___18 dqio_mutex;
	struct mutex___18 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___18 *files[2];
	struct mem_dqinfo___17 info[2];
	const struct quota_format_ops___17 *ops[2];
};

struct file_system_type___17;

struct super_operations___17;

struct dquot_operations___17;

struct quotactl_ops___17;

struct super_block___18 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___17 *s_type;
	const struct super_operations___17 *s_op;
	const struct dquot_operations___17 *dq_op;
	const struct quotactl_ops___17 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___18 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___17 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___17 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___18 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___17 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___17 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___18 *bd_inode;
	struct super_block___18 *bd_super;
	struct mutex___18 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___17 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___18 bd_fsfreeze_mutex;
};

struct iattr___18 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___17 *ia_file;
};

struct dquot___17 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___18 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___18 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___17 {
	int qf_fmt_id;
	const struct quota_format_ops___17 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___17 *qf_next;
};

struct quota_format_ops___17 {
	int (*check_quota_file)(struct super_block___18 *, int);
	int (*read_file_info)(struct super_block___18 *, int);
	int (*write_file_info)(struct super_block___18 *, int);
	int (*free_file_info)(struct super_block___18 *, int);
	int (*read_dqblk)(struct dquot___17 *);
	int (*commit_dqblk)(struct dquot___17 *);
	int (*release_dqblk)(struct dquot___17 *);
};

struct dquot_operations___17 {
	int (*write_dquot)(struct dquot___17 *);
	struct dquot___17 * (*alloc_dquot)(struct super_block___18 *, int);
	void (*destroy_dquot)(struct dquot___17 *);
	int (*acquire_dquot)(struct dquot___17 *);
	int (*release_dquot)(struct dquot___17 *);
	int (*mark_dirty)(struct dquot___17 *);
	int (*write_info)(struct super_block___18 *, int);
	qsize_t * (*get_reserved_space)(struct inode___18 *);
};

struct quotactl_ops___17 {
	int (*quota_on)(struct super_block___18 *, int, int, struct path___17 *);
	int (*quota_on_meta)(struct super_block___18 *, int, int);
	int (*quota_off)(struct super_block___18 *, int);
	int (*quota_sync)(struct super_block___18 *, int);
	int (*get_info)(struct super_block___18 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___18 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___18 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___18 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___18 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___18 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___18 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___18 *, unsigned int);
};

struct address_space_operations___17 {
	int (*writepage)(struct page___17 *, struct writeback_control *);
	int (*readpage)(struct file___17 *, struct page___17 *);
	int (*writepages)(struct address_space___17 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___17 *);
	int (*readpages)(struct file___17 *, struct address_space___17 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___17 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___17 **, void **);
	int (*write_end)(struct file___17 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___17 *, void *);
	sector_t (*bmap)(struct address_space___17 *, sector_t);
	void (*invalidatepage)(struct page___17 *, long unsigned int);
	int (*releasepage)(struct page___17 *, gfp_t);
	void (*freepage)(struct page___17 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___17 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___17 *, struct page___17 *, struct page___17 *, enum migrate_mode);
	int (*launder_page)(struct page___17 *);
	int (*is_partially_uptodate)(struct page___17 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___17 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___17 *, struct page___17 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___17 *, sector_t *);
	void (*swap_deactivate)(struct file___17 *);
	void (*invalidatepage_range)(struct page___17 *, unsigned int, unsigned int);
};

struct cdev___6 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___17 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___17 {
	struct dentry___18 * (*lookup)(struct inode___18 *, struct dentry___18 *, unsigned int);
	void * (*follow_link)(struct dentry___18 *, struct nameidata *);
	int (*permission)(struct inode___18 *, int);
	struct posix_acl * (*get_acl)(struct inode___18 *, int);
	int (*readlink)(struct dentry___18 *, char *, int);
	void (*put_link)(struct dentry___18 *, struct nameidata *, void *);
	int (*create)(struct inode___18 *, struct dentry___18 *, umode_t, bool);
	int (*link)(struct dentry___18 *, struct inode___18 *, struct dentry___18 *);
	int (*unlink)(struct inode___18 *, struct dentry___18 *);
	int (*symlink)(struct inode___18 *, struct dentry___18 *, const char *);
	int (*mkdir)(struct inode___18 *, struct dentry___18 *, umode_t);
	int (*rmdir)(struct inode___18 *, struct dentry___18 *);
	int (*mknod)(struct inode___18 *, struct dentry___18 *, umode_t, dev_t);
	int (*rename)(struct inode___18 *, struct dentry___18 *, struct inode___18 *, struct dentry___18 *);
	int (*setattr)(struct dentry___18 *, struct iattr___18 *);
	int (*getattr)(struct vfsmount *, struct dentry___18 *, struct kstat *);
	int (*setxattr)(struct dentry___18 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___18 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___18 *, char *, size_t);
	int (*removexattr)(struct dentry___18 *, const char *);
	int (*fiemap)(struct inode___18 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___18 *, struct timespec *, int);
	int (*atomic_open)(struct inode___18 *, struct dentry___18 *, struct file___17 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___11;

struct seq_file___15;

struct file_operations___17 {
	struct module *owner;
	loff_t (*llseek)(struct file___17 *, loff_t, int);
	ssize_t (*read)(struct file___17 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___17 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___17 *, void *, filldir_t);
	unsigned int (*poll)(struct file___17 *, struct poll_table_struct___11 *);
	long int (*unlocked_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___17 *, struct vm_area_struct___20 *);
	int (*open)(struct inode___18 *, struct file___17 *);
	int (*flush)(struct file___17 *, fl_owner_t);
	int (*release)(struct inode___18 *, struct file___17 *);
	int (*fsync)(struct file___17 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___17 *, int);
	int (*lock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*sendpage)(struct file___17 *, struct page___17 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___17 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___17 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___17 *, long int, struct file_lock___17 **, void **);
		struct {
			int (*setlease)(struct file___17 *, long int, struct file_lock___17 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___17 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___15 *, struct file___17 *);
};

struct fasync_struct___17;

struct file_lock_operations___17;

struct lock_manager_operations___17;

struct file_lock___17 {
	struct file_lock___17 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___8 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___17 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___17 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___17 *fl_ops;
	const struct lock_manager_operations___17 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___17 {
	void (*fl_copy_lock)(struct file_lock___17 *, struct file_lock___17 *);
	void (*fl_release_private)(struct file_lock___17 *);
};

struct lock_manager_operations___17 {
	int (*lm_compare_owner)(struct file_lock___17 *, struct file_lock___17 *);
	long unsigned int (*lm_owner_key)(struct file_lock___17 *);
	void (*lm_notify)(struct file_lock___17 *);
	int (*lm_grant)(struct file_lock___17 *, struct file_lock___17 *, int);
	void (*lm_break)(struct file_lock___17 *);
	int (*lm_change)(struct file_lock___17 **, int);
};

struct fasync_struct___17 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___17 *fa_next;
	struct file___17 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___17 {
	const char *name;
	int fs_flags;
	struct dentry___18 * (*mount)(struct file_system_type___17 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___18 *);
	struct module *owner;
	struct file_system_type___17 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___17 {
	struct inode___18 * (*alloc_inode)(struct super_block___18 *);
	void (*destroy_inode)(struct inode___18 *);
	void (*dirty_inode)(struct inode___18 *, int);
	int (*write_inode)(struct inode___18 *, struct writeback_control *);
	int (*drop_inode)(struct inode___18 *);
	void (*evict_inode)(struct inode___18 *);
	void (*put_super)(struct super_block___18 *);
	int (*sync_fs)(struct super_block___18 *, int);
	int (*freeze_fs)(struct super_block___18 *);
	int (*unfreeze_fs)(struct super_block___18 *);
	int (*statfs)(struct dentry___18 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___18 *, int *, char *);
	void (*umount_begin)(struct super_block___18 *);
	int (*show_options)(struct seq_file___15 *, struct dentry___18 *);
	int (*show_devname)(struct seq_file___15 *, struct dentry___18 *);
	int (*show_path)(struct seq_file___15 *, struct dentry___18 *);
	int (*show_stats)(struct seq_file___15 *, struct dentry___18 *);
	ssize_t (*quota_read)(struct super_block___18 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___18 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___18 *);
	int (*bdev_try_to_free_page)(struct super_block___18 *, struct page___17 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___18 *);
	void (*free_cached_objects)(struct super_block___18 *, int);
};

typedef void (*poll_queue_proc___11)(struct file___17 *, wait_queue_head_t *, struct poll_table_struct___11 *);

struct poll_table_struct___11 {
	poll_queue_proc___11 _qproc;
	long unsigned int _key;
};

struct seq_operations___15;

struct seq_file___15 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___18 lock;
	const struct seq_operations___15 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___15 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___15 *);
	void (*irq_shutdown)(struct irq_data___15 *);
	void (*irq_enable)(struct irq_data___15 *);
	void (*irq_disable)(struct irq_data___15 *);
	void (*irq_ack)(struct irq_data___15 *);
	void (*irq_mask)(struct irq_data___15 *);
	void (*irq_mask_ack)(struct irq_data___15 *);
	void (*irq_unmask)(struct irq_data___15 *);
	void (*irq_eoi)(struct irq_data___15 *);
	int (*irq_set_affinity)(struct irq_data___15 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___15 *);
	int (*irq_set_type)(struct irq_data___15 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___15 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___15 *);
	void (*irq_bus_sync_unlock)(struct irq_data___15 *);
	void (*irq_cpu_online)(struct irq_data___15 *);
	void (*irq_cpu_offline)(struct irq_data___15 *);
	void (*irq_suspend)(struct irq_data___15 *);
	void (*irq_resume)(struct irq_data___15 *);
	void (*irq_pm_shutdown)(struct irq_data___15 *);
	void (*irq_print_chip)(struct irq_data___15 *, struct seq_file___15 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___15 *, void *);
	long unsigned int flags;
};

struct seq_operations___15 {
	void * (*start)(struct seq_file___15 *, loff_t *);
	void (*stop)(struct seq_file___15 *, void *);
	void * (*next)(struct seq_file___15 *, void *, loff_t *);
	int (*show)(struct seq_file___15 *, void *);
};

struct change_member {
	struct e820entry *pbios;
	long long unsigned int addr;
};

struct msi_desc___2 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev *dev;
	struct msi_msg msg;
	struct kobject kobj;
};

struct msi_chip {
	struct module *owner;
	struct device___6 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip *, struct pci_dev *, struct msi_desc___2 *);
	void (*teardown_irq)(struct msi_chip *, unsigned int);
	int (*check_device)(struct msi_chip *, struct pci_dev *, int, int);
};

struct pci_fixup {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev *);
};

enum {
	NONE_FORCE_HPET_RESUME = 0,
	OLD_ICH_FORCE_HPET_RESUME = 1,
	ICH_FORCE_HPET_RESUME = 2,
	VT8237_FORCE_HPET_RESUME = 3,
	NVIDIA_FORCE_HPET_RESUME = 4,
	ATI_FORCE_HPET_RESUME = 5,
};

struct cpu {
	int node_id;
	int hotpluggable;
	struct device___12 dev;
};

struct x86_cpu {
	struct cpu cpu;
};

struct debugfs_blob_wrapper {
	void *data;
	long unsigned int size;
};

struct setup_data_node {
	u64 paddr;
	u32 type;
	u32 len;
};

struct alt_instr {
	s32 instr_offset;
	s32 repl_offset;
	u16 cpuid;
	u8 instrlen;
	u8 replacementlen;
};

struct text_poke_param {
	void *addr;
	const void *opcode;
	size_t len;
};

struct paravirt_patch_site {
	u8 *instr;
	u8 instrtype;
	u8 len;
	u16 clobbers;
};

struct smp_alt_module {
	struct module___2 *mod;
	char *name;
	const s32 *locks;
	const s32 *locks_end;
	u8 *text;
	u8 *text_end;
	struct list_head next;
};

struct text_poke_params {
	struct text_poke_param *params;
	int nparams;
};

struct page___18;

typedef struct page___18 *pgtable_t___18;

struct address_space___18;

struct kmem_cache___15;

struct page___18 {
	long unsigned int flags;
	struct address_space___18 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___18 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___18 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___15 *slab_cache;
		struct page___18 *first_page;
	};
	long: 64;
};

struct thread_struct___8;

struct task_struct___19;

struct pv_cpu_ops___18 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___8 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___8 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___19 *);
	void (*end_context_switch)(struct task_struct___19 *);
};

struct perf_event___8;

struct thread_struct___8 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___8 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___9;

struct pid_link___9 {
	struct hlist_node node;
	struct pid___9 *pid;
};

struct mutex___19 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___19 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___16 {
	struct page___18 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___21;

struct nsproxy___9;

struct signal_struct___18;

struct css_set___8;

struct perf_event_context___8;

struct task_struct___19 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___19 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___21 *mm;
	struct mm_struct___21 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___19 *real_parent;
	struct task_struct___19 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___19 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___9 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___18 = 0,
		VTIME_USER___18 = 1,
		VTIME_SYS___18 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___8 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___9 *nsproxy;
	struct signal_struct___18 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___8 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___8 *perf_event_ctxp[2];
	struct mutex___19 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___16 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___21 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___21 *, struct mm_struct___21 *);
	void (*dup_mmap)(struct mm_struct___21 *, struct mm_struct___21 *);
	void (*exit_mmap)(struct mm_struct___21 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___21 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___21 *);
	void (*pgd_free)(struct mm_struct___21 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___21 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___21 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___21 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___21 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___21 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___21 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___21 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___21 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___21 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___21 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___21 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___19 lock;
	void *vdso;
} mm_context_t___19;

struct xol_area___18;

struct uprobes_state___18 {
	struct xol_area___18 *xol_area;
};

struct vm_area_struct___21;

struct file___18;

struct core_state___18;

struct mm_struct___21 {
	struct vm_area_struct___21 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___21 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___21 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___19 context;
	long unsigned int flags;
	struct core_state___18 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___19 *owner;
	struct file___18 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___18 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___9;

struct exec_domain___6 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___9 *module;
	struct exec_domain___6 *next;
};

struct module_kobject___8 {
	struct kobject kobj;
	struct module___9 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___8;

struct module___9 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___8 mkobj;
	struct module_attribute___8 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___19 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___8 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___19 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___19 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___19 *target;
};

typedef void (*perf_overflow_handler_t___8)(struct perf_event___8 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___8;

typedef void (*ftrace_func_t___8)(long unsigned int, long unsigned int, struct ftrace_ops___8 *, struct pt_regs *);

struct ftrace_ops___8 {
	ftrace_func_t___8 func;
	struct ftrace_ops___8 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___19 regex_lock;
};

struct pmu___8;

struct fasync_struct___18;

struct pid_namespace___9;

struct perf_cgroup___8;

struct perf_event___8 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___8 *group_leader;
	struct pmu___8 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___8 hw;
	struct perf_event_context___8 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___19 child_mutex;
	struct list_head child_list;
	struct perf_event___8 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___19 *owner;
	struct mutex___19 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___18 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___8 *);
	struct callback_head callback_head;
	struct pid_namespace___9 *ns;
	u64 id;
	perf_overflow_handler_t___8 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___8 ftrace_ops;
	struct perf_cgroup___8 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___10 {
	struct task_struct___19 *task;
	struct exec_domain___6 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___18 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___18 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___15;

struct memcg_cache_params___15;

struct kmem_cache___15 {
	struct kmem_cache_cpu___15 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___15 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___19;

struct address_space_operations___18;

struct address_space___18 {
	struct inode___19 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___19 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___18 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___19;

struct path___18 {
	struct vfsmount *mnt;
	struct dentry___19 *dentry;
};

struct fown_struct___9 {
	rwlock_t lock;
	struct pid___9 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___18;

struct file___18 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___18 f_path;
	struct inode___19 *f_inode;
	const struct file_operations___18 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___9 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___18 *f_mapping;
	struct mutex___19 f_pos_lock;
};

struct vm_operations_struct___16;

struct vm_area_struct___21 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___21 *vm_next;
	struct vm_area_struct___21 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___21 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___16 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___18 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___14;

struct vm_operations_struct___16 {
	void (*open)(struct vm_area_struct___21 *);
	void (*close)(struct vm_area_struct___21 *);
	int (*fault)(struct vm_area_struct___21 *, struct vm_fault___14 *);
	int (*page_mkwrite)(struct vm_area_struct___21 *, struct vm_fault___14 *);
	int (*access)(struct vm_area_struct___21 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___21 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___21 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___21 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___21 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___18 {
	struct task_struct___19 *task;
	struct core_thread___18 *next;
};

struct core_state___18 {
	atomic_t nr_threads;
	struct core_thread___18 dumper;
	struct completion startup;
};

struct device___13;

struct dev_pm_ops___13 {
	int (*prepare)(struct device___13 *);
	void (*complete)(struct device___13 *);
	int (*suspend)(struct device___13 *);
	int (*resume)(struct device___13 *);
	int (*freeze)(struct device___13 *);
	int (*thaw)(struct device___13 *);
	int (*poweroff)(struct device___13 *);
	int (*restore)(struct device___13 *);
	int (*suspend_late)(struct device___13 *);
	int (*resume_early)(struct device___13 *);
	int (*freeze_late)(struct device___13 *);
	int (*thaw_early)(struct device___13 *);
	int (*poweroff_late)(struct device___13 *);
	int (*restore_early)(struct device___13 *);
	int (*suspend_noirq)(struct device___13 *);
	int (*resume_noirq)(struct device___13 *);
	int (*freeze_noirq)(struct device___13 *);
	int (*thaw_noirq)(struct device___13 *);
	int (*poweroff_noirq)(struct device___13 *);
	int (*restore_noirq)(struct device___13 *);
	int (*runtime_suspend)(struct device___13 *);
	int (*runtime_resume)(struct device___13 *);
	int (*runtime_idle)(struct device___13 *);
};

struct device_type___13;

struct bus_type___13;

struct device_driver___13;

struct dev_pm_domain___13;

struct class___13;

struct attribute_group___12;

struct device_rh___13;

struct device___13 {
	struct device___13 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___13 *type;
	struct mutex___19 mutex;
	struct bus_type___13 *bus;
	struct device_driver___13 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___13 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___6 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___6 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___13 *class;
	const struct attribute_group___12 **groups;
	void (*release)(struct device___13 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___13 *device_rh;
};

struct dev_pm_info_rh___13 {
	void (*set_latency_tolerance)(struct device___13 *, s32);
};

struct dev_pm_domain___13 {
	struct dev_pm_ops___13 ops;
};

struct smp_ops___18 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___19 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___9 {
	int nr;
	struct pid_namespace___9 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___9 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___19 *child_reaper;
	struct kmem_cache___15 *pid_cachep;
	unsigned int level;
	struct pid_namespace___9 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___19 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___9 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___9 numbers[1];
};

struct zone___18;

struct lruvec___18 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___18 *zone;
};

struct pglist_data___18;

struct zone___18 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___18 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___18 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___18 {
	struct zone___18 *zone;
	int zone_idx;
};

struct zonelist___18 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___18 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___18 {
	struct zone___18 node_zones[4];
	struct zonelist___18 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___19 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___9 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___9 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___18 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___19 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___19 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___9 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___9 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___19 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___8;

struct css_set___8 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___8 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___8 {
	struct pmu___8 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___19 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___19 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___8 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct die_args {
	struct pt_regs *regs;
	const char *str;
	long int err;
	int trapnr;
	int signr;
};

struct dentry_operations___18;

struct super_block___19;

struct dentry___19 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___19 *d_parent;
	struct qstr d_name;
	struct inode___19 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___18 *d_op;
	struct super_block___19 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___18;

struct file_lock___18;

struct dquot___18;

struct block_device___18;

struct inode___19 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___18 *i_op;
	struct super_block___19 *i_sb;
	struct address_space___18 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___19 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___18 *i_fop;
	struct file_lock___18 *i_flock;
	struct address_space___18 i_data;
	struct dquot___18 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___18 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___18 {
	int (*d_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_hash)(const struct dentry___19 *, struct qstr *);
	int (*d_compare)(const struct dentry___19 *, const struct dentry___19 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___19 *);
	void (*d_release)(struct dentry___19 *);
	void (*d_prune)(struct dentry___19 *);
	void (*d_iput)(struct dentry___19 *, struct inode___19 *);
	char * (*d_dname)(struct dentry___19 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___18 *);
	int (*d_manage)(struct dentry___19 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___18;

struct mem_dqinfo___18 {
	struct quota_format_type___18 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___18;

struct quota_info___18 {
	unsigned int flags;
	struct mutex___19 dqio_mutex;
	struct mutex___19 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___19 *files[2];
	struct mem_dqinfo___18 info[2];
	const struct quota_format_ops___18 *ops[2];
};

struct file_system_type___18;

struct super_operations___18;

struct dquot_operations___18;

struct quotactl_ops___18;

struct xattr_handler___8;

struct super_block___19 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___18 *s_type;
	const struct super_operations___18 *s_op;
	const struct dquot_operations___18 *dq_op;
	const struct quotactl_ops___18 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___19 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___8 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___18 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___18 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___19 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___18 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___18 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___19 *bd_inode;
	struct super_block___19 *bd_super;
	struct mutex___19 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___18 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___19 bd_fsfreeze_mutex;
};

struct cgroup___8;

struct cgroup_subsys_state___8 {
	struct cgroup___8 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___19 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___18 *ia_file;
};

struct dquot___18 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___19 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___19 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___18 {
	int qf_fmt_id;
	const struct quota_format_ops___18 *qf_ops;
	struct module___9 *qf_owner;
	struct quota_format_type___18 *qf_next;
};

struct quota_format_ops___18 {
	int (*check_quota_file)(struct super_block___19 *, int);
	int (*read_file_info)(struct super_block___19 *, int);
	int (*write_file_info)(struct super_block___19 *, int);
	int (*free_file_info)(struct super_block___19 *, int);
	int (*read_dqblk)(struct dquot___18 *);
	int (*commit_dqblk)(struct dquot___18 *);
	int (*release_dqblk)(struct dquot___18 *);
};

struct dquot_operations___18 {
	int (*write_dquot)(struct dquot___18 *);
	struct dquot___18 * (*alloc_dquot)(struct super_block___19 *, int);
	void (*destroy_dquot)(struct dquot___18 *);
	int (*acquire_dquot)(struct dquot___18 *);
	int (*release_dquot)(struct dquot___18 *);
	int (*mark_dirty)(struct dquot___18 *);
	int (*write_info)(struct super_block___19 *, int);
	qsize_t * (*get_reserved_space)(struct inode___19 *);
};

struct quotactl_ops___18 {
	int (*quota_on)(struct super_block___19 *, int, int, struct path___18 *);
	int (*quota_on_meta)(struct super_block___19 *, int, int);
	int (*quota_off)(struct super_block___19 *, int);
	int (*quota_sync)(struct super_block___19 *, int);
	int (*get_info)(struct super_block___19 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___19 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___19 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___19 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___19 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___19 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___19 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___19 *, unsigned int);
};

struct address_space_operations___18 {
	int (*writepage)(struct page___18 *, struct writeback_control *);
	int (*readpage)(struct file___18 *, struct page___18 *);
	int (*writepages)(struct address_space___18 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___18 *);
	int (*readpages)(struct file___18 *, struct address_space___18 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___18 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___18 **, void **);
	int (*write_end)(struct file___18 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___18 *, void *);
	sector_t (*bmap)(struct address_space___18 *, sector_t);
	void (*invalidatepage)(struct page___18 *, long unsigned int);
	int (*releasepage)(struct page___18 *, gfp_t);
	void (*freepage)(struct page___18 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___18 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___18 *, struct page___18 *, struct page___18 *, enum migrate_mode);
	int (*launder_page)(struct page___18 *);
	int (*is_partially_uptodate)(struct page___18 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___18 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___18 *, struct page___18 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___18 *, sector_t *);
	void (*swap_deactivate)(struct file___18 *);
	void (*invalidatepage_range)(struct page___18 *, unsigned int, unsigned int);
};

struct inode_operations___18 {
	struct dentry___19 * (*lookup)(struct inode___19 *, struct dentry___19 *, unsigned int);
	void * (*follow_link)(struct dentry___19 *, struct nameidata *);
	int (*permission)(struct inode___19 *, int);
	struct posix_acl * (*get_acl)(struct inode___19 *, int);
	int (*readlink)(struct dentry___19 *, char *, int);
	void (*put_link)(struct dentry___19 *, struct nameidata *, void *);
	int (*create)(struct inode___19 *, struct dentry___19 *, umode_t, bool);
	int (*link)(struct dentry___19 *, struct inode___19 *, struct dentry___19 *);
	int (*unlink)(struct inode___19 *, struct dentry___19 *);
	int (*symlink)(struct inode___19 *, struct dentry___19 *, const char *);
	int (*mkdir)(struct inode___19 *, struct dentry___19 *, umode_t);
	int (*rmdir)(struct inode___19 *, struct dentry___19 *);
	int (*mknod)(struct inode___19 *, struct dentry___19 *, umode_t, dev_t);
	int (*rename)(struct inode___19 *, struct dentry___19 *, struct inode___19 *, struct dentry___19 *);
	int (*setattr)(struct dentry___19 *, struct iattr___19 *);
	int (*getattr)(struct vfsmount *, struct dentry___19 *, struct kstat *);
	int (*setxattr)(struct dentry___19 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___19 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___19 *, char *, size_t);
	int (*removexattr)(struct dentry___19 *, const char *);
	int (*fiemap)(struct inode___19 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___19 *, struct timespec *, int);
	int (*atomic_open)(struct inode___19 *, struct dentry___19 *, struct file___18 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___18 {
	struct module___9 *owner;
	loff_t (*llseek)(struct file___18 *, loff_t, int);
	ssize_t (*read)(struct file___18 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___18 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___18 *, void *, filldir_t);
	unsigned int (*poll)(struct file___18 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___18 *, struct vm_area_struct___21 *);
	int (*open)(struct inode___19 *, struct file___18 *);
	int (*flush)(struct file___18 *, fl_owner_t);
	int (*release)(struct inode___19 *, struct file___18 *);
	int (*fsync)(struct file___18 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___18 *, int);
	int (*lock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*sendpage)(struct file___18 *, struct page___18 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___18 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___18 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___18 *, long int, struct file_lock___18 **, void **);
		struct {
			int (*setlease)(struct file___18 *, long int, struct file_lock___18 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___18 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___18 *);
};

struct file_lock_operations___18;

struct lock_manager_operations___18;

struct file_lock___18 {
	struct file_lock___18 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___9 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___18 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___18 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___18 *fl_ops;
	const struct lock_manager_operations___18 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___18 {
	void (*fl_copy_lock)(struct file_lock___18 *, struct file_lock___18 *);
	void (*fl_release_private)(struct file_lock___18 *);
};

struct lock_manager_operations___18 {
	int (*lm_compare_owner)(struct file_lock___18 *, struct file_lock___18 *);
	long unsigned int (*lm_owner_key)(struct file_lock___18 *);
	void (*lm_notify)(struct file_lock___18 *);
	int (*lm_grant)(struct file_lock___18 *, struct file_lock___18 *, int);
	void (*lm_break)(struct file_lock___18 *);
	int (*lm_change)(struct file_lock___18 **, int);
};

struct fasync_struct___18 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___18 *fa_next;
	struct file___18 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___18 {
	const char *name;
	int fs_flags;
	struct dentry___19 * (*mount)(struct file_system_type___18 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___19 *);
	struct module___9 *owner;
	struct file_system_type___18 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___18 {
	struct inode___19 * (*alloc_inode)(struct super_block___19 *);
	void (*destroy_inode)(struct inode___19 *);
	void (*dirty_inode)(struct inode___19 *, int);
	int (*write_inode)(struct inode___19 *, struct writeback_control *);
	int (*drop_inode)(struct inode___19 *);
	void (*evict_inode)(struct inode___19 *);
	void (*put_super)(struct super_block___19 *);
	int (*sync_fs)(struct super_block___19 *, int);
	int (*freeze_fs)(struct super_block___19 *);
	int (*unfreeze_fs)(struct super_block___19 *);
	int (*statfs)(struct dentry___19 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___19 *, int *, char *);
	void (*umount_begin)(struct super_block___19 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___19 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___19 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___19 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___19 *);
	ssize_t (*quota_read)(struct super_block___19 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___19 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___19 *);
	int (*bdev_try_to_free_page)(struct super_block___19 *, struct page___18 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___19 *);
	void (*free_cached_objects)(struct super_block___19 *, int);
};

struct xattr_handler___8 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___19 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___19 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___19 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___14 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___18 *page;
};

struct bin_attribute___12;

struct attribute_group___12 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___12 **bin_attrs;
};

struct bin_attribute___12 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___18 *, struct kobject *, struct bin_attribute___12 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___18 *, struct kobject *, struct bin_attribute___12 *, char *, loff_t, size_t);
	int (*mmap)(struct file___18 *, struct kobject *, struct bin_attribute___12 *, struct vm_area_struct___21 *);
};

struct bus_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___13 *, char *);
	ssize_t (*store)(struct bus_type___13 *, const char *, size_t);
};

struct device_attribute___13;

struct driver_attribute___13;

struct bus_type___13 {
	const char *name;
	const char *dev_name;
	struct device___13 *dev_root;
	struct bus_attribute___13 *bus_attrs;
	struct device_attribute___13 *dev_attrs;
	struct driver_attribute___13 *drv_attrs;
	const struct attribute_group___12 **bus_groups;
	const struct attribute_group___12 **dev_groups;
	const struct attribute_group___12 **drv_groups;
	int (*match)(struct device___13 *, struct device_driver___13 *);
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	int (*probe)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*online)(struct device___13 *);
	int (*offline)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct dev_pm_ops___13 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct device___13 *, struct device_attribute___13 *, char *);
	ssize_t (*store)(struct device___13 *, struct device_attribute___13 *, const char *, size_t);
};

struct driver_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___13 *, char *);
	ssize_t (*store)(struct device_driver___13 *, const char *, size_t);
};

struct device_driver___13 {
	const char *name;
	struct bus_type___13 *bus;
	struct module___9 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct attribute_group___12 **groups;
	const struct dev_pm_ops___13 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___13 {
	const char *name;
	const struct attribute_group___12 **groups;
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___13 *);
	const struct dev_pm_ops___13 *pm;
};

struct class_attribute___13;

struct class___13 {
	const char *name;
	struct module___9 *owner;
	struct class_attribute___13 *class_attrs;
	struct device_attribute___13 *dev_attrs;
	const struct attribute_group___12 **dev_groups;
	struct bin_attribute___12 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *);
	void (*class_release)(struct class___13 *);
	void (*dev_release)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___13 *);
	const struct dev_pm_ops___13 *pm;
	struct subsys_private *p;
};

struct class_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct class___13 *, struct class_attribute___13 *, char *);
	ssize_t (*store)(struct class___13 *, struct class_attribute___13 *, const char *, size_t);
	const void * (*namespace)(struct class___13 *, const struct class_attribute___13 *);
};

struct device_rh___13 {
	struct dev_pm_info_rh___13 power;
};

struct kmem_cache_cpu___15 {
	void **freelist;
	long unsigned int tid;
	struct page___18 *page;
	struct page___18 *partial;
};

struct memcg_cache_params___15 {
	bool is_root_cache;
	union {
		struct kmem_cache___15 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___15 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___8;

struct cgroup___8 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___8 *parent;
	struct dentry___19 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___8 *subsys[11];
	struct cgroupfs_root___8 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___19 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___8 {
	struct super_block___19 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___8 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___8;

struct pmu___8 {
	struct list_head entry;
	struct device___13 *dev;
	const struct attribute_group___12 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___8 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___8 *);
	void (*pmu_disable)(struct pmu___8 *);
	int (*event_init)(struct perf_event___8 *);
	int (*add)(struct perf_event___8 *, int);
	void (*del)(struct perf_event___8 *, int);
	void (*start)(struct perf_event___8 *, int);
	void (*stop)(struct perf_event___8 *, int);
	void (*read)(struct perf_event___8 *);
	void (*start_txn)(struct pmu___8 *);
	int (*commit_txn)(struct pmu___8 *);
	void (*cancel_txn)(struct pmu___8 *);
	int (*event_idx)(struct perf_event___8 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___9 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___8 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___8 *);
};

struct perf_cpu_context___8 {
	struct perf_event_context___8 ctx;
	struct perf_event_context___8 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___8 *unique_pmu;
	struct perf_cgroup___8 *cgrp;
};

struct perf_cgroup___8 {
	struct cgroup_subsys_state___8 css;
	struct perf_cgroup_info *info;
};

enum {
	HW_BREAKPOINT_LEN_1 = 1,
	HW_BREAKPOINT_LEN_2 = 2,
	HW_BREAKPOINT_LEN_4 = 4,
	HW_BREAKPOINT_LEN_8 = 8,
};

enum {
	HW_BREAKPOINT_EMPTY = 0,
	HW_BREAKPOINT_R = 1,
	HW_BREAKPOINT_W = 2,
	HW_BREAKPOINT_RW = 3,
	HW_BREAKPOINT_X = 4,
	HW_BREAKPOINT_INVALID = 7,
};

struct kprobe_insn_cache___5 {
	struct mutex___19 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct user_i387_struct {
	short unsigned int cwd;
	short unsigned int swd;
	short unsigned int twd;
	short unsigned int fop;
	__u64 rip;
	__u64 rdp;
	__u32 mxcsr;
	__u32 mxcsr_mask;
	__u32 st_space[32];
	__u32 xmm_space[64];
	__u32 padding[24];
};

struct user_regs_struct {
	long unsigned int r15;
	long unsigned int r14;
	long unsigned int r13;
	long unsigned int r12;
	long unsigned int bp;
	long unsigned int bx;
	long unsigned int r11;
	long unsigned int r10;
	long unsigned int r9;
	long unsigned int r8;
	long unsigned int ax;
	long unsigned int cx;
	long unsigned int dx;
	long unsigned int si;
	long unsigned int di;
	long unsigned int orig_ax;
	long unsigned int ip;
	long unsigned int cs;
	long unsigned int flags;
	long unsigned int sp;
	long unsigned int ss;
	long unsigned int fs_base;
	long unsigned int gs_base;
	long unsigned int ds;
	long unsigned int es;
	long unsigned int fs;
	long unsigned int gs;
};

struct user {
	struct user_regs_struct regs;
	int u_fpvalid;
	int pad0;
	struct user_i387_struct i387;
	long unsigned int u_tsize;
	long unsigned int u_dsize;
	long unsigned int u_ssize;
	long unsigned int start_code;
	long unsigned int start_stack;
	long int signal;
	int reserved;
	int pad1;
	long unsigned int u_ar0;
	struct user_i387_struct *u_fpstate;
	long unsigned int magic;
	char u_comm[32];
	long unsigned int u_debugreg[8];
	long unsigned int error_code;
	long unsigned int fault_address;
};

struct module_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___8 *, struct module_kobject___8 *, char *);
	ssize_t (*store)(struct module_attribute___8 *, struct module_kobject___8 *, const char *, size_t);
	void (*setup)(struct module___9 *, const char *);
	int (*test)(struct module___9 *);
	void (*free)(struct module___9 *);
};

typedef unsigned int u_int;

typedef long long unsigned int cycles_t;

enum {
	WORK_STRUCT_PENDING_BIT = 0,
	WORK_STRUCT_DELAYED_BIT = 1,
	WORK_STRUCT_PWQ_BIT = 2,
	WORK_STRUCT_LINKED_BIT = 3,
	WORK_STRUCT_COLOR_SHIFT = 4,
	WORK_STRUCT_COLOR_BITS = 4,
	WORK_STRUCT_PENDING = 1,
	WORK_STRUCT_DELAYED = 2,
	WORK_STRUCT_PWQ = 4,
	WORK_STRUCT_LINKED = 8,
	WORK_STRUCT_STATIC = 0,
	WORK_NR_COLORS = 15,
	WORK_NO_COLOR = 15,
	WORK_CPU_UNBOUND = 5120,
	WORK_CPU_END = 5121,
	WORK_STRUCT_FLAG_BITS = 8,
	WORK_OFFQ_FLAG_BASE = 4,
	WORK_OFFQ_CANCELING = 16,
	WORK_OFFQ_FLAG_BITS = 1,
	WORK_OFFQ_POOL_SHIFT = 5,
	WORK_OFFQ_LEFT = 59,
	WORK_OFFQ_POOL_BITS = 31,
	WORK_OFFQ_POOL_NONE = 2147483647,
	WORK_STRUCT_FLAG_MASK = 255,
	WORK_STRUCT_WQ_DATA_MASK = 4294967040,
	WORK_STRUCT_NO_POOL = 4294967264,
	WORK_BUSY_PENDING = 1,
	WORK_BUSY_RUNNING = 2,
	WORKER_DESC_LEN = 24,
};

struct cpufreq_freqs {
	unsigned int cpu;
	unsigned int old;
	unsigned int new;
	u8 flags;
};

enum dmi_field {
	DMI_NONE = 0,
	DMI_BIOS_VENDOR = 1,
	DMI_BIOS_VERSION = 2,
	DMI_BIOS_DATE = 3,
	DMI_SYS_VENDOR = 4,
	DMI_PRODUCT_NAME = 5,
	DMI_PRODUCT_VERSION = 6,
	DMI_PRODUCT_SERIAL = 7,
	DMI_PRODUCT_UUID = 8,
	DMI_BOARD_VENDOR = 9,
	DMI_BOARD_NAME = 10,
	DMI_BOARD_VERSION = 11,
	DMI_BOARD_SERIAL = 12,
	DMI_BOARD_ASSET_TAG = 13,
	DMI_CHASSIS_VENDOR = 14,
	DMI_CHASSIS_TYPE = 15,
	DMI_CHASSIS_VERSION = 16,
	DMI_CHASSIS_SERIAL = 17,
	DMI_CHASSIS_ASSET_TAG = 18,
	DMI_STRING_MAX = 19,
};

struct dmi_strmatch {
	unsigned char slot: 7;
	unsigned char exact_match: 1;
	char substr[79];
};

struct dmi_system_id {
	int (*callback)(const struct dmi_system_id *);
	const char *ident;
	struct dmi_strmatch matches[4];
	void *driver_data;
};

struct page___19;

typedef struct page___19 *pgtable_t___19;

struct address_space___19;

struct kmem_cache___16;

struct page___19 {
	long unsigned int flags;
	struct address_space___19 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___19 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___19 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___16 *slab_cache;
		struct page___19 *first_page;
	};
	long: 64;
};

struct task_struct___20;

struct pv_cpu_ops___19 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___8 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___8 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___20 *);
	void (*end_context_switch)(struct task_struct___20 *);
};

struct mutex___20 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___20 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___17 {
	struct page___19 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___22;

struct signal_struct___19;

struct task_struct___20 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___20 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___22 *mm;
	struct mm_struct___22 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___20 *real_parent;
	struct task_struct___20 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___20 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___9 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___19 = 0,
		VTIME_USER___19 = 1,
		VTIME_SYS___19 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___8 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___19 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___20 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___17 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___22 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___22 *, struct mm_struct___22 *);
	void (*dup_mmap)(struct mm_struct___22 *, struct mm_struct___22 *);
	void (*exit_mmap)(struct mm_struct___22 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___22 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___22 *);
	void (*pgd_free)(struct mm_struct___22 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___22 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___22 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___22 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___22 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___22 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___22 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___22 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___22 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___22 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___22 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___22 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___20 lock;
	void *vdso;
} mm_context_t___20;

struct xol_area___19;

struct uprobes_state___19 {
	struct xol_area___19 *xol_area;
};

struct vm_area_struct___22;

struct file___19;

struct core_state___19;

struct mm_struct___22 {
	struct vm_area_struct___22 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___22 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___22 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___20 context;
	long unsigned int flags;
	struct core_state___19 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___20 *owner;
	struct file___19 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___19 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct bin_attribute___13;

struct attribute_group___13 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___13 **bin_attrs;
};

struct bin_attribute___13 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___19 *, struct kobject *, struct bin_attribute___13 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___19 *, struct kobject *, struct bin_attribute___13 *, char *, loff_t, size_t);
	int (*mmap)(struct file___19 *, struct kobject *, struct bin_attribute___13 *, struct vm_area_struct___22 *);
};

struct dentry___20;

struct path___19 {
	struct vfsmount *mnt;
	struct dentry___20 *dentry;
};

struct inode___20;

struct file_operations___19;

struct file___19 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___19 f_path;
	struct inode___20 *f_inode;
	const struct file_operations___19 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___9 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___19 *f_mapping;
	struct mutex___20 f_pos_lock;
};

struct vm_area_struct___22 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___22 *vm_next;
	struct vm_area_struct___22 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___22 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___19 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___14;

struct dev_pm_ops___14 {
	int (*prepare)(struct device___14 *);
	void (*complete)(struct device___14 *);
	int (*suspend)(struct device___14 *);
	int (*resume)(struct device___14 *);
	int (*freeze)(struct device___14 *);
	int (*thaw)(struct device___14 *);
	int (*poweroff)(struct device___14 *);
	int (*restore)(struct device___14 *);
	int (*suspend_late)(struct device___14 *);
	int (*resume_early)(struct device___14 *);
	int (*freeze_late)(struct device___14 *);
	int (*thaw_early)(struct device___14 *);
	int (*poweroff_late)(struct device___14 *);
	int (*restore_early)(struct device___14 *);
	int (*suspend_noirq)(struct device___14 *);
	int (*resume_noirq)(struct device___14 *);
	int (*freeze_noirq)(struct device___14 *);
	int (*thaw_noirq)(struct device___14 *);
	int (*poweroff_noirq)(struct device___14 *);
	int (*restore_noirq)(struct device___14 *);
	int (*runtime_suspend)(struct device___14 *);
	int (*runtime_resume)(struct device___14 *);
	int (*runtime_idle)(struct device___14 *);
};

struct acpi_device___5;

struct acpi_dev_node___7 {
	union {
		struct acpi_device___5 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___14;

struct bus_type___14;

struct device_driver___14;

struct dev_pm_domain___14;

struct device_node___4;

struct class___14;

struct device_rh___14;

struct device___14 {
	struct device___14 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___14 *type;
	struct mutex___20 mutex;
	struct bus_type___14 *bus;
	struct device_driver___14 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___14 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___6 archdata;
	struct device_node___4 *of_node;
	struct acpi_dev_node___7 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___14 *class;
	const struct attribute_group___13 **groups;
	void (*release)(struct device___14 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___14 *device_rh;
};

struct dev_pm_info_rh___14 {
	void (*set_latency_tolerance)(struct device___14 *, s32);
};

struct dev_pm_domain___14 {
	struct dev_pm_ops___14 ops;
};

struct zone___19;

struct lruvec___19 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___19 *zone;
};

struct pglist_data___19;

struct zone___19 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___19 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___19 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___19 {
	struct zone___19 *zone;
	int zone_idx;
};

struct zonelist___19 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___19 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___19 {
	struct zone___19 node_zones[4];
	struct zonelist___19 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___20 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___16;

struct x86_io_apic_ops___16 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___16 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___16;

struct irq_data___16 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___16 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct property___4;

struct device_node___4 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___4 *properties;
	struct property___4 *deadprops;
	struct device_node___4 *parent;
	struct device_node___4 *child;
	struct device_node___4 *sibling;
	struct device_node___4 *next;
	struct device_node___4 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct smp_ops___19 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___20 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pdev_archdata {};

struct bus_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___14 *, char *);
	ssize_t (*store)(struct bus_type___14 *, const char *, size_t);
};

struct device_attribute___14;

struct driver_attribute___14;

struct bus_type___14 {
	const char *name;
	const char *dev_name;
	struct device___14 *dev_root;
	struct bus_attribute___14 *bus_attrs;
	struct device_attribute___14 *dev_attrs;
	struct driver_attribute___14 *drv_attrs;
	const struct attribute_group___13 **bus_groups;
	const struct attribute_group___13 **dev_groups;
	const struct attribute_group___13 **drv_groups;
	int (*match)(struct device___14 *, struct device_driver___14 *);
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	int (*probe)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*online)(struct device___14 *);
	int (*offline)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct dev_pm_ops___14 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct device___14 *, struct device_attribute___14 *, char *);
	ssize_t (*store)(struct device___14 *, struct device_attribute___14 *, const char *, size_t);
};

struct driver_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___14 *, char *);
	ssize_t (*store)(struct device_driver___14 *, const char *, size_t);
};

struct device_driver___14 {
	const char *name;
	struct bus_type___14 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct attribute_group___13 **groups;
	const struct dev_pm_ops___14 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___14 {
	const char *name;
	const struct attribute_group___13 **groups;
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___14 *);
	const struct dev_pm_ops___14 *pm;
};

struct class_attribute___14;

struct class___14 {
	const char *name;
	struct module *owner;
	struct class_attribute___14 *class_attrs;
	struct device_attribute___14 *dev_attrs;
	const struct attribute_group___13 **dev_groups;
	struct bin_attribute___13 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *);
	void (*class_release)(struct class___14 *);
	void (*dev_release)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___14 *);
	const struct dev_pm_ops___14 *pm;
	struct subsys_private *p;
};

struct class_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct class___14 *, struct class_attribute___14 *, char *);
	ssize_t (*store)(struct class___14 *, struct class_attribute___14 *, const char *, size_t);
	const void * (*namespace)(struct class___14 *, const struct class_attribute___14 *);
};

struct acpi_scan_handler___5;

struct acpi_hotplug_context___5;

struct acpi_driver___5;

struct acpi_device___5 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___5 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___5 *handler;
	struct acpi_hotplug_context___5 *hp;
	struct acpi_driver___5 *driver;
	void *driver_data;
	struct device___14 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___20 physical_node_lock;
	void (*remove)(struct acpi_device___5 *);
};

struct device_rh___14 {
	struct dev_pm_info_rh___14 power;
};

struct pnp_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
};

struct pnp_card_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
	struct {
		__u8 id[8];
	} devs[8];
};

struct platform_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

struct mfd_cell;

struct platform_device {
	const char *name;
	int id;
	bool id_auto;
	struct device___14 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct seq_file___16;

struct irq_chip___16 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___16 *);
	void (*irq_shutdown)(struct irq_data___16 *);
	void (*irq_enable)(struct irq_data___16 *);
	void (*irq_disable)(struct irq_data___16 *);
	void (*irq_ack)(struct irq_data___16 *);
	void (*irq_mask)(struct irq_data___16 *);
	void (*irq_mask_ack)(struct irq_data___16 *);
	void (*irq_unmask)(struct irq_data___16 *);
	void (*irq_eoi)(struct irq_data___16 *);
	int (*irq_set_affinity)(struct irq_data___16 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___16 *);
	int (*irq_set_type)(struct irq_data___16 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___16 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___16 *);
	void (*irq_bus_sync_unlock)(struct irq_data___16 *);
	void (*irq_cpu_online)(struct irq_data___16 *);
	void (*irq_cpu_offline)(struct irq_data___16 *);
	void (*irq_suspend)(struct irq_data___16 *);
	void (*irq_resume)(struct irq_data___16 *);
	void (*irq_pm_shutdown)(struct irq_data___16 *);
	void (*irq_print_chip)(struct irq_data___16 *, struct seq_file___16 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___16 *, void *);
	long unsigned int flags;
};

struct seq_operations___16;

struct seq_file___16 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___20 lock;
	const struct seq_operations___16 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct rtc_time {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
	int tm_wday;
	int tm_yday;
	int tm_isdst;
};

struct seq_operations___16 {
	void * (*start)(struct seq_file___16 *, loff_t *);
	void (*stop)(struct seq_file___16 *, void *);
	void * (*next)(struct seq_file___16 *, void *, loff_t *);
	int (*show)(struct seq_file___16 *, void *);
};

struct cdev___7 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___19 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___12;

struct file_lock___19;

struct file_operations___19 {
	struct module *owner;
	loff_t (*llseek)(struct file___19 *, loff_t, int);
	ssize_t (*read)(struct file___19 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___19 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___19 *, void *, filldir_t);
	unsigned int (*poll)(struct file___19 *, struct poll_table_struct___12 *);
	long int (*unlocked_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___19 *, struct vm_area_struct___22 *);
	int (*open)(struct inode___20 *, struct file___19 *);
	int (*flush)(struct file___19 *, fl_owner_t);
	int (*release)(struct inode___20 *, struct file___19 *);
	int (*fsync)(struct file___19 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___19 *, int);
	int (*lock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*sendpage)(struct file___19 *, struct page___19 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___19 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___19 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___19 *, long int, struct file_lock___19 **, void **);
		struct {
			int (*setlease)(struct file___19 *, long int, struct file_lock___19 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___19 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___16 *, struct file___19 *);
};

struct dentry_operations___19;

struct super_block___20;

struct dentry___20 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___20 *d_parent;
	struct qstr d_name;
	struct inode___20 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___19 *d_op;
	struct super_block___20 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___19;

struct address_space___19 {
	struct inode___20 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___20 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___19 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___19;

struct dquot___19;

struct block_device___19;

struct inode___20 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___19 *i_op;
	struct super_block___20 *i_sb;
	struct address_space___19 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___20 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___19 *i_fop;
	struct file_lock___19 *i_flock;
	struct address_space___19 i_data;
	struct dquot___19 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___19 *i_bdev;
		struct cdev___7 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___19 {
	int (*d_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_hash)(const struct dentry___20 *, struct qstr *);
	int (*d_compare)(const struct dentry___20 *, const struct dentry___20 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___20 *);
	void (*d_release)(struct dentry___20 *);
	void (*d_prune)(struct dentry___20 *);
	void (*d_iput)(struct dentry___20 *, struct inode___20 *);
	char * (*d_dname)(struct dentry___20 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___19 *);
	int (*d_manage)(struct dentry___20 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___19;

struct mem_dqinfo___19 {
	struct quota_format_type___19 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___19;

struct quota_info___19 {
	unsigned int flags;
	struct mutex___20 dqio_mutex;
	struct mutex___20 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___20 *files[2];
	struct mem_dqinfo___19 info[2];
	const struct quota_format_ops___19 *ops[2];
};

struct file_system_type___19;

struct super_operations___19;

struct dquot_operations___19;

struct quotactl_ops___19;

struct super_block___20 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___19 *s_type;
	const struct super_operations___19 *s_op;
	const struct dquot_operations___19 *dq_op;
	const struct quotactl_ops___19 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___20 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___19 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___19 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___20 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___19 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___19 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___20 *bd_inode;
	struct super_block___20 *bd_super;
	struct mutex___20 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___19 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___20 bd_fsfreeze_mutex;
};

struct iattr___20 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___19 *ia_file;
};

struct dquot___19 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___20 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___20 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___19 {
	int qf_fmt_id;
	const struct quota_format_ops___19 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___19 *qf_next;
};

struct quota_format_ops___19 {
	int (*check_quota_file)(struct super_block___20 *, int);
	int (*read_file_info)(struct super_block___20 *, int);
	int (*write_file_info)(struct super_block___20 *, int);
	int (*free_file_info)(struct super_block___20 *, int);
	int (*read_dqblk)(struct dquot___19 *);
	int (*commit_dqblk)(struct dquot___19 *);
	int (*release_dqblk)(struct dquot___19 *);
};

struct dquot_operations___19 {
	int (*write_dquot)(struct dquot___19 *);
	struct dquot___19 * (*alloc_dquot)(struct super_block___20 *, int);
	void (*destroy_dquot)(struct dquot___19 *);
	int (*acquire_dquot)(struct dquot___19 *);
	int (*release_dquot)(struct dquot___19 *);
	int (*mark_dirty)(struct dquot___19 *);
	int (*write_info)(struct super_block___20 *, int);
	qsize_t * (*get_reserved_space)(struct inode___20 *);
};

struct quotactl_ops___19 {
	int (*quota_on)(struct super_block___20 *, int, int, struct path___19 *);
	int (*quota_on_meta)(struct super_block___20 *, int, int);
	int (*quota_off)(struct super_block___20 *, int);
	int (*quota_sync)(struct super_block___20 *, int);
	int (*get_info)(struct super_block___20 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___20 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___20 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___20 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___20 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___20 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___20 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___20 *, unsigned int);
};

struct address_space_operations___19 {
	int (*writepage)(struct page___19 *, struct writeback_control *);
	int (*readpage)(struct file___19 *, struct page___19 *);
	int (*writepages)(struct address_space___19 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___19 *);
	int (*readpages)(struct file___19 *, struct address_space___19 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___19 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___19 **, void **);
	int (*write_end)(struct file___19 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___19 *, void *);
	sector_t (*bmap)(struct address_space___19 *, sector_t);
	void (*invalidatepage)(struct page___19 *, long unsigned int);
	int (*releasepage)(struct page___19 *, gfp_t);
	void (*freepage)(struct page___19 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___19 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___19 *, struct page___19 *, struct page___19 *, enum migrate_mode);
	int (*launder_page)(struct page___19 *);
	int (*is_partially_uptodate)(struct page___19 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___19 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___19 *, struct page___19 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___19 *, sector_t *);
	void (*swap_deactivate)(struct file___19 *);
	void (*invalidatepage_range)(struct page___19 *, unsigned int, unsigned int);
};

struct inode_operations___19 {
	struct dentry___20 * (*lookup)(struct inode___20 *, struct dentry___20 *, unsigned int);
	void * (*follow_link)(struct dentry___20 *, struct nameidata *);
	int (*permission)(struct inode___20 *, int);
	struct posix_acl * (*get_acl)(struct inode___20 *, int);
	int (*readlink)(struct dentry___20 *, char *, int);
	void (*put_link)(struct dentry___20 *, struct nameidata *, void *);
	int (*create)(struct inode___20 *, struct dentry___20 *, umode_t, bool);
	int (*link)(struct dentry___20 *, struct inode___20 *, struct dentry___20 *);
	int (*unlink)(struct inode___20 *, struct dentry___20 *);
	int (*symlink)(struct inode___20 *, struct dentry___20 *, const char *);
	int (*mkdir)(struct inode___20 *, struct dentry___20 *, umode_t);
	int (*rmdir)(struct inode___20 *, struct dentry___20 *);
	int (*mknod)(struct inode___20 *, struct dentry___20 *, umode_t, dev_t);
	int (*rename)(struct inode___20 *, struct dentry___20 *, struct inode___20 *, struct dentry___20 *);
	int (*setattr)(struct dentry___20 *, struct iattr___20 *);
	int (*getattr)(struct vfsmount *, struct dentry___20 *, struct kstat *);
	int (*setxattr)(struct dentry___20 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___20 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___20 *, char *, size_t);
	int (*removexattr)(struct dentry___20 *, const char *);
	int (*fiemap)(struct inode___20 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___20 *, struct timespec *, int);
	int (*atomic_open)(struct inode___20 *, struct dentry___20 *, struct file___19 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___19;

struct file_lock_operations___19;

struct lock_manager_operations___19;

struct file_lock___19 {
	struct file_lock___19 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___9 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___19 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___19 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___19 *fl_ops;
	const struct lock_manager_operations___19 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___19 {
	void (*fl_copy_lock)(struct file_lock___19 *, struct file_lock___19 *);
	void (*fl_release_private)(struct file_lock___19 *);
};

struct lock_manager_operations___19 {
	int (*lm_compare_owner)(struct file_lock___19 *, struct file_lock___19 *);
	long unsigned int (*lm_owner_key)(struct file_lock___19 *);
	void (*lm_notify)(struct file_lock___19 *);
	int (*lm_grant)(struct file_lock___19 *, struct file_lock___19 *, int);
	void (*lm_break)(struct file_lock___19 *);
	int (*lm_change)(struct file_lock___19 **, int);
};

struct fasync_struct___19 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___19 *fa_next;
	struct file___19 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___19 {
	const char *name;
	int fs_flags;
	struct dentry___20 * (*mount)(struct file_system_type___19 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___20 *);
	struct module *owner;
	struct file_system_type___19 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___19 {
	struct inode___20 * (*alloc_inode)(struct super_block___20 *);
	void (*destroy_inode)(struct inode___20 *);
	void (*dirty_inode)(struct inode___20 *, int);
	int (*write_inode)(struct inode___20 *, struct writeback_control *);
	int (*drop_inode)(struct inode___20 *);
	void (*evict_inode)(struct inode___20 *);
	void (*put_super)(struct super_block___20 *);
	int (*sync_fs)(struct super_block___20 *, int);
	int (*freeze_fs)(struct super_block___20 *);
	int (*unfreeze_fs)(struct super_block___20 *);
	int (*statfs)(struct dentry___20 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___20 *, int *, char *);
	void (*umount_begin)(struct super_block___20 *);
	int (*show_options)(struct seq_file___16 *, struct dentry___20 *);
	int (*show_devname)(struct seq_file___16 *, struct dentry___20 *);
	int (*show_path)(struct seq_file___16 *, struct dentry___20 *);
	int (*show_stats)(struct seq_file___16 *, struct dentry___20 *);
	ssize_t (*quota_read)(struct super_block___20 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___20 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___20 *);
	int (*bdev_try_to_free_page)(struct super_block___20 *, struct page___19 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___20 *);
	void (*free_cached_objects)(struct super_block___20 *, int);
};

typedef void (*poll_queue_proc___12)(struct file___19 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct poll_table_struct___12 {
	poll_queue_proc___12 _qproc;
	long unsigned int _key;
};

struct xol_area___19 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___19 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___16;

struct memcg_cache_params___16;

struct kmem_cache___16 {
	struct kmem_cache_cpu___16 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___16 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct core_thread___19 {
	struct task_struct___20 *task;
	struct core_thread___19 *next;
};

struct core_state___19 {
	atomic_t nr_threads;
	struct core_thread___19 dumper;
	struct completion startup;
};

struct signal_struct___19 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___20 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___20 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___9 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___9 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___20 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___16 {
	void **freelist;
	long unsigned int tid;
	struct page___19 *page;
	struct page___19 *partial;
};

struct memcg_cache_params___16 {
	bool is_root_cache;
	union {
		struct kmem_cache___16 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___16 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct acpi_table_header {
	char signature[4];
	u32 length;
	u8 revision;
	u8 checksum;
	char oem_id[6];
	char oem_table_id[8];
	u32 oem_revision;
	char asl_compiler_id[4];
	u32 asl_compiler_revision;
};

struct acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct acpi_table_fadt {
	struct acpi_table_header header;
	u32 facs;
	u32 dsdt;
	u8 model;
	u8 preferred_profile;
	u16 sci_interrupt;
	u32 smi_command;
	u8 acpi_enable;
	u8 acpi_disable;
	u8 s4_bios_request;
	u8 pstate_control;
	u32 pm1a_event_block;
	u32 pm1b_event_block;
	u32 pm1a_control_block;
	u32 pm1b_control_block;
	u32 pm2_control_block;
	u32 pm_timer_block;
	u32 gpe0_block;
	u32 gpe1_block;
	u8 pm1_event_length;
	u8 pm1_control_length;
	u8 pm2_control_length;
	u8 pm_timer_length;
	u8 gpe0_block_length;
	u8 gpe1_block_length;
	u8 gpe1_base;
	u8 cst_control;
	u16 c2_latency;
	u16 c3_latency;
	u16 flush_size;
	u16 flush_stride;
	u8 duty_offset;
	u8 duty_width;
	u8 day_alarm;
	u8 month_alarm;
	u8 century;
	u16 boot_flags;
	u8 reserved;
	u32 flags;
	struct acpi_generic_address reset_register;
	u8 reset_value;
	u8 reserved4[3];
	u64 Xfacs;
	u64 Xdsdt;
	struct acpi_generic_address xpm1a_event_block;
	struct acpi_generic_address xpm1b_event_block;
	struct acpi_generic_address xpm1a_control_block;
	struct acpi_generic_address xpm1b_control_block;
	struct acpi_generic_address xpm2_control_block;
	struct acpi_generic_address xpm_timer_block;
	struct acpi_generic_address xgpe0_block;
	struct acpi_generic_address xgpe1_block;
	struct acpi_generic_address sleep_control;
	struct acpi_generic_address sleep_status;
} __attribute__((packed));

struct acpi_hotplug_profile___5 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___5 *);
	void (*notify_online)(struct acpi_device___5 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___5 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___5 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___5 *);
	void (*bind)(struct device___14 *);
	void (*unbind)(struct device___14 *);
	struct acpi_hotplug_profile___5 hotplug;
};

struct acpi_hotplug_context___5 {
	struct acpi_device___5 *self;
	int (*notify)(struct acpi_device___5 *, u32);
	void (*uevent)(struct acpi_device___5 *, u32);
	void (*fixup)(struct acpi_device___5 *);
};

typedef int (*acpi_op_add___5)(struct acpi_device___5 *);

typedef int (*acpi_op_remove___5)(struct acpi_device___5 *);

typedef void (*acpi_op_notify___5)(struct acpi_device___5 *, u32);

struct acpi_device_ops___5 {
	acpi_op_add___5 add;
	acpi_op_remove___5 remove;
	acpi_op_notify___5 notify;
};

struct acpi_driver___5 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___5 ops;
	struct device_driver___14 drv;
	struct module *owner;
};

struct pnp_protocol;

struct pnp_id;

struct pnp_card {
	struct device___14 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev;

struct pnp_protocol {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev *);
	int (*set)(struct pnp_dev *);
	int (*disable)(struct pnp_dev *);
	bool (*can_wakeup)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	unsigned char number;
	struct device___14 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_id {
	char id[8];
	struct pnp_id *next;
};

struct pnp_card_driver;

struct pnp_card_link {
	struct pnp_card *card;
	struct pnp_card_driver *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev *);
	void (*shutdown)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	struct device_driver___14 driver;
};

struct pnp_card_driver {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link *);
	int (*suspend)(struct pnp_card_link *, pm_message_t);
	int (*resume)(struct pnp_card_link *);
	struct pnp_driver link;
};

struct pnp_dev {
	struct device___14 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol *protocol;
	struct pnp_card *card;
	struct pnp_driver *driver;
	struct pnp_card_link *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct property___4 {
	char *name;
	int length;
	void *value;
	struct property___4 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___13 attr;
};

struct page___20;

typedef struct page___20 *pgtable_t___20;

struct address_space___20;

struct kmem_cache___17;

struct page___20 {
	long unsigned int flags;
	struct address_space___20 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___20 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___20 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___17 *slab_cache;
		struct page___20 *first_page;
	};
	long: 64;
};

struct thread_struct___9;

struct task_struct___21;

struct pv_cpu_ops___20 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___9 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___21 *);
	void (*end_context_switch)(struct task_struct___21 *);
};

struct perf_event___9;

struct thread_struct___9 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___9 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___10;

struct pid_link___10 {
	struct hlist_node node;
	struct pid___10 *pid;
};

struct mutex___21 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___21 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___18 {
	struct page___20 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___23;

struct nsproxy___10;

struct signal_struct___20;

struct css_set___9;

struct perf_event_context___9;

struct task_struct___21 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___21 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___23 *mm;
	struct mm_struct___23 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___21 *real_parent;
	struct task_struct___21 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___21 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___10 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___20 = 0,
		VTIME_USER___20 = 1,
		VTIME_SYS___20 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___9 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___10 *nsproxy;
	struct signal_struct___20 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___9 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___9 *perf_event_ctxp[2];
	struct mutex___21 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___18 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___23 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___23 *, struct mm_struct___23 *);
	void (*dup_mmap)(struct mm_struct___23 *, struct mm_struct___23 *);
	void (*exit_mmap)(struct mm_struct___23 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___23 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___23 *);
	void (*pgd_free)(struct mm_struct___23 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___23 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___23 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___23 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___23 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___23 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___23 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___23 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___23 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___23 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___23 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___23 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___21 lock;
	void *vdso;
} mm_context_t___21;

struct xol_area___20;

struct uprobes_state___20 {
	struct xol_area___20 *xol_area;
};

struct vm_area_struct___23;

struct file___20;

struct core_state___20;

struct mm_struct___23 {
	struct vm_area_struct___23 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___23 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___23 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___21 context;
	long unsigned int flags;
	struct core_state___20 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___21 *owner;
	struct file___20 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___20 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___10;

struct exec_domain___7 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___10 *module;
	struct exec_domain___7 *next;
};

struct module_kobject___9 {
	struct kobject kobj;
	struct module___10 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___9;

struct module___10 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___9 mkobj;
	struct module_attribute___9 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___21 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___9 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___21 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___21 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___21 *target;
};

typedef void (*perf_overflow_handler_t___9)(struct perf_event___9 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___9;

typedef void (*ftrace_func_t___9)(long unsigned int, long unsigned int, struct ftrace_ops___9 *, struct pt_regs *);

struct ftrace_ops___9 {
	ftrace_func_t___9 func;
	struct ftrace_ops___9 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___21 regex_lock;
};

struct pmu___9;

struct fasync_struct___20;

struct pid_namespace___10;

struct perf_cgroup___9;

struct perf_event___9 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___9 *group_leader;
	struct pmu___9 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___9 hw;
	struct perf_event_context___9 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___21 child_mutex;
	struct list_head child_list;
	struct perf_event___9 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___21 *owner;
	struct mutex___21 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___20 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___9 *);
	struct callback_head callback_head;
	struct pid_namespace___10 *ns;
	u64 id;
	perf_overflow_handler_t___9 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___9 ftrace_ops;
	struct perf_cgroup___9 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

enum idle_boot_override {
	IDLE_NO_OVERRIDE = 0,
	IDLE_HALT = 1,
	IDLE_NOMWAIT = 2,
	IDLE_POLL = 3,
};

struct thread_info___11 {
	struct task_struct___21 *task;
	struct exec_domain___7 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___20;

struct lruvec___20 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___20 *zone;
};

struct pglist_data___20;

struct zone___20 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___20 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___20 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___20 {
	struct zone___20 *zone;
	int zone_idx;
};

struct zonelist___20 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___20 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___20 {
	struct zone___20 node_zones[4];
	struct zonelist___20 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___21 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___15;

struct dev_pm_ops___15 {
	int (*prepare)(struct device___15 *);
	void (*complete)(struct device___15 *);
	int (*suspend)(struct device___15 *);
	int (*resume)(struct device___15 *);
	int (*freeze)(struct device___15 *);
	int (*thaw)(struct device___15 *);
	int (*poweroff)(struct device___15 *);
	int (*restore)(struct device___15 *);
	int (*suspend_late)(struct device___15 *);
	int (*resume_early)(struct device___15 *);
	int (*freeze_late)(struct device___15 *);
	int (*thaw_early)(struct device___15 *);
	int (*poweroff_late)(struct device___15 *);
	int (*restore_early)(struct device___15 *);
	int (*suspend_noirq)(struct device___15 *);
	int (*resume_noirq)(struct device___15 *);
	int (*freeze_noirq)(struct device___15 *);
	int (*thaw_noirq)(struct device___15 *);
	int (*poweroff_noirq)(struct device___15 *);
	int (*restore_noirq)(struct device___15 *);
	int (*runtime_suspend)(struct device___15 *);
	int (*runtime_resume)(struct device___15 *);
	int (*runtime_idle)(struct device___15 *);
};

struct dev_pm_qos___2;

struct dev_pm_info___2 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___2 *qos;
};

struct device_type___15;

struct bus_type___15;

struct device_driver___15;

struct dev_pm_domain___15;

struct class___15;

struct attribute_group___14;

struct device_rh___15;

struct device___15 {
	struct device___15 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___15 *type;
	struct mutex___21 mutex;
	struct bus_type___15 *bus;
	struct device_driver___15 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___15 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___6 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___5 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___15 *class;
	const struct attribute_group___14 **groups;
	void (*release)(struct device___15 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___15 *device_rh;
};

struct dev_pm_qos_request___2;

struct dev_pm_qos___2 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___2 *latency_req;
	struct dev_pm_qos_request___2 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___2 *latency_tolerance_req;
};

struct dev_pm_info_rh___15 {
	void (*set_latency_tolerance)(struct device___15 *, s32);
};

struct dev_pm_domain___15 {
	struct dev_pm_ops___15 ops;
};

struct smp_ops___20 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___21 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___20 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___20 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___17;

struct memcg_cache_params___17;

struct kmem_cache___17 {
	struct kmem_cache_cpu___17 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___17 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___21;

struct address_space_operations___20;

struct address_space___20 {
	struct inode___21 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___21 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___20 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___21;

struct path___20 {
	struct vfsmount *mnt;
	struct dentry___21 *dentry;
};

struct fown_struct___10 {
	rwlock_t lock;
	struct pid___10 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___20;

struct file___20 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___20 f_path;
	struct inode___21 *f_inode;
	const struct file_operations___20 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___10 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___20 *f_mapping;
	struct mutex___21 f_pos_lock;
};

struct vm_operations_struct___17;

struct vm_area_struct___23 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___23 *vm_next;
	struct vm_area_struct___23 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___23 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___17 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___20 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___15;

struct vm_operations_struct___17 {
	void (*open)(struct vm_area_struct___23 *);
	void (*close)(struct vm_area_struct___23 *);
	int (*fault)(struct vm_area_struct___23 *, struct vm_fault___15 *);
	int (*page_mkwrite)(struct vm_area_struct___23 *, struct vm_fault___15 *);
	int (*access)(struct vm_area_struct___23 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___23 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___23 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___23 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___23 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___20 {
	struct task_struct___21 *task;
	struct core_thread___20 *next;
};

struct core_state___20 {
	atomic_t nr_threads;
	struct core_thread___20 dumper;
	struct completion startup;
};

struct vm_fault___15 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___20 *page;
};

struct bin_attribute___14;

struct attribute_group___14 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___14 **bin_attrs;
};

struct bin_attribute___14 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___20 *, struct kobject *, struct bin_attribute___14 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___20 *, struct kobject *, struct bin_attribute___14 *, char *, loff_t, size_t);
	int (*mmap)(struct file___20 *, struct kobject *, struct bin_attribute___14 *, struct vm_area_struct___23 *);
};

struct kmem_cache_cpu___17 {
	void **freelist;
	long unsigned int tid;
	struct page___20 *page;
	struct page___20 *partial;
};

struct memcg_cache_params___17 {
	bool is_root_cache;
	union {
		struct kmem_cache___17 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___17 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct upid___10 {
	int nr;
	struct pid_namespace___10 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___10 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___21 *child_reaper;
	struct kmem_cache___17 *pid_cachep;
	unsigned int level;
	struct pid_namespace___10 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___21 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___10 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___10 numbers[1];
};

struct nsproxy___10 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___10 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___20 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___21 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___21 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___10 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___10 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___21 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___9;

struct css_set___9 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___9 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___9 {
	struct pmu___9 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___21 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___21 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___9 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

union thread_union___2 {
	struct thread_info___11 thread_info;
	long unsigned int stack[2048];
};

struct module_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___9 *, struct module_kobject___9 *, char *);
	ssize_t (*store)(struct module_attribute___9 *, struct module_kobject___9 *, const char *, size_t);
	void (*setup)(struct module___10 *, const char *);
	int (*test)(struct module___10 *);
	void (*free)(struct module___10 *);
};

struct file_lock___20;

struct file_operations___20 {
	struct module___10 *owner;
	loff_t (*llseek)(struct file___20 *, loff_t, int);
	ssize_t (*read)(struct file___20 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___20 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___20 *, void *, filldir_t);
	unsigned int (*poll)(struct file___20 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___20 *, struct vm_area_struct___23 *);
	int (*open)(struct inode___21 *, struct file___20 *);
	int (*flush)(struct file___20 *, fl_owner_t);
	int (*release)(struct inode___21 *, struct file___20 *);
	int (*fsync)(struct file___20 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___20 *, int);
	int (*lock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*sendpage)(struct file___20 *, struct page___20 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___20 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___20 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___20 *, long int, struct file_lock___20 **, void **);
		struct {
			int (*setlease)(struct file___20 *, long int, struct file_lock___20 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___20 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___20 *);
};

struct bus_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___15 *, char *);
	ssize_t (*store)(struct bus_type___15 *, const char *, size_t);
};

struct device_attribute___15;

struct driver_attribute___15;

struct bus_type___15 {
	const char *name;
	const char *dev_name;
	struct device___15 *dev_root;
	struct bus_attribute___15 *bus_attrs;
	struct device_attribute___15 *dev_attrs;
	struct driver_attribute___15 *drv_attrs;
	const struct attribute_group___14 **bus_groups;
	const struct attribute_group___14 **dev_groups;
	const struct attribute_group___14 **drv_groups;
	int (*match)(struct device___15 *, struct device_driver___15 *);
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	int (*probe)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*online)(struct device___15 *);
	int (*offline)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct device___15 *, struct device_attribute___15 *, char *);
	ssize_t (*store)(struct device___15 *, struct device_attribute___15 *, const char *, size_t);
};

struct driver_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___15 *, char *);
	ssize_t (*store)(struct device_driver___15 *, const char *, size_t);
};

struct device_driver___15 {
	const char *name;
	struct bus_type___15 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct attribute_group___14 **groups;
	const struct dev_pm_ops___15 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___15 {
	const char *name;
	const struct attribute_group___14 **groups;
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
};

struct class_attribute___15;

struct class___15 {
	const char *name;
	struct module___10 *owner;
	struct class_attribute___15 *class_attrs;
	struct device_attribute___15 *dev_attrs;
	const struct attribute_group___14 **dev_groups;
	struct bin_attribute___14 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *);
	void (*class_release)(struct class___15 *);
	void (*dev_release)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
	struct subsys_private *p;
};

struct class_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct class___15 *, struct class_attribute___15 *, char *);
	ssize_t (*store)(struct class___15 *, struct class_attribute___15 *, const char *, size_t);
	const void * (*namespace)(struct class___15 *, const struct class_attribute___15 *);
};

struct device_rh___15 {
	struct dev_pm_info_rh___15 power;
};

struct dev_pm_qos_request___2 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___15 *dev;
};

struct dentry_operations___20;

struct super_block___21;

struct dentry___21 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___21 *d_parent;
	struct qstr d_name;
	struct inode___21 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___20 *d_op;
	struct super_block___21 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___20;

struct dquot___20;

struct block_device___20;

struct inode___21 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___20 *i_op;
	struct super_block___21 *i_sb;
	struct address_space___20 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___21 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___20 *i_fop;
	struct file_lock___20 *i_flock;
	struct address_space___20 i_data;
	struct dquot___20 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___20 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___20 {
	int (*d_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_hash)(const struct dentry___21 *, struct qstr *);
	int (*d_compare)(const struct dentry___21 *, const struct dentry___21 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___21 *);
	void (*d_release)(struct dentry___21 *);
	void (*d_prune)(struct dentry___21 *);
	void (*d_iput)(struct dentry___21 *, struct inode___21 *);
	char * (*d_dname)(struct dentry___21 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___20 *);
	int (*d_manage)(struct dentry___21 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___20;

struct mem_dqinfo___20 {
	struct quota_format_type___20 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___20;

struct quota_info___20 {
	unsigned int flags;
	struct mutex___21 dqio_mutex;
	struct mutex___21 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___21 *files[2];
	struct mem_dqinfo___20 info[2];
	const struct quota_format_ops___20 *ops[2];
};

struct file_system_type___20;

struct super_operations___20;

struct dquot_operations___20;

struct quotactl_ops___20;

struct xattr_handler___9;

struct super_block___21 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___20 *s_type;
	const struct super_operations___20 *s_op;
	const struct dquot_operations___20 *dq_op;
	const struct quotactl_ops___20 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___21 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___9 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___20 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___20 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___21 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___20 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___20 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___21 *bd_inode;
	struct super_block___21 *bd_super;
	struct mutex___21 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___20 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___21 bd_fsfreeze_mutex;
};

struct cgroup___9;

struct cgroup_subsys_state___9 {
	struct cgroup___9 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___21 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___20 *ia_file;
};

struct dquot___20 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___21 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___21 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___20 {
	int qf_fmt_id;
	const struct quota_format_ops___20 *qf_ops;
	struct module___10 *qf_owner;
	struct quota_format_type___20 *qf_next;
};

struct quota_format_ops___20 {
	int (*check_quota_file)(struct super_block___21 *, int);
	int (*read_file_info)(struct super_block___21 *, int);
	int (*write_file_info)(struct super_block___21 *, int);
	int (*free_file_info)(struct super_block___21 *, int);
	int (*read_dqblk)(struct dquot___20 *);
	int (*commit_dqblk)(struct dquot___20 *);
	int (*release_dqblk)(struct dquot___20 *);
};

struct dquot_operations___20 {
	int (*write_dquot)(struct dquot___20 *);
	struct dquot___20 * (*alloc_dquot)(struct super_block___21 *, int);
	void (*destroy_dquot)(struct dquot___20 *);
	int (*acquire_dquot)(struct dquot___20 *);
	int (*release_dquot)(struct dquot___20 *);
	int (*mark_dirty)(struct dquot___20 *);
	int (*write_info)(struct super_block___21 *, int);
	qsize_t * (*get_reserved_space)(struct inode___21 *);
};

struct quotactl_ops___20 {
	int (*quota_on)(struct super_block___21 *, int, int, struct path___20 *);
	int (*quota_on_meta)(struct super_block___21 *, int, int);
	int (*quota_off)(struct super_block___21 *, int);
	int (*quota_sync)(struct super_block___21 *, int);
	int (*get_info)(struct super_block___21 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___21 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___21 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___21 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___21 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___21 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___21 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___21 *, unsigned int);
};

struct address_space_operations___20 {
	int (*writepage)(struct page___20 *, struct writeback_control *);
	int (*readpage)(struct file___20 *, struct page___20 *);
	int (*writepages)(struct address_space___20 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___20 *);
	int (*readpages)(struct file___20 *, struct address_space___20 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___20 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___20 **, void **);
	int (*write_end)(struct file___20 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___20 *, void *);
	sector_t (*bmap)(struct address_space___20 *, sector_t);
	void (*invalidatepage)(struct page___20 *, long unsigned int);
	int (*releasepage)(struct page___20 *, gfp_t);
	void (*freepage)(struct page___20 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___20 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___20 *, struct page___20 *, struct page___20 *, enum migrate_mode);
	int (*launder_page)(struct page___20 *);
	int (*is_partially_uptodate)(struct page___20 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___20 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___20 *, struct page___20 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___20 *, sector_t *);
	void (*swap_deactivate)(struct file___20 *);
	void (*invalidatepage_range)(struct page___20 *, unsigned int, unsigned int);
};

struct inode_operations___20 {
	struct dentry___21 * (*lookup)(struct inode___21 *, struct dentry___21 *, unsigned int);
	void * (*follow_link)(struct dentry___21 *, struct nameidata *);
	int (*permission)(struct inode___21 *, int);
	struct posix_acl * (*get_acl)(struct inode___21 *, int);
	int (*readlink)(struct dentry___21 *, char *, int);
	void (*put_link)(struct dentry___21 *, struct nameidata *, void *);
	int (*create)(struct inode___21 *, struct dentry___21 *, umode_t, bool);
	int (*link)(struct dentry___21 *, struct inode___21 *, struct dentry___21 *);
	int (*unlink)(struct inode___21 *, struct dentry___21 *);
	int (*symlink)(struct inode___21 *, struct dentry___21 *, const char *);
	int (*mkdir)(struct inode___21 *, struct dentry___21 *, umode_t);
	int (*rmdir)(struct inode___21 *, struct dentry___21 *);
	int (*mknod)(struct inode___21 *, struct dentry___21 *, umode_t, dev_t);
	int (*rename)(struct inode___21 *, struct dentry___21 *, struct inode___21 *, struct dentry___21 *);
	int (*setattr)(struct dentry___21 *, struct iattr___21 *);
	int (*getattr)(struct vfsmount *, struct dentry___21 *, struct kstat *);
	int (*setxattr)(struct dentry___21 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___21 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___21 *, char *, size_t);
	int (*removexattr)(struct dentry___21 *, const char *);
	int (*fiemap)(struct inode___21 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___21 *, struct timespec *, int);
	int (*atomic_open)(struct inode___21 *, struct dentry___21 *, struct file___20 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___20;

struct lock_manager_operations___20;

struct file_lock___20 {
	struct file_lock___20 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___10 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___20 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___20 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___20 *fl_ops;
	const struct lock_manager_operations___20 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___20 {
	void (*fl_copy_lock)(struct file_lock___20 *, struct file_lock___20 *);
	void (*fl_release_private)(struct file_lock___20 *);
};

struct lock_manager_operations___20 {
	int (*lm_compare_owner)(struct file_lock___20 *, struct file_lock___20 *);
	long unsigned int (*lm_owner_key)(struct file_lock___20 *);
	void (*lm_notify)(struct file_lock___20 *);
	int (*lm_grant)(struct file_lock___20 *, struct file_lock___20 *, int);
	void (*lm_break)(struct file_lock___20 *);
	int (*lm_change)(struct file_lock___20 **, int);
};

struct fasync_struct___20 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___20 *fa_next;
	struct file___20 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___20 {
	const char *name;
	int fs_flags;
	struct dentry___21 * (*mount)(struct file_system_type___20 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___21 *);
	struct module___10 *owner;
	struct file_system_type___20 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___20 {
	struct inode___21 * (*alloc_inode)(struct super_block___21 *);
	void (*destroy_inode)(struct inode___21 *);
	void (*dirty_inode)(struct inode___21 *, int);
	int (*write_inode)(struct inode___21 *, struct writeback_control *);
	int (*drop_inode)(struct inode___21 *);
	void (*evict_inode)(struct inode___21 *);
	void (*put_super)(struct super_block___21 *);
	int (*sync_fs)(struct super_block___21 *, int);
	int (*freeze_fs)(struct super_block___21 *);
	int (*unfreeze_fs)(struct super_block___21 *);
	int (*statfs)(struct dentry___21 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___21 *, int *, char *);
	void (*umount_begin)(struct super_block___21 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___21 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___21 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___21 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___21 *);
	ssize_t (*quota_read)(struct super_block___21 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___21 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___21 *);
	int (*bdev_try_to_free_page)(struct super_block___21 *, struct page___20 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___21 *);
	void (*free_cached_objects)(struct super_block___21 *, int);
};

struct xattr_handler___9 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___21 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___21 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___21 *, const char *, const void *, size_t, int, int);
};

struct cgroupfs_root___9;

struct cgroup___9 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___9 *parent;
	struct dentry___21 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___9 *subsys[11];
	struct cgroupfs_root___9 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___21 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___9 {
	struct super_block___21 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___9 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___9;

struct pmu___9 {
	struct list_head entry;
	struct device___15 *dev;
	const struct attribute_group___14 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___9 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___9 *);
	void (*pmu_disable)(struct pmu___9 *);
	int (*event_init)(struct perf_event___9 *);
	int (*add)(struct perf_event___9 *, int);
	void (*del)(struct perf_event___9 *, int);
	void (*start)(struct perf_event___9 *, int);
	void (*stop)(struct perf_event___9 *, int);
	void (*read)(struct perf_event___9 *);
	void (*start_txn)(struct pmu___9 *);
	int (*commit_txn)(struct pmu___9 *);
	void (*cancel_txn)(struct pmu___9 *);
	int (*event_idx)(struct perf_event___9 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___10 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___9 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___9 *);
};

struct perf_cpu_context___9 {
	struct perf_event_context___9 ctx;
	struct perf_event_context___9 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___9 *unique_pmu;
	struct perf_cgroup___9 *cgrp;
};

struct perf_cgroup___9 {
	struct cgroup_subsys_state___9 css;
	struct perf_cgroup_info *info;
};

typedef unsigned char pto_T_____2;

struct user_regset;

typedef int user_regset_active_fn(struct task_struct___5 *, const struct user_regset *);

typedef int user_regset_get_fn(struct task_struct___5 *, const struct user_regset *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn(struct task_struct___5 *, const struct user_regset *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn(struct task_struct___5 *, const struct user_regset *, int);

struct user_regset {
	user_regset_get_fn *get;
	user_regset_set_fn *set;
	user_regset_active_fn *active;
	user_regset_writeback_fn *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_i387_ia32_struct {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
};

struct _fpreg {
	short unsigned int significand[4];
	short unsigned int exponent;
};

struct _fpxreg {
	short unsigned int significand[4];
	short unsigned int exponent;
	short unsigned int padding[3];
};

typedef struct task_struct___5 *pto_T_____3;

struct _fpx_sw_bytes {
	__u32 magic1;
	__u32 extended_size;
	__u64 xstate_bv;
	__u32 xstate_size;
	__u32 padding[7];
};

struct _xmmreg {
	__u32 element[4];
};

struct _fpstate_ia32 {
	__u32 cw;
	__u32 sw;
	__u32 tag;
	__u32 ipoff;
	__u32 cssel;
	__u32 dataoff;
	__u32 datasel;
	struct _fpreg _st[8];
	short unsigned int status;
	short unsigned int magic;
	__u32 _fxsr_env[6];
	__u32 mxcsr;
	__u32 reserved;
	struct _fpxreg _fxsr_st[8];
	struct _xmmreg _xmm[8];
	__u32 padding[44];
	union {
		__u32 padding2[12];
		struct _fpx_sw_bytes sw_reserved;
	};
};

enum {
	AUTO = 0,
	ENABLE = 1,
	DISABLE = 2,
};

struct user_regset___2;

typedef int user_regset_active_fn___2(struct task_struct___11 *, const struct user_regset___2 *);

typedef int user_regset_get_fn___2(struct task_struct___11 *, const struct user_regset___2 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___2(struct task_struct___11 *, const struct user_regset___2 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___2(struct task_struct___11 *, const struct user_regset___2 *, int);

struct user_regset___2 {
	user_regset_get_fn___2 *get;
	user_regset_set_fn___2 *set;
	user_regset_active_fn___2 *active;
	user_regset_writeback_fn___2 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view {
	const char *name;
	const struct user_regset___2 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

enum perf_type_id {
	PERF_TYPE_HARDWARE = 0,
	PERF_TYPE_SOFTWARE = 1,
	PERF_TYPE_TRACEPOINT = 2,
	PERF_TYPE_HW_CACHE = 3,
	PERF_TYPE_RAW = 4,
	PERF_TYPE_BREAKPOINT = 5,
	PERF_TYPE_MAX = 6,
};

typedef u32 compat_ulong_t;

struct kprobe_insn_cache___6 {
	struct mutex___11 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct ftrace_raw_sys_enter {
	struct trace_entry ent;
	long int id;
	long unsigned int args[6];
	char __data[0];
};

struct ftrace_raw_sys_exit {
	struct trace_entry ent;
	long int id;
	long int ret;
	char __data[0];
};

struct ftrace_data_offsets_sys_enter {};

struct ftrace_data_offsets_sys_exit {};

enum x86_regset {
	REGSET_GENERAL = 0,
	REGSET_FP = 1,
	REGSET_XFP = 2,
	REGSET_IOPERM64 = 2,
	REGSET_XSTATE = 3,
	REGSET_TLS = 4,
	REGSET_IOPERM32 = 5,
};

struct pt_regs_offset {
	const char *name;
	int offset;
};

struct device___16;

struct dev_pm_ops___16 {
	int (*prepare)(struct device___16 *);
	void (*complete)(struct device___16 *);
	int (*suspend)(struct device___16 *);
	int (*resume)(struct device___16 *);
	int (*freeze)(struct device___16 *);
	int (*thaw)(struct device___16 *);
	int (*poweroff)(struct device___16 *);
	int (*restore)(struct device___16 *);
	int (*suspend_late)(struct device___16 *);
	int (*resume_early)(struct device___16 *);
	int (*freeze_late)(struct device___16 *);
	int (*thaw_early)(struct device___16 *);
	int (*poweroff_late)(struct device___16 *);
	int (*restore_early)(struct device___16 *);
	int (*suspend_noirq)(struct device___16 *);
	int (*resume_noirq)(struct device___16 *);
	int (*freeze_noirq)(struct device___16 *);
	int (*thaw_noirq)(struct device___16 *);
	int (*poweroff_noirq)(struct device___16 *);
	int (*restore_noirq)(struct device___16 *);
	int (*runtime_suspend)(struct device___16 *);
	int (*runtime_resume)(struct device___16 *);
	int (*runtime_idle)(struct device___16 *);
};

struct dma_map_ops___7;

struct dev_archdata___7 {
	struct dma_map_ops___7 *dma_ops;
	void *iommu;
};

struct acpi_device___6;

struct acpi_dev_node___8 {
	union {
		struct acpi_device___6 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct device_type___16;

struct bus_type___16;

struct device_driver___16;

struct dev_pm_domain___16;

struct class___16;

struct device_rh___16;

struct device___16 {
	struct device___16 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___16 *type;
	struct mutex___8 mutex;
	struct bus_type___16 *bus;
	struct device_driver___16 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___16 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___7 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___16 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___16 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___16 *device_rh;
};

struct dev_pm_info_rh___16 {
	void (*set_latency_tolerance)(struct device___16 *, s32);
};

struct dev_pm_domain___16 {
	struct dev_pm_ops___16 ops;
};

struct dma_map_ops___7 {
	void * (*alloc)(struct device___16 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___16 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___16 *, struct vm_area_struct___8 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___16 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___16 *, struct page___5 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___16 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___16 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___16 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___16 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___16 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___16 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___16 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___16 *, dma_addr_t);
	int (*dma_supported)(struct device___16 *, u64);
	int (*set_dma_mask)(struct device___16 *, u64);
	int is_phys;
};

struct bus_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___16 *, char *);
	ssize_t (*store)(struct bus_type___16 *, const char *, size_t);
};

struct device_attribute___16;

struct driver_attribute___16;

struct bus_type___16 {
	const char *name;
	const char *dev_name;
	struct device___16 *dev_root;
	struct bus_attribute___16 *bus_attrs;
	struct device_attribute___16 *dev_attrs;
	struct driver_attribute___16 *drv_attrs;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___16 *, struct device_driver___16 *);
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	int (*probe)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*online)(struct device___16 *);
	int (*offline)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct device___16 *, struct device_attribute___16 *, char *);
	ssize_t (*store)(struct device___16 *, struct device_attribute___16 *, const char *, size_t);
};

struct driver_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___16 *, char *);
	ssize_t (*store)(struct device_driver___16 *, const char *, size_t);
};

struct device_driver___16 {
	const char *name;
	struct bus_type___16 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct attribute_group___5 **groups;
	const struct dev_pm_ops___16 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___16 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
};

struct class_attribute___16;

struct class___16 {
	const char *name;
	struct module *owner;
	struct class_attribute___16 *class_attrs;
	struct device_attribute___16 *dev_attrs;
	const struct attribute_group___5 **dev_groups;
	struct bin_attribute___5 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *);
	void (*class_release)(struct class___16 *);
	void (*dev_release)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	struct subsys_private *p;
};

struct class_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct class___16 *, struct class_attribute___16 *, char *);
	ssize_t (*store)(struct class___16 *, struct class_attribute___16 *, const char *, size_t);
	const void * (*namespace)(struct class___16 *, const struct class_attribute___16 *);
};

struct acpi_scan_handler___6;

struct acpi_hotplug_context___6;

struct acpi_driver___6;

struct acpi_device___6 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___6 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___6 *handler;
	struct acpi_hotplug_context___6 *hp;
	struct acpi_driver___6 *driver;
	void *driver_data;
	struct device___16 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___8 physical_node_lock;
	void (*remove)(struct acpi_device___6 *);
};

struct device_rh___16 {
	struct dev_pm_info_rh___16 power;
};

struct acpi_hotplug_profile___6 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___6 *);
	void (*notify_online)(struct acpi_device___6 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___6 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___6 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___6 *);
	void (*bind)(struct device___16 *);
	void (*unbind)(struct device___16 *);
	struct acpi_hotplug_profile___6 hotplug;
};

struct acpi_hotplug_context___6 {
	struct acpi_device___6 *self;
	int (*notify)(struct acpi_device___6 *, u32);
	void (*uevent)(struct acpi_device___6 *, u32);
	void (*fixup)(struct acpi_device___6 *);
};

typedef int (*acpi_op_add___6)(struct acpi_device___6 *);

typedef int (*acpi_op_remove___6)(struct acpi_device___6 *);

typedef void (*acpi_op_notify___6)(struct acpi_device___6 *, u32);

struct acpi_device_ops___6 {
	acpi_op_add___6 add;
	acpi_op_remove___6 remove;
	acpi_op_notify___6 notify;
};

struct acpi_driver___6 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___6 ops;
	struct device_driver___16 drv;
	struct module *owner;
};

enum {
	TB_SHUTDOWN_REBOOT = 0,
	TB_SHUTDOWN_S5 = 1,
	TB_SHUTDOWN_S4 = 2,
	TB_SHUTDOWN_S3 = 3,
	TB_SHUTDOWN_HALT = 4,
	TB_SHUTDOWN_WFS = 5,
};

struct sha1_hash {
	u8 hash[20];
};

struct sinit_mle_data {
	u32 version;
	struct sha1_hash bios_acm_id;
	u32 edx_senter_flags;
	u64 mseg_valid;
	struct sha1_hash sinit_hash;
	struct sha1_hash mle_hash;
	struct sha1_hash stm_hash;
	struct sha1_hash lcp_policy_hash;
	u32 lcp_policy_control;
	u32 rlp_wakeup_addr;
	u32 reserved;
	u32 num_mdrs;
	u32 mdrs_off;
	u32 num_vtd_dmars;
	u32 vtd_dmars_off;
} __attribute__((packed));

enum tlb_infos {
	ENTRIES = 0,
	NR_INFO = 1,
};

struct stack_trace {
	unsigned int nr_entries;
	unsigned int max_entries;
	long unsigned int *entries;
	int skip;
};

struct stacktrace_ops___2;

typedef long unsigned int (*walk_stack_t___2)(struct thread_info___10 *, long unsigned int *, long unsigned int, const struct stacktrace_ops___2 *, void *, long unsigned int *, int *);

struct stacktrace_ops___2 {
	void (*address)(void *, long unsigned int, int);
	int (*stack)(void *, char *);
	walk_stack_t___2 walk_stack;
};

struct stack_frame_user {
	const void *next_fp;
	long unsigned int ret_addr;
};

typedef __kernel_long_t __kernel_ptrdiff_t;

typedef __kernel_ptrdiff_t ptrdiff_t;

enum kobject_action {
	KOBJ_ADD = 0,
	KOBJ_REMOVE = 1,
	KOBJ_CHANGE = 2,
	KOBJ_MOVE = 3,
	KOBJ_ONLINE = 4,
	KOBJ_OFFLINE = 5,
	KOBJ_MAX = 6,
};

struct amd_northbridge___2 {
	struct pci_dev *misc;
	struct pci_dev *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info___2 {
	u16 num;
	u64 flags;
	struct amd_northbridge___2 *nb;
};

struct _cache_table {
	unsigned char descriptor;
	char cache_type;
	short int size;
};

enum _cache_type {
	CACHE_TYPE_NULL = 0,
	CACHE_TYPE_DATA = 1,
	CACHE_TYPE_INST = 2,
	CACHE_TYPE_UNIFIED = 3,
};

union _cpuid4_leaf_eax {
	struct {
		enum _cache_type type: 5;
		unsigned int level: 3;
		unsigned int is_self_initializing: 1;
		unsigned int is_fully_associative: 1;
		unsigned int reserved: 4;
		unsigned int num_threads_sharing: 12;
		unsigned int num_cores_on_die: 6;
	} split;
	u32 full;
};

union _cpuid4_leaf_ebx {
	struct {
		unsigned int coherency_line_size: 12;
		unsigned int physical_line_partition: 10;
		unsigned int ways_of_associativity: 10;
	} split;
	u32 full;
};

union _cpuid4_leaf_ecx {
	struct {
		unsigned int number_of_sets: 32;
	} split;
	u32 full;
};

struct _cpuid4_info_regs {
	union _cpuid4_leaf_eax eax;
	union _cpuid4_leaf_ebx ebx;
	union _cpuid4_leaf_ecx ecx;
	long unsigned int size;
	struct amd_northbridge___2 *nb;
};

struct _cpuid4_info {
	struct _cpuid4_info_regs base;
	long unsigned int shared_cpu_map[80];
};

union l1_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 8;
		unsigned int assoc: 8;
		unsigned int size_in_kb: 8;
	};
	unsigned int val;
};

union l2_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 4;
		unsigned int assoc: 4;
		unsigned int size_in_kb: 16;
	};
	unsigned int val;
};

union l3_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 4;
		unsigned int assoc: 4;
		unsigned int res: 2;
		unsigned int size_encoded: 14;
	};
	unsigned int val;
};

struct _cache_attr {
	struct attribute attr;
	ssize_t (*show)(struct _cpuid4_info *, char *, unsigned int);
	ssize_t (*store)(struct _cpuid4_info *, const char *, size_t, unsigned int);
};

struct _index_kobject {
	struct kobject kobj;
	unsigned int cpu;
	short unsigned int index;
};

struct cpuid_bit {
	u16 feature;
	u8 reg;
	u8 bit;
	u32 level;
	u32 sub_leaf;
};

enum cpuid_regs {
	CR_EAX = 0,
	CR_ECX = 1,
	CR_EDX = 2,
	CR_EBX = 3,
};

struct ldttss_desc64 {
	u16 limit0;
	u16 base0;
	unsigned int base1: 8;
	unsigned int type: 5;
	unsigned int dpl: 2;
	unsigned int p: 1;
	unsigned int limit1: 4;
	unsigned int zero0: 3;
	unsigned int g: 1;
	unsigned int base2: 8;
	u32 base3;
	u32 zero1;
};

typedef struct ldttss_desc64 tss_desc;

union thread_union___3 {
	struct thread_info___8 thread_info;
	long unsigned int stack[2048];
};

enum kgdb_bptype {
	BP_BREAKPOINT = 0,
	BP_HARDWARE_BREAKPOINT = 1,
	BP_WRITE_WATCHPOINT = 2,
	BP_READ_WATCHPOINT = 3,
	BP_ACCESS_WATCHPOINT = 4,
	BP_POKE_BREAKPOINT = 5,
};

struct kgdb_arch {
	unsigned char gdb_bpt_instr[1];
	long unsigned int flags;
	int (*set_breakpoint)(long unsigned int, char *);
	int (*remove_breakpoint)(long unsigned int, char *);
	int (*set_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	int (*remove_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	void (*disable_hw_break)(struct pt_regs *);
	void (*remove_all_hw_break)();
	void (*correct_hw_break)();
	void (*enable_nmi)(bool);
};

struct cpu_model_info {
	int vendor;
	int family;
	const char *model_names[16];
};

struct cpu_dev {
	const char *c_vendor;
	const char *c_ident[2];
	struct cpu_model_info c_models[4];
	void (*c_early_init)(struct cpuinfo_x86 *);
	void (*c_bsp_init)(struct cpuinfo_x86 *);
	void (*c_init)(struct cpuinfo_x86 *);
	void (*c_identify)(struct cpuinfo_x86 *);
	void (*c_detect_tlb)(struct cpuinfo_x86 *);
	unsigned int (*c_size_cache)(struct cpuinfo_x86 *, unsigned int);
	int c_x86_vendor;
};

struct cpuid_dependent_feature {
	u32 feature;
	u32 level;
};

struct msr_range {
	unsigned int min;
	unsigned int max;
};

struct x86_cpu_id {
	__u16 vendor;
	__u16 family;
	__u16 model;
	__u16 feature;
	kernel_ulong_t driver_data;
};

struct _tlb_table {
	unsigned char descriptor;
	char tlb_type;
	unsigned int entries;
	char info[128];
};

enum perf_hw_id {
	PERF_COUNT_HW_CPU_CYCLES = 0,
	PERF_COUNT_HW_INSTRUCTIONS = 1,
	PERF_COUNT_HW_CACHE_REFERENCES = 2,
	PERF_COUNT_HW_CACHE_MISSES = 3,
	PERF_COUNT_HW_BRANCH_INSTRUCTIONS = 4,
	PERF_COUNT_HW_BRANCH_MISSES = 5,
	PERF_COUNT_HW_BUS_CYCLES = 6,
	PERF_COUNT_HW_STALLED_CYCLES_FRONTEND = 7,
	PERF_COUNT_HW_STALLED_CYCLES_BACKEND = 8,
	PERF_COUNT_HW_REF_CPU_CYCLES = 9,
	PERF_COUNT_HW_MAX = 10,
};

enum perf_hw_cache_id {
	PERF_COUNT_HW_CACHE_L1D = 0,
	PERF_COUNT_HW_CACHE_L1I = 1,
	PERF_COUNT_HW_CACHE_LL = 2,
	PERF_COUNT_HW_CACHE_DTLB = 3,
	PERF_COUNT_HW_CACHE_ITLB = 4,
	PERF_COUNT_HW_CACHE_BPU = 5,
	PERF_COUNT_HW_CACHE_NODE = 6,
	PERF_COUNT_HW_CACHE_MAX = 7,
};

enum perf_hw_cache_op_id {
	PERF_COUNT_HW_CACHE_OP_READ = 0,
	PERF_COUNT_HW_CACHE_OP_WRITE = 1,
	PERF_COUNT_HW_CACHE_OP_PREFETCH = 2,
	PERF_COUNT_HW_CACHE_OP_MAX = 3,
};

enum perf_hw_cache_op_result_id {
	PERF_COUNT_HW_CACHE_RESULT_ACCESS = 0,
	PERF_COUNT_HW_CACHE_RESULT_MISS = 1,
	PERF_COUNT_HW_CACHE_RESULT_MAX = 2,
};

enum perf_event_sample_format {
	PERF_SAMPLE_IP = 1,
	PERF_SAMPLE_TID = 2,
	PERF_SAMPLE_TIME = 4,
	PERF_SAMPLE_ADDR = 8,
	PERF_SAMPLE_READ = 16,
	PERF_SAMPLE_CALLCHAIN = 32,
	PERF_SAMPLE_ID = 64,
	PERF_SAMPLE_CPU = 128,
	PERF_SAMPLE_PERIOD = 256,
	PERF_SAMPLE_STREAM_ID = 512,
	PERF_SAMPLE_RAW = 1024,
	PERF_SAMPLE_BRANCH_STACK = 2048,
	PERF_SAMPLE_REGS_USER = 4096,
	PERF_SAMPLE_STACK_USER = 8192,
	PERF_SAMPLE_WEIGHT = 16384,
	PERF_SAMPLE_DATA_SRC = 32768,
	PERF_SAMPLE_IDENTIFIER = 65536,
	PERF_SAMPLE_TRANSACTION = 131072,
	PERF_SAMPLE_REGS_INTR = 262144,
	PERF_SAMPLE_MAX = 524288,
};

enum perf_branch_sample_type {
	PERF_SAMPLE_BRANCH_USER = 1,
	PERF_SAMPLE_BRANCH_KERNEL = 2,
	PERF_SAMPLE_BRANCH_HV = 4,
	PERF_SAMPLE_BRANCH_ANY = 8,
	PERF_SAMPLE_BRANCH_ANY_CALL = 16,
	PERF_SAMPLE_BRANCH_ANY_RETURN = 32,
	PERF_SAMPLE_BRANCH_IND_CALL = 64,
	PERF_SAMPLE_BRANCH_ABORT_TX = 128,
	PERF_SAMPLE_BRANCH_IN_TX = 256,
	PERF_SAMPLE_BRANCH_NO_TX = 512,
	PERF_SAMPLE_BRANCH_COND = 1024,
	PERF_SAMPLE_BRANCH_CALL_STACK = 2048,
	PERF_SAMPLE_BRANCH_MAX = 4096,
};

struct perf_event_mmap_page {
	__u32 version;
	__u32 compat_version;
	__u32 lock;
	__u32 index;
	__s64 offset;
	__u64 time_enabled;
	__u64 time_running;
	union {
		__u64 capabilities;
		struct {
			__u64 cap_bit0: 1;
			__u64 cap_bit0_is_deprecated: 1;
			__u64 cap_user_rdpmc: 1;
			__u64 cap_user_time: 1;
			__u64 cap_user_time_zero: 1;
			__u64 cap_____res: 59;
		};
	};
	__u16 pmc_width;
	__u16 time_shift;
	__u32 time_mult;
	__u64 time_offset;
	__u64 time_zero;
	__u32 size;
	__u8 __reserved[948];
	__u64 data_head;
	__u64 data_tail;
};

struct x86_pmu_capability {
	int version;
	int num_counters_gp;
	int num_counters_fixed;
	int bit_width_gp;
	int bit_width_fixed;
	unsigned int events_mask;
	int events_mask_len;
};

struct stack_frame_ia32 {
	u32 next_frame;
	u32 return_address;
};

struct perf_guest_switch_msr {
	unsigned int msr;
	u64 host;
	u64 guest;
};

struct perf_guest_info_callbacks {
	int (*is_in_guest)();
	int (*is_user_mode)();
	long unsigned int (*get_guest_ip)();
};

enum {
	CPU_PRI_SCHED_ACTIVE = 2147483647,
	CPU_PRI_CPUSET_ACTIVE = 2147483646,
	CPU_PRI_SCHED_INACTIVE = 2147483649,
	CPU_PRI_CPUSET_INACTIVE = 2147483648,
	CPU_PRI_PERF = 20,
	CPU_PRI_MIGRATION = 10,
	CPU_PRI_WORKQUEUE_UP = 5,
	CPU_PRI_WORKQUEUE_DOWN = 4294967291,
};

struct event_constraint {
	union {
		long unsigned int idxmsk[1];
		u64 idxmsk64;
	};
	u64 code;
	u64 cmask;
	int weight;
	int overlap;
	int flags;
};

struct perf_pmu_events_attr {
	struct device_attribute___13 attr;
	u64 id;
	const char *event_str;
};

enum extra_reg_type {
	EXTRA_REG_NONE = 4294967295,
	EXTRA_REG_RSP_0 = 0,
	EXTRA_REG_RSP_1 = 1,
	EXTRA_REG_LBR = 2,
	EXTRA_REG_LDLAT = 3,
	EXTRA_REG_MAX = 4,
};

struct amd_nb {
	int nb_id;
	int refcnt;
	struct perf_event___8 *owners[64];
	struct event_constraint event_constraints[64];
};

struct debug_store {
	u64 bts_buffer_base;
	u64 bts_index;
	u64 bts_absolute_maximum;
	u64 bts_interrupt_threshold;
	u64 pebs_buffer_base;
	u64 pebs_index;
	u64 pebs_absolute_maximum;
	u64 pebs_interrupt_threshold;
	u64 pebs_event_reset[8];
};

struct er_account {
	raw_spinlock_t lock;
	u64 config;
	u64 reg;
	atomic_t ref;
};

struct intel_shared_regs {
	struct er_account regs[4];
	int refcnt;
	unsigned int core_id;
};

enum intel_excl_state_type {
	INTEL_EXCL_UNUSED = 0,
	INTEL_EXCL_SHARED = 1,
	INTEL_EXCL_EXCLUSIVE = 2,
};

struct intel_excl_states {
	enum intel_excl_state_type init_state[64];
	enum intel_excl_state_type state[64];
	bool sched_started;
};

struct intel_excl_cntrs {
	raw_spinlock_t lock;
	struct intel_excl_states states[2];
	union {
		u16 has_exclusive[2];
		u32 exclusive_present;
	};
	int refcnt;
	unsigned int core_id;
};

enum {
	X86_PERF_KFREE_SHARED = 0,
	X86_PERF_KFREE_EXCL = 1,
	X86_PERF_KFREE_MAX = 2,
};

struct cpu_hw_events {
	struct perf_event___8 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___8 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

struct extra_reg {
	unsigned int event;
	unsigned int msr;
	u64 config_mask;
	u64 valid_mask;
	int idx;
	bool extra_msr_access;
};

union perf_capabilities {
	struct {
		u64 lbr_format: 6;
		u64 pebs_trap: 1;
		u64 pebs_arch_reg: 1;
		u64 pebs_format: 4;
		u64 smm_freeze: 1;
		u64 full_width_write: 1;
	};
	u64 capabilities;
};

struct x86_pmu_quirk {
	struct x86_pmu_quirk *next;
	void (*func)();
};

struct x86_pmu {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___8 *);
	void (*disable)(struct perf_event___8 *);
	int (*hw_config)(struct perf_event___8 *);
	int (*schedule_events)(struct cpu_hw_events *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events *, int, struct perf_event___8 *);
	void (*put_event_constraints)(struct cpu_hw_events *, struct perf_event___8 *);
	void (*commit_scheduling)(struct cpu_hw_events *, int, int);
	void (*start_scheduling)(struct cpu_hw_events *);
	void (*stop_scheduling)(struct cpu_hw_events *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___8 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___8 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___8 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

struct sched_state {
	int weight;
	int event;
	int counter;
	int unassigned;
	int nr_gp;
	long unsigned int used[1];
};

struct perf_sched {
	int max_weight;
	int max_events;
	int max_gp;
	int saved_states;
	struct event_constraint **constraints;
	struct sched_state state;
	struct sched_state saved[2];
};

struct amd_uncore {
	int id;
	int refcnt;
	int cpu;
	int num_counters;
	int rdpmc_base;
	u32 msr_base;
	cpumask_t *active_mask;
	struct pmu___8 *pmu;
	struct perf_event___8 *events[4];
	struct amd_uncore *free_when_cpu_online;
};

enum P4_EVENTS {
	P4_EVENT_TC_DELIVER_MODE = 0,
	P4_EVENT_BPU_FETCH_REQUEST = 1,
	P4_EVENT_ITLB_REFERENCE = 2,
	P4_EVENT_MEMORY_CANCEL = 3,
	P4_EVENT_MEMORY_COMPLETE = 4,
	P4_EVENT_LOAD_PORT_REPLAY = 5,
	P4_EVENT_STORE_PORT_REPLAY = 6,
	P4_EVENT_MOB_LOAD_REPLAY = 7,
	P4_EVENT_PAGE_WALK_TYPE = 8,
	P4_EVENT_BSQ_CACHE_REFERENCE = 9,
	P4_EVENT_IOQ_ALLOCATION = 10,
	P4_EVENT_IOQ_ACTIVE_ENTRIES = 11,
	P4_EVENT_FSB_DATA_ACTIVITY = 12,
	P4_EVENT_BSQ_ALLOCATION = 13,
	P4_EVENT_BSQ_ACTIVE_ENTRIES = 14,
	P4_EVENT_SSE_INPUT_ASSIST = 15,
	P4_EVENT_PACKED_SP_UOP = 16,
	P4_EVENT_PACKED_DP_UOP = 17,
	P4_EVENT_SCALAR_SP_UOP = 18,
	P4_EVENT_SCALAR_DP_UOP = 19,
	P4_EVENT_64BIT_MMX_UOP = 20,
	P4_EVENT_128BIT_MMX_UOP = 21,
	P4_EVENT_X87_FP_UOP = 22,
	P4_EVENT_TC_MISC = 23,
	P4_EVENT_GLOBAL_POWER_EVENTS = 24,
	P4_EVENT_TC_MS_XFER = 25,
	P4_EVENT_UOP_QUEUE_WRITES = 26,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE = 27,
	P4_EVENT_RETIRED_BRANCH_TYPE = 28,
	P4_EVENT_RESOURCE_STALL = 29,
	P4_EVENT_WC_BUFFER = 30,
	P4_EVENT_B2B_CYCLES = 31,
	P4_EVENT_BNR = 32,
	P4_EVENT_SNOOP = 33,
	P4_EVENT_RESPONSE = 34,
	P4_EVENT_FRONT_END_EVENT = 35,
	P4_EVENT_EXECUTION_EVENT = 36,
	P4_EVENT_REPLAY_EVENT = 37,
	P4_EVENT_INSTR_RETIRED = 38,
	P4_EVENT_UOPS_RETIRED = 39,
	P4_EVENT_UOP_TYPE = 40,
	P4_EVENT_BRANCH_RETIRED = 41,
	P4_EVENT_MISPRED_BRANCH_RETIRED = 42,
	P4_EVENT_X87_ASSIST = 43,
	P4_EVENT_MACHINE_CLEAR = 44,
	P4_EVENT_INSTR_COMPLETED = 45,
};

enum P4_EVENT_OPCODES {
	P4_EVENT_TC_DELIVER_MODE_OPCODE = 257,
	P4_EVENT_BPU_FETCH_REQUEST_OPCODE = 768,
	P4_EVENT_ITLB_REFERENCE_OPCODE = 6147,
	P4_EVENT_MEMORY_CANCEL_OPCODE = 517,
	P4_EVENT_MEMORY_COMPLETE_OPCODE = 2050,
	P4_EVENT_LOAD_PORT_REPLAY_OPCODE = 1026,
	P4_EVENT_STORE_PORT_REPLAY_OPCODE = 1282,
	P4_EVENT_MOB_LOAD_REPLAY_OPCODE = 770,
	P4_EVENT_PAGE_WALK_TYPE_OPCODE = 260,
	P4_EVENT_BSQ_CACHE_REFERENCE_OPCODE = 3079,
	P4_EVENT_IOQ_ALLOCATION_OPCODE = 774,
	P4_EVENT_IOQ_ACTIVE_ENTRIES_OPCODE = 6662,
	P4_EVENT_FSB_DATA_ACTIVITY_OPCODE = 5894,
	P4_EVENT_BSQ_ALLOCATION_OPCODE = 1287,
	P4_EVENT_BSQ_ACTIVE_ENTRIES_OPCODE = 1543,
	P4_EVENT_SSE_INPUT_ASSIST_OPCODE = 13313,
	P4_EVENT_PACKED_SP_UOP_OPCODE = 2049,
	P4_EVENT_PACKED_DP_UOP_OPCODE = 3073,
	P4_EVENT_SCALAR_SP_UOP_OPCODE = 2561,
	P4_EVENT_SCALAR_DP_UOP_OPCODE = 3585,
	P4_EVENT_64BIT_MMX_UOP_OPCODE = 513,
	P4_EVENT_128BIT_MMX_UOP_OPCODE = 6657,
	P4_EVENT_X87_FP_UOP_OPCODE = 1025,
	P4_EVENT_TC_MISC_OPCODE = 1537,
	P4_EVENT_GLOBAL_POWER_EVENTS_OPCODE = 4870,
	P4_EVENT_TC_MS_XFER_OPCODE = 1280,
	P4_EVENT_UOP_QUEUE_WRITES_OPCODE = 2304,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE_OPCODE = 1282,
	P4_EVENT_RETIRED_BRANCH_TYPE_OPCODE = 1026,
	P4_EVENT_RESOURCE_STALL_OPCODE = 257,
	P4_EVENT_WC_BUFFER_OPCODE = 1285,
	P4_EVENT_B2B_CYCLES_OPCODE = 5635,
	P4_EVENT_BNR_OPCODE = 2051,
	P4_EVENT_SNOOP_OPCODE = 1539,
	P4_EVENT_RESPONSE_OPCODE = 1027,
	P4_EVENT_FRONT_END_EVENT_OPCODE = 2053,
	P4_EVENT_EXECUTION_EVENT_OPCODE = 3077,
	P4_EVENT_REPLAY_EVENT_OPCODE = 2309,
	P4_EVENT_INSTR_RETIRED_OPCODE = 516,
	P4_EVENT_UOPS_RETIRED_OPCODE = 260,
	P4_EVENT_UOP_TYPE_OPCODE = 514,
	P4_EVENT_BRANCH_RETIRED_OPCODE = 1541,
	P4_EVENT_MISPRED_BRANCH_RETIRED_OPCODE = 772,
	P4_EVENT_X87_ASSIST_OPCODE = 773,
	P4_EVENT_MACHINE_CLEAR_OPCODE = 517,
	P4_EVENT_INSTR_COMPLETED_OPCODE = 1796,
};

enum P4_ESCR_EMASKS {
	P4_EVENT_TC_DELIVER_MODE__DD = 512,
	P4_EVENT_TC_DELIVER_MODE__DB = 1024,
	P4_EVENT_TC_DELIVER_MODE__DI = 2048,
	P4_EVENT_TC_DELIVER_MODE__BD = 4096,
	P4_EVENT_TC_DELIVER_MODE__BB = 8192,
	P4_EVENT_TC_DELIVER_MODE__BI = 16384,
	P4_EVENT_TC_DELIVER_MODE__ID = 32768,
	P4_EVENT_BPU_FETCH_REQUEST__TCMISS = 512,
	P4_EVENT_ITLB_REFERENCE__HIT = 512,
	P4_EVENT_ITLB_REFERENCE__MISS = 1024,
	P4_EVENT_ITLB_REFERENCE__HIT_UK = 2048,
	P4_EVENT_MEMORY_CANCEL__ST_RB_FULL = 2048,
	P4_EVENT_MEMORY_CANCEL__64K_CONF = 4096,
	P4_EVENT_MEMORY_COMPLETE__LSC = 512,
	P4_EVENT_MEMORY_COMPLETE__SSC = 1024,
	P4_EVENT_LOAD_PORT_REPLAY__SPLIT_LD = 1024,
	P4_EVENT_STORE_PORT_REPLAY__SPLIT_ST = 1024,
	P4_EVENT_MOB_LOAD_REPLAY__NO_STA = 1024,
	P4_EVENT_MOB_LOAD_REPLAY__NO_STD = 4096,
	P4_EVENT_MOB_LOAD_REPLAY__PARTIAL_DATA = 8192,
	P4_EVENT_MOB_LOAD_REPLAY__UNALGN_ADDR = 16384,
	P4_EVENT_PAGE_WALK_TYPE__DTMISS = 512,
	P4_EVENT_PAGE_WALK_TYPE__ITMISS = 1024,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITS = 512,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITE = 1024,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITM = 2048,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITS = 4096,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITE = 8192,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITM = 16384,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_MISS = 131072,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_MISS = 262144,
	P4_EVENT_BSQ_CACHE_REFERENCE__WR_2ndL_MISS = 524288,
	P4_EVENT_IOQ_ALLOCATION__DEFAULT = 512,
	P4_EVENT_IOQ_ALLOCATION__ALL_READ = 16384,
	P4_EVENT_IOQ_ALLOCATION__ALL_WRITE = 32768,
	P4_EVENT_IOQ_ALLOCATION__MEM_UC = 65536,
	P4_EVENT_IOQ_ALLOCATION__MEM_WC = 131072,
	P4_EVENT_IOQ_ALLOCATION__MEM_WT = 262144,
	P4_EVENT_IOQ_ALLOCATION__MEM_WP = 524288,
	P4_EVENT_IOQ_ALLOCATION__MEM_WB = 1048576,
	P4_EVENT_IOQ_ALLOCATION__OWN = 4194304,
	P4_EVENT_IOQ_ALLOCATION__OTHER = 8388608,
	P4_EVENT_IOQ_ALLOCATION__PREFETCH = 16777216,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__DEFAULT = 512,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__ALL_READ = 16384,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__ALL_WRITE = 32768,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_UC = 65536,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WC = 131072,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WT = 262144,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WP = 524288,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WB = 1048576,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__OWN = 4194304,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__OTHER = 8388608,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__PREFETCH = 16777216,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_DRV = 512,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_OWN = 1024,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_OTHER = 2048,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_DRV = 4096,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_OWN = 8192,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_OTHER = 16384,
	P4_EVENT_BSQ_ALLOCATION__REQ_TYPE0 = 512,
	P4_EVENT_BSQ_ALLOCATION__REQ_TYPE1 = 1024,
	P4_EVENT_BSQ_ALLOCATION__REQ_LEN0 = 2048,
	P4_EVENT_BSQ_ALLOCATION__REQ_LEN1 = 4096,
	P4_EVENT_BSQ_ALLOCATION__REQ_IO_TYPE = 16384,
	P4_EVENT_BSQ_ALLOCATION__REQ_LOCK_TYPE = 32768,
	P4_EVENT_BSQ_ALLOCATION__REQ_CACHE_TYPE = 65536,
	P4_EVENT_BSQ_ALLOCATION__REQ_SPLIT_TYPE = 131072,
	P4_EVENT_BSQ_ALLOCATION__REQ_DEM_TYPE = 262144,
	P4_EVENT_BSQ_ALLOCATION__REQ_ORD_TYPE = 524288,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE0 = 1048576,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE1 = 2097152,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE2 = 4194304,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_TYPE0 = 512,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_TYPE1 = 1024,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LEN0 = 2048,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LEN1 = 4096,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_IO_TYPE = 16384,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LOCK_TYPE = 32768,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_CACHE_TYPE = 65536,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_SPLIT_TYPE = 131072,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_DEM_TYPE = 262144,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_ORD_TYPE = 524288,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE0 = 1048576,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE1 = 2097152,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE2 = 4194304,
	P4_EVENT_SSE_INPUT_ASSIST__ALL = 16777216,
	P4_EVENT_PACKED_SP_UOP__ALL = 16777216,
	P4_EVENT_PACKED_DP_UOP__ALL = 16777216,
	P4_EVENT_SCALAR_SP_UOP__ALL = 16777216,
	P4_EVENT_SCALAR_DP_UOP__ALL = 16777216,
	P4_EVENT_64BIT_MMX_UOP__ALL = 16777216,
	P4_EVENT_128BIT_MMX_UOP__ALL = 16777216,
	P4_EVENT_X87_FP_UOP__ALL = 16777216,
	P4_EVENT_TC_MISC__FLUSH = 8192,
	P4_EVENT_GLOBAL_POWER_EVENTS__RUNNING = 512,
	P4_EVENT_TC_MS_XFER__CISC = 512,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_TC_BUILD = 512,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_TC_DELIVER = 1024,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_ROM = 2048,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__CONDITIONAL = 1024,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__CALL = 2048,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__RETURN = 4096,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__INDIRECT = 8192,
	P4_EVENT_RETIRED_BRANCH_TYPE__CONDITIONAL = 1024,
	P4_EVENT_RETIRED_BRANCH_TYPE__CALL = 2048,
	P4_EVENT_RETIRED_BRANCH_TYPE__RETURN = 4096,
	P4_EVENT_RETIRED_BRANCH_TYPE__INDIRECT = 8192,
	P4_EVENT_RESOURCE_STALL__SBFULL = 16384,
	P4_EVENT_WC_BUFFER__WCB_EVICTS = 512,
	P4_EVENT_WC_BUFFER__WCB_FULL_EVICTS = 1024,
	P4_EVENT_FRONT_END_EVENT__NBOGUS = 512,
	P4_EVENT_FRONT_END_EVENT__BOGUS = 1024,
	P4_EVENT_EXECUTION_EVENT__NBOGUS0 = 512,
	P4_EVENT_EXECUTION_EVENT__NBOGUS1 = 1024,
	P4_EVENT_EXECUTION_EVENT__NBOGUS2 = 2048,
	P4_EVENT_EXECUTION_EVENT__NBOGUS3 = 4096,
	P4_EVENT_EXECUTION_EVENT__BOGUS0 = 8192,
	P4_EVENT_EXECUTION_EVENT__BOGUS1 = 16384,
	P4_EVENT_EXECUTION_EVENT__BOGUS2 = 32768,
	P4_EVENT_EXECUTION_EVENT__BOGUS3 = 65536,
	P4_EVENT_REPLAY_EVENT__NBOGUS = 512,
	P4_EVENT_REPLAY_EVENT__BOGUS = 1024,
	P4_EVENT_INSTR_RETIRED__NBOGUSNTAG = 512,
	P4_EVENT_INSTR_RETIRED__NBOGUSTAG = 1024,
	P4_EVENT_INSTR_RETIRED__BOGUSNTAG = 2048,
	P4_EVENT_INSTR_RETIRED__BOGUSTAG = 4096,
	P4_EVENT_UOPS_RETIRED__NBOGUS = 512,
	P4_EVENT_UOPS_RETIRED__BOGUS = 1024,
	P4_EVENT_UOP_TYPE__TAGLOADS = 1024,
	P4_EVENT_UOP_TYPE__TAGSTORES = 2048,
	P4_EVENT_BRANCH_RETIRED__MMNP = 512,
	P4_EVENT_BRANCH_RETIRED__MMNM = 1024,
	P4_EVENT_BRANCH_RETIRED__MMTP = 2048,
	P4_EVENT_BRANCH_RETIRED__MMTM = 4096,
	P4_EVENT_MISPRED_BRANCH_RETIRED__NBOGUS = 512,
	P4_EVENT_X87_ASSIST__FPSU = 512,
	P4_EVENT_X87_ASSIST__FPSO = 1024,
	P4_EVENT_X87_ASSIST__POAO = 2048,
	P4_EVENT_X87_ASSIST__POAU = 4096,
	P4_EVENT_X87_ASSIST__PREA = 8192,
	P4_EVENT_MACHINE_CLEAR__CLEAR = 512,
	P4_EVENT_MACHINE_CLEAR__MOCLEAR = 1024,
	P4_EVENT_MACHINE_CLEAR__SMCLEAR = 2048,
	P4_EVENT_INSTR_COMPLETED__NBOGUS = 512,
	P4_EVENT_INSTR_COMPLETED__BOGUS = 1024,
};

enum P4_PEBS_METRIC {
	P4_PEBS_METRIC__none = 0,
	P4_PEBS_METRIC__1stl_cache_load_miss_retired = 1,
	P4_PEBS_METRIC__2ndl_cache_load_miss_retired = 2,
	P4_PEBS_METRIC__dtlb_load_miss_retired = 3,
	P4_PEBS_METRIC__dtlb_store_miss_retired = 4,
	P4_PEBS_METRIC__dtlb_all_miss_retired = 5,
	P4_PEBS_METRIC__tagged_mispred_branch = 6,
	P4_PEBS_METRIC__mob_load_replay_retired = 7,
	P4_PEBS_METRIC__split_load_retired = 8,
	P4_PEBS_METRIC__split_store_retired = 9,
	P4_PEBS_METRIC__max = 10,
};

struct p4_event_bind {
	unsigned int opcode;
	unsigned int escr_msr[2];
	unsigned int escr_emask;
	unsigned int shared;
	char cntr[6];
};

struct p4_pebs_bind {
	unsigned int metric_pebs;
	unsigned int metric_vert;
};

struct p4_event_alias {
	u64 original;
	u64 alternative;
};

typedef unsigned int insn_attr_t;

typedef unsigned char insn_byte_t;

typedef int insn_value_t;

struct insn_field {
	union {
		insn_value_t value;
		insn_byte_t bytes[4];
	};
	unsigned char got;
	unsigned char nbytes;
};

struct insn {
	struct insn_field prefixes;
	struct insn_field rex_prefix;
	struct insn_field vex_prefix;
	struct insn_field opcode;
	struct insn_field modrm;
	struct insn_field sib;
	struct insn_field displacement;
	union {
		struct insn_field immediate;
		struct insn_field moffset1;
		struct insn_field immediate1;
	};
	union {
		struct insn_field moffset2;
		struct insn_field immediate2;
	};
	insn_attr_t attr;
	unsigned char opnd_bytes;
	unsigned char addr_bytes;
	unsigned char length;
	unsigned char x86_64;
	const insn_byte_t *kaddr;
	const insn_byte_t *end_kaddr;
	const insn_byte_t *next_byte;
};

struct x86_perf_task_context {
	u64 lbr_from[32];
	u64 lbr_to[32];
	u64 lbr_info[32];
	int lbr_callstack_users;
	int lbr_stack_state;
};

enum {
	LBR_FORMAT_32 = 0,
	LBR_FORMAT_LIP = 1,
	LBR_FORMAT_EIP = 2,
	LBR_FORMAT_EIP_FLAGS = 3,
	LBR_FORMAT_EIP_FLAGS2 = 4,
	LBR_FORMAT_INFO = 5,
	LBR_FORMAT_MAX_KNOWN = 5,
};

enum {
	X86_BR_NONE = 0,
	X86_BR_USER = 1,
	X86_BR_KERNEL = 2,
	X86_BR_CALL = 4,
	X86_BR_RET = 8,
	X86_BR_SYSCALL = 16,
	X86_BR_SYSRET = 32,
	X86_BR_INT = 64,
	X86_BR_IRET = 128,
	X86_BR_JCC = 256,
	X86_BR_JMP = 512,
	X86_BR_IRQ = 1024,
	X86_BR_IND_CALL = 2048,
	X86_BR_ABORT = 4096,
	X86_BR_IN_TX = 8192,
	X86_BR_NO_TX = 16384,
	X86_BR_ZERO_CALL = 32768,
	X86_BR_CALL_STACK = 65536,
};

enum {
	LBR_NONE = 0,
	LBR_VALID = 1,
};

struct page___21;

typedef struct page___21 *pgtable_t___21;

struct address_space___21;

struct kmem_cache___18;

struct page___21 {
	long unsigned int flags;
	struct address_space___21 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___21 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___21 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___18 *slab_cache;
		struct page___21 *first_page;
	};
	long: 64;
};

struct thread_struct___10;

struct task_struct___22;

struct pv_cpu_ops___21 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___10 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___10 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___22 *);
	void (*end_context_switch)(struct task_struct___22 *);
};

struct perf_event___10;

struct thread_struct___10 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___10 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___11;

struct pid_link___11 {
	struct hlist_node node;
	struct pid___11 *pid;
};

struct mutex___22 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___22 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___19 {
	struct page___21 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___24;

struct nsproxy___11;

struct signal_struct___21;

struct css_set___10;

struct perf_event_context___10;

struct task_struct___22 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___22 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___24 *mm;
	struct mm_struct___24 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___22 *real_parent;
	struct task_struct___22 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___22 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___11 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___21 = 0,
		VTIME_USER___21 = 1,
		VTIME_SYS___21 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___10 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___11 *nsproxy;
	struct signal_struct___21 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___10 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___10 *perf_event_ctxp[2];
	struct mutex___22 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___19 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___24 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___24 *, struct mm_struct___24 *);
	void (*dup_mmap)(struct mm_struct___24 *, struct mm_struct___24 *);
	void (*exit_mmap)(struct mm_struct___24 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___24 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___24 *);
	void (*pgd_free)(struct mm_struct___24 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___24 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___24 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___24 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___24 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___24 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___24 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___24 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___24 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___24 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___24 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___24 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___22 lock;
	void *vdso;
} mm_context_t___22;

struct xol_area___21;

struct uprobes_state___21 {
	struct xol_area___21 *xol_area;
};

struct vm_area_struct___24;

struct file___21;

struct core_state___21;

struct mm_struct___24 {
	struct vm_area_struct___24 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___24 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___24 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___22 context;
	long unsigned int flags;
	struct core_state___21 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___22 *owner;
	struct file___21 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___21 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___10 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___22 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___22 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___22 *target;
};

typedef void (*perf_overflow_handler_t___10)(struct perf_event___10 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___10;

typedef void (*ftrace_func_t___10)(long unsigned int, long unsigned int, struct ftrace_ops___10 *, struct pt_regs *);

struct ftrace_ops___10 {
	ftrace_func_t___10 func;
	struct ftrace_ops___10 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___22 regex_lock;
};

struct pmu___10;

struct fasync_struct___21;

struct pid_namespace___11;

struct perf_cgroup___10;

struct perf_event___10 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___10 *group_leader;
	struct pmu___10 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___10 hw;
	struct perf_event_context___10 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___22 child_mutex;
	struct list_head child_list;
	struct perf_event___10 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___22 *owner;
	struct mutex___22 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___21 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___10 *);
	struct callback_head callback_head;
	struct pid_namespace___11 *ns;
	u64 id;
	perf_overflow_handler_t___10 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___10 ftrace_ops;
	struct perf_cgroup___10 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___12 {
	struct task_struct___22 *task;
	struct exec_domain___7 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___21;

struct lruvec___21 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___21 *zone;
};

struct pglist_data___21;

struct zone___21 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___21 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___21 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___21 {
	struct zone___21 *zone;
	int zone_idx;
};

struct zonelist___21 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___21 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___21 {
	struct zone___21 node_zones[4];
	struct zonelist___21 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___22 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___17;

struct dev_pm_ops___17 {
	int (*prepare)(struct device___17 *);
	void (*complete)(struct device___17 *);
	int (*suspend)(struct device___17 *);
	int (*resume)(struct device___17 *);
	int (*freeze)(struct device___17 *);
	int (*thaw)(struct device___17 *);
	int (*poweroff)(struct device___17 *);
	int (*restore)(struct device___17 *);
	int (*suspend_late)(struct device___17 *);
	int (*resume_early)(struct device___17 *);
	int (*freeze_late)(struct device___17 *);
	int (*thaw_early)(struct device___17 *);
	int (*poweroff_late)(struct device___17 *);
	int (*restore_early)(struct device___17 *);
	int (*suspend_noirq)(struct device___17 *);
	int (*resume_noirq)(struct device___17 *);
	int (*freeze_noirq)(struct device___17 *);
	int (*thaw_noirq)(struct device___17 *);
	int (*poweroff_noirq)(struct device___17 *);
	int (*restore_noirq)(struct device___17 *);
	int (*runtime_suspend)(struct device___17 *);
	int (*runtime_resume)(struct device___17 *);
	int (*runtime_idle)(struct device___17 *);
};

struct device_type___17;

struct bus_type___17;

struct device_driver___17;

struct dev_pm_domain___17;

struct class___17;

struct attribute_group___15;

struct device_rh___17;

struct device___17 {
	struct device___17 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___17 *type;
	struct mutex___22 mutex;
	struct bus_type___17 *bus;
	struct device_driver___17 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___17 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___7 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___6 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___17 *class;
	const struct attribute_group___15 **groups;
	void (*release)(struct device___17 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___17 *device_rh;
};

struct dev_pm_info_rh___17 {
	void (*set_latency_tolerance)(struct device___17 *, s32);
};

struct dev_pm_domain___17 {
	struct dev_pm_ops___17 ops;
};

struct smp_ops___21 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___22 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___15;

struct attribute_group___15 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___15 **bin_attrs;
};

struct bin_attribute___15 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___21 *, struct kobject *, struct bin_attribute___15 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___21 *, struct kobject *, struct bin_attribute___15 *, char *, loff_t, size_t);
	int (*mmap)(struct file___21 *, struct kobject *, struct bin_attribute___15 *, struct vm_area_struct___24 *);
};

struct dentry___22;

struct path___21 {
	struct vfsmount *mnt;
	struct dentry___22 *dentry;
};

struct fown_struct___11 {
	rwlock_t lock;
	struct pid___11 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___22;

struct file_operations___21;

struct file___21 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___21 f_path;
	struct inode___22 *f_inode;
	const struct file_operations___21 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___11 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___21 *f_mapping;
	struct mutex___22 f_pos_lock;
};

struct vm_operations_struct___18;

struct vm_area_struct___24 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___24 *vm_next;
	struct vm_area_struct___24 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___24 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___18 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___21 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___18 {
	void **freelist;
	long unsigned int tid;
	struct page___21 *page;
	struct page___21 *partial;
};

struct memcg_cache_params___18;

struct kmem_cache___18 {
	struct kmem_cache_cpu___18 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___18 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___18 {
	bool is_root_cache;
	union {
		struct kmem_cache___18 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___18 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___21 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___21 *page;
	long unsigned int vaddr;
};

struct address_space_operations___21;

struct address_space___21 {
	struct inode___22 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___22 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___21 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___16;

struct vm_operations_struct___18 {
	void (*open)(struct vm_area_struct___24 *);
	void (*close)(struct vm_area_struct___24 *);
	int (*fault)(struct vm_area_struct___24 *, struct vm_fault___16 *);
	int (*page_mkwrite)(struct vm_area_struct___24 *, struct vm_fault___16 *);
	int (*access)(struct vm_area_struct___24 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___24 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___24 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___24 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___24 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___21 {
	struct task_struct___22 *task;
	struct core_thread___21 *next;
};

struct core_state___21 {
	atomic_t nr_threads;
	struct core_thread___21 dumper;
	struct completion startup;
};

struct upid___11 {
	int nr;
	struct pid_namespace___11 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___11 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___22 *child_reaper;
	struct kmem_cache___18 *pid_cachep;
	unsigned int level;
	struct pid_namespace___11 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___22 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___11 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___11 numbers[1];
};

struct nsproxy___11 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___11 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___21 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___22 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___22 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___11 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___11 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___22 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___10;

struct css_set___10 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___10 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___10 {
	struct pmu___10 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___22 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___22 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___10 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

enum {
	PERF_TXN_ELISION = 1,
	PERF_TXN_TRANSACTION = 2,
	PERF_TXN_SYNC = 4,
	PERF_TXN_ASYNC = 8,
	PERF_TXN_RETRY = 16,
	PERF_TXN_CONFLICT = 32,
	PERF_TXN_CAPACITY_WRITE = 64,
	PERF_TXN_CAPACITY_READ = 128,
	PERF_TXN_MAX = 256,
	PERF_TXN_ABORT_MASK = 0,
	PERF_TXN_ABORT_SHIFT = 32,
};

struct perf_event_header {
	__u32 type;
	__u16 misc;
	__u16 size;
};

struct dentry_operations___21;

struct super_block___22;

struct dentry___22 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___22 *d_parent;
	struct qstr d_name;
	struct inode___22 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___21 *d_op;
	struct super_block___22 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___21;

struct file_lock___21;

struct dquot___21;

struct block_device___21;

struct inode___22 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___21 *i_op;
	struct super_block___22 *i_sb;
	struct address_space___21 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___22 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___21 *i_fop;
	struct file_lock___21 *i_flock;
	struct address_space___21 i_data;
	struct dquot___21 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___21 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___21 {
	int (*d_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_hash)(const struct dentry___22 *, struct qstr *);
	int (*d_compare)(const struct dentry___22 *, const struct dentry___22 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___22 *);
	void (*d_release)(struct dentry___22 *);
	void (*d_prune)(struct dentry___22 *);
	void (*d_iput)(struct dentry___22 *, struct inode___22 *);
	char * (*d_dname)(struct dentry___22 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___21 *);
	int (*d_manage)(struct dentry___22 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___21;

struct mem_dqinfo___21 {
	struct quota_format_type___21 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___21;

struct quota_info___21 {
	unsigned int flags;
	struct mutex___22 dqio_mutex;
	struct mutex___22 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___22 *files[2];
	struct mem_dqinfo___21 info[2];
	const struct quota_format_ops___21 *ops[2];
};

struct file_system_type___21;

struct super_operations___21;

struct dquot_operations___21;

struct quotactl_ops___21;

struct xattr_handler___10;

struct super_block___22 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___21 *s_type;
	const struct super_operations___21 *s_op;
	const struct dquot_operations___21 *dq_op;
	const struct quotactl_ops___21 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___22 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___10 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___21 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___21 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___22 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___21 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___21 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___22 *bd_inode;
	struct super_block___22 *bd_super;
	struct mutex___22 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___21 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___22 bd_fsfreeze_mutex;
};

struct cgroup___10;

struct cgroup_subsys_state___10 {
	struct cgroup___10 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___22 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___21 *ia_file;
};

struct dquot___21 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___22 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___22 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___21 {
	int qf_fmt_id;
	const struct quota_format_ops___21 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___21 *qf_next;
};

struct quota_format_ops___21 {
	int (*check_quota_file)(struct super_block___22 *, int);
	int (*read_file_info)(struct super_block___22 *, int);
	int (*write_file_info)(struct super_block___22 *, int);
	int (*free_file_info)(struct super_block___22 *, int);
	int (*read_dqblk)(struct dquot___21 *);
	int (*commit_dqblk)(struct dquot___21 *);
	int (*release_dqblk)(struct dquot___21 *);
};

struct dquot_operations___21 {
	int (*write_dquot)(struct dquot___21 *);
	struct dquot___21 * (*alloc_dquot)(struct super_block___22 *, int);
	void (*destroy_dquot)(struct dquot___21 *);
	int (*acquire_dquot)(struct dquot___21 *);
	int (*release_dquot)(struct dquot___21 *);
	int (*mark_dirty)(struct dquot___21 *);
	int (*write_info)(struct super_block___22 *, int);
	qsize_t * (*get_reserved_space)(struct inode___22 *);
};

struct quotactl_ops___21 {
	int (*quota_on)(struct super_block___22 *, int, int, struct path___21 *);
	int (*quota_on_meta)(struct super_block___22 *, int, int);
	int (*quota_off)(struct super_block___22 *, int);
	int (*quota_sync)(struct super_block___22 *, int);
	int (*get_info)(struct super_block___22 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___22 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___22 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___22 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___22 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___22 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___22 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___22 *, unsigned int);
};

struct address_space_operations___21 {
	int (*writepage)(struct page___21 *, struct writeback_control *);
	int (*readpage)(struct file___21 *, struct page___21 *);
	int (*writepages)(struct address_space___21 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___21 *);
	int (*readpages)(struct file___21 *, struct address_space___21 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___21 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___21 **, void **);
	int (*write_end)(struct file___21 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___21 *, void *);
	sector_t (*bmap)(struct address_space___21 *, sector_t);
	void (*invalidatepage)(struct page___21 *, long unsigned int);
	int (*releasepage)(struct page___21 *, gfp_t);
	void (*freepage)(struct page___21 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___21 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___21 *, struct page___21 *, struct page___21 *, enum migrate_mode);
	int (*launder_page)(struct page___21 *);
	int (*is_partially_uptodate)(struct page___21 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___21 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___21 *, struct page___21 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___21 *, sector_t *);
	void (*swap_deactivate)(struct file___21 *);
	void (*invalidatepage_range)(struct page___21 *, unsigned int, unsigned int);
};

struct inode_operations___21 {
	struct dentry___22 * (*lookup)(struct inode___22 *, struct dentry___22 *, unsigned int);
	void * (*follow_link)(struct dentry___22 *, struct nameidata *);
	int (*permission)(struct inode___22 *, int);
	struct posix_acl * (*get_acl)(struct inode___22 *, int);
	int (*readlink)(struct dentry___22 *, char *, int);
	void (*put_link)(struct dentry___22 *, struct nameidata *, void *);
	int (*create)(struct inode___22 *, struct dentry___22 *, umode_t, bool);
	int (*link)(struct dentry___22 *, struct inode___22 *, struct dentry___22 *);
	int (*unlink)(struct inode___22 *, struct dentry___22 *);
	int (*symlink)(struct inode___22 *, struct dentry___22 *, const char *);
	int (*mkdir)(struct inode___22 *, struct dentry___22 *, umode_t);
	int (*rmdir)(struct inode___22 *, struct dentry___22 *);
	int (*mknod)(struct inode___22 *, struct dentry___22 *, umode_t, dev_t);
	int (*rename)(struct inode___22 *, struct dentry___22 *, struct inode___22 *, struct dentry___22 *);
	int (*setattr)(struct dentry___22 *, struct iattr___22 *);
	int (*getattr)(struct vfsmount *, struct dentry___22 *, struct kstat *);
	int (*setxattr)(struct dentry___22 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___22 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___22 *, char *, size_t);
	int (*removexattr)(struct dentry___22 *, const char *);
	int (*fiemap)(struct inode___22 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___22 *, struct timespec *, int);
	int (*atomic_open)(struct inode___22 *, struct dentry___22 *, struct file___21 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___21 {
	struct module *owner;
	loff_t (*llseek)(struct file___21 *, loff_t, int);
	ssize_t (*read)(struct file___21 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___21 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___21 *, void *, filldir_t);
	unsigned int (*poll)(struct file___21 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___21 *, struct vm_area_struct___24 *);
	int (*open)(struct inode___22 *, struct file___21 *);
	int (*flush)(struct file___21 *, fl_owner_t);
	int (*release)(struct inode___22 *, struct file___21 *);
	int (*fsync)(struct file___21 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___21 *, int);
	int (*lock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*sendpage)(struct file___21 *, struct page___21 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___21 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___21 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___21 *, long int, struct file_lock___21 **, void **);
		struct {
			int (*setlease)(struct file___21 *, long int, struct file_lock___21 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___21 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___21 *);
};

struct file_lock_operations___21;

struct lock_manager_operations___21;

struct file_lock___21 {
	struct file_lock___21 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___11 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___21 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___21 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___21 *fl_ops;
	const struct lock_manager_operations___21 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___21 {
	void (*fl_copy_lock)(struct file_lock___21 *, struct file_lock___21 *);
	void (*fl_release_private)(struct file_lock___21 *);
};

struct lock_manager_operations___21 {
	int (*lm_compare_owner)(struct file_lock___21 *, struct file_lock___21 *);
	long unsigned int (*lm_owner_key)(struct file_lock___21 *);
	void (*lm_notify)(struct file_lock___21 *);
	int (*lm_grant)(struct file_lock___21 *, struct file_lock___21 *, int);
	void (*lm_break)(struct file_lock___21 *);
	int (*lm_change)(struct file_lock___21 **, int);
};

struct fasync_struct___21 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___21 *fa_next;
	struct file___21 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___21 {
	const char *name;
	int fs_flags;
	struct dentry___22 * (*mount)(struct file_system_type___21 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___22 *);
	struct module *owner;
	struct file_system_type___21 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___21 {
	struct inode___22 * (*alloc_inode)(struct super_block___22 *);
	void (*destroy_inode)(struct inode___22 *);
	void (*dirty_inode)(struct inode___22 *, int);
	int (*write_inode)(struct inode___22 *, struct writeback_control *);
	int (*drop_inode)(struct inode___22 *);
	void (*evict_inode)(struct inode___22 *);
	void (*put_super)(struct super_block___22 *);
	int (*sync_fs)(struct super_block___22 *, int);
	int (*freeze_fs)(struct super_block___22 *);
	int (*unfreeze_fs)(struct super_block___22 *);
	int (*statfs)(struct dentry___22 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___22 *, int *, char *);
	void (*umount_begin)(struct super_block___22 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___22 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___22 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___22 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___22 *);
	ssize_t (*quota_read)(struct super_block___22 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___22 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___22 *);
	int (*bdev_try_to_free_page)(struct super_block___22 *, struct page___21 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___22 *);
	void (*free_cached_objects)(struct super_block___22 *, int);
};

struct xattr_handler___10 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___22 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___22 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___22 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___16 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___21 *page;
};

struct bus_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___17 *, char *);
	ssize_t (*store)(struct bus_type___17 *, const char *, size_t);
};

struct device_attribute___17;

struct driver_attribute___17;

struct bus_type___17 {
	const char *name;
	const char *dev_name;
	struct device___17 *dev_root;
	struct bus_attribute___17 *bus_attrs;
	struct device_attribute___17 *dev_attrs;
	struct driver_attribute___17 *drv_attrs;
	const struct attribute_group___15 **bus_groups;
	const struct attribute_group___15 **dev_groups;
	const struct attribute_group___15 **drv_groups;
	int (*match)(struct device___17 *, struct device_driver___17 *);
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	int (*probe)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*online)(struct device___17 *);
	int (*offline)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct device___17 *, struct device_attribute___17 *, char *);
	ssize_t (*store)(struct device___17 *, struct device_attribute___17 *, const char *, size_t);
};

struct driver_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___17 *, char *);
	ssize_t (*store)(struct device_driver___17 *, const char *, size_t);
};

struct device_driver___17 {
	const char *name;
	struct bus_type___17 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct attribute_group___15 **groups;
	const struct dev_pm_ops___17 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___17 {
	const char *name;
	const struct attribute_group___15 **groups;
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
};

struct class_attribute___17;

struct class___17 {
	const char *name;
	struct module *owner;
	struct class_attribute___17 *class_attrs;
	struct device_attribute___17 *dev_attrs;
	const struct attribute_group___15 **dev_groups;
	struct bin_attribute___15 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *);
	void (*class_release)(struct class___17 *);
	void (*dev_release)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	struct subsys_private *p;
};

struct class_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct class___17 *, struct class_attribute___17 *, char *);
	ssize_t (*store)(struct class___17 *, struct class_attribute___17 *, const char *, size_t);
	const void * (*namespace)(struct class___17 *, const struct class_attribute___17 *);
};

struct device_rh___17 {
	struct dev_pm_info_rh___17 power;
};

struct cgroupfs_root___10;

struct cgroup___10 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___10 *parent;
	struct dentry___22 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___10 *subsys[11];
	struct cgroupfs_root___10 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___22 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___10 {
	struct super_block___22 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___10 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___10;

struct pmu___10 {
	struct list_head entry;
	struct device___17 *dev;
	const struct attribute_group___15 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___10 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___10 *);
	void (*pmu_disable)(struct pmu___10 *);
	int (*event_init)(struct perf_event___10 *);
	int (*add)(struct perf_event___10 *, int);
	void (*del)(struct perf_event___10 *, int);
	void (*start)(struct perf_event___10 *, int);
	void (*stop)(struct perf_event___10 *, int);
	void (*read)(struct perf_event___10 *);
	void (*start_txn)(struct pmu___10 *);
	int (*commit_txn)(struct pmu___10 *);
	void (*cancel_txn)(struct pmu___10 *);
	int (*event_idx)(struct perf_event___10 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___10 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___10 *);
};

struct perf_cpu_context___10 {
	struct perf_event_context___10 ctx;
	struct perf_event_context___10 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___10 *unique_pmu;
	struct perf_cgroup___10 *cgrp;
};

struct perf_cgroup___10 {
	struct cgroup_subsys_state___10 css;
	struct perf_cgroup_info *info;
};

struct perf_output_handle {
	struct perf_event___10 *event;
	struct ring_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	void *addr;
	int page;
};

struct amd_nb___2 {
	int nb_id;
	int refcnt;
	struct perf_event___10 *owners[64];
	struct event_constraint event_constraints[64];
};

struct cpu_hw_events___2 {
	struct perf_event___10 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___10 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb___2 *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

struct x86_pmu___2 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___10 *);
	void (*disable)(struct perf_event___10 *);
	int (*hw_config)(struct perf_event___10 *);
	int (*schedule_events)(struct cpu_hw_events___2 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___2 *, int, struct perf_event___10 *);
	void (*put_event_constraints)(struct cpu_hw_events___2 *, struct perf_event___10 *);
	void (*commit_scheduling)(struct cpu_hw_events___2 *, int, int);
	void (*start_scheduling)(struct cpu_hw_events___2 *);
	void (*stop_scheduling)(struct cpu_hw_events___2 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___10 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___10 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___10 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

union intel_x86_pebs_dse {
	u64 val;
	struct {
		unsigned int ld_dse: 4;
		unsigned int ld_stlb_miss: 1;
		unsigned int ld_locked: 1;
		unsigned int ld_reserved: 26;
	};
	struct {
		unsigned int st_l1d_hit: 1;
		unsigned int st_reserved1: 3;
		unsigned int st_stlb_miss: 1;
		unsigned int st_locked: 1;
		unsigned int st_reserved2: 26;
	};
};

struct pebs_record_core {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
};

struct pebs_record_nhm {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
	u64 status;
	u64 dla;
	u64 dse;
	u64 lat;
};

struct pebs_record_hsw {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
	u64 status;
	u64 dla;
	u64 dse;
	u64 lat;
	u64 real_ip;
	u64 tsx_tuning;
};

union hsw_tsx_tuning {
	struct {
		u32 cycles_last_block: 32;
		u32 hle_abort: 1;
		u32 rtm_abort: 1;
		u32 instruction_abort: 1;
		u32 non_instruction_abort: 1;
		u32 retry: 1;
		u32 data_conflict: 1;
		u32 capacity_writes: 1;
		u32 capacity_reads: 1;
	};
	u64 value;
};

struct bts_record {
	u64 from;
	u64 to;
	u64 flags;
};

struct page___22;

typedef struct page___22 *pgtable_t___22;

struct address_space___22;

struct kmem_cache___19;

struct page___22 {
	long unsigned int flags;
	struct address_space___22 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___22 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___22 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___19 *slab_cache;
		struct page___22 *first_page;
	};
	long: 64;
};

struct thread_struct___11;

struct task_struct___23;

struct pv_cpu_ops___22 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___11 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___11 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___23 *);
	void (*end_context_switch)(struct task_struct___23 *);
};

struct perf_event___11;

struct thread_struct___11 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___11 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___12;

struct pid_link___12 {
	struct hlist_node node;
	struct pid___12 *pid;
};

struct mutex___23 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___23 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___20 {
	struct page___22 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___25;

struct nsproxy___12;

struct signal_struct___22;

struct css_set___11;

struct perf_event_context___11;

struct task_struct___23 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___23 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___25 *mm;
	struct mm_struct___25 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___23 *real_parent;
	struct task_struct___23 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___23 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___12 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___22 = 0,
		VTIME_USER___22 = 1,
		VTIME_SYS___22 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___11 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___12 *nsproxy;
	struct signal_struct___22 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___11 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___11 *perf_event_ctxp[2];
	struct mutex___23 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___20 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___25 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___25 *, struct mm_struct___25 *);
	void (*dup_mmap)(struct mm_struct___25 *, struct mm_struct___25 *);
	void (*exit_mmap)(struct mm_struct___25 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___25 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___25 *);
	void (*pgd_free)(struct mm_struct___25 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___25 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___25 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___25 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___25 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___25 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___25 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___25 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___25 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___25 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___25 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___25 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___23 lock;
	void *vdso;
} mm_context_t___23;

struct xol_area___22;

struct uprobes_state___22 {
	struct xol_area___22 *xol_area;
};

struct vm_area_struct___25;

struct file___22;

struct core_state___22;

struct mm_struct___25 {
	struct vm_area_struct___25 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___25 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___25 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___23 context;
	long unsigned int flags;
	struct core_state___22 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___23 *owner;
	struct file___22 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___22 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___11 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___23 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___23 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___23 *target;
};

typedef void (*perf_overflow_handler_t___11)(struct perf_event___11 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___11;

typedef void (*ftrace_func_t___11)(long unsigned int, long unsigned int, struct ftrace_ops___11 *, struct pt_regs *);

struct ftrace_ops___11 {
	ftrace_func_t___11 func;
	struct ftrace_ops___11 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___23 regex_lock;
};

struct pmu___11;

struct fasync_struct___22;

struct pid_namespace___12;

struct perf_cgroup___11;

struct perf_event___11 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___11 *group_leader;
	struct pmu___11 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___11 hw;
	struct perf_event_context___11 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___23 child_mutex;
	struct list_head child_list;
	struct perf_event___11 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___23 *owner;
	struct mutex___23 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___22 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___11 *);
	struct callback_head callback_head;
	struct pid_namespace___12 *ns;
	u64 id;
	perf_overflow_handler_t___11 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___11 ftrace_ops;
	struct perf_cgroup___11 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___22;

struct lruvec___22 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___22 *zone;
};

struct pglist_data___22;

struct zone___22 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___22 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___22 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___22 {
	struct zone___22 *zone;
	int zone_idx;
};

struct zonelist___22 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___22 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___22 {
	struct zone___22 node_zones[4];
	struct zonelist___22 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___23 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___18;

struct dev_pm_ops___18 {
	int (*prepare)(struct device___18 *);
	void (*complete)(struct device___18 *);
	int (*suspend)(struct device___18 *);
	int (*resume)(struct device___18 *);
	int (*freeze)(struct device___18 *);
	int (*thaw)(struct device___18 *);
	int (*poweroff)(struct device___18 *);
	int (*restore)(struct device___18 *);
	int (*suspend_late)(struct device___18 *);
	int (*resume_early)(struct device___18 *);
	int (*freeze_late)(struct device___18 *);
	int (*thaw_early)(struct device___18 *);
	int (*poweroff_late)(struct device___18 *);
	int (*restore_early)(struct device___18 *);
	int (*suspend_noirq)(struct device___18 *);
	int (*resume_noirq)(struct device___18 *);
	int (*freeze_noirq)(struct device___18 *);
	int (*thaw_noirq)(struct device___18 *);
	int (*poweroff_noirq)(struct device___18 *);
	int (*restore_noirq)(struct device___18 *);
	int (*runtime_suspend)(struct device___18 *);
	int (*runtime_resume)(struct device___18 *);
	int (*runtime_idle)(struct device___18 *);
};

struct device_type___18;

struct bus_type___18;

struct device_driver___18;

struct dev_pm_domain___18;

struct class___18;

struct attribute_group___16;

struct device_rh___18;

struct device___18 {
	struct device___18 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___18 *type;
	struct mutex___23 mutex;
	struct bus_type___18 *bus;
	struct device_driver___18 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___18 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___7 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___7 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___18 *class;
	const struct attribute_group___16 **groups;
	void (*release)(struct device___18 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___18 *device_rh;
};

struct dev_pm_info_rh___18 {
	void (*set_latency_tolerance)(struct device___18 *, s32);
};

struct dev_pm_domain___18 {
	struct dev_pm_ops___18 ops;
};

struct smp_ops___22 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___23 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___16;

struct attribute_group___16 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___16 **bin_attrs;
};

struct bin_attribute___16 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___22 *, struct kobject *, struct bin_attribute___16 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___22 *, struct kobject *, struct bin_attribute___16 *, char *, loff_t, size_t);
	int (*mmap)(struct file___22 *, struct kobject *, struct bin_attribute___16 *, struct vm_area_struct___25 *);
};

struct dentry___23;

struct path___22 {
	struct vfsmount *mnt;
	struct dentry___23 *dentry;
};

struct fown_struct___12 {
	rwlock_t lock;
	struct pid___12 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___23;

struct file_operations___22;

struct file___22 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___22 f_path;
	struct inode___23 *f_inode;
	const struct file_operations___22 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___12 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___22 *f_mapping;
	struct mutex___23 f_pos_lock;
};

struct vm_operations_struct___19;

struct vm_area_struct___25 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___25 *vm_next;
	struct vm_area_struct___25 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___25 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___19 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___22 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___19 {
	void **freelist;
	long unsigned int tid;
	struct page___22 *page;
	struct page___22 *partial;
};

struct memcg_cache_params___19;

struct kmem_cache___19 {
	struct kmem_cache_cpu___19 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___19 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___19 {
	bool is_root_cache;
	union {
		struct kmem_cache___19 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___19 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___18 *, char *);
	ssize_t (*store)(struct bus_type___18 *, const char *, size_t);
};

struct device_attribute___18;

struct driver_attribute___18;

struct bus_type___18 {
	const char *name;
	const char *dev_name;
	struct device___18 *dev_root;
	struct bus_attribute___18 *bus_attrs;
	struct device_attribute___18 *dev_attrs;
	struct driver_attribute___18 *drv_attrs;
	const struct attribute_group___16 **bus_groups;
	const struct attribute_group___16 **dev_groups;
	const struct attribute_group___16 **drv_groups;
	int (*match)(struct device___18 *, struct device_driver___18 *);
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	int (*probe)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*online)(struct device___18 *);
	int (*offline)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct device___18 *, struct device_attribute___18 *, char *);
	ssize_t (*store)(struct device___18 *, struct device_attribute___18 *, const char *, size_t);
};

struct driver_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___18 *, char *);
	ssize_t (*store)(struct device_driver___18 *, const char *, size_t);
};

struct device_driver___18 {
	const char *name;
	struct bus_type___18 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct attribute_group___16 **groups;
	const struct dev_pm_ops___18 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___18 {
	const char *name;
	const struct attribute_group___16 **groups;
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
};

struct class_attribute___18;

struct class___18 {
	const char *name;
	struct module *owner;
	struct class_attribute___18 *class_attrs;
	struct device_attribute___18 *dev_attrs;
	const struct attribute_group___16 **dev_groups;
	struct bin_attribute___16 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *);
	void (*class_release)(struct class___18 *);
	void (*dev_release)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	struct subsys_private *p;
};

struct class_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct class___18 *, struct class_attribute___18 *, char *);
	ssize_t (*store)(struct class___18 *, struct class_attribute___18 *, const char *, size_t);
	const void * (*namespace)(struct class___18 *, const struct class_attribute___18 *);
};

struct device_rh___18 {
	struct dev_pm_info_rh___18 power;
};

struct cdev___8 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___22 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct file_lock___22;

struct file_operations___22 {
	struct module *owner;
	loff_t (*llseek)(struct file___22 *, loff_t, int);
	ssize_t (*read)(struct file___22 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___22 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___22 *, void *, filldir_t);
	unsigned int (*poll)(struct file___22 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___22 *, struct vm_area_struct___25 *);
	int (*open)(struct inode___23 *, struct file___22 *);
	int (*flush)(struct file___22 *, fl_owner_t);
	int (*release)(struct inode___23 *, struct file___22 *);
	int (*fsync)(struct file___22 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___22 *, int);
	int (*lock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*sendpage)(struct file___22 *, struct page___22 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___22 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___22 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___22 *, long int, struct file_lock___22 **, void **);
		struct {
			int (*setlease)(struct file___22 *, long int, struct file_lock___22 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___22 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___22 *);
};

union cpuid10_eax {
	struct {
		unsigned int version_id: 8;
		unsigned int num_counters: 8;
		unsigned int bit_width: 8;
		unsigned int mask_length: 8;
	} split;
	unsigned int full;
};

union cpuid10_ebx {
	struct {
		unsigned int no_unhalted_core_cycles: 1;
		unsigned int no_instructions_retired: 1;
		unsigned int no_unhalted_reference_cycles: 1;
		unsigned int no_llc_reference: 1;
		unsigned int no_llc_misses: 1;
		unsigned int no_branch_instruction_retired: 1;
		unsigned int no_branch_misses_retired: 1;
	} split;
	unsigned int full;
};

union cpuid10_edx {
	struct {
		unsigned int num_counters_fixed: 5;
		unsigned int bit_width_fixed: 8;
		unsigned int reserved: 19;
	} split;
	unsigned int full;
};

struct xol_area___22 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___22 *page;
	long unsigned int vaddr;
};

struct address_space_operations___22;

struct address_space___22 {
	struct inode___23 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___23 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___22 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___17;

struct vm_operations_struct___19 {
	void (*open)(struct vm_area_struct___25 *);
	void (*close)(struct vm_area_struct___25 *);
	int (*fault)(struct vm_area_struct___25 *, struct vm_fault___17 *);
	int (*page_mkwrite)(struct vm_area_struct___25 *, struct vm_fault___17 *);
	int (*access)(struct vm_area_struct___25 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___25 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___25 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___25 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___25 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___22 {
	struct task_struct___23 *task;
	struct core_thread___22 *next;
};

struct core_state___22 {
	atomic_t nr_threads;
	struct core_thread___22 dumper;
	struct completion startup;
};

struct upid___12 {
	int nr;
	struct pid_namespace___12 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___12 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___23 *child_reaper;
	struct kmem_cache___19 *pid_cachep;
	unsigned int level;
	struct pid_namespace___12 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___23 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___12 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___12 numbers[1];
};

struct nsproxy___12 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___12 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___22 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___23 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___23 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___12 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___12 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___23 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___11;

struct css_set___11 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___11 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___11 {
	struct pmu___11 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___23 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___23 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___11 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___22;

struct super_block___23;

struct dentry___23 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___23 *d_parent;
	struct qstr d_name;
	struct inode___23 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___22 *d_op;
	struct super_block___23 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___22;

struct dquot___22;

struct block_device___22;

struct inode___23 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___22 *i_op;
	struct super_block___23 *i_sb;
	struct address_space___22 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___23 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___22 *i_fop;
	struct file_lock___22 *i_flock;
	struct address_space___22 i_data;
	struct dquot___22 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___22 *i_bdev;
		struct cdev___8 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___22 {
	int (*d_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_hash)(const struct dentry___23 *, struct qstr *);
	int (*d_compare)(const struct dentry___23 *, const struct dentry___23 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___23 *);
	void (*d_release)(struct dentry___23 *);
	void (*d_prune)(struct dentry___23 *);
	void (*d_iput)(struct dentry___23 *, struct inode___23 *);
	char * (*d_dname)(struct dentry___23 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___22 *);
	int (*d_manage)(struct dentry___23 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___22;

struct mem_dqinfo___22 {
	struct quota_format_type___22 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___22;

struct quota_info___22 {
	unsigned int flags;
	struct mutex___23 dqio_mutex;
	struct mutex___23 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___23 *files[2];
	struct mem_dqinfo___22 info[2];
	const struct quota_format_ops___22 *ops[2];
};

struct file_system_type___22;

struct super_operations___22;

struct dquot_operations___22;

struct quotactl_ops___22;

struct xattr_handler___11;

struct super_block___23 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___22 *s_type;
	const struct super_operations___22 *s_op;
	const struct dquot_operations___22 *dq_op;
	const struct quotactl_ops___22 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___23 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___11 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___22 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___22 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___23 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___22 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___22 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___23 *bd_inode;
	struct super_block___23 *bd_super;
	struct mutex___23 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___22 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___23 bd_fsfreeze_mutex;
};

struct cgroup___11;

struct cgroup_subsys_state___11 {
	struct cgroup___11 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___23 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___22 *ia_file;
};

struct dquot___22 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___23 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___23 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___22 {
	int qf_fmt_id;
	const struct quota_format_ops___22 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___22 *qf_next;
};

struct quota_format_ops___22 {
	int (*check_quota_file)(struct super_block___23 *, int);
	int (*read_file_info)(struct super_block___23 *, int);
	int (*write_file_info)(struct super_block___23 *, int);
	int (*free_file_info)(struct super_block___23 *, int);
	int (*read_dqblk)(struct dquot___22 *);
	int (*commit_dqblk)(struct dquot___22 *);
	int (*release_dqblk)(struct dquot___22 *);
};

struct dquot_operations___22 {
	int (*write_dquot)(struct dquot___22 *);
	struct dquot___22 * (*alloc_dquot)(struct super_block___23 *, int);
	void (*destroy_dquot)(struct dquot___22 *);
	int (*acquire_dquot)(struct dquot___22 *);
	int (*release_dquot)(struct dquot___22 *);
	int (*mark_dirty)(struct dquot___22 *);
	int (*write_info)(struct super_block___23 *, int);
	qsize_t * (*get_reserved_space)(struct inode___23 *);
};

struct quotactl_ops___22 {
	int (*quota_on)(struct super_block___23 *, int, int, struct path___22 *);
	int (*quota_on_meta)(struct super_block___23 *, int, int);
	int (*quota_off)(struct super_block___23 *, int);
	int (*quota_sync)(struct super_block___23 *, int);
	int (*get_info)(struct super_block___23 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___23 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___23 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___23 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___23 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___23 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___23 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___23 *, unsigned int);
};

struct address_space_operations___22 {
	int (*writepage)(struct page___22 *, struct writeback_control *);
	int (*readpage)(struct file___22 *, struct page___22 *);
	int (*writepages)(struct address_space___22 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___22 *);
	int (*readpages)(struct file___22 *, struct address_space___22 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___22 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___22 **, void **);
	int (*write_end)(struct file___22 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___22 *, void *);
	sector_t (*bmap)(struct address_space___22 *, sector_t);
	void (*invalidatepage)(struct page___22 *, long unsigned int);
	int (*releasepage)(struct page___22 *, gfp_t);
	void (*freepage)(struct page___22 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___22 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___22 *, struct page___22 *, struct page___22 *, enum migrate_mode);
	int (*launder_page)(struct page___22 *);
	int (*is_partially_uptodate)(struct page___22 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___22 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___22 *, struct page___22 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___22 *, sector_t *);
	void (*swap_deactivate)(struct file___22 *);
	void (*invalidatepage_range)(struct page___22 *, unsigned int, unsigned int);
};

struct inode_operations___22 {
	struct dentry___23 * (*lookup)(struct inode___23 *, struct dentry___23 *, unsigned int);
	void * (*follow_link)(struct dentry___23 *, struct nameidata *);
	int (*permission)(struct inode___23 *, int);
	struct posix_acl * (*get_acl)(struct inode___23 *, int);
	int (*readlink)(struct dentry___23 *, char *, int);
	void (*put_link)(struct dentry___23 *, struct nameidata *, void *);
	int (*create)(struct inode___23 *, struct dentry___23 *, umode_t, bool);
	int (*link)(struct dentry___23 *, struct inode___23 *, struct dentry___23 *);
	int (*unlink)(struct inode___23 *, struct dentry___23 *);
	int (*symlink)(struct inode___23 *, struct dentry___23 *, const char *);
	int (*mkdir)(struct inode___23 *, struct dentry___23 *, umode_t);
	int (*rmdir)(struct inode___23 *, struct dentry___23 *);
	int (*mknod)(struct inode___23 *, struct dentry___23 *, umode_t, dev_t);
	int (*rename)(struct inode___23 *, struct dentry___23 *, struct inode___23 *, struct dentry___23 *);
	int (*setattr)(struct dentry___23 *, struct iattr___23 *);
	int (*getattr)(struct vfsmount *, struct dentry___23 *, struct kstat *);
	int (*setxattr)(struct dentry___23 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___23 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___23 *, char *, size_t);
	int (*removexattr)(struct dentry___23 *, const char *);
	int (*fiemap)(struct inode___23 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___23 *, struct timespec *, int);
	int (*atomic_open)(struct inode___23 *, struct dentry___23 *, struct file___22 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___22;

struct lock_manager_operations___22;

struct file_lock___22 {
	struct file_lock___22 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___12 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___22 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___22 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___22 *fl_ops;
	const struct lock_manager_operations___22 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___22 {
	void (*fl_copy_lock)(struct file_lock___22 *, struct file_lock___22 *);
	void (*fl_release_private)(struct file_lock___22 *);
};

struct lock_manager_operations___22 {
	int (*lm_compare_owner)(struct file_lock___22 *, struct file_lock___22 *);
	long unsigned int (*lm_owner_key)(struct file_lock___22 *);
	void (*lm_notify)(struct file_lock___22 *);
	int (*lm_grant)(struct file_lock___22 *, struct file_lock___22 *, int);
	void (*lm_break)(struct file_lock___22 *);
	int (*lm_change)(struct file_lock___22 **, int);
};

struct fasync_struct___22 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___22 *fa_next;
	struct file___22 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___22 {
	const char *name;
	int fs_flags;
	struct dentry___23 * (*mount)(struct file_system_type___22 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___23 *);
	struct module *owner;
	struct file_system_type___22 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___22 {
	struct inode___23 * (*alloc_inode)(struct super_block___23 *);
	void (*destroy_inode)(struct inode___23 *);
	void (*dirty_inode)(struct inode___23 *, int);
	int (*write_inode)(struct inode___23 *, struct writeback_control *);
	int (*drop_inode)(struct inode___23 *);
	void (*evict_inode)(struct inode___23 *);
	void (*put_super)(struct super_block___23 *);
	int (*sync_fs)(struct super_block___23 *, int);
	int (*freeze_fs)(struct super_block___23 *);
	int (*unfreeze_fs)(struct super_block___23 *);
	int (*statfs)(struct dentry___23 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___23 *, int *, char *);
	void (*umount_begin)(struct super_block___23 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___23 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___23 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___23 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___23 *);
	ssize_t (*quota_read)(struct super_block___23 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___23 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___23 *);
	int (*bdev_try_to_free_page)(struct super_block___23 *, struct page___22 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___23 *);
	void (*free_cached_objects)(struct super_block___23 *, int);
};

struct xattr_handler___11 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___23 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___23 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___23 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___17 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___22 *page;
};

struct cgroupfs_root___11;

struct cgroup___11 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___11 *parent;
	struct dentry___23 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___11 *subsys[11];
	struct cgroupfs_root___11 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___23 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___11 {
	struct super_block___23 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___11 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___11;

struct pmu___11 {
	struct list_head entry;
	struct device___18 *dev;
	const struct attribute_group___16 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___11 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___11 *);
	void (*pmu_disable)(struct pmu___11 *);
	int (*event_init)(struct perf_event___11 *);
	int (*add)(struct perf_event___11 *, int);
	void (*del)(struct perf_event___11 *, int);
	void (*start)(struct perf_event___11 *, int);
	void (*stop)(struct perf_event___11 *, int);
	void (*read)(struct perf_event___11 *);
	void (*start_txn)(struct pmu___11 *);
	int (*commit_txn)(struct pmu___11 *);
	void (*cancel_txn)(struct pmu___11 *);
	int (*event_idx)(struct perf_event___11 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___11 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___11 *);
};

struct perf_cpu_context___11 {
	struct perf_event_context___11 ctx;
	struct perf_event_context___11 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___11 *unique_pmu;
	struct perf_cgroup___11 *cgrp;
};

struct perf_cgroup___11 {
	struct cgroup_subsys_state___11 css;
	struct perf_cgroup_info *info;
};

struct perf_pmu_events_attr___2 {
	struct device_attribute___18 attr;
	u64 id;
	const char *event_str;
};

struct amd_nb___3 {
	int nb_id;
	int refcnt;
	struct perf_event___11 *owners[64];
	struct event_constraint event_constraints[64];
};

struct cpu_hw_events___3 {
	struct perf_event___11 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___11 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb___3 *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

union x86_pmu_config {
	struct {
		u64 event: 8;
		u64 umask: 8;
		u64 usr: 1;
		u64 os: 1;
		u64 edge: 1;
		u64 pc: 1;
		u64 interrupt: 1;
		u64 __reserved1: 1;
		u64 en: 1;
		u64 inv: 1;
		u64 cmask: 8;
		u64 event2: 4;
		u64 __reserved2: 4;
		u64 go: 1;
		u64 ho: 1;
	} bits;
	u64 value;
};

struct x86_pmu___3 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___11 *);
	void (*disable)(struct perf_event___11 *);
	int (*hw_config)(struct perf_event___11 *);
	int (*schedule_events)(struct cpu_hw_events___3 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___3 *, int, struct perf_event___11 *);
	void (*put_event_constraints)(struct cpu_hw_events___3 *, struct perf_event___11 *);
	void (*commit_scheduling)(struct cpu_hw_events___3 *, int, int);
	void (*start_scheduling)(struct cpu_hw_events___3 *);
	void (*stop_scheduling)(struct cpu_hw_events___3 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___11 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___11 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___11 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

struct page___23;

typedef struct page___23 *pgtable_t___23;

struct address_space___23;

struct kmem_cache___20;

struct page___23 {
	long unsigned int flags;
	struct address_space___23 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___23 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___23 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___20 *slab_cache;
		struct page___23 *first_page;
	};
	long: 64;
};

struct thread_struct___12;

struct task_struct___24;

struct pv_cpu_ops___23 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___12 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___12 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___24 *);
	void (*end_context_switch)(struct task_struct___24 *);
};

struct perf_event___12;

struct thread_struct___12 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___12 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___13;

struct pid_link___13 {
	struct hlist_node node;
	struct pid___13 *pid;
};

struct mutex___24 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___24 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___21 {
	struct page___23 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___26;

struct nsproxy___13;

struct signal_struct___23;

struct css_set___12;

struct perf_event_context___12;

struct task_struct___24 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___24 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___26 *mm;
	struct mm_struct___26 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___24 *real_parent;
	struct task_struct___24 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___24 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___13 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___23 = 0,
		VTIME_USER___23 = 1,
		VTIME_SYS___23 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___12 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___13 *nsproxy;
	struct signal_struct___23 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___12 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___12 *perf_event_ctxp[2];
	struct mutex___24 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___21 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___26 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___26 *, struct mm_struct___26 *);
	void (*dup_mmap)(struct mm_struct___26 *, struct mm_struct___26 *);
	void (*exit_mmap)(struct mm_struct___26 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___26 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___26 *);
	void (*pgd_free)(struct mm_struct___26 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___26 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___26 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___26 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___26 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___26 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___26 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___26 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___26 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___26 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___26 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___26 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___24 lock;
	void *vdso;
} mm_context_t___24;

struct xol_area___23;

struct uprobes_state___23 {
	struct xol_area___23 *xol_area;
};

struct vm_area_struct___26;

struct file___23;

struct core_state___23;

struct mm_struct___26 {
	struct vm_area_struct___26 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___26 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___26 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___24 context;
	long unsigned int flags;
	struct core_state___23 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___24 *owner;
	struct file___23 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___23 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___11;

struct module_kobject___10 {
	struct kobject kobj;
	struct module___11 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___10;

struct module___11 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___10 mkobj;
	struct module_attribute___10 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___24 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___12 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___24 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___24 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___24 *target;
};

typedef void (*perf_overflow_handler_t___12)(struct perf_event___12 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___12;

typedef void (*ftrace_func_t___12)(long unsigned int, long unsigned int, struct ftrace_ops___12 *, struct pt_regs *);

struct ftrace_ops___12 {
	ftrace_func_t___12 func;
	struct ftrace_ops___12 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___24 regex_lock;
};

struct pmu___12;

struct fasync_struct___23;

struct pid_namespace___13;

struct perf_cgroup___12;

struct perf_event___12 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___12 *group_leader;
	struct pmu___12 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___12 hw;
	struct perf_event_context___12 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___24 child_mutex;
	struct list_head child_list;
	struct perf_event___12 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___24 *owner;
	struct mutex___24 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___23 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___12 *);
	struct callback_head callback_head;
	struct pid_namespace___13 *ns;
	u64 id;
	perf_overflow_handler_t___12 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___12 ftrace_ops;
	struct perf_cgroup___12 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___23;

struct lruvec___23 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___23 *zone;
};

struct pglist_data___23;

struct zone___23 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___23 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___23 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___23 {
	struct zone___23 *zone;
	int zone_idx;
};

struct zonelist___23 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___23 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___23 {
	struct zone___23 node_zones[4];
	struct zonelist___23 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___24 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___8;

struct dev_archdata___8 {
	struct dma_map_ops___8 *dma_ops;
	void *iommu;
};

struct device_type___19;

struct bus_type___19;

struct device_driver___19;

struct dev_pm_domain___19;

struct class___19;

struct attribute_group___17;

struct device_rh___19;

struct device___19 {
	struct device___19 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___19 *type;
	struct mutex___24 mutex;
	struct bus_type___19 *bus;
	struct device_driver___19 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___19 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___8 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___7 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___19 *class;
	const struct attribute_group___17 **groups;
	void (*release)(struct device___19 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___19 *device_rh;
};

struct pci_bus___4;

struct pci_slot___4;

struct pci_driver___4;

struct bin_attribute___17;

struct pci_dev___4 {
	struct list_head bus_list;
	struct pci_bus___4 *bus;
	struct pci_bus___4 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___4 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___4 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___19 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___17 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___17 *res_attr[17];
	struct bin_attribute___17 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___17 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___4 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___19 {
	int (*prepare)(struct device___19 *);
	void (*complete)(struct device___19 *);
	int (*suspend)(struct device___19 *);
	int (*resume)(struct device___19 *);
	int (*freeze)(struct device___19 *);
	int (*thaw)(struct device___19 *);
	int (*poweroff)(struct device___19 *);
	int (*restore)(struct device___19 *);
	int (*suspend_late)(struct device___19 *);
	int (*resume_early)(struct device___19 *);
	int (*freeze_late)(struct device___19 *);
	int (*thaw_early)(struct device___19 *);
	int (*poweroff_late)(struct device___19 *);
	int (*restore_early)(struct device___19 *);
	int (*suspend_noirq)(struct device___19 *);
	int (*resume_noirq)(struct device___19 *);
	int (*freeze_noirq)(struct device___19 *);
	int (*thaw_noirq)(struct device___19 *);
	int (*poweroff_noirq)(struct device___19 *);
	int (*restore_noirq)(struct device___19 *);
	int (*runtime_suspend)(struct device___19 *);
	int (*runtime_resume)(struct device___19 *);
	int (*runtime_idle)(struct device___19 *);
};

struct dev_pm_info_rh___19 {
	void (*set_latency_tolerance)(struct device___19 *, s32);
};

struct dev_pm_domain___19 {
	struct dev_pm_ops___19 ops;
};

struct smp_ops___23 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___24 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___13 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___13 *pid_ns;
	struct net *net_ns;
};

struct attribute_group___17 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___17 **bin_attrs;
};

struct bin_attribute___17 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___23 *, struct kobject *, struct bin_attribute___17 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___23 *, struct kobject *, struct bin_attribute___17 *, char *, loff_t, size_t);
	int (*mmap)(struct file___23 *, struct kobject *, struct bin_attribute___17 *, struct vm_area_struct___26 *);
};

struct dentry___24;

struct path___23 {
	struct vfsmount *mnt;
	struct dentry___24 *dentry;
};

struct fown_struct___13 {
	rwlock_t lock;
	struct pid___13 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___24;

struct file_operations___23;

struct file___23 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___23 f_path;
	struct inode___24 *f_inode;
	const struct file_operations___23 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___13 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___23 *f_mapping;
	struct mutex___24 f_pos_lock;
};

struct vm_operations_struct___20;

struct vm_area_struct___26 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___26 *vm_next;
	struct vm_area_struct___26 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___26 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___20 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___23 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___10 *, struct module_kobject___10 *, char *);
	ssize_t (*store)(struct module_attribute___10 *, struct module_kobject___10 *, const char *, size_t);
	void (*setup)(struct module___11 *, const char *);
	int (*test)(struct module___11 *);
	void (*free)(struct module___11 *);
};

struct kmem_cache_cpu___20 {
	void **freelist;
	long unsigned int tid;
	struct page___23 *page;
	struct page___23 *partial;
};

struct memcg_cache_params___20;

struct kmem_cache___20 {
	struct kmem_cache_cpu___20 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___20 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___20 {
	bool is_root_cache;
	union {
		struct kmem_cache___20 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___20 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___8 {
	void * (*alloc)(struct device___19 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___19 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___19 *, struct vm_area_struct___26 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___19 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___19 *, struct page___23 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___19 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___19 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___19 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___19 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___19 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___19 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___19 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___19 *, dma_addr_t);
	int (*dma_supported)(struct device___19 *, u64);
	int (*set_dma_mask)(struct device___19 *, u64);
	int is_phys;
};

struct bus_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___19 *, char *);
	ssize_t (*store)(struct bus_type___19 *, const char *, size_t);
};

struct device_attribute___19;

struct driver_attribute___19;

struct bus_type___19 {
	const char *name;
	const char *dev_name;
	struct device___19 *dev_root;
	struct bus_attribute___19 *bus_attrs;
	struct device_attribute___19 *dev_attrs;
	struct driver_attribute___19 *drv_attrs;
	const struct attribute_group___17 **bus_groups;
	const struct attribute_group___17 **dev_groups;
	const struct attribute_group___17 **drv_groups;
	int (*match)(struct device___19 *, struct device_driver___19 *);
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	int (*probe)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*online)(struct device___19 *);
	int (*offline)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct device___19 *, struct device_attribute___19 *, char *);
	ssize_t (*store)(struct device___19 *, struct device_attribute___19 *, const char *, size_t);
};

struct driver_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___19 *, char *);
	ssize_t (*store)(struct device_driver___19 *, const char *, size_t);
};

struct device_driver___19 {
	const char *name;
	struct bus_type___19 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct attribute_group___17 **groups;
	const struct dev_pm_ops___19 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___19 {
	const char *name;
	const struct attribute_group___17 **groups;
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
};

struct class_attribute___19;

struct class___19 {
	const char *name;
	struct module___11 *owner;
	struct class_attribute___19 *class_attrs;
	struct device_attribute___19 *dev_attrs;
	const struct attribute_group___17 **dev_groups;
	struct bin_attribute___17 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *);
	void (*class_release)(struct class___19 *);
	void (*dev_release)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	struct subsys_private *p;
};

struct class_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct class___19 *, struct class_attribute___19 *, char *);
	ssize_t (*store)(struct class___19 *, struct class_attribute___19 *, const char *, size_t);
	const void * (*namespace)(struct class___19 *, const struct class_attribute___19 *);
};

struct device_rh___19 {
	struct dev_pm_info_rh___19 power;
};

struct pci_slot___4 {
	struct pci_bus___4 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___4;

struct pci_bus___4 {
	struct list_head node;
	struct pci_bus___4 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___4 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___4 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___19 *bridge;
	struct device___19 dev;
	struct bin_attribute___17 *legacy_io;
	struct bin_attribute___17 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___4;

struct pci_driver_rh___4;

struct pci_driver___4 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___4 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___4 *);
	int (*suspend)(struct pci_dev___4 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___4 *, pm_message_t);
	int (*resume_early)(struct pci_dev___4 *);
	int (*resume)(struct pci_dev___4 *);
	void (*shutdown)(struct pci_dev___4 *);
	int (*sriov_configure)(struct pci_dev___4 *, int);
	const struct pci_error_handlers___4 *err_handler;
	struct device_driver___19 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___4 *pci_driver_rh;
};

struct pci_ops___4 {
	int (*read)(struct pci_bus___4 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___4 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___4 {
	pci_ers_result_t (*error_detected)(struct pci_dev___4 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___4 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___4 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___4 *);
	void (*resume)(struct pci_dev___4 *);
};

struct pci_driver_rh___4 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___4 *, bool);
};

struct xol_area___23 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___23 *page;
	long unsigned int vaddr;
};

struct address_space_operations___23;

struct address_space___23 {
	struct inode___24 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___24 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___23 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___18;

struct vm_operations_struct___20 {
	void (*open)(struct vm_area_struct___26 *);
	void (*close)(struct vm_area_struct___26 *);
	int (*fault)(struct vm_area_struct___26 *, struct vm_fault___18 *);
	int (*page_mkwrite)(struct vm_area_struct___26 *, struct vm_fault___18 *);
	int (*access)(struct vm_area_struct___26 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___26 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___26 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___26 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___26 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___23 {
	struct task_struct___24 *task;
	struct core_thread___23 *next;
};

struct core_state___23 {
	atomic_t nr_threads;
	struct core_thread___23 dumper;
	struct completion startup;
};

struct vm_fault___18 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___23 *page;
};

struct pci_sysdata {
	int domain;
	int node;
	struct acpi_device *companion;
	void *iommu;
};

struct upid___13 {
	int nr;
	struct pid_namespace___13 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___13 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___24 *child_reaper;
	struct kmem_cache___20 *pid_cachep;
	unsigned int level;
	struct pid_namespace___13 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___24 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___13 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___13 numbers[1];
};

enum hrtimer_mode {
	HRTIMER_MODE_ABS = 0,
	HRTIMER_MODE_REL = 1,
	HRTIMER_MODE_PINNED = 2,
	HRTIMER_MODE_ABS_PINNED = 2,
	HRTIMER_MODE_REL_PINNED = 3,
};

struct signal_struct___23 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___24 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___24 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___13 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___13 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___24 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___12;

struct css_set___12 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___12 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___12 {
	struct pmu___12 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___24 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___24 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___12 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___23;

struct super_block___24;

struct dentry___24 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___24 *d_parent;
	struct qstr d_name;
	struct inode___24 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___23 *d_op;
	struct super_block___24 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___23;

struct file_lock___23;

struct dquot___23;

struct block_device___23;

struct inode___24 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___23 *i_op;
	struct super_block___24 *i_sb;
	struct address_space___23 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___24 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___23 *i_fop;
	struct file_lock___23 *i_flock;
	struct address_space___23 i_data;
	struct dquot___23 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___23 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___23 {
	int (*d_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_hash)(const struct dentry___24 *, struct qstr *);
	int (*d_compare)(const struct dentry___24 *, const struct dentry___24 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___24 *);
	void (*d_release)(struct dentry___24 *);
	void (*d_prune)(struct dentry___24 *);
	void (*d_iput)(struct dentry___24 *, struct inode___24 *);
	char * (*d_dname)(struct dentry___24 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___23 *);
	int (*d_manage)(struct dentry___24 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___23;

struct mem_dqinfo___23 {
	struct quota_format_type___23 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___23;

struct quota_info___23 {
	unsigned int flags;
	struct mutex___24 dqio_mutex;
	struct mutex___24 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___24 *files[2];
	struct mem_dqinfo___23 info[2];
	const struct quota_format_ops___23 *ops[2];
};

struct file_system_type___23;

struct super_operations___23;

struct dquot_operations___23;

struct quotactl_ops___23;

struct xattr_handler___12;

struct super_block___24 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___23 *s_type;
	const struct super_operations___23 *s_op;
	const struct dquot_operations___23 *dq_op;
	const struct quotactl_ops___23 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___24 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___12 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___23 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___23 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___24 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___23 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___23 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___24 *bd_inode;
	struct super_block___24 *bd_super;
	struct mutex___24 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___23 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___24 bd_fsfreeze_mutex;
};

struct cgroup___12;

struct cgroup_subsys_state___12 {
	struct cgroup___12 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___24 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___23 *ia_file;
};

struct dquot___23 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___24 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___24 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___23 {
	int qf_fmt_id;
	const struct quota_format_ops___23 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___23 *qf_next;
};

struct quota_format_ops___23 {
	int (*check_quota_file)(struct super_block___24 *, int);
	int (*read_file_info)(struct super_block___24 *, int);
	int (*write_file_info)(struct super_block___24 *, int);
	int (*free_file_info)(struct super_block___24 *, int);
	int (*read_dqblk)(struct dquot___23 *);
	int (*commit_dqblk)(struct dquot___23 *);
	int (*release_dqblk)(struct dquot___23 *);
};

struct dquot_operations___23 {
	int (*write_dquot)(struct dquot___23 *);
	struct dquot___23 * (*alloc_dquot)(struct super_block___24 *, int);
	void (*destroy_dquot)(struct dquot___23 *);
	int (*acquire_dquot)(struct dquot___23 *);
	int (*release_dquot)(struct dquot___23 *);
	int (*mark_dirty)(struct dquot___23 *);
	int (*write_info)(struct super_block___24 *, int);
	qsize_t * (*get_reserved_space)(struct inode___24 *);
};

struct quotactl_ops___23 {
	int (*quota_on)(struct super_block___24 *, int, int, struct path___23 *);
	int (*quota_on_meta)(struct super_block___24 *, int, int);
	int (*quota_off)(struct super_block___24 *, int);
	int (*quota_sync)(struct super_block___24 *, int);
	int (*get_info)(struct super_block___24 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___24 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___24 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___24 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___24 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___24 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___24 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___24 *, unsigned int);
};

struct address_space_operations___23 {
	int (*writepage)(struct page___23 *, struct writeback_control *);
	int (*readpage)(struct file___23 *, struct page___23 *);
	int (*writepages)(struct address_space___23 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___23 *);
	int (*readpages)(struct file___23 *, struct address_space___23 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___23 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___23 **, void **);
	int (*write_end)(struct file___23 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___23 *, void *);
	sector_t (*bmap)(struct address_space___23 *, sector_t);
	void (*invalidatepage)(struct page___23 *, long unsigned int);
	int (*releasepage)(struct page___23 *, gfp_t);
	void (*freepage)(struct page___23 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___23 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___23 *, struct page___23 *, struct page___23 *, enum migrate_mode);
	int (*launder_page)(struct page___23 *);
	int (*is_partially_uptodate)(struct page___23 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___23 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___23 *, struct page___23 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___23 *, sector_t *);
	void (*swap_deactivate)(struct file___23 *);
	void (*invalidatepage_range)(struct page___23 *, unsigned int, unsigned int);
};

struct inode_operations___23 {
	struct dentry___24 * (*lookup)(struct inode___24 *, struct dentry___24 *, unsigned int);
	void * (*follow_link)(struct dentry___24 *, struct nameidata *);
	int (*permission)(struct inode___24 *, int);
	struct posix_acl * (*get_acl)(struct inode___24 *, int);
	int (*readlink)(struct dentry___24 *, char *, int);
	void (*put_link)(struct dentry___24 *, struct nameidata *, void *);
	int (*create)(struct inode___24 *, struct dentry___24 *, umode_t, bool);
	int (*link)(struct dentry___24 *, struct inode___24 *, struct dentry___24 *);
	int (*unlink)(struct inode___24 *, struct dentry___24 *);
	int (*symlink)(struct inode___24 *, struct dentry___24 *, const char *);
	int (*mkdir)(struct inode___24 *, struct dentry___24 *, umode_t);
	int (*rmdir)(struct inode___24 *, struct dentry___24 *);
	int (*mknod)(struct inode___24 *, struct dentry___24 *, umode_t, dev_t);
	int (*rename)(struct inode___24 *, struct dentry___24 *, struct inode___24 *, struct dentry___24 *);
	int (*setattr)(struct dentry___24 *, struct iattr___24 *);
	int (*getattr)(struct vfsmount *, struct dentry___24 *, struct kstat *);
	int (*setxattr)(struct dentry___24 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___24 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___24 *, char *, size_t);
	int (*removexattr)(struct dentry___24 *, const char *);
	int (*fiemap)(struct inode___24 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___24 *, struct timespec *, int);
	int (*atomic_open)(struct inode___24 *, struct dentry___24 *, struct file___23 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___23 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___23 *, loff_t, int);
	ssize_t (*read)(struct file___23 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___23 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___23 *, void *, filldir_t);
	unsigned int (*poll)(struct file___23 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___23 *, struct vm_area_struct___26 *);
	int (*open)(struct inode___24 *, struct file___23 *);
	int (*flush)(struct file___23 *, fl_owner_t);
	int (*release)(struct inode___24 *, struct file___23 *);
	int (*fsync)(struct file___23 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___23 *, int);
	int (*lock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*sendpage)(struct file___23 *, struct page___23 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___23 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___23 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___23 *, long int, struct file_lock___23 **, void **);
		struct {
			int (*setlease)(struct file___23 *, long int, struct file_lock___23 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___23 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___23 *);
};

struct file_lock_operations___23;

struct lock_manager_operations___23;

struct file_lock___23 {
	struct file_lock___23 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___13 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___23 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___23 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___23 *fl_ops;
	const struct lock_manager_operations___23 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___23 {
	void (*fl_copy_lock)(struct file_lock___23 *, struct file_lock___23 *);
	void (*fl_release_private)(struct file_lock___23 *);
};

struct lock_manager_operations___23 {
	int (*lm_compare_owner)(struct file_lock___23 *, struct file_lock___23 *);
	long unsigned int (*lm_owner_key)(struct file_lock___23 *);
	void (*lm_notify)(struct file_lock___23 *);
	int (*lm_grant)(struct file_lock___23 *, struct file_lock___23 *, int);
	void (*lm_break)(struct file_lock___23 *);
	int (*lm_change)(struct file_lock___23 **, int);
};

struct fasync_struct___23 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___23 *fa_next;
	struct file___23 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___23 {
	const char *name;
	int fs_flags;
	struct dentry___24 * (*mount)(struct file_system_type___23 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___24 *);
	struct module___11 *owner;
	struct file_system_type___23 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___23 {
	struct inode___24 * (*alloc_inode)(struct super_block___24 *);
	void (*destroy_inode)(struct inode___24 *);
	void (*dirty_inode)(struct inode___24 *, int);
	int (*write_inode)(struct inode___24 *, struct writeback_control *);
	int (*drop_inode)(struct inode___24 *);
	void (*evict_inode)(struct inode___24 *);
	void (*put_super)(struct super_block___24 *);
	int (*sync_fs)(struct super_block___24 *, int);
	int (*freeze_fs)(struct super_block___24 *);
	int (*unfreeze_fs)(struct super_block___24 *);
	int (*statfs)(struct dentry___24 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___24 *, int *, char *);
	void (*umount_begin)(struct super_block___24 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___24 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___24 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___24 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___24 *);
	ssize_t (*quota_read)(struct super_block___24 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___24 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___24 *);
	int (*bdev_try_to_free_page)(struct super_block___24 *, struct page___23 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___24 *);
	void (*free_cached_objects)(struct super_block___24 *, int);
};

struct xattr_handler___12 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___24 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___24 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___24 *, const char *, const void *, size_t, int, int);
};

struct cgroupfs_root___12;

struct cgroup___12 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___12 *parent;
	struct dentry___24 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___12 *subsys[11];
	struct cgroupfs_root___12 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___24 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___12 {
	struct super_block___24 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___12 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___12;

struct pmu___12 {
	struct list_head entry;
	struct device___19 *dev;
	const struct attribute_group___17 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___12 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___12 *);
	void (*pmu_disable)(struct pmu___12 *);
	int (*event_init)(struct perf_event___12 *);
	int (*add)(struct perf_event___12 *, int);
	void (*del)(struct perf_event___12 *, int);
	void (*start)(struct perf_event___12 *, int);
	void (*stop)(struct perf_event___12 *, int);
	void (*read)(struct perf_event___12 *);
	void (*start_txn)(struct pmu___12 *);
	int (*commit_txn)(struct pmu___12 *);
	void (*cancel_txn)(struct pmu___12 *);
	int (*event_idx)(struct perf_event___12 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___11 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___12 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___12 *);
};

struct perf_cpu_context___12 {
	struct perf_event_context___12 ctx;
	struct perf_event_context___12 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___12 *unique_pmu;
	struct perf_cgroup___12 *cgrp;
};

struct perf_cgroup___12 {
	struct cgroup_subsys_state___12 css;
	struct perf_cgroup_info *info;
};

struct amd_nb___4 {
	int nb_id;
	int refcnt;
	struct perf_event___12 *owners[64];
	struct event_constraint event_constraints[64];
};

struct cpu_hw_events___4 {
	struct perf_event___12 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___12 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb___4 *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

struct x86_pmu___4 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___12 *);
	void (*disable)(struct perf_event___12 *);
	int (*hw_config)(struct perf_event___12 *);
	int (*schedule_events)(struct cpu_hw_events___4 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___4 *, int, struct perf_event___12 *);
	void (*put_event_constraints)(struct cpu_hw_events___4 *, struct perf_event___12 *);
	void (*commit_scheduling)(struct cpu_hw_events___4 *, int, int);
	void (*start_scheduling)(struct cpu_hw_events___4 *);
	void (*stop_scheduling)(struct cpu_hw_events___4 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___12 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___12 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___12 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

struct intel_uncore_pmu;

struct intel_uncore_ops;

struct uncore_event_desc;

struct intel_uncore_type {
	const char *name;
	int num_counters;
	int num_boxes;
	int perf_ctr_bits;
	int fixed_ctr_bits;
	unsigned int perf_ctr;
	unsigned int event_ctl;
	unsigned int event_mask;
	unsigned int fixed_ctr;
	unsigned int fixed_ctl;
	unsigned int box_ctl;
	unsigned int msr_offset;
	unsigned int num_shared_regs: 8;
	unsigned int single_fixed: 1;
	unsigned int pair_ctr_ctl: 1;
	unsigned int *msr_offsets;
	struct event_constraint unconstrainted;
	struct event_constraint *constraints;
	struct intel_uncore_pmu *pmus;
	struct intel_uncore_ops *ops;
	struct uncore_event_desc *event_descs;
	const struct attribute_group___17 *attr_groups[4];
	struct pmu___12 *pmu;
};

struct intel_uncore_box;

struct intel_uncore_pmu {
	struct pmu___12 pmu;
	char name[32];
	int pmu_idx;
	int func_id;
	struct intel_uncore_type *type;
	struct intel_uncore_box **box;
	struct list_head box_list;
};

struct intel_uncore_ops {
	void (*init_box)(struct intel_uncore_box *);
	void (*disable_box)(struct intel_uncore_box *);
	void (*enable_box)(struct intel_uncore_box *);
	void (*disable_event)(struct intel_uncore_box *, struct perf_event___12 *);
	void (*enable_event)(struct intel_uncore_box *, struct perf_event___12 *);
	u64 (*read_counter)(struct intel_uncore_box *, struct perf_event___12 *);
	int (*hw_config)(struct intel_uncore_box *, struct perf_event___12 *);
	struct event_constraint * (*get_constraint)(struct intel_uncore_box *, struct perf_event___12 *);
	void (*put_constraint)(struct intel_uncore_box *, struct perf_event___12 *);
};

struct uncore_event_desc {
	struct kobj_attribute attr;
	const char *config;
};

struct intel_uncore_extra_reg {
	raw_spinlock_t lock;
	u64 config;
	u64 config1;
	u64 config2;
	atomic_t ref;
};

struct intel_uncore_box {
	int phys_id;
	int n_active;
	int n_events;
	int cpu;
	long unsigned int flags;
	atomic_t refcnt;
	struct perf_event___12 *events[9];
	struct perf_event___12 *event_list[9];
	struct event_constraint *event_constraint[9];
	long unsigned int active_mask[1];
	u64 tags[9];
	struct pci_dev___4 *pci_dev;
	struct intel_uncore_pmu *pmu;
	u64 hrtimer_duration;
	struct hrtimer hrtimer;
	struct list_head list;
	struct list_head active_list;
	void *io_addr;
	struct intel_uncore_extra_reg shared_regs[0];
};

struct pci2phy_map {
	struct list_head list;
	int segment;
	int pbus_to_physid[256];
};

enum {
	SNB_PCI_UNCORE_IMC = 0,
};

struct imc_uncore_pci_dev {
	__u32 pci_id;
	struct pci_driver___4 *driver;
};

enum {
	SNBEP_PCI_QPI_PORT0_FILTER = 0,
	SNBEP_PCI_QPI_PORT1_FILTER = 1,
	HSWEP_PCI_PCU_3 = 2,
};

enum {
	SNBEP_PCI_UNCORE_HA = 0,
	SNBEP_PCI_UNCORE_IMC = 1,
	SNBEP_PCI_UNCORE_QPI = 2,
	SNBEP_PCI_UNCORE_R2PCIE = 3,
	SNBEP_PCI_UNCORE_R3QPI = 4,
};

enum {
	IVBEP_PCI_UNCORE_HA = 0,
	IVBEP_PCI_UNCORE_IMC = 1,
	IVBEP_PCI_UNCORE_IRP = 2,
	IVBEP_PCI_UNCORE_QPI = 3,
	IVBEP_PCI_UNCORE_R2PCIE = 4,
	IVBEP_PCI_UNCORE_R3QPI = 5,
};

enum {
	HSWEP_PCI_UNCORE_HA = 0,
	HSWEP_PCI_UNCORE_IMC = 1,
	HSWEP_PCI_UNCORE_IRP = 2,
	HSWEP_PCI_UNCORE_QPI = 3,
	HSWEP_PCI_UNCORE_R2PCIE = 4,
	HSWEP_PCI_UNCORE_R3QPI = 5,
};

enum {
	EXTRA_REG_NHMEX_M_FILTER = 0,
	EXTRA_REG_NHMEX_M_DSP = 1,
	EXTRA_REG_NHMEX_M_ISS = 2,
	EXTRA_REG_NHMEX_M_MAP = 3,
	EXTRA_REG_NHMEX_M_MSC_THR = 4,
	EXTRA_REG_NHMEX_M_PGT = 5,
	EXTRA_REG_NHMEX_M_PLD = 6,
	EXTRA_REG_NHMEX_M_ZDP_CTL_FVC = 7,
};

struct page___24;

typedef struct page___24 *pgtable_t___24;

struct address_space___24;

struct kmem_cache___21;

struct page___24 {
	long unsigned int flags;
	struct address_space___24 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___24 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___24 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___21 *slab_cache;
		struct page___24 *first_page;
	};
	long: 64;
};

struct thread_struct___13;

struct task_struct___25;

struct pv_cpu_ops___24 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___13 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___13 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___25 *);
	void (*end_context_switch)(struct task_struct___25 *);
};

struct perf_event___13;

struct thread_struct___13 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___13 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___14;

struct pid_link___14 {
	struct hlist_node node;
	struct pid___14 *pid;
};

struct mutex___25 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___25 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___22 {
	struct page___24 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___27;

struct nsproxy___14;

struct signal_struct___24;

struct css_set___13;

struct perf_event_context___13;

struct task_struct___25 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___25 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___27 *mm;
	struct mm_struct___27 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___25 *real_parent;
	struct task_struct___25 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___25 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___14 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___24 = 0,
		VTIME_USER___24 = 1,
		VTIME_SYS___24 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___13 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___14 *nsproxy;
	struct signal_struct___24 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___13 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___13 *perf_event_ctxp[2];
	struct mutex___25 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___22 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___27 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___27 *, struct mm_struct___27 *);
	void (*dup_mmap)(struct mm_struct___27 *, struct mm_struct___27 *);
	void (*exit_mmap)(struct mm_struct___27 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___27 *);
	void (*pgd_free)(struct mm_struct___27 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___27 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___27 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___27 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___27 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___27 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___27 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___27 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___27 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___27 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___27 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___27 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___25 lock;
	void *vdso;
} mm_context_t___25;

struct xol_area___24;

struct uprobes_state___24 {
	struct xol_area___24 *xol_area;
};

struct vm_area_struct___27;

struct file___24;

struct core_state___24;

struct mm_struct___27 {
	struct vm_area_struct___27 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___27 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___27 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___25 context;
	long unsigned int flags;
	struct core_state___24 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___25 *owner;
	struct file___24 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___24 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___12;

struct module_kobject___11 {
	struct kobject kobj;
	struct module___12 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___11;

struct module___12 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___11 mkobj;
	struct module_attribute___11 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___25 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___13 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___25 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___25 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___25 *target;
};

typedef void (*perf_overflow_handler_t___13)(struct perf_event___13 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___13;

typedef void (*ftrace_func_t___13)(long unsigned int, long unsigned int, struct ftrace_ops___13 *, struct pt_regs *);

struct ftrace_ops___13 {
	ftrace_func_t___13 func;
	struct ftrace_ops___13 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___25 regex_lock;
};

struct pmu___13;

struct fasync_struct___24;

struct pid_namespace___14;

struct perf_cgroup___13;

struct perf_event___13 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___13 *group_leader;
	struct pmu___13 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___13 hw;
	struct perf_event_context___13 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___25 child_mutex;
	struct list_head child_list;
	struct perf_event___13 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___25 *owner;
	struct mutex___25 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___24 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___13 *);
	struct callback_head callback_head;
	struct pid_namespace___14 *ns;
	u64 id;
	perf_overflow_handler_t___13 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___13 ftrace_ops;
	struct perf_cgroup___13 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___24;

struct lruvec___24 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___24 *zone;
};

struct pglist_data___24;

struct zone___24 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___24 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___24 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___24 {
	struct zone___24 *zone;
	int zone_idx;
};

struct zonelist___24 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___24 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___24 {
	struct zone___24 node_zones[4];
	struct zonelist___24 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___25 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___20;

struct dev_pm_ops___20 {
	int (*prepare)(struct device___20 *);
	void (*complete)(struct device___20 *);
	int (*suspend)(struct device___20 *);
	int (*resume)(struct device___20 *);
	int (*freeze)(struct device___20 *);
	int (*thaw)(struct device___20 *);
	int (*poweroff)(struct device___20 *);
	int (*restore)(struct device___20 *);
	int (*suspend_late)(struct device___20 *);
	int (*resume_early)(struct device___20 *);
	int (*freeze_late)(struct device___20 *);
	int (*thaw_early)(struct device___20 *);
	int (*poweroff_late)(struct device___20 *);
	int (*restore_early)(struct device___20 *);
	int (*suspend_noirq)(struct device___20 *);
	int (*resume_noirq)(struct device___20 *);
	int (*freeze_noirq)(struct device___20 *);
	int (*thaw_noirq)(struct device___20 *);
	int (*poweroff_noirq)(struct device___20 *);
	int (*restore_noirq)(struct device___20 *);
	int (*runtime_suspend)(struct device___20 *);
	int (*runtime_resume)(struct device___20 *);
	int (*runtime_idle)(struct device___20 *);
};

struct device_type___20;

struct bus_type___20;

struct device_driver___20;

struct dev_pm_domain___20;

struct class___20;

struct attribute_group___18;

struct device_rh___20;

struct device___20 {
	struct device___20 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___20 *type;
	struct mutex___25 mutex;
	struct bus_type___20 *bus;
	struct device_driver___20 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___20 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___8 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___6 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___20 *class;
	const struct attribute_group___18 **groups;
	void (*release)(struct device___20 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___20 *device_rh;
};

struct dev_pm_info_rh___20 {
	void (*set_latency_tolerance)(struct device___20 *, s32);
};

struct dev_pm_domain___20 {
	struct dev_pm_ops___20 ops;
};

struct smp_ops___24 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___25 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___14 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___14 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___18;

struct attribute_group___18 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___18 **bin_attrs;
};

struct bin_attribute___18 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___24 *, struct kobject *, struct bin_attribute___18 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___24 *, struct kobject *, struct bin_attribute___18 *, char *, loff_t, size_t);
	int (*mmap)(struct file___24 *, struct kobject *, struct bin_attribute___18 *, struct vm_area_struct___27 *);
};

struct dentry___25;

struct path___24 {
	struct vfsmount *mnt;
	struct dentry___25 *dentry;
};

struct fown_struct___14 {
	rwlock_t lock;
	struct pid___14 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___25;

struct file_operations___24;

struct file___24 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___24 f_path;
	struct inode___25 *f_inode;
	const struct file_operations___24 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___24 *f_mapping;
	struct mutex___25 f_pos_lock;
};

struct vm_operations_struct___21;

struct vm_area_struct___27 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___27 *vm_next;
	struct vm_area_struct___27 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___27 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___21 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___24 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___11 *, struct module_kobject___11 *, char *);
	ssize_t (*store)(struct module_attribute___11 *, struct module_kobject___11 *, const char *, size_t);
	void (*setup)(struct module___12 *, const char *);
	int (*test)(struct module___12 *);
	void (*free)(struct module___12 *);
};

struct kmem_cache_cpu___21 {
	void **freelist;
	long unsigned int tid;
	struct page___24 *page;
	struct page___24 *partial;
};

struct memcg_cache_params___21;

struct kmem_cache___21 {
	struct kmem_cache_cpu___21 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___21 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___21 {
	bool is_root_cache;
	union {
		struct kmem_cache___21 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___21 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___24 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___24 *page;
	long unsigned int vaddr;
};

struct address_space_operations___24;

struct address_space___24 {
	struct inode___25 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___25 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___24 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___19;

struct vm_operations_struct___21 {
	void (*open)(struct vm_area_struct___27 *);
	void (*close)(struct vm_area_struct___27 *);
	int (*fault)(struct vm_area_struct___27 *, struct vm_fault___19 *);
	int (*page_mkwrite)(struct vm_area_struct___27 *, struct vm_fault___19 *);
	int (*access)(struct vm_area_struct___27 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___27 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___27 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___27 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___27 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___24 {
	struct task_struct___25 *task;
	struct core_thread___24 *next;
};

struct core_state___24 {
	atomic_t nr_threads;
	struct core_thread___24 dumper;
	struct completion startup;
};

struct upid___14 {
	int nr;
	struct pid_namespace___14 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___14 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___25 *child_reaper;
	struct kmem_cache___21 *pid_cachep;
	unsigned int level;
	struct pid_namespace___14 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___25 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___14 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___14 numbers[1];
};

struct signal_struct___24 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___25 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___25 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___14 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___25 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___13;

struct css_set___13 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___13 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___13 {
	struct pmu___13 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___25 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___25 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___13 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___24;

struct super_block___25;

struct dentry___25 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___25 *d_parent;
	struct qstr d_name;
	struct inode___25 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___24 *d_op;
	struct super_block___25 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___24;

struct file_lock___24;

struct dquot___24;

struct block_device___24;

struct inode___25 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___24 *i_op;
	struct super_block___25 *i_sb;
	struct address_space___24 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___25 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___24 *i_fop;
	struct file_lock___24 *i_flock;
	struct address_space___24 i_data;
	struct dquot___24 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___24 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___24 {
	int (*d_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_hash)(const struct dentry___25 *, struct qstr *);
	int (*d_compare)(const struct dentry___25 *, const struct dentry___25 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___25 *);
	void (*d_release)(struct dentry___25 *);
	void (*d_prune)(struct dentry___25 *);
	void (*d_iput)(struct dentry___25 *, struct inode___25 *);
	char * (*d_dname)(struct dentry___25 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___24 *);
	int (*d_manage)(struct dentry___25 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___24;

struct mem_dqinfo___24 {
	struct quota_format_type___24 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___24;

struct quota_info___24 {
	unsigned int flags;
	struct mutex___25 dqio_mutex;
	struct mutex___25 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___25 *files[2];
	struct mem_dqinfo___24 info[2];
	const struct quota_format_ops___24 *ops[2];
};

struct file_system_type___24;

struct super_operations___24;

struct dquot_operations___24;

struct quotactl_ops___24;

struct xattr_handler___13;

struct super_block___25 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___24 *s_type;
	const struct super_operations___24 *s_op;
	const struct dquot_operations___24 *dq_op;
	const struct quotactl_ops___24 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___25 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___13 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___24 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___24 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___25 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___24 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___24 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___25 *bd_inode;
	struct super_block___25 *bd_super;
	struct mutex___25 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___24 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___25 bd_fsfreeze_mutex;
};

struct cgroup___13;

struct cgroup_subsys_state___13 {
	struct cgroup___13 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___25 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___24 *ia_file;
};

struct dquot___24 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___25 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___25 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___24 {
	int qf_fmt_id;
	const struct quota_format_ops___24 *qf_ops;
	struct module___12 *qf_owner;
	struct quota_format_type___24 *qf_next;
};

struct quota_format_ops___24 {
	int (*check_quota_file)(struct super_block___25 *, int);
	int (*read_file_info)(struct super_block___25 *, int);
	int (*write_file_info)(struct super_block___25 *, int);
	int (*free_file_info)(struct super_block___25 *, int);
	int (*read_dqblk)(struct dquot___24 *);
	int (*commit_dqblk)(struct dquot___24 *);
	int (*release_dqblk)(struct dquot___24 *);
};

struct dquot_operations___24 {
	int (*write_dquot)(struct dquot___24 *);
	struct dquot___24 * (*alloc_dquot)(struct super_block___25 *, int);
	void (*destroy_dquot)(struct dquot___24 *);
	int (*acquire_dquot)(struct dquot___24 *);
	int (*release_dquot)(struct dquot___24 *);
	int (*mark_dirty)(struct dquot___24 *);
	int (*write_info)(struct super_block___25 *, int);
	qsize_t * (*get_reserved_space)(struct inode___25 *);
};

struct quotactl_ops___24 {
	int (*quota_on)(struct super_block___25 *, int, int, struct path___24 *);
	int (*quota_on_meta)(struct super_block___25 *, int, int);
	int (*quota_off)(struct super_block___25 *, int);
	int (*quota_sync)(struct super_block___25 *, int);
	int (*get_info)(struct super_block___25 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___25 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___25 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___25 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___25 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___25 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___25 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___25 *, unsigned int);
};

struct address_space_operations___24 {
	int (*writepage)(struct page___24 *, struct writeback_control *);
	int (*readpage)(struct file___24 *, struct page___24 *);
	int (*writepages)(struct address_space___24 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___24 *);
	int (*readpages)(struct file___24 *, struct address_space___24 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___24 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___24 **, void **);
	int (*write_end)(struct file___24 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___24 *, void *);
	sector_t (*bmap)(struct address_space___24 *, sector_t);
	void (*invalidatepage)(struct page___24 *, long unsigned int);
	int (*releasepage)(struct page___24 *, gfp_t);
	void (*freepage)(struct page___24 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___24 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___24 *, struct page___24 *, struct page___24 *, enum migrate_mode);
	int (*launder_page)(struct page___24 *);
	int (*is_partially_uptodate)(struct page___24 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___24 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___24 *, struct page___24 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___24 *, sector_t *);
	void (*swap_deactivate)(struct file___24 *);
	void (*invalidatepage_range)(struct page___24 *, unsigned int, unsigned int);
};

struct inode_operations___24 {
	struct dentry___25 * (*lookup)(struct inode___25 *, struct dentry___25 *, unsigned int);
	void * (*follow_link)(struct dentry___25 *, struct nameidata *);
	int (*permission)(struct inode___25 *, int);
	struct posix_acl * (*get_acl)(struct inode___25 *, int);
	int (*readlink)(struct dentry___25 *, char *, int);
	void (*put_link)(struct dentry___25 *, struct nameidata *, void *);
	int (*create)(struct inode___25 *, struct dentry___25 *, umode_t, bool);
	int (*link)(struct dentry___25 *, struct inode___25 *, struct dentry___25 *);
	int (*unlink)(struct inode___25 *, struct dentry___25 *);
	int (*symlink)(struct inode___25 *, struct dentry___25 *, const char *);
	int (*mkdir)(struct inode___25 *, struct dentry___25 *, umode_t);
	int (*rmdir)(struct inode___25 *, struct dentry___25 *);
	int (*mknod)(struct inode___25 *, struct dentry___25 *, umode_t, dev_t);
	int (*rename)(struct inode___25 *, struct dentry___25 *, struct inode___25 *, struct dentry___25 *);
	int (*setattr)(struct dentry___25 *, struct iattr___25 *);
	int (*getattr)(struct vfsmount *, struct dentry___25 *, struct kstat *);
	int (*setxattr)(struct dentry___25 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___25 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___25 *, char *, size_t);
	int (*removexattr)(struct dentry___25 *, const char *);
	int (*fiemap)(struct inode___25 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___25 *, struct timespec *, int);
	int (*atomic_open)(struct inode___25 *, struct dentry___25 *, struct file___24 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___24 {
	struct module___12 *owner;
	loff_t (*llseek)(struct file___24 *, loff_t, int);
	ssize_t (*read)(struct file___24 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___24 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___24 *, void *, filldir_t);
	unsigned int (*poll)(struct file___24 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___24 *, struct vm_area_struct___27 *);
	int (*open)(struct inode___25 *, struct file___24 *);
	int (*flush)(struct file___24 *, fl_owner_t);
	int (*release)(struct inode___25 *, struct file___24 *);
	int (*fsync)(struct file___24 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___24 *, int);
	int (*lock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*sendpage)(struct file___24 *, struct page___24 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___24 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___24 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___24 *, long int, struct file_lock___24 **, void **);
		struct {
			int (*setlease)(struct file___24 *, long int, struct file_lock___24 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___24 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___24 *);
};

struct file_lock_operations___24;

struct lock_manager_operations___24;

struct file_lock___24 {
	struct file_lock___24 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___14 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___24 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___24 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___24 *fl_ops;
	const struct lock_manager_operations___24 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___24 {
	void (*fl_copy_lock)(struct file_lock___24 *, struct file_lock___24 *);
	void (*fl_release_private)(struct file_lock___24 *);
};

struct lock_manager_operations___24 {
	int (*lm_compare_owner)(struct file_lock___24 *, struct file_lock___24 *);
	long unsigned int (*lm_owner_key)(struct file_lock___24 *);
	void (*lm_notify)(struct file_lock___24 *);
	int (*lm_grant)(struct file_lock___24 *, struct file_lock___24 *, int);
	void (*lm_break)(struct file_lock___24 *);
	int (*lm_change)(struct file_lock___24 **, int);
};

struct fasync_struct___24 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___24 *fa_next;
	struct file___24 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___24 {
	const char *name;
	int fs_flags;
	struct dentry___25 * (*mount)(struct file_system_type___24 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___25 *);
	struct module___12 *owner;
	struct file_system_type___24 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___24 {
	struct inode___25 * (*alloc_inode)(struct super_block___25 *);
	void (*destroy_inode)(struct inode___25 *);
	void (*dirty_inode)(struct inode___25 *, int);
	int (*write_inode)(struct inode___25 *, struct writeback_control *);
	int (*drop_inode)(struct inode___25 *);
	void (*evict_inode)(struct inode___25 *);
	void (*put_super)(struct super_block___25 *);
	int (*sync_fs)(struct super_block___25 *, int);
	int (*freeze_fs)(struct super_block___25 *);
	int (*unfreeze_fs)(struct super_block___25 *);
	int (*statfs)(struct dentry___25 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___25 *, int *, char *);
	void (*umount_begin)(struct super_block___25 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___25 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___25 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___25 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___25 *);
	ssize_t (*quota_read)(struct super_block___25 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___25 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___25 *);
	int (*bdev_try_to_free_page)(struct super_block___25 *, struct page___24 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___25 *);
	void (*free_cached_objects)(struct super_block___25 *, int);
};

struct xattr_handler___13 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___25 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___25 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___25 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___19 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___24 *page;
};

struct bus_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___20 *, char *);
	ssize_t (*store)(struct bus_type___20 *, const char *, size_t);
};

struct device_attribute___20;

struct driver_attribute___20;

struct bus_type___20 {
	const char *name;
	const char *dev_name;
	struct device___20 *dev_root;
	struct bus_attribute___20 *bus_attrs;
	struct device_attribute___20 *dev_attrs;
	struct driver_attribute___20 *drv_attrs;
	const struct attribute_group___18 **bus_groups;
	const struct attribute_group___18 **dev_groups;
	const struct attribute_group___18 **drv_groups;
	int (*match)(struct device___20 *, struct device_driver___20 *);
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	int (*probe)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*online)(struct device___20 *);
	int (*offline)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct device___20 *, struct device_attribute___20 *, char *);
	ssize_t (*store)(struct device___20 *, struct device_attribute___20 *, const char *, size_t);
};

struct driver_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___20 *, char *);
	ssize_t (*store)(struct device_driver___20 *, const char *, size_t);
};

struct device_driver___20 {
	const char *name;
	struct bus_type___20 *bus;
	struct module___12 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct attribute_group___18 **groups;
	const struct dev_pm_ops___20 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___20 {
	const char *name;
	const struct attribute_group___18 **groups;
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
};

struct class_attribute___20;

struct class___20 {
	const char *name;
	struct module___12 *owner;
	struct class_attribute___20 *class_attrs;
	struct device_attribute___20 *dev_attrs;
	const struct attribute_group___18 **dev_groups;
	struct bin_attribute___18 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *);
	void (*class_release)(struct class___20 *);
	void (*dev_release)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	struct subsys_private *p;
};

struct class_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct class___20 *, struct class_attribute___20 *, char *);
	ssize_t (*store)(struct class___20 *, struct class_attribute___20 *, const char *, size_t);
	const void * (*namespace)(struct class___20 *, const struct class_attribute___20 *);
};

struct device_rh___20 {
	struct dev_pm_info_rh___20 power;
};

struct cgroupfs_root___13;

struct cgroup___13 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___13 *parent;
	struct dentry___25 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___13 *subsys[11];
	struct cgroupfs_root___13 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___25 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___13 {
	struct super_block___25 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___13 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___13;

struct pmu___13 {
	struct list_head entry;
	struct device___20 *dev;
	const struct attribute_group___18 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___13 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___13 *);
	void (*pmu_disable)(struct pmu___13 *);
	int (*event_init)(struct perf_event___13 *);
	int (*add)(struct perf_event___13 *, int);
	void (*del)(struct perf_event___13 *, int);
	void (*start)(struct perf_event___13 *, int);
	void (*stop)(struct perf_event___13 *, int);
	void (*read)(struct perf_event___13 *);
	void (*start_txn)(struct pmu___13 *);
	int (*commit_txn)(struct pmu___13 *);
	void (*cancel_txn)(struct pmu___13 *);
	int (*event_idx)(struct perf_event___13 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___12 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___13 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___13 *);
};

struct perf_cpu_context___13 {
	struct perf_event_context___13 ctx;
	struct perf_event_context___13 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___13 *unique_pmu;
	struct perf_cgroup___13 *cgrp;
};

struct perf_cgroup___13 {
	struct cgroup_subsys_state___13 css;
	struct perf_cgroup_info *info;
};

struct perf_pmu_events_attr___3 {
	struct device_attribute___20 attr;
	u64 id;
	const char *event_str;
};

struct amd_nb___5 {
	int nb_id;
	int refcnt;
	struct perf_event___13 *owners[64];
	struct event_constraint event_constraints[64];
};

struct cpu_hw_events___5 {
	struct perf_event___13 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___13 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb___5 *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

struct x86_pmu___5 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___13 *);
	void (*disable)(struct perf_event___13 *);
	int (*hw_config)(struct perf_event___13 *);
	int (*schedule_events)(struct cpu_hw_events___5 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___5 *, int, struct perf_event___13 *);
	void (*put_event_constraints)(struct cpu_hw_events___5 *, struct perf_event___13 *);
	void (*commit_scheduling)(struct cpu_hw_events___5 *, int, int);
	void (*start_scheduling)(struct cpu_hw_events___5 *);
	void (*stop_scheduling)(struct cpu_hw_events___5 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___13 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___13 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___13 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

struct rapl_pmu {
	spinlock_t lock;
	int n_active;
	struct list_head active_list;
	struct pmu___13 *pmu;
	ktime_t timer_interval;
	struct hrtimer hrtimer;
};

struct intel_pqr_state {
	u32 rmid;
	u32 closid;
	int rmid_usecnt;
};

enum rmid_recycle_state {
	RMID_YOUNG = 0,
	RMID_AVAILABLE = 1,
	RMID_DIRTY = 2,
};

struct cqm_rmid_entry {
	u32 rmid;
	enum rmid_recycle_state state;
	struct list_head list;
	long unsigned int queue_time;
};

struct rmid_read {
	u32 rmid;
	atomic64_t value;
};

struct miscdevice {
	int minor;
	const char *name;
	const struct file_operations___12 *fops;
	struct list_head list;
	struct device___8 *parent;
	struct device___8 *this_device;
	const char *nodename;
	umode_t mode;
};

struct dev_ext_attribute {
	struct device_attribute___8 attr;
	void *var;
};

typedef struct poll_table_struct___7 poll_table;

enum mf_flags {
	MF_COUNT_INCREASED = 1,
	MF_ACTION_REQUIRED = 2,
	MF_MUST_KILL = 4,
	MF_SOFT_OFFLINE = 8,
};

struct mce {
	__u64 status;
	__u64 misc;
	__u64 addr;
	__u64 mcgstatus;
	__u64 ip;
	__u64 tsc;
	__u64 time;
	__u8 cpuvendor;
	__u8 inject_flags;
	__u16 pad;
	__u32 cpuid;
	__u8 cs;
	__u8 bank;
	__u8 cpu;
	__u8 finished;
	__u32 extcpu;
	__u32 socketid;
	__u32 apicid;
	__u64 mcgcap;
};

struct mce_log {
	char signature[12];
	unsigned int len;
	unsigned int next;
	unsigned int flags;
	unsigned int recordlen;
	struct mce entry[32];
};

struct mca_config {
	bool dont_log_ce;
	bool cmci_disabled;
	bool lmce_disabled;
	bool ignore_ce;
	bool disabled;
	bool ser;
	bool bios_cmci_threshold;
	u8 banks;
	s8 bootlog;
	int tolerant;
	int monarch_timeout;
	int panic_timeout;
	u32 rip_msr;
};

struct mce_vendor_flags {
	__u64 overflow_recov: 1;
	__u64 __reserved_0: 63;
};

typedef long unsigned int mce_banks_t[1];

enum mcp_flags {
	MCP_TIMESTAMP = 1,
	MCP_UC = 2,
	MCP_DONTLOG = 4,
};

enum severity_level {
	MCE_NO_SEVERITY = 0,
	MCE_DEFERRED_SEVERITY = 1,
	MCE_UCNA_SEVERITY = 1,
	MCE_KEEP_SEVERITY = 2,
	MCE_SOME_SEVERITY = 3,
	MCE_AO_SEVERITY = 4,
	MCE_UC_SEVERITY = 5,
	MCE_AR_SEVERITY = 6,
	MCE_PANIC_SEVERITY = 7,
};

struct mce_bank {
	u64 ctl;
	unsigned char init;
	struct device_attribute___8 attr;
	char attrname[16];
};

struct ftrace_raw_mce_record {
	struct trace_entry ent;
	u64 mcgcap;
	u64 mcgstatus;
	u64 status;
	u64 addr;
	u64 misc;
	u64 ip;
	u64 tsc;
	u64 walltime;
	u32 cpu;
	u32 cpuid;
	u32 apicid;
	u32 socketid;
	u8 cs;
	u8 bank;
	u8 cpuvendor;
	char __data[0];
};

struct ftrace_data_offsets_mce_record {};

struct mce_ring {
	short unsigned int start;
	short unsigned int end;
	long unsigned int ring[16];
};

enum context {
	IN_KERNEL = 1,
	IN_USER = 2,
};

enum ser {
	SER_REQUIRED = 1,
	NO_SER = 2,
};

enum exception {
	EXCP_CONTEXT = 1,
	NO_EXCP = 2,
};

struct severity {
	u64 mask;
	u64 result;
	unsigned char sev;
	unsigned char mcgmask;
	unsigned char mcgres;
	unsigned char ser;
	unsigned char context;
	unsigned char excp;
	unsigned char covered;
	char *msg;
};

enum {
	CMCI_STORM_NONE = 0,
	CMCI_STORM_ACTIVE = 1,
	CMCI_STORM_SUBSIDED = 2,
};

struct dma_map_ops___9;

struct dev_archdata___9 {
	struct dma_map_ops___9 *dma_ops;
	void *iommu;
};

struct device_type___21;

struct bus_type___21;

struct device_driver___21;

struct dev_pm_domain___21;

struct class___21;

struct attribute_group___19;

struct device_rh___21;

struct device___21 {
	struct device___21 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___21 *type;
	struct mutex mutex;
	struct bus_type___21 *bus;
	struct device_driver___21 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___21 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___9 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___5 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___21 *class;
	const struct attribute_group___19 **groups;
	void (*release)(struct device___21 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___21 *device_rh;
};

struct pci_bus___5;

struct pci_slot___5;

struct pci_driver___5;

struct bin_attribute___19;

struct pci_dev___5 {
	struct list_head bus_list;
	struct pci_bus___5 *bus;
	struct pci_bus___5 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___5 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___5 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___21 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___19 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___19 *res_attr[17];
	struct bin_attribute___19 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___19 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___5 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___21 {
	int (*prepare)(struct device___21 *);
	void (*complete)(struct device___21 *);
	int (*suspend)(struct device___21 *);
	int (*resume)(struct device___21 *);
	int (*freeze)(struct device___21 *);
	int (*thaw)(struct device___21 *);
	int (*poweroff)(struct device___21 *);
	int (*restore)(struct device___21 *);
	int (*suspend_late)(struct device___21 *);
	int (*resume_early)(struct device___21 *);
	int (*freeze_late)(struct device___21 *);
	int (*thaw_early)(struct device___21 *);
	int (*poweroff_late)(struct device___21 *);
	int (*restore_early)(struct device___21 *);
	int (*suspend_noirq)(struct device___21 *);
	int (*resume_noirq)(struct device___21 *);
	int (*freeze_noirq)(struct device___21 *);
	int (*thaw_noirq)(struct device___21 *);
	int (*poweroff_noirq)(struct device___21 *);
	int (*restore_noirq)(struct device___21 *);
	int (*runtime_suspend)(struct device___21 *);
	int (*runtime_resume)(struct device___21 *);
	int (*runtime_idle)(struct device___21 *);
};

struct dev_pm_info_rh___21 {
	void (*set_latency_tolerance)(struct device___21 *, s32);
};

struct dev_pm_domain___21 {
	struct dev_pm_ops___21 ops;
};

struct attribute_group___19 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___19 **bin_attrs;
};

struct bin_attribute___19 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file *, struct kobject *, struct bin_attribute___19 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file *, struct kobject *, struct bin_attribute___19 *, char *, loff_t, size_t);
	int (*mmap)(struct file *, struct kobject *, struct bin_attribute___19 *, struct vm_area_struct___16 *);
};

struct dma_map_ops___9 {
	void * (*alloc)(struct device___21 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___21 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___21 *, struct vm_area_struct___16 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___21 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___21 *, struct page___24 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___21 *, dma_addr_t);
	int (*dma_supported)(struct device___21 *, u64);
	int (*set_dma_mask)(struct device___21 *, u64);
	int is_phys;
};

struct bus_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___21 *, char *);
	ssize_t (*store)(struct bus_type___21 *, const char *, size_t);
};

struct device_attribute___21;

struct driver_attribute___21;

struct bus_type___21 {
	const char *name;
	const char *dev_name;
	struct device___21 *dev_root;
	struct bus_attribute___21 *bus_attrs;
	struct device_attribute___21 *dev_attrs;
	struct driver_attribute___21 *drv_attrs;
	const struct attribute_group___19 **bus_groups;
	const struct attribute_group___19 **dev_groups;
	const struct attribute_group___19 **drv_groups;
	int (*match)(struct device___21 *, struct device_driver___21 *);
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	int (*probe)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*online)(struct device___21 *);
	int (*offline)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct device___21 *, struct device_attribute___21 *, char *);
	ssize_t (*store)(struct device___21 *, struct device_attribute___21 *, const char *, size_t);
};

struct driver_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___21 *, char *);
	ssize_t (*store)(struct device_driver___21 *, const char *, size_t);
};

struct device_driver___21 {
	const char *name;
	struct bus_type___21 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct attribute_group___19 **groups;
	const struct dev_pm_ops___21 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___21 {
	const char *name;
	const struct attribute_group___19 **groups;
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
};

struct class_attribute___21;

struct class___21 {
	const char *name;
	struct module *owner;
	struct class_attribute___21 *class_attrs;
	struct device_attribute___21 *dev_attrs;
	const struct attribute_group___19 **dev_groups;
	struct bin_attribute___19 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *);
	void (*class_release)(struct class___21 *);
	void (*dev_release)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	struct subsys_private *p;
};

struct class_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct class___21 *, struct class_attribute___21 *, char *);
	ssize_t (*store)(struct class___21 *, struct class_attribute___21 *, const char *, size_t);
	const void * (*namespace)(struct class___21 *, const struct class_attribute___21 *);
};

struct device_rh___21 {
	struct dev_pm_info_rh___21 power;
};

struct pci_slot___5 {
	struct pci_bus___5 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___5;

struct pci_bus___5 {
	struct list_head node;
	struct pci_bus___5 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___5 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___5 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___21 *bridge;
	struct device___21 dev;
	struct bin_attribute___19 *legacy_io;
	struct bin_attribute___19 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___5;

struct pci_driver_rh___5;

struct pci_driver___5 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___5 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___5 *);
	int (*suspend)(struct pci_dev___5 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___5 *, pm_message_t);
	int (*resume_early)(struct pci_dev___5 *);
	int (*resume)(struct pci_dev___5 *);
	void (*shutdown)(struct pci_dev___5 *);
	int (*sriov_configure)(struct pci_dev___5 *, int);
	const struct pci_error_handlers___5 *err_handler;
	struct device_driver___21 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___5 *pci_driver_rh;
};

struct pci_ops___5 {
	int (*read)(struct pci_bus___5 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___5 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___5 {
	pci_ers_result_t (*error_detected)(struct pci_dev___5 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___5 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___5 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___5 *);
	void (*resume)(struct pci_dev___5 *);
};

struct pci_driver_rh___5 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___5 *, bool);
};

struct amd_northbridge___3 {
	struct pci_dev___5 *misc;
	struct pci_dev___5 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info___3 {
	u16 num;
	u64 flags;
	struct amd_northbridge___3 *nb;
};

struct thresh_restart {
	struct threshold_block *b;
	int reset;
	int set_lvt_off;
	int lvt_off;
	u16 old_limit;
};

struct threshold_attr {
	struct attribute attr;
	ssize_t (*show)(struct threshold_block *, char *);
	ssize_t (*store)(struct threshold_block *, const char *, size_t);
};

struct device___22;

struct dev_pm_ops___22 {
	int (*prepare)(struct device___22 *);
	void (*complete)(struct device___22 *);
	int (*suspend)(struct device___22 *);
	int (*resume)(struct device___22 *);
	int (*freeze)(struct device___22 *);
	int (*thaw)(struct device___22 *);
	int (*poweroff)(struct device___22 *);
	int (*restore)(struct device___22 *);
	int (*suspend_late)(struct device___22 *);
	int (*resume_early)(struct device___22 *);
	int (*freeze_late)(struct device___22 *);
	int (*thaw_early)(struct device___22 *);
	int (*poweroff_late)(struct device___22 *);
	int (*restore_early)(struct device___22 *);
	int (*suspend_noirq)(struct device___22 *);
	int (*resume_noirq)(struct device___22 *);
	int (*freeze_noirq)(struct device___22 *);
	int (*thaw_noirq)(struct device___22 *);
	int (*poweroff_noirq)(struct device___22 *);
	int (*restore_noirq)(struct device___22 *);
	int (*runtime_suspend)(struct device___22 *);
	int (*runtime_resume)(struct device___22 *);
	int (*runtime_idle)(struct device___22 *);
};

struct device_type___22;

struct bus_type___22;

struct device_driver___22;

struct dev_pm_domain___22;

struct class___22;

struct device_rh___22;

struct device___22 {
	struct device___22 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___22 *type;
	struct mutex___15 mutex;
	struct bus_type___22 *bus;
	struct device_driver___22 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___22 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___9 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___7 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___22 *class;
	const struct attribute_group___19 **groups;
	void (*release)(struct device___22 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___22 *device_rh;
};

struct dev_pm_info_rh___22 {
	void (*set_latency_tolerance)(struct device___22 *, s32);
};

struct dev_pm_domain___22 {
	struct dev_pm_ops___22 ops;
};

struct bus_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___22 *, char *);
	ssize_t (*store)(struct bus_type___22 *, const char *, size_t);
};

struct device_attribute___22;

struct driver_attribute___22;

struct bus_type___22 {
	const char *name;
	const char *dev_name;
	struct device___22 *dev_root;
	struct bus_attribute___22 *bus_attrs;
	struct device_attribute___22 *dev_attrs;
	struct driver_attribute___22 *drv_attrs;
	const struct attribute_group___19 **bus_groups;
	const struct attribute_group___19 **dev_groups;
	const struct attribute_group___19 **drv_groups;
	int (*match)(struct device___22 *, struct device_driver___22 *);
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	int (*probe)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*online)(struct device___22 *);
	int (*offline)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct device___22 *, struct device_attribute___22 *, char *);
	ssize_t (*store)(struct device___22 *, struct device_attribute___22 *, const char *, size_t);
};

struct driver_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___22 *, char *);
	ssize_t (*store)(struct device_driver___22 *, const char *, size_t);
};

struct device_driver___22 {
	const char *name;
	struct bus_type___22 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct attribute_group___19 **groups;
	const struct dev_pm_ops___22 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___22 {
	const char *name;
	const struct attribute_group___19 **groups;
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
};

struct class_attribute___22;

struct class___22 {
	const char *name;
	struct module *owner;
	struct class_attribute___22 *class_attrs;
	struct device_attribute___22 *dev_attrs;
	const struct attribute_group___19 **dev_groups;
	struct bin_attribute___19 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *);
	void (*class_release)(struct class___22 *);
	void (*dev_release)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	struct subsys_private *p;
};

struct class_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct class___22 *, struct class_attribute___22 *, char *);
	ssize_t (*store)(struct class___22 *, struct class_attribute___22 *, const char *, size_t);
	const void * (*namespace)(struct class___22 *, const struct class_attribute___22 *);
};

struct device_rh___22 {
	struct dev_pm_info_rh___22 power;
};

struct _thermal_state {
	bool new_event;
	int event;
	u64 next_check;
	long unsigned int count;
	long unsigned int last_count;
};

struct thermal_state {
	struct _thermal_state core_throttle;
	struct _thermal_state core_power_limit;
	struct _thermal_state package_throttle;
	struct _thermal_state package_power_limit;
	struct _thermal_state core_thresh0;
	struct _thermal_state core_thresh1;
	struct _thermal_state pkg_thresh0;
	struct _thermal_state pkg_thresh1;
};

typedef struct {
	__u8 b[16];
} uuid_le;

enum {
	CPER_SEV_RECOVERABLE = 0,
	CPER_SEV_FATAL = 1,
	CPER_SEV_CORRECTED = 2,
	CPER_SEV_INFORMATIONAL = 3,
};

struct cper_record_header {
	char signature[4];
	__u16 revision;
	__u32 signature_end;
	__u16 section_count;
	__u32 error_severity;
	__u32 validation_bits;
	__u32 record_length;
	__u64 timestamp;
	uuid_le platform_id;
	uuid_le partition_id;
	uuid_le creator_id;
	uuid_le notification_type;
	__u64 record_id;
	__u32 flags;
	__u64 persistence_information;
	__u8 reserved[12];
} __attribute__((packed));

struct cper_section_descriptor {
	__u32 section_offset;
	__u32 section_length;
	__u16 revision;
	__u8 validation_bits;
	__u8 reserved;
	__u32 flags;
	uuid_le section_type;
	uuid_le fru_id;
	__u32 section_severity;
	__u8 fru_text[20];
};

struct cper_sec_mem_err {
	__u64 validation_bits;
	__u64 error_status;
	__u64 physical_addr;
	__u64 physical_addr_mask;
	__u16 node;
	__u16 card;
	__u16 module;
	__u16 bank;
	__u16 device;
	__u16 row;
	__u16 column;
	__u16 bit_pos;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 target_id;
	__u8 error_type;
	__u8 reserved;
	__u16 rank;
	__u16 mem_array_handle;
	__u16 mem_dev_handle;
};

enum {
	GHES_SEV_NO = 0,
	GHES_SEV_CORRECTED = 1,
	GHES_SEV_RECOVERABLE = 2,
	GHES_SEV_PANIC = 3,
};

struct cper_mce_record {
	struct cper_record_header hdr;
	struct cper_section_descriptor sec_hdr;
	struct mce mce;
};

struct page___25;

typedef struct page___25 *pgtable_t___25;

struct address_space___25;

struct kmem_cache___22;

struct page___25 {
	long unsigned int flags;
	struct address_space___25 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___25 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___25 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___22 *slab_cache;
		struct page___25 *first_page;
	};
	long: 64;
};

struct task_struct___26;

struct pv_cpu_ops___25 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___13 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___13 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___26 *);
	void (*end_context_switch)(struct task_struct___26 *);
};

struct mutex___26 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___26 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___23 {
	struct page___25 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___28;

struct signal_struct___25;

struct task_struct___26 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___26 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___28 *mm;
	struct mm_struct___28 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___26 *real_parent;
	struct task_struct___26 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___26 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___14 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___25 = 0,
		VTIME_USER___25 = 1,
		VTIME_SYS___25 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___13 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___25 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___26 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___23 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___28 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___28 *, struct mm_struct___28 *);
	void (*dup_mmap)(struct mm_struct___28 *, struct mm_struct___28 *);
	void (*exit_mmap)(struct mm_struct___28 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___28 *);
	void (*pgd_free)(struct mm_struct___28 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___28 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___28 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___28 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___28 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___28 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___28 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___28 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___28 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___28 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___28 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___28 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___26 lock;
	void *vdso;
} mm_context_t___26;

struct xol_area___25;

struct uprobes_state___25 {
	struct xol_area___25 *xol_area;
};

struct vm_area_struct___28;

struct file___25;

struct core_state___25;

struct mm_struct___28 {
	struct vm_area_struct___28 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___28 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___28 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___26 context;
	long unsigned int flags;
	struct core_state___25 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___26 *owner;
	struct file___25 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___25 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___13;

struct module_kobject___12 {
	struct kobject kobj;
	struct module___13 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___12;

struct module___13 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___12 mkobj;
	struct module_attribute___12 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___26 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct bin_attribute___20;

struct attribute_group___20 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___20 **bin_attrs;
};

struct bin_attribute___20 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___25 *, struct kobject *, struct bin_attribute___20 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___25 *, struct kobject *, struct bin_attribute___20 *, char *, loff_t, size_t);
	int (*mmap)(struct file___25 *, struct kobject *, struct bin_attribute___20 *, struct vm_area_struct___28 *);
};

struct dentry___26;

struct path___25 {
	struct vfsmount *mnt;
	struct dentry___26 *dentry;
};

struct inode___26;

struct file_operations___25;

struct file___25 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___25 f_path;
	struct inode___26 *f_inode;
	const struct file_operations___25 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___25 *f_mapping;
	struct mutex___26 f_pos_lock;
};

struct vm_operations_struct___22;

struct vm_area_struct___28 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___28 *vm_next;
	struct vm_area_struct___28 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___28 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___22 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___25 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___23;

struct dev_pm_ops___23 {
	int (*prepare)(struct device___23 *);
	void (*complete)(struct device___23 *);
	int (*suspend)(struct device___23 *);
	int (*resume)(struct device___23 *);
	int (*freeze)(struct device___23 *);
	int (*thaw)(struct device___23 *);
	int (*poweroff)(struct device___23 *);
	int (*restore)(struct device___23 *);
	int (*suspend_late)(struct device___23 *);
	int (*resume_early)(struct device___23 *);
	int (*freeze_late)(struct device___23 *);
	int (*thaw_early)(struct device___23 *);
	int (*poweroff_late)(struct device___23 *);
	int (*restore_early)(struct device___23 *);
	int (*suspend_noirq)(struct device___23 *);
	int (*resume_noirq)(struct device___23 *);
	int (*freeze_noirq)(struct device___23 *);
	int (*thaw_noirq)(struct device___23 *);
	int (*poweroff_noirq)(struct device___23 *);
	int (*restore_noirq)(struct device___23 *);
	int (*runtime_suspend)(struct device___23 *);
	int (*runtime_resume)(struct device___23 *);
	int (*runtime_idle)(struct device___23 *);
};

struct dma_map_ops___10;

struct dev_archdata___10 {
	struct dma_map_ops___10 *dma_ops;
	void *iommu;
};

struct device_type___23;

struct bus_type___23;

struct device_driver___23;

struct dev_pm_domain___23;

struct class___23;

struct device_rh___23;

struct device___23 {
	struct device___23 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___23 *type;
	struct mutex___26 mutex;
	struct bus_type___23 *bus;
	struct device_driver___23 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___23 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___10 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___7 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___23 *class;
	const struct attribute_group___20 **groups;
	void (*release)(struct device___23 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___23 *device_rh;
};

struct dev_pm_info_rh___23 {
	void (*set_latency_tolerance)(struct device___23 *, s32);
};

struct dev_pm_domain___23 {
	struct dev_pm_ops___23 ops;
};

struct zone___25;

struct lruvec___25 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___25 *zone;
};

struct pglist_data___25;

struct zone___25 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___25 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___25 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___25 {
	struct zone___25 *zone;
	int zone_idx;
};

struct zonelist___25 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___25 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___25 {
	struct zone___25 node_zones[4];
	struct zonelist___25 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___26 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_bus___6;

struct pci_slot___6;

struct pci_driver___6;

struct pci_dev___6 {
	struct list_head bus_list;
	struct pci_bus___6 *bus;
	struct pci_bus___6 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___6 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___6 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___23 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___20 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___20 *res_attr[17];
	struct bin_attribute___20 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___20 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___6 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct smp_ops___25 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___26 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___10 {
	void * (*alloc)(struct device___23 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___23 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___23 *, struct vm_area_struct___28 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___23 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___23 *, struct page___25 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___23 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___23 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___23 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___23 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___23 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___23 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___23 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___23 *, dma_addr_t);
	int (*dma_supported)(struct device___23 *, u64);
	int (*set_dma_mask)(struct device___23 *, u64);
	int is_phys;
};

struct bus_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___23 *, char *);
	ssize_t (*store)(struct bus_type___23 *, const char *, size_t);
};

struct device_attribute___23;

struct driver_attribute___23;

struct bus_type___23 {
	const char *name;
	const char *dev_name;
	struct device___23 *dev_root;
	struct bus_attribute___23 *bus_attrs;
	struct device_attribute___23 *dev_attrs;
	struct driver_attribute___23 *drv_attrs;
	const struct attribute_group___20 **bus_groups;
	const struct attribute_group___20 **dev_groups;
	const struct attribute_group___20 **drv_groups;
	int (*match)(struct device___23 *, struct device_driver___23 *);
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	int (*probe)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*online)(struct device___23 *);
	int (*offline)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct device___23 *, struct device_attribute___23 *, char *);
	ssize_t (*store)(struct device___23 *, struct device_attribute___23 *, const char *, size_t);
};

struct driver_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___23 *, char *);
	ssize_t (*store)(struct device_driver___23 *, const char *, size_t);
};

struct device_driver___23 {
	const char *name;
	struct bus_type___23 *bus;
	struct module___13 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct attribute_group___20 **groups;
	const struct dev_pm_ops___23 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___23 {
	const char *name;
	const struct attribute_group___20 **groups;
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
};

struct class_attribute___23;

struct class___23 {
	const char *name;
	struct module___13 *owner;
	struct class_attribute___23 *class_attrs;
	struct device_attribute___23 *dev_attrs;
	const struct attribute_group___20 **dev_groups;
	struct bin_attribute___20 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *);
	void (*class_release)(struct class___23 *);
	void (*dev_release)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	struct subsys_private *p;
};

struct class_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct class___23 *, struct class_attribute___23 *, char *);
	ssize_t (*store)(struct class___23 *, struct class_attribute___23 *, const char *, size_t);
	const void * (*namespace)(struct class___23 *, const struct class_attribute___23 *);
};

struct device_rh___23 {
	struct dev_pm_info_rh___23 power;
};

struct module_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___12 *, struct module_kobject___12 *, char *);
	ssize_t (*store)(struct module_attribute___12 *, struct module_kobject___12 *, const char *, size_t);
	void (*setup)(struct module___13 *, const char *);
	int (*test)(struct module___13 *);
	void (*free)(struct module___13 *);
};

struct pci_slot___6 {
	struct pci_bus___6 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___6;

struct pci_bus___6 {
	struct list_head node;
	struct pci_bus___6 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___6 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___6 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___23 *bridge;
	struct device___23 dev;
	struct bin_attribute___20 *legacy_io;
	struct bin_attribute___20 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___6;

struct pci_driver_rh___6;

struct pci_driver___6 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___6 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___6 *);
	int (*suspend)(struct pci_dev___6 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___6 *, pm_message_t);
	int (*resume_early)(struct pci_dev___6 *);
	int (*resume)(struct pci_dev___6 *);
	void (*shutdown)(struct pci_dev___6 *);
	int (*sriov_configure)(struct pci_dev___6 *, int);
	const struct pci_error_handlers___6 *err_handler;
	struct device_driver___23 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___6 *pci_driver_rh;
};

struct pci_ops___6 {
	int (*read)(struct pci_bus___6 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___6 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___6 {
	pci_ers_result_t (*error_detected)(struct pci_dev___6 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___6 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___6 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___6 *);
	void (*resume)(struct pci_dev___6 *);
};

struct pci_driver_rh___6 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___6 *, bool);
};

struct xol_area___25 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___25 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___22;

struct memcg_cache_params___22;

struct kmem_cache___22 {
	struct kmem_cache_cpu___22 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___22 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___25;

struct address_space___25 {
	struct inode___26 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___26 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___25 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___20;

struct vm_operations_struct___22 {
	void (*open)(struct vm_area_struct___28 *);
	void (*close)(struct vm_area_struct___28 *);
	int (*fault)(struct vm_area_struct___28 *, struct vm_fault___20 *);
	int (*page_mkwrite)(struct vm_area_struct___28 *, struct vm_fault___20 *);
	int (*access)(struct vm_area_struct___28 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___28 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___28 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___28 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___28 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___25 {
	struct task_struct___26 *task;
	struct core_thread___25 *next;
};

struct core_state___25 {
	atomic_t nr_threads;
	struct core_thread___25 dumper;
	struct completion startup;
};

struct vm_fault___20 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___25 *page;
};

struct kmem_cache_cpu___22 {
	void **freelist;
	long unsigned int tid;
	struct page___25 *page;
	struct page___25 *partial;
};

struct memcg_cache_params___22 {
	bool is_root_cache;
	union {
		struct kmem_cache___22 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___22 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef __u8 mtrr_type;

struct dentry_operations___25;

struct super_block___26;

struct dentry___26 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___26 *d_parent;
	struct qstr d_name;
	struct inode___26 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___25 *d_op;
	struct super_block___26 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___25;

struct file_lock___25;

struct dquot___25;

struct block_device___25;

struct inode___26 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___25 *i_op;
	struct super_block___26 *i_sb;
	struct address_space___25 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___26 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___25 *i_fop;
	struct file_lock___25 *i_flock;
	struct address_space___25 i_data;
	struct dquot___25 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___25 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___25 {
	int (*d_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_hash)(const struct dentry___26 *, struct qstr *);
	int (*d_compare)(const struct dentry___26 *, const struct dentry___26 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___26 *);
	void (*d_release)(struct dentry___26 *);
	void (*d_prune)(struct dentry___26 *);
	void (*d_iput)(struct dentry___26 *, struct inode___26 *);
	char * (*d_dname)(struct dentry___26 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___25 *);
	int (*d_manage)(struct dentry___26 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___25;

struct mem_dqinfo___25 {
	struct quota_format_type___25 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___25;

struct quota_info___25 {
	unsigned int flags;
	struct mutex___26 dqio_mutex;
	struct mutex___26 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___26 *files[2];
	struct mem_dqinfo___25 info[2];
	const struct quota_format_ops___25 *ops[2];
};

struct file_system_type___25;

struct super_operations___25;

struct dquot_operations___25;

struct quotactl_ops___25;

struct super_block___26 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___25 *s_type;
	const struct super_operations___25 *s_op;
	const struct dquot_operations___25 *dq_op;
	const struct quotactl_ops___25 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___26 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___25 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___25 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___26 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___25 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___25 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___26 *bd_inode;
	struct super_block___26 *bd_super;
	struct mutex___26 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___25 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___26 bd_fsfreeze_mutex;
};

struct iattr___26 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___25 *ia_file;
};

struct dquot___25 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___26 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___26 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___25 {
	int qf_fmt_id;
	const struct quota_format_ops___25 *qf_ops;
	struct module___13 *qf_owner;
	struct quota_format_type___25 *qf_next;
};

struct quota_format_ops___25 {
	int (*check_quota_file)(struct super_block___26 *, int);
	int (*read_file_info)(struct super_block___26 *, int);
	int (*write_file_info)(struct super_block___26 *, int);
	int (*free_file_info)(struct super_block___26 *, int);
	int (*read_dqblk)(struct dquot___25 *);
	int (*commit_dqblk)(struct dquot___25 *);
	int (*release_dqblk)(struct dquot___25 *);
};

struct dquot_operations___25 {
	int (*write_dquot)(struct dquot___25 *);
	struct dquot___25 * (*alloc_dquot)(struct super_block___26 *, int);
	void (*destroy_dquot)(struct dquot___25 *);
	int (*acquire_dquot)(struct dquot___25 *);
	int (*release_dquot)(struct dquot___25 *);
	int (*mark_dirty)(struct dquot___25 *);
	int (*write_info)(struct super_block___26 *, int);
	qsize_t * (*get_reserved_space)(struct inode___26 *);
};

struct quotactl_ops___25 {
	int (*quota_on)(struct super_block___26 *, int, int, struct path___25 *);
	int (*quota_on_meta)(struct super_block___26 *, int, int);
	int (*quota_off)(struct super_block___26 *, int);
	int (*quota_sync)(struct super_block___26 *, int);
	int (*get_info)(struct super_block___26 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___26 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___26 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___26 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___26 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___26 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___26 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___26 *, unsigned int);
};

struct address_space_operations___25 {
	int (*writepage)(struct page___25 *, struct writeback_control *);
	int (*readpage)(struct file___25 *, struct page___25 *);
	int (*writepages)(struct address_space___25 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___25 *);
	int (*readpages)(struct file___25 *, struct address_space___25 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___25 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___25 **, void **);
	int (*write_end)(struct file___25 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___25 *, void *);
	sector_t (*bmap)(struct address_space___25 *, sector_t);
	void (*invalidatepage)(struct page___25 *, long unsigned int);
	int (*releasepage)(struct page___25 *, gfp_t);
	void (*freepage)(struct page___25 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___25 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___25 *, struct page___25 *, struct page___25 *, enum migrate_mode);
	int (*launder_page)(struct page___25 *);
	int (*is_partially_uptodate)(struct page___25 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___25 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___25 *, struct page___25 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___25 *, sector_t *);
	void (*swap_deactivate)(struct file___25 *);
	void (*invalidatepage_range)(struct page___25 *, unsigned int, unsigned int);
};

struct inode_operations___25 {
	struct dentry___26 * (*lookup)(struct inode___26 *, struct dentry___26 *, unsigned int);
	void * (*follow_link)(struct dentry___26 *, struct nameidata *);
	int (*permission)(struct inode___26 *, int);
	struct posix_acl * (*get_acl)(struct inode___26 *, int);
	int (*readlink)(struct dentry___26 *, char *, int);
	void (*put_link)(struct dentry___26 *, struct nameidata *, void *);
	int (*create)(struct inode___26 *, struct dentry___26 *, umode_t, bool);
	int (*link)(struct dentry___26 *, struct inode___26 *, struct dentry___26 *);
	int (*unlink)(struct inode___26 *, struct dentry___26 *);
	int (*symlink)(struct inode___26 *, struct dentry___26 *, const char *);
	int (*mkdir)(struct inode___26 *, struct dentry___26 *, umode_t);
	int (*rmdir)(struct inode___26 *, struct dentry___26 *);
	int (*mknod)(struct inode___26 *, struct dentry___26 *, umode_t, dev_t);
	int (*rename)(struct inode___26 *, struct dentry___26 *, struct inode___26 *, struct dentry___26 *);
	int (*setattr)(struct dentry___26 *, struct iattr___26 *);
	int (*getattr)(struct vfsmount *, struct dentry___26 *, struct kstat *);
	int (*setxattr)(struct dentry___26 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___26 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___26 *, char *, size_t);
	int (*removexattr)(struct dentry___26 *, const char *);
	int (*fiemap)(struct inode___26 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___26 *, struct timespec *, int);
	int (*atomic_open)(struct inode___26 *, struct dentry___26 *, struct file___25 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___25 {
	struct module___13 *owner;
	loff_t (*llseek)(struct file___25 *, loff_t, int);
	ssize_t (*read)(struct file___25 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___25 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___25 *, void *, filldir_t);
	unsigned int (*poll)(struct file___25 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___25 *, struct vm_area_struct___28 *);
	int (*open)(struct inode___26 *, struct file___25 *);
	int (*flush)(struct file___25 *, fl_owner_t);
	int (*release)(struct inode___26 *, struct file___25 *);
	int (*fsync)(struct file___25 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___25 *, int);
	int (*lock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*sendpage)(struct file___25 *, struct page___25 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___25 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___25 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___25 *, long int, struct file_lock___25 **, void **);
		struct {
			int (*setlease)(struct file___25 *, long int, struct file_lock___25 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___25 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___25 *);
};

struct fasync_struct___25;

struct file_lock_operations___25;

struct lock_manager_operations___25;

struct file_lock___25 {
	struct file_lock___25 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___14 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___25 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___25 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___25 *fl_ops;
	const struct lock_manager_operations___25 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___25 {
	void (*fl_copy_lock)(struct file_lock___25 *, struct file_lock___25 *);
	void (*fl_release_private)(struct file_lock___25 *);
};

struct lock_manager_operations___25 {
	int (*lm_compare_owner)(struct file_lock___25 *, struct file_lock___25 *);
	long unsigned int (*lm_owner_key)(struct file_lock___25 *);
	void (*lm_notify)(struct file_lock___25 *);
	int (*lm_grant)(struct file_lock___25 *, struct file_lock___25 *, int);
	void (*lm_break)(struct file_lock___25 *);
	int (*lm_change)(struct file_lock___25 **, int);
};

struct fasync_struct___25 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___25 *fa_next;
	struct file___25 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___25 {
	const char *name;
	int fs_flags;
	struct dentry___26 * (*mount)(struct file_system_type___25 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___26 *);
	struct module___13 *owner;
	struct file_system_type___25 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___25 {
	struct inode___26 * (*alloc_inode)(struct super_block___26 *);
	void (*destroy_inode)(struct inode___26 *);
	void (*dirty_inode)(struct inode___26 *, int);
	int (*write_inode)(struct inode___26 *, struct writeback_control *);
	int (*drop_inode)(struct inode___26 *);
	void (*evict_inode)(struct inode___26 *);
	void (*put_super)(struct super_block___26 *);
	int (*sync_fs)(struct super_block___26 *, int);
	int (*freeze_fs)(struct super_block___26 *);
	int (*unfreeze_fs)(struct super_block___26 *);
	int (*statfs)(struct dentry___26 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___26 *, int *, char *);
	void (*umount_begin)(struct super_block___26 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___26 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___26 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___26 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___26 *);
	ssize_t (*quota_read)(struct super_block___26 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___26 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___26 *);
	int (*bdev_try_to_free_page)(struct super_block___26 *, struct page___25 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___26 *);
	void (*free_cached_objects)(struct super_block___26 *, int);
};

struct signal_struct___25 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___26 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___26 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___14 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___26 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mtrr_ops {
	u32 vendor;
	u32 use_intel_if;
	void (*set)(unsigned int, long unsigned int, long unsigned int, mtrr_type);
	void (*set_all)();
	void (*get)(unsigned int, long unsigned int *, long unsigned int *, mtrr_type *);
	int (*get_free_region)(long unsigned int, long unsigned int, int);
	int (*validate_add_page)(long unsigned int, long unsigned int, unsigned int);
	int (*have_wrcomb)();
};

struct set_mtrr_data {
	long unsigned int smp_base;
	long unsigned int smp_size;
	unsigned int smp_reg;
	mtrr_type smp_type;
};

struct mtrr_value {
	mtrr_type ltype;
	long unsigned int lbase;
	long unsigned int lsize;
};

struct mtrr_sentry {
	__u64 base;
	__u32 size;
	__u32 type;
};

struct mtrr_gentry {
	__u64 base;
	__u32 size;
	__u32 regnum;
	__u32 type;
	__u32 _pad;
};

typedef u32 compat_uint_t;

struct mtrr_sentry32 {
	compat_ulong_t base;
	compat_uint_t size;
	compat_uint_t type;
};

struct mtrr_gentry32 {
	compat_ulong_t regnum;
	compat_uint_t base;
	compat_uint_t size;
	compat_uint_t type;
};

struct tlb_state___6 {
	struct mm_struct___27 *active_mm;
	int state;
};

struct mtrr_var_range {
	__u32 base_lo;
	__u32 base_hi;
	__u32 mask_lo;
	__u32 mask_hi;
};

struct mtrr_state_type {
	struct mtrr_var_range var_ranges[256];
	mtrr_type fixed_ranges[88];
	unsigned char enabled;
	unsigned char have_fixed;
	mtrr_type def_type;
};

struct fixed_range_block {
	int base_msr;
	int ranges;
};

struct range {
	u64 start;
	u64 end;
};

struct var_mtrr_range_state {
	long unsigned int base_pfn;
	long unsigned int size_pfn;
	mtrr_type type;
};

struct var_mtrr_state {
	long unsigned int range_startk;
	long unsigned int range_sizek;
	long unsigned int chunk_sizek;
	long unsigned int gran_sizek;
	unsigned int reg;
};

struct mtrr_cleanup_result {
	long unsigned int gran_sizek;
	long unsigned int chunk_sizek;
	long unsigned int lose_cover_sizek;
	unsigned int num_reg;
	int bad;
};

struct kprobe_insn_cache___7 {
	struct mutex___15 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct page___26;

typedef struct page___26 *pgtable_t___26;

struct address_space___26;

struct kmem_cache___23;

struct page___26 {
	long unsigned int flags;
	struct address_space___26 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___26 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___26 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___23 *slab_cache;
		struct page___26 *first_page;
	};
	long: 64;
};

struct thread_struct___14;

struct task_struct___27;

struct pv_cpu_ops___26 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___27 *);
	void (*end_context_switch)(struct task_struct___27 *);
};

struct perf_event___14;

struct thread_struct___14 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___14 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___15;

struct pid_link___15 {
	struct hlist_node node;
	struct pid___15 *pid;
};

struct mutex___27 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___27 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___24 {
	struct page___26 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___29;

struct nsproxy___15;

struct signal_struct___26;

struct css_set___14;

struct perf_event_context___14;

struct task_struct___27 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___27 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___29 *mm;
	struct mm_struct___29 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___27 *real_parent;
	struct task_struct___27 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___27 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___26 = 0,
		VTIME_USER___26 = 1,
		VTIME_SYS___26 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___15 *nsproxy;
	struct signal_struct___26 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___14 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___14 *perf_event_ctxp[2];
	struct mutex___27 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___24 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___29 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___29 *, struct mm_struct___29 *);
	void (*dup_mmap)(struct mm_struct___29 *, struct mm_struct___29 *);
	void (*exit_mmap)(struct mm_struct___29 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___29 *);
	void (*pgd_free)(struct mm_struct___29 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___29 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___29 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___29 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___29 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___29 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___29 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___29 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___29 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___29 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___29 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___29 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___27 lock;
	void *vdso;
} mm_context_t___27;

struct xol_area___26;

struct uprobes_state___26 {
	struct xol_area___26 *xol_area;
};

struct vm_area_struct___29;

struct file___26;

struct core_state___26;

struct mm_struct___29 {
	struct vm_area_struct___29 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___29 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___29 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___27 context;
	long unsigned int flags;
	struct core_state___26 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___27 *owner;
	struct file___26 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___26 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___14;

struct module_kobject___13 {
	struct kobject kobj;
	struct module___14 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___13;

struct module___14 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___13 mkobj;
	struct module_attribute___13 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___27 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___14 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___27 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___27 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___27 *target;
};

typedef void (*perf_overflow_handler_t___14)(struct perf_event___14 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___14;

typedef void (*ftrace_func_t___14)(long unsigned int, long unsigned int, struct ftrace_ops___14 *, struct pt_regs *);

struct ftrace_ops___14 {
	ftrace_func_t___14 func;
	struct ftrace_ops___14 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___27 regex_lock;
};

struct pmu___14;

struct fasync_struct___26;

struct pid_namespace___15;

struct perf_cgroup___14;

struct perf_event___14 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___14 *group_leader;
	struct pmu___14 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___14 hw;
	struct perf_event_context___14 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___27 child_mutex;
	struct list_head child_list;
	struct perf_event___14 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___27 *owner;
	struct mutex___27 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___26 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___14 *);
	struct callback_head callback_head;
	struct pid_namespace___15 *ns;
	u64 id;
	perf_overflow_handler_t___14 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___14 ftrace_ops;
	struct perf_cgroup___14 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___26 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___26 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___23;

struct memcg_cache_params___23;

struct kmem_cache___23 {
	struct kmem_cache_cpu___23 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___23 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___27;

struct address_space_operations___26;

struct address_space___26 {
	struct inode___27 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___27 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___26 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___27;

struct path___26 {
	struct vfsmount *mnt;
	struct dentry___27 *dentry;
};

struct fown_struct___15 {
	rwlock_t lock;
	struct pid___15 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___26;

struct file___26 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___26 f_path;
	struct inode___27 *f_inode;
	const struct file_operations___26 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___26 *f_mapping;
	struct mutex___27 f_pos_lock;
};

struct vm_operations_struct___23;

struct vm_area_struct___29 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___29 *vm_next;
	struct vm_area_struct___29 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___29 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___23 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___26 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___21;

struct vm_operations_struct___23 {
	void (*open)(struct vm_area_struct___29 *);
	void (*close)(struct vm_area_struct___29 *);
	int (*fault)(struct vm_area_struct___29 *, struct vm_fault___21 *);
	int (*page_mkwrite)(struct vm_area_struct___29 *, struct vm_fault___21 *);
	int (*access)(struct vm_area_struct___29 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___29 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___29 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___29 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___29 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___26 {
	struct task_struct___27 *task;
	struct core_thread___26 *next;
};

struct core_state___26 {
	atomic_t nr_threads;
	struct core_thread___26 dumper;
	struct completion startup;
};

struct dma_map_ops___11;

struct dev_archdata___11 {
	struct dma_map_ops___11 *dma_ops;
	void *iommu;
};

struct device_type___24;

struct bus_type___24;

struct device_driver___24;

struct dev_pm_domain___24;

struct class___24;

struct attribute_group___21;

struct device_rh___24;

struct device___24 {
	struct device___24 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___24 *type;
	struct mutex___27 mutex;
	struct bus_type___24 *bus;
	struct device_driver___24 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___24 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___11 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___6 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___24 *class;
	const struct attribute_group___21 **groups;
	void (*release)(struct device___24 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___24 *device_rh;
};

struct pci_bus___7;

struct pci_slot___7;

struct pci_driver___7;

struct bin_attribute___21;

struct pci_dev___7 {
	struct list_head bus_list;
	struct pci_bus___7 *bus;
	struct pci_bus___7 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___7 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___7 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___24 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___21 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___21 *res_attr[17];
	struct bin_attribute___21 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___21 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___7 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___24 {
	int (*prepare)(struct device___24 *);
	void (*complete)(struct device___24 *);
	int (*suspend)(struct device___24 *);
	int (*resume)(struct device___24 *);
	int (*freeze)(struct device___24 *);
	int (*thaw)(struct device___24 *);
	int (*poweroff)(struct device___24 *);
	int (*restore)(struct device___24 *);
	int (*suspend_late)(struct device___24 *);
	int (*resume_early)(struct device___24 *);
	int (*freeze_late)(struct device___24 *);
	int (*thaw_early)(struct device___24 *);
	int (*poweroff_late)(struct device___24 *);
	int (*restore_early)(struct device___24 *);
	int (*suspend_noirq)(struct device___24 *);
	int (*resume_noirq)(struct device___24 *);
	int (*freeze_noirq)(struct device___24 *);
	int (*thaw_noirq)(struct device___24 *);
	int (*poweroff_noirq)(struct device___24 *);
	int (*restore_noirq)(struct device___24 *);
	int (*runtime_suspend)(struct device___24 *);
	int (*runtime_resume)(struct device___24 *);
	int (*runtime_idle)(struct device___24 *);
};

struct dev_pm_info_rh___24 {
	void (*set_latency_tolerance)(struct device___24 *, s32);
};

struct dev_pm_domain___24 {
	struct dev_pm_ops___24 ops;
};

struct smp_ops___26 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___27 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___15 {
	int nr;
	struct pid_namespace___15 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___15 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___27 *child_reaper;
	struct kmem_cache___23 *pid_cachep;
	unsigned int level;
	struct pid_namespace___15 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___27 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___15 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___15 numbers[1];
};

struct zone___26;

struct lruvec___26 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___26 *zone;
};

struct pglist_data___26;

struct zone___26 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___26 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___26 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___26 {
	struct zone___26 *zone;
	int zone_idx;
};

struct zonelist___26 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___26 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___26 {
	struct zone___26 node_zones[4];
	struct zonelist___26 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___27 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___15 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___15 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___26 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___27 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___27 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___27 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___14;

struct css_set___14 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___14 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___14 {
	struct pmu___14 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___27 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___27 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___14 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___26;

struct super_block___27;

struct dentry___27 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___27 *d_parent;
	struct qstr d_name;
	struct inode___27 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___26 *d_op;
	struct super_block___27 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___26;

struct file_lock___26;

struct dquot___26;

struct block_device___26;

struct inode___27 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___26 *i_op;
	struct super_block___27 *i_sb;
	struct address_space___26 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___27 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___26 *i_fop;
	struct file_lock___26 *i_flock;
	struct address_space___26 i_data;
	struct dquot___26 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___26 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___26 {
	int (*d_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_hash)(const struct dentry___27 *, struct qstr *);
	int (*d_compare)(const struct dentry___27 *, const struct dentry___27 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___27 *);
	void (*d_release)(struct dentry___27 *);
	void (*d_prune)(struct dentry___27 *);
	void (*d_iput)(struct dentry___27 *, struct inode___27 *);
	char * (*d_dname)(struct dentry___27 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___26 *);
	int (*d_manage)(struct dentry___27 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___26;

struct mem_dqinfo___26 {
	struct quota_format_type___26 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___26;

struct quota_info___26 {
	unsigned int flags;
	struct mutex___27 dqio_mutex;
	struct mutex___27 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___27 *files[2];
	struct mem_dqinfo___26 info[2];
	const struct quota_format_ops___26 *ops[2];
};

struct file_system_type___26;

struct super_operations___26;

struct dquot_operations___26;

struct quotactl_ops___26;

struct xattr_handler___14;

struct super_block___27 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___26 *s_type;
	const struct super_operations___26 *s_op;
	const struct dquot_operations___26 *dq_op;
	const struct quotactl_ops___26 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___27 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___14 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___26 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___26 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___27 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___26 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___26 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___27 *bd_inode;
	struct super_block___27 *bd_super;
	struct mutex___27 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___26 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___27 bd_fsfreeze_mutex;
};

struct cgroup___14;

struct cgroup_subsys_state___14 {
	struct cgroup___14 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___27 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___26 *ia_file;
};

struct dquot___26 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___27 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___27 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___26 {
	int qf_fmt_id;
	const struct quota_format_ops___26 *qf_ops;
	struct module___14 *qf_owner;
	struct quota_format_type___26 *qf_next;
};

struct quota_format_ops___26 {
	int (*check_quota_file)(struct super_block___27 *, int);
	int (*read_file_info)(struct super_block___27 *, int);
	int (*write_file_info)(struct super_block___27 *, int);
	int (*free_file_info)(struct super_block___27 *, int);
	int (*read_dqblk)(struct dquot___26 *);
	int (*commit_dqblk)(struct dquot___26 *);
	int (*release_dqblk)(struct dquot___26 *);
};

struct dquot_operations___26 {
	int (*write_dquot)(struct dquot___26 *);
	struct dquot___26 * (*alloc_dquot)(struct super_block___27 *, int);
	void (*destroy_dquot)(struct dquot___26 *);
	int (*acquire_dquot)(struct dquot___26 *);
	int (*release_dquot)(struct dquot___26 *);
	int (*mark_dirty)(struct dquot___26 *);
	int (*write_info)(struct super_block___27 *, int);
	qsize_t * (*get_reserved_space)(struct inode___27 *);
};

struct quotactl_ops___26 {
	int (*quota_on)(struct super_block___27 *, int, int, struct path___26 *);
	int (*quota_on_meta)(struct super_block___27 *, int, int);
	int (*quota_off)(struct super_block___27 *, int);
	int (*quota_sync)(struct super_block___27 *, int);
	int (*get_info)(struct super_block___27 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___27 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___27 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___27 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___27 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___27 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___27 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___27 *, unsigned int);
};

struct address_space_operations___26 {
	int (*writepage)(struct page___26 *, struct writeback_control *);
	int (*readpage)(struct file___26 *, struct page___26 *);
	int (*writepages)(struct address_space___26 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___26 *);
	int (*readpages)(struct file___26 *, struct address_space___26 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___26 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___26 **, void **);
	int (*write_end)(struct file___26 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___26 *, void *);
	sector_t (*bmap)(struct address_space___26 *, sector_t);
	void (*invalidatepage)(struct page___26 *, long unsigned int);
	int (*releasepage)(struct page___26 *, gfp_t);
	void (*freepage)(struct page___26 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___26 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___26 *, struct page___26 *, struct page___26 *, enum migrate_mode);
	int (*launder_page)(struct page___26 *);
	int (*is_partially_uptodate)(struct page___26 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___26 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___26 *, struct page___26 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___26 *, sector_t *);
	void (*swap_deactivate)(struct file___26 *);
	void (*invalidatepage_range)(struct page___26 *, unsigned int, unsigned int);
};

struct inode_operations___26 {
	struct dentry___27 * (*lookup)(struct inode___27 *, struct dentry___27 *, unsigned int);
	void * (*follow_link)(struct dentry___27 *, struct nameidata *);
	int (*permission)(struct inode___27 *, int);
	struct posix_acl * (*get_acl)(struct inode___27 *, int);
	int (*readlink)(struct dentry___27 *, char *, int);
	void (*put_link)(struct dentry___27 *, struct nameidata *, void *);
	int (*create)(struct inode___27 *, struct dentry___27 *, umode_t, bool);
	int (*link)(struct dentry___27 *, struct inode___27 *, struct dentry___27 *);
	int (*unlink)(struct inode___27 *, struct dentry___27 *);
	int (*symlink)(struct inode___27 *, struct dentry___27 *, const char *);
	int (*mkdir)(struct inode___27 *, struct dentry___27 *, umode_t);
	int (*rmdir)(struct inode___27 *, struct dentry___27 *);
	int (*mknod)(struct inode___27 *, struct dentry___27 *, umode_t, dev_t);
	int (*rename)(struct inode___27 *, struct dentry___27 *, struct inode___27 *, struct dentry___27 *);
	int (*setattr)(struct dentry___27 *, struct iattr___27 *);
	int (*getattr)(struct vfsmount *, struct dentry___27 *, struct kstat *);
	int (*setxattr)(struct dentry___27 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___27 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___27 *, char *, size_t);
	int (*removexattr)(struct dentry___27 *, const char *);
	int (*fiemap)(struct inode___27 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___27 *, struct timespec *, int);
	int (*atomic_open)(struct inode___27 *, struct dentry___27 *, struct file___26 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___26 {
	struct module___14 *owner;
	loff_t (*llseek)(struct file___26 *, loff_t, int);
	ssize_t (*read)(struct file___26 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___26 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___26 *, void *, filldir_t);
	unsigned int (*poll)(struct file___26 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___26 *, struct vm_area_struct___29 *);
	int (*open)(struct inode___27 *, struct file___26 *);
	int (*flush)(struct file___26 *, fl_owner_t);
	int (*release)(struct inode___27 *, struct file___26 *);
	int (*fsync)(struct file___26 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___26 *, int);
	int (*lock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*sendpage)(struct file___26 *, struct page___26 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___26 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___26 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___26 *, long int, struct file_lock___26 **, void **);
		struct {
			int (*setlease)(struct file___26 *, long int, struct file_lock___26 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___26 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___26 *);
};

struct file_lock_operations___26;

struct lock_manager_operations___26;

struct file_lock___26 {
	struct file_lock___26 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___26 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___26 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___26 *fl_ops;
	const struct lock_manager_operations___26 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___26 {
	void (*fl_copy_lock)(struct file_lock___26 *, struct file_lock___26 *);
	void (*fl_release_private)(struct file_lock___26 *);
};

struct lock_manager_operations___26 {
	int (*lm_compare_owner)(struct file_lock___26 *, struct file_lock___26 *);
	long unsigned int (*lm_owner_key)(struct file_lock___26 *);
	void (*lm_notify)(struct file_lock___26 *);
	int (*lm_grant)(struct file_lock___26 *, struct file_lock___26 *, int);
	void (*lm_break)(struct file_lock___26 *);
	int (*lm_change)(struct file_lock___26 **, int);
};

struct fasync_struct___26 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___26 *fa_next;
	struct file___26 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___26 {
	const char *name;
	int fs_flags;
	struct dentry___27 * (*mount)(struct file_system_type___26 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___27 *);
	struct module___14 *owner;
	struct file_system_type___26 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___26 {
	struct inode___27 * (*alloc_inode)(struct super_block___27 *);
	void (*destroy_inode)(struct inode___27 *);
	void (*dirty_inode)(struct inode___27 *, int);
	int (*write_inode)(struct inode___27 *, struct writeback_control *);
	int (*drop_inode)(struct inode___27 *);
	void (*evict_inode)(struct inode___27 *);
	void (*put_super)(struct super_block___27 *);
	int (*sync_fs)(struct super_block___27 *, int);
	int (*freeze_fs)(struct super_block___27 *);
	int (*unfreeze_fs)(struct super_block___27 *);
	int (*statfs)(struct dentry___27 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___27 *, int *, char *);
	void (*umount_begin)(struct super_block___27 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___27 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___27 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___27 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___27 *);
	ssize_t (*quota_read)(struct super_block___27 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___27 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___27 *);
	int (*bdev_try_to_free_page)(struct super_block___27 *, struct page___26 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___27 *);
	void (*free_cached_objects)(struct super_block___27 *, int);
};

struct xattr_handler___14 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___27 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___27 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___27 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___21 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___26 *page;
};

struct attribute_group___21 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___21 **bin_attrs;
};

struct bin_attribute___21 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___26 *, struct kobject *, struct bin_attribute___21 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___26 *, struct kobject *, struct bin_attribute___21 *, char *, loff_t, size_t);
	int (*mmap)(struct file___26 *, struct kobject *, struct bin_attribute___21 *, struct vm_area_struct___29 *);
};

struct dma_map_ops___11 {
	void * (*alloc)(struct device___24 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___24 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___24 *, struct vm_area_struct___29 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___24 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___24 *, struct page___26 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___24 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___24 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___24 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___24 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___24 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___24 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___24 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___24 *, dma_addr_t);
	int (*dma_supported)(struct device___24 *, u64);
	int (*set_dma_mask)(struct device___24 *, u64);
	int is_phys;
};

struct bus_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___24 *, char *);
	ssize_t (*store)(struct bus_type___24 *, const char *, size_t);
};

struct device_attribute___24;

struct driver_attribute___24;

struct bus_type___24 {
	const char *name;
	const char *dev_name;
	struct device___24 *dev_root;
	struct bus_attribute___24 *bus_attrs;
	struct device_attribute___24 *dev_attrs;
	struct driver_attribute___24 *drv_attrs;
	const struct attribute_group___21 **bus_groups;
	const struct attribute_group___21 **dev_groups;
	const struct attribute_group___21 **drv_groups;
	int (*match)(struct device___24 *, struct device_driver___24 *);
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	int (*probe)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*online)(struct device___24 *);
	int (*offline)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct device___24 *, struct device_attribute___24 *, char *);
	ssize_t (*store)(struct device___24 *, struct device_attribute___24 *, const char *, size_t);
};

struct driver_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___24 *, char *);
	ssize_t (*store)(struct device_driver___24 *, const char *, size_t);
};

struct device_driver___24 {
	const char *name;
	struct bus_type___24 *bus;
	struct module___14 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct attribute_group___21 **groups;
	const struct dev_pm_ops___24 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___24 {
	const char *name;
	const struct attribute_group___21 **groups;
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
};

struct class_attribute___24;

struct class___24 {
	const char *name;
	struct module___14 *owner;
	struct class_attribute___24 *class_attrs;
	struct device_attribute___24 *dev_attrs;
	const struct attribute_group___21 **dev_groups;
	struct bin_attribute___21 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *);
	void (*class_release)(struct class___24 *);
	void (*dev_release)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	struct subsys_private *p;
};

struct class_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct class___24 *, struct class_attribute___24 *, char *);
	ssize_t (*store)(struct class___24 *, struct class_attribute___24 *, const char *, size_t);
	const void * (*namespace)(struct class___24 *, const struct class_attribute___24 *);
};

struct device_rh___24 {
	struct dev_pm_info_rh___24 power;
};

struct kmem_cache_cpu___23 {
	void **freelist;
	long unsigned int tid;
	struct page___26 *page;
	struct page___26 *partial;
};

struct memcg_cache_params___23 {
	bool is_root_cache;
	union {
		struct kmem_cache___23 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___23 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___14;

struct cgroup___14 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___14 *parent;
	struct dentry___27 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___14 *subsys[11];
	struct cgroupfs_root___14 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___27 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___14 {
	struct super_block___27 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___14 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___14;

struct pmu___14 {
	struct list_head entry;
	struct device___24 *dev;
	const struct attribute_group___21 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___14 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___14 *);
	void (*pmu_disable)(struct pmu___14 *);
	int (*event_init)(struct perf_event___14 *);
	int (*add)(struct perf_event___14 *, int);
	void (*del)(struct perf_event___14 *, int);
	void (*start)(struct perf_event___14 *, int);
	void (*stop)(struct perf_event___14 *, int);
	void (*read)(struct perf_event___14 *);
	void (*start_txn)(struct pmu___14 *);
	int (*commit_txn)(struct pmu___14 *);
	void (*cancel_txn)(struct pmu___14 *);
	int (*event_idx)(struct perf_event___14 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___14 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___14 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___14 *);
};

struct perf_cpu_context___14 {
	struct perf_event_context___14 ctx;
	struct perf_event_context___14 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___14 *unique_pmu;
	struct perf_cgroup___14 *cgrp;
};

struct perf_cgroup___14 {
	struct cgroup_subsys_state___14 css;
	struct perf_cgroup_info *info;
};

struct module_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___13 *, struct module_kobject___13 *, char *);
	ssize_t (*store)(struct module_attribute___13 *, struct module_kobject___13 *, const char *, size_t);
	void (*setup)(struct module___14 *, const char *);
	int (*test)(struct module___14 *);
	void (*free)(struct module___14 *);
};

struct pci_slot___7 {
	struct pci_bus___7 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___7;

struct pci_bus___7 {
	struct list_head node;
	struct pci_bus___7 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___7 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___7 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___24 *bridge;
	struct device___24 dev;
	struct bin_attribute___21 *legacy_io;
	struct bin_attribute___21 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___7;

struct pci_driver_rh___7;

struct pci_driver___7 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___7 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___7 *);
	int (*suspend)(struct pci_dev___7 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___7 *, pm_message_t);
	int (*resume_early)(struct pci_dev___7 *);
	int (*resume)(struct pci_dev___7 *);
	void (*shutdown)(struct pci_dev___7 *);
	int (*sriov_configure)(struct pci_dev___7 *, int);
	const struct pci_error_handlers___7 *err_handler;
	struct device_driver___24 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___7 *pci_driver_rh;
};

struct pci_ops___7 {
	int (*read)(struct pci_bus___7 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___7 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___7 {
	pci_ers_result_t (*error_detected)(struct pci_dev___7 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___7 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___7 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___7 *);
	void (*resume)(struct pci_dev___7 *);
};

struct pci_driver_rh___7 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___7 *, bool);
};

struct amd_nb___6 {
	int nb_id;
	int refcnt;
	struct perf_event___14 *owners[64];
	struct event_constraint event_constraints[64];
};

struct cpu_hw_events___6 {
	struct perf_event___14 *events[64];
	long unsigned int active_mask[1];
	long unsigned int running[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int assign[64];
	u64 tags[64];
	struct perf_event___14 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int group_flag;
	int is_fake;
	struct debug_store *ds;
	u64 pebs_enabled;
	int lbr_users;
	void *lbr_context;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	struct er_account *lbr_sel;
	u64 br_sel;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	struct amd_nb___6 *amd_nb;
	u64 perf_ctr_virt_mask;
	void *kfree_on_online[2];
};

struct x86_pmu___6 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___14 *);
	void (*disable)(struct perf_event___14 *);
	int (*hw_config)(struct perf_event___14 *);
	int (*schedule_events)(struct cpu_hw_events___6 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___6 *, int, struct perf_event___14 *);
	void (*put_event_constraints)(struct cpu_hw_events___6 *, struct perf_event___14 *);
	void (*commit_scheduling)(struct cpu_hw_events___6 *, int, int);
	void (*start_scheduling)(struct cpu_hw_events___6 *);
	void (*stop_scheduling)(struct cpu_hw_events___6 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	bool late_ack;
	unsigned int (*limit_period)(struct perf_event___14 *, unsigned int);
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	struct attribute **cpu_events;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context___14 *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	int pebs_record_size;
	void (*drain_pebs)(struct pt_regs *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___14 *);
	int max_pebs_events;
	long unsigned int lbr_tos;
	long unsigned int lbr_from;
	long unsigned int lbr_to;
	int lbr_nr;
	u64 lbr_sel_mask;
	const int *lbr_sel_map;
	bool lbr_double_abort;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
};

struct kprobe_insn_cache___8 {
	struct mutex___27 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

enum ibs_states {
	IBS_ENABLED = 0,
	IBS_STARTED = 1,
	IBS_STOPPING = 2,
	IBS_MAX_STATES = 3,
};

struct cpu_perf_ibs {
	struct perf_event___14 *event;
	long unsigned int state[1];
};

struct perf_ibs {
	struct pmu___14 pmu;
	unsigned int msr;
	u64 config_mask;
	u64 cnt_mask;
	u64 enable_mask;
	u64 valid_mask;
	u64 max_period;
	long unsigned int offset_mask[1];
	int offset_max;
	struct cpu_perf_ibs *pcpu;
	struct attribute **format_attrs;
	struct attribute_group___21 format_group;
	const struct attribute_group___21 *attr_groups[2];
	u64 (*get_count)(u64);
};

struct perf_ibs_data {
	u32 size;
	union {
		u32 data[0];
		u32 caps;
	};
	u64 regs[8];
};

struct page___27;

typedef struct page___27 *pgtable_t___27;

struct address_space___27;

struct page___27 {
	long unsigned int flags;
	struct address_space___27 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___27 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___27 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___27 *first_page;
	};
	long: 64;
};

struct task_struct___28;

struct pv_cpu_ops___27 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___28 *);
	void (*end_context_switch)(struct task_struct___28 *);
};

struct mutex___28 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___28 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___25 {
	struct page___27 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___30;

struct signal_struct___27;

struct task_struct___28 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___28 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___30 *mm;
	struct mm_struct___30 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___28 *real_parent;
	struct task_struct___28 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___28 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___27 = 0,
		VTIME_USER___27 = 1,
		VTIME_SYS___27 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___27 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___28 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___25 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___30 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___30 *, struct mm_struct___30 *);
	void (*dup_mmap)(struct mm_struct___30 *, struct mm_struct___30 *);
	void (*exit_mmap)(struct mm_struct___30 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___30 *);
	void (*pgd_free)(struct mm_struct___30 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___30 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___30 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___30 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___30 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___30 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___30 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___30 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___30 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___30 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___30 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___30 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___28 lock;
	void *vdso;
} mm_context_t___28;

struct xol_area___27;

struct uprobes_state___27 {
	struct xol_area___27 *xol_area;
};

struct vm_area_struct___30;

struct file___27;

struct core_state___27;

struct mm_struct___30 {
	struct vm_area_struct___30 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___30 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___30 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___28 context;
	long unsigned int flags;
	struct core_state___27 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___28 *owner;
	struct file___27 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___27 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___15;

struct module_kobject___14 {
	struct kobject kobj;
	struct module___15 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___14;

struct module___15 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___14 mkobj;
	struct module_attribute___14 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___28 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___27;

struct lruvec___27 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___27 *zone;
};

struct pglist_data___27;

struct zone___27 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___27 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___27 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___27 {
	struct zone___27 *zone;
	int zone_idx;
};

struct zonelist___27 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___27 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___27 {
	struct zone___27 node_zones[4];
	struct zonelist___27 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___28 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___17;

struct x86_io_apic_ops___17 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___17 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___17;

struct irq_data___17 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___17 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___27 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___28 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dentry___28;

struct path___27 {
	struct vfsmount *mnt;
	struct dentry___28 *dentry;
};

struct inode___28;

struct file_operations___27;

struct file___27 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___27 f_path;
	struct inode___28 *f_inode;
	const struct file_operations___27 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___27 *f_mapping;
	struct mutex___28 f_pos_lock;
};

struct vm_area_struct___30 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___30 *vm_next;
	struct vm_area_struct___30 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___30 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___27 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___14 *, struct module_kobject___14 *, char *);
	ssize_t (*store)(struct module_attribute___14 *, struct module_kobject___14 *, const char *, size_t);
	void (*setup)(struct module___15 *, const char *);
	int (*test)(struct module___15 *);
	void (*free)(struct module___15 *);
};

struct seq_file___17;

struct irq_chip___17 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___17 *);
	void (*irq_shutdown)(struct irq_data___17 *);
	void (*irq_enable)(struct irq_data___17 *);
	void (*irq_disable)(struct irq_data___17 *);
	void (*irq_ack)(struct irq_data___17 *);
	void (*irq_mask)(struct irq_data___17 *);
	void (*irq_mask_ack)(struct irq_data___17 *);
	void (*irq_unmask)(struct irq_data___17 *);
	void (*irq_eoi)(struct irq_data___17 *);
	int (*irq_set_affinity)(struct irq_data___17 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___17 *);
	int (*irq_set_type)(struct irq_data___17 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___17 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___17 *);
	void (*irq_bus_sync_unlock)(struct irq_data___17 *);
	void (*irq_cpu_online)(struct irq_data___17 *);
	void (*irq_cpu_offline)(struct irq_data___17 *);
	void (*irq_suspend)(struct irq_data___17 *);
	void (*irq_resume)(struct irq_data___17 *);
	void (*irq_pm_shutdown)(struct irq_data___17 *);
	void (*irq_print_chip)(struct irq_data___17 *, struct seq_file___17 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___17 *, void *);
	long unsigned int flags;
};

struct seq_operations___17;

struct seq_file___17 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___28 lock;
	const struct seq_operations___17 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___27;

struct super_block___28;

struct dentry___28 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___28 *d_parent;
	struct qstr d_name;
	struct inode___28 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___27 *d_op;
	struct super_block___28 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___27;

struct address_space___27 {
	struct inode___28 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___28 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___27 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___27;

struct file_lock___27;

struct dquot___27;

struct block_device___27;

struct cdev___9;

struct inode___28 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___27 *i_op;
	struct super_block___28 *i_sb;
	struct address_space___27 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___28 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___27 *i_fop;
	struct file_lock___27 *i_flock;
	struct address_space___27 i_data;
	struct dquot___27 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___27 *i_bdev;
		struct cdev___9 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___27 {
	int (*d_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_hash)(const struct dentry___28 *, struct qstr *);
	int (*d_compare)(const struct dentry___28 *, const struct dentry___28 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___28 *);
	void (*d_release)(struct dentry___28 *);
	void (*d_prune)(struct dentry___28 *);
	void (*d_iput)(struct dentry___28 *, struct inode___28 *);
	char * (*d_dname)(struct dentry___28 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___27 *);
	int (*d_manage)(struct dentry___28 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___27;

struct mem_dqinfo___27 {
	struct quota_format_type___27 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___27;

struct quota_info___27 {
	unsigned int flags;
	struct mutex___28 dqio_mutex;
	struct mutex___28 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___28 *files[2];
	struct mem_dqinfo___27 info[2];
	const struct quota_format_ops___27 *ops[2];
};

struct file_system_type___27;

struct super_operations___27;

struct dquot_operations___27;

struct quotactl_ops___27;

struct super_block___28 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___27 *s_type;
	const struct super_operations___27 *s_op;
	const struct dquot_operations___27 *dq_op;
	const struct quotactl_ops___27 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___28 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___27 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___27 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___28 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___27 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___27 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___28 *bd_inode;
	struct super_block___28 *bd_super;
	struct mutex___28 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___27 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___28 bd_fsfreeze_mutex;
};

struct iattr___28 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___27 *ia_file;
};

struct dquot___27 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___28 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___28 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___27 {
	int qf_fmt_id;
	const struct quota_format_ops___27 *qf_ops;
	struct module___15 *qf_owner;
	struct quota_format_type___27 *qf_next;
};

struct quota_format_ops___27 {
	int (*check_quota_file)(struct super_block___28 *, int);
	int (*read_file_info)(struct super_block___28 *, int);
	int (*write_file_info)(struct super_block___28 *, int);
	int (*free_file_info)(struct super_block___28 *, int);
	int (*read_dqblk)(struct dquot___27 *);
	int (*commit_dqblk)(struct dquot___27 *);
	int (*release_dqblk)(struct dquot___27 *);
};

struct dquot_operations___27 {
	int (*write_dquot)(struct dquot___27 *);
	struct dquot___27 * (*alloc_dquot)(struct super_block___28 *, int);
	void (*destroy_dquot)(struct dquot___27 *);
	int (*acquire_dquot)(struct dquot___27 *);
	int (*release_dquot)(struct dquot___27 *);
	int (*mark_dirty)(struct dquot___27 *);
	int (*write_info)(struct super_block___28 *, int);
	qsize_t * (*get_reserved_space)(struct inode___28 *);
};

struct quotactl_ops___27 {
	int (*quota_on)(struct super_block___28 *, int, int, struct path___27 *);
	int (*quota_on_meta)(struct super_block___28 *, int, int);
	int (*quota_off)(struct super_block___28 *, int);
	int (*quota_sync)(struct super_block___28 *, int);
	int (*get_info)(struct super_block___28 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___28 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___28 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___28 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___28 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___28 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___28 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___28 *, unsigned int);
};

struct address_space_operations___27 {
	int (*writepage)(struct page___27 *, struct writeback_control *);
	int (*readpage)(struct file___27 *, struct page___27 *);
	int (*writepages)(struct address_space___27 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___27 *);
	int (*readpages)(struct file___27 *, struct address_space___27 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___27 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___27 **, void **);
	int (*write_end)(struct file___27 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___27 *, void *);
	sector_t (*bmap)(struct address_space___27 *, sector_t);
	void (*invalidatepage)(struct page___27 *, long unsigned int);
	int (*releasepage)(struct page___27 *, gfp_t);
	void (*freepage)(struct page___27 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___27 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___27 *, struct page___27 *, struct page___27 *, enum migrate_mode);
	int (*launder_page)(struct page___27 *);
	int (*is_partially_uptodate)(struct page___27 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___27 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___27 *, struct page___27 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___27 *, sector_t *);
	void (*swap_deactivate)(struct file___27 *);
	void (*invalidatepage_range)(struct page___27 *, unsigned int, unsigned int);
};

struct cdev___9 {
	struct kobject kobj;
	struct module___15 *owner;
	const struct file_operations___27 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___27 {
	struct dentry___28 * (*lookup)(struct inode___28 *, struct dentry___28 *, unsigned int);
	void * (*follow_link)(struct dentry___28 *, struct nameidata *);
	int (*permission)(struct inode___28 *, int);
	struct posix_acl * (*get_acl)(struct inode___28 *, int);
	int (*readlink)(struct dentry___28 *, char *, int);
	void (*put_link)(struct dentry___28 *, struct nameidata *, void *);
	int (*create)(struct inode___28 *, struct dentry___28 *, umode_t, bool);
	int (*link)(struct dentry___28 *, struct inode___28 *, struct dentry___28 *);
	int (*unlink)(struct inode___28 *, struct dentry___28 *);
	int (*symlink)(struct inode___28 *, struct dentry___28 *, const char *);
	int (*mkdir)(struct inode___28 *, struct dentry___28 *, umode_t);
	int (*rmdir)(struct inode___28 *, struct dentry___28 *);
	int (*mknod)(struct inode___28 *, struct dentry___28 *, umode_t, dev_t);
	int (*rename)(struct inode___28 *, struct dentry___28 *, struct inode___28 *, struct dentry___28 *);
	int (*setattr)(struct dentry___28 *, struct iattr___28 *);
	int (*getattr)(struct vfsmount *, struct dentry___28 *, struct kstat *);
	int (*setxattr)(struct dentry___28 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___28 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___28 *, char *, size_t);
	int (*removexattr)(struct dentry___28 *, const char *);
	int (*fiemap)(struct inode___28 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___28 *, struct timespec *, int);
	int (*atomic_open)(struct inode___28 *, struct dentry___28 *, struct file___27 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___13;

struct file_operations___27 {
	struct module___15 *owner;
	loff_t (*llseek)(struct file___27 *, loff_t, int);
	ssize_t (*read)(struct file___27 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___27 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___27 *, void *, filldir_t);
	unsigned int (*poll)(struct file___27 *, struct poll_table_struct___13 *);
	long int (*unlocked_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___27 *, struct vm_area_struct___30 *);
	int (*open)(struct inode___28 *, struct file___27 *);
	int (*flush)(struct file___27 *, fl_owner_t);
	int (*release)(struct inode___28 *, struct file___27 *);
	int (*fsync)(struct file___27 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___27 *, int);
	int (*lock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*sendpage)(struct file___27 *, struct page___27 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___27 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___27 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___27 *, long int, struct file_lock___27 **, void **);
		struct {
			int (*setlease)(struct file___27 *, long int, struct file_lock___27 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___27 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___17 *, struct file___27 *);
};

struct fasync_struct___27;

struct file_lock_operations___27;

struct lock_manager_operations___27;

struct file_lock___27 {
	struct file_lock___27 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___27 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___27 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___27 *fl_ops;
	const struct lock_manager_operations___27 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___27 {
	void (*fl_copy_lock)(struct file_lock___27 *, struct file_lock___27 *);
	void (*fl_release_private)(struct file_lock___27 *);
};

struct lock_manager_operations___27 {
	int (*lm_compare_owner)(struct file_lock___27 *, struct file_lock___27 *);
	long unsigned int (*lm_owner_key)(struct file_lock___27 *);
	void (*lm_notify)(struct file_lock___27 *);
	int (*lm_grant)(struct file_lock___27 *, struct file_lock___27 *, int);
	void (*lm_break)(struct file_lock___27 *);
	int (*lm_change)(struct file_lock___27 **, int);
};

struct fasync_struct___27 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___27 *fa_next;
	struct file___27 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___27 {
	const char *name;
	int fs_flags;
	struct dentry___28 * (*mount)(struct file_system_type___27 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___28 *);
	struct module___15 *owner;
	struct file_system_type___27 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___27 {
	struct inode___28 * (*alloc_inode)(struct super_block___28 *);
	void (*destroy_inode)(struct inode___28 *);
	void (*dirty_inode)(struct inode___28 *, int);
	int (*write_inode)(struct inode___28 *, struct writeback_control *);
	int (*drop_inode)(struct inode___28 *);
	void (*evict_inode)(struct inode___28 *);
	void (*put_super)(struct super_block___28 *);
	int (*sync_fs)(struct super_block___28 *, int);
	int (*freeze_fs)(struct super_block___28 *);
	int (*unfreeze_fs)(struct super_block___28 *);
	int (*statfs)(struct dentry___28 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___28 *, int *, char *);
	void (*umount_begin)(struct super_block___28 *);
	int (*show_options)(struct seq_file___17 *, struct dentry___28 *);
	int (*show_devname)(struct seq_file___17 *, struct dentry___28 *);
	int (*show_path)(struct seq_file___17 *, struct dentry___28 *);
	int (*show_stats)(struct seq_file___17 *, struct dentry___28 *);
	ssize_t (*quota_read)(struct super_block___28 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___28 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___28 *);
	int (*bdev_try_to_free_page)(struct super_block___28 *, struct page___27 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___28 *);
	void (*free_cached_objects)(struct super_block___28 *, int);
};

typedef void (*poll_queue_proc___13)(struct file___27 *, wait_queue_head_t *, struct poll_table_struct___13 *);

struct poll_table_struct___13 {
	poll_queue_proc___13 _qproc;
	long unsigned int _key;
};

struct seq_operations___17 {
	void * (*start)(struct seq_file___17 *, loff_t *);
	void (*stop)(struct seq_file___17 *, void *);
	void * (*next)(struct seq_file___17 *, void *, loff_t *);
	int (*show)(struct seq_file___17 *, void *);
};

struct xol_area___27 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___27 *page;
	long unsigned int vaddr;
};

struct core_thread___27 {
	struct task_struct___28 *task;
	struct core_thread___27 *next;
};

struct core_state___27 {
	atomic_t nr_threads;
	struct core_thread___27 dumper;
	struct completion startup;
};

struct signal_struct___27 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___28 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___28 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___28 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct ms_hyperv_info {
	u32 features;
	u32 misc_features;
	u32 hints;
};

struct legacy_pic___3 {
	int nr_legacy_irqs;
	struct irq_chip___17 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

typedef long unsigned int irq_hw_number_t;

struct page___28;

typedef struct page___28 *pgtable_t___28;

struct address_space___28;

struct kmem_cache___24;

struct page___28 {
	long unsigned int flags;
	struct address_space___28 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___28 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___28 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___24 *slab_cache;
		struct page___28 *first_page;
	};
	long: 64;
};

struct task_struct___29;

struct pv_cpu_ops___28 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___29 *);
	void (*end_context_switch)(struct task_struct___29 *);
};

struct mutex___29 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___29 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___26 {
	struct page___28 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___31;

struct signal_struct___28;

struct task_struct___29 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___29 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___31 *mm;
	struct mm_struct___31 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___29 *real_parent;
	struct task_struct___29 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___29 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___28 = 0,
		VTIME_USER___28 = 1,
		VTIME_SYS___28 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___28 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___29 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___26 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___31 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___31 *, struct mm_struct___31 *);
	void (*dup_mmap)(struct mm_struct___31 *, struct mm_struct___31 *);
	void (*exit_mmap)(struct mm_struct___31 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___31 *);
	void (*pgd_free)(struct mm_struct___31 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___31 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___31 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___31 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___31 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___31 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___31 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___31 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___31 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___31 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___31 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___31 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___29 lock;
	void *vdso;
} mm_context_t___29;

struct xol_area___28;

struct uprobes_state___28 {
	struct xol_area___28 *xol_area;
};

struct vm_area_struct___31;

struct file___28;

struct core_state___28;

struct mm_struct___31 {
	struct vm_area_struct___31 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___31 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___31 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___29 context;
	long unsigned int flags;
	struct core_state___28 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___29 *owner;
	struct file___28 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___28 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___16;

struct module_kobject___15 {
	struct kobject kobj;
	struct module___16 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___15;

struct module___16 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___15 mkobj;
	struct module_attribute___15 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___29 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct bin_attribute___22;

struct attribute_group___22 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___22 **bin_attrs;
};

struct bin_attribute___22 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___28 *, struct kobject *, struct bin_attribute___22 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___28 *, struct kobject *, struct bin_attribute___22 *, char *, loff_t, size_t);
	int (*mmap)(struct file___28 *, struct kobject *, struct bin_attribute___22 *, struct vm_area_struct___31 *);
};

struct dentry___29;

struct path___28 {
	struct vfsmount *mnt;
	struct dentry___29 *dentry;
};

struct inode___29;

struct file_operations___28;

struct file___28 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___28 f_path;
	struct inode___29 *f_inode;
	const struct file_operations___28 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___28 *f_mapping;
	struct mutex___29 f_pos_lock;
};

struct vm_operations_struct___24;

struct vm_area_struct___31 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___31 *vm_next;
	struct vm_area_struct___31 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___31 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___24 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___28 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___25;

struct dev_pm_ops___25 {
	int (*prepare)(struct device___25 *);
	void (*complete)(struct device___25 *);
	int (*suspend)(struct device___25 *);
	int (*resume)(struct device___25 *);
	int (*freeze)(struct device___25 *);
	int (*thaw)(struct device___25 *);
	int (*poweroff)(struct device___25 *);
	int (*restore)(struct device___25 *);
	int (*suspend_late)(struct device___25 *);
	int (*resume_early)(struct device___25 *);
	int (*freeze_late)(struct device___25 *);
	int (*thaw_early)(struct device___25 *);
	int (*poweroff_late)(struct device___25 *);
	int (*restore_early)(struct device___25 *);
	int (*suspend_noirq)(struct device___25 *);
	int (*resume_noirq)(struct device___25 *);
	int (*freeze_noirq)(struct device___25 *);
	int (*thaw_noirq)(struct device___25 *);
	int (*poweroff_noirq)(struct device___25 *);
	int (*restore_noirq)(struct device___25 *);
	int (*runtime_suspend)(struct device___25 *);
	int (*runtime_resume)(struct device___25 *);
	int (*runtime_idle)(struct device___25 *);
};

struct dma_map_ops___12;

struct dev_archdata___12 {
	struct dma_map_ops___12 *dma_ops;
	void *iommu;
};

struct acpi_device___7;

struct acpi_dev_node___9 {
	union {
		struct acpi_device___7 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___25;

struct bus_type___25;

struct device_driver___25;

struct dev_pm_domain___25;

struct class___25;

struct device_rh___25;

struct device___25 {
	struct device___25 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___25 *type;
	struct mutex___29 mutex;
	struct bus_type___25 *bus;
	struct device_driver___25 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___25 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___12 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___9 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___25 *class;
	const struct attribute_group___22 **groups;
	void (*release)(struct device___25 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___25 *device_rh;
};

struct dev_pm_info_rh___25 {
	void (*set_latency_tolerance)(struct device___25 *, s32);
};

struct dev_pm_domain___25 {
	struct dev_pm_ops___25 ops;
};

struct zone___28;

struct lruvec___28 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___28 *zone;
};

struct pglist_data___28;

struct zone___28 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___28 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___28 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___28 {
	struct zone___28 *zone;
	int zone_idx;
};

struct zonelist___28 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___28 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___28 {
	struct zone___28 node_zones[4];
	struct zonelist___28 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___29 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mpc_intsrc {
	unsigned char type;
	unsigned char irqtype;
	short unsigned int irqflag;
	unsigned char srcbus;
	unsigned char srcbusirq;
	unsigned char dstapic;
	unsigned char dstirq;
};

enum mp_irq_source_types {
	mp_INT = 0,
	mp_NMI = 1,
	mp_SMI = 2,
	mp_ExtINT = 3,
};

struct pci_bus___8;

struct pci_slot___8;

struct pci_driver___8;

struct pci_dev___8 {
	struct list_head bus_list;
	struct pci_bus___8 *bus;
	struct pci_bus___8 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___8 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___8 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___25 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___22 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___22 *res_attr[17];
	struct bin_attribute___22 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___22 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___8 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___3 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___8 *dev;
	struct msi_msg msg;
	struct kobject kobj;
};

struct irq_data___18;

struct x86_io_apic_ops___18 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___18 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___18;

struct irq_data___18 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___18 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
};

enum ioapic_domain_type {
	IOAPIC_DOMAIN_INVALID = 0,
	IOAPIC_DOMAIN_LEGACY = 1,
	IOAPIC_DOMAIN_STRICT = 2,
	IOAPIC_DOMAIN_DYNAMIC = 3,
};

struct irq_domain_ops;

struct ioapic_domain_cfg {
	enum ioapic_domain_type type;
	const struct irq_domain_ops *ops;
	struct device_node *dev;
};

struct irq_domain_ops {
	int (*match)(struct irq_domain *, struct device_node *);
	int (*map)(struct irq_domain *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain *, unsigned int);
	int (*xlate)(struct irq_domain *, struct device_node *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
};

struct smp_ops___28 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___29 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___12 {
	void * (*alloc)(struct device___25 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___25 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___25 *, struct vm_area_struct___31 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___25 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___25 *, struct page___28 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___25 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___25 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___25 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___25 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___25 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___25 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___25 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___25 *, dma_addr_t);
	int (*dma_supported)(struct device___25 *, u64);
	int (*set_dma_mask)(struct device___25 *, u64);
	int is_phys;
};

struct bus_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___25 *, char *);
	ssize_t (*store)(struct bus_type___25 *, const char *, size_t);
};

struct device_attribute___25;

struct driver_attribute___25;

struct bus_type___25 {
	const char *name;
	const char *dev_name;
	struct device___25 *dev_root;
	struct bus_attribute___25 *bus_attrs;
	struct device_attribute___25 *dev_attrs;
	struct driver_attribute___25 *drv_attrs;
	const struct attribute_group___22 **bus_groups;
	const struct attribute_group___22 **dev_groups;
	const struct attribute_group___22 **drv_groups;
	int (*match)(struct device___25 *, struct device_driver___25 *);
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	int (*probe)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*online)(struct device___25 *);
	int (*offline)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct device___25 *, struct device_attribute___25 *, char *);
	ssize_t (*store)(struct device___25 *, struct device_attribute___25 *, const char *, size_t);
};

struct driver_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___25 *, char *);
	ssize_t (*store)(struct device_driver___25 *, const char *, size_t);
};

struct device_driver___25 {
	const char *name;
	struct bus_type___25 *bus;
	struct module___16 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct attribute_group___22 **groups;
	const struct dev_pm_ops___25 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___25 {
	const char *name;
	const struct attribute_group___22 **groups;
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
};

struct class_attribute___25;

struct class___25 {
	const char *name;
	struct module___16 *owner;
	struct class_attribute___25 *class_attrs;
	struct device_attribute___25 *dev_attrs;
	const struct attribute_group___22 **dev_groups;
	struct bin_attribute___22 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *);
	void (*class_release)(struct class___25 *);
	void (*dev_release)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	struct subsys_private *p;
};

struct class_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct class___25 *, struct class_attribute___25 *, char *);
	ssize_t (*store)(struct class___25 *, struct class_attribute___25 *, const char *, size_t);
	const void * (*namespace)(struct class___25 *, const struct class_attribute___25 *);
};

struct acpi_scan_handler___7;

struct acpi_hotplug_context___7;

struct acpi_driver___7;

struct acpi_device___7 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___7 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___7 *handler;
	struct acpi_hotplug_context___7 *hp;
	struct acpi_driver___7 *driver;
	void *driver_data;
	struct device___25 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___29 physical_node_lock;
	void (*remove)(struct acpi_device___7 *);
};

struct device_rh___25 {
	struct dev_pm_info_rh___25 power;
};

struct xol_area___28 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___28 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___24;

struct memcg_cache_params___24;

struct kmem_cache___24 {
	struct kmem_cache_cpu___24 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___24 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___28;

struct address_space___28 {
	struct inode___29 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___29 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___28 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___22;

struct vm_operations_struct___24 {
	void (*open)(struct vm_area_struct___31 *);
	void (*close)(struct vm_area_struct___31 *);
	int (*fault)(struct vm_area_struct___31 *, struct vm_fault___22 *);
	int (*page_mkwrite)(struct vm_area_struct___31 *, struct vm_fault___22 *);
	int (*access)(struct vm_area_struct___31 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___31 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___31 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___31 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___31 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___28 {
	struct task_struct___29 *task;
	struct core_thread___28 *next;
};

struct core_state___28 {
	atomic_t nr_threads;
	struct core_thread___28 dumper;
	struct completion startup;
};

struct signal_struct___28 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___29 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___29 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___29 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___24 {
	void **freelist;
	long unsigned int tid;
	struct page___28 *page;
	struct page___28 *partial;
};

struct memcg_cache_params___24 {
	bool is_root_cache;
	union {
		struct kmem_cache___24 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___24 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef u64 acpi_physical_address;

typedef u8 acpi_adr_space_type;

struct acpi_subtable_header {
	u8 type;
	u8 length;
};

struct acpi_table_madt {
	struct acpi_table_header header;
	u32 address;
	u32 flags;
};

enum acpi_madt_type {
	ACPI_MADT_TYPE_LOCAL_APIC = 0,
	ACPI_MADT_TYPE_IO_APIC = 1,
	ACPI_MADT_TYPE_INTERRUPT_OVERRIDE = 2,
	ACPI_MADT_TYPE_NMI_SOURCE = 3,
	ACPI_MADT_TYPE_LOCAL_APIC_NMI = 4,
	ACPI_MADT_TYPE_LOCAL_APIC_OVERRIDE = 5,
	ACPI_MADT_TYPE_IO_SAPIC = 6,
	ACPI_MADT_TYPE_LOCAL_SAPIC = 7,
	ACPI_MADT_TYPE_INTERRUPT_SOURCE = 8,
	ACPI_MADT_TYPE_LOCAL_X2APIC = 9,
	ACPI_MADT_TYPE_LOCAL_X2APIC_NMI = 10,
	ACPI_MADT_TYPE_GENERIC_INTERRUPT = 11,
	ACPI_MADT_TYPE_GENERIC_DISTRIBUTOR = 12,
	ACPI_MADT_TYPE_RESERVED = 13,
};

struct acpi_madt_local_apic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u32 lapic_flags;
};

struct acpi_madt_io_apic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 address;
	u32 global_irq_base;
};

struct acpi_madt_interrupt_override {
	struct acpi_subtable_header header;
	u8 bus;
	u8 source_irq;
	u32 global_irq;
	u16 inti_flags;
} __attribute__((packed));

struct acpi_madt_nmi_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 global_irq;
};

struct acpi_madt_local_apic_nmi {
	struct acpi_subtable_header header;
	u8 processor_id;
	u16 inti_flags;
	u8 lint;
} __attribute__((packed));

struct acpi_madt_local_apic_override {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_madt_local_sapic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u8 eid;
	u8 reserved[3];
	u32 lapic_flags;
	u32 uid;
	char uid_string[1];
} __attribute__((packed));

struct acpi_madt_local_x2apic {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 local_apic_id;
	u32 lapic_flags;
	u32 uid;
};

struct acpi_madt_local_x2apic_nmi {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 uid;
	u8 lint;
	u8 reserved[3];
};

struct acpi_table_boot {
	struct acpi_table_header header;
	u8 cmos_index;
	u8 reserved[3];
};

struct acpi_table_hpet {
	struct acpi_table_header header;
	u32 id;
	struct acpi_generic_address address;
	u8 sequence;
	u16 minimum_tick;
	u8 flags;
} __attribute__((packed));

struct dentry_operations___28;

struct super_block___29;

struct dentry___29 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___29 *d_parent;
	struct qstr d_name;
	struct inode___29 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___28 *d_op;
	struct super_block___29 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___28;

struct file_lock___28;

struct dquot___28;

struct block_device___28;

struct cdev___10;

struct inode___29 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___28 *i_op;
	struct super_block___29 *i_sb;
	struct address_space___28 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___29 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___28 *i_fop;
	struct file_lock___28 *i_flock;
	struct address_space___28 i_data;
	struct dquot___28 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___28 *i_bdev;
		struct cdev___10 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___28 {
	int (*d_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_hash)(const struct dentry___29 *, struct qstr *);
	int (*d_compare)(const struct dentry___29 *, const struct dentry___29 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___29 *);
	void (*d_release)(struct dentry___29 *);
	void (*d_prune)(struct dentry___29 *);
	void (*d_iput)(struct dentry___29 *, struct inode___29 *);
	char * (*d_dname)(struct dentry___29 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___28 *);
	int (*d_manage)(struct dentry___29 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___28;

struct mem_dqinfo___28 {
	struct quota_format_type___28 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___28;

struct quota_info___28 {
	unsigned int flags;
	struct mutex___29 dqio_mutex;
	struct mutex___29 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___29 *files[2];
	struct mem_dqinfo___28 info[2];
	const struct quota_format_ops___28 *ops[2];
};

struct file_system_type___28;

struct super_operations___28;

struct dquot_operations___28;

struct quotactl_ops___28;

struct super_block___29 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___28 *s_type;
	const struct super_operations___28 *s_op;
	const struct dquot_operations___28 *dq_op;
	const struct quotactl_ops___28 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___29 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___28 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___28 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___29 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___28 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___28 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___29 *bd_inode;
	struct super_block___29 *bd_super;
	struct mutex___29 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___28 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___29 bd_fsfreeze_mutex;
};

struct iattr___29 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___28 *ia_file;
};

struct dquot___28 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___29 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___29 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___28 {
	int qf_fmt_id;
	const struct quota_format_ops___28 *qf_ops;
	struct module___16 *qf_owner;
	struct quota_format_type___28 *qf_next;
};

struct quota_format_ops___28 {
	int (*check_quota_file)(struct super_block___29 *, int);
	int (*read_file_info)(struct super_block___29 *, int);
	int (*write_file_info)(struct super_block___29 *, int);
	int (*free_file_info)(struct super_block___29 *, int);
	int (*read_dqblk)(struct dquot___28 *);
	int (*commit_dqblk)(struct dquot___28 *);
	int (*release_dqblk)(struct dquot___28 *);
};

struct dquot_operations___28 {
	int (*write_dquot)(struct dquot___28 *);
	struct dquot___28 * (*alloc_dquot)(struct super_block___29 *, int);
	void (*destroy_dquot)(struct dquot___28 *);
	int (*acquire_dquot)(struct dquot___28 *);
	int (*release_dquot)(struct dquot___28 *);
	int (*mark_dirty)(struct dquot___28 *);
	int (*write_info)(struct super_block___29 *, int);
	qsize_t * (*get_reserved_space)(struct inode___29 *);
};

struct quotactl_ops___28 {
	int (*quota_on)(struct super_block___29 *, int, int, struct path___28 *);
	int (*quota_on_meta)(struct super_block___29 *, int, int);
	int (*quota_off)(struct super_block___29 *, int);
	int (*quota_sync)(struct super_block___29 *, int);
	int (*get_info)(struct super_block___29 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___29 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___29 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___29 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___29 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___29 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___29 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___29 *, unsigned int);
};

struct address_space_operations___28 {
	int (*writepage)(struct page___28 *, struct writeback_control *);
	int (*readpage)(struct file___28 *, struct page___28 *);
	int (*writepages)(struct address_space___28 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___28 *);
	int (*readpages)(struct file___28 *, struct address_space___28 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___28 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___28 **, void **);
	int (*write_end)(struct file___28 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___28 *, void *);
	sector_t (*bmap)(struct address_space___28 *, sector_t);
	void (*invalidatepage)(struct page___28 *, long unsigned int);
	int (*releasepage)(struct page___28 *, gfp_t);
	void (*freepage)(struct page___28 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___28 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___28 *, struct page___28 *, struct page___28 *, enum migrate_mode);
	int (*launder_page)(struct page___28 *);
	int (*is_partially_uptodate)(struct page___28 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___28 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___28 *, struct page___28 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___28 *, sector_t *);
	void (*swap_deactivate)(struct file___28 *);
	void (*invalidatepage_range)(struct page___28 *, unsigned int, unsigned int);
};

struct cdev___10 {
	struct kobject kobj;
	struct module___16 *owner;
	const struct file_operations___28 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___28 {
	struct dentry___29 * (*lookup)(struct inode___29 *, struct dentry___29 *, unsigned int);
	void * (*follow_link)(struct dentry___29 *, struct nameidata *);
	int (*permission)(struct inode___29 *, int);
	struct posix_acl * (*get_acl)(struct inode___29 *, int);
	int (*readlink)(struct dentry___29 *, char *, int);
	void (*put_link)(struct dentry___29 *, struct nameidata *, void *);
	int (*create)(struct inode___29 *, struct dentry___29 *, umode_t, bool);
	int (*link)(struct dentry___29 *, struct inode___29 *, struct dentry___29 *);
	int (*unlink)(struct inode___29 *, struct dentry___29 *);
	int (*symlink)(struct inode___29 *, struct dentry___29 *, const char *);
	int (*mkdir)(struct inode___29 *, struct dentry___29 *, umode_t);
	int (*rmdir)(struct inode___29 *, struct dentry___29 *);
	int (*mknod)(struct inode___29 *, struct dentry___29 *, umode_t, dev_t);
	int (*rename)(struct inode___29 *, struct dentry___29 *, struct inode___29 *, struct dentry___29 *);
	int (*setattr)(struct dentry___29 *, struct iattr___29 *);
	int (*getattr)(struct vfsmount *, struct dentry___29 *, struct kstat *);
	int (*setxattr)(struct dentry___29 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___29 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___29 *, char *, size_t);
	int (*removexattr)(struct dentry___29 *, const char *);
	int (*fiemap)(struct inode___29 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___29 *, struct timespec *, int);
	int (*atomic_open)(struct inode___29 *, struct dentry___29 *, struct file___28 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___14;

struct seq_file___18;

struct file_operations___28 {
	struct module___16 *owner;
	loff_t (*llseek)(struct file___28 *, loff_t, int);
	ssize_t (*read)(struct file___28 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___28 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___28 *, void *, filldir_t);
	unsigned int (*poll)(struct file___28 *, struct poll_table_struct___14 *);
	long int (*unlocked_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___28 *, struct vm_area_struct___31 *);
	int (*open)(struct inode___29 *, struct file___28 *);
	int (*flush)(struct file___28 *, fl_owner_t);
	int (*release)(struct inode___29 *, struct file___28 *);
	int (*fsync)(struct file___28 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___28 *, int);
	int (*lock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*sendpage)(struct file___28 *, struct page___28 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___28 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___28 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___28 *, long int, struct file_lock___28 **, void **);
		struct {
			int (*setlease)(struct file___28 *, long int, struct file_lock___28 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___28 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___18 *, struct file___28 *);
};

struct fasync_struct___28;

struct file_lock_operations___28;

struct lock_manager_operations___28;

struct file_lock___28 {
	struct file_lock___28 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___28 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___28 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___28 *fl_ops;
	const struct lock_manager_operations___28 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___28 {
	void (*fl_copy_lock)(struct file_lock___28 *, struct file_lock___28 *);
	void (*fl_release_private)(struct file_lock___28 *);
};

struct lock_manager_operations___28 {
	int (*lm_compare_owner)(struct file_lock___28 *, struct file_lock___28 *);
	long unsigned int (*lm_owner_key)(struct file_lock___28 *);
	void (*lm_notify)(struct file_lock___28 *);
	int (*lm_grant)(struct file_lock___28 *, struct file_lock___28 *, int);
	void (*lm_break)(struct file_lock___28 *);
	int (*lm_change)(struct file_lock___28 **, int);
};

struct fasync_struct___28 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___28 *fa_next;
	struct file___28 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___28 {
	const char *name;
	int fs_flags;
	struct dentry___29 * (*mount)(struct file_system_type___28 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___29 *);
	struct module___16 *owner;
	struct file_system_type___28 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___28 {
	struct inode___29 * (*alloc_inode)(struct super_block___29 *);
	void (*destroy_inode)(struct inode___29 *);
	void (*dirty_inode)(struct inode___29 *, int);
	int (*write_inode)(struct inode___29 *, struct writeback_control *);
	int (*drop_inode)(struct inode___29 *);
	void (*evict_inode)(struct inode___29 *);
	void (*put_super)(struct super_block___29 *);
	int (*sync_fs)(struct super_block___29 *, int);
	int (*freeze_fs)(struct super_block___29 *);
	int (*unfreeze_fs)(struct super_block___29 *);
	int (*statfs)(struct dentry___29 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___29 *, int *, char *);
	void (*umount_begin)(struct super_block___29 *);
	int (*show_options)(struct seq_file___18 *, struct dentry___29 *);
	int (*show_devname)(struct seq_file___18 *, struct dentry___29 *);
	int (*show_path)(struct seq_file___18 *, struct dentry___29 *);
	int (*show_stats)(struct seq_file___18 *, struct dentry___29 *);
	ssize_t (*quota_read)(struct super_block___29 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___29 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___29 *);
	int (*bdev_try_to_free_page)(struct super_block___29 *, struct page___28 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___29 *);
	void (*free_cached_objects)(struct super_block___29 *, int);
};

typedef void (*poll_queue_proc___14)(struct file___28 *, wait_queue_head_t *, struct poll_table_struct___14 *);

struct poll_table_struct___14 {
	poll_queue_proc___14 _qproc;
	long unsigned int _key;
};

struct seq_operations___18;

struct seq_file___18 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___29 lock;
	const struct seq_operations___18 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct acpi_hotplug_profile___7 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___7 *);
	void (*notify_online)(struct acpi_device___7 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___7 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___7 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___7 *);
	void (*bind)(struct device___25 *);
	void (*unbind)(struct device___25 *);
	struct acpi_hotplug_profile___7 hotplug;
};

struct acpi_hotplug_context___7 {
	struct acpi_device___7 *self;
	int (*notify)(struct acpi_device___7 *, u32);
	void (*uevent)(struct acpi_device___7 *, u32);
	void (*fixup)(struct acpi_device___7 *);
};

typedef int (*acpi_op_add___7)(struct acpi_device___7 *);

typedef int (*acpi_op_remove___7)(struct acpi_device___7 *);

typedef void (*acpi_op_notify___7)(struct acpi_device___7 *, u32);

struct acpi_device_ops___7 {
	acpi_op_add___7 add;
	acpi_op_remove___7 remove;
	acpi_op_notify___7 notify;
};

struct acpi_driver___7 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___7 ops;
	struct device_driver___25 drv;
	struct module___16 *owner;
};

struct pci_ops___8;

struct msi_chip___3;

struct pci_bus___8 {
	struct list_head node;
	struct pci_bus___8 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___8 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___8 *ops;
	struct msi_chip___3 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___25 *bridge;
	struct device___25 dev;
	struct bin_attribute___22 *legacy_io;
	struct bin_attribute___22 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

enum acpi_irq_model_id {
	ACPI_IRQ_MODEL_PIC = 0,
	ACPI_IRQ_MODEL_IOAPIC = 1,
	ACPI_IRQ_MODEL_IOSAPIC = 2,
	ACPI_IRQ_MODEL_PLATFORM = 3,
	ACPI_IRQ_MODEL_COUNT = 4,
};

typedef int (*acpi_tbl_table_handler)(struct acpi_table_header *);

typedef int (*acpi_tbl_entry_handler)(struct acpi_subtable_header *, const long unsigned int);

struct irq_chip___18 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___18 *);
	void (*irq_shutdown)(struct irq_data___18 *);
	void (*irq_enable)(struct irq_data___18 *);
	void (*irq_disable)(struct irq_data___18 *);
	void (*irq_ack)(struct irq_data___18 *);
	void (*irq_mask)(struct irq_data___18 *);
	void (*irq_mask_ack)(struct irq_data___18 *);
	void (*irq_unmask)(struct irq_data___18 *);
	void (*irq_eoi)(struct irq_data___18 *);
	int (*irq_set_affinity)(struct irq_data___18 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___18 *);
	int (*irq_set_type)(struct irq_data___18 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___18 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___18 *);
	void (*irq_bus_sync_unlock)(struct irq_data___18 *);
	void (*irq_cpu_online)(struct irq_data___18 *);
	void (*irq_cpu_offline)(struct irq_data___18 *);
	void (*irq_suspend)(struct irq_data___18 *);
	void (*irq_resume)(struct irq_data___18 *);
	void (*irq_pm_shutdown)(struct irq_data___18 *);
	void (*irq_print_chip)(struct irq_data___18 *, struct seq_file___18 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___18 *, void *);
	long unsigned int flags;
};

struct irq_domain {
	struct list_head link;
	unsigned int revmap_type;
	union {
		struct {
			unsigned int size;
			unsigned int first_irq;
			irq_hw_number_t first_hwirq;
		} legacy;
		struct {
			unsigned int size;
			unsigned int *revmap;
		} linear;
		struct {
			unsigned int max_irq;
		} nomap;
		struct radix_tree_root tree;
	} revmap_data;
	const struct irq_domain_ops *ops;
	void *host_data;
	irq_hw_number_t inval_irq;
	struct device_node *of_node;
};

struct seq_operations___18 {
	void * (*start)(struct seq_file___18 *, loff_t *);
	void (*stop)(struct seq_file___18 *, void *);
	void * (*next)(struct seq_file___18 *, void *, loff_t *);
	int (*show)(struct seq_file___18 *, void *);
};

struct module_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___15 *, struct module_kobject___15 *, char *);
	ssize_t (*store)(struct module_attribute___15 *, struct module_kobject___15 *, const char *, size_t);
	void (*setup)(struct module___16 *, const char *);
	int (*test)(struct module___16 *);
	void (*free)(struct module___16 *);
};

struct pci_slot___8 {
	struct pci_bus___8 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_error_handlers___8;

struct pci_driver_rh___8;

struct pci_driver___8 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___8 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___8 *);
	int (*suspend)(struct pci_dev___8 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___8 *, pm_message_t);
	int (*resume_early)(struct pci_dev___8 *);
	int (*resume)(struct pci_dev___8 *);
	void (*shutdown)(struct pci_dev___8 *);
	int (*sriov_configure)(struct pci_dev___8 *, int);
	const struct pci_error_handlers___8 *err_handler;
	struct device_driver___25 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___8 *pci_driver_rh;
};

struct pci_ops___8 {
	int (*read)(struct pci_bus___8 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___8 *, unsigned int, int, int, u32);
};

struct msi_chip___3 {
	struct module___16 *owner;
	struct device___25 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___3 *, struct pci_dev___8 *, struct msi_desc___3 *);
	void (*teardown_irq)(struct msi_chip___3 *, unsigned int);
	int (*check_device)(struct msi_chip___3 *, struct pci_dev___8 *, int, int);
};

struct pci_error_handlers___8 {
	pci_ers_result_t (*error_detected)(struct pci_dev___8 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___8 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___8 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___8 *);
	void (*resume)(struct pci_dev___8 *);
};

struct pci_driver_rh___8 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___8 *, bool);
};

struct vm_fault___22 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___28 *page;
};

struct legacy_pic___4 {
	int nr_legacy_irqs;
	struct irq_chip___18 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

struct wakeup_header {
	u16 video_mode;
	u32 pmode_entry;
	u16 pmode_cs;
	u32 pmode_cr0;
	u32 pmode_cr3;
	u32 pmode_cr4;
	u32 pmode_efer_low;
	u32 pmode_efer_high;
	u64 pmode_gdt;
	u32 pmode_misc_en_low;
	u32 pmode_misc_en_high;
	u32 pmode_behavior;
	u32 realmode_flags;
	u32 real_magic;
	u32 signature;
} __attribute__((packed));

typedef void (*exitcall_t)();

struct acpi_power_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_processor_cx {
	u8 valid;
	u8 type;
	u32 address;
	u8 entry_method;
	u8 index;
	u32 latency;
	u8 bm_sts_skip;
	char desc[32];
};

struct acpi_processor_flags {
	u8 power: 1;
	u8 performance: 1;
	u8 throttling: 1;
	u8 limit: 1;
	u8 bm_control: 1;
	u8 bm_check: 1;
	u8 has_cst: 1;
	u8 power_setup_done: 1;
	u8 bm_rld_set: 1;
	u8 need_hotplug_init: 1;
};

struct cstate_entry {
	struct {
		unsigned int eax;
		unsigned int ecx;
	} states[8];
};

struct page___29;

typedef struct page___29 *pgtable_t___29;

struct address_space___29;

struct kmem_cache___25;

struct page___29 {
	long unsigned int flags;
	struct address_space___29 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___29 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___29 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___25 *slab_cache;
		struct page___29 *first_page;
	};
	long: 64;
};

struct task_struct___30;

struct pv_cpu_ops___29 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___30 *);
	void (*end_context_switch)(struct task_struct___30 *);
};

struct mutex___30 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___30 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___27 {
	struct page___29 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___32;

struct signal_struct___29;

struct task_struct___30 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___30 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___32 *mm;
	struct mm_struct___32 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___30 *real_parent;
	struct task_struct___30 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___30 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___29 = 0,
		VTIME_USER___29 = 1,
		VTIME_SYS___29 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___29 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___30 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___27 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___32 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___32 *, struct mm_struct___32 *);
	void (*dup_mmap)(struct mm_struct___32 *, struct mm_struct___32 *);
	void (*exit_mmap)(struct mm_struct___32 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___32 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___32 *);
	void (*pgd_free)(struct mm_struct___32 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___32 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___32 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___32 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___32 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___32 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___32 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___32 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___32 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___32 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___30 lock;
	void *vdso;
} mm_context_t___30;

struct xol_area___29;

struct uprobes_state___29 {
	struct xol_area___29 *xol_area;
};

struct vm_area_struct___32;

struct file___29;

struct core_state___29;

struct mm_struct___32 {
	struct vm_area_struct___32 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___32 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___32 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___30 context;
	long unsigned int flags;
	struct core_state___29 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___30 *owner;
	struct file___29 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___29 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___17;

struct module_kobject___16 {
	struct kobject kobj;
	struct module___17 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___16;

struct module___17 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___16 mkobj;
	struct module_attribute___16 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___30 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___29;

struct lruvec___29 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___29 *zone;
};

struct pglist_data___29;

struct zone___29 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___29 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___29 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___29 {
	struct zone___29 *zone;
	int zone_idx;
};

struct zonelist___29 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___29 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___29 {
	struct zone___29 node_zones[4];
	struct zonelist___29 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___30 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___19;

struct x86_io_apic_ops___19 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___19 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___19;

struct irq_data___19 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___19 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___29 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___30 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dentry___30;

struct path___29 {
	struct vfsmount *mnt;
	struct dentry___30 *dentry;
};

struct inode___30;

struct file_operations___29;

struct file___29 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___29 f_path;
	struct inode___30 *f_inode;
	const struct file_operations___29 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___29 *f_mapping;
	struct mutex___30 f_pos_lock;
};

struct vm_area_struct___32 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___32 *vm_next;
	struct vm_area_struct___32 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___32 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___16 *, struct module_kobject___16 *, char *);
	ssize_t (*store)(struct module_attribute___16 *, struct module_kobject___16 *, const char *, size_t);
	void (*setup)(struct module___17 *, const char *);
	int (*test)(struct module___17 *);
	void (*free)(struct module___17 *);
};

enum reboot_type {
	BOOT_TRIPLE = 116,
	BOOT_KBD = 107,
	BOOT_BIOS = 98,
	BOOT_ACPI = 97,
	BOOT_EFI = 101,
	BOOT_CF9 = 112,
	BOOT_CF9_COND = 113,
};

struct dentry_operations___29;

struct super_block___30;

struct dentry___30 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___30 *d_parent;
	struct qstr d_name;
	struct inode___30 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___29 *d_op;
	struct super_block___30 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___29;

struct address_space___29 {
	struct inode___30 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___30 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___29 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___29;

struct file_lock___29;

struct dquot___29;

struct block_device___29;

struct cdev___11;

struct inode___30 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___29 *i_op;
	struct super_block___30 *i_sb;
	struct address_space___29 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___30 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___29 *i_fop;
	struct file_lock___29 *i_flock;
	struct address_space___29 i_data;
	struct dquot___29 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___29 *i_bdev;
		struct cdev___11 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___29 {
	int (*d_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_hash)(const struct dentry___30 *, struct qstr *);
	int (*d_compare)(const struct dentry___30 *, const struct dentry___30 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___30 *);
	void (*d_release)(struct dentry___30 *);
	void (*d_prune)(struct dentry___30 *);
	void (*d_iput)(struct dentry___30 *, struct inode___30 *);
	char * (*d_dname)(struct dentry___30 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___29 *);
	int (*d_manage)(struct dentry___30 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___29;

struct mem_dqinfo___29 {
	struct quota_format_type___29 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___29;

struct quota_info___29 {
	unsigned int flags;
	struct mutex___30 dqio_mutex;
	struct mutex___30 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___30 *files[2];
	struct mem_dqinfo___29 info[2];
	const struct quota_format_ops___29 *ops[2];
};

struct file_system_type___29;

struct super_operations___29;

struct dquot_operations___29;

struct quotactl_ops___29;

struct super_block___30 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___29 *s_type;
	const struct super_operations___29 *s_op;
	const struct dquot_operations___29 *dq_op;
	const struct quotactl_ops___29 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___30 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___29 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___29 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___30 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___29 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___29 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___30 *bd_inode;
	struct super_block___30 *bd_super;
	struct mutex___30 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___29 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___30 bd_fsfreeze_mutex;
};

struct iattr___30 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___29 *ia_file;
};

struct dquot___29 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___30 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___30 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___29 {
	int qf_fmt_id;
	const struct quota_format_ops___29 *qf_ops;
	struct module___17 *qf_owner;
	struct quota_format_type___29 *qf_next;
};

struct quota_format_ops___29 {
	int (*check_quota_file)(struct super_block___30 *, int);
	int (*read_file_info)(struct super_block___30 *, int);
	int (*write_file_info)(struct super_block___30 *, int);
	int (*free_file_info)(struct super_block___30 *, int);
	int (*read_dqblk)(struct dquot___29 *);
	int (*commit_dqblk)(struct dquot___29 *);
	int (*release_dqblk)(struct dquot___29 *);
};

struct dquot_operations___29 {
	int (*write_dquot)(struct dquot___29 *);
	struct dquot___29 * (*alloc_dquot)(struct super_block___30 *, int);
	void (*destroy_dquot)(struct dquot___29 *);
	int (*acquire_dquot)(struct dquot___29 *);
	int (*release_dquot)(struct dquot___29 *);
	int (*mark_dirty)(struct dquot___29 *);
	int (*write_info)(struct super_block___30 *, int);
	qsize_t * (*get_reserved_space)(struct inode___30 *);
};

struct quotactl_ops___29 {
	int (*quota_on)(struct super_block___30 *, int, int, struct path___29 *);
	int (*quota_on_meta)(struct super_block___30 *, int, int);
	int (*quota_off)(struct super_block___30 *, int);
	int (*quota_sync)(struct super_block___30 *, int);
	int (*get_info)(struct super_block___30 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___30 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___30 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___30 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___30 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___30 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___30 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___30 *, unsigned int);
};

struct address_space_operations___29 {
	int (*writepage)(struct page___29 *, struct writeback_control *);
	int (*readpage)(struct file___29 *, struct page___29 *);
	int (*writepages)(struct address_space___29 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___29 *);
	int (*readpages)(struct file___29 *, struct address_space___29 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___29 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___29 **, void **);
	int (*write_end)(struct file___29 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___29 *, void *);
	sector_t (*bmap)(struct address_space___29 *, sector_t);
	void (*invalidatepage)(struct page___29 *, long unsigned int);
	int (*releasepage)(struct page___29 *, gfp_t);
	void (*freepage)(struct page___29 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___29 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___29 *, struct page___29 *, struct page___29 *, enum migrate_mode);
	int (*launder_page)(struct page___29 *);
	int (*is_partially_uptodate)(struct page___29 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___29 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___29 *, struct page___29 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___29 *, sector_t *);
	void (*swap_deactivate)(struct file___29 *);
	void (*invalidatepage_range)(struct page___29 *, unsigned int, unsigned int);
};

struct cdev___11 {
	struct kobject kobj;
	struct module___17 *owner;
	const struct file_operations___29 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___29 {
	struct dentry___30 * (*lookup)(struct inode___30 *, struct dentry___30 *, unsigned int);
	void * (*follow_link)(struct dentry___30 *, struct nameidata *);
	int (*permission)(struct inode___30 *, int);
	struct posix_acl * (*get_acl)(struct inode___30 *, int);
	int (*readlink)(struct dentry___30 *, char *, int);
	void (*put_link)(struct dentry___30 *, struct nameidata *, void *);
	int (*create)(struct inode___30 *, struct dentry___30 *, umode_t, bool);
	int (*link)(struct dentry___30 *, struct inode___30 *, struct dentry___30 *);
	int (*unlink)(struct inode___30 *, struct dentry___30 *);
	int (*symlink)(struct inode___30 *, struct dentry___30 *, const char *);
	int (*mkdir)(struct inode___30 *, struct dentry___30 *, umode_t);
	int (*rmdir)(struct inode___30 *, struct dentry___30 *);
	int (*mknod)(struct inode___30 *, struct dentry___30 *, umode_t, dev_t);
	int (*rename)(struct inode___30 *, struct dentry___30 *, struct inode___30 *, struct dentry___30 *);
	int (*setattr)(struct dentry___30 *, struct iattr___30 *);
	int (*getattr)(struct vfsmount *, struct dentry___30 *, struct kstat *);
	int (*setxattr)(struct dentry___30 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___30 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___30 *, char *, size_t);
	int (*removexattr)(struct dentry___30 *, const char *);
	int (*fiemap)(struct inode___30 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___30 *, struct timespec *, int);
	int (*atomic_open)(struct inode___30 *, struct dentry___30 *, struct file___29 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___15;

struct seq_file___19;

struct file_operations___29 {
	struct module___17 *owner;
	loff_t (*llseek)(struct file___29 *, loff_t, int);
	ssize_t (*read)(struct file___29 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___29 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___29 *, void *, filldir_t);
	unsigned int (*poll)(struct file___29 *, struct poll_table_struct___15 *);
	long int (*unlocked_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___29 *, struct vm_area_struct___32 *);
	int (*open)(struct inode___30 *, struct file___29 *);
	int (*flush)(struct file___29 *, fl_owner_t);
	int (*release)(struct inode___30 *, struct file___29 *);
	int (*fsync)(struct file___29 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___29 *, int);
	int (*lock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*sendpage)(struct file___29 *, struct page___29 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___29 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___29 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___29 *, long int, struct file_lock___29 **, void **);
		struct {
			int (*setlease)(struct file___29 *, long int, struct file_lock___29 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___29 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___19 *, struct file___29 *);
};

struct fasync_struct___29;

struct file_lock_operations___29;

struct lock_manager_operations___29;

struct file_lock___29 {
	struct file_lock___29 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___29 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___29 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___29 *fl_ops;
	const struct lock_manager_operations___29 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___29 {
	void (*fl_copy_lock)(struct file_lock___29 *, struct file_lock___29 *);
	void (*fl_release_private)(struct file_lock___29 *);
};

struct lock_manager_operations___29 {
	int (*lm_compare_owner)(struct file_lock___29 *, struct file_lock___29 *);
	long unsigned int (*lm_owner_key)(struct file_lock___29 *);
	void (*lm_notify)(struct file_lock___29 *);
	int (*lm_grant)(struct file_lock___29 *, struct file_lock___29 *, int);
	void (*lm_break)(struct file_lock___29 *);
	int (*lm_change)(struct file_lock___29 **, int);
};

struct fasync_struct___29 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___29 *fa_next;
	struct file___29 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___29 {
	const char *name;
	int fs_flags;
	struct dentry___30 * (*mount)(struct file_system_type___29 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___30 *);
	struct module___17 *owner;
	struct file_system_type___29 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___29 {
	struct inode___30 * (*alloc_inode)(struct super_block___30 *);
	void (*destroy_inode)(struct inode___30 *);
	void (*dirty_inode)(struct inode___30 *, int);
	int (*write_inode)(struct inode___30 *, struct writeback_control *);
	int (*drop_inode)(struct inode___30 *);
	void (*evict_inode)(struct inode___30 *);
	void (*put_super)(struct super_block___30 *);
	int (*sync_fs)(struct super_block___30 *, int);
	int (*freeze_fs)(struct super_block___30 *);
	int (*unfreeze_fs)(struct super_block___30 *);
	int (*statfs)(struct dentry___30 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___30 *, int *, char *);
	void (*umount_begin)(struct super_block___30 *);
	int (*show_options)(struct seq_file___19 *, struct dentry___30 *);
	int (*show_devname)(struct seq_file___19 *, struct dentry___30 *);
	int (*show_path)(struct seq_file___19 *, struct dentry___30 *);
	int (*show_stats)(struct seq_file___19 *, struct dentry___30 *);
	ssize_t (*quota_read)(struct super_block___30 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___30 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___30 *);
	int (*bdev_try_to_free_page)(struct super_block___30 *, struct page___29 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___30 *);
	void (*free_cached_objects)(struct super_block___30 *, int);
};

typedef void (*poll_queue_proc___15)(struct file___29 *, wait_queue_head_t *, struct poll_table_struct___15 *);

struct poll_table_struct___15 {
	poll_queue_proc___15 _qproc;
	long unsigned int _key;
};

struct seq_operations___19;

struct seq_file___19 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___30 lock;
	const struct seq_operations___19 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___19 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___19 *);
	void (*irq_shutdown)(struct irq_data___19 *);
	void (*irq_enable)(struct irq_data___19 *);
	void (*irq_disable)(struct irq_data___19 *);
	void (*irq_ack)(struct irq_data___19 *);
	void (*irq_mask)(struct irq_data___19 *);
	void (*irq_mask_ack)(struct irq_data___19 *);
	void (*irq_unmask)(struct irq_data___19 *);
	void (*irq_eoi)(struct irq_data___19 *);
	int (*irq_set_affinity)(struct irq_data___19 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___19 *);
	int (*irq_set_type)(struct irq_data___19 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___19 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___19 *);
	void (*irq_bus_sync_unlock)(struct irq_data___19 *);
	void (*irq_cpu_online)(struct irq_data___19 *);
	void (*irq_cpu_offline)(struct irq_data___19 *);
	void (*irq_suspend)(struct irq_data___19 *);
	void (*irq_resume)(struct irq_data___19 *);
	void (*irq_pm_shutdown)(struct irq_data___19 *);
	void (*irq_print_chip)(struct irq_data___19 *, struct seq_file___19 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___19 *, void *);
	long unsigned int flags;
};

struct seq_operations___19 {
	void * (*start)(struct seq_file___19 *, loff_t *);
	void (*stop)(struct seq_file___19 *, void *);
	void * (*next)(struct seq_file___19 *, void *, loff_t *);
	int (*show)(struct seq_file___19 *, void *);
};

typedef long unsigned int efi_status_t;

typedef u8 efi_bool_t;

typedef u16 efi_char16_t;

typedef u64 efi_physical_addr_t;

typedef void *efi_handle_t;

typedef struct {
	u8 b[16];
} efi_guid_t;

typedef struct {
	u64 signature;
	u32 revision;
	u32 headersize;
	u32 crc32;
	u32 reserved;
} efi_table_hdr_t;

typedef struct {
	u32 type;
	u32 pad;
	u64 phys_addr;
	u64 virt_addr;
	u64 num_pages;
	u64 attribute;
} efi_memory_desc_t;

typedef struct {
	efi_guid_t guid;
	u32 headersize;
	u32 flags;
	u32 imagesize;
} efi_capsule_header_t;

typedef struct {
	u16 year;
	u8 month;
	u8 day;
	u8 hour;
	u8 minute;
	u8 second;
	u8 pad1;
	u32 nanosecond;
	s16 timezone;
	u8 daylight;
	u8 pad2;
} efi_time_t;

typedef struct {
	u32 resolution;
	u32 accuracy;
	u8 sets_to_zero;
} efi_time_cap_t;

typedef struct {
	efi_table_hdr_t hdr;
	void *raise_tpl;
	void *restore_tpl;
	efi_status_t (*allocate_pages)(int, int, long unsigned int, efi_physical_addr_t *);
	efi_status_t (*free_pages)(efi_physical_addr_t, long unsigned int);
	efi_status_t (*get_memory_map)(long unsigned int *, void *, long unsigned int *, long unsigned int *, u32 *);
	efi_status_t (*allocate_pool)(int, long unsigned int, void **);
	efi_status_t (*free_pool)(void *);
	void *create_event;
	void *set_timer;
	void *wait_for_event;
	void *signal_event;
	void *close_event;
	void *check_event;
	void *install_protocol_interface;
	void *reinstall_protocol_interface;
	void *uninstall_protocol_interface;
	efi_status_t (*handle_protocol)(efi_handle_t, efi_guid_t *, void **);
	void *__reserved;
	void *register_protocol_notify;
	void *locate_handle;
	void *locate_device_path;
	void *install_configuration_table;
	void *load_image;
	void *start_image;
	void *exit;
	void *unload_image;
	efi_status_t (*exit_boot_services)(efi_handle_t, long unsigned int);
	void *get_next_monotonic_count;
	void *stall;
	void *set_watchdog_timer;
	void *connect_controller;
	void *disconnect_controller;
	void *open_protocol;
	void *close_protocol;
	void *open_protocol_information;
	void *protocols_per_handle;
	void *locate_handle_buffer;
	void *locate_protocol;
	void *install_multiple_protocol_interfaces;
	void *uninstall_multiple_protocol_interfaces;
	void *calculate_crc32;
	void *copy_mem;
	void *set_mem;
	void *create_event_ex;
} efi_boot_services_t;

typedef struct {
	efi_table_hdr_t hdr;
	void *get_time;
	void *set_time;
	void *get_wakeup_time;
	void *set_wakeup_time;
	void *set_virtual_address_map;
	void *convert_pointer;
	void *get_variable;
	void *get_next_variable;
	void *set_variable;
	void *get_next_high_mono_count;
	void *reset_system;
	void *update_capsule;
	void *query_capsule_caps;
	void *query_variable_info;
} efi_runtime_services_t;

typedef efi_status_t efi_get_time_t(efi_time_t *, efi_time_cap_t *);

typedef efi_status_t efi_set_time_t(efi_time_t *);

typedef efi_status_t efi_get_wakeup_time_t(efi_bool_t *, efi_bool_t *, efi_time_t *);

typedef efi_status_t efi_set_wakeup_time_t(efi_bool_t, efi_time_t *);

typedef efi_status_t efi_get_variable_t(efi_char16_t *, efi_guid_t *, u32 *, long unsigned int *, void *);

typedef efi_status_t efi_get_next_variable_t(long unsigned int *, efi_char16_t *, efi_guid_t *);

typedef efi_status_t efi_set_variable_t(efi_char16_t *, efi_guid_t *, u32, long unsigned int, void *);

typedef efi_status_t efi_get_next_high_mono_count_t(u32 *);

typedef void efi_reset_system_t(int, efi_status_t, long unsigned int, efi_char16_t *);

typedef efi_status_t efi_set_virtual_address_map_t(long unsigned int, long unsigned int, u32, efi_memory_desc_t *);

typedef efi_status_t efi_query_variable_info_t(u32, u64 *, u64 *, u64 *);

typedef efi_status_t efi_update_capsule_t(efi_capsule_header_t **, long unsigned int, long unsigned int);

typedef efi_status_t efi_query_capsule_caps_t(efi_capsule_header_t **, long unsigned int, u64 *, int *);

typedef struct {
	efi_table_hdr_t hdr;
	long unsigned int fw_vendor;
	u32 fw_revision;
	long unsigned int con_in_handle;
	long unsigned int con_in;
	long unsigned int con_out_handle;
	long unsigned int con_out;
	long unsigned int stderr_handle;
	long unsigned int stderr;
	efi_runtime_services_t *runtime;
	efi_boot_services_t *boottime;
	long unsigned int nr_tables;
	long unsigned int tables;
} efi_system_table_t;

struct efi_memory_map {
	void *phys_map;
	void *map;
	void *map_end;
	int nr_map;
	long unsigned int desc_version;
	long unsigned int desc_size;
};

struct efi {
	efi_system_table_t *systab;
	unsigned int runtime_version;
	long unsigned int mps;
	long unsigned int acpi;
	long unsigned int acpi20;
	long unsigned int smbios;
	long unsigned int sal_systab;
	long unsigned int boot_info;
	long unsigned int hcdp;
	long unsigned int uga;
	long unsigned int uv_systab;
	long unsigned int fw_vendor;
	long unsigned int runtime;
	long unsigned int config_table;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_query_variable_info_t *query_variable_info;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	efi_set_virtual_address_map_t *set_virtual_address_map;
	struct efi_memory_map *memmap;
	long unsigned int smbios3;
};

struct xol_area___29 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___29 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___25;

struct memcg_cache_params___25;

struct kmem_cache___25 {
	struct kmem_cache_cpu___25 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___25 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct core_thread___29 {
	struct task_struct___30 *task;
	struct core_thread___29 *next;
};

struct core_state___29 {
	atomic_t nr_threads;
	struct core_thread___29 dumper;
	struct completion startup;
};

struct signal_struct___29 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___30 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___30 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___30 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___25 {
	void **freelist;
	long unsigned int tid;
	struct page___29 *page;
	struct page___29 *partial;
};

struct memcg_cache_params___25 {
	bool is_root_cache;
	union {
		struct kmem_cache___25 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___25 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef void (*nmi_shootdown_cb)(int, struct pt_regs *);

struct device___26;

struct dev_pm_ops___26 {
	int (*prepare)(struct device___26 *);
	void (*complete)(struct device___26 *);
	int (*suspend)(struct device___26 *);
	int (*resume)(struct device___26 *);
	int (*freeze)(struct device___26 *);
	int (*thaw)(struct device___26 *);
	int (*poweroff)(struct device___26 *);
	int (*restore)(struct device___26 *);
	int (*suspend_late)(struct device___26 *);
	int (*resume_early)(struct device___26 *);
	int (*freeze_late)(struct device___26 *);
	int (*thaw_early)(struct device___26 *);
	int (*poweroff_late)(struct device___26 *);
	int (*restore_early)(struct device___26 *);
	int (*suspend_noirq)(struct device___26 *);
	int (*resume_noirq)(struct device___26 *);
	int (*freeze_noirq)(struct device___26 *);
	int (*thaw_noirq)(struct device___26 *);
	int (*poweroff_noirq)(struct device___26 *);
	int (*restore_noirq)(struct device___26 *);
	int (*runtime_suspend)(struct device___26 *);
	int (*runtime_resume)(struct device___26 *);
	int (*runtime_idle)(struct device___26 *);
};

struct acpi_dev_node___10 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___26;

struct bus_type___26;

struct device_driver___26;

struct dev_pm_domain___26;

struct class___26;

struct device_rh___26;

struct device___26 {
	struct device___26 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___26 *type;
	struct mutex___30 mutex;
	struct bus_type___26 *bus;
	struct device_driver___26 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___26 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___12 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___10 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___26 *class;
	const struct attribute_group **groups;
	void (*release)(struct device___26 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___26 *device_rh;
};

struct dev_pm_info_rh___26 {
	void (*set_latency_tolerance)(struct device___26 *, s32);
};

struct dev_pm_domain___26 {
	struct dev_pm_ops___26 ops;
};

struct bus_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___26 *, char *);
	ssize_t (*store)(struct bus_type___26 *, const char *, size_t);
};

struct device_attribute___26;

struct driver_attribute___26;

struct bus_type___26 {
	const char *name;
	const char *dev_name;
	struct device___26 *dev_root;
	struct bus_attribute___26 *bus_attrs;
	struct device_attribute___26 *dev_attrs;
	struct driver_attribute___26 *drv_attrs;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device___26 *, struct device_driver___26 *);
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	int (*probe)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*online)(struct device___26 *);
	int (*offline)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct device___26 *, struct device_attribute___26 *, char *);
	ssize_t (*store)(struct device___26 *, struct device_attribute___26 *, const char *, size_t);
};

struct driver_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___26 *, char *);
	ssize_t (*store)(struct device_driver___26 *, const char *, size_t);
};

struct device_driver___26 {
	const char *name;
	struct bus_type___26 *bus;
	struct module___17 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct attribute_group **groups;
	const struct dev_pm_ops___26 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___26 {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
};

struct class_attribute___26;

struct class___26 {
	const char *name;
	struct module___17 *owner;
	struct class_attribute___26 *class_attrs;
	struct device_attribute___26 *dev_attrs;
	const struct attribute_group **dev_groups;
	struct bin_attribute *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *);
	void (*class_release)(struct class___26 *);
	void (*dev_release)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	struct subsys_private *p;
};

struct class_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct class___26 *, struct class_attribute___26 *, char *);
	ssize_t (*store)(struct class___26 *, struct class_attribute___26 *, const char *, size_t);
	const void * (*namespace)(struct class___26 *, const struct class_attribute___26 *);
};

struct device_rh___26 {
	struct dev_pm_info_rh___26 power;
};

struct cpuid_regs___2 {
	u32 eax;
	u32 ebx;
	u32 ecx;
	u32 edx;
};

struct intel_stolen_funcs {
	size_t (*size)(int, int, int);
	u32 (*base)(int, int, int, size_t);
};

struct chipset {
	u32 vendor;
	u32 device;
	u32 class;
	u32 class_mask;
	u32 flags;
	void (*f)(int, int, int);
};

struct page___30;

typedef struct page___30 *pgtable_t___30;

struct address_space___30;

struct page___30 {
	long unsigned int flags;
	struct address_space___30 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___30 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___30 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___30 *first_page;
	};
	long: 64;
};

struct task_struct___31;

struct pv_cpu_ops___30 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___31 *);
	void (*end_context_switch)(struct task_struct___31 *);
};

struct mutex___31 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___31 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___28 {
	struct page___30 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___33;

struct signal_struct___30;

struct task_struct___31 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___31 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___33 *mm;
	struct mm_struct___33 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___31 *real_parent;
	struct task_struct___31 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___31 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___30 = 0,
		VTIME_USER___30 = 1,
		VTIME_SYS___30 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___30 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___31 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___28 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___33 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___33 *, struct mm_struct___33 *);
	void (*dup_mmap)(struct mm_struct___33 *, struct mm_struct___33 *);
	void (*exit_mmap)(struct mm_struct___33 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___33 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___33 *);
	void (*pgd_free)(struct mm_struct___33 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___33 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___33 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___33 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___33 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___33 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___33 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___33 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___33 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___33 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___33 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___33 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___31 lock;
	void *vdso;
} mm_context_t___31;

struct xol_area___30;

struct uprobes_state___30 {
	struct xol_area___30 *xol_area;
};

struct vm_area_struct___33;

struct file___30;

struct core_state___30;

struct mm_struct___33 {
	struct vm_area_struct___33 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___33 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___33 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___31 context;
	long unsigned int flags;
	struct core_state___30 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___31 *owner;
	struct file___30 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___30 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___30;

struct lruvec___30 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___30 *zone;
};

struct pglist_data___30;

struct zone___30 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___30 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___30 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___30 {
	struct zone___30 *zone;
	int zone_idx;
};

struct zonelist___30 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___30 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___30 {
	struct zone___30 node_zones[4];
	struct zonelist___30 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___31 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___20;

struct x86_io_apic_ops___20 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___20 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___20;

struct irq_data___20 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___20 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___30 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___31 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___30 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___30 *page;
	long unsigned int vaddr;
};

struct inode___31;

struct address_space_operations___30;

struct address_space___30 {
	struct inode___31 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___31 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___30 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___31;

struct path___30 {
	struct vfsmount *mnt;
	struct dentry___31 *dentry;
};

struct file_operations___30;

struct file___30 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___30 f_path;
	struct inode___31 *f_inode;
	const struct file_operations___30 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___30 *f_mapping;
	struct mutex___31 f_pos_lock;
};

struct vm_operations_struct___25;

struct vm_area_struct___33 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___33 *vm_next;
	struct vm_area_struct___33 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___33 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___25 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___30 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___23;

struct vm_operations_struct___25 {
	void (*open)(struct vm_area_struct___33 *);
	void (*close)(struct vm_area_struct___33 *);
	int (*fault)(struct vm_area_struct___33 *, struct vm_fault___23 *);
	int (*page_mkwrite)(struct vm_area_struct___33 *, struct vm_fault___23 *);
	int (*access)(struct vm_area_struct___33 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___33 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___33 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___33 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___33 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___30 {
	struct task_struct___31 *task;
	struct core_thread___30 *next;
};

struct core_state___30 {
	atomic_t nr_threads;
	struct core_thread___30 dumper;
	struct completion startup;
};

struct vm_fault___23 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___30 *page;
};

struct seq_file___20;

struct irq_chip___20 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___20 *);
	void (*irq_shutdown)(struct irq_data___20 *);
	void (*irq_enable)(struct irq_data___20 *);
	void (*irq_disable)(struct irq_data___20 *);
	void (*irq_ack)(struct irq_data___20 *);
	void (*irq_mask)(struct irq_data___20 *);
	void (*irq_mask_ack)(struct irq_data___20 *);
	void (*irq_unmask)(struct irq_data___20 *);
	void (*irq_eoi)(struct irq_data___20 *);
	int (*irq_set_affinity)(struct irq_data___20 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___20 *);
	int (*irq_set_type)(struct irq_data___20 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___20 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___20 *);
	void (*irq_bus_sync_unlock)(struct irq_data___20 *);
	void (*irq_cpu_online)(struct irq_data___20 *);
	void (*irq_cpu_offline)(struct irq_data___20 *);
	void (*irq_suspend)(struct irq_data___20 *);
	void (*irq_resume)(struct irq_data___20 *);
	void (*irq_pm_shutdown)(struct irq_data___20 *);
	void (*irq_print_chip)(struct irq_data___20 *, struct seq_file___20 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___20 *, void *);
	long unsigned int flags;
};

struct seq_operations___20;

struct seq_file___20 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___31 lock;
	const struct seq_operations___20 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___30 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___31 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___31 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___31 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___20 {
	void * (*start)(struct seq_file___20 *, loff_t *);
	void (*stop)(struct seq_file___20 *, void *);
	void * (*next)(struct seq_file___20 *, void *, loff_t *);
	int (*show)(struct seq_file___20 *, void *);
};

struct cdev___12 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___30 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___16;

struct file_lock___30;

struct file_operations___30 {
	struct module *owner;
	loff_t (*llseek)(struct file___30 *, loff_t, int);
	ssize_t (*read)(struct file___30 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___30 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___30 *, void *, filldir_t);
	unsigned int (*poll)(struct file___30 *, struct poll_table_struct___16 *);
	long int (*unlocked_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___30 *, struct vm_area_struct___33 *);
	int (*open)(struct inode___31 *, struct file___30 *);
	int (*flush)(struct file___30 *, fl_owner_t);
	int (*release)(struct inode___31 *, struct file___30 *);
	int (*fsync)(struct file___30 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___30 *, int);
	int (*lock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*sendpage)(struct file___30 *, struct page___30 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___30 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___30 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___30 *, long int, struct file_lock___30 **, void **);
		struct {
			int (*setlease)(struct file___30 *, long int, struct file_lock___30 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___30 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___20 *, struct file___30 *);
};

struct dentry_operations___30;

struct super_block___31;

struct dentry___31 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___31 *d_parent;
	struct qstr d_name;
	struct inode___31 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___30 *d_op;
	struct super_block___31 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___30;

struct dquot___30;

struct block_device___30;

struct inode___31 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___30 *i_op;
	struct super_block___31 *i_sb;
	struct address_space___30 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___31 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___30 *i_fop;
	struct file_lock___30 *i_flock;
	struct address_space___30 i_data;
	struct dquot___30 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___30 *i_bdev;
		struct cdev___12 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___30 {
	int (*d_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_hash)(const struct dentry___31 *, struct qstr *);
	int (*d_compare)(const struct dentry___31 *, const struct dentry___31 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___31 *);
	void (*d_release)(struct dentry___31 *);
	void (*d_prune)(struct dentry___31 *);
	void (*d_iput)(struct dentry___31 *, struct inode___31 *);
	char * (*d_dname)(struct dentry___31 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___30 *);
	int (*d_manage)(struct dentry___31 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___30;

struct mem_dqinfo___30 {
	struct quota_format_type___30 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___30;

struct quota_info___30 {
	unsigned int flags;
	struct mutex___31 dqio_mutex;
	struct mutex___31 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___31 *files[2];
	struct mem_dqinfo___30 info[2];
	const struct quota_format_ops___30 *ops[2];
};

struct file_system_type___30;

struct super_operations___30;

struct dquot_operations___30;

struct quotactl_ops___30;

struct super_block___31 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___30 *s_type;
	const struct super_operations___30 *s_op;
	const struct dquot_operations___30 *dq_op;
	const struct quotactl_ops___30 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___31 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___30 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___30 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___31 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___30 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___30 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___31 *bd_inode;
	struct super_block___31 *bd_super;
	struct mutex___31 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___30 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___31 bd_fsfreeze_mutex;
};

struct iattr___31 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___30 *ia_file;
};

struct dquot___30 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___31 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___31 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___30 {
	int qf_fmt_id;
	const struct quota_format_ops___30 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___30 *qf_next;
};

struct quota_format_ops___30 {
	int (*check_quota_file)(struct super_block___31 *, int);
	int (*read_file_info)(struct super_block___31 *, int);
	int (*write_file_info)(struct super_block___31 *, int);
	int (*free_file_info)(struct super_block___31 *, int);
	int (*read_dqblk)(struct dquot___30 *);
	int (*commit_dqblk)(struct dquot___30 *);
	int (*release_dqblk)(struct dquot___30 *);
};

struct dquot_operations___30 {
	int (*write_dquot)(struct dquot___30 *);
	struct dquot___30 * (*alloc_dquot)(struct super_block___31 *, int);
	void (*destroy_dquot)(struct dquot___30 *);
	int (*acquire_dquot)(struct dquot___30 *);
	int (*release_dquot)(struct dquot___30 *);
	int (*mark_dirty)(struct dquot___30 *);
	int (*write_info)(struct super_block___31 *, int);
	qsize_t * (*get_reserved_space)(struct inode___31 *);
};

struct quotactl_ops___30 {
	int (*quota_on)(struct super_block___31 *, int, int, struct path___30 *);
	int (*quota_on_meta)(struct super_block___31 *, int, int);
	int (*quota_off)(struct super_block___31 *, int);
	int (*quota_sync)(struct super_block___31 *, int);
	int (*get_info)(struct super_block___31 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___31 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___31 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___31 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___31 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___31 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___31 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___31 *, unsigned int);
};

struct address_space_operations___30 {
	int (*writepage)(struct page___30 *, struct writeback_control *);
	int (*readpage)(struct file___30 *, struct page___30 *);
	int (*writepages)(struct address_space___30 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___30 *);
	int (*readpages)(struct file___30 *, struct address_space___30 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___30 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___30 **, void **);
	int (*write_end)(struct file___30 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___30 *, void *);
	sector_t (*bmap)(struct address_space___30 *, sector_t);
	void (*invalidatepage)(struct page___30 *, long unsigned int);
	int (*releasepage)(struct page___30 *, gfp_t);
	void (*freepage)(struct page___30 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___30 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___30 *, struct page___30 *, struct page___30 *, enum migrate_mode);
	int (*launder_page)(struct page___30 *);
	int (*is_partially_uptodate)(struct page___30 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___30 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___30 *, struct page___30 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___30 *, sector_t *);
	void (*swap_deactivate)(struct file___30 *);
	void (*invalidatepage_range)(struct page___30 *, unsigned int, unsigned int);
};

struct inode_operations___30 {
	struct dentry___31 * (*lookup)(struct inode___31 *, struct dentry___31 *, unsigned int);
	void * (*follow_link)(struct dentry___31 *, struct nameidata *);
	int (*permission)(struct inode___31 *, int);
	struct posix_acl * (*get_acl)(struct inode___31 *, int);
	int (*readlink)(struct dentry___31 *, char *, int);
	void (*put_link)(struct dentry___31 *, struct nameidata *, void *);
	int (*create)(struct inode___31 *, struct dentry___31 *, umode_t, bool);
	int (*link)(struct dentry___31 *, struct inode___31 *, struct dentry___31 *);
	int (*unlink)(struct inode___31 *, struct dentry___31 *);
	int (*symlink)(struct inode___31 *, struct dentry___31 *, const char *);
	int (*mkdir)(struct inode___31 *, struct dentry___31 *, umode_t);
	int (*rmdir)(struct inode___31 *, struct dentry___31 *);
	int (*mknod)(struct inode___31 *, struct dentry___31 *, umode_t, dev_t);
	int (*rename)(struct inode___31 *, struct dentry___31 *, struct inode___31 *, struct dentry___31 *);
	int (*setattr)(struct dentry___31 *, struct iattr___31 *);
	int (*getattr)(struct vfsmount *, struct dentry___31 *, struct kstat *);
	int (*setxattr)(struct dentry___31 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___31 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___31 *, char *, size_t);
	int (*removexattr)(struct dentry___31 *, const char *);
	int (*fiemap)(struct inode___31 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___31 *, struct timespec *, int);
	int (*atomic_open)(struct inode___31 *, struct dentry___31 *, struct file___30 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___30;

struct file_lock_operations___30;

struct lock_manager_operations___30;

struct file_lock___30 {
	struct file_lock___30 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___30 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___30 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___30 *fl_ops;
	const struct lock_manager_operations___30 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___30 {
	void (*fl_copy_lock)(struct file_lock___30 *, struct file_lock___30 *);
	void (*fl_release_private)(struct file_lock___30 *);
};

struct lock_manager_operations___30 {
	int (*lm_compare_owner)(struct file_lock___30 *, struct file_lock___30 *);
	long unsigned int (*lm_owner_key)(struct file_lock___30 *);
	void (*lm_notify)(struct file_lock___30 *);
	int (*lm_grant)(struct file_lock___30 *, struct file_lock___30 *, int);
	void (*lm_break)(struct file_lock___30 *);
	int (*lm_change)(struct file_lock___30 **, int);
};

struct fasync_struct___30 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___30 *fa_next;
	struct file___30 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___30 {
	const char *name;
	int fs_flags;
	struct dentry___31 * (*mount)(struct file_system_type___30 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___31 *);
	struct module *owner;
	struct file_system_type___30 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___30 {
	struct inode___31 * (*alloc_inode)(struct super_block___31 *);
	void (*destroy_inode)(struct inode___31 *);
	void (*dirty_inode)(struct inode___31 *, int);
	int (*write_inode)(struct inode___31 *, struct writeback_control *);
	int (*drop_inode)(struct inode___31 *);
	void (*evict_inode)(struct inode___31 *);
	void (*put_super)(struct super_block___31 *);
	int (*sync_fs)(struct super_block___31 *, int);
	int (*freeze_fs)(struct super_block___31 *);
	int (*unfreeze_fs)(struct super_block___31 *);
	int (*statfs)(struct dentry___31 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___31 *, int *, char *);
	void (*umount_begin)(struct super_block___31 *);
	int (*show_options)(struct seq_file___20 *, struct dentry___31 *);
	int (*show_devname)(struct seq_file___20 *, struct dentry___31 *);
	int (*show_path)(struct seq_file___20 *, struct dentry___31 *);
	int (*show_stats)(struct seq_file___20 *, struct dentry___31 *);
	ssize_t (*quota_read)(struct super_block___31 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___31 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___31 *);
	int (*bdev_try_to_free_page)(struct super_block___31 *, struct page___30 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___31 *);
	void (*free_cached_objects)(struct super_block___31 *, int);
};

typedef void (*poll_queue_proc___16)(struct file___30 *, wait_queue_head_t *, struct poll_table_struct___16 *);

struct poll_table_struct___16 {
	poll_queue_proc___16 _qproc;
	long unsigned int _key;
};

struct tlb_state___7 {
	struct mm_struct___33 *active_mm;
	int state;
};

struct page___31;

typedef struct page___31 *pgtable_t___31;

struct address_space___31;

struct kmem_cache___26;

struct page___31 {
	long unsigned int flags;
	struct address_space___31 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___31 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___31 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___26 *slab_cache;
		struct page___31 *first_page;
	};
	long: 64;
};

struct task_struct___32;

struct pv_cpu_ops___31 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___32 *);
	void (*end_context_switch)(struct task_struct___32 *);
};

struct mutex___32 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___32 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___29 {
	struct page___31 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___34;

struct signal_struct___31;

struct task_struct___32 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___32 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___34 *mm;
	struct mm_struct___34 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___32 *real_parent;
	struct task_struct___32 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___32 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___31 = 0,
		VTIME_USER___31 = 1,
		VTIME_SYS___31 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___31 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___32 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___29 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___34 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___34 *, struct mm_struct___34 *);
	void (*dup_mmap)(struct mm_struct___34 *, struct mm_struct___34 *);
	void (*exit_mmap)(struct mm_struct___34 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___34 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___34 *);
	void (*pgd_free)(struct mm_struct___34 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___34 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___34 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___34 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___34 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___34 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___34 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___34 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___34 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___34 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___34 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___34 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___32 lock;
	void *vdso;
} mm_context_t___32;

struct xol_area___31;

struct uprobes_state___31 {
	struct xol_area___31 *xol_area;
};

struct vm_area_struct___34;

struct file___31;

struct core_state___31;

struct mm_struct___34 {
	struct vm_area_struct___34 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___34 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___34 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___32 context;
	long unsigned int flags;
	struct core_state___31 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___32 *owner;
	struct file___31 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___31 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___18;

struct exec_domain___8 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___18 *module;
	struct exec_domain___8 *next;
};

struct module_kobject___17 {
	struct kobject kobj;
	struct module___18 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___17;

struct module___18 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___17 mkobj;
	struct module_attribute___17 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___32 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___13 {
	struct task_struct___32 *task;
	struct exec_domain___8 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___21;

struct x86_io_apic_ops___21 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___21 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___21;

struct irq_data___21 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___21 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___31 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___32 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___31;

struct lruvec___31 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___31 *zone;
};

struct pglist_data___31;

struct zone___31 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___31 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___31 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___31 {
	struct zone___31 *zone;
	int zone_idx;
};

struct zonelist___31 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___31 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___31 {
	struct zone___31 node_zones[4];
	struct zonelist___31 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___32 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___32;

struct path___31 {
	struct vfsmount *mnt;
	struct dentry___32 *dentry;
};

struct inode___32;

struct file_operations___31;

struct file___31 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___31 f_path;
	struct inode___32 *f_inode;
	const struct file_operations___31 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___31 *f_mapping;
	struct mutex___32 f_pos_lock;
};

struct vm_operations_struct___26;

struct vm_area_struct___34 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___34 *vm_next;
	struct vm_area_struct___34 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___34 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___26 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___31 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___17 *, struct module_kobject___17 *, char *);
	ssize_t (*store)(struct module_attribute___17 *, struct module_kobject___17 *, const char *, size_t);
	void (*setup)(struct module___18 *, const char *);
	int (*test)(struct module___18 *);
	void (*free)(struct module___18 *);
};

struct xol_area___31 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___31 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___26;

struct memcg_cache_params___26;

struct kmem_cache___26 {
	struct kmem_cache_cpu___26 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___26 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___31;

struct address_space___31 {
	struct inode___32 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___32 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___31 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___24;

struct vm_operations_struct___26 {
	void (*open)(struct vm_area_struct___34 *);
	void (*close)(struct vm_area_struct___34 *);
	int (*fault)(struct vm_area_struct___34 *, struct vm_fault___24 *);
	int (*page_mkwrite)(struct vm_area_struct___34 *, struct vm_fault___24 *);
	int (*access)(struct vm_area_struct___34 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___34 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___34 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___34 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___34 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___31 {
	struct task_struct___32 *task;
	struct core_thread___31 *next;
};

struct core_state___31 {
	atomic_t nr_threads;
	struct core_thread___31 dumper;
	struct completion startup;
};

struct signal_struct___31 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___32 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___32 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___32 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sched_group;

struct sched_domain {
	struct sched_domain *parent;
	struct sched_domain *child;
	struct sched_group *groups;
	long unsigned int min_interval;
	long unsigned int max_interval;
	unsigned int busy_factor;
	unsigned int imbalance_pct;
	unsigned int cache_nice_tries;
	unsigned int busy_idx;
	unsigned int idle_idx;
	unsigned int newidle_idx;
	unsigned int wake_idx;
	unsigned int forkexec_idx;
	unsigned int smt_gain;
	int nohz_idle;
	int flags;
	int level;
	long unsigned int last_balance;
	unsigned int balance_interval;
	unsigned int nr_balance_failed;
	u64 last_update;
	u64 max_newidle_lb_cost;
	long unsigned int next_decay_max_lb_cost;
	unsigned int lb_count[3];
	unsigned int lb_failed[3];
	unsigned int lb_balanced[3];
	unsigned int lb_imbalance[3];
	unsigned int lb_gained[3];
	unsigned int lb_hot_gained[3];
	unsigned int lb_nobusyg[3];
	unsigned int lb_nobusyq[3];
	unsigned int alb_count;
	unsigned int alb_failed;
	unsigned int alb_pushed;
	unsigned int sbe_count;
	unsigned int sbe_balanced;
	unsigned int sbe_pushed;
	unsigned int sbf_count;
	unsigned int sbf_balanced;
	unsigned int sbf_pushed;
	unsigned int ttwu_wake_remote;
	unsigned int ttwu_move_affine;
	unsigned int ttwu_move_balance;
	char *name;
	union {
		void *private;
		struct callback_head rcu;
	};
	unsigned int span_weight;
	long unsigned int span[0];
};

typedef const struct cpumask * (*sched_domain_mask_f)(int);

typedef int (*sched_domain_flags_f)();

struct sched_group_power;

struct sd_data {
	struct sched_domain **sd;
	struct sched_group **sg;
	struct sched_group_power **sgp;
};

struct sched_domain_topology_level {
	sched_domain_mask_f mask;
	sched_domain_flags_f sd_flags;
	int flags;
	int numa_level;
	struct sd_data data;
	char *name;
};

struct kmem_cache_cpu___26 {
	void **freelist;
	long unsigned int tid;
	struct page___31 *page;
	struct page___31 *partial;
};

struct memcg_cache_params___26 {
	bool is_root_cache;
	union {
		struct kmem_cache___26 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___26 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___24 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___31 *page;
};

struct tlb_state___8 {
	struct mm_struct___34 *active_mm;
	int state;
};

struct dentry_operations___31;

struct super_block___32;

struct dentry___32 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___32 *d_parent;
	struct qstr d_name;
	struct inode___32 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___31 *d_op;
	struct super_block___32 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___31;

struct file_lock___31;

struct dquot___31;

struct block_device___31;

struct cdev___13;

struct inode___32 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___31 *i_op;
	struct super_block___32 *i_sb;
	struct address_space___31 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___32 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___31 *i_fop;
	struct file_lock___31 *i_flock;
	struct address_space___31 i_data;
	struct dquot___31 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___31 *i_bdev;
		struct cdev___13 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___31 {
	int (*d_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_hash)(const struct dentry___32 *, struct qstr *);
	int (*d_compare)(const struct dentry___32 *, const struct dentry___32 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___32 *);
	void (*d_release)(struct dentry___32 *);
	void (*d_prune)(struct dentry___32 *);
	void (*d_iput)(struct dentry___32 *, struct inode___32 *);
	char * (*d_dname)(struct dentry___32 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___31 *);
	int (*d_manage)(struct dentry___32 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___31;

struct mem_dqinfo___31 {
	struct quota_format_type___31 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___31;

struct quota_info___31 {
	unsigned int flags;
	struct mutex___32 dqio_mutex;
	struct mutex___32 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___32 *files[2];
	struct mem_dqinfo___31 info[2];
	const struct quota_format_ops___31 *ops[2];
};

struct file_system_type___31;

struct super_operations___31;

struct dquot_operations___31;

struct quotactl_ops___31;

struct super_block___32 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___31 *s_type;
	const struct super_operations___31 *s_op;
	const struct dquot_operations___31 *dq_op;
	const struct quotactl_ops___31 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___32 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___31 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___31 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___32 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___31 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___31 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___32 *bd_inode;
	struct super_block___32 *bd_super;
	struct mutex___32 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___31 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___32 bd_fsfreeze_mutex;
};

struct iattr___32 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___31 *ia_file;
};

struct dquot___31 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___32 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___32 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___31 {
	int qf_fmt_id;
	const struct quota_format_ops___31 *qf_ops;
	struct module___18 *qf_owner;
	struct quota_format_type___31 *qf_next;
};

struct quota_format_ops___31 {
	int (*check_quota_file)(struct super_block___32 *, int);
	int (*read_file_info)(struct super_block___32 *, int);
	int (*write_file_info)(struct super_block___32 *, int);
	int (*free_file_info)(struct super_block___32 *, int);
	int (*read_dqblk)(struct dquot___31 *);
	int (*commit_dqblk)(struct dquot___31 *);
	int (*release_dqblk)(struct dquot___31 *);
};

struct dquot_operations___31 {
	int (*write_dquot)(struct dquot___31 *);
	struct dquot___31 * (*alloc_dquot)(struct super_block___32 *, int);
	void (*destroy_dquot)(struct dquot___31 *);
	int (*acquire_dquot)(struct dquot___31 *);
	int (*release_dquot)(struct dquot___31 *);
	int (*mark_dirty)(struct dquot___31 *);
	int (*write_info)(struct super_block___32 *, int);
	qsize_t * (*get_reserved_space)(struct inode___32 *);
};

struct quotactl_ops___31 {
	int (*quota_on)(struct super_block___32 *, int, int, struct path___31 *);
	int (*quota_on_meta)(struct super_block___32 *, int, int);
	int (*quota_off)(struct super_block___32 *, int);
	int (*quota_sync)(struct super_block___32 *, int);
	int (*get_info)(struct super_block___32 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___32 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___32 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___32 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___32 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___32 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___32 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___32 *, unsigned int);
};

struct address_space_operations___31 {
	int (*writepage)(struct page___31 *, struct writeback_control *);
	int (*readpage)(struct file___31 *, struct page___31 *);
	int (*writepages)(struct address_space___31 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___31 *);
	int (*readpages)(struct file___31 *, struct address_space___31 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___31 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___31 **, void **);
	int (*write_end)(struct file___31 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___31 *, void *);
	sector_t (*bmap)(struct address_space___31 *, sector_t);
	void (*invalidatepage)(struct page___31 *, long unsigned int);
	int (*releasepage)(struct page___31 *, gfp_t);
	void (*freepage)(struct page___31 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___31 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___31 *, struct page___31 *, struct page___31 *, enum migrate_mode);
	int (*launder_page)(struct page___31 *);
	int (*is_partially_uptodate)(struct page___31 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___31 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___31 *, struct page___31 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___31 *, sector_t *);
	void (*swap_deactivate)(struct file___31 *);
	void (*invalidatepage_range)(struct page___31 *, unsigned int, unsigned int);
};

struct cdev___13 {
	struct kobject kobj;
	struct module___18 *owner;
	const struct file_operations___31 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___31 {
	struct dentry___32 * (*lookup)(struct inode___32 *, struct dentry___32 *, unsigned int);
	void * (*follow_link)(struct dentry___32 *, struct nameidata *);
	int (*permission)(struct inode___32 *, int);
	struct posix_acl * (*get_acl)(struct inode___32 *, int);
	int (*readlink)(struct dentry___32 *, char *, int);
	void (*put_link)(struct dentry___32 *, struct nameidata *, void *);
	int (*create)(struct inode___32 *, struct dentry___32 *, umode_t, bool);
	int (*link)(struct dentry___32 *, struct inode___32 *, struct dentry___32 *);
	int (*unlink)(struct inode___32 *, struct dentry___32 *);
	int (*symlink)(struct inode___32 *, struct dentry___32 *, const char *);
	int (*mkdir)(struct inode___32 *, struct dentry___32 *, umode_t);
	int (*rmdir)(struct inode___32 *, struct dentry___32 *);
	int (*mknod)(struct inode___32 *, struct dentry___32 *, umode_t, dev_t);
	int (*rename)(struct inode___32 *, struct dentry___32 *, struct inode___32 *, struct dentry___32 *);
	int (*setattr)(struct dentry___32 *, struct iattr___32 *);
	int (*getattr)(struct vfsmount *, struct dentry___32 *, struct kstat *);
	int (*setxattr)(struct dentry___32 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___32 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___32 *, char *, size_t);
	int (*removexattr)(struct dentry___32 *, const char *);
	int (*fiemap)(struct inode___32 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___32 *, struct timespec *, int);
	int (*atomic_open)(struct inode___32 *, struct dentry___32 *, struct file___31 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___17;

struct seq_file___21;

struct file_operations___31 {
	struct module___18 *owner;
	loff_t (*llseek)(struct file___31 *, loff_t, int);
	ssize_t (*read)(struct file___31 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___31 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___31 *, void *, filldir_t);
	unsigned int (*poll)(struct file___31 *, struct poll_table_struct___17 *);
	long int (*unlocked_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___31 *, struct vm_area_struct___34 *);
	int (*open)(struct inode___32 *, struct file___31 *);
	int (*flush)(struct file___31 *, fl_owner_t);
	int (*release)(struct inode___32 *, struct file___31 *);
	int (*fsync)(struct file___31 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___31 *, int);
	int (*lock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*sendpage)(struct file___31 *, struct page___31 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___31 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___31 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___31 *, long int, struct file_lock___31 **, void **);
		struct {
			int (*setlease)(struct file___31 *, long int, struct file_lock___31 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___31 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___21 *, struct file___31 *);
};

struct fasync_struct___31;

struct file_lock_operations___31;

struct lock_manager_operations___31;

struct file_lock___31 {
	struct file_lock___31 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___31 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___31 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___31 *fl_ops;
	const struct lock_manager_operations___31 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___31 {
	void (*fl_copy_lock)(struct file_lock___31 *, struct file_lock___31 *);
	void (*fl_release_private)(struct file_lock___31 *);
};

struct lock_manager_operations___31 {
	int (*lm_compare_owner)(struct file_lock___31 *, struct file_lock___31 *);
	long unsigned int (*lm_owner_key)(struct file_lock___31 *);
	void (*lm_notify)(struct file_lock___31 *);
	int (*lm_grant)(struct file_lock___31 *, struct file_lock___31 *, int);
	void (*lm_break)(struct file_lock___31 *);
	int (*lm_change)(struct file_lock___31 **, int);
};

struct fasync_struct___31 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___31 *fa_next;
	struct file___31 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___31 {
	const char *name;
	int fs_flags;
	struct dentry___32 * (*mount)(struct file_system_type___31 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___32 *);
	struct module___18 *owner;
	struct file_system_type___31 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___31 {
	struct inode___32 * (*alloc_inode)(struct super_block___32 *);
	void (*destroy_inode)(struct inode___32 *);
	void (*dirty_inode)(struct inode___32 *, int);
	int (*write_inode)(struct inode___32 *, struct writeback_control *);
	int (*drop_inode)(struct inode___32 *);
	void (*evict_inode)(struct inode___32 *);
	void (*put_super)(struct super_block___32 *);
	int (*sync_fs)(struct super_block___32 *, int);
	int (*freeze_fs)(struct super_block___32 *);
	int (*unfreeze_fs)(struct super_block___32 *);
	int (*statfs)(struct dentry___32 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___32 *, int *, char *);
	void (*umount_begin)(struct super_block___32 *);
	int (*show_options)(struct seq_file___21 *, struct dentry___32 *);
	int (*show_devname)(struct seq_file___21 *, struct dentry___32 *);
	int (*show_path)(struct seq_file___21 *, struct dentry___32 *);
	int (*show_stats)(struct seq_file___21 *, struct dentry___32 *);
	ssize_t (*quota_read)(struct super_block___32 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___32 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___32 *);
	int (*bdev_try_to_free_page)(struct super_block___32 *, struct page___31 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___32 *);
	void (*free_cached_objects)(struct super_block___32 *, int);
};

typedef void (*poll_queue_proc___17)(struct file___31 *, wait_queue_head_t *, struct poll_table_struct___17 *);

struct poll_table_struct___17 {
	poll_queue_proc___17 _qproc;
	long unsigned int _key;
};

struct seq_operations___21;

struct seq_file___21 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___32 lock;
	const struct seq_operations___21 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___21 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___21 *);
	void (*irq_shutdown)(struct irq_data___21 *);
	void (*irq_enable)(struct irq_data___21 *);
	void (*irq_disable)(struct irq_data___21 *);
	void (*irq_ack)(struct irq_data___21 *);
	void (*irq_mask)(struct irq_data___21 *);
	void (*irq_mask_ack)(struct irq_data___21 *);
	void (*irq_unmask)(struct irq_data___21 *);
	void (*irq_eoi)(struct irq_data___21 *);
	int (*irq_set_affinity)(struct irq_data___21 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___21 *);
	int (*irq_set_type)(struct irq_data___21 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___21 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___21 *);
	void (*irq_bus_sync_unlock)(struct irq_data___21 *);
	void (*irq_cpu_online)(struct irq_data___21 *);
	void (*irq_cpu_offline)(struct irq_data___21 *);
	void (*irq_suspend)(struct irq_data___21 *);
	void (*irq_resume)(struct irq_data___21 *);
	void (*irq_pm_shutdown)(struct irq_data___21 *);
	void (*irq_print_chip)(struct irq_data___21 *, struct seq_file___21 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___21 *, void *);
	long unsigned int flags;
};

enum uv_system_type {
	UV_NONE = 0,
	UV_LEGACY_APIC = 1,
	UV_X2APIC = 2,
	UV_NON_UNIQUE_APIC = 3,
};

struct seq_operations___21 {
	void * (*start)(struct seq_file___21 *, loff_t *);
	void (*stop)(struct seq_file___21 *, void *);
	void * (*next)(struct seq_file___21 *, void *, loff_t *);
	int (*show)(struct seq_file___21 *, void *);
};

struct legacy_pic___5 {
	int nr_legacy_irqs;
	struct irq_chip___21 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

typedef void * (*pcpu_fc_alloc_fn_t)(unsigned int, size_t, size_t);

typedef void (*pcpu_fc_free_fn_t)(void *, size_t);

typedef void (*pcpu_fc_populate_pte_fn_t)(long unsigned int);

typedef int pcpu_fc_cpu_distance_fn_t(unsigned int, unsigned int);

struct tlb_state___9 {
	struct mm_struct___3 *active_mm;
	int state;
};

enum {
	DUMP_PREFIX_NONE = 0,
	DUMP_PREFIX_ADDRESS = 1,
	DUMP_PREFIX_OFFSET = 2,
};

struct page___32;

typedef struct page___32 *pgtable_t___32;

struct address_space___32;

struct kmem_cache___27;

struct page___32 {
	long unsigned int flags;
	struct address_space___32 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___32 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___32 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___27 *slab_cache;
		struct page___32 *first_page;
	};
	long: 64;
};

struct task_struct___33;

struct pv_cpu_ops___32 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___14 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___33 *);
	void (*end_context_switch)(struct task_struct___33 *);
};

struct mutex___33 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___33 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___30 {
	struct page___32 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___35;

struct signal_struct___32;

struct task_struct___33 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___33 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___35 *mm;
	struct mm_struct___35 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___33 *real_parent;
	struct task_struct___33 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___33 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___15 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___32 = 0,
		VTIME_USER___32 = 1,
		VTIME_SYS___32 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___14 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___32 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___33 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___30 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___35 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___35 *, struct mm_struct___35 *);
	void (*dup_mmap)(struct mm_struct___35 *, struct mm_struct___35 *);
	void (*exit_mmap)(struct mm_struct___35 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___35 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___35 *);
	void (*pgd_free)(struct mm_struct___35 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___35 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___35 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___35 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___35 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___35 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___35 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___35 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___35 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___35 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___35 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___35 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___33 lock;
	void *vdso;
} mm_context_t___33;

struct xol_area___32;

struct uprobes_state___32 {
	struct xol_area___32 *xol_area;
};

struct vm_area_struct___35;

struct file___32;

struct core_state___32;

struct mm_struct___35 {
	struct vm_area_struct___35 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___35 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___35 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___33 context;
	long unsigned int flags;
	struct core_state___32 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___33 *owner;
	struct file___32 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___32 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___19;

struct module_kobject___18 {
	struct kobject kobj;
	struct module___19 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___18;

struct module___19 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___18 mkobj;
	struct module_attribute___18 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___33 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___32;

struct lruvec___32 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___32 *zone;
};

struct pglist_data___32;

struct zone___32 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___32 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___32 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___32 {
	struct zone___32 *zone;
	int zone_idx;
};

struct zonelist___32 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___32 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___32 {
	struct zone___32 node_zones[4];
	struct zonelist___32 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___33 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mpf_intel {
	char signature[4];
	unsigned int physptr;
	unsigned char length;
	unsigned char specification;
	unsigned char checksum;
	unsigned char feature1;
	unsigned char feature2;
	unsigned char feature3;
	unsigned char feature4;
	unsigned char feature5;
};

struct mpc_ioapic {
	unsigned char type;
	unsigned char apicid;
	unsigned char apicver;
	unsigned char flags;
	unsigned int apicaddr;
};

struct mpc_lintsrc {
	unsigned char type;
	unsigned char irqtype;
	short unsigned int irqflag;
	unsigned char srcbusid;
	unsigned char srcbusirq;
	unsigned char destapic;
	unsigned char destapiclint;
};

struct irq_data___22;

struct x86_io_apic_ops___22 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___22 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___22;

struct irq_data___22 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___22 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___27;

struct dev_pm_ops___27 {
	int (*prepare)(struct device___27 *);
	void (*complete)(struct device___27 *);
	int (*suspend)(struct device___27 *);
	int (*resume)(struct device___27 *);
	int (*freeze)(struct device___27 *);
	int (*thaw)(struct device___27 *);
	int (*poweroff)(struct device___27 *);
	int (*restore)(struct device___27 *);
	int (*suspend_late)(struct device___27 *);
	int (*resume_early)(struct device___27 *);
	int (*freeze_late)(struct device___27 *);
	int (*thaw_early)(struct device___27 *);
	int (*poweroff_late)(struct device___27 *);
	int (*restore_early)(struct device___27 *);
	int (*suspend_noirq)(struct device___27 *);
	int (*resume_noirq)(struct device___27 *);
	int (*freeze_noirq)(struct device___27 *);
	int (*thaw_noirq)(struct device___27 *);
	int (*poweroff_noirq)(struct device___27 *);
	int (*restore_noirq)(struct device___27 *);
	int (*runtime_suspend)(struct device___27 *);
	int (*runtime_resume)(struct device___27 *);
	int (*runtime_idle)(struct device___27 *);
};

struct dma_map_ops___13;

struct dev_archdata___13 {
	struct dma_map_ops___13 *dma_ops;
	void *iommu;
};

struct acpi_device___8;

struct acpi_dev_node___11 {
	union {
		struct acpi_device___8 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___27;

struct bus_type___27;

struct device_driver___27;

struct dev_pm_domain___27;

struct class___27;

struct attribute_group___23;

struct device_rh___27;

struct device___27 {
	struct device___27 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___27 *type;
	struct mutex___33 mutex;
	struct bus_type___27 *bus;
	struct device_driver___27 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___27 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___13 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___27 *class;
	const struct attribute_group___23 **groups;
	void (*release)(struct device___27 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___27 *device_rh;
};

struct dev_pm_info_rh___27 {
	void (*set_latency_tolerance)(struct device___27 *, s32);
};

struct dev_pm_domain___27 {
	struct dev_pm_ops___27 ops;
};

struct smp_ops___32 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___33 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___32 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___32 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___27;

struct memcg_cache_params___27;

struct kmem_cache___27 {
	struct kmem_cache_cpu___27 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___27 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___33;

struct address_space_operations___32;

struct address_space___32 {
	struct inode___33 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___33 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___32 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___33;

struct path___32 {
	struct vfsmount *mnt;
	struct dentry___33 *dentry;
};

struct file_operations___32;

struct file___32 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___32 f_path;
	struct inode___33 *f_inode;
	const struct file_operations___32 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___32 *f_mapping;
	struct mutex___33 f_pos_lock;
};

struct vm_operations_struct___27;

struct vm_area_struct___35 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___35 *vm_next;
	struct vm_area_struct___35 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___35 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___27 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___32 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___25;

struct vm_operations_struct___27 {
	void (*open)(struct vm_area_struct___35 *);
	void (*close)(struct vm_area_struct___35 *);
	int (*fault)(struct vm_area_struct___35 *, struct vm_fault___25 *);
	int (*page_mkwrite)(struct vm_area_struct___35 *, struct vm_fault___25 *);
	int (*access)(struct vm_area_struct___35 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___35 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___35 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___35 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___35 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___32 {
	struct task_struct___33 *task;
	struct core_thread___32 *next;
};

struct core_state___32 {
	atomic_t nr_threads;
	struct core_thread___32 dumper;
	struct completion startup;
};

struct vm_fault___25 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___32 *page;
};

struct seq_file___22;

struct irq_chip___22 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___22 *);
	void (*irq_shutdown)(struct irq_data___22 *);
	void (*irq_enable)(struct irq_data___22 *);
	void (*irq_disable)(struct irq_data___22 *);
	void (*irq_ack)(struct irq_data___22 *);
	void (*irq_mask)(struct irq_data___22 *);
	void (*irq_mask_ack)(struct irq_data___22 *);
	void (*irq_unmask)(struct irq_data___22 *);
	void (*irq_eoi)(struct irq_data___22 *);
	int (*irq_set_affinity)(struct irq_data___22 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___22 *);
	int (*irq_set_type)(struct irq_data___22 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___22 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___22 *);
	void (*irq_bus_sync_unlock)(struct irq_data___22 *);
	void (*irq_cpu_online)(struct irq_data___22 *);
	void (*irq_cpu_offline)(struct irq_data___22 *);
	void (*irq_suspend)(struct irq_data___22 *);
	void (*irq_resume)(struct irq_data___22 *);
	void (*irq_pm_shutdown)(struct irq_data___22 *);
	void (*irq_print_chip)(struct irq_data___22 *, struct seq_file___22 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___22 *, void *);
	long unsigned int flags;
};

struct seq_operations___22;

struct seq_file___22 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___33 lock;
	const struct seq_operations___22 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___32 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___33 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___33 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___15 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___33 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___23;

struct attribute_group___23 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___23 **bin_attrs;
};

struct bin_attribute___23 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___32 *, struct kobject *, struct bin_attribute___23 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___32 *, struct kobject *, struct bin_attribute___23 *, char *, loff_t, size_t);
	int (*mmap)(struct file___32 *, struct kobject *, struct bin_attribute___23 *, struct vm_area_struct___35 *);
};

struct dma_map_ops___13 {
	void * (*alloc)(struct device___27 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___27 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___27 *, struct vm_area_struct___35 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___27 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___27 *, struct page___32 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___27 *, dma_addr_t);
	int (*dma_supported)(struct device___27 *, u64);
	int (*set_dma_mask)(struct device___27 *, u64);
	int is_phys;
};

struct bus_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___27 *, char *);
	ssize_t (*store)(struct bus_type___27 *, const char *, size_t);
};

struct device_attribute___27;

struct driver_attribute___27;

struct bus_type___27 {
	const char *name;
	const char *dev_name;
	struct device___27 *dev_root;
	struct bus_attribute___27 *bus_attrs;
	struct device_attribute___27 *dev_attrs;
	struct driver_attribute___27 *drv_attrs;
	const struct attribute_group___23 **bus_groups;
	const struct attribute_group___23 **dev_groups;
	const struct attribute_group___23 **drv_groups;
	int (*match)(struct device___27 *, struct device_driver___27 *);
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	int (*probe)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*online)(struct device___27 *);
	int (*offline)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct device___27 *, struct device_attribute___27 *, char *);
	ssize_t (*store)(struct device___27 *, struct device_attribute___27 *, const char *, size_t);
};

struct driver_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___27 *, char *);
	ssize_t (*store)(struct device_driver___27 *, const char *, size_t);
};

struct device_driver___27 {
	const char *name;
	struct bus_type___27 *bus;
	struct module___19 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct attribute_group___23 **groups;
	const struct dev_pm_ops___27 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___27 {
	const char *name;
	const struct attribute_group___23 **groups;
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
};

struct class_attribute___27;

struct class___27 {
	const char *name;
	struct module___19 *owner;
	struct class_attribute___27 *class_attrs;
	struct device_attribute___27 *dev_attrs;
	const struct attribute_group___23 **dev_groups;
	struct bin_attribute___23 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *);
	void (*class_release)(struct class___27 *);
	void (*dev_release)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	struct subsys_private *p;
};

struct class_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct class___27 *, struct class_attribute___27 *, char *);
	ssize_t (*store)(struct class___27 *, struct class_attribute___27 *, const char *, size_t);
	const void * (*namespace)(struct class___27 *, const struct class_attribute___27 *);
};

struct acpi_scan_handler___8;

struct acpi_hotplug_context___8;

struct acpi_driver___8;

struct acpi_device___8 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___8 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___8 *handler;
	struct acpi_hotplug_context___8 *hp;
	struct acpi_driver___8 *driver;
	void *driver_data;
	struct device___27 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___33 physical_node_lock;
	void (*remove)(struct acpi_device___8 *);
};

struct device_rh___27 {
	struct dev_pm_info_rh___27 power;
};

struct seq_operations___22 {
	void * (*start)(struct seq_file___22 *, loff_t *);
	void (*stop)(struct seq_file___22 *, void *);
	void * (*next)(struct seq_file___22 *, void *, loff_t *);
	int (*show)(struct seq_file___22 *, void *);
};

struct cdev___14 {
	struct kobject kobj;
	struct module___19 *owner;
	const struct file_operations___32 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___18;

struct file_lock___32;

struct file_operations___32 {
	struct module___19 *owner;
	loff_t (*llseek)(struct file___32 *, loff_t, int);
	ssize_t (*read)(struct file___32 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___32 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___32 *, void *, filldir_t);
	unsigned int (*poll)(struct file___32 *, struct poll_table_struct___18 *);
	long int (*unlocked_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___32 *, struct vm_area_struct___35 *);
	int (*open)(struct inode___33 *, struct file___32 *);
	int (*flush)(struct file___32 *, fl_owner_t);
	int (*release)(struct inode___33 *, struct file___32 *);
	int (*fsync)(struct file___32 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___32 *, int);
	int (*lock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*sendpage)(struct file___32 *, struct page___32 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___32 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___32 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___32 *, long int, struct file_lock___32 **, void **);
		struct {
			int (*setlease)(struct file___32 *, long int, struct file_lock___32 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___32 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___22 *, struct file___32 *);
};

struct dentry_operations___32;

struct super_block___33;

struct dentry___33 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___33 *d_parent;
	struct qstr d_name;
	struct inode___33 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___32 *d_op;
	struct super_block___33 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___32;

struct dquot___32;

struct block_device___32;

struct inode___33 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___32 *i_op;
	struct super_block___33 *i_sb;
	struct address_space___32 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___33 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___32 *i_fop;
	struct file_lock___32 *i_flock;
	struct address_space___32 i_data;
	struct dquot___32 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___32 *i_bdev;
		struct cdev___14 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___32 {
	int (*d_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_hash)(const struct dentry___33 *, struct qstr *);
	int (*d_compare)(const struct dentry___33 *, const struct dentry___33 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___33 *);
	void (*d_release)(struct dentry___33 *);
	void (*d_prune)(struct dentry___33 *);
	void (*d_iput)(struct dentry___33 *, struct inode___33 *);
	char * (*d_dname)(struct dentry___33 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___32 *);
	int (*d_manage)(struct dentry___33 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___32;

struct mem_dqinfo___32 {
	struct quota_format_type___32 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___32;

struct quota_info___32 {
	unsigned int flags;
	struct mutex___33 dqio_mutex;
	struct mutex___33 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___33 *files[2];
	struct mem_dqinfo___32 info[2];
	const struct quota_format_ops___32 *ops[2];
};

struct file_system_type___32;

struct super_operations___32;

struct dquot_operations___32;

struct quotactl_ops___32;

struct super_block___33 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___32 *s_type;
	const struct super_operations___32 *s_op;
	const struct dquot_operations___32 *dq_op;
	const struct quotactl_ops___32 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___33 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___32 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___32 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___33 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___32 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___32 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___33 *bd_inode;
	struct super_block___33 *bd_super;
	struct mutex___33 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___32 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___33 bd_fsfreeze_mutex;
};

struct iattr___33 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___32 *ia_file;
};

struct dquot___32 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___33 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___33 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___32 {
	int qf_fmt_id;
	const struct quota_format_ops___32 *qf_ops;
	struct module___19 *qf_owner;
	struct quota_format_type___32 *qf_next;
};

struct quota_format_ops___32 {
	int (*check_quota_file)(struct super_block___33 *, int);
	int (*read_file_info)(struct super_block___33 *, int);
	int (*write_file_info)(struct super_block___33 *, int);
	int (*free_file_info)(struct super_block___33 *, int);
	int (*read_dqblk)(struct dquot___32 *);
	int (*commit_dqblk)(struct dquot___32 *);
	int (*release_dqblk)(struct dquot___32 *);
};

struct dquot_operations___32 {
	int (*write_dquot)(struct dquot___32 *);
	struct dquot___32 * (*alloc_dquot)(struct super_block___33 *, int);
	void (*destroy_dquot)(struct dquot___32 *);
	int (*acquire_dquot)(struct dquot___32 *);
	int (*release_dquot)(struct dquot___32 *);
	int (*mark_dirty)(struct dquot___32 *);
	int (*write_info)(struct super_block___33 *, int);
	qsize_t * (*get_reserved_space)(struct inode___33 *);
};

struct quotactl_ops___32 {
	int (*quota_on)(struct super_block___33 *, int, int, struct path___32 *);
	int (*quota_on_meta)(struct super_block___33 *, int, int);
	int (*quota_off)(struct super_block___33 *, int);
	int (*quota_sync)(struct super_block___33 *, int);
	int (*get_info)(struct super_block___33 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___33 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___33 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___33 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___33 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___33 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___33 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___33 *, unsigned int);
};

struct address_space_operations___32 {
	int (*writepage)(struct page___32 *, struct writeback_control *);
	int (*readpage)(struct file___32 *, struct page___32 *);
	int (*writepages)(struct address_space___32 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___32 *);
	int (*readpages)(struct file___32 *, struct address_space___32 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___32 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___32 **, void **);
	int (*write_end)(struct file___32 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___32 *, void *);
	sector_t (*bmap)(struct address_space___32 *, sector_t);
	void (*invalidatepage)(struct page___32 *, long unsigned int);
	int (*releasepage)(struct page___32 *, gfp_t);
	void (*freepage)(struct page___32 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___32 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___32 *, struct page___32 *, struct page___32 *, enum migrate_mode);
	int (*launder_page)(struct page___32 *);
	int (*is_partially_uptodate)(struct page___32 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___32 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___32 *, struct page___32 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___32 *, sector_t *);
	void (*swap_deactivate)(struct file___32 *);
	void (*invalidatepage_range)(struct page___32 *, unsigned int, unsigned int);
};

struct inode_operations___32 {
	struct dentry___33 * (*lookup)(struct inode___33 *, struct dentry___33 *, unsigned int);
	void * (*follow_link)(struct dentry___33 *, struct nameidata *);
	int (*permission)(struct inode___33 *, int);
	struct posix_acl * (*get_acl)(struct inode___33 *, int);
	int (*readlink)(struct dentry___33 *, char *, int);
	void (*put_link)(struct dentry___33 *, struct nameidata *, void *);
	int (*create)(struct inode___33 *, struct dentry___33 *, umode_t, bool);
	int (*link)(struct dentry___33 *, struct inode___33 *, struct dentry___33 *);
	int (*unlink)(struct inode___33 *, struct dentry___33 *);
	int (*symlink)(struct inode___33 *, struct dentry___33 *, const char *);
	int (*mkdir)(struct inode___33 *, struct dentry___33 *, umode_t);
	int (*rmdir)(struct inode___33 *, struct dentry___33 *);
	int (*mknod)(struct inode___33 *, struct dentry___33 *, umode_t, dev_t);
	int (*rename)(struct inode___33 *, struct dentry___33 *, struct inode___33 *, struct dentry___33 *);
	int (*setattr)(struct dentry___33 *, struct iattr___33 *);
	int (*getattr)(struct vfsmount *, struct dentry___33 *, struct kstat *);
	int (*setxattr)(struct dentry___33 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___33 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___33 *, char *, size_t);
	int (*removexattr)(struct dentry___33 *, const char *);
	int (*fiemap)(struct inode___33 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___33 *, struct timespec *, int);
	int (*atomic_open)(struct inode___33 *, struct dentry___33 *, struct file___32 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___32;

struct file_lock_operations___32;

struct lock_manager_operations___32;

struct file_lock___32 {
	struct file_lock___32 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___15 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___32 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___32 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___32 *fl_ops;
	const struct lock_manager_operations___32 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___32 {
	void (*fl_copy_lock)(struct file_lock___32 *, struct file_lock___32 *);
	void (*fl_release_private)(struct file_lock___32 *);
};

struct lock_manager_operations___32 {
	int (*lm_compare_owner)(struct file_lock___32 *, struct file_lock___32 *);
	long unsigned int (*lm_owner_key)(struct file_lock___32 *);
	void (*lm_notify)(struct file_lock___32 *);
	int (*lm_grant)(struct file_lock___32 *, struct file_lock___32 *, int);
	void (*lm_break)(struct file_lock___32 *);
	int (*lm_change)(struct file_lock___32 **, int);
};

struct fasync_struct___32 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___32 *fa_next;
	struct file___32 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___32 {
	const char *name;
	int fs_flags;
	struct dentry___33 * (*mount)(struct file_system_type___32 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___33 *);
	struct module___19 *owner;
	struct file_system_type___32 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___32 {
	struct inode___33 * (*alloc_inode)(struct super_block___33 *);
	void (*destroy_inode)(struct inode___33 *);
	void (*dirty_inode)(struct inode___33 *, int);
	int (*write_inode)(struct inode___33 *, struct writeback_control *);
	int (*drop_inode)(struct inode___33 *);
	void (*evict_inode)(struct inode___33 *);
	void (*put_super)(struct super_block___33 *);
	int (*sync_fs)(struct super_block___33 *, int);
	int (*freeze_fs)(struct super_block___33 *);
	int (*unfreeze_fs)(struct super_block___33 *);
	int (*statfs)(struct dentry___33 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___33 *, int *, char *);
	void (*umount_begin)(struct super_block___33 *);
	int (*show_options)(struct seq_file___22 *, struct dentry___33 *);
	int (*show_devname)(struct seq_file___22 *, struct dentry___33 *);
	int (*show_path)(struct seq_file___22 *, struct dentry___33 *);
	int (*show_stats)(struct seq_file___22 *, struct dentry___33 *);
	ssize_t (*quota_read)(struct super_block___33 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___33 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___33 *);
	int (*bdev_try_to_free_page)(struct super_block___33 *, struct page___32 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___33 *);
	void (*free_cached_objects)(struct super_block___33 *, int);
};

typedef void (*poll_queue_proc___18)(struct file___32 *, wait_queue_head_t *, struct poll_table_struct___18 *);

struct poll_table_struct___18 {
	poll_queue_proc___18 _qproc;
	long unsigned int _key;
};

struct kmem_cache_cpu___27 {
	void **freelist;
	long unsigned int tid;
	struct page___32 *page;
	struct page___32 *partial;
};

struct memcg_cache_params___27 {
	bool is_root_cache;
	union {
		struct kmem_cache___27 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___27 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct acpi_hotplug_profile___8 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___8 *);
	void (*notify_online)(struct acpi_device___8 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___8 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___8 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___8 *);
	void (*bind)(struct device___27 *);
	void (*unbind)(struct device___27 *);
	struct acpi_hotplug_profile___8 hotplug;
};

struct acpi_hotplug_context___8 {
	struct acpi_device___8 *self;
	int (*notify)(struct acpi_device___8 *, u32);
	void (*uevent)(struct acpi_device___8 *, u32);
	void (*fixup)(struct acpi_device___8 *);
};

typedef int (*acpi_op_add___8)(struct acpi_device___8 *);

typedef int (*acpi_op_remove___8)(struct acpi_device___8 *);

typedef void (*acpi_op_notify___8)(struct acpi_device___8 *, u32);

struct acpi_device_ops___8 {
	acpi_op_add___8 add;
	acpi_op_remove___8 remove;
	acpi_op_notify___8 notify;
};

struct acpi_driver___8 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___8 ops;
	struct device_driver___27 drv;
	struct module___19 *owner;
};

struct module_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___18 *, struct module_kobject___18 *, char *);
	ssize_t (*store)(struct module_attribute___18 *, struct module_kobject___18 *, const char *, size_t);
	void (*setup)(struct module___19 *, const char *);
	int (*test)(struct module___19 *);
	void (*free)(struct module___19 *);
};

struct page___33;

typedef struct page___33 *pgtable_t___33;

struct address_space___33;

struct kmem_cache___28;

struct page___33 {
	long unsigned int flags;
	struct address_space___33 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___33 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___33 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___28 *slab_cache;
		struct page___33 *first_page;
	};
	long: 64;
};

struct thread_struct___15;

struct task_struct___34;

struct pv_cpu_ops___33 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___15 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___15 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___34 *);
	void (*end_context_switch)(struct task_struct___34 *);
};

struct perf_event___15;

struct thread_struct___15 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___15 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___16;

struct pid_link___16 {
	struct hlist_node node;
	struct pid___16 *pid;
};

struct mutex___34 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___34 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___31 {
	struct page___33 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___36;

struct nsproxy___16;

struct signal_struct___33;

struct css_set___15;

struct perf_event_context___15;

struct task_struct___34 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___34 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___36 *mm;
	struct mm_struct___36 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___34 *real_parent;
	struct task_struct___34 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___34 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___16 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___33 = 0,
		VTIME_USER___33 = 1,
		VTIME_SYS___33 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___15 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___16 *nsproxy;
	struct signal_struct___33 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___15 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___15 *perf_event_ctxp[2];
	struct mutex___34 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___31 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___36 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___36 *, struct mm_struct___36 *);
	void (*dup_mmap)(struct mm_struct___36 *, struct mm_struct___36 *);
	void (*exit_mmap)(struct mm_struct___36 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___36 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___36 *);
	void (*pgd_free)(struct mm_struct___36 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___36 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___36 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___36 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___36 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___36 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___36 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___36 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___36 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___36 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___36 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___36 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___34 lock;
	void *vdso;
} mm_context_t___34;

struct xol_area___33;

struct uprobes_state___33 {
	struct xol_area___33 *xol_area;
};

struct vm_area_struct___36;

struct file___33;

struct core_state___33;

struct mm_struct___36 {
	struct vm_area_struct___36 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___36 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___36 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___34 context;
	long unsigned int flags;
	struct core_state___33 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___34 *owner;
	struct file___33 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___33 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___20;

struct module_kobject___19 {
	struct kobject kobj;
	struct module___20 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___19;

struct module___20 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___19 mkobj;
	struct module_attribute___19 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___34 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___15 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___34 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___34 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___34 *target;
};

typedef void (*perf_overflow_handler_t___15)(struct perf_event___15 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___15;

typedef void (*ftrace_func_t___15)(long unsigned int, long unsigned int, struct ftrace_ops___15 *, struct pt_regs *);

struct ftrace_ops___15 {
	ftrace_func_t___15 func;
	struct ftrace_ops___15 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___34 regex_lock;
};

struct pmu___15;

struct fasync_struct___33;

struct pid_namespace___16;

struct perf_cgroup___15;

struct perf_event___15 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___15 *group_leader;
	struct pmu___15 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___15 hw;
	struct perf_event_context___15 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___34 child_mutex;
	struct list_head child_list;
	struct perf_event___15 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___34 *owner;
	struct mutex___34 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___33 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___15 *);
	struct callback_head callback_head;
	struct pid_namespace___16 *ns;
	u64 id;
	perf_overflow_handler_t___15 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___15 ftrace_ops;
	struct perf_cgroup___15 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___33 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___33 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___28;

struct memcg_cache_params___28;

struct kmem_cache___28 {
	struct kmem_cache_cpu___28 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___28 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___34;

struct address_space_operations___33;

struct address_space___33 {
	struct inode___34 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___34 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___33 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___34;

struct path___33 {
	struct vfsmount *mnt;
	struct dentry___34 *dentry;
};

struct fown_struct___16 {
	rwlock_t lock;
	struct pid___16 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___33;

struct file___33 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___33 f_path;
	struct inode___34 *f_inode;
	const struct file_operations___33 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___33 *f_mapping;
	struct mutex___34 f_pos_lock;
};

struct vm_operations_struct___28;

struct vm_area_struct___36 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___36 *vm_next;
	struct vm_area_struct___36 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___36 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___28 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___33 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___26;

struct vm_operations_struct___28 {
	void (*open)(struct vm_area_struct___36 *);
	void (*close)(struct vm_area_struct___36 *);
	int (*fault)(struct vm_area_struct___36 *, struct vm_fault___26 *);
	int (*page_mkwrite)(struct vm_area_struct___36 *, struct vm_fault___26 *);
	int (*access)(struct vm_area_struct___36 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___36 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___36 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___36 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___36 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___33 {
	struct task_struct___34 *task;
	struct core_thread___33 *next;
};

struct core_state___33 {
	atomic_t nr_threads;
	struct core_thread___33 dumper;
	struct completion startup;
};

struct irq_data___23;

struct x86_io_apic_ops___23 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___23 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___23;

struct irq_data___23 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___23 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
};

struct device___28;

struct dev_pm_ops___28 {
	int (*prepare)(struct device___28 *);
	void (*complete)(struct device___28 *);
	int (*suspend)(struct device___28 *);
	int (*resume)(struct device___28 *);
	int (*freeze)(struct device___28 *);
	int (*thaw)(struct device___28 *);
	int (*poweroff)(struct device___28 *);
	int (*restore)(struct device___28 *);
	int (*suspend_late)(struct device___28 *);
	int (*resume_early)(struct device___28 *);
	int (*freeze_late)(struct device___28 *);
	int (*thaw_early)(struct device___28 *);
	int (*poweroff_late)(struct device___28 *);
	int (*restore_early)(struct device___28 *);
	int (*suspend_noirq)(struct device___28 *);
	int (*resume_noirq)(struct device___28 *);
	int (*freeze_noirq)(struct device___28 *);
	int (*thaw_noirq)(struct device___28 *);
	int (*poweroff_noirq)(struct device___28 *);
	int (*restore_noirq)(struct device___28 *);
	int (*runtime_suspend)(struct device___28 *);
	int (*runtime_resume)(struct device___28 *);
	int (*runtime_idle)(struct device___28 *);
};

struct acpi_device___9;

struct acpi_dev_node___12 {
	union {
		struct acpi_device___9 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct device_type___28;

struct bus_type___28;

struct device_driver___28;

struct dev_pm_domain___28;

struct class___28;

struct attribute_group___24;

struct device_rh___28;

struct device___28 {
	struct device___28 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___28 *type;
	struct mutex___34 mutex;
	struct bus_type___28 *bus;
	struct device_driver___28 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___28 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___13 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___28 *class;
	const struct attribute_group___24 **groups;
	void (*release)(struct device___28 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___28 *device_rh;
};

struct dev_pm_info_rh___28 {
	void (*set_latency_tolerance)(struct device___28 *, s32);
};

struct dev_pm_domain___28 {
	struct dev_pm_ops___28 ops;
};

struct smp_ops___33 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___34 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___16 {
	int nr;
	struct pid_namespace___16 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___16 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___34 *child_reaper;
	struct kmem_cache___28 *pid_cachep;
	unsigned int level;
	struct pid_namespace___16 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___34 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___16 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___16 numbers[1];
};

struct zone___33;

struct lruvec___33 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___33 *zone;
};

struct pglist_data___33;

struct zone___33 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___33 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___33 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___33 {
	struct zone___33 *zone;
	int zone_idx;
};

struct zonelist___33 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___33 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___33 {
	struct zone___33 node_zones[4];
	struct zonelist___33 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___34 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___16 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___16 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___33 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___34 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___34 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___16 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___34 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___15;

struct css_set___15 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___15 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___15 {
	struct pmu___15 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___34 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___34 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___15 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___33;

struct super_block___34;

struct dentry___34 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___34 *d_parent;
	struct qstr d_name;
	struct inode___34 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___33 *d_op;
	struct super_block___34 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___33;

struct file_lock___33;

struct dquot___33;

struct block_device___33;

struct cdev___15;

struct inode___34 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___33 *i_op;
	struct super_block___34 *i_sb;
	struct address_space___33 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___34 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___33 *i_fop;
	struct file_lock___33 *i_flock;
	struct address_space___33 i_data;
	struct dquot___33 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___33 *i_bdev;
		struct cdev___15 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___33 {
	int (*d_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_hash)(const struct dentry___34 *, struct qstr *);
	int (*d_compare)(const struct dentry___34 *, const struct dentry___34 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___34 *);
	void (*d_release)(struct dentry___34 *);
	void (*d_prune)(struct dentry___34 *);
	void (*d_iput)(struct dentry___34 *, struct inode___34 *);
	char * (*d_dname)(struct dentry___34 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___33 *);
	int (*d_manage)(struct dentry___34 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___33;

struct mem_dqinfo___33 {
	struct quota_format_type___33 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___33;

struct quota_info___33 {
	unsigned int flags;
	struct mutex___34 dqio_mutex;
	struct mutex___34 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___34 *files[2];
	struct mem_dqinfo___33 info[2];
	const struct quota_format_ops___33 *ops[2];
};

struct file_system_type___33;

struct super_operations___33;

struct dquot_operations___33;

struct quotactl_ops___33;

struct xattr_handler___15;

struct super_block___34 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___33 *s_type;
	const struct super_operations___33 *s_op;
	const struct dquot_operations___33 *dq_op;
	const struct quotactl_ops___33 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___34 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___15 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___33 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___33 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___34 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___33 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___33 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___34 *bd_inode;
	struct super_block___34 *bd_super;
	struct mutex___34 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___33 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___34 bd_fsfreeze_mutex;
};

struct cgroup___15;

struct cgroup_subsys_state___15 {
	struct cgroup___15 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___34 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___33 *ia_file;
};

struct dquot___33 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___34 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___34 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___33 {
	int qf_fmt_id;
	const struct quota_format_ops___33 *qf_ops;
	struct module___20 *qf_owner;
	struct quota_format_type___33 *qf_next;
};

struct quota_format_ops___33 {
	int (*check_quota_file)(struct super_block___34 *, int);
	int (*read_file_info)(struct super_block___34 *, int);
	int (*write_file_info)(struct super_block___34 *, int);
	int (*free_file_info)(struct super_block___34 *, int);
	int (*read_dqblk)(struct dquot___33 *);
	int (*commit_dqblk)(struct dquot___33 *);
	int (*release_dqblk)(struct dquot___33 *);
};

struct dquot_operations___33 {
	int (*write_dquot)(struct dquot___33 *);
	struct dquot___33 * (*alloc_dquot)(struct super_block___34 *, int);
	void (*destroy_dquot)(struct dquot___33 *);
	int (*acquire_dquot)(struct dquot___33 *);
	int (*release_dquot)(struct dquot___33 *);
	int (*mark_dirty)(struct dquot___33 *);
	int (*write_info)(struct super_block___34 *, int);
	qsize_t * (*get_reserved_space)(struct inode___34 *);
};

struct quotactl_ops___33 {
	int (*quota_on)(struct super_block___34 *, int, int, struct path___33 *);
	int (*quota_on_meta)(struct super_block___34 *, int, int);
	int (*quota_off)(struct super_block___34 *, int);
	int (*quota_sync)(struct super_block___34 *, int);
	int (*get_info)(struct super_block___34 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___34 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___34 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___34 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___34 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___34 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___34 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___34 *, unsigned int);
};

struct address_space_operations___33 {
	int (*writepage)(struct page___33 *, struct writeback_control *);
	int (*readpage)(struct file___33 *, struct page___33 *);
	int (*writepages)(struct address_space___33 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___33 *);
	int (*readpages)(struct file___33 *, struct address_space___33 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___33 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___33 **, void **);
	int (*write_end)(struct file___33 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___33 *, void *);
	sector_t (*bmap)(struct address_space___33 *, sector_t);
	void (*invalidatepage)(struct page___33 *, long unsigned int);
	int (*releasepage)(struct page___33 *, gfp_t);
	void (*freepage)(struct page___33 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___33 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___33 *, struct page___33 *, struct page___33 *, enum migrate_mode);
	int (*launder_page)(struct page___33 *);
	int (*is_partially_uptodate)(struct page___33 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___33 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___33 *, struct page___33 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___33 *, sector_t *);
	void (*swap_deactivate)(struct file___33 *);
	void (*invalidatepage_range)(struct page___33 *, unsigned int, unsigned int);
};

struct cdev___15 {
	struct kobject kobj;
	struct module___20 *owner;
	const struct file_operations___33 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___33 {
	struct dentry___34 * (*lookup)(struct inode___34 *, struct dentry___34 *, unsigned int);
	void * (*follow_link)(struct dentry___34 *, struct nameidata *);
	int (*permission)(struct inode___34 *, int);
	struct posix_acl * (*get_acl)(struct inode___34 *, int);
	int (*readlink)(struct dentry___34 *, char *, int);
	void (*put_link)(struct dentry___34 *, struct nameidata *, void *);
	int (*create)(struct inode___34 *, struct dentry___34 *, umode_t, bool);
	int (*link)(struct dentry___34 *, struct inode___34 *, struct dentry___34 *);
	int (*unlink)(struct inode___34 *, struct dentry___34 *);
	int (*symlink)(struct inode___34 *, struct dentry___34 *, const char *);
	int (*mkdir)(struct inode___34 *, struct dentry___34 *, umode_t);
	int (*rmdir)(struct inode___34 *, struct dentry___34 *);
	int (*mknod)(struct inode___34 *, struct dentry___34 *, umode_t, dev_t);
	int (*rename)(struct inode___34 *, struct dentry___34 *, struct inode___34 *, struct dentry___34 *);
	int (*setattr)(struct dentry___34 *, struct iattr___34 *);
	int (*getattr)(struct vfsmount *, struct dentry___34 *, struct kstat *);
	int (*setxattr)(struct dentry___34 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___34 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___34 *, char *, size_t);
	int (*removexattr)(struct dentry___34 *, const char *);
	int (*fiemap)(struct inode___34 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___34 *, struct timespec *, int);
	int (*atomic_open)(struct inode___34 *, struct dentry___34 *, struct file___33 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___19;

struct seq_file___23;

struct file_operations___33 {
	struct module___20 *owner;
	loff_t (*llseek)(struct file___33 *, loff_t, int);
	ssize_t (*read)(struct file___33 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___33 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___33 *, void *, filldir_t);
	unsigned int (*poll)(struct file___33 *, struct poll_table_struct___19 *);
	long int (*unlocked_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___33 *, struct vm_area_struct___36 *);
	int (*open)(struct inode___34 *, struct file___33 *);
	int (*flush)(struct file___33 *, fl_owner_t);
	int (*release)(struct inode___34 *, struct file___33 *);
	int (*fsync)(struct file___33 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___33 *, int);
	int (*lock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*sendpage)(struct file___33 *, struct page___33 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___33 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___33 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___33 *, long int, struct file_lock___33 **, void **);
		struct {
			int (*setlease)(struct file___33 *, long int, struct file_lock___33 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___33 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___23 *, struct file___33 *);
};

struct file_lock_operations___33;

struct lock_manager_operations___33;

struct file_lock___33 {
	struct file_lock___33 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___16 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___33 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___33 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___33 *fl_ops;
	const struct lock_manager_operations___33 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___33 {
	void (*fl_copy_lock)(struct file_lock___33 *, struct file_lock___33 *);
	void (*fl_release_private)(struct file_lock___33 *);
};

struct lock_manager_operations___33 {
	int (*lm_compare_owner)(struct file_lock___33 *, struct file_lock___33 *);
	long unsigned int (*lm_owner_key)(struct file_lock___33 *);
	void (*lm_notify)(struct file_lock___33 *);
	int (*lm_grant)(struct file_lock___33 *, struct file_lock___33 *, int);
	void (*lm_break)(struct file_lock___33 *);
	int (*lm_change)(struct file_lock___33 **, int);
};

struct fasync_struct___33 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___33 *fa_next;
	struct file___33 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___33 {
	const char *name;
	int fs_flags;
	struct dentry___34 * (*mount)(struct file_system_type___33 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___34 *);
	struct module___20 *owner;
	struct file_system_type___33 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___33 {
	struct inode___34 * (*alloc_inode)(struct super_block___34 *);
	void (*destroy_inode)(struct inode___34 *);
	void (*dirty_inode)(struct inode___34 *, int);
	int (*write_inode)(struct inode___34 *, struct writeback_control *);
	int (*drop_inode)(struct inode___34 *);
	void (*evict_inode)(struct inode___34 *);
	void (*put_super)(struct super_block___34 *);
	int (*sync_fs)(struct super_block___34 *, int);
	int (*freeze_fs)(struct super_block___34 *);
	int (*unfreeze_fs)(struct super_block___34 *);
	int (*statfs)(struct dentry___34 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___34 *, int *, char *);
	void (*umount_begin)(struct super_block___34 *);
	int (*show_options)(struct seq_file___23 *, struct dentry___34 *);
	int (*show_devname)(struct seq_file___23 *, struct dentry___34 *);
	int (*show_path)(struct seq_file___23 *, struct dentry___34 *);
	int (*show_stats)(struct seq_file___23 *, struct dentry___34 *);
	ssize_t (*quota_read)(struct super_block___34 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___34 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___34 *);
	int (*bdev_try_to_free_page)(struct super_block___34 *, struct page___33 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___34 *);
	void (*free_cached_objects)(struct super_block___34 *, int);
};

struct xattr_handler___15 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___34 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___34 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___34 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___19)(struct file___33 *, wait_queue_head_t *, struct poll_table_struct___19 *);

struct poll_table_struct___19 {
	poll_queue_proc___19 _qproc;
	long unsigned int _key;
};

struct seq_operations___23;

struct seq_file___23 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___34 lock;
	const struct seq_operations___23 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___26 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___33 *page;
};

struct bin_attribute___24;

struct attribute_group___24 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___24 **bin_attrs;
};

struct bin_attribute___24 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___33 *, struct kobject *, struct bin_attribute___24 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___33 *, struct kobject *, struct bin_attribute___24 *, char *, loff_t, size_t);
	int (*mmap)(struct file___33 *, struct kobject *, struct bin_attribute___24 *, struct vm_area_struct___36 *);
};

struct bus_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___28 *, char *);
	ssize_t (*store)(struct bus_type___28 *, const char *, size_t);
};

struct device_attribute___28;

struct driver_attribute___28;

struct bus_type___28 {
	const char *name;
	const char *dev_name;
	struct device___28 *dev_root;
	struct bus_attribute___28 *bus_attrs;
	struct device_attribute___28 *dev_attrs;
	struct driver_attribute___28 *drv_attrs;
	const struct attribute_group___24 **bus_groups;
	const struct attribute_group___24 **dev_groups;
	const struct attribute_group___24 **drv_groups;
	int (*match)(struct device___28 *, struct device_driver___28 *);
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	int (*probe)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*online)(struct device___28 *);
	int (*offline)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct device___28 *, struct device_attribute___28 *, char *);
	ssize_t (*store)(struct device___28 *, struct device_attribute___28 *, const char *, size_t);
};

struct driver_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___28 *, char *);
	ssize_t (*store)(struct device_driver___28 *, const char *, size_t);
};

struct device_driver___28 {
	const char *name;
	struct bus_type___28 *bus;
	struct module___20 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct attribute_group___24 **groups;
	const struct dev_pm_ops___28 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___28 {
	const char *name;
	const struct attribute_group___24 **groups;
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
};

struct class_attribute___28;

struct class___28 {
	const char *name;
	struct module___20 *owner;
	struct class_attribute___28 *class_attrs;
	struct device_attribute___28 *dev_attrs;
	const struct attribute_group___24 **dev_groups;
	struct bin_attribute___24 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *);
	void (*class_release)(struct class___28 *);
	void (*dev_release)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	struct subsys_private *p;
};

struct class_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct class___28 *, struct class_attribute___28 *, char *);
	ssize_t (*store)(struct class___28 *, struct class_attribute___28 *, const char *, size_t);
	const void * (*namespace)(struct class___28 *, const struct class_attribute___28 *);
};

struct acpi_scan_handler___9;

struct acpi_hotplug_context___9;

struct acpi_driver___9;

struct acpi_device___9 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___9 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___9 *handler;
	struct acpi_hotplug_context___9 *hp;
	struct acpi_driver___9 *driver;
	void *driver_data;
	struct device___28 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___34 physical_node_lock;
	void (*remove)(struct acpi_device___9 *);
};

struct device_rh___28 {
	struct dev_pm_info_rh___28 power;
};

struct kmem_cache_cpu___28 {
	void **freelist;
	long unsigned int tid;
	struct page___33 *page;
	struct page___33 *partial;
};

struct memcg_cache_params___28 {
	bool is_root_cache;
	union {
		struct kmem_cache___28 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___28 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___15;

struct cgroup___15 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___15 *parent;
	struct dentry___34 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___15 *subsys[11];
	struct cgroupfs_root___15 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___34 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___15 {
	struct super_block___34 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___15 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___15;

struct pmu___15 {
	struct list_head entry;
	struct device___28 *dev;
	const struct attribute_group___24 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___15 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___15 *);
	void (*pmu_disable)(struct pmu___15 *);
	int (*event_init)(struct perf_event___15 *);
	int (*add)(struct perf_event___15 *, int);
	void (*del)(struct perf_event___15 *, int);
	void (*start)(struct perf_event___15 *, int);
	void (*stop)(struct perf_event___15 *, int);
	void (*read)(struct perf_event___15 *);
	void (*start_txn)(struct pmu___15 *);
	int (*commit_txn)(struct pmu___15 *);
	void (*cancel_txn)(struct pmu___15 *);
	int (*event_idx)(struct perf_event___15 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___20 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___15 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___15 *);
};

struct perf_cpu_context___15 {
	struct perf_event_context___15 ctx;
	struct perf_event_context___15 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___15 *unique_pmu;
	struct perf_cgroup___15 *cgrp;
};

struct perf_cgroup___15 {
	struct cgroup_subsys_state___15 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___23 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___23 *);
	void (*irq_shutdown)(struct irq_data___23 *);
	void (*irq_enable)(struct irq_data___23 *);
	void (*irq_disable)(struct irq_data___23 *);
	void (*irq_ack)(struct irq_data___23 *);
	void (*irq_mask)(struct irq_data___23 *);
	void (*irq_mask_ack)(struct irq_data___23 *);
	void (*irq_unmask)(struct irq_data___23 *);
	void (*irq_eoi)(struct irq_data___23 *);
	int (*irq_set_affinity)(struct irq_data___23 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___23 *);
	int (*irq_set_type)(struct irq_data___23 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___23 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___23 *);
	void (*irq_bus_sync_unlock)(struct irq_data___23 *);
	void (*irq_cpu_online)(struct irq_data___23 *);
	void (*irq_cpu_offline)(struct irq_data___23 *);
	void (*irq_suspend)(struct irq_data___23 *);
	void (*irq_resume)(struct irq_data___23 *);
	void (*irq_pm_shutdown)(struct irq_data___23 *);
	void (*irq_print_chip)(struct irq_data___23 *, struct seq_file___23 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___23 *, void *);
	long unsigned int flags;
};

struct seq_operations___23 {
	void * (*start)(struct seq_file___23 *, loff_t *);
	void (*stop)(struct seq_file___23 *, void *);
	void * (*next)(struct seq_file___23 *, void *, loff_t *);
	int (*show)(struct seq_file___23 *, void *);
};

struct clock_event_device___2 {
	void (*event_handler)(struct clock_event_device___2 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___2 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___2 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_mode mode;
	unsigned int features;
	long unsigned int retries;
	void (*broadcast)(const struct cpumask *);
	void (*set_mode)(enum clock_event_mode, struct clock_event_device___2 *);
	void (*suspend)(struct clock_event_device___2 *);
	void (*resume)(struct clock_event_device___2 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___20 *owner;
	long: 64;
	long: 64;
};

struct module_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___19 *, struct module_kobject___19 *, char *);
	ssize_t (*store)(struct module_attribute___19 *, struct module_kobject___19 *, const char *, size_t);
	void (*setup)(struct module___20 *, const char *);
	int (*test)(struct module___20 *);
	void (*free)(struct module___20 *);
};

struct acpi_hotplug_profile___9 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___9 *);
	void (*notify_online)(struct acpi_device___9 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___9 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___9 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___9 *);
	void (*bind)(struct device___28 *);
	void (*unbind)(struct device___28 *);
	struct acpi_hotplug_profile___9 hotplug;
};

struct acpi_hotplug_context___9 {
	struct acpi_device___9 *self;
	int (*notify)(struct acpi_device___9 *, u32);
	void (*uevent)(struct acpi_device___9 *, u32);
	void (*fixup)(struct acpi_device___9 *);
};

typedef int (*acpi_op_add___9)(struct acpi_device___9 *);

typedef int (*acpi_op_remove___9)(struct acpi_device___9 *);

typedef void (*acpi_op_notify___9)(struct acpi_device___9 *, u32);

struct acpi_device_ops___9 {
	acpi_op_add___9 add;
	acpi_op_remove___9 remove;
	acpi_op_notify___9 notify;
};

struct acpi_driver___9 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___9 ops;
	struct device_driver___28 drv;
	struct module___20 *owner;
};

enum {
	IRQ_REMAP_XAPIC_MODE = 0,
	IRQ_REMAP_X2APIC_MODE = 1,
};

struct legacy_pic___6 {
	int nr_legacy_irqs;
	struct irq_chip___23 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

enum ioapic_irq_destination_types {
	dest_Fixed = 0,
	dest_LowestPrio = 1,
	dest_SMI = 2,
	dest__reserved_1 = 3,
	dest_NMI = 4,
	dest_INIT = 5,
	dest__reserved_2 = 6,
	dest_ExtINT = 7,
};

struct pci_dev___9;

struct msi_desc___4;

struct x86_msi_ops___2 {
	int (*setup_msi_irqs)(struct pci_dev___9 *, int, int);
	void (*compose_msi_msg)(struct pci_dev___9 *, unsigned int, unsigned int, struct msi_msg *, u8);
	void (*teardown_msi_irq)(unsigned int);
	void (*teardown_msi_irqs)(struct pci_dev___9 *);
	void (*restore_msi_irqs)(struct pci_dev___9 *);
	int (*setup_hpet_msi)(unsigned int, unsigned int);
	u32 (*msi_mask_irq)(struct msi_desc___4 *, u32, u32);
	u32 (*msix_mask_irq)(struct msi_desc___4 *, u32);
};

struct pci_bus___9;

struct pci_slot___9;

struct pci_driver___9;

struct pci_dev___9 {
	struct list_head bus_list;
	struct pci_bus___9 *bus;
	struct pci_bus___9 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___9 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___9 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___27 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___23 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___23 *res_attr[17];
	struct bin_attribute___23 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___23 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___9 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___4 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___9 *dev;
	struct msi_msg msg;
	struct kobject kobj;
};

struct irq_data___24;

struct x86_io_apic_ops___24 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___24 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___24;

struct irq_data___24 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___24 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___4 *msi_desc;
	cpumask_var_t affinity;
};

union IO_APIC_reg_00 {
	u32 raw;
	struct {
		u32 __reserved_2: 14;
		u32 LTS: 1;
		u32 delivery_type: 1;
		u32 __reserved_1: 8;
		u32 ID: 8;
	} bits;
};

union IO_APIC_reg_01 {
	u32 raw;
	struct {
		u32 version: 8;
		u32 __reserved_2: 7;
		u32 PRQ: 1;
		u32 entries: 8;
		u32 __reserved_1: 8;
	} bits;
};

union IO_APIC_reg_02 {
	u32 raw;
	struct {
		u32 __reserved_2: 24;
		u32 arbitration: 4;
		u32 __reserved_1: 4;
	} bits;
};

union IO_APIC_reg_03 {
	u32 raw;
	struct {
		u32 boot_DT: 1;
		u32 __reserved_1: 31;
	} bits;
};

struct IR_IO_APIC_route_entry {
	__u64 vector: 8;
	__u64 zero: 3;
	__u64 index2: 1;
	__u64 delivery_status: 1;
	__u64 polarity: 1;
	__u64 irr: 1;
	__u64 trigger: 1;
	__u64 mask: 1;
	__u64 reserved: 31;
	__u64 format: 1;
	__u64 index: 15;
};

struct mp_ioapic_gsi {
	u32 gsi_base;
	u32 gsi_end;
};

struct irq_desc___6;

typedef void (*irq_flow_handler_t___6)(unsigned int, struct irq_desc___6 *);

struct irqaction___6;

struct irq_desc___6 {
	struct irq_data___24 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___6 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module___19 *owner;
	const char *name;
	long: 64;
	long: 64;
};

enum {
	IRQ_TYPE_NONE = 0,
	IRQ_TYPE_EDGE_RISING = 1,
	IRQ_TYPE_EDGE_FALLING = 2,
	IRQ_TYPE_EDGE_BOTH = 3,
	IRQ_TYPE_LEVEL_HIGH = 4,
	IRQ_TYPE_LEVEL_LOW = 8,
	IRQ_TYPE_LEVEL_MASK = 12,
	IRQ_TYPE_SENSE_MASK = 15,
	IRQ_TYPE_DEFAULT = 15,
	IRQ_TYPE_PROBE = 16,
	IRQ_LEVEL = 256,
	IRQ_PER_CPU = 512,
	IRQ_NOPROBE = 1024,
	IRQ_NOREQUEST = 2048,
	IRQ_NOAUTOEN = 4096,
	IRQ_NO_BALANCING = 8192,
	IRQ_MOVE_PCNTXT = 16384,
	IRQ_NESTED_THREAD = 32768,
	IRQ_NOTHREAD = 65536,
	IRQ_PER_CPU_DEVID = 131072,
};

enum {
	IRQ_SET_MASK_OK = 0,
	IRQ_SET_MASK_OK_NOCOPY = 1,
};

struct irq_chip___24 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___24 *);
	void (*irq_shutdown)(struct irq_data___24 *);
	void (*irq_enable)(struct irq_data___24 *);
	void (*irq_disable)(struct irq_data___24 *);
	void (*irq_ack)(struct irq_data___24 *);
	void (*irq_mask)(struct irq_data___24 *);
	void (*irq_mask_ack)(struct irq_data___24 *);
	void (*irq_unmask)(struct irq_data___24 *);
	void (*irq_eoi)(struct irq_data___24 *);
	int (*irq_set_affinity)(struct irq_data___24 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___24 *);
	int (*irq_set_type)(struct irq_data___24 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___24 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___24 *);
	void (*irq_bus_sync_unlock)(struct irq_data___24 *);
	void (*irq_cpu_online)(struct irq_data___24 *);
	void (*irq_cpu_offline)(struct irq_data___24 *);
	void (*irq_suspend)(struct irq_data___24 *);
	void (*irq_resume)(struct irq_data___24 *);
	void (*irq_pm_shutdown)(struct irq_data___24 *);
	void (*irq_print_chip)(struct irq_data___24 *, struct seq_file___22 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___24 *, void *);
	long unsigned int flags;
};

struct irqaction___6 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___6 *next;
	irq_handler_t thread_fn;
	struct task_struct___33 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irte_tmp {
	u64 low;
	u64 high;
};

enum irq_mode {
	IRQ_REMAPPING = 0,
	IRQ_POSTING = 1,
};

struct intel_iommu;

struct irq_2_iommu {
	struct intel_iommu *iommu;
	u16 irte_index;
	u16 sub_handle;
	u8 irte_mask;
	struct irte_tmp irte;
	enum irq_mode mode;
};

struct irq_2_irte {
	u16 devid;
	u16 index;
};

struct irq_pin_list;

struct irq_cfg {
	struct irq_pin_list *irq_2_pin;
	cpumask_var_t domain;
	cpumask_var_t old_domain;
	u8 vector;
	u8 move_in_progress: 1;
	u8 remapped: 1;
	union {
		struct irq_2_iommu irq_2_iommu;
		struct irq_2_irte irq_2_irte;
	};
};

struct irq_pin_list {
	int apic;
	int pin;
	struct irq_pin_list *next;
};

struct pci_slot___9 {
	struct pci_bus___9 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___9;

struct msi_chip___4;

struct pci_bus___9 {
	struct list_head node;
	struct pci_bus___9 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___9 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___9 *ops;
	struct msi_chip___4 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___27 *bridge;
	struct device___27 dev;
	struct bin_attribute___23 *legacy_io;
	struct bin_attribute___23 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___9;

struct pci_driver_rh___9;

struct pci_driver___9 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___9 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___9 *);
	int (*suspend)(struct pci_dev___9 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___9 *, pm_message_t);
	int (*resume_early)(struct pci_dev___9 *);
	int (*resume)(struct pci_dev___9 *);
	void (*shutdown)(struct pci_dev___9 *);
	int (*sriov_configure)(struct pci_dev___9 *, int);
	const struct pci_error_handlers___9 *err_handler;
	struct device_driver___27 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___9 *pci_driver_rh;
};

struct pci_ops___9 {
	int (*read)(struct pci_bus___9 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___9 *, unsigned int, int, int, u32);
};

struct msi_chip___4 {
	struct module___19 *owner;
	struct device___27 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___4 *, struct pci_dev___9 *, struct msi_desc___4 *);
	void (*teardown_irq)(struct msi_chip___4 *, unsigned int);
	int (*check_device)(struct msi_chip___4 *, struct pci_dev___9 *, int, int);
};

struct pci_error_handlers___9 {
	pci_ers_result_t (*error_detected)(struct pci_dev___9 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___9 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___9 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___9 *);
	void (*resume)(struct pci_dev___9 *);
};

struct pci_driver_rh___9 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___9 *, bool);
};

struct ht_irq_msg {
	u32 address_lo;
	u32 address_hi;
};

struct legacy_pic___7 {
	int nr_legacy_irqs;
	struct irq_chip___24 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

struct mp_pin_info {
	int trigger;
	int polarity;
	int node;
	int set;
	u32 count;
};

struct ioapic {
	int nr_registers;
	struct IO_APIC_route_entry *saved_registers;
	struct mpc_ioapic mp_config;
	struct mp_ioapic_gsi gsi_config;
	struct ioapic_domain_cfg irqdomain_cfg;
	struct irq_domain *irqdomain;
	struct mp_pin_info *pin_info;
};

struct io_apic {
	unsigned int index;
	unsigned int unused[3];
	unsigned int data;
	unsigned int unused2[11];
	unsigned int eoi;
};

union entry_union {
	struct {
		u32 w1;
		u32 w2;
	};
	struct IO_APIC_route_entry entry;
};

struct hpet_dev;

struct page___34;

typedef struct page___34 *pgtable_t___34;

struct address_space___34;

struct kmem_cache___29;

struct page___34 {
	long unsigned int flags;
	struct address_space___34 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___34 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___34 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___29 *slab_cache;
		struct page___34 *first_page;
	};
	long: 64;
};

struct task_struct___35;

struct pv_cpu_ops___34 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___15 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___15 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___35 *);
	void (*end_context_switch)(struct task_struct___35 *);
};

struct mutex___35 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___35 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___32 {
	struct page___34 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___37;

struct signal_struct___34;

struct task_struct___35 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___35 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___37 *mm;
	struct mm_struct___37 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___35 *real_parent;
	struct task_struct___35 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___35 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___16 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___34 = 0,
		VTIME_USER___34 = 1,
		VTIME_SYS___34 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___15 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___34 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___35 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___32 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___37 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___37 *, struct mm_struct___37 *);
	void (*dup_mmap)(struct mm_struct___37 *, struct mm_struct___37 *);
	void (*exit_mmap)(struct mm_struct___37 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___37 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___37 *);
	void (*pgd_free)(struct mm_struct___37 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___37 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___37 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___37 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___37 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___37 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___37 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___37 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___37 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___37 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___37 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___37 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___35 lock;
	void *vdso;
} mm_context_t___35;

struct xol_area___34;

struct uprobes_state___34 {
	struct xol_area___34 *xol_area;
};

struct vm_area_struct___37;

struct file___34;

struct core_state___34;

struct mm_struct___37 {
	struct vm_area_struct___37 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___37 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___37 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___35 context;
	long unsigned int flags;
	struct core_state___34 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___35 *owner;
	struct file___34 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___34 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___21;

struct module_kobject___20 {
	struct kobject kobj;
	struct module___21 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___20;

struct module___21 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___20 mkobj;
	struct module_attribute___20 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___35 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct dma_map_ops___14;

struct dev_archdata___14 {
	struct dma_map_ops___14 *dma_ops;
	void *iommu;
};

struct device_type___29;

struct bus_type___29;

struct device_driver___29;

struct dev_pm_domain___29;

struct class___29;

struct attribute_group___25;

struct device_rh___29;

struct device___29 {
	struct device___29 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___29 *type;
	struct mutex___35 mutex;
	struct bus_type___29 *bus;
	struct device_driver___29 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___29 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___14 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___29 *class;
	const struct attribute_group___25 **groups;
	void (*release)(struct device___29 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___29 *device_rh;
};

struct pci_bus___10;

struct pci_slot___10;

struct pci_driver___10;

struct bin_attribute___25;

struct pci_dev___10 {
	struct list_head bus_list;
	struct pci_bus___10 *bus;
	struct pci_bus___10 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___10 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___10 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___29 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___25 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___25 *res_attr[17];
	struct bin_attribute___25 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___25 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___10 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct irq_data___25;

struct x86_io_apic_ops___25 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___25 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___25;

struct irq_data___25 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___25 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct dev_pm_ops___29 {
	int (*prepare)(struct device___29 *);
	void (*complete)(struct device___29 *);
	int (*suspend)(struct device___29 *);
	int (*resume)(struct device___29 *);
	int (*freeze)(struct device___29 *);
	int (*thaw)(struct device___29 *);
	int (*poweroff)(struct device___29 *);
	int (*restore)(struct device___29 *);
	int (*suspend_late)(struct device___29 *);
	int (*resume_early)(struct device___29 *);
	int (*freeze_late)(struct device___29 *);
	int (*thaw_early)(struct device___29 *);
	int (*poweroff_late)(struct device___29 *);
	int (*restore_early)(struct device___29 *);
	int (*suspend_noirq)(struct device___29 *);
	int (*resume_noirq)(struct device___29 *);
	int (*freeze_noirq)(struct device___29 *);
	int (*thaw_noirq)(struct device___29 *);
	int (*poweroff_noirq)(struct device___29 *);
	int (*restore_noirq)(struct device___29 *);
	int (*runtime_suspend)(struct device___29 *);
	int (*runtime_resume)(struct device___29 *);
	int (*runtime_idle)(struct device___29 *);
};

struct dev_pm_info_rh___29 {
	void (*set_latency_tolerance)(struct device___29 *, s32);
};

struct dev_pm_domain___29 {
	struct dev_pm_ops___29 ops;
};

struct smp_ops___34 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___35 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___34;

struct lruvec___34 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___34 *zone;
};

struct pglist_data___34;

struct zone___34 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___34 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___34 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___34 {
	struct zone___34 *zone;
	int zone_idx;
};

struct zonelist___34 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___34 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___34 {
	struct zone___34 node_zones[4];
	struct zonelist___34 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___35 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___24;

struct irq_chip___25 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___25 *);
	void (*irq_shutdown)(struct irq_data___25 *);
	void (*irq_enable)(struct irq_data___25 *);
	void (*irq_disable)(struct irq_data___25 *);
	void (*irq_ack)(struct irq_data___25 *);
	void (*irq_mask)(struct irq_data___25 *);
	void (*irq_mask_ack)(struct irq_data___25 *);
	void (*irq_unmask)(struct irq_data___25 *);
	void (*irq_eoi)(struct irq_data___25 *);
	int (*irq_set_affinity)(struct irq_data___25 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___25 *);
	int (*irq_set_type)(struct irq_data___25 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___25 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___25 *);
	void (*irq_bus_sync_unlock)(struct irq_data___25 *);
	void (*irq_cpu_online)(struct irq_data___25 *);
	void (*irq_cpu_offline)(struct irq_data___25 *);
	void (*irq_suspend)(struct irq_data___25 *);
	void (*irq_resume)(struct irq_data___25 *);
	void (*irq_pm_shutdown)(struct irq_data___25 *);
	void (*irq_print_chip)(struct irq_data___25 *, struct seq_file___24 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___25 *, void *);
	long unsigned int flags;
};

struct seq_operations___24;

struct seq_file___24 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___35 lock;
	const struct seq_operations___24 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct inode___35;

struct dentry_operations___34;

struct super_block___35;

struct dentry___35 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___35 *d_parent;
	struct qstr d_name;
	struct inode___35 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___34 *d_op;
	struct super_block___35 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___34;

struct address_space___34 {
	struct inode___35 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___35 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___34 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___34;

struct file_operations___34;

struct file_lock___34;

struct dquot___34;

struct block_device___34;

struct cdev___16;

struct inode___35 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___34 *i_op;
	struct super_block___35 *i_sb;
	struct address_space___34 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___35 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___34 *i_fop;
	struct file_lock___34 *i_flock;
	struct address_space___34 i_data;
	struct dquot___34 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___34 *i_bdev;
		struct cdev___16 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___34;

struct dentry_operations___34 {
	int (*d_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_hash)(const struct dentry___35 *, struct qstr *);
	int (*d_compare)(const struct dentry___35 *, const struct dentry___35 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___35 *);
	void (*d_release)(struct dentry___35 *);
	void (*d_prune)(struct dentry___35 *);
	void (*d_iput)(struct dentry___35 *, struct inode___35 *);
	char * (*d_dname)(struct dentry___35 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___34 *);
	int (*d_manage)(struct dentry___35 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___34;

struct mem_dqinfo___34 {
	struct quota_format_type___34 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___34;

struct quota_info___34 {
	unsigned int flags;
	struct mutex___35 dqio_mutex;
	struct mutex___35 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___35 *files[2];
	struct mem_dqinfo___34 info[2];
	const struct quota_format_ops___34 *ops[2];
};

struct file_system_type___34;

struct super_operations___34;

struct dquot_operations___34;

struct quotactl_ops___34;

struct super_block___35 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___34 *s_type;
	const struct super_operations___34 *s_op;
	const struct dquot_operations___34 *dq_op;
	const struct quotactl_ops___34 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___35 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___34 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___34 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___35 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___34 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___34 {
	struct vfsmount *mnt;
	struct dentry___35 *dentry;
};

struct block_device___34 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___35 *bd_inode;
	struct super_block___35 *bd_super;
	struct mutex___35 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___34 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___35 bd_fsfreeze_mutex;
};

struct iattr___35 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___34 *ia_file;
};

struct file___34 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___34 f_path;
	struct inode___35 *f_inode;
	const struct file_operations___34 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___34 *f_mapping;
	struct mutex___35 f_pos_lock;
};

struct dquot___34 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___35 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___35 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___34 {
	int qf_fmt_id;
	const struct quota_format_ops___34 *qf_ops;
	struct module___21 *qf_owner;
	struct quota_format_type___34 *qf_next;
};

struct quota_format_ops___34 {
	int (*check_quota_file)(struct super_block___35 *, int);
	int (*read_file_info)(struct super_block___35 *, int);
	int (*write_file_info)(struct super_block___35 *, int);
	int (*free_file_info)(struct super_block___35 *, int);
	int (*read_dqblk)(struct dquot___34 *);
	int (*commit_dqblk)(struct dquot___34 *);
	int (*release_dqblk)(struct dquot___34 *);
};

struct dquot_operations___34 {
	int (*write_dquot)(struct dquot___34 *);
	struct dquot___34 * (*alloc_dquot)(struct super_block___35 *, int);
	void (*destroy_dquot)(struct dquot___34 *);
	int (*acquire_dquot)(struct dquot___34 *);
	int (*release_dquot)(struct dquot___34 *);
	int (*mark_dirty)(struct dquot___34 *);
	int (*write_info)(struct super_block___35 *, int);
	qsize_t * (*get_reserved_space)(struct inode___35 *);
};

struct quotactl_ops___34 {
	int (*quota_on)(struct super_block___35 *, int, int, struct path___34 *);
	int (*quota_on_meta)(struct super_block___35 *, int, int);
	int (*quota_off)(struct super_block___35 *, int);
	int (*quota_sync)(struct super_block___35 *, int);
	int (*get_info)(struct super_block___35 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___35 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___35 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___35 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___35 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___35 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___35 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___35 *, unsigned int);
};

struct address_space_operations___34 {
	int (*writepage)(struct page___34 *, struct writeback_control *);
	int (*readpage)(struct file___34 *, struct page___34 *);
	int (*writepages)(struct address_space___34 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___34 *);
	int (*readpages)(struct file___34 *, struct address_space___34 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___34 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___34 **, void **);
	int (*write_end)(struct file___34 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___34 *, void *);
	sector_t (*bmap)(struct address_space___34 *, sector_t);
	void (*invalidatepage)(struct page___34 *, long unsigned int);
	int (*releasepage)(struct page___34 *, gfp_t);
	void (*freepage)(struct page___34 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___34 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___34 *, struct page___34 *, struct page___34 *, enum migrate_mode);
	int (*launder_page)(struct page___34 *);
	int (*is_partially_uptodate)(struct page___34 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___34 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___34 *, struct page___34 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___34 *, sector_t *);
	void (*swap_deactivate)(struct file___34 *);
	void (*invalidatepage_range)(struct page___34 *, unsigned int, unsigned int);
};

struct cdev___16 {
	struct kobject kobj;
	struct module___21 *owner;
	const struct file_operations___34 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___34 {
	struct dentry___35 * (*lookup)(struct inode___35 *, struct dentry___35 *, unsigned int);
	void * (*follow_link)(struct dentry___35 *, struct nameidata *);
	int (*permission)(struct inode___35 *, int);
	struct posix_acl * (*get_acl)(struct inode___35 *, int);
	int (*readlink)(struct dentry___35 *, char *, int);
	void (*put_link)(struct dentry___35 *, struct nameidata *, void *);
	int (*create)(struct inode___35 *, struct dentry___35 *, umode_t, bool);
	int (*link)(struct dentry___35 *, struct inode___35 *, struct dentry___35 *);
	int (*unlink)(struct inode___35 *, struct dentry___35 *);
	int (*symlink)(struct inode___35 *, struct dentry___35 *, const char *);
	int (*mkdir)(struct inode___35 *, struct dentry___35 *, umode_t);
	int (*rmdir)(struct inode___35 *, struct dentry___35 *);
	int (*mknod)(struct inode___35 *, struct dentry___35 *, umode_t, dev_t);
	int (*rename)(struct inode___35 *, struct dentry___35 *, struct inode___35 *, struct dentry___35 *);
	int (*setattr)(struct dentry___35 *, struct iattr___35 *);
	int (*getattr)(struct vfsmount *, struct dentry___35 *, struct kstat *);
	int (*setxattr)(struct dentry___35 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___35 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___35 *, char *, size_t);
	int (*removexattr)(struct dentry___35 *, const char *);
	int (*fiemap)(struct inode___35 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___35 *, struct timespec *, int);
	int (*atomic_open)(struct inode___35 *, struct dentry___35 *, struct file___34 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___20;

struct file_operations___34 {
	struct module___21 *owner;
	loff_t (*llseek)(struct file___34 *, loff_t, int);
	ssize_t (*read)(struct file___34 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___34 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___34 *, void *, filldir_t);
	unsigned int (*poll)(struct file___34 *, struct poll_table_struct___20 *);
	long int (*unlocked_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___34 *, struct vm_area_struct___37 *);
	int (*open)(struct inode___35 *, struct file___34 *);
	int (*flush)(struct file___34 *, fl_owner_t);
	int (*release)(struct inode___35 *, struct file___34 *);
	int (*fsync)(struct file___34 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___34 *, int);
	int (*lock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*sendpage)(struct file___34 *, struct page___34 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___34 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___34 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___34 *, long int, struct file_lock___34 **, void **);
		struct {
			int (*setlease)(struct file___34 *, long int, struct file_lock___34 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___34 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___24 *, struct file___34 *);
};

struct fasync_struct___34;

struct file_lock_operations___34;

struct lock_manager_operations___34;

struct file_lock___34 {
	struct file_lock___34 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___16 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___34 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___34 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___34 *fl_ops;
	const struct lock_manager_operations___34 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___34 {
	void (*fl_copy_lock)(struct file_lock___34 *, struct file_lock___34 *);
	void (*fl_release_private)(struct file_lock___34 *);
};

struct lock_manager_operations___34 {
	int (*lm_compare_owner)(struct file_lock___34 *, struct file_lock___34 *);
	long unsigned int (*lm_owner_key)(struct file_lock___34 *);
	void (*lm_notify)(struct file_lock___34 *);
	int (*lm_grant)(struct file_lock___34 *, struct file_lock___34 *, int);
	void (*lm_break)(struct file_lock___34 *);
	int (*lm_change)(struct file_lock___34 **, int);
};

struct fasync_struct___34 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___34 *fa_next;
	struct file___34 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___34 {
	const char *name;
	int fs_flags;
	struct dentry___35 * (*mount)(struct file_system_type___34 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___35 *);
	struct module___21 *owner;
	struct file_system_type___34 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___34 {
	struct inode___35 * (*alloc_inode)(struct super_block___35 *);
	void (*destroy_inode)(struct inode___35 *);
	void (*dirty_inode)(struct inode___35 *, int);
	int (*write_inode)(struct inode___35 *, struct writeback_control *);
	int (*drop_inode)(struct inode___35 *);
	void (*evict_inode)(struct inode___35 *);
	void (*put_super)(struct super_block___35 *);
	int (*sync_fs)(struct super_block___35 *, int);
	int (*freeze_fs)(struct super_block___35 *);
	int (*unfreeze_fs)(struct super_block___35 *);
	int (*statfs)(struct dentry___35 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___35 *, int *, char *);
	void (*umount_begin)(struct super_block___35 *);
	int (*show_options)(struct seq_file___24 *, struct dentry___35 *);
	int (*show_devname)(struct seq_file___24 *, struct dentry___35 *);
	int (*show_path)(struct seq_file___24 *, struct dentry___35 *);
	int (*show_stats)(struct seq_file___24 *, struct dentry___35 *);
	ssize_t (*quota_read)(struct super_block___35 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___35 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___35 *);
	int (*bdev_try_to_free_page)(struct super_block___35 *, struct page___34 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___35 *);
	void (*free_cached_objects)(struct super_block___35 *, int);
};

typedef void (*poll_queue_proc___20)(struct file___34 *, wait_queue_head_t *, struct poll_table_struct___20 *);

struct poll_table_struct___20 {
	poll_queue_proc___20 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___29;

struct vm_area_struct___37 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___37 *vm_next;
	struct vm_area_struct___37 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___37 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___29 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___34 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct attribute_group___25 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___25 **bin_attrs;
};

struct bin_attribute___25 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___34 *, struct kobject *, struct bin_attribute___25 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___34 *, struct kobject *, struct bin_attribute___25 *, char *, loff_t, size_t);
	int (*mmap)(struct file___34 *, struct kobject *, struct bin_attribute___25 *, struct vm_area_struct___37 *);
};

struct module_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___20 *, struct module_kobject___20 *, char *);
	ssize_t (*store)(struct module_attribute___20 *, struct module_kobject___20 *, const char *, size_t);
	void (*setup)(struct module___21 *, const char *);
	int (*test)(struct module___21 *);
	void (*free)(struct module___21 *);
};

struct xol_area___34 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___34 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___29;

struct memcg_cache_params___29;

struct kmem_cache___29 {
	struct kmem_cache_cpu___29 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___29 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___27;

struct vm_operations_struct___29 {
	void (*open)(struct vm_area_struct___37 *);
	void (*close)(struct vm_area_struct___37 *);
	int (*fault)(struct vm_area_struct___37 *, struct vm_fault___27 *);
	int (*page_mkwrite)(struct vm_area_struct___37 *, struct vm_fault___27 *);
	int (*access)(struct vm_area_struct___37 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___37 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___37 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___37 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___37 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___34 {
	struct task_struct___35 *task;
	struct core_thread___34 *next;
};

struct core_state___34 {
	atomic_t nr_threads;
	struct core_thread___34 dumper;
	struct completion startup;
};

struct signal_struct___34 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___35 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___35 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___16 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___35 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___29 {
	void **freelist;
	long unsigned int tid;
	struct page___34 *page;
	struct page___34 *partial;
};

struct memcg_cache_params___29 {
	bool is_root_cache;
	union {
		struct kmem_cache___29 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___29 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___14 {
	void * (*alloc)(struct device___29 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___29 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___29 *, struct vm_area_struct___37 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___29 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___29 *, struct page___34 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___29 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___29 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___29 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___29 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___29 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___29 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___29 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___29 *, dma_addr_t);
	int (*dma_supported)(struct device___29 *, u64);
	int (*set_dma_mask)(struct device___29 *, u64);
	int is_phys;
};

struct bus_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___29 *, char *);
	ssize_t (*store)(struct bus_type___29 *, const char *, size_t);
};

struct device_attribute___29;

struct driver_attribute___29;

struct bus_type___29 {
	const char *name;
	const char *dev_name;
	struct device___29 *dev_root;
	struct bus_attribute___29 *bus_attrs;
	struct device_attribute___29 *dev_attrs;
	struct driver_attribute___29 *drv_attrs;
	const struct attribute_group___25 **bus_groups;
	const struct attribute_group___25 **dev_groups;
	const struct attribute_group___25 **drv_groups;
	int (*match)(struct device___29 *, struct device_driver___29 *);
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	int (*probe)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*online)(struct device___29 *);
	int (*offline)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct device___29 *, struct device_attribute___29 *, char *);
	ssize_t (*store)(struct device___29 *, struct device_attribute___29 *, const char *, size_t);
};

struct driver_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___29 *, char *);
	ssize_t (*store)(struct device_driver___29 *, const char *, size_t);
};

struct device_driver___29 {
	const char *name;
	struct bus_type___29 *bus;
	struct module___21 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct attribute_group___25 **groups;
	const struct dev_pm_ops___29 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___29 {
	const char *name;
	const struct attribute_group___25 **groups;
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
};

struct class_attribute___29;

struct class___29 {
	const char *name;
	struct module___21 *owner;
	struct class_attribute___29 *class_attrs;
	struct device_attribute___29 *dev_attrs;
	const struct attribute_group___25 **dev_groups;
	struct bin_attribute___25 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *);
	void (*class_release)(struct class___29 *);
	void (*dev_release)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	struct subsys_private *p;
};

struct class_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct class___29 *, struct class_attribute___29 *, char *);
	ssize_t (*store)(struct class___29 *, struct class_attribute___29 *, const char *, size_t);
	const void * (*namespace)(struct class___29 *, const struct class_attribute___29 *);
};

struct device_rh___29 {
	struct dev_pm_info_rh___29 power;
};

struct pci_slot___10 {
	struct pci_bus___10 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___10;

struct pci_bus___10 {
	struct list_head node;
	struct pci_bus___10 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___10 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___10 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___29 *bridge;
	struct device___29 dev;
	struct bin_attribute___25 *legacy_io;
	struct bin_attribute___25 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___10;

struct pci_driver_rh___10;

struct pci_driver___10 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___10 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___10 *);
	int (*suspend)(struct pci_dev___10 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___10 *, pm_message_t);
	int (*resume_early)(struct pci_dev___10 *);
	int (*resume)(struct pci_dev___10 *);
	void (*shutdown)(struct pci_dev___10 *);
	int (*sriov_configure)(struct pci_dev___10 *, int);
	const struct pci_error_handlers___10 *err_handler;
	struct device_driver___29 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___10 *pci_driver_rh;
};

struct pci_ops___10 {
	int (*read)(struct pci_bus___10 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___10 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___10 {
	pci_ers_result_t (*error_detected)(struct pci_dev___10 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___10 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___10 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___10 *);
	void (*resume)(struct pci_dev___10 *);
};

struct pci_driver_rh___10 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___10 *, bool);
};

typedef int (*arch_set_vga_state_t)(struct pci_dev___10 *, bool, unsigned int, u32);

struct vm_fault___27 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___34 *page;
};

struct uvh_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47_63: 17;
};

struct uv1h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47: 1;
	long unsigned int nodes_per_bit: 7;
	long unsigned int rsvd_55: 1;
	long unsigned int ni_port: 4;
	long unsigned int rsvd_60_63: 4;
};

struct uvxh_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47_49: 3;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

struct uv2h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47_49: 3;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

struct uv3h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47: 1;
	long unsigned int router_select: 1;
	long unsigned int rsvd_49: 1;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

union uvh_node_id_u {
	long unsigned int v;
	struct uvh_node_id_s s;
	struct uv1h_node_id_s s1;
	struct uvxh_node_id_s sx;
	struct uv2h_node_id_s s2;
	struct uv3h_node_id_s s3;
};

struct uvh_rh_gam_alias210_overlay_config_2_mmr_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

union uvh_rh_gam_alias210_overlay_config_2_mmr_u {
	long unsigned int v;
	struct uvh_rh_gam_alias210_overlay_config_2_mmr_s s;
};

struct uvh_rh_gam_alias210_redirect_config_2_mmr_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

union uvh_rh_gam_alias210_redirect_config_2_mmr_u {
	long unsigned int v;
	struct uvh_rh_gam_alias210_redirect_config_2_mmr_s s;
};

struct uvh_rh_gam_config_mmr_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv1h_rh_gam_config_mmr_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_11: 2;
	long unsigned int mmiol_cfg: 1;
	long unsigned int rsvd_13_63: 51;
};

struct uvxh_rh_gam_config_mmr_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv2h_rh_gam_config_mmr_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv3h_rh_gam_config_mmr_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

union uvh_rh_gam_config_mmr_u {
	long unsigned int v;
	struct uvh_rh_gam_config_mmr_s s;
	struct uv1h_rh_gam_config_mmr_s s1;
	struct uvxh_rh_gam_config_mmr_s sx;
	struct uv2h_rh_gam_config_mmr_s s2;
	struct uv3h_rh_gam_config_mmr_s s3;
};

struct uvh_rh_gam_gru_overlay_config_mmr_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv1h_rh_gam_gru_overlay_config_mmr_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_47: 2;
	long unsigned int gr4: 1;
	long unsigned int rsvd_49_51: 3;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_gru_overlay_config_mmr_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_gru_overlay_config_mmr_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_gru_overlay_config_mmr_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_61: 6;
	long unsigned int mode: 1;
	long unsigned int enable: 1;
};

union uvh_rh_gam_gru_overlay_config_mmr_u {
	long unsigned int v;
	struct uvh_rh_gam_gru_overlay_config_mmr_s s;
	struct uv1h_rh_gam_gru_overlay_config_mmr_s s1;
	struct uvxh_rh_gam_gru_overlay_config_mmr_s sx;
	struct uv2h_rh_gam_gru_overlay_config_mmr_s s2;
	struct uv3h_rh_gam_gru_overlay_config_mmr_s s3;
};

struct uv1h_rh_gam_mmioh_overlay_config_mmr_s {
	long unsigned int rsvd_0_29: 30;
	long unsigned int base: 16;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_mmioh_overlay_config_mmr_s {
	long unsigned int rsvd_0_26: 27;
	long unsigned int base: 19;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmioh_overlay_config_mmr_u {
	long unsigned int v;
	struct uv1h_rh_gam_mmioh_overlay_config_mmr_s s1;
	struct uv2h_rh_gam_mmioh_overlay_config_mmr_s s2;
};

struct uvh_rh_gam_mmr_overlay_config_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv1h_rh_gam_mmr_overlay_config_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int dual_hub: 1;
	long unsigned int rsvd_47_62: 16;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_mmr_overlay_config_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_mmr_overlay_config_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_mmr_overlay_config_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmr_overlay_config_mmr_u {
	long unsigned int v;
	struct uvh_rh_gam_mmr_overlay_config_mmr_s s;
	struct uv1h_rh_gam_mmr_overlay_config_mmr_s s1;
	struct uvxh_rh_gam_mmr_overlay_config_mmr_s sx;
	struct uv2h_rh_gam_mmr_overlay_config_mmr_s s2;
	struct uv3h_rh_gam_mmr_overlay_config_mmr_s s3;
};

struct uv1h_lb_target_physical_apic_id_mask_s {
	long unsigned int bit_enables: 32;
	long unsigned int rsvd_32_63: 32;
};

union uv1h_lb_target_physical_apic_id_mask_u {
	long unsigned int v;
	struct uv1h_lb_target_physical_apic_id_mask_s s1;
};

struct uv3h_gr0_gam_gr_config_s {
	long unsigned int m_skt: 6;
	long unsigned int undef_6_9: 4;
	long unsigned int subspace: 1;
	long unsigned int reserved: 53;
};

union uv3h_gr0_gam_gr_config_u {
	long unsigned int v;
	struct uv3h_gr0_gam_gr_config_s s3;
};

struct uv3h_rh_gam_mmioh_overlay_config0_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uv3h_rh_gam_mmioh_overlay_config0_mmr_u {
	long unsigned int v;
	struct uv3h_rh_gam_mmioh_overlay_config0_mmr_s s3;
};

struct uv3h_rh_gam_mmioh_redirect_config0_mmr_s {
	long unsigned int nasid: 15;
	long unsigned int rsvd_15_63: 49;
};

union uv3h_rh_gam_mmioh_redirect_config0_mmr_u {
	long unsigned int v;
	struct uv3h_rh_gam_mmioh_redirect_config0_mmr_s s3;
};

struct uv_scir_s {
	struct timer_list timer;
	long unsigned int offset;
	long unsigned int last;
	long unsigned int idle_on;
	long unsigned int idle_off;
	unsigned char state;
	unsigned char enabled;
};

struct uv_hub_info_s {
	long unsigned int global_mmr_base;
	long unsigned int gpa_mask;
	unsigned int gnode_extra;
	unsigned char hub_revision;
	unsigned char apic_pnode_shift;
	unsigned char m_shift;
	unsigned char n_lshift;
	long unsigned int gnode_upper;
	long unsigned int lowmem_remap_top;
	long unsigned int lowmem_remap_base;
	short unsigned int pnode;
	short unsigned int pnode_mask;
	short unsigned int coherency_domain_number;
	short unsigned int numa_blade_id;
	unsigned char blade_processor_id;
	unsigned char m_val;
	unsigned char n_val;
	struct uv_scir_s scir;
};

struct uvh_apicid_s {
	long unsigned int local_apic_mask: 24;
	long unsigned int local_apic_shift: 5;
	long unsigned int unused1: 3;
	long unsigned int pnode_mask: 24;
	long unsigned int pnode_shift: 5;
	long unsigned int unused2: 3;
};

union uvh_apicid {
	long unsigned int v;
	struct uvh_apicid_s s;
};

struct uv_blade_info {
	short unsigned int nr_possible_cpus;
	short unsigned int nr_online_cpus;
	short unsigned int pnode;
	short int memory_nid;
	spinlock_t nmi_lock;
	long unsigned int nmi_count;
};

struct seq_operations___24 {
	void * (*start)(struct seq_file___24 *, loff_t *);
	void (*stop)(struct seq_file___24 *, void *);
	void * (*next)(struct seq_file___24 *, void *, loff_t *);
	int (*show)(struct seq_file___24 *, void *);
};

enum {
	BIOS_STATUS_MORE_PASSES = 1,
	BIOS_STATUS_SUCCESS = 0,
	BIOS_STATUS_UNIMPLEMENTED = 4294967258,
	BIOS_STATUS_EINVAL = 4294967274,
	BIOS_STATUS_UNAVAIL = 4294967280,
};

enum {
	BIOS_FREQ_BASE_PLATFORM = 0,
	BIOS_FREQ_BASE_INTERVAL_TIMER = 1,
	BIOS_FREQ_BASE_REALTIME_CLOCK = 2,
};

struct redir_addr {
	long unsigned int redirect;
	long unsigned int alias;
};

enum map_type {
	map_wb = 0,
	map_uc = 1,
};

struct mmioh_config {
	long unsigned int overlay;
	long unsigned int redirect;
	char *id;
};

typedef int pto_T_____4;

struct page___35;

typedef struct page___35 *pgtable_t___35;

struct address_space___35;

struct kmem_cache___30;

struct page___35 {
	long unsigned int flags;
	struct address_space___35 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___35 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___35 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___30 *slab_cache;
		struct page___35 *first_page;
	};
	long: 64;
};

struct task_struct___36;

struct pv_cpu_ops___35 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___15 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___15 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___36 *);
	void (*end_context_switch)(struct task_struct___36 *);
};

struct mutex___36 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___36 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___33 {
	struct page___35 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___38;

struct signal_struct___35;

struct task_struct___36 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___36 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___38 *mm;
	struct mm_struct___38 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___36 *real_parent;
	struct task_struct___36 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___36 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___16 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___35 = 0,
		VTIME_USER___35 = 1,
		VTIME_SYS___35 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___15 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___35 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___36 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___33 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___38 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___38 *, struct mm_struct___38 *);
	void (*dup_mmap)(struct mm_struct___38 *, struct mm_struct___38 *);
	void (*exit_mmap)(struct mm_struct___38 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___38 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___38 *);
	void (*pgd_free)(struct mm_struct___38 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___38 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___38 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___38 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___38 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___38 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___38 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___38 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___38 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___38 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___38 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___38 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___36 lock;
	void *vdso;
} mm_context_t___36;

struct xol_area___35;

struct uprobes_state___35 {
	struct xol_area___35 *xol_area;
};

struct vm_area_struct___38;

struct file___35;

struct core_state___35;

struct mm_struct___38 {
	struct vm_area_struct___38 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___38 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___38 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___36 context;
	long unsigned int flags;
	struct core_state___35 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___36 *owner;
	struct file___35 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___35 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___22;

struct module_kobject___21 {
	struct kobject kobj;
	struct module___22 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___21;

struct module___22 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___21 mkobj;
	struct module_attribute___21 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___36 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct smp_ops___35 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___36 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___35;

struct lruvec___35 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___35 *zone;
};

struct pglist_data___35;

struct zone___35 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___35 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___35 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___35 {
	struct zone___35 *zone;
	int zone_idx;
};

struct zonelist___35 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___35 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___35 {
	struct zone___35 node_zones[4];
	struct zonelist___35 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___36 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___36;

struct path___35 {
	struct vfsmount *mnt;
	struct dentry___36 *dentry;
};

struct inode___36;

struct file_operations___35;

struct file___35 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___35 f_path;
	struct inode___36 *f_inode;
	const struct file_operations___35 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___35 *f_mapping;
	struct mutex___36 f_pos_lock;
};

struct vm_area_struct___38 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___38 *vm_next;
	struct vm_area_struct___38 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___38 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___35 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___21 *, struct module_kobject___21 *, char *);
	ssize_t (*store)(struct module_attribute___21 *, struct module_kobject___21 *, const char *, size_t);
	void (*setup)(struct module___22 *, const char *);
	int (*test)(struct module___22 *);
	void (*free)(struct module___22 *);
};

struct xol_area___35 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___35 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___30;

struct memcg_cache_params___30;

struct kmem_cache___30 {
	struct kmem_cache_cpu___30 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___30 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___35;

struct address_space___35 {
	struct inode___36 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___36 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___35 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct core_thread___35 {
	struct task_struct___36 *task;
	struct core_thread___35 *next;
};

struct core_state___35 {
	atomic_t nr_threads;
	struct core_thread___35 dumper;
	struct completion startup;
};

struct signal_struct___35 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___36 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___36 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___16 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___36 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___30 {
	void **freelist;
	long unsigned int tid;
	struct page___35 *page;
	struct page___35 *partial;
};

struct memcg_cache_params___30 {
	bool is_root_cache;
	union {
		struct kmem_cache___30 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___30 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___35;

struct super_block___36;

struct dentry___36 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___36 *d_parent;
	struct qstr d_name;
	struct inode___36 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___35 *d_op;
	struct super_block___36 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___35;

struct file_lock___35;

struct dquot___35;

struct block_device___35;

struct inode___36 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___35 *i_op;
	struct super_block___36 *i_sb;
	struct address_space___35 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___36 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___35 *i_fop;
	struct file_lock___35 *i_flock;
	struct address_space___35 i_data;
	struct dquot___35 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___35 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___35 {
	int (*d_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_hash)(const struct dentry___36 *, struct qstr *);
	int (*d_compare)(const struct dentry___36 *, const struct dentry___36 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___36 *);
	void (*d_release)(struct dentry___36 *);
	void (*d_prune)(struct dentry___36 *);
	void (*d_iput)(struct dentry___36 *, struct inode___36 *);
	char * (*d_dname)(struct dentry___36 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___35 *);
	int (*d_manage)(struct dentry___36 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___35;

struct mem_dqinfo___35 {
	struct quota_format_type___35 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___35;

struct quota_info___35 {
	unsigned int flags;
	struct mutex___36 dqio_mutex;
	struct mutex___36 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___36 *files[2];
	struct mem_dqinfo___35 info[2];
	const struct quota_format_ops___35 *ops[2];
};

struct file_system_type___35;

struct super_operations___35;

struct dquot_operations___35;

struct quotactl_ops___35;

struct super_block___36 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___35 *s_type;
	const struct super_operations___35 *s_op;
	const struct dquot_operations___35 *dq_op;
	const struct quotactl_ops___35 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___36 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___35 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___35 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___36 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___35 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___35 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___36 *bd_inode;
	struct super_block___36 *bd_super;
	struct mutex___36 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___35 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___36 bd_fsfreeze_mutex;
};

struct iattr___36 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___35 *ia_file;
};

struct dquot___35 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___36 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___36 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___35 {
	int qf_fmt_id;
	const struct quota_format_ops___35 *qf_ops;
	struct module___22 *qf_owner;
	struct quota_format_type___35 *qf_next;
};

struct quota_format_ops___35 {
	int (*check_quota_file)(struct super_block___36 *, int);
	int (*read_file_info)(struct super_block___36 *, int);
	int (*write_file_info)(struct super_block___36 *, int);
	int (*free_file_info)(struct super_block___36 *, int);
	int (*read_dqblk)(struct dquot___35 *);
	int (*commit_dqblk)(struct dquot___35 *);
	int (*release_dqblk)(struct dquot___35 *);
};

struct dquot_operations___35 {
	int (*write_dquot)(struct dquot___35 *);
	struct dquot___35 * (*alloc_dquot)(struct super_block___36 *, int);
	void (*destroy_dquot)(struct dquot___35 *);
	int (*acquire_dquot)(struct dquot___35 *);
	int (*release_dquot)(struct dquot___35 *);
	int (*mark_dirty)(struct dquot___35 *);
	int (*write_info)(struct super_block___36 *, int);
	qsize_t * (*get_reserved_space)(struct inode___36 *);
};

struct quotactl_ops___35 {
	int (*quota_on)(struct super_block___36 *, int, int, struct path___35 *);
	int (*quota_on_meta)(struct super_block___36 *, int, int);
	int (*quota_off)(struct super_block___36 *, int);
	int (*quota_sync)(struct super_block___36 *, int);
	int (*get_info)(struct super_block___36 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___36 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___36 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___36 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___36 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___36 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___36 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___36 *, unsigned int);
};

struct address_space_operations___35 {
	int (*writepage)(struct page___35 *, struct writeback_control *);
	int (*readpage)(struct file___35 *, struct page___35 *);
	int (*writepages)(struct address_space___35 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___35 *);
	int (*readpages)(struct file___35 *, struct address_space___35 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___35 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___35 **, void **);
	int (*write_end)(struct file___35 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___35 *, void *);
	sector_t (*bmap)(struct address_space___35 *, sector_t);
	void (*invalidatepage)(struct page___35 *, long unsigned int);
	int (*releasepage)(struct page___35 *, gfp_t);
	void (*freepage)(struct page___35 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___35 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___35 *, struct page___35 *, struct page___35 *, enum migrate_mode);
	int (*launder_page)(struct page___35 *);
	int (*is_partially_uptodate)(struct page___35 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___35 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___35 *, struct page___35 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___35 *, sector_t *);
	void (*swap_deactivate)(struct file___35 *);
	void (*invalidatepage_range)(struct page___35 *, unsigned int, unsigned int);
};

struct inode_operations___35 {
	struct dentry___36 * (*lookup)(struct inode___36 *, struct dentry___36 *, unsigned int);
	void * (*follow_link)(struct dentry___36 *, struct nameidata *);
	int (*permission)(struct inode___36 *, int);
	struct posix_acl * (*get_acl)(struct inode___36 *, int);
	int (*readlink)(struct dentry___36 *, char *, int);
	void (*put_link)(struct dentry___36 *, struct nameidata *, void *);
	int (*create)(struct inode___36 *, struct dentry___36 *, umode_t, bool);
	int (*link)(struct dentry___36 *, struct inode___36 *, struct dentry___36 *);
	int (*unlink)(struct inode___36 *, struct dentry___36 *);
	int (*symlink)(struct inode___36 *, struct dentry___36 *, const char *);
	int (*mkdir)(struct inode___36 *, struct dentry___36 *, umode_t);
	int (*rmdir)(struct inode___36 *, struct dentry___36 *);
	int (*mknod)(struct inode___36 *, struct dentry___36 *, umode_t, dev_t);
	int (*rename)(struct inode___36 *, struct dentry___36 *, struct inode___36 *, struct dentry___36 *);
	int (*setattr)(struct dentry___36 *, struct iattr___36 *);
	int (*getattr)(struct vfsmount *, struct dentry___36 *, struct kstat *);
	int (*setxattr)(struct dentry___36 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___36 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___36 *, char *, size_t);
	int (*removexattr)(struct dentry___36 *, const char *);
	int (*fiemap)(struct inode___36 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___36 *, struct timespec *, int);
	int (*atomic_open)(struct inode___36 *, struct dentry___36 *, struct file___35 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___35 {
	struct module___22 *owner;
	loff_t (*llseek)(struct file___35 *, loff_t, int);
	ssize_t (*read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___35 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___35 *, void *, filldir_t);
	unsigned int (*poll)(struct file___35 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___35 *, struct vm_area_struct___38 *);
	int (*open)(struct inode___36 *, struct file___35 *);
	int (*flush)(struct file___35 *, fl_owner_t);
	int (*release)(struct inode___36 *, struct file___35 *);
	int (*fsync)(struct file___35 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___35 *, int);
	int (*lock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*sendpage)(struct file___35 *, struct page___35 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___35 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___35 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___35 *, long int, struct file_lock___35 **, void **);
		struct {
			int (*setlease)(struct file___35 *, long int, struct file_lock___35 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___35 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___35 *);
};

struct fasync_struct___35;

struct file_lock_operations___35;

struct lock_manager_operations___35;

struct file_lock___35 {
	struct file_lock___35 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___16 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___35 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___35 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___35 *fl_ops;
	const struct lock_manager_operations___35 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___35 {
	void (*fl_copy_lock)(struct file_lock___35 *, struct file_lock___35 *);
	void (*fl_release_private)(struct file_lock___35 *);
};

struct lock_manager_operations___35 {
	int (*lm_compare_owner)(struct file_lock___35 *, struct file_lock___35 *);
	long unsigned int (*lm_owner_key)(struct file_lock___35 *);
	void (*lm_notify)(struct file_lock___35 *);
	int (*lm_grant)(struct file_lock___35 *, struct file_lock___35 *, int);
	void (*lm_break)(struct file_lock___35 *);
	int (*lm_change)(struct file_lock___35 **, int);
};

struct fasync_struct___35 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___35 *fa_next;
	struct file___35 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___35 {
	const char *name;
	int fs_flags;
	struct dentry___36 * (*mount)(struct file_system_type___35 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___36 *);
	struct module___22 *owner;
	struct file_system_type___35 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___35 {
	struct inode___36 * (*alloc_inode)(struct super_block___36 *);
	void (*destroy_inode)(struct inode___36 *);
	void (*dirty_inode)(struct inode___36 *, int);
	int (*write_inode)(struct inode___36 *, struct writeback_control *);
	int (*drop_inode)(struct inode___36 *);
	void (*evict_inode)(struct inode___36 *);
	void (*put_super)(struct super_block___36 *);
	int (*sync_fs)(struct super_block___36 *, int);
	int (*freeze_fs)(struct super_block___36 *);
	int (*unfreeze_fs)(struct super_block___36 *);
	int (*statfs)(struct dentry___36 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___36 *, int *, char *);
	void (*umount_begin)(struct super_block___36 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___36 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___36 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___36 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___36 *);
	ssize_t (*quota_read)(struct super_block___36 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___36 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___36 *);
	int (*bdev_try_to_free_page)(struct super_block___36 *, struct page___35 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___36 *);
	void (*free_cached_objects)(struct super_block___36 *, int);
};

struct page___36;

typedef struct page___36 *pgtable_t___36;

struct address_space___36;

struct kmem_cache___31;

struct page___36 {
	long unsigned int flags;
	struct address_space___36 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___36 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___36 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___31 *slab_cache;
		struct page___36 *first_page;
	};
	long: 64;
};

struct thread_struct___16;

struct task_struct___37;

struct pv_cpu_ops___36 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___16 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___16 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___37 *);
	void (*end_context_switch)(struct task_struct___37 *);
};

struct perf_event___16;

struct thread_struct___16 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___16 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___17;

struct pid_link___17 {
	struct hlist_node node;
	struct pid___17 *pid;
};

struct mutex___37 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___37 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___34 {
	struct page___36 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___39;

struct nsproxy___17;

struct signal_struct___36;

struct css_set___16;

struct perf_event_context___16;

struct task_struct___37 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___37 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___39 *mm;
	struct mm_struct___39 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___37 *real_parent;
	struct task_struct___37 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___37 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___17 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___36 = 0,
		VTIME_USER___36 = 1,
		VTIME_SYS___36 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___16 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___17 *nsproxy;
	struct signal_struct___36 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___16 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___16 *perf_event_ctxp[2];
	struct mutex___37 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___34 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___39 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___39 *, struct mm_struct___39 *);
	void (*dup_mmap)(struct mm_struct___39 *, struct mm_struct___39 *);
	void (*exit_mmap)(struct mm_struct___39 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___39 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___39 *);
	void (*pgd_free)(struct mm_struct___39 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___39 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___39 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___39 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___39 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___39 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___39 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___39 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___39 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___39 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___39 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___39 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___37 lock;
	void *vdso;
} mm_context_t___37;

struct xol_area___36;

struct uprobes_state___36 {
	struct xol_area___36 *xol_area;
};

struct vm_area_struct___39;

struct file___36;

struct core_state___36;

struct mm_struct___39 {
	struct vm_area_struct___39 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___39 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___39 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___37 context;
	long unsigned int flags;
	struct core_state___36 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___37 *owner;
	struct file___36 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___36 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___23;

struct module_kobject___22 {
	struct kobject kobj;
	struct module___23 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___22;

struct ftrace_event_call___8;

struct module___23 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___22 mkobj;
	struct module_attribute___22 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___8 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___37 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___16 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___37 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___37 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___37 *target;
};

typedef void (*perf_overflow_handler_t___16)(struct perf_event___16 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___16;

typedef void (*ftrace_func_t___16)(long unsigned int, long unsigned int, struct ftrace_ops___16 *, struct pt_regs *);

struct ftrace_ops___16 {
	ftrace_func_t___16 func;
	struct ftrace_ops___16 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___37 regex_lock;
};

struct pmu___16;

struct fasync_struct___36;

struct pid_namespace___17;

struct perf_cgroup___16;

struct perf_event___16 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___16 *group_leader;
	struct pmu___16 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___16 hw;
	struct perf_event_context___16 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___37 child_mutex;
	struct list_head child_list;
	struct perf_event___16 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___37 *owner;
	struct mutex___37 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___36 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___16 *);
	struct callback_head callback_head;
	struct pid_namespace___17 *ns;
	u64 id;
	perf_overflow_handler_t___16 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___8 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___16 ftrace_ops;
	struct perf_cgroup___16 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct irq_data___26;

struct x86_io_apic_ops___26 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___26 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___26;

struct irq_data___26 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___26 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___30;

struct dev_pm_ops___30 {
	int (*prepare)(struct device___30 *);
	void (*complete)(struct device___30 *);
	int (*suspend)(struct device___30 *);
	int (*resume)(struct device___30 *);
	int (*freeze)(struct device___30 *);
	int (*thaw)(struct device___30 *);
	int (*poweroff)(struct device___30 *);
	int (*restore)(struct device___30 *);
	int (*suspend_late)(struct device___30 *);
	int (*resume_early)(struct device___30 *);
	int (*freeze_late)(struct device___30 *);
	int (*thaw_early)(struct device___30 *);
	int (*poweroff_late)(struct device___30 *);
	int (*restore_early)(struct device___30 *);
	int (*suspend_noirq)(struct device___30 *);
	int (*resume_noirq)(struct device___30 *);
	int (*freeze_noirq)(struct device___30 *);
	int (*thaw_noirq)(struct device___30 *);
	int (*poweroff_noirq)(struct device___30 *);
	int (*restore_noirq)(struct device___30 *);
	int (*runtime_suspend)(struct device___30 *);
	int (*runtime_resume)(struct device___30 *);
	int (*runtime_idle)(struct device___30 *);
};

struct device_type___30;

struct bus_type___30;

struct device_driver___30;

struct dev_pm_domain___30;

struct class___30;

struct attribute_group___26;

struct device_rh___30;

struct device___30 {
	struct device___30 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___30 *type;
	struct mutex___37 mutex;
	struct bus_type___30 *bus;
	struct device_driver___30 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___30 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___14 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___30 *class;
	const struct attribute_group___26 **groups;
	void (*release)(struct device___30 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___30 *device_rh;
};

struct dev_pm_info_rh___30 {
	void (*set_latency_tolerance)(struct device___30 *, s32);
};

struct dev_pm_domain___30 {
	struct dev_pm_ops___30 ops;
};

struct smp_ops___36 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___37 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___36;

struct lruvec___36 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___36 *zone;
};

struct pglist_data___36;

struct zone___36 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___36 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___36 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___36 {
	struct zone___36 *zone;
	int zone_idx;
};

struct zonelist___36 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___36 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___36 {
	struct zone___36 node_zones[4];
	struct zonelist___36 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___37 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___25;

struct irq_chip___26 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___26 *);
	void (*irq_shutdown)(struct irq_data___26 *);
	void (*irq_enable)(struct irq_data___26 *);
	void (*irq_disable)(struct irq_data___26 *);
	void (*irq_ack)(struct irq_data___26 *);
	void (*irq_mask)(struct irq_data___26 *);
	void (*irq_mask_ack)(struct irq_data___26 *);
	void (*irq_unmask)(struct irq_data___26 *);
	void (*irq_eoi)(struct irq_data___26 *);
	int (*irq_set_affinity)(struct irq_data___26 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___26 *);
	int (*irq_set_type)(struct irq_data___26 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___26 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___26 *);
	void (*irq_bus_sync_unlock)(struct irq_data___26 *);
	void (*irq_cpu_online)(struct irq_data___26 *);
	void (*irq_cpu_offline)(struct irq_data___26 *);
	void (*irq_suspend)(struct irq_data___26 *);
	void (*irq_resume)(struct irq_data___26 *);
	void (*irq_pm_shutdown)(struct irq_data___26 *);
	void (*irq_print_chip)(struct irq_data___26 *, struct seq_file___25 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___26 *, void *);
	long unsigned int flags;
};

struct seq_operations___25;

struct seq_file___25 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___37 lock;
	const struct seq_operations___25 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___36 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___36 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___31;

struct memcg_cache_params___31;

struct kmem_cache___31 {
	struct kmem_cache_cpu___31 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___31 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___37;

struct address_space_operations___36;

struct address_space___36 {
	struct inode___37 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___37 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___36 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___37;

struct path___36 {
	struct vfsmount *mnt;
	struct dentry___37 *dentry;
};

struct fown_struct___17 {
	rwlock_t lock;
	struct pid___17 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___36;

struct file___36 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___36 f_path;
	struct inode___37 *f_inode;
	const struct file_operations___36 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___17 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___36 *f_mapping;
	struct mutex___37 f_pos_lock;
};

struct vm_operations_struct___30;

struct vm_area_struct___39 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___39 *vm_next;
	struct vm_area_struct___39 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___39 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___30 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___36 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___28;

struct vm_operations_struct___30 {
	void (*open)(struct vm_area_struct___39 *);
	void (*close)(struct vm_area_struct___39 *);
	int (*fault)(struct vm_area_struct___39 *, struct vm_fault___28 *);
	int (*page_mkwrite)(struct vm_area_struct___39 *, struct vm_fault___28 *);
	int (*access)(struct vm_area_struct___39 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___39 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___39 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___39 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___39 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___36 {
	struct task_struct___37 *task;
	struct core_thread___36 *next;
};

struct core_state___36 {
	atomic_t nr_threads;
	struct core_thread___36 dumper;
	struct completion startup;
};

struct upid___17 {
	int nr;
	struct pid_namespace___17 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___17 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___37 *child_reaper;
	struct kmem_cache___31 *pid_cachep;
	unsigned int level;
	struct pid_namespace___17 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___37 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___17 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___17 numbers[1];
};

struct nsproxy___17 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___17 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___36 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___37 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___37 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___17 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___17 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___37 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___16;

struct css_set___16 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___16 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___16 {
	struct pmu___16 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___37 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___37 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___16 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___36;

struct super_block___37;

struct dentry___37 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___37 *d_parent;
	struct qstr d_name;
	struct inode___37 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___36 *d_op;
	struct super_block___37 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___36;

struct file_lock___36;

struct dquot___36;

struct block_device___36;

struct inode___37 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___36 *i_op;
	struct super_block___37 *i_sb;
	struct address_space___36 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___37 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___36 *i_fop;
	struct file_lock___36 *i_flock;
	struct address_space___36 i_data;
	struct dquot___36 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___36 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___36 {
	int (*d_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_hash)(const struct dentry___37 *, struct qstr *);
	int (*d_compare)(const struct dentry___37 *, const struct dentry___37 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___37 *);
	void (*d_release)(struct dentry___37 *);
	void (*d_prune)(struct dentry___37 *);
	void (*d_iput)(struct dentry___37 *, struct inode___37 *);
	char * (*d_dname)(struct dentry___37 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___36 *);
	int (*d_manage)(struct dentry___37 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___36;

struct mem_dqinfo___36 {
	struct quota_format_type___36 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___36;

struct quota_info___36 {
	unsigned int flags;
	struct mutex___37 dqio_mutex;
	struct mutex___37 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___37 *files[2];
	struct mem_dqinfo___36 info[2];
	const struct quota_format_ops___36 *ops[2];
};

struct file_system_type___36;

struct super_operations___36;

struct dquot_operations___36;

struct quotactl_ops___36;

struct xattr_handler___16;

struct super_block___37 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___36 *s_type;
	const struct super_operations___36 *s_op;
	const struct dquot_operations___36 *dq_op;
	const struct quotactl_ops___36 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___37 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___16 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___36 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___36 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___37 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___36 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___36 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___37 *bd_inode;
	struct super_block___37 *bd_super;
	struct mutex___37 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___36 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___37 bd_fsfreeze_mutex;
};

struct cgroup___16;

struct cgroup_subsys_state___16 {
	struct cgroup___16 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___37 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___36 *ia_file;
};

struct dquot___36 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___37 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___37 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___36 {
	int qf_fmt_id;
	const struct quota_format_ops___36 *qf_ops;
	struct module___23 *qf_owner;
	struct quota_format_type___36 *qf_next;
};

struct quota_format_ops___36 {
	int (*check_quota_file)(struct super_block___37 *, int);
	int (*read_file_info)(struct super_block___37 *, int);
	int (*write_file_info)(struct super_block___37 *, int);
	int (*free_file_info)(struct super_block___37 *, int);
	int (*read_dqblk)(struct dquot___36 *);
	int (*commit_dqblk)(struct dquot___36 *);
	int (*release_dqblk)(struct dquot___36 *);
};

struct dquot_operations___36 {
	int (*write_dquot)(struct dquot___36 *);
	struct dquot___36 * (*alloc_dquot)(struct super_block___37 *, int);
	void (*destroy_dquot)(struct dquot___36 *);
	int (*acquire_dquot)(struct dquot___36 *);
	int (*release_dquot)(struct dquot___36 *);
	int (*mark_dirty)(struct dquot___36 *);
	int (*write_info)(struct super_block___37 *, int);
	qsize_t * (*get_reserved_space)(struct inode___37 *);
};

struct quotactl_ops___36 {
	int (*quota_on)(struct super_block___37 *, int, int, struct path___36 *);
	int (*quota_on_meta)(struct super_block___37 *, int, int);
	int (*quota_off)(struct super_block___37 *, int);
	int (*quota_sync)(struct super_block___37 *, int);
	int (*get_info)(struct super_block___37 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___37 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___37 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___37 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___37 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___37 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___37 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___37 *, unsigned int);
};

struct address_space_operations___36 {
	int (*writepage)(struct page___36 *, struct writeback_control *);
	int (*readpage)(struct file___36 *, struct page___36 *);
	int (*writepages)(struct address_space___36 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___36 *);
	int (*readpages)(struct file___36 *, struct address_space___36 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___36 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___36 **, void **);
	int (*write_end)(struct file___36 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___36 *, void *);
	sector_t (*bmap)(struct address_space___36 *, sector_t);
	void (*invalidatepage)(struct page___36 *, long unsigned int);
	int (*releasepage)(struct page___36 *, gfp_t);
	void (*freepage)(struct page___36 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___36 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___36 *, struct page___36 *, struct page___36 *, enum migrate_mode);
	int (*launder_page)(struct page___36 *);
	int (*is_partially_uptodate)(struct page___36 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___36 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___36 *, struct page___36 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___36 *, sector_t *);
	void (*swap_deactivate)(struct file___36 *);
	void (*invalidatepage_range)(struct page___36 *, unsigned int, unsigned int);
};

struct inode_operations___36 {
	struct dentry___37 * (*lookup)(struct inode___37 *, struct dentry___37 *, unsigned int);
	void * (*follow_link)(struct dentry___37 *, struct nameidata *);
	int (*permission)(struct inode___37 *, int);
	struct posix_acl * (*get_acl)(struct inode___37 *, int);
	int (*readlink)(struct dentry___37 *, char *, int);
	void (*put_link)(struct dentry___37 *, struct nameidata *, void *);
	int (*create)(struct inode___37 *, struct dentry___37 *, umode_t, bool);
	int (*link)(struct dentry___37 *, struct inode___37 *, struct dentry___37 *);
	int (*unlink)(struct inode___37 *, struct dentry___37 *);
	int (*symlink)(struct inode___37 *, struct dentry___37 *, const char *);
	int (*mkdir)(struct inode___37 *, struct dentry___37 *, umode_t);
	int (*rmdir)(struct inode___37 *, struct dentry___37 *);
	int (*mknod)(struct inode___37 *, struct dentry___37 *, umode_t, dev_t);
	int (*rename)(struct inode___37 *, struct dentry___37 *, struct inode___37 *, struct dentry___37 *);
	int (*setattr)(struct dentry___37 *, struct iattr___37 *);
	int (*getattr)(struct vfsmount *, struct dentry___37 *, struct kstat *);
	int (*setxattr)(struct dentry___37 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___37 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___37 *, char *, size_t);
	int (*removexattr)(struct dentry___37 *, const char *);
	int (*fiemap)(struct inode___37 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___37 *, struct timespec *, int);
	int (*atomic_open)(struct inode___37 *, struct dentry___37 *, struct file___36 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___21;

struct file_operations___36 {
	struct module___23 *owner;
	loff_t (*llseek)(struct file___36 *, loff_t, int);
	ssize_t (*read)(struct file___36 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___36 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___36 *, void *, filldir_t);
	unsigned int (*poll)(struct file___36 *, struct poll_table_struct___21 *);
	long int (*unlocked_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___36 *, struct vm_area_struct___39 *);
	int (*open)(struct inode___37 *, struct file___36 *);
	int (*flush)(struct file___36 *, fl_owner_t);
	int (*release)(struct inode___37 *, struct file___36 *);
	int (*fsync)(struct file___36 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___36 *, int);
	int (*lock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*sendpage)(struct file___36 *, struct page___36 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___36 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___36 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___36 *, long int, struct file_lock___36 **, void **);
		struct {
			int (*setlease)(struct file___36 *, long int, struct file_lock___36 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___36 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___25 *, struct file___36 *);
};

struct file_lock_operations___36;

struct lock_manager_operations___36;

struct file_lock___36 {
	struct file_lock___36 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___17 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___36 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___36 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___36 *fl_ops;
	const struct lock_manager_operations___36 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___36 {
	void (*fl_copy_lock)(struct file_lock___36 *, struct file_lock___36 *);
	void (*fl_release_private)(struct file_lock___36 *);
};

struct lock_manager_operations___36 {
	int (*lm_compare_owner)(struct file_lock___36 *, struct file_lock___36 *);
	long unsigned int (*lm_owner_key)(struct file_lock___36 *);
	void (*lm_notify)(struct file_lock___36 *);
	int (*lm_grant)(struct file_lock___36 *, struct file_lock___36 *, int);
	void (*lm_break)(struct file_lock___36 *);
	int (*lm_change)(struct file_lock___36 **, int);
};

struct fasync_struct___36 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___36 *fa_next;
	struct file___36 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___36 {
	const char *name;
	int fs_flags;
	struct dentry___37 * (*mount)(struct file_system_type___36 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___37 *);
	struct module___23 *owner;
	struct file_system_type___36 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___36 {
	struct inode___37 * (*alloc_inode)(struct super_block___37 *);
	void (*destroy_inode)(struct inode___37 *);
	void (*dirty_inode)(struct inode___37 *, int);
	int (*write_inode)(struct inode___37 *, struct writeback_control *);
	int (*drop_inode)(struct inode___37 *);
	void (*evict_inode)(struct inode___37 *);
	void (*put_super)(struct super_block___37 *);
	int (*sync_fs)(struct super_block___37 *, int);
	int (*freeze_fs)(struct super_block___37 *);
	int (*unfreeze_fs)(struct super_block___37 *);
	int (*statfs)(struct dentry___37 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___37 *, int *, char *);
	void (*umount_begin)(struct super_block___37 *);
	int (*show_options)(struct seq_file___25 *, struct dentry___37 *);
	int (*show_devname)(struct seq_file___25 *, struct dentry___37 *);
	int (*show_path)(struct seq_file___25 *, struct dentry___37 *);
	int (*show_stats)(struct seq_file___25 *, struct dentry___37 *);
	ssize_t (*quota_read)(struct super_block___37 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___37 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___37 *);
	int (*bdev_try_to_free_page)(struct super_block___37 *, struct page___36 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___37 *);
	void (*free_cached_objects)(struct super_block___37 *, int);
};

struct xattr_handler___16 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___37 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___37 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___37 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___21)(struct file___36 *, wait_queue_head_t *, struct poll_table_struct___21 *);

struct poll_table_struct___21 {
	poll_queue_proc___21 _qproc;
	long unsigned int _key;
};

struct dyn_arch_ftrace {};

enum {
	FTRACE_FL_ENABLED = 536870912,
	FTRACE_FL_REGS = 1073741824,
	FTRACE_FL_REGS_EN = 2147483648,
};

struct dyn_ftrace {
	union {
		long unsigned int ip;
		struct dyn_ftrace *freelist;
	};
	long unsigned int flags;
	struct dyn_arch_ftrace arch;
};

enum {
	FTRACE_UPDATE_IGNORE = 0,
	FTRACE_UPDATE_MAKE_CALL = 1,
	FTRACE_UPDATE_MODIFY_CALL = 2,
	FTRACE_UPDATE_MODIFY_CALL_REGS = 3,
	FTRACE_UPDATE_MAKE_NOP = 4,
};

struct ftrace_graph_ent {
	long unsigned int func;
	int depth;
};

typedef int (*trace_func_graph_ent_t)(struct ftrace_graph_ent *);

struct bin_attribute___26;

struct attribute_group___26 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___26 **bin_attrs;
};

struct bin_attribute___26 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___36 *, struct kobject *, struct bin_attribute___26 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___36 *, struct kobject *, struct bin_attribute___26 *, char *, loff_t, size_t);
	int (*mmap)(struct file___36 *, struct kobject *, struct bin_attribute___26 *, struct vm_area_struct___39 *);
};

struct module_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___22 *, struct module_kobject___22 *, char *);
	ssize_t (*store)(struct module_attribute___22 *, struct module_kobject___22 *, const char *, size_t);
	void (*setup)(struct module___23 *, const char *);
	int (*test)(struct module___23 *);
	void (*free)(struct module___23 *);
};

struct trace_event_functions___8;

struct trace_event___8 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___8 *funcs;
};

struct ftrace_event_class___8;

struct ftrace_event_call___8 {
	struct list_head list;
	struct ftrace_event_class___8 *class;
	char *name;
	struct trace_event___8 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct vm_fault___28 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___36 *page;
};

struct seq_operations___25 {
	void * (*start)(struct seq_file___25 *, loff_t *);
	void (*stop)(struct seq_file___25 *, void *);
	void * (*next)(struct seq_file___25 *, void *, loff_t *);
	int (*show)(struct seq_file___25 *, void *);
};

struct bus_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___30 *, char *);
	ssize_t (*store)(struct bus_type___30 *, const char *, size_t);
};

struct device_attribute___30;

struct driver_attribute___30;

struct bus_type___30 {
	const char *name;
	const char *dev_name;
	struct device___30 *dev_root;
	struct bus_attribute___30 *bus_attrs;
	struct device_attribute___30 *dev_attrs;
	struct driver_attribute___30 *drv_attrs;
	const struct attribute_group___26 **bus_groups;
	const struct attribute_group___26 **dev_groups;
	const struct attribute_group___26 **drv_groups;
	int (*match)(struct device___30 *, struct device_driver___30 *);
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	int (*probe)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*online)(struct device___30 *);
	int (*offline)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct device___30 *, struct device_attribute___30 *, char *);
	ssize_t (*store)(struct device___30 *, struct device_attribute___30 *, const char *, size_t);
};

struct driver_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___30 *, char *);
	ssize_t (*store)(struct device_driver___30 *, const char *, size_t);
};

struct device_driver___30 {
	const char *name;
	struct bus_type___30 *bus;
	struct module___23 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct attribute_group___26 **groups;
	const struct dev_pm_ops___30 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___30 {
	const char *name;
	const struct attribute_group___26 **groups;
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
};

struct class_attribute___30;

struct class___30 {
	const char *name;
	struct module___23 *owner;
	struct class_attribute___30 *class_attrs;
	struct device_attribute___30 *dev_attrs;
	const struct attribute_group___26 **dev_groups;
	struct bin_attribute___26 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *);
	void (*class_release)(struct class___30 *);
	void (*dev_release)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	struct subsys_private *p;
};

struct class_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct class___30 *, struct class_attribute___30 *, char *);
	ssize_t (*store)(struct class___30 *, struct class_attribute___30 *, const char *, size_t);
	const void * (*namespace)(struct class___30 *, const struct class_attribute___30 *);
};

struct device_rh___30 {
	struct dev_pm_info_rh___30 power;
};

struct kmem_cache_cpu___31 {
	void **freelist;
	long unsigned int tid;
	struct page___36 *page;
	struct page___36 *partial;
};

struct memcg_cache_params___31 {
	bool is_root_cache;
	union {
		struct kmem_cache___31 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___31 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___16;

struct cgroup___16 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___16 *parent;
	struct dentry___37 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___16 *subsys[11];
	struct cgroupfs_root___16 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___37 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___16 {
	struct super_block___37 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___16 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___16;

struct pmu___16 {
	struct list_head entry;
	struct device___30 *dev;
	const struct attribute_group___26 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___16 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___16 *);
	void (*pmu_disable)(struct pmu___16 *);
	int (*event_init)(struct perf_event___16 *);
	int (*add)(struct perf_event___16 *, int);
	void (*del)(struct perf_event___16 *, int);
	void (*start)(struct perf_event___16 *, int);
	void (*stop)(struct perf_event___16 *, int);
	void (*read)(struct perf_event___16 *);
	void (*start_txn)(struct pmu___16 *);
	int (*commit_txn)(struct pmu___16 *);
	void (*cancel_txn)(struct pmu___16 *);
	int (*event_idx)(struct perf_event___16 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___23 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___16 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___16 *);
};

struct perf_cpu_context___16 {
	struct perf_event_context___16 ctx;
	struct perf_event_context___16 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___16 *unique_pmu;
	struct perf_cgroup___16 *cgrp;
};

struct perf_cgroup___16 {
	struct cgroup_subsys_state___16 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___8 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___37 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___8)(struct trace_iterator___8 *, int, struct trace_event___8 *);

struct trace_event_functions___8 {
	trace_print_func___8 trace;
	trace_print_func___8 raw;
	trace_print_func___8 hex;
	trace_print_func___8 binary;
};

struct ftrace_event_class___8 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___8 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___8 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___8 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___8 *);
};

union ftrace_code_union {
	char code[5];
	struct {
		char e8;
		int offset;
	} __attribute__((packed));
};

struct ftrace_rec_iter;

struct page___37;

typedef struct page___37 *pgtable_t___37;

struct address_space___37;

struct kmem_cache___32;

struct page___37 {
	long unsigned int flags;
	struct address_space___37 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___37 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___37 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___32 *slab_cache;
		struct page___37 *first_page;
	};
	long: 64;
};

struct task_struct___38;

struct pv_cpu_ops___37 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___16 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___16 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___38 *);
	void (*end_context_switch)(struct task_struct___38 *);
};

struct mutex___38 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___38 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___35 {
	struct page___37 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___40;

struct signal_struct___37;

struct css_set___17;

struct task_struct___38 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___38 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___40 *mm;
	struct mm_struct___40 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___38 *real_parent;
	struct task_struct___38 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___38 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___17 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___37 = 0,
		VTIME_USER___37 = 1,
		VTIME_SYS___37 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___16 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___37 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___17 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___38 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___35 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___40 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___40 *, struct mm_struct___40 *);
	void (*dup_mmap)(struct mm_struct___40 *, struct mm_struct___40 *);
	void (*exit_mmap)(struct mm_struct___40 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___40 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___40 *);
	void (*pgd_free)(struct mm_struct___40 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___40 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___40 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___40 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___40 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___40 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___40 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___40 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___40 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___40 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___40 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___40 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___38 lock;
	void *vdso;
} mm_context_t___38;

struct xol_area___37;

struct uprobes_state___37 {
	struct xol_area___37 *xol_area;
};

struct vm_area_struct___40;

struct file___37;

struct core_state___37;

struct mm_struct___40 {
	struct vm_area_struct___40 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___40 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___40 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___38 context;
	long unsigned int flags;
	struct core_state___37 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___38 *owner;
	struct file___37 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___37 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___24;

struct module_kobject___23 {
	struct kobject kobj;
	struct module___24 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___23;

struct module___24 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___23 mkobj;
	struct module_attribute___23 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___38 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___37;

struct lruvec___37 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___37 *zone;
};

struct pglist_data___37;

struct zone___37 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___37 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___37 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___37 {
	struct zone___37 *zone;
	int zone_idx;
};

struct zonelist___37 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___37 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___37 {
	struct zone___37 node_zones[4];
	struct zonelist___37 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___38 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___37 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___38 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___37 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___37 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___32;

struct memcg_cache_params___32;

struct kmem_cache___32 {
	struct kmem_cache_cpu___32 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___32 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___38;

struct address_space_operations___37;

struct address_space___37 {
	struct inode___38 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___38 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___37 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___38;

struct path___37 {
	struct vfsmount *mnt;
	struct dentry___38 *dentry;
};

struct file_operations___37;

struct file___37 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___37 f_path;
	struct inode___38 *f_inode;
	const struct file_operations___37 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___17 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___37 *f_mapping;
	struct mutex___38 f_pos_lock;
};

struct vm_operations_struct___31;

struct vm_area_struct___40 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___40 *vm_next;
	struct vm_area_struct___40 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___40 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___31 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___37 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___29;

struct vm_operations_struct___31 {
	void (*open)(struct vm_area_struct___40 *);
	void (*close)(struct vm_area_struct___40 *);
	int (*fault)(struct vm_area_struct___40 *, struct vm_fault___29 *);
	int (*page_mkwrite)(struct vm_area_struct___40 *, struct vm_fault___29 *);
	int (*access)(struct vm_area_struct___40 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___40 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___40 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___40 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___40 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___37 {
	struct task_struct___38 *task;
	struct core_thread___37 *next;
};

struct core_state___37 {
	atomic_t nr_threads;
	struct core_thread___37 dumper;
	struct completion startup;
};

struct vm_fault___29 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___37 *page;
};

struct dentry_operations___37;

struct super_block___38;

struct dentry___38 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___38 *d_parent;
	struct qstr d_name;
	struct inode___38 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___37 *d_op;
	struct super_block___38 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___37;

struct file_lock___37;

struct dquot___37;

struct block_device___37;

struct inode___38 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___37 *i_op;
	struct super_block___38 *i_sb;
	struct address_space___37 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___38 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___37 *i_fop;
	struct file_lock___37 *i_flock;
	struct address_space___37 i_data;
	struct dquot___37 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___37 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___37 {
	int (*d_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_hash)(const struct dentry___38 *, struct qstr *);
	int (*d_compare)(const struct dentry___38 *, const struct dentry___38 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___38 *);
	void (*d_release)(struct dentry___38 *);
	void (*d_prune)(struct dentry___38 *);
	void (*d_iput)(struct dentry___38 *, struct inode___38 *);
	char * (*d_dname)(struct dentry___38 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___37 *);
	int (*d_manage)(struct dentry___38 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___37;

struct mem_dqinfo___37 {
	struct quota_format_type___37 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___37;

struct quota_info___37 {
	unsigned int flags;
	struct mutex___38 dqio_mutex;
	struct mutex___38 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___38 *files[2];
	struct mem_dqinfo___37 info[2];
	const struct quota_format_ops___37 *ops[2];
};

struct file_system_type___37;

struct super_operations___37;

struct dquot_operations___37;

struct quotactl_ops___37;

struct xattr_handler___17;

struct super_block___38 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___37 *s_type;
	const struct super_operations___37 *s_op;
	const struct dquot_operations___37 *dq_op;
	const struct quotactl_ops___37 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___38 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___17 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___37 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___37 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___38 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___37 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___37 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___38 *bd_inode;
	struct super_block___38 *bd_super;
	struct mutex___38 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___37 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___38 bd_fsfreeze_mutex;
};

struct cgroup___17;

struct cgroup_subsys_state___17 {
	struct cgroup___17 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___38 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___37 *ia_file;
};

struct dquot___37 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___38 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___38 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___37 {
	int qf_fmt_id;
	const struct quota_format_ops___37 *qf_ops;
	struct module___24 *qf_owner;
	struct quota_format_type___37 *qf_next;
};

struct quota_format_ops___37 {
	int (*check_quota_file)(struct super_block___38 *, int);
	int (*read_file_info)(struct super_block___38 *, int);
	int (*write_file_info)(struct super_block___38 *, int);
	int (*free_file_info)(struct super_block___38 *, int);
	int (*read_dqblk)(struct dquot___37 *);
	int (*commit_dqblk)(struct dquot___37 *);
	int (*release_dqblk)(struct dquot___37 *);
};

struct dquot_operations___37 {
	int (*write_dquot)(struct dquot___37 *);
	struct dquot___37 * (*alloc_dquot)(struct super_block___38 *, int);
	void (*destroy_dquot)(struct dquot___37 *);
	int (*acquire_dquot)(struct dquot___37 *);
	int (*release_dquot)(struct dquot___37 *);
	int (*mark_dirty)(struct dquot___37 *);
	int (*write_info)(struct super_block___38 *, int);
	qsize_t * (*get_reserved_space)(struct inode___38 *);
};

struct quotactl_ops___37 {
	int (*quota_on)(struct super_block___38 *, int, int, struct path___37 *);
	int (*quota_on_meta)(struct super_block___38 *, int, int);
	int (*quota_off)(struct super_block___38 *, int);
	int (*quota_sync)(struct super_block___38 *, int);
	int (*get_info)(struct super_block___38 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___38 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___38 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___38 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___38 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___38 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___38 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___38 *, unsigned int);
};

struct swap_info_struct___3;

struct address_space_operations___37 {
	int (*writepage)(struct page___37 *, struct writeback_control *);
	int (*readpage)(struct file___37 *, struct page___37 *);
	int (*writepages)(struct address_space___37 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___37 *);
	int (*readpages)(struct file___37 *, struct address_space___37 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___37 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___37 **, void **);
	int (*write_end)(struct file___37 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___37 *, void *);
	sector_t (*bmap)(struct address_space___37 *, sector_t);
	void (*invalidatepage)(struct page___37 *, long unsigned int);
	int (*releasepage)(struct page___37 *, gfp_t);
	void (*freepage)(struct page___37 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___37 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___37 *, struct page___37 *, struct page___37 *, enum migrate_mode);
	int (*launder_page)(struct page___37 *);
	int (*is_partially_uptodate)(struct page___37 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___37 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___37 *, struct page___37 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___37 *, sector_t *);
	void (*swap_deactivate)(struct file___37 *);
	void (*invalidatepage_range)(struct page___37 *, unsigned int, unsigned int);
};

struct swap_info_struct___3 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___37 *bdev;
	struct file___37 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___37 {
	struct dentry___38 * (*lookup)(struct inode___38 *, struct dentry___38 *, unsigned int);
	void * (*follow_link)(struct dentry___38 *, struct nameidata *);
	int (*permission)(struct inode___38 *, int);
	struct posix_acl * (*get_acl)(struct inode___38 *, int);
	int (*readlink)(struct dentry___38 *, char *, int);
	void (*put_link)(struct dentry___38 *, struct nameidata *, void *);
	int (*create)(struct inode___38 *, struct dentry___38 *, umode_t, bool);
	int (*link)(struct dentry___38 *, struct inode___38 *, struct dentry___38 *);
	int (*unlink)(struct inode___38 *, struct dentry___38 *);
	int (*symlink)(struct inode___38 *, struct dentry___38 *, const char *);
	int (*mkdir)(struct inode___38 *, struct dentry___38 *, umode_t);
	int (*rmdir)(struct inode___38 *, struct dentry___38 *);
	int (*mknod)(struct inode___38 *, struct dentry___38 *, umode_t, dev_t);
	int (*rename)(struct inode___38 *, struct dentry___38 *, struct inode___38 *, struct dentry___38 *);
	int (*setattr)(struct dentry___38 *, struct iattr___38 *);
	int (*getattr)(struct vfsmount *, struct dentry___38 *, struct kstat *);
	int (*setxattr)(struct dentry___38 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___38 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___38 *, char *, size_t);
	int (*removexattr)(struct dentry___38 *, const char *);
	int (*fiemap)(struct inode___38 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___38 *, struct timespec *, int);
	int (*atomic_open)(struct inode___38 *, struct dentry___38 *, struct file___37 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___37 {
	struct module___24 *owner;
	loff_t (*llseek)(struct file___37 *, loff_t, int);
	ssize_t (*read)(struct file___37 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___37 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___37 *, void *, filldir_t);
	unsigned int (*poll)(struct file___37 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___37 *, struct vm_area_struct___40 *);
	int (*open)(struct inode___38 *, struct file___37 *);
	int (*flush)(struct file___37 *, fl_owner_t);
	int (*release)(struct inode___38 *, struct file___37 *);
	int (*fsync)(struct file___37 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___37 *, int);
	int (*lock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*sendpage)(struct file___37 *, struct page___37 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___37 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___37 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___37 *, long int, struct file_lock___37 **, void **);
		struct {
			int (*setlease)(struct file___37 *, long int, struct file_lock___37 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___37 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___37 *);
};

struct fasync_struct___37;

struct file_lock_operations___37;

struct lock_manager_operations___37;

struct file_lock___37 {
	struct file_lock___37 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___17 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___37 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___37 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___37 *fl_ops;
	const struct lock_manager_operations___37 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___37 {
	void (*fl_copy_lock)(struct file_lock___37 *, struct file_lock___37 *);
	void (*fl_release_private)(struct file_lock___37 *);
};

struct lock_manager_operations___37 {
	int (*lm_compare_owner)(struct file_lock___37 *, struct file_lock___37 *);
	long unsigned int (*lm_owner_key)(struct file_lock___37 *);
	void (*lm_notify)(struct file_lock___37 *);
	int (*lm_grant)(struct file_lock___37 *, struct file_lock___37 *, int);
	void (*lm_break)(struct file_lock___37 *);
	int (*lm_change)(struct file_lock___37 **, int);
};

struct fasync_struct___37 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___37 *fa_next;
	struct file___37 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___37 {
	const char *name;
	int fs_flags;
	struct dentry___38 * (*mount)(struct file_system_type___37 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___38 *);
	struct module___24 *owner;
	struct file_system_type___37 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___37 {
	struct inode___38 * (*alloc_inode)(struct super_block___38 *);
	void (*destroy_inode)(struct inode___38 *);
	void (*dirty_inode)(struct inode___38 *, int);
	int (*write_inode)(struct inode___38 *, struct writeback_control *);
	int (*drop_inode)(struct inode___38 *);
	void (*evict_inode)(struct inode___38 *);
	void (*put_super)(struct super_block___38 *);
	int (*sync_fs)(struct super_block___38 *, int);
	int (*freeze_fs)(struct super_block___38 *);
	int (*unfreeze_fs)(struct super_block___38 *);
	int (*statfs)(struct dentry___38 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___38 *, int *, char *);
	void (*umount_begin)(struct super_block___38 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___38 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___38 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___38 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___38 *);
	ssize_t (*quota_read)(struct super_block___38 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___38 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___38 *);
	int (*bdev_try_to_free_page)(struct super_block___38 *, struct page___37 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___38 *);
	void (*free_cached_objects)(struct super_block___38 *, int);
};

struct xattr_handler___17 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___38 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___38 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___38 *, const char *, const void *, size_t, int, int);
};

struct signal_struct___37 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___38 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___38 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___17 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___17 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___38 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___17 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___17 *subsys[11];
	struct callback_head callback_head;
};

typedef __u64 Elf64_Off;

typedef __s64 Elf64_Sxword;

struct elf64_rela {
	Elf64_Addr r_offset;
	Elf64_Xword r_info;
	Elf64_Sxword r_addend;
};

typedef struct elf64_rela Elf64_Rela;

struct elf64_hdr {
	unsigned char e_ident[16];
	Elf64_Half e_type;
	Elf64_Half e_machine;
	Elf64_Word e_version;
	Elf64_Addr e_entry;
	Elf64_Off e_phoff;
	Elf64_Off e_shoff;
	Elf64_Word e_flags;
	Elf64_Half e_ehsize;
	Elf64_Half e_phentsize;
	Elf64_Half e_phnum;
	Elf64_Half e_shentsize;
	Elf64_Half e_shnum;
	Elf64_Half e_shstrndx;
};

typedef struct elf64_hdr Elf64_Ehdr;

struct elf64_shdr {
	Elf64_Word sh_name;
	Elf64_Word sh_type;
	Elf64_Xword sh_flags;
	Elf64_Addr sh_addr;
	Elf64_Off sh_offset;
	Elf64_Xword sh_size;
	Elf64_Word sh_link;
	Elf64_Word sh_info;
	Elf64_Xword sh_addralign;
	Elf64_Xword sh_entsize;
};

typedef struct elf64_shdr Elf64_Shdr;

struct module_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___23 *, struct module_kobject___23 *, char *);
	ssize_t (*store)(struct module_attribute___23 *, struct module_kobject___23 *, const char *, size_t);
	void (*setup)(struct module___24 *, const char *);
	int (*test)(struct module___24 *);
	void (*free)(struct module___24 *);
};

struct kimage_arch {
	pud_t *pud;
	pmd_t *pmd;
	pte_t *pte;
	long unsigned int backup_src_start;
	long unsigned int backup_src_sz;
	long unsigned int backup_load_addr;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

typedef long unsigned int kimage_entry_t;

struct kexec_segment {
	union {
		void *buf;
		void *kbuf;
	};
	size_t bufsz;
	long unsigned int mem;
	size_t memsz;
};

struct purgatory_info {
	Elf64_Ehdr *ehdr;
	Elf64_Shdr *sechdrs;
	void *purgatory_buf;
	long unsigned int purgatory_load_addr;
};

struct kexec_file_ops;

struct kimage {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int destination;
	long unsigned int start;
	struct page___37 *control_code_page;
	struct page___37 *swap_page;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	struct kexec_file_ops *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef int kexec_probe_t(const char *, long unsigned int);

typedef void *kexec_load_t(struct kimage *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

typedef int kexec_cleanup_t(void *);

typedef int kexec_verify_sig_t(const char *, long unsigned int);

struct kexec_file_ops {
	kexec_probe_t *probe;
	kexec_load_t *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kmem_cache_cpu___32 {
	void **freelist;
	long unsigned int tid;
	struct page___37 *page;
	struct page___37 *partial;
};

struct memcg_cache_params___32 {
	bool is_root_cache;
	union {
		struct kmem_cache___32 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___32 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___17;

struct cgroup___17 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___17 *parent;
	struct dentry___38 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___17 *subsys[11];
	struct cgroupfs_root___17 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___38 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___17 {
	struct super_block___38 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___17 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___3 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___38 *, struct file___37 *);
	ssize_t (*read)(struct cgroup___17 *, struct cftype___3 *, struct file___37 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___17 *, struct cftype___3 *);
	s64 (*read_s64)(struct cgroup___17 *, struct cftype___3 *);
	int (*read_map)(struct cgroup___17 *, struct cftype___3 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___17 *, struct cftype___3 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___17 *, struct cftype___3 *, struct file___37 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___17 *, struct cftype___3 *, u64);
	int (*write_s64)(struct cgroup___17 *, struct cftype___3 *, s64);
	int (*write_string)(struct cgroup___17 *, struct cftype___3 *, const char *);
	int (*trigger)(struct cgroup___17 *, unsigned int);
	int (*release)(struct inode___38 *, struct file___37 *);
	int (*register_event)(struct cgroup___17 *, struct cftype___3 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___17 *, struct cftype___3 *, struct eventfd_ctx *);
};

struct cftype_set___3 {
	struct list_head node;
	struct cftype___3 *cfts;
};

struct task_and_cgroup___3 {
	struct task_struct___38 *task;
	struct cgroup___17 *cgrp;
	struct css_set___17 *cg;
};

struct cgroup_taskset___3 {
	struct task_and_cgroup___3 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___17 *cur_cgrp;
};

struct cgroup_subsys___3 {
	struct cgroup_subsys_state___17 * (*css_alloc)(struct cgroup___17 *);
	int (*css_online)(struct cgroup___17 *);
	void (*css_offline)(struct cgroup___17 *);
	void (*css_free)(struct cgroup___17 *);
	int (*can_attach)(struct cgroup___17 *, struct cgroup_taskset___3 *);
	void (*cancel_attach)(struct cgroup___17 *, struct cgroup_taskset___3 *);
	void (*attach)(struct cgroup___17 *, struct cgroup_taskset___3 *);
	void (*fork)(struct task_struct___38 *);
	void (*exit)(struct cgroup___17 *, struct cgroup___17 *, struct task_struct___38 *);
	void (*bind)(struct cgroup___17 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___17 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___3 *base_cftypes;
	struct cftype_set___3 base_cftset;
	struct module___24 *module;
};

struct x86_mapping_info {
	void * (*alloc_pgt_page)(void *);
	void *context;
	long unsigned int pmd_flag;
	bool kernel_mapping;
};

struct tlb_state___10 {
	struct mm_struct___40 *active_mm;
	int state;
};

struct elf64_phdr {
	Elf64_Word p_type;
	Elf64_Word p_flags;
	Elf64_Off p_offset;
	Elf64_Addr p_vaddr;
	Elf64_Addr p_paddr;
	Elf64_Xword p_filesz;
	Elf64_Xword p_memsz;
	Elf64_Xword p_align;
};

typedef struct elf64_phdr Elf64_Phdr;

typedef void crash_vmclear_fn();

struct kexec_file_ops___2;

struct kimage___2 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int destination;
	long unsigned int start;
	struct page___34 *control_code_page;
	struct page___34 *swap_page;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	struct kexec_file_ops___2 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef void *kexec_load_t___2(struct kimage___2 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___2 {
	kexec_probe_t *probe;
	kexec_load_t___2 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

typedef u32 note_buf_t[92];

struct crash_mem_range {
	u64 start;
	u64 end;
};

struct crash_mem {
	unsigned int nr_ranges;
	struct crash_mem_range ranges[16];
};

struct crash_elf_data {
	struct kimage___2 *image;
	unsigned int max_nr_ranges;
	long unsigned int gart_start;
	long unsigned int gart_end;
	void *ehdr;
	void *bufp;
	struct crash_mem mem;
};

struct crash_memmap_data {
	struct boot_params *params;
	unsigned int type;
};

struct kexec_entry64_regs {
	uint64_t rax;
	uint64_t rcx;
	uint64_t rdx;
	uint64_t rbx;
	uint64_t rsp;
	uint64_t rbp;
	uint64_t rsi;
	uint64_t rdi;
	uint64_t r8;
	uint64_t r9;
	uint64_t r10;
	uint64_t r11;
	uint64_t r12;
	uint64_t r13;
	uint64_t r14;
	uint64_t r15;
	uint64_t rip;
};

struct kexec_file_ops___3;

struct kimage___3 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int destination;
	long unsigned int start;
	struct page___3 *control_code_page;
	struct page___3 *swap_page;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	struct kexec_file_ops___3 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef void *kexec_load_t___3(struct kimage___3 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___3 {
	kexec_probe_t *probe;
	kexec_load_t___3 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct efi_setup_data {
	u64 fw_vendor;
	u64 runtime;
	u64 tables;
	u64 smbios;
	u64 reserved[8];
};

struct bzimage64_data {
	void *bootparams_buf;
};

struct kretprobe_instance;

typedef int (*kretprobe_handler_t)(struct kretprobe_instance *, struct pt_regs *);

struct kretprobe;

struct kretprobe_instance {
	struct hlist_node hlist;
	struct kretprobe *rp;
	kprobe_opcode_t *ret_addr;
	struct task_struct___5 *task;
	char data[0];
};

struct jprobe {
	struct kprobe kp;
	void *entry;
};

struct kretprobe {
	struct kprobe kp;
	kretprobe_handler_t handler;
	kretprobe_handler_t entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct hlist_head free_instances;
	raw_spinlock_t lock;
};

struct kretprobe_blackpoint {
	const char *name;
	void *addr;
};

struct __arch_relative_insn {
	u8 op;
	s32 raddr;
} __attribute__((packed));

struct arch_optimized_insn {
	kprobe_opcode_t copied_insn[4];
	kprobe_opcode_t *insn;
	size_t size;
};

struct optimized_kprobe {
	struct kprobe kp;
	struct list_head list;
	struct arch_optimized_insn optinsn;
};

struct jump_poke_buffer {
	u8 buf[5];
};

enum regnames {
	GDB_AX = 0,
	GDB_BX = 1,
	GDB_CX = 2,
	GDB_DX = 3,
	GDB_SI = 4,
	GDB_DI = 5,
	GDB_BP = 6,
	GDB_SP = 7,
	GDB_R8 = 8,
	GDB_R9 = 9,
	GDB_R10 = 10,
	GDB_R11 = 11,
	GDB_R12 = 12,
	GDB_R13 = 13,
	GDB_R14 = 14,
	GDB_R15 = 15,
	GDB_PC = 16,
	GDB_PS = 17,
	GDB_CS = 18,
	GDB_SS = 19,
	GDB_DS = 20,
	GDB_ES = 21,
	GDB_FS = 22,
	GDB_GS = 23,
};

enum kgdb_bpstate {
	BP_UNDEFINED = 0,
	BP_REMOVED = 1,
	BP_SET = 2,
	BP_ACTIVE = 3,
};

struct kgdb_bkpt {
	long unsigned int bpt_addr;
	unsigned char saved_instr[1];
	enum kgdb_bptype type;
	enum kgdb_bpstate state;
};

struct dbg_reg_def_t {
	char *name;
	int size;
	int offset;
};

struct hw_breakpoint {
	unsigned int enabled;
	long unsigned int addr;
	int len;
	int type;
	struct perf_event___5 **pev;
};

struct tty_driver___3;

struct console {
	char name[16];
	void (*write)(struct console *, const char *, unsigned int);
	int (*read)(struct console *, char *, unsigned int);
	struct tty_driver___3 * (*device)(struct console *, int *);
	void (*unblank)();
	int (*setup)(struct console *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console *next;
};

struct page___38;

typedef struct page___38 *pgtable_t___38;

struct address_space___38;

struct page___38 {
	long unsigned int flags;
	struct address_space___38 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___38 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___38 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___38 *first_page;
	};
	long: 64;
};

struct mm_struct___41;

struct pv_mmu_ops___41 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___41 *, struct mm_struct___41 *);
	void (*dup_mmap)(struct mm_struct___41 *, struct mm_struct___41 *);
	void (*exit_mmap)(struct mm_struct___41 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___41 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___41 *);
	void (*pgd_free)(struct mm_struct___41 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___41 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___41 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___41 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___41 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___41 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___41 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___41 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___41 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___41 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___41 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___41 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct xol_area___38;

struct uprobes_state___38 {
	struct xol_area___38 *xol_area;
};

struct vm_area_struct___41;

struct file___38;

struct mm_struct___41 {
	struct vm_area_struct___41 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___41 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___41 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___11 context;
	long unsigned int flags;
	struct core_state___10 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file___38 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___38 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___38 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___38 *page;
	long unsigned int vaddr;
};

struct inode___39;

struct address_space_operations___38;

struct address_space___38 {
	struct inode___39 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___11 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___38 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___39;

struct path___38 {
	struct vfsmount *mnt;
	struct dentry___39 *dentry;
};

struct file_operations___38;

struct file___38 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___38 f_path;
	struct inode___39 *f_inode;
	const struct file_operations___38 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___38 *f_mapping;
	struct mutex___11 f_pos_lock;
};

struct vm_area_struct___41 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___41 *vm_next;
	struct vm_area_struct___41 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___41 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___38 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___38;

struct super_block___39;

struct dentry___39 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___39 *d_parent;
	struct qstr d_name;
	struct inode___39 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___38 *d_op;
	struct super_block___39 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___38;

struct file_lock___38;

struct dquot___38;

struct block_device___38;

struct cdev___17;

struct inode___39 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___38 *i_op;
	struct super_block___39 *i_sb;
	struct address_space___38 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___11 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___38 *i_fop;
	struct file_lock___38 *i_flock;
	struct address_space___38 i_data;
	struct dquot___38 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___38 *i_bdev;
		struct cdev___17 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___38 {
	int (*d_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_hash)(const struct dentry___39 *, struct qstr *);
	int (*d_compare)(const struct dentry___39 *, const struct dentry___39 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___39 *);
	void (*d_release)(struct dentry___39 *);
	void (*d_prune)(struct dentry___39 *);
	void (*d_iput)(struct dentry___39 *, struct inode___39 *);
	char * (*d_dname)(struct dentry___39 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___38 *);
	int (*d_manage)(struct dentry___39 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___38;

struct mem_dqinfo___38 {
	struct quota_format_type___38 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___38;

struct quota_info___38 {
	unsigned int flags;
	struct mutex___11 dqio_mutex;
	struct mutex___11 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___39 *files[2];
	struct mem_dqinfo___38 info[2];
	const struct quota_format_ops___38 *ops[2];
};

struct file_system_type___38;

struct super_operations___38;

struct dquot_operations___38;

struct quotactl_ops___38;

struct super_block___39 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___38 *s_type;
	const struct super_operations___38 *s_op;
	const struct dquot_operations___38 *dq_op;
	const struct quotactl_ops___38 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___39 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___38 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___38 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___11 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___38 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___38 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___39 *bd_inode;
	struct super_block___39 *bd_super;
	struct mutex___11 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___38 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___11 bd_fsfreeze_mutex;
};

struct iattr___39 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___38 *ia_file;
};

struct dquot___38 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___11 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___39 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___38 {
	int qf_fmt_id;
	const struct quota_format_ops___38 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___38 *qf_next;
};

struct quota_format_ops___38 {
	int (*check_quota_file)(struct super_block___39 *, int);
	int (*read_file_info)(struct super_block___39 *, int);
	int (*write_file_info)(struct super_block___39 *, int);
	int (*free_file_info)(struct super_block___39 *, int);
	int (*read_dqblk)(struct dquot___38 *);
	int (*commit_dqblk)(struct dquot___38 *);
	int (*release_dqblk)(struct dquot___38 *);
};

struct dquot_operations___38 {
	int (*write_dquot)(struct dquot___38 *);
	struct dquot___38 * (*alloc_dquot)(struct super_block___39 *, int);
	void (*destroy_dquot)(struct dquot___38 *);
	int (*acquire_dquot)(struct dquot___38 *);
	int (*release_dquot)(struct dquot___38 *);
	int (*mark_dirty)(struct dquot___38 *);
	int (*write_info)(struct super_block___39 *, int);
	qsize_t * (*get_reserved_space)(struct inode___39 *);
};

struct quotactl_ops___38 {
	int (*quota_on)(struct super_block___39 *, int, int, struct path___38 *);
	int (*quota_on_meta)(struct super_block___39 *, int, int);
	int (*quota_off)(struct super_block___39 *, int);
	int (*quota_sync)(struct super_block___39 *, int);
	int (*get_info)(struct super_block___39 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___39 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___39 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___39 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___39 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___39 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___39 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___39 *, unsigned int);
};

struct address_space_operations___38 {
	int (*writepage)(struct page___38 *, struct writeback_control *);
	int (*readpage)(struct file___38 *, struct page___38 *);
	int (*writepages)(struct address_space___38 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___38 *);
	int (*readpages)(struct file___38 *, struct address_space___38 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___38 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___38 **, void **);
	int (*write_end)(struct file___38 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___38 *, void *);
	sector_t (*bmap)(struct address_space___38 *, sector_t);
	void (*invalidatepage)(struct page___38 *, long unsigned int);
	int (*releasepage)(struct page___38 *, gfp_t);
	void (*freepage)(struct page___38 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___38 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___38 *, struct page___38 *, struct page___38 *, enum migrate_mode);
	int (*launder_page)(struct page___38 *);
	int (*is_partially_uptodate)(struct page___38 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___38 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___38 *, struct page___38 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___38 *, sector_t *);
	void (*swap_deactivate)(struct file___38 *);
	void (*invalidatepage_range)(struct page___38 *, unsigned int, unsigned int);
};

struct cdev___17 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___38 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___38 {
	struct dentry___39 * (*lookup)(struct inode___39 *, struct dentry___39 *, unsigned int);
	void * (*follow_link)(struct dentry___39 *, struct nameidata *);
	int (*permission)(struct inode___39 *, int);
	struct posix_acl * (*get_acl)(struct inode___39 *, int);
	int (*readlink)(struct dentry___39 *, char *, int);
	void (*put_link)(struct dentry___39 *, struct nameidata *, void *);
	int (*create)(struct inode___39 *, struct dentry___39 *, umode_t, bool);
	int (*link)(struct dentry___39 *, struct inode___39 *, struct dentry___39 *);
	int (*unlink)(struct inode___39 *, struct dentry___39 *);
	int (*symlink)(struct inode___39 *, struct dentry___39 *, const char *);
	int (*mkdir)(struct inode___39 *, struct dentry___39 *, umode_t);
	int (*rmdir)(struct inode___39 *, struct dentry___39 *);
	int (*mknod)(struct inode___39 *, struct dentry___39 *, umode_t, dev_t);
	int (*rename)(struct inode___39 *, struct dentry___39 *, struct inode___39 *, struct dentry___39 *);
	int (*setattr)(struct dentry___39 *, struct iattr___39 *);
	int (*getattr)(struct vfsmount *, struct dentry___39 *, struct kstat *);
	int (*setxattr)(struct dentry___39 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___39 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___39 *, char *, size_t);
	int (*removexattr)(struct dentry___39 *, const char *);
	int (*fiemap)(struct inode___39 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___39 *, struct timespec *, int);
	int (*atomic_open)(struct inode___39 *, struct dentry___39 *, struct file___38 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___22;

struct file_operations___38 {
	struct module *owner;
	loff_t (*llseek)(struct file___38 *, loff_t, int);
	ssize_t (*read)(struct file___38 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___38 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___38 *, void *, filldir_t);
	unsigned int (*poll)(struct file___38 *, struct poll_table_struct___22 *);
	long int (*unlocked_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___38 *, struct vm_area_struct___41 *);
	int (*open)(struct inode___39 *, struct file___38 *);
	int (*flush)(struct file___38 *, fl_owner_t);
	int (*release)(struct inode___39 *, struct file___38 *);
	int (*fsync)(struct file___38 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___38 *, int);
	int (*lock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*sendpage)(struct file___38 *, struct page___38 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___38 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___38 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___38 *, long int, struct file_lock___38 **, void **);
		struct {
			int (*setlease)(struct file___38 *, long int, struct file_lock___38 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___38 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___8 *, struct file___38 *);
};

struct fasync_struct___38;

struct file_lock_operations___38;

struct lock_manager_operations___38;

struct file_lock___38 {
	struct file_lock___38 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___38 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___38 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___38 *fl_ops;
	const struct lock_manager_operations___38 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___38 {
	void (*fl_copy_lock)(struct file_lock___38 *, struct file_lock___38 *);
	void (*fl_release_private)(struct file_lock___38 *);
};

struct lock_manager_operations___38 {
	int (*lm_compare_owner)(struct file_lock___38 *, struct file_lock___38 *);
	long unsigned int (*lm_owner_key)(struct file_lock___38 *);
	void (*lm_notify)(struct file_lock___38 *);
	int (*lm_grant)(struct file_lock___38 *, struct file_lock___38 *, int);
	void (*lm_break)(struct file_lock___38 *);
	int (*lm_change)(struct file_lock___38 **, int);
};

struct fasync_struct___38 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___38 *fa_next;
	struct file___38 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___38 {
	const char *name;
	int fs_flags;
	struct dentry___39 * (*mount)(struct file_system_type___38 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___39 *);
	struct module *owner;
	struct file_system_type___38 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___38 {
	struct inode___39 * (*alloc_inode)(struct super_block___39 *);
	void (*destroy_inode)(struct inode___39 *);
	void (*dirty_inode)(struct inode___39 *, int);
	int (*write_inode)(struct inode___39 *, struct writeback_control *);
	int (*drop_inode)(struct inode___39 *);
	void (*evict_inode)(struct inode___39 *);
	void (*put_super)(struct super_block___39 *);
	int (*sync_fs)(struct super_block___39 *, int);
	int (*freeze_fs)(struct super_block___39 *);
	int (*unfreeze_fs)(struct super_block___39 *);
	int (*statfs)(struct dentry___39 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___39 *, int *, char *);
	void (*umount_begin)(struct super_block___39 *);
	int (*show_options)(struct seq_file___8 *, struct dentry___39 *);
	int (*show_devname)(struct seq_file___8 *, struct dentry___39 *);
	int (*show_path)(struct seq_file___8 *, struct dentry___39 *);
	int (*show_stats)(struct seq_file___8 *, struct dentry___39 *);
	ssize_t (*quota_read)(struct super_block___39 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___39 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___39 *);
	int (*bdev_try_to_free_page)(struct super_block___39 *, struct page___38 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___39 *);
	void (*free_cached_objects)(struct super_block___39 *, int);
};

typedef void (*poll_queue_proc___22)(struct file___38 *, wait_queue_head_t *, struct poll_table_struct___22 *);

struct poll_table_struct___22 {
	poll_queue_proc___22 _qproc;
	long unsigned int _key;
};

struct hpet_timer {
	u64 hpet_config;
	union {
		u64 _hpet_hc64;
		u32 _hpet_hc32;
		long unsigned int _hpet_compare;
	} _u1;
	u64 hpet_fsb[2];
};

struct hpet {
	u64 hpet_cap;
	u64 res0;
	u64 hpet_config;
	u64 res1;
	u64 hpet_isr;
	u64 res2[25];
	union {
		u64 _hpet_mc64;
		u32 _hpet_mc32;
		long unsigned int _hpet_mc;
	} _u0;
	u64 res3;
	struct hpet_timer hpet_timers[1];
};

struct hpet_data {
	long unsigned int hd_phys_address;
	void *hd_address;
	short unsigned int hd_nirqs;
	unsigned int hd_state;
	unsigned int hd_irq[32];
};

typedef irqreturn_t (*rtc_irq_handler)(int, void *);

struct hpet_dev___2 {
	struct clock_event_device evt;
	unsigned int num;
	int cpu;
	unsigned int irq;
	unsigned int flags;
	char name[10];
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hpet_work_struct {
	struct delayed_work work;
	struct completion complete;
};

struct amd_nb_bus_dev_range {
	u8 bus;
	u8 dev_base;
	u8 dev_limit;
};

struct exec_domain___9 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___8 *module;
	struct exec_domain___9 *next;
};

struct thread_info___14 {
	struct task_struct___16 *task;
	struct exec_domain___9 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct __wait_queue;

typedef struct __wait_queue wait_queue_t;

typedef int (*wait_queue_func_t)(wait_queue_t *, unsigned int, int, void *);

struct __wait_queue {
	unsigned int flags;
	void *private;
	wait_queue_func_t func;
	struct list_head task_list;
};

struct kvm_steal_time {
	__u64 steal;
	__u32 version;
	__u32 flags;
	__u32 pad[12];
};

struct kvm_vcpu_pv_apf_data {
	__u32 reason;
	__u8 pad[60];
	__u32 enabled;
};

struct kprobe_insn_cache___9 {
	struct mutex___16 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct kvm_task_sleep_node {
	struct hlist_node link;
	wait_queue_head_t wq;
	u32 token;
	int cpu;
	bool halted;
};

struct kvm_task_sleep_head {
	spinlock_t lock;
	struct hlist_head list;
};

enum kvm_contention_stat {
	TAKEN_SLOW___2 = 0,
	TAKEN_SLOW_PICKUP___2 = 1,
	RELEASED_SLOW___2 = 2,
	RELEASED_SLOW_KICKED___2 = 3,
	NR_CONTENTION_STATS___2 = 4,
};

struct kvm_lock_waiting {
	struct arch_spinlock *lock;
	__ticket_t want;
};

struct pvclock_vsyscall_time_info {
	struct pvclock_vcpu_time_info pvti;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct ldttss_desc64 ldt_desc;

struct page___39;

typedef struct page___39 *pgtable_t___39;

struct address_space___39;

struct page___39 {
	long unsigned int flags;
	struct address_space___39 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___39 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___39 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___39 *first_page;
	};
	long: 64;
};

struct task_struct___39;

struct pv_cpu_ops___38 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___39 *);
	void (*end_context_switch)(struct task_struct___39 *);
};

struct mutex___39 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___39 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___36 {
	struct page___39 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___42;

struct signal_struct___38;

struct task_struct___39 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___39 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___42 *mm;
	struct mm_struct___42 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___39 *real_parent;
	struct task_struct___39 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___39 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___38 = 0,
		VTIME_USER___38 = 1,
		VTIME_SYS___38 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___38 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___39 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___36 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___42 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___42 *, struct mm_struct___42 *);
	void (*dup_mmap)(struct mm_struct___42 *, struct mm_struct___42 *);
	void (*exit_mmap)(struct mm_struct___42 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___42 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___42 *);
	void (*pgd_free)(struct mm_struct___42 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___42 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___42 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___42 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___42 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___42 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___42 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___42 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___42 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___42 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___42 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___42 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___39 lock;
	void *vdso;
} mm_context_t___39;

struct xol_area___39;

struct uprobes_state___39 {
	struct xol_area___39 *xol_area;
};

struct vm_area_struct___42;

struct file___39;

struct core_state___38;

struct mm_struct___42 {
	struct vm_area_struct___42 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___42 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___42 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___39 context;
	long unsigned int flags;
	struct core_state___38 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___39 *owner;
	struct file___39 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___39 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct paravirt_patch_template {
	struct pv_init_ops pv_init_ops;
	struct pv_time_ops pv_time_ops;
	struct pv_cpu_ops___38 pv_cpu_ops;
	struct pv_irq_ops pv_irq_ops;
	struct pv_apic_ops pv_apic_ops;
	struct pv_mmu_ops___42 pv_mmu_ops;
	struct pv_lock_ops pv_lock_ops;
};

struct module___25;

struct exec_domain___10 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___25 *module;
	struct exec_domain___10 *next;
};

struct module_kobject___24 {
	struct kobject kobj;
	struct module___25 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___24;

struct module___25 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___24 mkobj;
	struct module_attribute___24 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___39 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___15 {
	struct task_struct___39 *task;
	struct exec_domain___10 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___38;

struct lruvec___38 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___38 *zone;
};

struct pglist_data___38;

struct zone___38 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___38 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___38 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___38 {
	struct zone___38 *zone;
	int zone_idx;
};

struct zonelist___38 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___38 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___38 {
	struct zone___38 node_zones[4];
	struct zonelist___38 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___39 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___27;

struct x86_io_apic_ops___27 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___27 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___27;

struct irq_data___27 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___27 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___38 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___39 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dentry___40;

struct path___39 {
	struct vfsmount *mnt;
	struct dentry___40 *dentry;
};

struct inode___40;

struct file_operations___39;

struct file___39 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___39 f_path;
	struct inode___40 *f_inode;
	const struct file_operations___39 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___39 *f_mapping;
	struct mutex___39 f_pos_lock;
};

struct vm_operations_struct___32;

struct vm_area_struct___42 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___42 *vm_next;
	struct vm_area_struct___42 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___42 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___32 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___39 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___24 *, struct module_kobject___24 *, char *);
	ssize_t (*store)(struct module_attribute___24 *, struct module_kobject___24 *, const char *, size_t);
	void (*setup)(struct module___25 *, const char *);
	int (*test)(struct module___25 *);
	void (*free)(struct module___25 *);
};

struct dentry_operations___39;

struct super_block___40;

struct dentry___40 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___40 *d_parent;
	struct qstr d_name;
	struct inode___40 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___39 *d_op;
	struct super_block___40 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___39;

struct address_space___39 {
	struct inode___40 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___39 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___39 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___39;

struct file_lock___39;

struct dquot___39;

struct block_device___39;

struct cdev___18;

struct inode___40 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___39 *i_op;
	struct super_block___40 *i_sb;
	struct address_space___39 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___39 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___39 *i_fop;
	struct file_lock___39 *i_flock;
	struct address_space___39 i_data;
	struct dquot___39 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___39 *i_bdev;
		struct cdev___18 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___39 {
	int (*d_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_hash)(const struct dentry___40 *, struct qstr *);
	int (*d_compare)(const struct dentry___40 *, const struct dentry___40 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___40 *);
	void (*d_release)(struct dentry___40 *);
	void (*d_prune)(struct dentry___40 *);
	void (*d_iput)(struct dentry___40 *, struct inode___40 *);
	char * (*d_dname)(struct dentry___40 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___39 *);
	int (*d_manage)(struct dentry___40 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___39;

struct mem_dqinfo___39 {
	struct quota_format_type___39 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___39;

struct quota_info___39 {
	unsigned int flags;
	struct mutex___39 dqio_mutex;
	struct mutex___39 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___40 *files[2];
	struct mem_dqinfo___39 info[2];
	const struct quota_format_ops___39 *ops[2];
};

struct file_system_type___39;

struct super_operations___39;

struct dquot_operations___39;

struct quotactl_ops___39;

struct super_block___40 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___39 *s_type;
	const struct super_operations___39 *s_op;
	const struct dquot_operations___39 *dq_op;
	const struct quotactl_ops___39 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___40 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___39 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___39 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___39 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___39 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___39 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___40 *bd_inode;
	struct super_block___40 *bd_super;
	struct mutex___39 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___39 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___39 bd_fsfreeze_mutex;
};

struct iattr___40 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___39 *ia_file;
};

struct dquot___39 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___39 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___40 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___39 {
	int qf_fmt_id;
	const struct quota_format_ops___39 *qf_ops;
	struct module___25 *qf_owner;
	struct quota_format_type___39 *qf_next;
};

struct quota_format_ops___39 {
	int (*check_quota_file)(struct super_block___40 *, int);
	int (*read_file_info)(struct super_block___40 *, int);
	int (*write_file_info)(struct super_block___40 *, int);
	int (*free_file_info)(struct super_block___40 *, int);
	int (*read_dqblk)(struct dquot___39 *);
	int (*commit_dqblk)(struct dquot___39 *);
	int (*release_dqblk)(struct dquot___39 *);
};

struct dquot_operations___39 {
	int (*write_dquot)(struct dquot___39 *);
	struct dquot___39 * (*alloc_dquot)(struct super_block___40 *, int);
	void (*destroy_dquot)(struct dquot___39 *);
	int (*acquire_dquot)(struct dquot___39 *);
	int (*release_dquot)(struct dquot___39 *);
	int (*mark_dirty)(struct dquot___39 *);
	int (*write_info)(struct super_block___40 *, int);
	qsize_t * (*get_reserved_space)(struct inode___40 *);
};

struct quotactl_ops___39 {
	int (*quota_on)(struct super_block___40 *, int, int, struct path___39 *);
	int (*quota_on_meta)(struct super_block___40 *, int, int);
	int (*quota_off)(struct super_block___40 *, int);
	int (*quota_sync)(struct super_block___40 *, int);
	int (*get_info)(struct super_block___40 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___40 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___40 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___40 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___40 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___40 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___40 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___40 *, unsigned int);
};

struct address_space_operations___39 {
	int (*writepage)(struct page___39 *, struct writeback_control *);
	int (*readpage)(struct file___39 *, struct page___39 *);
	int (*writepages)(struct address_space___39 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___39 *);
	int (*readpages)(struct file___39 *, struct address_space___39 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___39 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___39 **, void **);
	int (*write_end)(struct file___39 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___39 *, void *);
	sector_t (*bmap)(struct address_space___39 *, sector_t);
	void (*invalidatepage)(struct page___39 *, long unsigned int);
	int (*releasepage)(struct page___39 *, gfp_t);
	void (*freepage)(struct page___39 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___39 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___39 *, struct page___39 *, struct page___39 *, enum migrate_mode);
	int (*launder_page)(struct page___39 *);
	int (*is_partially_uptodate)(struct page___39 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___39 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___39 *, struct page___39 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___39 *, sector_t *);
	void (*swap_deactivate)(struct file___39 *);
	void (*invalidatepage_range)(struct page___39 *, unsigned int, unsigned int);
};

struct cdev___18 {
	struct kobject kobj;
	struct module___25 *owner;
	const struct file_operations___39 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___39 {
	struct dentry___40 * (*lookup)(struct inode___40 *, struct dentry___40 *, unsigned int);
	void * (*follow_link)(struct dentry___40 *, struct nameidata *);
	int (*permission)(struct inode___40 *, int);
	struct posix_acl * (*get_acl)(struct inode___40 *, int);
	int (*readlink)(struct dentry___40 *, char *, int);
	void (*put_link)(struct dentry___40 *, struct nameidata *, void *);
	int (*create)(struct inode___40 *, struct dentry___40 *, umode_t, bool);
	int (*link)(struct dentry___40 *, struct inode___40 *, struct dentry___40 *);
	int (*unlink)(struct inode___40 *, struct dentry___40 *);
	int (*symlink)(struct inode___40 *, struct dentry___40 *, const char *);
	int (*mkdir)(struct inode___40 *, struct dentry___40 *, umode_t);
	int (*rmdir)(struct inode___40 *, struct dentry___40 *);
	int (*mknod)(struct inode___40 *, struct dentry___40 *, umode_t, dev_t);
	int (*rename)(struct inode___40 *, struct dentry___40 *, struct inode___40 *, struct dentry___40 *);
	int (*setattr)(struct dentry___40 *, struct iattr___40 *);
	int (*getattr)(struct vfsmount *, struct dentry___40 *, struct kstat *);
	int (*setxattr)(struct dentry___40 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___40 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___40 *, char *, size_t);
	int (*removexattr)(struct dentry___40 *, const char *);
	int (*fiemap)(struct inode___40 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___40 *, struct timespec *, int);
	int (*atomic_open)(struct inode___40 *, struct dentry___40 *, struct file___39 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___23;

struct seq_file___26;

struct file_operations___39 {
	struct module___25 *owner;
	loff_t (*llseek)(struct file___39 *, loff_t, int);
	ssize_t (*read)(struct file___39 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___39 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___39 *, void *, filldir_t);
	unsigned int (*poll)(struct file___39 *, struct poll_table_struct___23 *);
	long int (*unlocked_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___39 *, struct vm_area_struct___42 *);
	int (*open)(struct inode___40 *, struct file___39 *);
	int (*flush)(struct file___39 *, fl_owner_t);
	int (*release)(struct inode___40 *, struct file___39 *);
	int (*fsync)(struct file___39 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___39 *, int);
	int (*lock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*sendpage)(struct file___39 *, struct page___39 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___39 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___39 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___39 *, long int, struct file_lock___39 **, void **);
		struct {
			int (*setlease)(struct file___39 *, long int, struct file_lock___39 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___39 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___26 *, struct file___39 *);
};

struct fasync_struct___39;

struct file_lock_operations___39;

struct lock_manager_operations___39;

struct file_lock___39 {
	struct file_lock___39 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___39 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___39 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___39 *fl_ops;
	const struct lock_manager_operations___39 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___39 {
	void (*fl_copy_lock)(struct file_lock___39 *, struct file_lock___39 *);
	void (*fl_release_private)(struct file_lock___39 *);
};

struct lock_manager_operations___39 {
	int (*lm_compare_owner)(struct file_lock___39 *, struct file_lock___39 *);
	long unsigned int (*lm_owner_key)(struct file_lock___39 *);
	void (*lm_notify)(struct file_lock___39 *);
	int (*lm_grant)(struct file_lock___39 *, struct file_lock___39 *, int);
	void (*lm_break)(struct file_lock___39 *);
	int (*lm_change)(struct file_lock___39 **, int);
};

struct fasync_struct___39 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___39 *fa_next;
	struct file___39 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___39 {
	const char *name;
	int fs_flags;
	struct dentry___40 * (*mount)(struct file_system_type___39 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___40 *);
	struct module___25 *owner;
	struct file_system_type___39 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___39 {
	struct inode___40 * (*alloc_inode)(struct super_block___40 *);
	void (*destroy_inode)(struct inode___40 *);
	void (*dirty_inode)(struct inode___40 *, int);
	int (*write_inode)(struct inode___40 *, struct writeback_control *);
	int (*drop_inode)(struct inode___40 *);
	void (*evict_inode)(struct inode___40 *);
	void (*put_super)(struct super_block___40 *);
	int (*sync_fs)(struct super_block___40 *, int);
	int (*freeze_fs)(struct super_block___40 *);
	int (*unfreeze_fs)(struct super_block___40 *);
	int (*statfs)(struct dentry___40 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___40 *, int *, char *);
	void (*umount_begin)(struct super_block___40 *);
	int (*show_options)(struct seq_file___26 *, struct dentry___40 *);
	int (*show_devname)(struct seq_file___26 *, struct dentry___40 *);
	int (*show_path)(struct seq_file___26 *, struct dentry___40 *);
	int (*show_stats)(struct seq_file___26 *, struct dentry___40 *);
	ssize_t (*quota_read)(struct super_block___40 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___40 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___40 *);
	int (*bdev_try_to_free_page)(struct super_block___40 *, struct page___39 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___40 *);
	void (*free_cached_objects)(struct super_block___40 *, int);
};

typedef void (*poll_queue_proc___23)(struct file___39 *, wait_queue_head_t *, struct poll_table_struct___23 *);

struct poll_table_struct___23 {
	poll_queue_proc___23 _qproc;
	long unsigned int _key;
};

struct seq_operations___26;

struct seq_file___26 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___39 lock;
	const struct seq_operations___26 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___27 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___27 *);
	void (*irq_shutdown)(struct irq_data___27 *);
	void (*irq_enable)(struct irq_data___27 *);
	void (*irq_disable)(struct irq_data___27 *);
	void (*irq_ack)(struct irq_data___27 *);
	void (*irq_mask)(struct irq_data___27 *);
	void (*irq_mask_ack)(struct irq_data___27 *);
	void (*irq_unmask)(struct irq_data___27 *);
	void (*irq_eoi)(struct irq_data___27 *);
	int (*irq_set_affinity)(struct irq_data___27 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___27 *);
	int (*irq_set_type)(struct irq_data___27 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___27 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___27 *);
	void (*irq_bus_sync_unlock)(struct irq_data___27 *);
	void (*irq_cpu_online)(struct irq_data___27 *);
	void (*irq_cpu_offline)(struct irq_data___27 *);
	void (*irq_suspend)(struct irq_data___27 *);
	void (*irq_resume)(struct irq_data___27 *);
	void (*irq_pm_shutdown)(struct irq_data___27 *);
	void (*irq_print_chip)(struct irq_data___27 *, struct seq_file___26 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___27 *, void *);
	long unsigned int flags;
};

struct seq_operations___26 {
	void * (*start)(struct seq_file___26 *, loff_t *);
	void (*stop)(struct seq_file___26 *, void *);
	void * (*next)(struct seq_file___26 *, void *, loff_t *);
	int (*show)(struct seq_file___26 *, void *);
};

struct xol_area___39 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___39 *page;
	long unsigned int vaddr;
};

struct vm_fault___30;

struct vm_operations_struct___32 {
	void (*open)(struct vm_area_struct___42 *);
	void (*close)(struct vm_area_struct___42 *);
	int (*fault)(struct vm_area_struct___42 *, struct vm_fault___30 *);
	int (*page_mkwrite)(struct vm_area_struct___42 *, struct vm_fault___30 *);
	int (*access)(struct vm_area_struct___42 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___42 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___42 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___42 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___42 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___38 {
	struct task_struct___39 *task;
	struct core_thread___38 *next;
};

struct core_state___38 {
	atomic_t nr_threads;
	struct core_thread___38 dumper;
	struct completion startup;
};

struct vm_fault___30 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___39 *page;
};

struct signal_struct___38 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___39 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___39 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___39 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tlb_state___11 {
	struct mm_struct___42 *active_mm;
	int state;
};

struct branch {
	unsigned char opcode;
	u32 delta;
} __attribute__((packed));

typedef long unsigned int ulong;

struct platform_device_info {
	struct device___6 *parent;
	struct acpi_dev_node___4 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct task_struct___40;

struct pv_cpu_ops___39 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___40 *);
	void (*end_context_switch)(struct task_struct___40 *);
};

struct mutex___40 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___40 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___43;

struct signal_struct___39;

struct task_struct___40 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___40 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___43 *mm;
	struct mm_struct___43 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___40 *real_parent;
	struct task_struct___40 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___40 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___39 = 0,
		VTIME_USER___39 = 1,
		VTIME_SYS___39 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___39 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___40 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___36 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___43 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___43 *, struct mm_struct___43 *);
	void (*dup_mmap)(struct mm_struct___43 *, struct mm_struct___43 *);
	void (*exit_mmap)(struct mm_struct___43 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___43 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___43 *);
	void (*pgd_free)(struct mm_struct___43 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___43 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___43 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___43 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___43 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___43 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___43 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___43 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___43 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___43 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___43 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___43 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___40 lock;
	void *vdso;
} mm_context_t___40;

struct vm_area_struct___43;

struct core_state___39;

struct mm_struct___43 {
	struct vm_area_struct___43 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___43 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___43 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___40 context;
	long unsigned int flags;
	struct core_state___39 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___40 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___39 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___39;

struct lruvec___39 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___39 *zone;
};

struct pglist_data___39;

struct zone___39 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___39 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___39 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___39 {
	struct zone___39 *zone;
	int zone_idx;
};

struct zonelist___39 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___39 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___39 {
	struct zone___39 node_zones[4];
	struct zonelist___39 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___40 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___39 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___40 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vm_operations_struct___33;

struct vm_area_struct___43 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___43 *vm_next;
	struct vm_area_struct___43 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___43 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___33 *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___33 {
	void (*open)(struct vm_area_struct___43 *);
	void (*close)(struct vm_area_struct___43 *);
	int (*fault)(struct vm_area_struct___43 *, struct vm_fault___30 *);
	int (*page_mkwrite)(struct vm_area_struct___43 *, struct vm_fault___30 *);
	int (*access)(struct vm_area_struct___43 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___43 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___43 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___43 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___43 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___39 {
	struct task_struct___40 *task;
	struct core_thread___39 *next;
};

struct core_state___39 {
	atomic_t nr_threads;
	struct core_thread___39 dumper;
	struct completion startup;
};

struct cpio_data {
	void *data;
	size_t size;
	char name[18];
};

struct cpu_signature {
	unsigned int sig;
	unsigned int pf;
	unsigned int rev;
};

enum ucode_state {
	UCODE_ERROR = 0,
	UCODE_OK = 1,
	UCODE_NFOUND = 2,
};

struct ucode_cpu_info {
	struct cpu_signature cpu_sig;
	int valid;
	void *mc;
};

struct microcode_header_intel {
	unsigned int hdrver;
	unsigned int rev;
	unsigned int date;
	unsigned int sig;
	unsigned int cksum;
	unsigned int ldrver;
	unsigned int pf;
	unsigned int datasize;
	unsigned int totalsize;
	unsigned int reserved[3];
};

struct microcode_intel {
	struct microcode_header_intel hdr;
	unsigned int bits[0];
};

struct extended_signature {
	unsigned int sig;
	unsigned int pf;
	unsigned int cksum;
};

struct extended_sigtable {
	unsigned int count;
	unsigned int cksum;
	unsigned int reserved[3];
	struct extended_signature sigs[0];
};

struct signal_struct___39 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___40 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___40 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___40 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tlb_state___12 {
	struct mm_struct___43 *active_mm;
	int state;
};

struct mc_saved_data {
	unsigned int mc_saved_count;
	struct microcode_intel **mc_saved;
};

struct equiv_cpu_entry {
	u32 installed_cpu;
	u32 fixed_errata_mask;
	u32 fixed_errata_compare;
	u16 equiv_cpu;
	u16 res;
};

struct microcode_header_amd {
	u32 data_code;
	u32 patch_id;
	u16 mc_patch_data_id;
	u8 mc_patch_data_len;
	u8 init_flag;
	u32 mc_patch_data_checksum;
	u32 nb_dev_id;
	u32 sb_dev_id;
	u16 processor_rev_id;
	u8 nb_rev_id;
	u8 sb_rev_id;
	u8 bios_api_rev;
	u8 reserved1[3];
	u32 match_reg[8];
};

struct microcode_amd {
	struct microcode_header_amd hdr;
	unsigned int mpb[0];
};

struct page___40;

typedef struct page___40 *pgtable_t___40;

struct address_space___40;

struct page___40 {
	long unsigned int flags;
	struct address_space___40 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___40 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___40 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___40 *first_page;
	};
	long: 64;
};

struct task_struct___41;

struct pv_cpu_ops___40 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___41 *);
	void (*end_context_switch)(struct task_struct___41 *);
};

struct mutex___41 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___41 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___37 {
	struct page___40 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___44;

struct signal_struct___40;

struct task_struct___41 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___41 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___44 *mm;
	struct mm_struct___44 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___41 *real_parent;
	struct task_struct___41 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___41 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___40 = 0,
		VTIME_USER___40 = 1,
		VTIME_SYS___40 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___40 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___41 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___37 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___44 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___44 *, struct mm_struct___44 *);
	void (*dup_mmap)(struct mm_struct___44 *, struct mm_struct___44 *);
	void (*exit_mmap)(struct mm_struct___44 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___44 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___44 *);
	void (*pgd_free)(struct mm_struct___44 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___44 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___44 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___44 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___44 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___44 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___44 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___44 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___44 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___44 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___44 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___44 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___41 lock;
	void *vdso;
} mm_context_t___41;

struct xol_area___40;

struct uprobes_state___40 {
	struct xol_area___40 *xol_area;
};

struct vm_area_struct___44;

struct file___40;

struct core_state___40;

struct mm_struct___44 {
	struct vm_area_struct___44 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___44 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___44 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___41 context;
	long unsigned int flags;
	struct core_state___40 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___41 *owner;
	struct file___40 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___40 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___26;

struct module_kobject___25 {
	struct kobject kobj;
	struct module___26 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___25;

struct module___26 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___25 mkobj;
	struct module_attribute___25 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___41 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct bin_attribute___27;

struct attribute_group___27 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___27 **bin_attrs;
};

struct bin_attribute___27 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___40 *, struct kobject *, struct bin_attribute___27 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___40 *, struct kobject *, struct bin_attribute___27 *, char *, loff_t, size_t);
	int (*mmap)(struct file___40 *, struct kobject *, struct bin_attribute___27 *, struct vm_area_struct___44 *);
};

struct dentry___41;

struct path___40 {
	struct vfsmount *mnt;
	struct dentry___41 *dentry;
};

struct inode___41;

struct file_operations___40;

struct file___40 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___40 f_path;
	struct inode___41 *f_inode;
	const struct file_operations___40 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___40 *f_mapping;
	struct mutex___41 f_pos_lock;
};

struct vm_operations_struct___34;

struct vm_area_struct___44 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___44 *vm_next;
	struct vm_area_struct___44 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___44 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___34 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___40 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___31;

struct dev_pm_ops___31 {
	int (*prepare)(struct device___31 *);
	void (*complete)(struct device___31 *);
	int (*suspend)(struct device___31 *);
	int (*resume)(struct device___31 *);
	int (*freeze)(struct device___31 *);
	int (*thaw)(struct device___31 *);
	int (*poweroff)(struct device___31 *);
	int (*restore)(struct device___31 *);
	int (*suspend_late)(struct device___31 *);
	int (*resume_early)(struct device___31 *);
	int (*freeze_late)(struct device___31 *);
	int (*thaw_early)(struct device___31 *);
	int (*poweroff_late)(struct device___31 *);
	int (*restore_early)(struct device___31 *);
	int (*suspend_noirq)(struct device___31 *);
	int (*resume_noirq)(struct device___31 *);
	int (*freeze_noirq)(struct device___31 *);
	int (*thaw_noirq)(struct device___31 *);
	int (*poweroff_noirq)(struct device___31 *);
	int (*restore_noirq)(struct device___31 *);
	int (*runtime_suspend)(struct device___31 *);
	int (*runtime_resume)(struct device___31 *);
	int (*runtime_idle)(struct device___31 *);
};

struct device_type___31;

struct bus_type___31;

struct device_driver___31;

struct dev_pm_domain___31;

struct class___31;

struct device_rh___31;

struct device___31 {
	struct device___31 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___31 *type;
	struct mutex___41 mutex;
	struct bus_type___31 *bus;
	struct device_driver___31 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___31 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___3 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___31 *class;
	const struct attribute_group___27 **groups;
	void (*release)(struct device___31 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___31 *device_rh;
};

struct dev_pm_info_rh___31 {
	void (*set_latency_tolerance)(struct device___31 *, s32);
};

struct dev_pm_domain___31 {
	struct dev_pm_ops___31 ops;
};

struct zone___40;

struct lruvec___40 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___40 *zone;
};

struct pglist_data___40;

struct zone___40 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___40 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___40 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___40 {
	struct zone___40 *zone;
	int zone_idx;
};

struct zonelist___40 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___40 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___40 {
	struct zone___40 node_zones[4];
	struct zonelist___40 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___41 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___40 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___41 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___31 *, char *);
	ssize_t (*store)(struct bus_type___31 *, const char *, size_t);
};

struct device_attribute___31;

struct driver_attribute___31;

struct bus_type___31 {
	const char *name;
	const char *dev_name;
	struct device___31 *dev_root;
	struct bus_attribute___31 *bus_attrs;
	struct device_attribute___31 *dev_attrs;
	struct driver_attribute___31 *drv_attrs;
	const struct attribute_group___27 **bus_groups;
	const struct attribute_group___27 **dev_groups;
	const struct attribute_group___27 **drv_groups;
	int (*match)(struct device___31 *, struct device_driver___31 *);
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	int (*probe)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*online)(struct device___31 *);
	int (*offline)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct device___31 *, struct device_attribute___31 *, char *);
	ssize_t (*store)(struct device___31 *, struct device_attribute___31 *, const char *, size_t);
};

struct driver_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___31 *, char *);
	ssize_t (*store)(struct device_driver___31 *, const char *, size_t);
};

struct device_driver___31 {
	const char *name;
	struct bus_type___31 *bus;
	struct module___26 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct attribute_group___27 **groups;
	const struct dev_pm_ops___31 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___31 {
	const char *name;
	const struct attribute_group___27 **groups;
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
};

struct subsys_interface {
	const char *name;
	struct bus_type___31 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___31 *, struct subsys_interface *);
	int (*remove_dev)(struct device___31 *, struct subsys_interface *);
};

struct class_attribute___31;

struct class___31 {
	const char *name;
	struct module___26 *owner;
	struct class_attribute___31 *class_attrs;
	struct device_attribute___31 *dev_attrs;
	const struct attribute_group___27 **dev_groups;
	struct bin_attribute___27 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *);
	void (*class_release)(struct class___31 *);
	void (*dev_release)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	struct subsys_private *p;
};

struct class_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct class___31 *, struct class_attribute___31 *, char *);
	ssize_t (*store)(struct class___31 *, struct class_attribute___31 *, const char *, size_t);
	const void * (*namespace)(struct class___31 *, const struct class_attribute___31 *);
};

struct device_rh___31 {
	struct dev_pm_info_rh___31 power;
};

struct platform_device___2 {
	const char *name;
	int id;
	bool id_auto;
	struct device___31 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___2 {
	struct device___31 *parent;
	struct acpi_dev_node___4 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct miscdevice___2 {
	int minor;
	const char *name;
	const struct file_operations___40 *fops;
	struct list_head list;
	struct device___31 *parent;
	struct device___31 *this_device;
	const char *nodename;
	umode_t mode;
};

struct file_lock___40;

struct file_operations___40 {
	struct module___26 *owner;
	loff_t (*llseek)(struct file___40 *, loff_t, int);
	ssize_t (*read)(struct file___40 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___40 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___40 *, void *, filldir_t);
	unsigned int (*poll)(struct file___40 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___40 *, struct vm_area_struct___44 *);
	int (*open)(struct inode___41 *, struct file___40 *);
	int (*flush)(struct file___40 *, fl_owner_t);
	int (*release)(struct inode___41 *, struct file___40 *);
	int (*fsync)(struct file___40 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___40 *, int);
	int (*lock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*sendpage)(struct file___40 *, struct page___40 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___40 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___40 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___40 *, long int, struct file_lock___40 **, void **);
		struct {
			int (*setlease)(struct file___40 *, long int, struct file_lock___40 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___40 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___40 *);
};

struct module_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___25 *, struct module_kobject___25 *, char *);
	ssize_t (*store)(struct module_attribute___25 *, struct module_kobject___25 *, const char *, size_t);
	void (*setup)(struct module___26 *, const char *);
	int (*test)(struct module___26 *);
	void (*free)(struct module___26 *);
};

struct dentry_operations___40;

struct super_block___41;

struct dentry___41 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___41 *d_parent;
	struct qstr d_name;
	struct inode___41 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___40 *d_op;
	struct super_block___41 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___40;

struct address_space___40 {
	struct inode___41 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___41 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___40 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___40;

struct dquot___40;

struct block_device___40;

struct inode___41 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___40 *i_op;
	struct super_block___41 *i_sb;
	struct address_space___40 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___41 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___40 *i_fop;
	struct file_lock___40 *i_flock;
	struct address_space___40 i_data;
	struct dquot___40 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___40 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___40 {
	int (*d_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_hash)(const struct dentry___41 *, struct qstr *);
	int (*d_compare)(const struct dentry___41 *, const struct dentry___41 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___41 *);
	void (*d_release)(struct dentry___41 *);
	void (*d_prune)(struct dentry___41 *);
	void (*d_iput)(struct dentry___41 *, struct inode___41 *);
	char * (*d_dname)(struct dentry___41 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___40 *);
	int (*d_manage)(struct dentry___41 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___40;

struct mem_dqinfo___40 {
	struct quota_format_type___40 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___40;

struct quota_info___40 {
	unsigned int flags;
	struct mutex___41 dqio_mutex;
	struct mutex___41 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___41 *files[2];
	struct mem_dqinfo___40 info[2];
	const struct quota_format_ops___40 *ops[2];
};

struct file_system_type___40;

struct super_operations___40;

struct dquot_operations___40;

struct quotactl_ops___40;

struct super_block___41 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___40 *s_type;
	const struct super_operations___40 *s_op;
	const struct dquot_operations___40 *dq_op;
	const struct quotactl_ops___40 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___41 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___40 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___40 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___41 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___40 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___40 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___41 *bd_inode;
	struct super_block___41 *bd_super;
	struct mutex___41 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___40 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___41 bd_fsfreeze_mutex;
};

struct iattr___41 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___40 *ia_file;
};

struct dquot___40 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___41 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___41 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___40 {
	int qf_fmt_id;
	const struct quota_format_ops___40 *qf_ops;
	struct module___26 *qf_owner;
	struct quota_format_type___40 *qf_next;
};

struct quota_format_ops___40 {
	int (*check_quota_file)(struct super_block___41 *, int);
	int (*read_file_info)(struct super_block___41 *, int);
	int (*write_file_info)(struct super_block___41 *, int);
	int (*free_file_info)(struct super_block___41 *, int);
	int (*read_dqblk)(struct dquot___40 *);
	int (*commit_dqblk)(struct dquot___40 *);
	int (*release_dqblk)(struct dquot___40 *);
};

struct dquot_operations___40 {
	int (*write_dquot)(struct dquot___40 *);
	struct dquot___40 * (*alloc_dquot)(struct super_block___41 *, int);
	void (*destroy_dquot)(struct dquot___40 *);
	int (*acquire_dquot)(struct dquot___40 *);
	int (*release_dquot)(struct dquot___40 *);
	int (*mark_dirty)(struct dquot___40 *);
	int (*write_info)(struct super_block___41 *, int);
	qsize_t * (*get_reserved_space)(struct inode___41 *);
};

struct quotactl_ops___40 {
	int (*quota_on)(struct super_block___41 *, int, int, struct path___40 *);
	int (*quota_on_meta)(struct super_block___41 *, int, int);
	int (*quota_off)(struct super_block___41 *, int);
	int (*quota_sync)(struct super_block___41 *, int);
	int (*get_info)(struct super_block___41 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___41 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___41 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___41 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___41 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___41 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___41 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___41 *, unsigned int);
};

struct address_space_operations___40 {
	int (*writepage)(struct page___40 *, struct writeback_control *);
	int (*readpage)(struct file___40 *, struct page___40 *);
	int (*writepages)(struct address_space___40 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___40 *);
	int (*readpages)(struct file___40 *, struct address_space___40 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___40 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___40 **, void **);
	int (*write_end)(struct file___40 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___40 *, void *);
	sector_t (*bmap)(struct address_space___40 *, sector_t);
	void (*invalidatepage)(struct page___40 *, long unsigned int);
	int (*releasepage)(struct page___40 *, gfp_t);
	void (*freepage)(struct page___40 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___40 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___40 *, struct page___40 *, struct page___40 *, enum migrate_mode);
	int (*launder_page)(struct page___40 *);
	int (*is_partially_uptodate)(struct page___40 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___40 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___40 *, struct page___40 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___40 *, sector_t *);
	void (*swap_deactivate)(struct file___40 *);
	void (*invalidatepage_range)(struct page___40 *, unsigned int, unsigned int);
};

struct inode_operations___40 {
	struct dentry___41 * (*lookup)(struct inode___41 *, struct dentry___41 *, unsigned int);
	void * (*follow_link)(struct dentry___41 *, struct nameidata *);
	int (*permission)(struct inode___41 *, int);
	struct posix_acl * (*get_acl)(struct inode___41 *, int);
	int (*readlink)(struct dentry___41 *, char *, int);
	void (*put_link)(struct dentry___41 *, struct nameidata *, void *);
	int (*create)(struct inode___41 *, struct dentry___41 *, umode_t, bool);
	int (*link)(struct dentry___41 *, struct inode___41 *, struct dentry___41 *);
	int (*unlink)(struct inode___41 *, struct dentry___41 *);
	int (*symlink)(struct inode___41 *, struct dentry___41 *, const char *);
	int (*mkdir)(struct inode___41 *, struct dentry___41 *, umode_t);
	int (*rmdir)(struct inode___41 *, struct dentry___41 *);
	int (*mknod)(struct inode___41 *, struct dentry___41 *, umode_t, dev_t);
	int (*rename)(struct inode___41 *, struct dentry___41 *, struct inode___41 *, struct dentry___41 *);
	int (*setattr)(struct dentry___41 *, struct iattr___41 *);
	int (*getattr)(struct vfsmount *, struct dentry___41 *, struct kstat *);
	int (*setxattr)(struct dentry___41 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___41 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___41 *, char *, size_t);
	int (*removexattr)(struct dentry___41 *, const char *);
	int (*fiemap)(struct inode___41 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___41 *, struct timespec *, int);
	int (*atomic_open)(struct inode___41 *, struct dentry___41 *, struct file___40 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___40;

struct file_lock_operations___40;

struct lock_manager_operations___40;

struct file_lock___40 {
	struct file_lock___40 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___40 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___40 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___40 *fl_ops;
	const struct lock_manager_operations___40 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___40 {
	void (*fl_copy_lock)(struct file_lock___40 *, struct file_lock___40 *);
	void (*fl_release_private)(struct file_lock___40 *);
};

struct lock_manager_operations___40 {
	int (*lm_compare_owner)(struct file_lock___40 *, struct file_lock___40 *);
	long unsigned int (*lm_owner_key)(struct file_lock___40 *);
	void (*lm_notify)(struct file_lock___40 *);
	int (*lm_grant)(struct file_lock___40 *, struct file_lock___40 *, int);
	void (*lm_break)(struct file_lock___40 *);
	int (*lm_change)(struct file_lock___40 **, int);
};

struct fasync_struct___40 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___40 *fa_next;
	struct file___40 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___40 {
	const char *name;
	int fs_flags;
	struct dentry___41 * (*mount)(struct file_system_type___40 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___41 *);
	struct module___26 *owner;
	struct file_system_type___40 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___40 {
	struct inode___41 * (*alloc_inode)(struct super_block___41 *);
	void (*destroy_inode)(struct inode___41 *);
	void (*dirty_inode)(struct inode___41 *, int);
	int (*write_inode)(struct inode___41 *, struct writeback_control *);
	int (*drop_inode)(struct inode___41 *);
	void (*evict_inode)(struct inode___41 *);
	void (*put_super)(struct super_block___41 *);
	int (*sync_fs)(struct super_block___41 *, int);
	int (*freeze_fs)(struct super_block___41 *);
	int (*unfreeze_fs)(struct super_block___41 *);
	int (*statfs)(struct dentry___41 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___41 *, int *, char *);
	void (*umount_begin)(struct super_block___41 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___41 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___41 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___41 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___41 *);
	ssize_t (*quota_read)(struct super_block___41 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___41 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___41 *);
	int (*bdev_try_to_free_page)(struct super_block___41 *, struct page___40 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___41 *);
	void (*free_cached_objects)(struct super_block___41 *, int);
};

struct xol_area___40 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___40 *page;
	long unsigned int vaddr;
};

struct vm_fault___31;

struct vm_operations_struct___34 {
	void (*open)(struct vm_area_struct___44 *);
	void (*close)(struct vm_area_struct___44 *);
	int (*fault)(struct vm_area_struct___44 *, struct vm_fault___31 *);
	int (*page_mkwrite)(struct vm_area_struct___44 *, struct vm_fault___31 *);
	int (*access)(struct vm_area_struct___44 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___44 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___44 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___44 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___44 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___40 {
	struct task_struct___41 *task;
	struct core_thread___40 *next;
};

struct core_state___40 {
	atomic_t nr_threads;
	struct core_thread___40 dumper;
	struct completion startup;
};

struct vm_fault___31 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___40 *page;
};

struct microcode_ops {
	enum ucode_state (*request_microcode_user)(int, const void *, size_t);
	enum ucode_state (*request_microcode_fw)(int, struct device___31 *, bool);
	void (*microcode_fini_cpu)(int);
	int (*apply_microcode)(int);
	int (*collect_cpu_info)(int, struct cpu_signature *);
};

struct signal_struct___40 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___41 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___41 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___41 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cpu_info_ctx {
	struct cpu_signature *cpu_sig;
	int err;
};

struct apply_microcode_ctx {
	int err;
};

struct firmware {
	size_t size;
	const u8 *data;
	struct page___20 **pages;
	void *priv;
};

struct microcode_ops___2 {
	enum ucode_state (*request_microcode_user)(int, const void *, size_t);
	enum ucode_state (*request_microcode_fw)(int, struct device___6 *, bool);
	void (*microcode_fini_cpu)(int);
	int (*apply_microcode)(int);
	int (*collect_cpu_info)(int, struct cpu_signature *);
};

struct ucode_patch {
	struct list_head plist;
	void *data;
	u32 patch_id;
	u16 equiv_cpu;
};

struct scan_area {
	u64 addr;
	u64 size;
};

struct uprobe_xol_ops;

struct arch_uprobe {
	u8 insn[16];
	const struct uprobe_xol_ops *ops;
	union {
		struct {
			s32 offs;
			u8 ilen;
			u8 opc1;
		} branch;
		struct {
			u8 fixups;
			u8 ilen;
		} defparam;
	};
};

struct uprobe_xol_ops {
	bool (*emulate)(struct arch_uprobe *, struct pt_regs *);
	int (*pre_xol)(struct arch_uprobe *, struct pt_regs *);
	int (*post_xol)(struct arch_uprobe *, struct pt_regs *);
	void (*abort)(struct arch_uprobe *, struct pt_regs *);
};

enum rp_check {
	RP_CHECK_CALL = 0,
	RP_CHECK_CHAIN_CALL = 1,
	RP_CHECK_RET = 2,
};

enum perf_sample_regs_abi {
	PERF_SAMPLE_REGS_ABI_NONE = 0,
	PERF_SAMPLE_REGS_ABI_32 = 1,
	PERF_SAMPLE_REGS_ABI_64 = 2,
};

enum perf_event_x86_regs {
	PERF_REG_X86_AX = 0,
	PERF_REG_X86_BX = 1,
	PERF_REG_X86_CX = 2,
	PERF_REG_X86_DX = 3,
	PERF_REG_X86_SI = 4,
	PERF_REG_X86_DI = 5,
	PERF_REG_X86_BP = 6,
	PERF_REG_X86_SP = 7,
	PERF_REG_X86_IP = 8,
	PERF_REG_X86_FLAGS = 9,
	PERF_REG_X86_CS = 10,
	PERF_REG_X86_SS = 11,
	PERF_REG_X86_DS = 12,
	PERF_REG_X86_ES = 13,
	PERF_REG_X86_FS = 14,
	PERF_REG_X86_GS = 15,
	PERF_REG_X86_R8 = 16,
	PERF_REG_X86_R9 = 17,
	PERF_REG_X86_R10 = 18,
	PERF_REG_X86_R11 = 19,
	PERF_REG_X86_R12 = 20,
	PERF_REG_X86_R13 = 21,
	PERF_REG_X86_R14 = 22,
	PERF_REG_X86_R15 = 23,
	PERF_REG_X86_32_MAX = 16,
	PERF_REG_X86_64_MAX = 24,
};

enum chipset_type {
	NOT_SUPPORTED = 0,
	SUPPORTED = 1,
};

struct agp_version {
	u16 major;
	u16 minor;
};

struct agp_kern_info {
	struct agp_version version;
	struct pci_dev___9 *device;
	enum chipset_type chipset;
	long unsigned int mode;
	long unsigned int aper_base;
	size_t aper_size;
	int max_memory;
	int current_memory;
	bool cant_use_aperture;
	long unsigned int page_mask;
	const struct vm_operations_struct___27 *vm_ops;
};

struct agp_bridge_data;

struct amd_northbridge___4 {
	struct pci_dev___9 *misc;
	struct pci_dev___9 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info___4 {
	u16 num;
	u64 flags;
	struct amd_northbridge___4 *nb;
};

struct page___41;

typedef struct page___41 *pgtable_t___41;

struct address_space___41;

struct kmem_cache___33;

struct page___41 {
	long unsigned int flags;
	struct address_space___41 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___41 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___41 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___33 *slab_cache;
		struct page___41 *first_page;
	};
	long: 64;
};

struct task_struct___42;

struct pv_cpu_ops___41 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___42 *);
	void (*end_context_switch)(struct task_struct___42 *);
};

struct mutex___42 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___42 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___38 {
	struct page___41 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___45;

struct signal_struct___41;

struct css_set___18;

struct task_struct___42 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___42 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___45 *mm;
	struct mm_struct___45 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___42 *real_parent;
	struct task_struct___42 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___42 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___41 = 0,
		VTIME_USER___41 = 1,
		VTIME_SYS___41 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___41 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___18 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___42 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___38 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___45 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___45 *, struct mm_struct___45 *);
	void (*dup_mmap)(struct mm_struct___45 *, struct mm_struct___45 *);
	void (*exit_mmap)(struct mm_struct___45 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___45 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___45 *);
	void (*pgd_free)(struct mm_struct___45 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___45 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___45 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___45 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___45 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___45 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___45 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___45 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___45 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___45 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___45 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___45 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___42 lock;
	void *vdso;
} mm_context_t___42;

struct xol_area___41;

struct uprobes_state___41 {
	struct xol_area___41 *xol_area;
};

struct vm_area_struct___45;

struct file___41;

struct core_state___41;

struct mm_struct___45 {
	struct vm_area_struct___45 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___45 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___45 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___42 context;
	long unsigned int flags;
	struct core_state___41 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___42 *owner;
	struct file___41 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___41 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___41;

struct lruvec___41 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___41 *zone;
};

struct pglist_data___41;

struct zone___41 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___41 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___41 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___41 {
	struct zone___41 *zone;
	int zone_idx;
};

struct zonelist___41 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___41 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___41 {
	struct zone___41 node_zones[4];
	struct zonelist___41 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___42 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___15;

struct dev_archdata___15 {
	struct dma_map_ops___15 *dma_ops;
	void *iommu;
};

struct device_type___32;

struct bus_type___32;

struct device_driver___32;

struct dev_pm_domain___32;

struct class___32;

struct attribute_group___28;

struct device_rh___32;

struct device___32 {
	struct device___32 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___32 *type;
	struct mutex___42 mutex;
	struct bus_type___32 *bus;
	struct device_driver___32 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___32 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___15 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___10 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___32 *class;
	const struct attribute_group___28 **groups;
	void (*release)(struct device___32 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___32 *device_rh;
};

struct pci_bus___11;

struct pci_slot___11;

struct pci_driver___11;

struct bin_attribute___28;

struct pci_dev___11 {
	struct list_head bus_list;
	struct pci_bus___11 *bus;
	struct pci_bus___11 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___11 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___11 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___32 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___28 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___28 *res_attr[17];
	struct bin_attribute___28 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___28 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___11 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___32 {
	int (*prepare)(struct device___32 *);
	void (*complete)(struct device___32 *);
	int (*suspend)(struct device___32 *);
	int (*resume)(struct device___32 *);
	int (*freeze)(struct device___32 *);
	int (*thaw)(struct device___32 *);
	int (*poweroff)(struct device___32 *);
	int (*restore)(struct device___32 *);
	int (*suspend_late)(struct device___32 *);
	int (*resume_early)(struct device___32 *);
	int (*freeze_late)(struct device___32 *);
	int (*thaw_early)(struct device___32 *);
	int (*poweroff_late)(struct device___32 *);
	int (*restore_early)(struct device___32 *);
	int (*suspend_noirq)(struct device___32 *);
	int (*resume_noirq)(struct device___32 *);
	int (*freeze_noirq)(struct device___32 *);
	int (*thaw_noirq)(struct device___32 *);
	int (*poweroff_noirq)(struct device___32 *);
	int (*restore_noirq)(struct device___32 *);
	int (*runtime_suspend)(struct device___32 *);
	int (*runtime_resume)(struct device___32 *);
	int (*runtime_idle)(struct device___32 *);
};

struct dev_pm_info_rh___32 {
	void (*set_latency_tolerance)(struct device___32 *, s32);
};

struct dev_pm_domain___32 {
	struct dev_pm_ops___32 ops;
};

struct smp_ops___41 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___42 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___41 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___41 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___33;

struct memcg_cache_params___33;

struct kmem_cache___33 {
	struct kmem_cache_cpu___33 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___33 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___42;

struct address_space_operations___41;

struct address_space___41 {
	struct inode___42 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___42 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___41 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___42;

struct path___41 {
	struct vfsmount *mnt;
	struct dentry___42 *dentry;
};

struct file_operations___41;

struct file___41 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___41 f_path;
	struct inode___42 *f_inode;
	const struct file_operations___41 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___41 *f_mapping;
	struct mutex___42 f_pos_lock;
};

struct vm_operations_struct___35;

struct vm_area_struct___45 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___45 *vm_next;
	struct vm_area_struct___45 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___45 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___35 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___41 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___32;

struct vm_operations_struct___35 {
	void (*open)(struct vm_area_struct___45 *);
	void (*close)(struct vm_area_struct___45 *);
	int (*fault)(struct vm_area_struct___45 *, struct vm_fault___32 *);
	int (*page_mkwrite)(struct vm_area_struct___45 *, struct vm_fault___32 *);
	int (*access)(struct vm_area_struct___45 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___45 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___45 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___45 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___45 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___41 {
	struct task_struct___42 *task;
	struct core_thread___41 *next;
};

struct core_state___41 {
	atomic_t nr_threads;
	struct core_thread___41 dumper;
	struct completion startup;
};

struct vm_fault___32 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___41 *page;
};

struct attribute_group___28 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___28 **bin_attrs;
};

struct bin_attribute___28 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___41 *, struct kobject *, struct bin_attribute___28 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___41 *, struct kobject *, struct bin_attribute___28 *, char *, loff_t, size_t);
	int (*mmap)(struct file___41 *, struct kobject *, struct bin_attribute___28 *, struct vm_area_struct___45 *);
};

struct dma_map_ops___15 {
	void * (*alloc)(struct device___32 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___32 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___32 *, struct vm_area_struct___45 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___32 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___32 *, struct page___41 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___32 *, dma_addr_t);
	int (*dma_supported)(struct device___32 *, u64);
	int (*set_dma_mask)(struct device___32 *, u64);
	int is_phys;
};

struct bus_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___32 *, char *);
	ssize_t (*store)(struct bus_type___32 *, const char *, size_t);
};

struct device_attribute___32;

struct driver_attribute___32;

struct bus_type___32 {
	const char *name;
	const char *dev_name;
	struct device___32 *dev_root;
	struct bus_attribute___32 *bus_attrs;
	struct device_attribute___32 *dev_attrs;
	struct driver_attribute___32 *drv_attrs;
	const struct attribute_group___28 **bus_groups;
	const struct attribute_group___28 **dev_groups;
	const struct attribute_group___28 **drv_groups;
	int (*match)(struct device___32 *, struct device_driver___32 *);
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	int (*probe)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*online)(struct device___32 *);
	int (*offline)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct device___32 *, struct device_attribute___32 *, char *);
	ssize_t (*store)(struct device___32 *, struct device_attribute___32 *, const char *, size_t);
};

struct driver_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___32 *, char *);
	ssize_t (*store)(struct device_driver___32 *, const char *, size_t);
};

struct device_driver___32 {
	const char *name;
	struct bus_type___32 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct attribute_group___28 **groups;
	const struct dev_pm_ops___32 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___32 {
	const char *name;
	const struct attribute_group___28 **groups;
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
};

struct class_attribute___32;

struct class___32 {
	const char *name;
	struct module *owner;
	struct class_attribute___32 *class_attrs;
	struct device_attribute___32 *dev_attrs;
	const struct attribute_group___28 **dev_groups;
	struct bin_attribute___28 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *);
	void (*class_release)(struct class___32 *);
	void (*dev_release)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	struct subsys_private *p;
};

struct class_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct class___32 *, struct class_attribute___32 *, char *);
	ssize_t (*store)(struct class___32 *, struct class_attribute___32 *, const char *, size_t);
	const void * (*namespace)(struct class___32 *, const struct class_attribute___32 *);
};

struct device_rh___32 {
	struct dev_pm_info_rh___32 power;
};

struct pci_slot___11 {
	struct pci_bus___11 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___11;

struct pci_bus___11 {
	struct list_head node;
	struct pci_bus___11 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___11 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___11 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___32 *bridge;
	struct device___32 dev;
	struct bin_attribute___28 *legacy_io;
	struct bin_attribute___28 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___11;

struct pci_driver_rh___11;

struct pci_driver___11 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___11 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___11 *);
	int (*suspend)(struct pci_dev___11 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___11 *, pm_message_t);
	int (*resume_early)(struct pci_dev___11 *);
	int (*resume)(struct pci_dev___11 *);
	void (*shutdown)(struct pci_dev___11 *);
	int (*sriov_configure)(struct pci_dev___11 *, int);
	const struct pci_error_handlers___11 *err_handler;
	struct device_driver___32 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___11 *pci_driver_rh;
};

struct pci_ops___11 {
	int (*read)(struct pci_bus___11 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___11 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___11 {
	pci_ers_result_t (*error_detected)(struct pci_dev___11 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___11 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___11 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___11 *);
	void (*resume)(struct pci_dev___11 *);
};

struct pci_driver_rh___11 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___11 *, bool);
};

struct kmem_cache_cpu___33 {
	void **freelist;
	long unsigned int tid;
	struct page___41 *page;
	struct page___41 *partial;
};

struct memcg_cache_params___33 {
	bool is_root_cache;
	union {
		struct kmem_cache___33 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___33 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___41 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___42 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___42 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___42 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___18;

struct css_set___18 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___18 *subsys[11];
	struct callback_head callback_head;
};

struct xattr_handler___18 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___42 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___42 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___42 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___41;

struct super_block___42;

struct dentry___42 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___42 *d_parent;
	struct qstr d_name;
	struct inode___42 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___41 *d_op;
	struct super_block___42 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___41;

struct file_lock___41;

struct dquot___41;

struct block_device___41;

struct inode___42 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___41 *i_op;
	struct super_block___42 *i_sb;
	struct address_space___41 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___42 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___41 *i_fop;
	struct file_lock___41 *i_flock;
	struct address_space___41 i_data;
	struct dquot___41 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___41 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___41 {
	int (*d_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_hash)(const struct dentry___42 *, struct qstr *);
	int (*d_compare)(const struct dentry___42 *, const struct dentry___42 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___42 *);
	void (*d_release)(struct dentry___42 *);
	void (*d_prune)(struct dentry___42 *);
	void (*d_iput)(struct dentry___42 *, struct inode___42 *);
	char * (*d_dname)(struct dentry___42 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___41 *);
	int (*d_manage)(struct dentry___42 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___41;

struct mem_dqinfo___41 {
	struct quota_format_type___41 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___41;

struct quota_info___41 {
	unsigned int flags;
	struct mutex___42 dqio_mutex;
	struct mutex___42 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___42 *files[2];
	struct mem_dqinfo___41 info[2];
	const struct quota_format_ops___41 *ops[2];
};

struct file_system_type___41;

struct super_operations___41;

struct dquot_operations___41;

struct quotactl_ops___41;

struct super_block___42 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___41 *s_type;
	const struct super_operations___41 *s_op;
	const struct dquot_operations___41 *dq_op;
	const struct quotactl_ops___41 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___42 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___18 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___41 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___41 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___42 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___41 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___41 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___42 *bd_inode;
	struct super_block___42 *bd_super;
	struct mutex___42 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___41 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___42 bd_fsfreeze_mutex;
};

struct cgroup___18;

struct cgroup_subsys_state___18 {
	struct cgroup___18 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___42 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___41 *ia_file;
};

struct dquot___41 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___42 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___42 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___41 {
	int qf_fmt_id;
	const struct quota_format_ops___41 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___41 *qf_next;
};

struct quota_format_ops___41 {
	int (*check_quota_file)(struct super_block___42 *, int);
	int (*read_file_info)(struct super_block___42 *, int);
	int (*write_file_info)(struct super_block___42 *, int);
	int (*free_file_info)(struct super_block___42 *, int);
	int (*read_dqblk)(struct dquot___41 *);
	int (*commit_dqblk)(struct dquot___41 *);
	int (*release_dqblk)(struct dquot___41 *);
};

struct dquot_operations___41 {
	int (*write_dquot)(struct dquot___41 *);
	struct dquot___41 * (*alloc_dquot)(struct super_block___42 *, int);
	void (*destroy_dquot)(struct dquot___41 *);
	int (*acquire_dquot)(struct dquot___41 *);
	int (*release_dquot)(struct dquot___41 *);
	int (*mark_dirty)(struct dquot___41 *);
	int (*write_info)(struct super_block___42 *, int);
	qsize_t * (*get_reserved_space)(struct inode___42 *);
};

struct quotactl_ops___41 {
	int (*quota_on)(struct super_block___42 *, int, int, struct path___41 *);
	int (*quota_on_meta)(struct super_block___42 *, int, int);
	int (*quota_off)(struct super_block___42 *, int);
	int (*quota_sync)(struct super_block___42 *, int);
	int (*get_info)(struct super_block___42 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___42 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___42 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___42 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___42 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___42 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___42 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___42 *, unsigned int);
};

struct swap_info_struct___4;

struct address_space_operations___41 {
	int (*writepage)(struct page___41 *, struct writeback_control *);
	int (*readpage)(struct file___41 *, struct page___41 *);
	int (*writepages)(struct address_space___41 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___41 *);
	int (*readpages)(struct file___41 *, struct address_space___41 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___41 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___41 **, void **);
	int (*write_end)(struct file___41 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___41 *, void *);
	sector_t (*bmap)(struct address_space___41 *, sector_t);
	void (*invalidatepage)(struct page___41 *, long unsigned int);
	int (*releasepage)(struct page___41 *, gfp_t);
	void (*freepage)(struct page___41 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___41 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___41 *, struct page___41 *, struct page___41 *, enum migrate_mode);
	int (*launder_page)(struct page___41 *);
	int (*is_partially_uptodate)(struct page___41 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___41 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___41 *, struct page___41 *);
	int (*swap_activate)(struct swap_info_struct___4 *, struct file___41 *, sector_t *);
	void (*swap_deactivate)(struct file___41 *);
	void (*invalidatepage_range)(struct page___41 *, unsigned int, unsigned int);
};

struct swap_info_struct___4 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___41 *bdev;
	struct file___41 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___41 {
	struct dentry___42 * (*lookup)(struct inode___42 *, struct dentry___42 *, unsigned int);
	void * (*follow_link)(struct dentry___42 *, struct nameidata *);
	int (*permission)(struct inode___42 *, int);
	struct posix_acl * (*get_acl)(struct inode___42 *, int);
	int (*readlink)(struct dentry___42 *, char *, int);
	void (*put_link)(struct dentry___42 *, struct nameidata *, void *);
	int (*create)(struct inode___42 *, struct dentry___42 *, umode_t, bool);
	int (*link)(struct dentry___42 *, struct inode___42 *, struct dentry___42 *);
	int (*unlink)(struct inode___42 *, struct dentry___42 *);
	int (*symlink)(struct inode___42 *, struct dentry___42 *, const char *);
	int (*mkdir)(struct inode___42 *, struct dentry___42 *, umode_t);
	int (*rmdir)(struct inode___42 *, struct dentry___42 *);
	int (*mknod)(struct inode___42 *, struct dentry___42 *, umode_t, dev_t);
	int (*rename)(struct inode___42 *, struct dentry___42 *, struct inode___42 *, struct dentry___42 *);
	int (*setattr)(struct dentry___42 *, struct iattr___42 *);
	int (*getattr)(struct vfsmount *, struct dentry___42 *, struct kstat *);
	int (*setxattr)(struct dentry___42 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___42 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___42 *, char *, size_t);
	int (*removexattr)(struct dentry___42 *, const char *);
	int (*fiemap)(struct inode___42 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___42 *, struct timespec *, int);
	int (*atomic_open)(struct inode___42 *, struct dentry___42 *, struct file___41 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___41 {
	struct module *owner;
	loff_t (*llseek)(struct file___41 *, loff_t, int);
	ssize_t (*read)(struct file___41 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___41 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___41 *, void *, filldir_t);
	unsigned int (*poll)(struct file___41 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___41 *, struct vm_area_struct___45 *);
	int (*open)(struct inode___42 *, struct file___41 *);
	int (*flush)(struct file___41 *, fl_owner_t);
	int (*release)(struct inode___42 *, struct file___41 *);
	int (*fsync)(struct file___41 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___41 *, int);
	int (*lock)(struct file___41 *, int, struct file_lock___41 *);
	ssize_t (*sendpage)(struct file___41 *, struct page___41 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___41 *, int, struct file_lock___41 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___41 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___41 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___41 *, long int, struct file_lock___41 **, void **);
		struct {
			int (*setlease)(struct file___41 *, long int, struct file_lock___41 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___41 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___41 *);
};

struct fasync_struct___41;

struct file_lock_operations___41;

struct lock_manager_operations___41;

struct file_lock___41 {
	struct file_lock___41 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___41 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___41 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___41 *fl_ops;
	const struct lock_manager_operations___41 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___41 {
	void (*fl_copy_lock)(struct file_lock___41 *, struct file_lock___41 *);
	void (*fl_release_private)(struct file_lock___41 *);
};

struct lock_manager_operations___41 {
	int (*lm_compare_owner)(struct file_lock___41 *, struct file_lock___41 *);
	long unsigned int (*lm_owner_key)(struct file_lock___41 *);
	void (*lm_notify)(struct file_lock___41 *);
	int (*lm_grant)(struct file_lock___41 *, struct file_lock___41 *, int);
	void (*lm_break)(struct file_lock___41 *);
	int (*lm_change)(struct file_lock___41 **, int);
};

struct fasync_struct___41 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___41 *fa_next;
	struct file___41 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___41 {
	const char *name;
	int fs_flags;
	struct dentry___42 * (*mount)(struct file_system_type___41 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___42 *);
	struct module *owner;
	struct file_system_type___41 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___41 {
	struct inode___42 * (*alloc_inode)(struct super_block___42 *);
	void (*destroy_inode)(struct inode___42 *);
	void (*dirty_inode)(struct inode___42 *, int);
	int (*write_inode)(struct inode___42 *, struct writeback_control *);
	int (*drop_inode)(struct inode___42 *);
	void (*evict_inode)(struct inode___42 *);
	void (*put_super)(struct super_block___42 *);
	int (*sync_fs)(struct super_block___42 *, int);
	int (*freeze_fs)(struct super_block___42 *);
	int (*unfreeze_fs)(struct super_block___42 *);
	int (*statfs)(struct dentry___42 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___42 *, int *, char *);
	void (*umount_begin)(struct super_block___42 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___42 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___42 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___42 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___42 *);
	ssize_t (*quota_read)(struct super_block___42 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___42 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___42 *);
	int (*bdev_try_to_free_page)(struct super_block___42 *, struct page___41 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___42 *);
	void (*free_cached_objects)(struct super_block___42 *, int);
};

struct cgroupfs_root___18;

struct cgroup___18 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___18 *parent;
	struct dentry___42 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___18 *subsys[11];
	struct cgroupfs_root___18 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___42 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___18 {
	struct super_block___42 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___18 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___4 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___42 *, struct file___41 *);
	ssize_t (*read)(struct cgroup___18 *, struct cftype___4 *, struct file___41 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___18 *, struct cftype___4 *);
	s64 (*read_s64)(struct cgroup___18 *, struct cftype___4 *);
	int (*read_map)(struct cgroup___18 *, struct cftype___4 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___18 *, struct cftype___4 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___18 *, struct cftype___4 *, struct file___41 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___18 *, struct cftype___4 *, u64);
	int (*write_s64)(struct cgroup___18 *, struct cftype___4 *, s64);
	int (*write_string)(struct cgroup___18 *, struct cftype___4 *, const char *);
	int (*trigger)(struct cgroup___18 *, unsigned int);
	int (*release)(struct inode___42 *, struct file___41 *);
	int (*register_event)(struct cgroup___18 *, struct cftype___4 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___18 *, struct cftype___4 *, struct eventfd_ctx *);
};

struct cftype_set___4 {
	struct list_head node;
	struct cftype___4 *cfts;
};

struct task_and_cgroup___4 {
	struct task_struct___42 *task;
	struct cgroup___18 *cgrp;
	struct css_set___18 *cg;
};

struct cgroup_taskset___4 {
	struct task_and_cgroup___4 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___18 *cur_cgrp;
};

struct cgroup_subsys___4 {
	struct cgroup_subsys_state___18 * (*css_alloc)(struct cgroup___18 *);
	int (*css_online)(struct cgroup___18 *);
	void (*css_offline)(struct cgroup___18 *);
	void (*css_free)(struct cgroup___18 *);
	int (*can_attach)(struct cgroup___18 *, struct cgroup_taskset___4 *);
	void (*cancel_attach)(struct cgroup___18 *, struct cgroup_taskset___4 *);
	void (*attach)(struct cgroup___18 *, struct cgroup_taskset___4 *);
	void (*fork)(struct task_struct___42 *);
	void (*exit)(struct cgroup___18 *, struct cgroup___18 *, struct task_struct___42 *);
	void (*bind)(struct cgroup___18 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___18 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___4 *base_cftypes;
	struct cftype_set___4 base_cftset;
	struct module *module;
};

struct amd_northbridge___5 {
	struct pci_dev___11 *misc;
	struct pci_dev___11 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info___5 {
	u16 num;
	u64 flags;
	struct amd_northbridge___5 *nb;
};

struct pci_hostbridge_probe {
	u32 bus;
	u32 slot;
	u32 vendor;
	u32 device;
};

struct map_range {
	long unsigned int start;
	long unsigned int end;
	unsigned int page_size_mask;
};

struct page___42;

typedef struct page___42 *pgtable_t___42;

struct address_space___42;

struct kmem_cache___34;

struct page___42 {
	long unsigned int flags;
	struct address_space___42 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___42 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___42 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___34 *slab_cache;
		struct page___42 *first_page;
	};
	long: 64;
};

struct task_struct___43;

struct pv_cpu_ops___42 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___5 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___43 *);
	void (*end_context_switch)(struct task_struct___43 *);
};

struct mutex___43 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___43 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___39 {
	struct page___42 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___46;

struct signal_struct___42;

struct css_set___19;

struct task_struct___43 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___43 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___46 *mm;
	struct mm_struct___46 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___43 *real_parent;
	struct task_struct___43 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___43 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___6 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___42 = 0,
		VTIME_USER___42 = 1,
		VTIME_SYS___42 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___5 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___42 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___19 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___43 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___39 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___46 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___46 *, struct mm_struct___46 *);
	void (*dup_mmap)(struct mm_struct___46 *, struct mm_struct___46 *);
	void (*exit_mmap)(struct mm_struct___46 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___46 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___46 *);
	void (*pgd_free)(struct mm_struct___46 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___46 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___46 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___46 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___46 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___46 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___46 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___46 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___46 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___46 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___46 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___46 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___43 lock;
	void *vdso;
} mm_context_t___43;

struct xol_area___42;

struct uprobes_state___42 {
	struct xol_area___42 *xol_area;
};

struct vm_area_struct___46;

struct file___42;

struct core_state___42;

struct mm_struct___46 {
	struct vm_area_struct___46 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___46 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___46 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___43 context;
	long unsigned int flags;
	struct core_state___42 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___43 *owner;
	struct file___42 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___42 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___27;

struct module_kobject___26 {
	struct kobject kobj;
	struct module___27 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___26;

struct module___27 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___26 mkobj;
	struct module_attribute___26 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___43 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___42 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___42 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___34;

struct memcg_cache_params___34;

struct kmem_cache___34 {
	struct kmem_cache_cpu___34 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___34 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___43;

struct address_space_operations___42;

struct address_space___42 {
	struct inode___43 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___43 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___42 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___43;

struct path___42 {
	struct vfsmount *mnt;
	struct dentry___43 *dentry;
};

struct file_operations___42;

struct file___42 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___42 f_path;
	struct inode___43 *f_inode;
	const struct file_operations___42 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___42 *f_mapping;
	struct mutex___43 f_pos_lock;
};

struct vm_operations_struct___36;

struct vm_area_struct___46 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___46 *vm_next;
	struct vm_area_struct___46 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___46 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___36 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___42 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___33;

struct vm_operations_struct___36 {
	void (*open)(struct vm_area_struct___46 *);
	void (*close)(struct vm_area_struct___46 *);
	int (*fault)(struct vm_area_struct___46 *, struct vm_fault___33 *);
	int (*page_mkwrite)(struct vm_area_struct___46 *, struct vm_fault___33 *);
	int (*access)(struct vm_area_struct___46 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___46 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___46 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___46 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___46 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___42 {
	struct task_struct___43 *task;
	struct core_thread___42 *next;
};

struct core_state___42 {
	atomic_t nr_threads;
	struct core_thread___42 dumper;
	struct completion startup;
};

struct device___33;

struct dev_pm_ops___33 {
	int (*prepare)(struct device___33 *);
	void (*complete)(struct device___33 *);
	int (*suspend)(struct device___33 *);
	int (*resume)(struct device___33 *);
	int (*freeze)(struct device___33 *);
	int (*thaw)(struct device___33 *);
	int (*poweroff)(struct device___33 *);
	int (*restore)(struct device___33 *);
	int (*suspend_late)(struct device___33 *);
	int (*resume_early)(struct device___33 *);
	int (*freeze_late)(struct device___33 *);
	int (*thaw_early)(struct device___33 *);
	int (*poweroff_late)(struct device___33 *);
	int (*restore_early)(struct device___33 *);
	int (*suspend_noirq)(struct device___33 *);
	int (*resume_noirq)(struct device___33 *);
	int (*freeze_noirq)(struct device___33 *);
	int (*thaw_noirq)(struct device___33 *);
	int (*poweroff_noirq)(struct device___33 *);
	int (*restore_noirq)(struct device___33 *);
	int (*runtime_suspend)(struct device___33 *);
	int (*runtime_resume)(struct device___33 *);
	int (*runtime_idle)(struct device___33 *);
};

struct dma_map_ops___16;

struct dev_archdata___16 {
	struct dma_map_ops___16 *dma_ops;
	void *iommu;
};

struct device_type___33;

struct bus_type___33;

struct device_driver___33;

struct dev_pm_domain___33;

struct class___33;

struct attribute_group___29;

struct device_rh___33;

struct device___33 {
	struct device___33 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___33 *type;
	struct mutex___43 mutex;
	struct bus_type___33 *bus;
	struct device_driver___33 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___33 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___16 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___33 *class;
	const struct attribute_group___29 **groups;
	void (*release)(struct device___33 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___33 *device_rh;
};

struct dev_pm_info_rh___33 {
	void (*set_latency_tolerance)(struct device___33 *, s32);
};

struct dev_pm_domain___33 {
	struct dev_pm_ops___33 ops;
};

struct smp_ops___42 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___43 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___42;

struct lruvec___42 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___42 *zone;
};

struct pglist_data___42;

struct zone___42 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___42 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___42 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___42 {
	struct zone___42 *zone;
	int zone_idx;
};

struct zonelist___42 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___42 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___42 {
	struct zone___42 node_zones[4];
	struct zonelist___42 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___43 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	MEMORY_HOTPLUG_MIN_BOOTMEM_TYPE = 12,
	SECTION_INFO = 12,
	MIX_SECTION_INFO = 13,
	NODE_INFO = 14,
	MEMORY_HOTPLUG_MAX_BOOTMEM_TYPE = 14,
};

struct signal_struct___42 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___43 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___43 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___6 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___43 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___19;

struct css_set___19 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___19 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___33 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___42 *page;
};

struct bin_attribute___29;

struct attribute_group___29 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___29 **bin_attrs;
};

struct bin_attribute___29 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___42 *, struct kobject *, struct bin_attribute___29 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___42 *, struct kobject *, struct bin_attribute___29 *, char *, loff_t, size_t);
	int (*mmap)(struct file___42 *, struct kobject *, struct bin_attribute___29 *, struct vm_area_struct___46 *);
};

struct kmem_cache_cpu___34 {
	void **freelist;
	long unsigned int tid;
	struct page___42 *page;
	struct page___42 *partial;
};

struct memcg_cache_params___34 {
	bool is_root_cache;
	union {
		struct kmem_cache___34 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___34 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___19 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___43 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___43 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___43 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___42;

struct super_block___43;

struct dentry___43 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___43 *d_parent;
	struct qstr d_name;
	struct inode___43 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___42 *d_op;
	struct super_block___43 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___42;

struct file_lock___42;

struct dquot___42;

struct block_device___42;

struct inode___43 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___42 *i_op;
	struct super_block___43 *i_sb;
	struct address_space___42 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___43 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___42 *i_fop;
	struct file_lock___42 *i_flock;
	struct address_space___42 i_data;
	struct dquot___42 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___42 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___42 {
	int (*d_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_hash)(const struct dentry___43 *, struct qstr *);
	int (*d_compare)(const struct dentry___43 *, const struct dentry___43 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___43 *);
	void (*d_release)(struct dentry___43 *);
	void (*d_prune)(struct dentry___43 *);
	void (*d_iput)(struct dentry___43 *, struct inode___43 *);
	char * (*d_dname)(struct dentry___43 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___42 *);
	int (*d_manage)(struct dentry___43 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___42;

struct mem_dqinfo___42 {
	struct quota_format_type___42 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___42;

struct quota_info___42 {
	unsigned int flags;
	struct mutex___43 dqio_mutex;
	struct mutex___43 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___43 *files[2];
	struct mem_dqinfo___42 info[2];
	const struct quota_format_ops___42 *ops[2];
};

struct file_system_type___42;

struct super_operations___42;

struct dquot_operations___42;

struct quotactl_ops___42;

struct super_block___43 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___42 *s_type;
	const struct super_operations___42 *s_op;
	const struct dquot_operations___42 *dq_op;
	const struct quotactl_ops___42 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___43 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___19 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___42 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___42 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___43 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___42 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___42 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___43 *bd_inode;
	struct super_block___43 *bd_super;
	struct mutex___43 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___42 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___43 bd_fsfreeze_mutex;
};

struct cgroup___19;

struct cgroup_subsys_state___19 {
	struct cgroup___19 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___43 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___42 *ia_file;
};

struct dquot___42 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___43 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___43 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___42 {
	int qf_fmt_id;
	const struct quota_format_ops___42 *qf_ops;
	struct module___27 *qf_owner;
	struct quota_format_type___42 *qf_next;
};

struct quota_format_ops___42 {
	int (*check_quota_file)(struct super_block___43 *, int);
	int (*read_file_info)(struct super_block___43 *, int);
	int (*write_file_info)(struct super_block___43 *, int);
	int (*free_file_info)(struct super_block___43 *, int);
	int (*read_dqblk)(struct dquot___42 *);
	int (*commit_dqblk)(struct dquot___42 *);
	int (*release_dqblk)(struct dquot___42 *);
};

struct dquot_operations___42 {
	int (*write_dquot)(struct dquot___42 *);
	struct dquot___42 * (*alloc_dquot)(struct super_block___43 *, int);
	void (*destroy_dquot)(struct dquot___42 *);
	int (*acquire_dquot)(struct dquot___42 *);
	int (*release_dquot)(struct dquot___42 *);
	int (*mark_dirty)(struct dquot___42 *);
	int (*write_info)(struct super_block___43 *, int);
	qsize_t * (*get_reserved_space)(struct inode___43 *);
};

struct quotactl_ops___42 {
	int (*quota_on)(struct super_block___43 *, int, int, struct path___42 *);
	int (*quota_on_meta)(struct super_block___43 *, int, int);
	int (*quota_off)(struct super_block___43 *, int);
	int (*quota_sync)(struct super_block___43 *, int);
	int (*get_info)(struct super_block___43 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___43 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___43 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___43 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___43 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___43 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___43 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___43 *, unsigned int);
};

struct swap_info_struct___5;

struct address_space_operations___42 {
	int (*writepage)(struct page___42 *, struct writeback_control *);
	int (*readpage)(struct file___42 *, struct page___42 *);
	int (*writepages)(struct address_space___42 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___42 *);
	int (*readpages)(struct file___42 *, struct address_space___42 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___42 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___42 **, void **);
	int (*write_end)(struct file___42 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___42 *, void *);
	sector_t (*bmap)(struct address_space___42 *, sector_t);
	void (*invalidatepage)(struct page___42 *, long unsigned int);
	int (*releasepage)(struct page___42 *, gfp_t);
	void (*freepage)(struct page___42 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___42 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___42 *, struct page___42 *, struct page___42 *, enum migrate_mode);
	int (*launder_page)(struct page___42 *);
	int (*is_partially_uptodate)(struct page___42 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___42 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___42 *, struct page___42 *);
	int (*swap_activate)(struct swap_info_struct___5 *, struct file___42 *, sector_t *);
	void (*swap_deactivate)(struct file___42 *);
	void (*invalidatepage_range)(struct page___42 *, unsigned int, unsigned int);
};

struct swap_info_struct___5 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___42 *bdev;
	struct file___42 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___42 {
	struct dentry___43 * (*lookup)(struct inode___43 *, struct dentry___43 *, unsigned int);
	void * (*follow_link)(struct dentry___43 *, struct nameidata *);
	int (*permission)(struct inode___43 *, int);
	struct posix_acl * (*get_acl)(struct inode___43 *, int);
	int (*readlink)(struct dentry___43 *, char *, int);
	void (*put_link)(struct dentry___43 *, struct nameidata *, void *);
	int (*create)(struct inode___43 *, struct dentry___43 *, umode_t, bool);
	int (*link)(struct dentry___43 *, struct inode___43 *, struct dentry___43 *);
	int (*unlink)(struct inode___43 *, struct dentry___43 *);
	int (*symlink)(struct inode___43 *, struct dentry___43 *, const char *);
	int (*mkdir)(struct inode___43 *, struct dentry___43 *, umode_t);
	int (*rmdir)(struct inode___43 *, struct dentry___43 *);
	int (*mknod)(struct inode___43 *, struct dentry___43 *, umode_t, dev_t);
	int (*rename)(struct inode___43 *, struct dentry___43 *, struct inode___43 *, struct dentry___43 *);
	int (*setattr)(struct dentry___43 *, struct iattr___43 *);
	int (*getattr)(struct vfsmount *, struct dentry___43 *, struct kstat *);
	int (*setxattr)(struct dentry___43 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___43 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___43 *, char *, size_t);
	int (*removexattr)(struct dentry___43 *, const char *);
	int (*fiemap)(struct inode___43 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___43 *, struct timespec *, int);
	int (*atomic_open)(struct inode___43 *, struct dentry___43 *, struct file___42 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___42 {
	struct module___27 *owner;
	loff_t (*llseek)(struct file___42 *, loff_t, int);
	ssize_t (*read)(struct file___42 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___42 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___42 *, void *, filldir_t);
	unsigned int (*poll)(struct file___42 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___42 *, struct vm_area_struct___46 *);
	int (*open)(struct inode___43 *, struct file___42 *);
	int (*flush)(struct file___42 *, fl_owner_t);
	int (*release)(struct inode___43 *, struct file___42 *);
	int (*fsync)(struct file___42 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___42 *, int);
	int (*lock)(struct file___42 *, int, struct file_lock___42 *);
	ssize_t (*sendpage)(struct file___42 *, struct page___42 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___42 *, int, struct file_lock___42 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___42 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___42 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___42 *, long int, struct file_lock___42 **, void **);
		struct {
			int (*setlease)(struct file___42 *, long int, struct file_lock___42 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___42 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___42 *);
};

struct fasync_struct___42;

struct file_lock_operations___42;

struct lock_manager_operations___42;

struct file_lock___42 {
	struct file_lock___42 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___6 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___42 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___42 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___42 *fl_ops;
	const struct lock_manager_operations___42 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___42 {
	void (*fl_copy_lock)(struct file_lock___42 *, struct file_lock___42 *);
	void (*fl_release_private)(struct file_lock___42 *);
};

struct lock_manager_operations___42 {
	int (*lm_compare_owner)(struct file_lock___42 *, struct file_lock___42 *);
	long unsigned int (*lm_owner_key)(struct file_lock___42 *);
	void (*lm_notify)(struct file_lock___42 *);
	int (*lm_grant)(struct file_lock___42 *, struct file_lock___42 *, int);
	void (*lm_break)(struct file_lock___42 *);
	int (*lm_change)(struct file_lock___42 **, int);
};

struct fasync_struct___42 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___42 *fa_next;
	struct file___42 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___42 {
	const char *name;
	int fs_flags;
	struct dentry___43 * (*mount)(struct file_system_type___42 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___43 *);
	struct module___27 *owner;
	struct file_system_type___42 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___42 {
	struct inode___43 * (*alloc_inode)(struct super_block___43 *);
	void (*destroy_inode)(struct inode___43 *);
	void (*dirty_inode)(struct inode___43 *, int);
	int (*write_inode)(struct inode___43 *, struct writeback_control *);
	int (*drop_inode)(struct inode___43 *);
	void (*evict_inode)(struct inode___43 *);
	void (*put_super)(struct super_block___43 *);
	int (*sync_fs)(struct super_block___43 *, int);
	int (*freeze_fs)(struct super_block___43 *);
	int (*unfreeze_fs)(struct super_block___43 *);
	int (*statfs)(struct dentry___43 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___43 *, int *, char *);
	void (*umount_begin)(struct super_block___43 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___43 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___43 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___43 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___43 *);
	ssize_t (*quota_read)(struct super_block___43 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___43 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___43 *);
	int (*bdev_try_to_free_page)(struct super_block___43 *, struct page___42 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___43 *);
	void (*free_cached_objects)(struct super_block___43 *, int);
};

struct cgroupfs_root___19;

struct cgroup___19 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___19 *parent;
	struct dentry___43 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___19 *subsys[11];
	struct cgroupfs_root___19 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___43 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___19 {
	struct super_block___43 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___19 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___5 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___43 *, struct file___42 *);
	ssize_t (*read)(struct cgroup___19 *, struct cftype___5 *, struct file___42 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___19 *, struct cftype___5 *);
	s64 (*read_s64)(struct cgroup___19 *, struct cftype___5 *);
	int (*read_map)(struct cgroup___19 *, struct cftype___5 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___19 *, struct cftype___5 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___19 *, struct cftype___5 *, struct file___42 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___19 *, struct cftype___5 *, u64);
	int (*write_s64)(struct cgroup___19 *, struct cftype___5 *, s64);
	int (*write_string)(struct cgroup___19 *, struct cftype___5 *, const char *);
	int (*trigger)(struct cgroup___19 *, unsigned int);
	int (*release)(struct inode___43 *, struct file___42 *);
	int (*register_event)(struct cgroup___19 *, struct cftype___5 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___19 *, struct cftype___5 *, struct eventfd_ctx *);
};

struct cftype_set___5 {
	struct list_head node;
	struct cftype___5 *cfts;
};

struct task_and_cgroup___5 {
	struct task_struct___43 *task;
	struct cgroup___19 *cgrp;
	struct css_set___19 *cg;
};

struct cgroup_taskset___5 {
	struct task_and_cgroup___5 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___19 *cur_cgrp;
};

struct cgroup_subsys___5 {
	struct cgroup_subsys_state___19 * (*css_alloc)(struct cgroup___19 *);
	int (*css_online)(struct cgroup___19 *);
	void (*css_offline)(struct cgroup___19 *);
	void (*css_free)(struct cgroup___19 *);
	int (*can_attach)(struct cgroup___19 *, struct cgroup_taskset___5 *);
	void (*cancel_attach)(struct cgroup___19 *, struct cgroup_taskset___5 *);
	void (*attach)(struct cgroup___19 *, struct cgroup_taskset___5 *);
	void (*fork)(struct task_struct___43 *);
	void (*exit)(struct cgroup___19 *, struct cgroup___19 *, struct task_struct___43 *);
	void (*bind)(struct cgroup___19 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___19 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___5 *base_cftypes;
	struct cftype_set___5 base_cftset;
	struct module___27 *module;
};

struct dma_map_ops___16 {
	void * (*alloc)(struct device___33 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___33 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___33 *, struct vm_area_struct___46 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___33 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___33 *, struct page___42 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___33 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___33 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___33 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___33 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___33 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___33 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___33 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___33 *, dma_addr_t);
	int (*dma_supported)(struct device___33 *, u64);
	int (*set_dma_mask)(struct device___33 *, u64);
	int is_phys;
};

struct bus_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___33 *, char *);
	ssize_t (*store)(struct bus_type___33 *, const char *, size_t);
};

struct device_attribute___33;

struct driver_attribute___33;

struct bus_type___33 {
	const char *name;
	const char *dev_name;
	struct device___33 *dev_root;
	struct bus_attribute___33 *bus_attrs;
	struct device_attribute___33 *dev_attrs;
	struct driver_attribute___33 *drv_attrs;
	const struct attribute_group___29 **bus_groups;
	const struct attribute_group___29 **dev_groups;
	const struct attribute_group___29 **drv_groups;
	int (*match)(struct device___33 *, struct device_driver___33 *);
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	int (*probe)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*online)(struct device___33 *);
	int (*offline)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct device___33 *, struct device_attribute___33 *, char *);
	ssize_t (*store)(struct device___33 *, struct device_attribute___33 *, const char *, size_t);
};

struct driver_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___33 *, char *);
	ssize_t (*store)(struct device_driver___33 *, const char *, size_t);
};

struct device_driver___33 {
	const char *name;
	struct bus_type___33 *bus;
	struct module___27 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct attribute_group___29 **groups;
	const struct dev_pm_ops___33 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___33 {
	const char *name;
	const struct attribute_group___29 **groups;
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
};

struct class_attribute___33;

struct class___33 {
	const char *name;
	struct module___27 *owner;
	struct class_attribute___33 *class_attrs;
	struct device_attribute___33 *dev_attrs;
	const struct attribute_group___29 **dev_groups;
	struct bin_attribute___29 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *);
	void (*class_release)(struct class___33 *);
	void (*dev_release)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	struct subsys_private *p;
};

struct class_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct class___33 *, struct class_attribute___33 *, char *);
	ssize_t (*store)(struct class___33 *, struct class_attribute___33 *, const char *, size_t);
	const void * (*namespace)(struct class___33 *, const struct class_attribute___33 *);
};

struct device_rh___33 {
	struct dev_pm_info_rh___33 power;
};

struct module_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___26 *, struct module_kobject___26 *, char *);
	ssize_t (*store)(struct module_attribute___26 *, struct module_kobject___26 *, const char *, size_t);
	void (*setup)(struct module___27 *, const char *);
	int (*test)(struct module___27 *);
	void (*free)(struct module___27 *);
};

enum kcore_type {
	KCORE_TEXT = 0,
	KCORE_VMALLOC = 1,
	KCORE_RAM = 2,
	KCORE_VMEMMAP = 3,
	KCORE_OTHER = 4,
};

struct kcore_list {
	struct list_head list;
	long unsigned int addr;
	size_t size;
	int type;
};

struct tlb_state___13 {
	struct mm_struct___46 *active_mm;
	int state;
};

struct page___43;

typedef struct page___43 *pgtable_t___43;

struct address_space___43;

struct kmem_cache___35;

struct page___43 {
	long unsigned int flags;
	struct address_space___43 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___43 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___43 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___35 *slab_cache;
		struct page___43 *first_page;
	};
	long: 64;
};

struct thread_struct___17;

struct task_struct___44;

struct pv_cpu_ops___43 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___17 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___17 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___44 *);
	void (*end_context_switch)(struct task_struct___44 *);
};

struct perf_event___17;

struct thread_struct___17 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___17 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___18;

struct pid_link___18 {
	struct hlist_node node;
	struct pid___18 *pid;
};

struct mutex___44 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___44 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___40 {
	struct page___43 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___47;

struct nsproxy___18;

struct signal_struct___43;

struct css_set___20;

struct perf_event_context___17;

struct task_struct___44 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___44 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___47 *mm;
	struct mm_struct___47 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___44 *real_parent;
	struct task_struct___44 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___44 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___18 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___43 = 0,
		VTIME_USER___43 = 1,
		VTIME_SYS___43 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___17 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___18 *nsproxy;
	struct signal_struct___43 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___20 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___17 *perf_event_ctxp[2];
	struct mutex___44 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___40 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___47 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___47 *, struct mm_struct___47 *);
	void (*dup_mmap)(struct mm_struct___47 *, struct mm_struct___47 *);
	void (*exit_mmap)(struct mm_struct___47 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___47 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___47 *);
	void (*pgd_free)(struct mm_struct___47 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___47 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___47 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___47 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___47 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___47 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___47 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___47 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___47 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___47 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___47 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___47 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___44 lock;
	void *vdso;
} mm_context_t___44;

struct xol_area___43;

struct uprobes_state___43 {
	struct xol_area___43 *xol_area;
};

struct vm_area_struct___47;

struct file___43;

struct core_state___43;

struct mm_struct___47 {
	struct vm_area_struct___47 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___47 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___47 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___44 context;
	long unsigned int flags;
	struct core_state___43 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___44 *owner;
	struct file___43 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___43 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___28;

struct exec_domain___11 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___28 *module;
	struct exec_domain___11 *next;
};

struct module_kobject___27 {
	struct kobject kobj;
	struct module___28 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___27;

struct ftrace_event_call___9;

struct module___28 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___27 mkobj;
	struct module_attribute___27 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___9 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___44 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___17 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___44 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___44 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___44 *target;
};

typedef void (*perf_overflow_handler_t___17)(struct perf_event___17 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___17;

typedef void (*ftrace_func_t___17)(long unsigned int, long unsigned int, struct ftrace_ops___17 *, struct pt_regs *);

struct ftrace_ops___17 {
	ftrace_func_t___17 func;
	struct ftrace_ops___17 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___44 regex_lock;
};

struct pmu___17;

struct fasync_struct___43;

struct pid_namespace___18;

struct perf_cgroup___17;

struct perf_event___17 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___17 *group_leader;
	struct pmu___17 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___17 hw;
	struct perf_event_context___17 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___44 child_mutex;
	struct list_head child_list;
	struct perf_event___17 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___44 *owner;
	struct mutex___44 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___43 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___17 *);
	struct callback_head callback_head;
	struct pid_namespace___18 *ns;
	u64 id;
	perf_overflow_handler_t___17 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___9 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___17 ftrace_ops;
	struct perf_cgroup___17 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___16 {
	struct task_struct___44 *task;
	struct exec_domain___11 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___43 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___43 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___35;

struct memcg_cache_params___35;

struct kmem_cache___35 {
	struct kmem_cache_cpu___35 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___35 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___44;

struct address_space_operations___43;

struct address_space___43 {
	struct inode___44 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___44 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___43 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___44;

struct path___43 {
	struct vfsmount *mnt;
	struct dentry___44 *dentry;
};

struct fown_struct___18 {
	rwlock_t lock;
	struct pid___18 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___43;

struct file___43 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___43 f_path;
	struct inode___44 *f_inode;
	const struct file_operations___43 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___43 *f_mapping;
	struct mutex___44 f_pos_lock;
};

struct vm_operations_struct___37;

struct vm_area_struct___47 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___47 *vm_next;
	struct vm_area_struct___47 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___47 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___37 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___43 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___34;

struct vm_operations_struct___37 {
	void (*open)(struct vm_area_struct___47 *);
	void (*close)(struct vm_area_struct___47 *);
	int (*fault)(struct vm_area_struct___47 *, struct vm_fault___34 *);
	int (*page_mkwrite)(struct vm_area_struct___47 *, struct vm_fault___34 *);
	int (*access)(struct vm_area_struct___47 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___47 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___47 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___47 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___47 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___43 {
	struct task_struct___44 *task;
	struct core_thread___43 *next;
};

struct core_state___43 {
	atomic_t nr_threads;
	struct core_thread___43 dumper;
	struct completion startup;
};

struct irq_data___28;

struct x86_io_apic_ops___28 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___28 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___28;

struct irq_data___28 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___28 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___34;

struct dev_pm_ops___34 {
	int (*prepare)(struct device___34 *);
	void (*complete)(struct device___34 *);
	int (*suspend)(struct device___34 *);
	int (*resume)(struct device___34 *);
	int (*freeze)(struct device___34 *);
	int (*thaw)(struct device___34 *);
	int (*poweroff)(struct device___34 *);
	int (*restore)(struct device___34 *);
	int (*suspend_late)(struct device___34 *);
	int (*resume_early)(struct device___34 *);
	int (*freeze_late)(struct device___34 *);
	int (*thaw_early)(struct device___34 *);
	int (*poweroff_late)(struct device___34 *);
	int (*restore_early)(struct device___34 *);
	int (*suspend_noirq)(struct device___34 *);
	int (*resume_noirq)(struct device___34 *);
	int (*freeze_noirq)(struct device___34 *);
	int (*thaw_noirq)(struct device___34 *);
	int (*poweroff_noirq)(struct device___34 *);
	int (*restore_noirq)(struct device___34 *);
	int (*runtime_suspend)(struct device___34 *);
	int (*runtime_resume)(struct device___34 *);
	int (*runtime_idle)(struct device___34 *);
};

struct device_type___34;

struct bus_type___34;

struct device_driver___34;

struct dev_pm_domain___34;

struct class___34;

struct attribute_group___30;

struct device_rh___34;

struct device___34 {
	struct device___34 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___34 *type;
	struct mutex___44 mutex;
	struct bus_type___34 *bus;
	struct device_driver___34 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___34 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___16 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___34 *class;
	const struct attribute_group___30 **groups;
	void (*release)(struct device___34 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___34 *device_rh;
};

struct dev_pm_info_rh___34 {
	void (*set_latency_tolerance)(struct device___34 *, s32);
};

struct dev_pm_domain___34 {
	struct dev_pm_ops___34 ops;
};

struct smp_ops___43 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___44 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___18 {
	int nr;
	struct pid_namespace___18 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___18 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___44 *child_reaper;
	struct kmem_cache___35 *pid_cachep;
	unsigned int level;
	struct pid_namespace___18 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___44 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___18 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___18 numbers[1];
};

struct zone___43;

struct lruvec___43 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___43 *zone;
};

struct pglist_data___43;

struct zone___43 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___43 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___43 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___43 {
	struct zone___43 *zone;
	int zone_idx;
};

struct zonelist___43 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___43 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___43 {
	struct zone___43 node_zones[4];
	struct zonelist___43 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___44 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___18 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___18 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___43 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___44 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___44 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___18 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___44 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___20;

struct css_set___20 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___20 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___17 {
	struct pmu___17 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___44 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___44 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___17 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___30;

struct attribute_group___30 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___30 **bin_attrs;
};

struct bin_attribute___30 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___43 *, struct kobject *, struct bin_attribute___30 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___43 *, struct kobject *, struct bin_attribute___30 *, char *, loff_t, size_t);
	int (*mmap)(struct file___43 *, struct kobject *, struct bin_attribute___30 *, struct vm_area_struct___47 *);
};

struct module_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___27 *, struct module_kobject___27 *, char *);
	ssize_t (*store)(struct module_attribute___27 *, struct module_kobject___27 *, const char *, size_t);
	void (*setup)(struct module___28 *, const char *);
	int (*test)(struct module___28 *);
	void (*free)(struct module___28 *);
};

struct trace_event_functions___9;

struct trace_event___9 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___9 *funcs;
};

struct ftrace_event_class___9;

struct ftrace_event_call___9 {
	struct list_head list;
	struct ftrace_event_class___9 *class;
	char *name;
	struct trace_event___9 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct dentry_operations___43;

struct super_block___44;

struct dentry___44 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___44 *d_parent;
	struct qstr d_name;
	struct inode___44 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___43 *d_op;
	struct super_block___44 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___43;

struct file_lock___43;

struct dquot___43;

struct block_device___43;

struct inode___44 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___43 *i_op;
	struct super_block___44 *i_sb;
	struct address_space___43 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___44 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___43 *i_fop;
	struct file_lock___43 *i_flock;
	struct address_space___43 i_data;
	struct dquot___43 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___43 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___43 {
	int (*d_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_hash)(const struct dentry___44 *, struct qstr *);
	int (*d_compare)(const struct dentry___44 *, const struct dentry___44 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___44 *);
	void (*d_release)(struct dentry___44 *);
	void (*d_prune)(struct dentry___44 *);
	void (*d_iput)(struct dentry___44 *, struct inode___44 *);
	char * (*d_dname)(struct dentry___44 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___43 *);
	int (*d_manage)(struct dentry___44 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___43;

struct mem_dqinfo___43 {
	struct quota_format_type___43 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___43;

struct quota_info___43 {
	unsigned int flags;
	struct mutex___44 dqio_mutex;
	struct mutex___44 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___44 *files[2];
	struct mem_dqinfo___43 info[2];
	const struct quota_format_ops___43 *ops[2];
};

struct file_system_type___43;

struct super_operations___43;

struct dquot_operations___43;

struct quotactl_ops___43;

struct xattr_handler___20;

struct super_block___44 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___43 *s_type;
	const struct super_operations___43 *s_op;
	const struct dquot_operations___43 *dq_op;
	const struct quotactl_ops___43 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___44 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___20 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___43 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___43 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___44 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___43 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___43 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___44 *bd_inode;
	struct super_block___44 *bd_super;
	struct mutex___44 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___43 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___44 bd_fsfreeze_mutex;
};

struct cgroup___20;

struct cgroup_subsys_state___20 {
	struct cgroup___20 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___44 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___43 *ia_file;
};

struct dquot___43 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___44 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___44 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___43 {
	int qf_fmt_id;
	const struct quota_format_ops___43 *qf_ops;
	struct module___28 *qf_owner;
	struct quota_format_type___43 *qf_next;
};

struct quota_format_ops___43 {
	int (*check_quota_file)(struct super_block___44 *, int);
	int (*read_file_info)(struct super_block___44 *, int);
	int (*write_file_info)(struct super_block___44 *, int);
	int (*free_file_info)(struct super_block___44 *, int);
	int (*read_dqblk)(struct dquot___43 *);
	int (*commit_dqblk)(struct dquot___43 *);
	int (*release_dqblk)(struct dquot___43 *);
};

struct dquot_operations___43 {
	int (*write_dquot)(struct dquot___43 *);
	struct dquot___43 * (*alloc_dquot)(struct super_block___44 *, int);
	void (*destroy_dquot)(struct dquot___43 *);
	int (*acquire_dquot)(struct dquot___43 *);
	int (*release_dquot)(struct dquot___43 *);
	int (*mark_dirty)(struct dquot___43 *);
	int (*write_info)(struct super_block___44 *, int);
	qsize_t * (*get_reserved_space)(struct inode___44 *);
};

struct quotactl_ops___43 {
	int (*quota_on)(struct super_block___44 *, int, int, struct path___43 *);
	int (*quota_on_meta)(struct super_block___44 *, int, int);
	int (*quota_off)(struct super_block___44 *, int);
	int (*quota_sync)(struct super_block___44 *, int);
	int (*get_info)(struct super_block___44 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___44 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___44 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___44 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___44 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___44 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___44 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___44 *, unsigned int);
};

struct address_space_operations___43 {
	int (*writepage)(struct page___43 *, struct writeback_control *);
	int (*readpage)(struct file___43 *, struct page___43 *);
	int (*writepages)(struct address_space___43 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___43 *);
	int (*readpages)(struct file___43 *, struct address_space___43 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___43 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___43 **, void **);
	int (*write_end)(struct file___43 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___43 *, void *);
	sector_t (*bmap)(struct address_space___43 *, sector_t);
	void (*invalidatepage)(struct page___43 *, long unsigned int);
	int (*releasepage)(struct page___43 *, gfp_t);
	void (*freepage)(struct page___43 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___43 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___43 *, struct page___43 *, struct page___43 *, enum migrate_mode);
	int (*launder_page)(struct page___43 *);
	int (*is_partially_uptodate)(struct page___43 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___43 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___43 *, struct page___43 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___43 *, sector_t *);
	void (*swap_deactivate)(struct file___43 *);
	void (*invalidatepage_range)(struct page___43 *, unsigned int, unsigned int);
};

struct inode_operations___43 {
	struct dentry___44 * (*lookup)(struct inode___44 *, struct dentry___44 *, unsigned int);
	void * (*follow_link)(struct dentry___44 *, struct nameidata *);
	int (*permission)(struct inode___44 *, int);
	struct posix_acl * (*get_acl)(struct inode___44 *, int);
	int (*readlink)(struct dentry___44 *, char *, int);
	void (*put_link)(struct dentry___44 *, struct nameidata *, void *);
	int (*create)(struct inode___44 *, struct dentry___44 *, umode_t, bool);
	int (*link)(struct dentry___44 *, struct inode___44 *, struct dentry___44 *);
	int (*unlink)(struct inode___44 *, struct dentry___44 *);
	int (*symlink)(struct inode___44 *, struct dentry___44 *, const char *);
	int (*mkdir)(struct inode___44 *, struct dentry___44 *, umode_t);
	int (*rmdir)(struct inode___44 *, struct dentry___44 *);
	int (*mknod)(struct inode___44 *, struct dentry___44 *, umode_t, dev_t);
	int (*rename)(struct inode___44 *, struct dentry___44 *, struct inode___44 *, struct dentry___44 *);
	int (*setattr)(struct dentry___44 *, struct iattr___44 *);
	int (*getattr)(struct vfsmount *, struct dentry___44 *, struct kstat *);
	int (*setxattr)(struct dentry___44 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___44 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___44 *, char *, size_t);
	int (*removexattr)(struct dentry___44 *, const char *);
	int (*fiemap)(struct inode___44 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___44 *, struct timespec *, int);
	int (*atomic_open)(struct inode___44 *, struct dentry___44 *, struct file___43 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___24;

struct seq_file___27;

struct file_operations___43 {
	struct module___28 *owner;
	loff_t (*llseek)(struct file___43 *, loff_t, int);
	ssize_t (*read)(struct file___43 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___43 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___43 *, void *, filldir_t);
	unsigned int (*poll)(struct file___43 *, struct poll_table_struct___24 *);
	long int (*unlocked_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___43 *, struct vm_area_struct___47 *);
	int (*open)(struct inode___44 *, struct file___43 *);
	int (*flush)(struct file___43 *, fl_owner_t);
	int (*release)(struct inode___44 *, struct file___43 *);
	int (*fsync)(struct file___43 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___43 *, int);
	int (*lock)(struct file___43 *, int, struct file_lock___43 *);
	ssize_t (*sendpage)(struct file___43 *, struct page___43 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___43 *, int, struct file_lock___43 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___43 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___43 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___43 *, long int, struct file_lock___43 **, void **);
		struct {
			int (*setlease)(struct file___43 *, long int, struct file_lock___43 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___43 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___27 *, struct file___43 *);
};

struct file_lock_operations___43;

struct lock_manager_operations___43;

struct file_lock___43 {
	struct file_lock___43 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___18 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___43 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___43 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___43 *fl_ops;
	const struct lock_manager_operations___43 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___43 {
	void (*fl_copy_lock)(struct file_lock___43 *, struct file_lock___43 *);
	void (*fl_release_private)(struct file_lock___43 *);
};

struct lock_manager_operations___43 {
	int (*lm_compare_owner)(struct file_lock___43 *, struct file_lock___43 *);
	long unsigned int (*lm_owner_key)(struct file_lock___43 *);
	void (*lm_notify)(struct file_lock___43 *);
	int (*lm_grant)(struct file_lock___43 *, struct file_lock___43 *, int);
	void (*lm_break)(struct file_lock___43 *);
	int (*lm_change)(struct file_lock___43 **, int);
};

struct fasync_struct___43 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___43 *fa_next;
	struct file___43 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___43 {
	const char *name;
	int fs_flags;
	struct dentry___44 * (*mount)(struct file_system_type___43 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___44 *);
	struct module___28 *owner;
	struct file_system_type___43 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___43 {
	struct inode___44 * (*alloc_inode)(struct super_block___44 *);
	void (*destroy_inode)(struct inode___44 *);
	void (*dirty_inode)(struct inode___44 *, int);
	int (*write_inode)(struct inode___44 *, struct writeback_control *);
	int (*drop_inode)(struct inode___44 *);
	void (*evict_inode)(struct inode___44 *);
	void (*put_super)(struct super_block___44 *);
	int (*sync_fs)(struct super_block___44 *, int);
	int (*freeze_fs)(struct super_block___44 *);
	int (*unfreeze_fs)(struct super_block___44 *);
	int (*statfs)(struct dentry___44 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___44 *, int *, char *);
	void (*umount_begin)(struct super_block___44 *);
	int (*show_options)(struct seq_file___27 *, struct dentry___44 *);
	int (*show_devname)(struct seq_file___27 *, struct dentry___44 *);
	int (*show_path)(struct seq_file___27 *, struct dentry___44 *);
	int (*show_stats)(struct seq_file___27 *, struct dentry___44 *);
	ssize_t (*quota_read)(struct super_block___44 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___44 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___44 *);
	int (*bdev_try_to_free_page)(struct super_block___44 *, struct page___43 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___44 *);
	void (*free_cached_objects)(struct super_block___44 *, int);
};

struct xattr_handler___20 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___44 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___44 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___44 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___24)(struct file___43 *, wait_queue_head_t *, struct poll_table_struct___24 *);

struct poll_table_struct___24 {
	poll_queue_proc___24 _qproc;
	long unsigned int _key;
};

struct seq_operations___27;

struct seq_file___27 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___44 lock;
	const struct seq_operations___27 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kprobe_insn_cache___10 {
	struct mutex___44 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct vm_fault___34 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___43 *page;
};

struct bus_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___34 *, char *);
	ssize_t (*store)(struct bus_type___34 *, const char *, size_t);
};

struct device_attribute___34;

struct driver_attribute___34;

struct bus_type___34 {
	const char *name;
	const char *dev_name;
	struct device___34 *dev_root;
	struct bus_attribute___34 *bus_attrs;
	struct device_attribute___34 *dev_attrs;
	struct driver_attribute___34 *drv_attrs;
	const struct attribute_group___30 **bus_groups;
	const struct attribute_group___30 **dev_groups;
	const struct attribute_group___30 **drv_groups;
	int (*match)(struct device___34 *, struct device_driver___34 *);
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	int (*probe)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*online)(struct device___34 *);
	int (*offline)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct device___34 *, struct device_attribute___34 *, char *);
	ssize_t (*store)(struct device___34 *, struct device_attribute___34 *, const char *, size_t);
};

struct driver_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___34 *, char *);
	ssize_t (*store)(struct device_driver___34 *, const char *, size_t);
};

struct device_driver___34 {
	const char *name;
	struct bus_type___34 *bus;
	struct module___28 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct attribute_group___30 **groups;
	const struct dev_pm_ops___34 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___34 {
	const char *name;
	const struct attribute_group___30 **groups;
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
};

struct class_attribute___34;

struct class___34 {
	const char *name;
	struct module___28 *owner;
	struct class_attribute___34 *class_attrs;
	struct device_attribute___34 *dev_attrs;
	const struct attribute_group___30 **dev_groups;
	struct bin_attribute___30 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *);
	void (*class_release)(struct class___34 *);
	void (*dev_release)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	struct subsys_private *p;
};

struct class_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct class___34 *, struct class_attribute___34 *, char *);
	ssize_t (*store)(struct class___34 *, struct class_attribute___34 *, const char *, size_t);
	const void * (*namespace)(struct class___34 *, const struct class_attribute___34 *);
};

struct device_rh___34 {
	struct dev_pm_info_rh___34 power;
};

struct kmem_cache_cpu___35 {
	void **freelist;
	long unsigned int tid;
	struct page___43 *page;
	struct page___43 *partial;
};

struct memcg_cache_params___35 {
	bool is_root_cache;
	union {
		struct kmem_cache___35 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___35 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___20;

struct cgroup___20 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___20 *parent;
	struct dentry___44 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___20 *subsys[11];
	struct cgroupfs_root___20 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___44 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___20 {
	struct super_block___44 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___20 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___6 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___44 *, struct file___43 *);
	ssize_t (*read)(struct cgroup___20 *, struct cftype___6 *, struct file___43 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___20 *, struct cftype___6 *);
	s64 (*read_s64)(struct cgroup___20 *, struct cftype___6 *);
	int (*read_map)(struct cgroup___20 *, struct cftype___6 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___20 *, struct cftype___6 *, struct seq_file___27 *);
	ssize_t (*write)(struct cgroup___20 *, struct cftype___6 *, struct file___43 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___20 *, struct cftype___6 *, u64);
	int (*write_s64)(struct cgroup___20 *, struct cftype___6 *, s64);
	int (*write_string)(struct cgroup___20 *, struct cftype___6 *, const char *);
	int (*trigger)(struct cgroup___20 *, unsigned int);
	int (*release)(struct inode___44 *, struct file___43 *);
	int (*register_event)(struct cgroup___20 *, struct cftype___6 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___20 *, struct cftype___6 *, struct eventfd_ctx *);
};

struct perf_cpu_context___17;

struct pmu___17 {
	struct list_head entry;
	struct device___34 *dev;
	const struct attribute_group___30 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___17 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___17 *);
	void (*pmu_disable)(struct pmu___17 *);
	int (*event_init)(struct perf_event___17 *);
	int (*add)(struct perf_event___17 *, int);
	void (*del)(struct perf_event___17 *, int);
	void (*start)(struct perf_event___17 *, int);
	void (*stop)(struct perf_event___17 *, int);
	void (*read)(struct perf_event___17 *);
	void (*start_txn)(struct pmu___17 *);
	int (*commit_txn)(struct pmu___17 *);
	void (*cancel_txn)(struct pmu___17 *);
	int (*event_idx)(struct perf_event___17 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___28 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___17 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___17 *);
};

struct perf_cpu_context___17 {
	struct perf_event_context___17 ctx;
	struct perf_event_context___17 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___17 *unique_pmu;
	struct perf_cgroup___17 *cgrp;
};

struct perf_cgroup___17 {
	struct cgroup_subsys_state___20 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___28 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___28 *);
	void (*irq_shutdown)(struct irq_data___28 *);
	void (*irq_enable)(struct irq_data___28 *);
	void (*irq_disable)(struct irq_data___28 *);
	void (*irq_ack)(struct irq_data___28 *);
	void (*irq_mask)(struct irq_data___28 *);
	void (*irq_mask_ack)(struct irq_data___28 *);
	void (*irq_unmask)(struct irq_data___28 *);
	void (*irq_eoi)(struct irq_data___28 *);
	int (*irq_set_affinity)(struct irq_data___28 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___28 *);
	int (*irq_set_type)(struct irq_data___28 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___28 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___28 *);
	void (*irq_bus_sync_unlock)(struct irq_data___28 *);
	void (*irq_cpu_online)(struct irq_data___28 *);
	void (*irq_cpu_offline)(struct irq_data___28 *);
	void (*irq_suspend)(struct irq_data___28 *);
	void (*irq_resume)(struct irq_data___28 *);
	void (*irq_pm_shutdown)(struct irq_data___28 *);
	void (*irq_print_chip)(struct irq_data___28 *, struct seq_file___27 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___28 *, void *);
	long unsigned int flags;
};

struct tlb_state___14 {
	struct mm_struct___47 *active_mm;
	int state;
};

struct hstate {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___6 cgroup_files[5];
	char name[32];
};

struct seq_operations___27 {
	void * (*start)(struct seq_file___27 *, loff_t *);
	void (*stop)(struct seq_file___27 *, void *);
	void * (*next)(struct seq_file___27 *, void *, loff_t *);
	int (*show)(struct seq_file___27 *, void *);
};

struct trace_iterator___9 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___44 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___9)(struct trace_iterator___9 *, int, struct trace_event___9 *);

struct trace_event_functions___9 {
	trace_print_func___9 trace;
	trace_print_func___9 raw;
	trace_print_func___9 hex;
	trace_print_func___9 binary;
};

struct ftrace_event_class___9 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___9 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___9 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___9 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___9 *);
};

struct ftrace_event_file___4 {
	struct list_head list;
	struct ftrace_event_call___9 *event_call;
	struct dentry___44 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_x86_exceptions {
	struct trace_entry ent;
	long unsigned int address;
	long unsigned int ip;
	long unsigned int error_code;
	char __data[0];
};

struct ftrace_data_offsets_x86_exceptions {};

enum x86_pf_error_code {
	PF_PROT = 1,
	PF_WRITE = 2,
	PF_USER = 4,
	PF_RSVD = 8,
	PF_INSTR = 16,
};

struct vm_struct___2 {
	struct vm_struct___2 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___2 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct device___35;

struct dev_pm_ops___35 {
	int (*prepare)(struct device___35 *);
	void (*complete)(struct device___35 *);
	int (*suspend)(struct device___35 *);
	int (*resume)(struct device___35 *);
	int (*freeze)(struct device___35 *);
	int (*thaw)(struct device___35 *);
	int (*poweroff)(struct device___35 *);
	int (*restore)(struct device___35 *);
	int (*suspend_late)(struct device___35 *);
	int (*resume_early)(struct device___35 *);
	int (*freeze_late)(struct device___35 *);
	int (*thaw_early)(struct device___35 *);
	int (*poweroff_late)(struct device___35 *);
	int (*restore_early)(struct device___35 *);
	int (*suspend_noirq)(struct device___35 *);
	int (*resume_noirq)(struct device___35 *);
	int (*freeze_noirq)(struct device___35 *);
	int (*thaw_noirq)(struct device___35 *);
	int (*poweroff_noirq)(struct device___35 *);
	int (*restore_noirq)(struct device___35 *);
	int (*runtime_suspend)(struct device___35 *);
	int (*runtime_resume)(struct device___35 *);
	int (*runtime_idle)(struct device___35 *);
};

struct dma_map_ops___17;

struct dev_archdata___17 {
	struct dma_map_ops___17 *dma_ops;
	void *iommu;
};

struct device_type___35;

struct bus_type___35;

struct device_driver___35;

struct dev_pm_domain___35;

struct class___35;

struct device_rh___35;

struct device___35 {
	struct device___35 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___35 *type;
	struct mutex___3 mutex;
	struct bus_type___35 *bus;
	struct device_driver___35 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___35 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___17 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___35 *class;
	const struct attribute_group___3 **groups;
	void (*release)(struct device___35 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___35 *device_rh;
};

struct dev_pm_info_rh___35 {
	void (*set_latency_tolerance)(struct device___35 *, s32);
};

struct dev_pm_domain___35 {
	struct dev_pm_ops___35 ops;
};

struct dma_map_ops___17 {
	void * (*alloc)(struct device___35 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___35 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___35 *, struct vm_area_struct___3 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___35 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___35 *, struct page___3 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___35 *, dma_addr_t);
	int (*dma_supported)(struct device___35 *, u64);
	int (*set_dma_mask)(struct device___35 *, u64);
	int is_phys;
};

struct bus_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___35 *, char *);
	ssize_t (*store)(struct bus_type___35 *, const char *, size_t);
};

struct device_attribute___35;

struct driver_attribute___35;

struct bus_type___35 {
	const char *name;
	const char *dev_name;
	struct device___35 *dev_root;
	struct bus_attribute___35 *bus_attrs;
	struct device_attribute___35 *dev_attrs;
	struct driver_attribute___35 *drv_attrs;
	const struct attribute_group___3 **bus_groups;
	const struct attribute_group___3 **dev_groups;
	const struct attribute_group___3 **drv_groups;
	int (*match)(struct device___35 *, struct device_driver___35 *);
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	int (*probe)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*online)(struct device___35 *);
	int (*offline)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct device___35 *, struct device_attribute___35 *, char *);
	ssize_t (*store)(struct device___35 *, struct device_attribute___35 *, const char *, size_t);
};

struct driver_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___35 *, char *);
	ssize_t (*store)(struct device_driver___35 *, const char *, size_t);
};

struct device_driver___35 {
	const char *name;
	struct bus_type___35 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct attribute_group___3 **groups;
	const struct dev_pm_ops___35 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___35 {
	const char *name;
	const struct attribute_group___3 **groups;
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
};

struct class_attribute___35;

struct class___35 {
	const char *name;
	struct module *owner;
	struct class_attribute___35 *class_attrs;
	struct device_attribute___35 *dev_attrs;
	const struct attribute_group___3 **dev_groups;
	struct bin_attribute___3 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *);
	void (*class_release)(struct class___35 *);
	void (*dev_release)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	struct subsys_private *p;
};

struct class_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct class___35 *, struct class_attribute___35 *, char *);
	ssize_t (*store)(struct class___35 *, struct class_attribute___35 *, const char *, size_t);
	const void * (*namespace)(struct class___35 *, const struct class_attribute___35 *);
};

struct device_rh___35 {
	struct dev_pm_info_rh___35 power;
};

struct cpa_data {
	long unsigned int *vaddr;
	pgd_t *pgd;
	pgprot_t mask_set;
	pgprot_t mask_clr;
	int numpages;
	int flags;
	long unsigned int pfn;
	unsigned int force_split: 1;
	int curpage;
	struct page___3 **pages;
};

struct memtype {
	u64 start;
	u64 end;
	u64 subtree_max_end;
	long unsigned int type;
	struct rb_node rb;
};

enum {
	PAT_UC = 0,
	PAT_WC = 1,
	PAT_WT = 4,
	PAT_WP = 5,
	PAT_WB = 6,
	PAT_UC_MINUS = 7,
};

struct pagerange_state {
	long unsigned int cur_pfn;
	int ram;
	int not_ram;
};

struct mmu_gather_batch {
	struct mmu_gather_batch *next;
	unsigned int nr;
	unsigned int max;
	struct page___37 *pages[0];
};

struct mmu_gather {
	struct mm_struct___40 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch *active;
	struct mmu_gather_batch local;
	struct page___37 *__pages[8];
	unsigned int batch_count;
};

struct thread_info___17 {
	struct task_struct___43 *task;
	struct exec_domain___11 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct rb_augment_callbacks {
	void (*propagate)(struct rb_node *, struct rb_node *);
	void (*copy)(struct rb_node *, struct rb_node *);
	void (*rotate)(struct rb_node *, struct rb_node *);
};

struct page___44;

typedef struct page___44 *pgtable_t___44;

struct address_space___44;

struct page___44 {
	long unsigned int flags;
	struct address_space___44 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___44 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___44 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___44 *first_page;
	};
	long: 64;
};

struct task_struct___45;

struct pv_cpu_ops___44 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___17 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___17 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___45 *);
	void (*end_context_switch)(struct task_struct___45 *);
};

struct mutex___45 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___45 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___41 {
	struct page___44 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___48;

struct signal_struct___44;

struct task_struct___45 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___45 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___48 *mm;
	struct mm_struct___48 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___45 *real_parent;
	struct task_struct___45 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___45 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___18 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___44 = 0,
		VTIME_USER___44 = 1,
		VTIME_SYS___44 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___17 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___44 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___45 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___41 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___48 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___48 *, struct mm_struct___48 *);
	void (*dup_mmap)(struct mm_struct___48 *, struct mm_struct___48 *);
	void (*exit_mmap)(struct mm_struct___48 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___48 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___48 *);
	void (*pgd_free)(struct mm_struct___48 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___48 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___48 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___48 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___48 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___48 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___48 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___48 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___48 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___48 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___48 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___48 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___45 lock;
	void *vdso;
} mm_context_t___45;

struct xol_area___44;

struct uprobes_state___44 {
	struct xol_area___44 *xol_area;
};

struct vm_area_struct___48;

struct file___44;

struct core_state___44;

struct mm_struct___48 {
	struct vm_area_struct___48 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___48 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___48 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___45 context;
	long unsigned int flags;
	struct core_state___44 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___45 *owner;
	struct file___44 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___44 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___29;

struct module_kobject___28 {
	struct kobject kobj;
	struct module___29 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___28;

struct module___29 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___28 mkobj;
	struct module_attribute___28 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___45 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___44;

struct lruvec___44 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___44 *zone;
};

struct pglist_data___44;

struct zone___44 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___44 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___44 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___44 {
	struct zone___44 *zone;
	int zone_idx;
};

struct zonelist___44 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___44 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___44 {
	struct zone___44 node_zones[4];
	struct zonelist___44 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___45 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___29;

struct x86_io_apic_ops___29 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___29 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___29;

struct irq_data___29 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___29 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___44 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___45 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___44 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___44 *page;
	long unsigned int vaddr;
};

struct inode___45;

struct address_space_operations___44;

struct address_space___44 {
	struct inode___45 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___45 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___44 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___45;

struct path___44 {
	struct vfsmount *mnt;
	struct dentry___45 *dentry;
};

struct file_operations___44;

struct file___44 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___44 f_path;
	struct inode___45 *f_inode;
	const struct file_operations___44 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___44 *f_mapping;
	struct mutex___45 f_pos_lock;
};

struct vm_operations_struct___38;

struct vm_area_struct___48 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___48 *vm_next;
	struct vm_area_struct___48 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___48 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___38 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___44 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___35;

struct vm_operations_struct___38 {
	void (*open)(struct vm_area_struct___48 *);
	void (*close)(struct vm_area_struct___48 *);
	int (*fault)(struct vm_area_struct___48 *, struct vm_fault___35 *);
	int (*page_mkwrite)(struct vm_area_struct___48 *, struct vm_fault___35 *);
	int (*access)(struct vm_area_struct___48 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___48 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___48 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___48 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___48 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___44 {
	struct task_struct___45 *task;
	struct core_thread___44 *next;
};

struct core_state___44 {
	atomic_t nr_threads;
	struct core_thread___44 dumper;
	struct completion startup;
};

struct vm_fault___35 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___44 *page;
};

struct seq_file___28;

struct irq_chip___29 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___29 *);
	void (*irq_shutdown)(struct irq_data___29 *);
	void (*irq_enable)(struct irq_data___29 *);
	void (*irq_disable)(struct irq_data___29 *);
	void (*irq_ack)(struct irq_data___29 *);
	void (*irq_mask)(struct irq_data___29 *);
	void (*irq_mask_ack)(struct irq_data___29 *);
	void (*irq_unmask)(struct irq_data___29 *);
	void (*irq_eoi)(struct irq_data___29 *);
	int (*irq_set_affinity)(struct irq_data___29 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___29 *);
	int (*irq_set_type)(struct irq_data___29 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___29 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___29 *);
	void (*irq_bus_sync_unlock)(struct irq_data___29 *);
	void (*irq_cpu_online)(struct irq_data___29 *);
	void (*irq_cpu_offline)(struct irq_data___29 *);
	void (*irq_suspend)(struct irq_data___29 *);
	void (*irq_resume)(struct irq_data___29 *);
	void (*irq_pm_shutdown)(struct irq_data___29 *);
	void (*irq_print_chip)(struct irq_data___29 *, struct seq_file___28 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___29 *, void *);
	long unsigned int flags;
};

struct seq_operations___28;

struct seq_file___28 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___45 lock;
	const struct seq_operations___28 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct module_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___28 *, struct module_kobject___28 *, char *);
	ssize_t (*store)(struct module_attribute___28 *, struct module_kobject___28 *, const char *, size_t);
	void (*setup)(struct module___29 *, const char *);
	int (*test)(struct module___29 *);
	void (*free)(struct module___29 *);
};

struct signal_struct___44 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___45 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___45 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___18 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___45 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tlb_state___15 {
	struct mm_struct___48 *active_mm;
	int state;
};

struct dentry_operations___44;

struct super_block___45;

struct dentry___45 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___45 *d_parent;
	struct qstr d_name;
	struct inode___45 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___44 *d_op;
	struct super_block___45 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___44;

struct file_lock___44;

struct dquot___44;

struct block_device___44;

struct inode___45 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___44 *i_op;
	struct super_block___45 *i_sb;
	struct address_space___44 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___45 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___44 *i_fop;
	struct file_lock___44 *i_flock;
	struct address_space___44 i_data;
	struct dquot___44 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___44 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___44 {
	int (*d_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_hash)(const struct dentry___45 *, struct qstr *);
	int (*d_compare)(const struct dentry___45 *, const struct dentry___45 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___45 *);
	void (*d_release)(struct dentry___45 *);
	void (*d_prune)(struct dentry___45 *);
	void (*d_iput)(struct dentry___45 *, struct inode___45 *);
	char * (*d_dname)(struct dentry___45 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___44 *);
	int (*d_manage)(struct dentry___45 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___44;

struct mem_dqinfo___44 {
	struct quota_format_type___44 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___44;

struct quota_info___44 {
	unsigned int flags;
	struct mutex___45 dqio_mutex;
	struct mutex___45 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___45 *files[2];
	struct mem_dqinfo___44 info[2];
	const struct quota_format_ops___44 *ops[2];
};

struct file_system_type___44;

struct super_operations___44;

struct dquot_operations___44;

struct quotactl_ops___44;

struct super_block___45 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___44 *s_type;
	const struct super_operations___44 *s_op;
	const struct dquot_operations___44 *dq_op;
	const struct quotactl_ops___44 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___45 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___44 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___44 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___45 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___44 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___44 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___45 *bd_inode;
	struct super_block___45 *bd_super;
	struct mutex___45 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___44 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___45 bd_fsfreeze_mutex;
};

struct iattr___45 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___44 *ia_file;
};

struct dquot___44 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___45 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___45 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___44 {
	int qf_fmt_id;
	const struct quota_format_ops___44 *qf_ops;
	struct module___29 *qf_owner;
	struct quota_format_type___44 *qf_next;
};

struct quota_format_ops___44 {
	int (*check_quota_file)(struct super_block___45 *, int);
	int (*read_file_info)(struct super_block___45 *, int);
	int (*write_file_info)(struct super_block___45 *, int);
	int (*free_file_info)(struct super_block___45 *, int);
	int (*read_dqblk)(struct dquot___44 *);
	int (*commit_dqblk)(struct dquot___44 *);
	int (*release_dqblk)(struct dquot___44 *);
};

struct dquot_operations___44 {
	int (*write_dquot)(struct dquot___44 *);
	struct dquot___44 * (*alloc_dquot)(struct super_block___45 *, int);
	void (*destroy_dquot)(struct dquot___44 *);
	int (*acquire_dquot)(struct dquot___44 *);
	int (*release_dquot)(struct dquot___44 *);
	int (*mark_dirty)(struct dquot___44 *);
	int (*write_info)(struct super_block___45 *, int);
	qsize_t * (*get_reserved_space)(struct inode___45 *);
};

struct quotactl_ops___44 {
	int (*quota_on)(struct super_block___45 *, int, int, struct path___44 *);
	int (*quota_on_meta)(struct super_block___45 *, int, int);
	int (*quota_off)(struct super_block___45 *, int);
	int (*quota_sync)(struct super_block___45 *, int);
	int (*get_info)(struct super_block___45 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___45 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___45 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___45 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___45 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___45 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___45 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___45 *, unsigned int);
};

struct address_space_operations___44 {
	int (*writepage)(struct page___44 *, struct writeback_control *);
	int (*readpage)(struct file___44 *, struct page___44 *);
	int (*writepages)(struct address_space___44 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___44 *);
	int (*readpages)(struct file___44 *, struct address_space___44 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___44 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___44 **, void **);
	int (*write_end)(struct file___44 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___44 *, void *);
	sector_t (*bmap)(struct address_space___44 *, sector_t);
	void (*invalidatepage)(struct page___44 *, long unsigned int);
	int (*releasepage)(struct page___44 *, gfp_t);
	void (*freepage)(struct page___44 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___44 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___44 *, struct page___44 *, struct page___44 *, enum migrate_mode);
	int (*launder_page)(struct page___44 *);
	int (*is_partially_uptodate)(struct page___44 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___44 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___44 *, struct page___44 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___44 *, sector_t *);
	void (*swap_deactivate)(struct file___44 *);
	void (*invalidatepage_range)(struct page___44 *, unsigned int, unsigned int);
};

struct inode_operations___44 {
	struct dentry___45 * (*lookup)(struct inode___45 *, struct dentry___45 *, unsigned int);
	void * (*follow_link)(struct dentry___45 *, struct nameidata *);
	int (*permission)(struct inode___45 *, int);
	struct posix_acl * (*get_acl)(struct inode___45 *, int);
	int (*readlink)(struct dentry___45 *, char *, int);
	void (*put_link)(struct dentry___45 *, struct nameidata *, void *);
	int (*create)(struct inode___45 *, struct dentry___45 *, umode_t, bool);
	int (*link)(struct dentry___45 *, struct inode___45 *, struct dentry___45 *);
	int (*unlink)(struct inode___45 *, struct dentry___45 *);
	int (*symlink)(struct inode___45 *, struct dentry___45 *, const char *);
	int (*mkdir)(struct inode___45 *, struct dentry___45 *, umode_t);
	int (*rmdir)(struct inode___45 *, struct dentry___45 *);
	int (*mknod)(struct inode___45 *, struct dentry___45 *, umode_t, dev_t);
	int (*rename)(struct inode___45 *, struct dentry___45 *, struct inode___45 *, struct dentry___45 *);
	int (*setattr)(struct dentry___45 *, struct iattr___45 *);
	int (*getattr)(struct vfsmount *, struct dentry___45 *, struct kstat *);
	int (*setxattr)(struct dentry___45 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___45 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___45 *, char *, size_t);
	int (*removexattr)(struct dentry___45 *, const char *);
	int (*fiemap)(struct inode___45 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___45 *, struct timespec *, int);
	int (*atomic_open)(struct inode___45 *, struct dentry___45 *, struct file___44 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___44 {
	struct module___29 *owner;
	loff_t (*llseek)(struct file___44 *, loff_t, int);
	ssize_t (*read)(struct file___44 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___44 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___44 *, void *, filldir_t);
	unsigned int (*poll)(struct file___44 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___44 *, struct vm_area_struct___48 *);
	int (*open)(struct inode___45 *, struct file___44 *);
	int (*flush)(struct file___44 *, fl_owner_t);
	int (*release)(struct inode___45 *, struct file___44 *);
	int (*fsync)(struct file___44 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___44 *, int);
	int (*lock)(struct file___44 *, int, struct file_lock___44 *);
	ssize_t (*sendpage)(struct file___44 *, struct page___44 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___44 *, int, struct file_lock___44 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___44 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___44 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___44 *, long int, struct file_lock___44 **, void **);
		struct {
			int (*setlease)(struct file___44 *, long int, struct file_lock___44 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___44 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___28 *, struct file___44 *);
};

struct fasync_struct___44;

struct file_lock_operations___44;

struct lock_manager_operations___44;

struct file_lock___44 {
	struct file_lock___44 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___18 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___44 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___44 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___44 *fl_ops;
	const struct lock_manager_operations___44 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___44 {
	void (*fl_copy_lock)(struct file_lock___44 *, struct file_lock___44 *);
	void (*fl_release_private)(struct file_lock___44 *);
};

struct lock_manager_operations___44 {
	int (*lm_compare_owner)(struct file_lock___44 *, struct file_lock___44 *);
	long unsigned int (*lm_owner_key)(struct file_lock___44 *);
	void (*lm_notify)(struct file_lock___44 *);
	int (*lm_grant)(struct file_lock___44 *, struct file_lock___44 *, int);
	void (*lm_break)(struct file_lock___44 *);
	int (*lm_change)(struct file_lock___44 **, int);
};

struct fasync_struct___44 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___44 *fa_next;
	struct file___44 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___44 {
	const char *name;
	int fs_flags;
	struct dentry___45 * (*mount)(struct file_system_type___44 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___45 *);
	struct module___29 *owner;
	struct file_system_type___44 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___44 {
	struct inode___45 * (*alloc_inode)(struct super_block___45 *);
	void (*destroy_inode)(struct inode___45 *);
	void (*dirty_inode)(struct inode___45 *, int);
	int (*write_inode)(struct inode___45 *, struct writeback_control *);
	int (*drop_inode)(struct inode___45 *);
	void (*evict_inode)(struct inode___45 *);
	void (*put_super)(struct super_block___45 *);
	int (*sync_fs)(struct super_block___45 *, int);
	int (*freeze_fs)(struct super_block___45 *);
	int (*unfreeze_fs)(struct super_block___45 *);
	int (*statfs)(struct dentry___45 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___45 *, int *, char *);
	void (*umount_begin)(struct super_block___45 *);
	int (*show_options)(struct seq_file___28 *, struct dentry___45 *);
	int (*show_devname)(struct seq_file___28 *, struct dentry___45 *);
	int (*show_path)(struct seq_file___28 *, struct dentry___45 *);
	int (*show_stats)(struct seq_file___28 *, struct dentry___45 *);
	ssize_t (*quota_read)(struct super_block___45 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___45 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___45 *);
	int (*bdev_try_to_free_page)(struct super_block___45 *, struct page___44 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___45 *);
	void (*free_cached_objects)(struct super_block___45 *, int);
};

struct seq_operations___28 {
	void * (*start)(struct seq_file___28 *, loff_t *);
	void (*stop)(struct seq_file___28 *, void *);
	void * (*next)(struct seq_file___28 *, void *, loff_t *);
	int (*show)(struct seq_file___28 *, void *);
};

struct flush_tlb_info {
	struct mm_struct___48 *flush_mm;
	long unsigned int flush_start;
	long unsigned int flush_end;
};

struct tlb_state___16 {
	struct mm_struct___6 *active_mm;
	int state;
};

struct hugepage_subpool {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
};

struct hstate___2;

struct hugetlbfs_sb_info {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___2 *hstate;
	struct hugepage_subpool *spool;
};

struct hstate___2 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype cgroup_files[5];
	char name[32];
};

typedef struct pglist_data___4 pg_data_t___2;

struct numa_memblk {
	u64 start;
	u64 end;
	int nid;
};

struct numa_meminfo {
	int nr_blks;
	struct numa_memblk blk[2048];
};

struct page___45;

typedef struct page___45 *pgtable_t___45;

struct address_space___45;

struct kmem_cache___36;

struct page___45 {
	long unsigned int flags;
	struct address_space___45 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___45 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___45 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___36 *slab_cache;
		struct page___45 *first_page;
	};
	long: 64;
};

struct task_struct___46;

struct pv_cpu_ops___45 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___17 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___17 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___46 *);
	void (*end_context_switch)(struct task_struct___46 *);
};

struct mutex___46 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___46 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___42 {
	struct page___45 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___49;

struct signal_struct___45;

struct task_struct___46 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___46 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___49 *mm;
	struct mm_struct___49 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___46 *real_parent;
	struct task_struct___46 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___46 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___18 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___45 = 0,
		VTIME_USER___45 = 1,
		VTIME_SYS___45 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___17 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___45 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___46 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___42 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___49 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___49 *, struct mm_struct___49 *);
	void (*dup_mmap)(struct mm_struct___49 *, struct mm_struct___49 *);
	void (*exit_mmap)(struct mm_struct___49 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___49 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___49 *);
	void (*pgd_free)(struct mm_struct___49 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___49 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___49 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___49 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___49 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___49 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___49 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___49 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___49 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___49 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___49 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___49 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___46 lock;
	void *vdso;
} mm_context_t___46;

struct xol_area___45;

struct uprobes_state___45 {
	struct xol_area___45 *xol_area;
};

struct vm_area_struct___49;

struct file___45;

struct core_state___45;

struct mm_struct___49 {
	struct vm_area_struct___49 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___49 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___49 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___46 context;
	long unsigned int flags;
	struct core_state___45 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___46 *owner;
	struct file___45 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___45 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___30;

struct module_kobject___29 {
	struct kobject kobj;
	struct module___30 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___29;

struct module___30 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___29 mkobj;
	struct module_attribute___29 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___46 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___45;

struct lruvec___45 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___45 *zone;
};

struct pglist_data___45;

struct zone___45 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___45 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___45 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___45 {
	struct zone___45 *zone;
	int zone_idx;
};

struct zonelist___45 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___45 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___45 {
	struct zone___45 node_zones[4];
	struct zonelist___45 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___46 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___18;

struct dev_archdata___18 {
	struct dma_map_ops___18 *dma_ops;
	void *iommu;
};

struct acpi_device___10;

struct acpi_dev_node___13 {
	union {
		struct acpi_device___10 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___36;

struct bus_type___36;

struct device_driver___36;

struct dev_pm_domain___36;

struct class___36;

struct attribute_group___31;

struct device_rh___36;

struct device___36 {
	struct device___36 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___36 *type;
	struct mutex___46 mutex;
	struct bus_type___36 *bus;
	struct device_driver___36 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___36 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___18 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___36 *class;
	const struct attribute_group___31 **groups;
	void (*release)(struct device___36 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___36 *device_rh;
};

struct pci_bus___12;

struct pci_slot___12;

struct pci_driver___12;

struct bin_attribute___31;

struct pci_dev___12 {
	struct list_head bus_list;
	struct pci_bus___12 *bus;
	struct pci_bus___12 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___12 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___12 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___36 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___31 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___31 *res_attr[17];
	struct bin_attribute___31 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___31 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___12 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___36 {
	int (*prepare)(struct device___36 *);
	void (*complete)(struct device___36 *);
	int (*suspend)(struct device___36 *);
	int (*resume)(struct device___36 *);
	int (*freeze)(struct device___36 *);
	int (*thaw)(struct device___36 *);
	int (*poweroff)(struct device___36 *);
	int (*restore)(struct device___36 *);
	int (*suspend_late)(struct device___36 *);
	int (*resume_early)(struct device___36 *);
	int (*freeze_late)(struct device___36 *);
	int (*thaw_early)(struct device___36 *);
	int (*poweroff_late)(struct device___36 *);
	int (*restore_early)(struct device___36 *);
	int (*suspend_noirq)(struct device___36 *);
	int (*resume_noirq)(struct device___36 *);
	int (*freeze_noirq)(struct device___36 *);
	int (*thaw_noirq)(struct device___36 *);
	int (*poweroff_noirq)(struct device___36 *);
	int (*restore_noirq)(struct device___36 *);
	int (*runtime_suspend)(struct device___36 *);
	int (*runtime_resume)(struct device___36 *);
	int (*runtime_idle)(struct device___36 *);
};

struct dev_pm_info_rh___36 {
	void (*set_latency_tolerance)(struct device___36 *, s32);
};

struct dev_pm_domain___36 {
	struct dev_pm_ops___36 ops;
};

struct smp_ops___45 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___46 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct attribute_group___31 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___31 **bin_attrs;
};

struct bin_attribute___31 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___45 *, struct kobject *, struct bin_attribute___31 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___45 *, struct kobject *, struct bin_attribute___31 *, char *, loff_t, size_t);
	int (*mmap)(struct file___45 *, struct kobject *, struct bin_attribute___31 *, struct vm_area_struct___49 *);
};

struct dentry___46;

struct path___45 {
	struct vfsmount *mnt;
	struct dentry___46 *dentry;
};

struct inode___46;

struct file_operations___45;

struct file___45 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___45 f_path;
	struct inode___46 *f_inode;
	const struct file_operations___45 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___45 *f_mapping;
	struct mutex___46 f_pos_lock;
};

struct vm_operations_struct___39;

struct vm_area_struct___49 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___49 *vm_next;
	struct vm_area_struct___49 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___49 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___39 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___45 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___29 *, struct module_kobject___29 *, char *);
	ssize_t (*store)(struct module_attribute___29 *, struct module_kobject___29 *, const char *, size_t);
	void (*setup)(struct module___30 *, const char *);
	int (*test)(struct module___30 *);
	void (*free)(struct module___30 *);
};

struct xol_area___45 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___45 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___36;

struct memcg_cache_params___36;

struct kmem_cache___36 {
	struct kmem_cache_cpu___36 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___36 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___45;

struct address_space___45 {
	struct inode___46 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___46 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___45 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___36;

struct vm_operations_struct___39 {
	void (*open)(struct vm_area_struct___49 *);
	void (*close)(struct vm_area_struct___49 *);
	int (*fault)(struct vm_area_struct___49 *, struct vm_fault___36 *);
	int (*page_mkwrite)(struct vm_area_struct___49 *, struct vm_fault___36 *);
	int (*access)(struct vm_area_struct___49 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___49 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___49 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___49 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___49 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___45 {
	struct task_struct___46 *task;
	struct core_thread___45 *next;
};

struct core_state___45 {
	atomic_t nr_threads;
	struct core_thread___45 dumper;
	struct completion startup;
};

struct vm_fault___36 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___45 *page;
};

struct dma_map_ops___18 {
	void * (*alloc)(struct device___36 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___36 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___36 *, struct vm_area_struct___49 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___36 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___36 *, struct page___45 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___36 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___36 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___36 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___36 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___36 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___36 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___36 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___36 *, dma_addr_t);
	int (*dma_supported)(struct device___36 *, u64);
	int (*set_dma_mask)(struct device___36 *, u64);
	int is_phys;
};

struct bus_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___36 *, char *);
	ssize_t (*store)(struct bus_type___36 *, const char *, size_t);
};

struct device_attribute___36;

struct driver_attribute___36;

struct bus_type___36 {
	const char *name;
	const char *dev_name;
	struct device___36 *dev_root;
	struct bus_attribute___36 *bus_attrs;
	struct device_attribute___36 *dev_attrs;
	struct driver_attribute___36 *drv_attrs;
	const struct attribute_group___31 **bus_groups;
	const struct attribute_group___31 **dev_groups;
	const struct attribute_group___31 **drv_groups;
	int (*match)(struct device___36 *, struct device_driver___36 *);
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	int (*probe)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*online)(struct device___36 *);
	int (*offline)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct device___36 *, struct device_attribute___36 *, char *);
	ssize_t (*store)(struct device___36 *, struct device_attribute___36 *, const char *, size_t);
};

struct driver_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___36 *, char *);
	ssize_t (*store)(struct device_driver___36 *, const char *, size_t);
};

struct device_driver___36 {
	const char *name;
	struct bus_type___36 *bus;
	struct module___30 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct attribute_group___31 **groups;
	const struct dev_pm_ops___36 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___36 {
	const char *name;
	const struct attribute_group___31 **groups;
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
};

struct class_attribute___36;

struct class___36 {
	const char *name;
	struct module___30 *owner;
	struct class_attribute___36 *class_attrs;
	struct device_attribute___36 *dev_attrs;
	const struct attribute_group___31 **dev_groups;
	struct bin_attribute___31 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *);
	void (*class_release)(struct class___36 *);
	void (*dev_release)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	struct subsys_private *p;
};

struct class_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct class___36 *, struct class_attribute___36 *, char *);
	ssize_t (*store)(struct class___36 *, struct class_attribute___36 *, const char *, size_t);
	const void * (*namespace)(struct class___36 *, const struct class_attribute___36 *);
};

struct acpi_scan_handler___10;

struct acpi_hotplug_context___10;

struct acpi_driver___10;

struct acpi_device___10 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___10 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___10 *handler;
	struct acpi_hotplug_context___10 *hp;
	struct acpi_driver___10 *driver;
	void *driver_data;
	struct device___36 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___46 physical_node_lock;
	void (*remove)(struct acpi_device___10 *);
};

struct device_rh___36 {
	struct dev_pm_info_rh___36 power;
};

struct signal_struct___45 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___46 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___46 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___18 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___46 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___36 {
	void **freelist;
	long unsigned int tid;
	struct page___45 *page;
	struct page___45 *partial;
};

struct memcg_cache_params___36 {
	bool is_root_cache;
	union {
		struct kmem_cache___36 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___36 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___45;

struct super_block___46;

struct dentry___46 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___46 *d_parent;
	struct qstr d_name;
	struct inode___46 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___45 *d_op;
	struct super_block___46 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___45;

struct file_lock___45;

struct dquot___45;

struct block_device___45;

struct inode___46 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___45 *i_op;
	struct super_block___46 *i_sb;
	struct address_space___45 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___46 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___45 *i_fop;
	struct file_lock___45 *i_flock;
	struct address_space___45 i_data;
	struct dquot___45 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___45 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___45 {
	int (*d_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_hash)(const struct dentry___46 *, struct qstr *);
	int (*d_compare)(const struct dentry___46 *, const struct dentry___46 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___46 *);
	void (*d_release)(struct dentry___46 *);
	void (*d_prune)(struct dentry___46 *);
	void (*d_iput)(struct dentry___46 *, struct inode___46 *);
	char * (*d_dname)(struct dentry___46 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___45 *);
	int (*d_manage)(struct dentry___46 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___45;

struct mem_dqinfo___45 {
	struct quota_format_type___45 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___45;

struct quota_info___45 {
	unsigned int flags;
	struct mutex___46 dqio_mutex;
	struct mutex___46 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___46 *files[2];
	struct mem_dqinfo___45 info[2];
	const struct quota_format_ops___45 *ops[2];
};

struct file_system_type___45;

struct super_operations___45;

struct dquot_operations___45;

struct quotactl_ops___45;

struct super_block___46 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___45 *s_type;
	const struct super_operations___45 *s_op;
	const struct dquot_operations___45 *dq_op;
	const struct quotactl_ops___45 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___46 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___45 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___45 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___46 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___45 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___45 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___46 *bd_inode;
	struct super_block___46 *bd_super;
	struct mutex___46 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___45 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___46 bd_fsfreeze_mutex;
};

struct iattr___46 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___45 *ia_file;
};

struct dquot___45 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___46 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___46 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___45 {
	int qf_fmt_id;
	const struct quota_format_ops___45 *qf_ops;
	struct module___30 *qf_owner;
	struct quota_format_type___45 *qf_next;
};

struct quota_format_ops___45 {
	int (*check_quota_file)(struct super_block___46 *, int);
	int (*read_file_info)(struct super_block___46 *, int);
	int (*write_file_info)(struct super_block___46 *, int);
	int (*free_file_info)(struct super_block___46 *, int);
	int (*read_dqblk)(struct dquot___45 *);
	int (*commit_dqblk)(struct dquot___45 *);
	int (*release_dqblk)(struct dquot___45 *);
};

struct dquot_operations___45 {
	int (*write_dquot)(struct dquot___45 *);
	struct dquot___45 * (*alloc_dquot)(struct super_block___46 *, int);
	void (*destroy_dquot)(struct dquot___45 *);
	int (*acquire_dquot)(struct dquot___45 *);
	int (*release_dquot)(struct dquot___45 *);
	int (*mark_dirty)(struct dquot___45 *);
	int (*write_info)(struct super_block___46 *, int);
	qsize_t * (*get_reserved_space)(struct inode___46 *);
};

struct quotactl_ops___45 {
	int (*quota_on)(struct super_block___46 *, int, int, struct path___45 *);
	int (*quota_on_meta)(struct super_block___46 *, int, int);
	int (*quota_off)(struct super_block___46 *, int);
	int (*quota_sync)(struct super_block___46 *, int);
	int (*get_info)(struct super_block___46 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___46 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___46 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___46 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___46 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___46 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___46 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___46 *, unsigned int);
};

struct address_space_operations___45 {
	int (*writepage)(struct page___45 *, struct writeback_control *);
	int (*readpage)(struct file___45 *, struct page___45 *);
	int (*writepages)(struct address_space___45 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___45 *);
	int (*readpages)(struct file___45 *, struct address_space___45 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___45 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___45 **, void **);
	int (*write_end)(struct file___45 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___45 *, void *);
	sector_t (*bmap)(struct address_space___45 *, sector_t);
	void (*invalidatepage)(struct page___45 *, long unsigned int);
	int (*releasepage)(struct page___45 *, gfp_t);
	void (*freepage)(struct page___45 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___45 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___45 *, struct page___45 *, struct page___45 *, enum migrate_mode);
	int (*launder_page)(struct page___45 *);
	int (*is_partially_uptodate)(struct page___45 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___45 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___45 *, struct page___45 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___45 *, sector_t *);
	void (*swap_deactivate)(struct file___45 *);
	void (*invalidatepage_range)(struct page___45 *, unsigned int, unsigned int);
};

struct inode_operations___45 {
	struct dentry___46 * (*lookup)(struct inode___46 *, struct dentry___46 *, unsigned int);
	void * (*follow_link)(struct dentry___46 *, struct nameidata *);
	int (*permission)(struct inode___46 *, int);
	struct posix_acl * (*get_acl)(struct inode___46 *, int);
	int (*readlink)(struct dentry___46 *, char *, int);
	void (*put_link)(struct dentry___46 *, struct nameidata *, void *);
	int (*create)(struct inode___46 *, struct dentry___46 *, umode_t, bool);
	int (*link)(struct dentry___46 *, struct inode___46 *, struct dentry___46 *);
	int (*unlink)(struct inode___46 *, struct dentry___46 *);
	int (*symlink)(struct inode___46 *, struct dentry___46 *, const char *);
	int (*mkdir)(struct inode___46 *, struct dentry___46 *, umode_t);
	int (*rmdir)(struct inode___46 *, struct dentry___46 *);
	int (*mknod)(struct inode___46 *, struct dentry___46 *, umode_t, dev_t);
	int (*rename)(struct inode___46 *, struct dentry___46 *, struct inode___46 *, struct dentry___46 *);
	int (*setattr)(struct dentry___46 *, struct iattr___46 *);
	int (*getattr)(struct vfsmount *, struct dentry___46 *, struct kstat *);
	int (*setxattr)(struct dentry___46 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___46 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___46 *, char *, size_t);
	int (*removexattr)(struct dentry___46 *, const char *);
	int (*fiemap)(struct inode___46 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___46 *, struct timespec *, int);
	int (*atomic_open)(struct inode___46 *, struct dentry___46 *, struct file___45 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___45 {
	struct module___30 *owner;
	loff_t (*llseek)(struct file___45 *, loff_t, int);
	ssize_t (*read)(struct file___45 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___45 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___45 *, void *, filldir_t);
	unsigned int (*poll)(struct file___45 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___45 *, struct vm_area_struct___49 *);
	int (*open)(struct inode___46 *, struct file___45 *);
	int (*flush)(struct file___45 *, fl_owner_t);
	int (*release)(struct inode___46 *, struct file___45 *);
	int (*fsync)(struct file___45 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___45 *, int);
	int (*lock)(struct file___45 *, int, struct file_lock___45 *);
	ssize_t (*sendpage)(struct file___45 *, struct page___45 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___45 *, int, struct file_lock___45 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___45 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___45 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___45 *, long int, struct file_lock___45 **, void **);
		struct {
			int (*setlease)(struct file___45 *, long int, struct file_lock___45 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___45 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___45 *);
};

struct fasync_struct___45;

struct file_lock_operations___45;

struct lock_manager_operations___45;

struct file_lock___45 {
	struct file_lock___45 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___18 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___45 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___45 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___45 *fl_ops;
	const struct lock_manager_operations___45 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___45 {
	void (*fl_copy_lock)(struct file_lock___45 *, struct file_lock___45 *);
	void (*fl_release_private)(struct file_lock___45 *);
};

struct lock_manager_operations___45 {
	int (*lm_compare_owner)(struct file_lock___45 *, struct file_lock___45 *);
	long unsigned int (*lm_owner_key)(struct file_lock___45 *);
	void (*lm_notify)(struct file_lock___45 *);
	int (*lm_grant)(struct file_lock___45 *, struct file_lock___45 *, int);
	void (*lm_break)(struct file_lock___45 *);
	int (*lm_change)(struct file_lock___45 **, int);
};

struct fasync_struct___45 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___45 *fa_next;
	struct file___45 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___45 {
	const char *name;
	int fs_flags;
	struct dentry___46 * (*mount)(struct file_system_type___45 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___46 *);
	struct module___30 *owner;
	struct file_system_type___45 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___45 {
	struct inode___46 * (*alloc_inode)(struct super_block___46 *);
	void (*destroy_inode)(struct inode___46 *);
	void (*dirty_inode)(struct inode___46 *, int);
	int (*write_inode)(struct inode___46 *, struct writeback_control *);
	int (*drop_inode)(struct inode___46 *);
	void (*evict_inode)(struct inode___46 *);
	void (*put_super)(struct super_block___46 *);
	int (*sync_fs)(struct super_block___46 *, int);
	int (*freeze_fs)(struct super_block___46 *);
	int (*unfreeze_fs)(struct super_block___46 *);
	int (*statfs)(struct dentry___46 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___46 *, int *, char *);
	void (*umount_begin)(struct super_block___46 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___46 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___46 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___46 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___46 *);
	ssize_t (*quota_read)(struct super_block___46 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___46 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___46 *);
	int (*bdev_try_to_free_page)(struct super_block___46 *, struct page___45 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___46 *);
	void (*free_cached_objects)(struct super_block___46 *, int);
};

struct acpi_hotplug_profile___10 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___10 *);
	void (*notify_online)(struct acpi_device___10 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___10 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___10 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___10 *);
	void (*bind)(struct device___36 *);
	void (*unbind)(struct device___36 *);
	struct acpi_hotplug_profile___10 hotplug;
};

struct acpi_hotplug_context___10 {
	struct acpi_device___10 *self;
	int (*notify)(struct acpi_device___10 *, u32);
	void (*uevent)(struct acpi_device___10 *, u32);
	void (*fixup)(struct acpi_device___10 *);
};

typedef int (*acpi_op_add___10)(struct acpi_device___10 *);

typedef int (*acpi_op_remove___10)(struct acpi_device___10 *);

typedef void (*acpi_op_notify___10)(struct acpi_device___10 *, u32);

struct acpi_device_ops___10 {
	acpi_op_add___10 add;
	acpi_op_remove___10 remove;
	acpi_op_notify___10 notify;
};

struct acpi_driver___10 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___10 ops;
	struct device_driver___36 drv;
	struct module___30 *owner;
};

struct pci_ops___12;

struct pci_bus___12 {
	struct list_head node;
	struct pci_bus___12 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___12 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___12 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___36 *bridge;
	struct device___36 dev;
	struct bin_attribute___31 *legacy_io;
	struct bin_attribute___31 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_slot___12 {
	struct pci_bus___12 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_error_handlers___12;

struct pci_driver_rh___12;

struct pci_driver___12 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___12 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___12 *);
	int (*suspend)(struct pci_dev___12 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___12 *, pm_message_t);
	int (*resume_early)(struct pci_dev___12 *);
	int (*resume)(struct pci_dev___12 *);
	void (*shutdown)(struct pci_dev___12 *);
	int (*sriov_configure)(struct pci_dev___12 *, int);
	const struct pci_error_handlers___12 *err_handler;
	struct device_driver___36 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___12 *pci_driver_rh;
};

struct pci_ops___12 {
	int (*read)(struct pci_bus___12 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___12 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___12 {
	pci_ers_result_t (*error_detected)(struct pci_dev___12 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___12 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___12 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___12 *);
	void (*resume)(struct pci_dev___12 *);
};

struct pci_driver_rh___12 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___12 *, bool);
};

struct amd_northbridge___6 {
	struct pci_dev___12 *misc;
	struct pci_dev___12 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct amd_northbridge_info___6 {
	u16 num;
	u64 flags;
	struct amd_northbridge___6 *nb;
};

struct acpi_table_slit {
	struct acpi_table_header header;
	u64 locality_count;
	u8 entry[1];
} __attribute__((packed));

struct acpi_srat_cpu_affinity {
	struct acpi_subtable_header header;
	u8 proximity_domain_lo;
	u8 apic_id;
	u32 flags;
	u8 local_sapic_eid;
	u8 proximity_domain_hi[3];
	u32 reserved;
};

struct acpi_srat_mem_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u16 reserved;
	u64 base_address;
	u64 length;
	u32 reserved1;
	u32 flags;
	u64 reserved2;
} __attribute__((packed));

struct acpi_srat_x2apic_cpu_affinity {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 proximity_domain;
	u32 apic_id;
	u32 flags;
	u32 clock_domain;
	u32 reserved2;
};

struct page___46;

typedef struct page___46 *pgtable_t___46;

struct address_space___46;

struct kmem_cache___37;

struct page___46 {
	long unsigned int flags;
	struct address_space___46 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___46 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___46 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___37 *slab_cache;
		struct page___46 *first_page;
	};
	long: 64;
};

struct thread_struct___18;

struct task_struct___47;

struct pv_cpu_ops___46 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___18 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___18 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___47 *);
	void (*end_context_switch)(struct task_struct___47 *);
};

struct perf_event___18;

struct thread_struct___18 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___18 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___19;

struct pid_link___19 {
	struct hlist_node node;
	struct pid___19 *pid;
};

struct mutex___47 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___47 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___43 {
	struct page___46 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___50;

struct nsproxy___19;

struct signal_struct___46;

struct css_set___21;

struct perf_event_context___18;

struct task_struct___47 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___47 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___50 *mm;
	struct mm_struct___50 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___47 *real_parent;
	struct task_struct___47 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___47 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___19 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___46 = 0,
		VTIME_USER___46 = 1,
		VTIME_SYS___46 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___18 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___19 *nsproxy;
	struct signal_struct___46 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___21 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___18 *perf_event_ctxp[2];
	struct mutex___47 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___43 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___50 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___50 *, struct mm_struct___50 *);
	void (*dup_mmap)(struct mm_struct___50 *, struct mm_struct___50 *);
	void (*exit_mmap)(struct mm_struct___50 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___50 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___50 *);
	void (*pgd_free)(struct mm_struct___50 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___50 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___50 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___50 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___50 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___50 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___50 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___50 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___50 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___50 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___50 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___50 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___47 lock;
	void *vdso;
} mm_context_t___47;

struct xol_area___46;

struct uprobes_state___46 {
	struct xol_area___46 *xol_area;
};

struct vm_area_struct___50;

struct file___46;

struct core_state___46;

struct mm_struct___50 {
	struct vm_area_struct___50 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___50 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___50 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___47 context;
	long unsigned int flags;
	struct core_state___46 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___47 *owner;
	struct file___46 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___46 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___18 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___47 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___47 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___47 *target;
};

typedef void (*perf_overflow_handler_t___18)(struct perf_event___18 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___18;

typedef void (*ftrace_func_t___18)(long unsigned int, long unsigned int, struct ftrace_ops___18 *, struct pt_regs *);

struct ftrace_ops___18 {
	ftrace_func_t___18 func;
	struct ftrace_ops___18 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___47 regex_lock;
};

struct pmu___18;

struct fasync_struct___46;

struct pid_namespace___19;

struct ftrace_event_call___10;

struct perf_cgroup___18;

struct perf_event___18 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___18 *group_leader;
	struct pmu___18 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___18 hw;
	struct perf_event_context___18 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___47 child_mutex;
	struct list_head child_list;
	struct perf_event___18 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___47 *owner;
	struct mutex___47 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___46 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___18 *);
	struct callback_head callback_head;
	struct pid_namespace___19 *ns;
	u64 id;
	perf_overflow_handler_t___18 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___10 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___18 ftrace_ops;
	struct perf_cgroup___18 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___18 {
	struct task_struct___47 *task;
	struct exec_domain___11 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___46;

struct lruvec___46 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___46 *zone;
};

struct pglist_data___46;

struct zone___46 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___46 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___46 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___46 {
	struct zone___46 *zone;
	int zone_idx;
};

struct zonelist___46 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___46 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___46 {
	struct zone___46 node_zones[4];
	struct zonelist___46 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___47 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___30;

struct x86_io_apic_ops___30 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___30 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___30;

struct irq_data___30 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___30 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___37;

struct dev_pm_ops___37 {
	int (*prepare)(struct device___37 *);
	void (*complete)(struct device___37 *);
	int (*suspend)(struct device___37 *);
	int (*resume)(struct device___37 *);
	int (*freeze)(struct device___37 *);
	int (*thaw)(struct device___37 *);
	int (*poweroff)(struct device___37 *);
	int (*restore)(struct device___37 *);
	int (*suspend_late)(struct device___37 *);
	int (*resume_early)(struct device___37 *);
	int (*freeze_late)(struct device___37 *);
	int (*thaw_early)(struct device___37 *);
	int (*poweroff_late)(struct device___37 *);
	int (*restore_early)(struct device___37 *);
	int (*suspend_noirq)(struct device___37 *);
	int (*resume_noirq)(struct device___37 *);
	int (*freeze_noirq)(struct device___37 *);
	int (*thaw_noirq)(struct device___37 *);
	int (*poweroff_noirq)(struct device___37 *);
	int (*restore_noirq)(struct device___37 *);
	int (*runtime_suspend)(struct device___37 *);
	int (*runtime_resume)(struct device___37 *);
	int (*runtime_idle)(struct device___37 *);
};

struct device_type___37;

struct bus_type___37;

struct device_driver___37;

struct dev_pm_domain___37;

struct class___37;

struct attribute_group___32;

struct device_rh___37;

struct device___37 {
	struct device___37 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___37 *type;
	struct mutex___47 mutex;
	struct bus_type___37 *bus;
	struct device_driver___37 *driver;
	void *platform_data;
	struct dev_pm_info power;
	struct dev_pm_domain___37 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___18 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___37 *class;
	const struct attribute_group___32 **groups;
	void (*release)(struct device___37 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___37 *device_rh;
};

struct dev_pm_info_rh___37 {
	void (*set_latency_tolerance)(struct device___37 *, s32);
};

struct dev_pm_domain___37 {
	struct dev_pm_ops___37 ops;
};

struct smp_ops___46 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___47 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___32;

struct attribute_group___32 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___32 **bin_attrs;
};

struct bin_attribute___32 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___46 *, struct kobject *, struct bin_attribute___32 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___46 *, struct kobject *, struct bin_attribute___32 *, char *, loff_t, size_t);
	int (*mmap)(struct file___46 *, struct kobject *, struct bin_attribute___32 *, struct vm_area_struct___50 *);
};

struct dentry___47;

struct path___46 {
	struct vfsmount *mnt;
	struct dentry___47 *dentry;
};

struct fown_struct___19 {
	rwlock_t lock;
	struct pid___19 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___47;

struct file_operations___46;

struct file___46 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___46 f_path;
	struct inode___47 *f_inode;
	const struct file_operations___46 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___46 *f_mapping;
	struct mutex___47 f_pos_lock;
};

struct vm_operations_struct___40;

struct vm_area_struct___50 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___50 *vm_next;
	struct vm_area_struct___50 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___50 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___40 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___46 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___37 {
	void **freelist;
	long unsigned int tid;
	struct page___46 *page;
	struct page___46 *partial;
};

struct memcg_cache_params___37;

struct kmem_cache___37 {
	struct kmem_cache_cpu___37 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___37 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___37 {
	bool is_root_cache;
	union {
		struct kmem_cache___37 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___37 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct super_block___47;

struct dquot___46 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___47 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___47 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___46;

struct mem_dqinfo___46 {
	struct quota_format_type___46 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___46;

struct quota_info___46 {
	unsigned int flags;
	struct mutex___47 dqio_mutex;
	struct mutex___47 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___47 *files[2];
	struct mem_dqinfo___46 info[2];
	const struct quota_format_ops___46 *ops[2];
};

struct file_system_type___46;

struct super_operations___46;

struct dquot_operations___46;

struct quotactl_ops___46;

struct xattr_handler___21;

struct block_device___46;

struct dentry_operations___46;

struct super_block___47 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___46 *s_type;
	const struct super_operations___46 *s_op;
	const struct dquot_operations___46 *dq_op;
	const struct quotactl_ops___46 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___47 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___21 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___46 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___46 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___47 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___46 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___46 {
	int qf_fmt_id;
	const struct quota_format_ops___46 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___46 *qf_next;
};

struct quota_format_ops___46 {
	int (*check_quota_file)(struct super_block___47 *, int);
	int (*read_file_info)(struct super_block___47 *, int);
	int (*write_file_info)(struct super_block___47 *, int);
	int (*free_file_info)(struct super_block___47 *, int);
	int (*read_dqblk)(struct dquot___46 *);
	int (*commit_dqblk)(struct dquot___46 *);
	int (*release_dqblk)(struct dquot___46 *);
};

struct dquot_operations___46 {
	int (*write_dquot)(struct dquot___46 *);
	struct dquot___46 * (*alloc_dquot)(struct super_block___47 *, int);
	void (*destroy_dquot)(struct dquot___46 *);
	int (*acquire_dquot)(struct dquot___46 *);
	int (*release_dquot)(struct dquot___46 *);
	int (*mark_dirty)(struct dquot___46 *);
	int (*write_info)(struct super_block___47 *, int);
	qsize_t * (*get_reserved_space)(struct inode___47 *);
};

struct address_space_operations___46;

struct address_space___46 {
	struct inode___47 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___47 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___46 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___46;

struct file_lock___46;

struct inode___47 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___46 *i_op;
	struct super_block___47 *i_sb;
	struct address_space___46 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___47 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___46 *i_fop;
	struct file_lock___46 *i_flock;
	struct address_space___46 i_data;
	struct dquot___46 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___46 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___46 {
	int (*quota_on)(struct super_block___47 *, int, int, struct path___46 *);
	int (*quota_on_meta)(struct super_block___47 *, int, int);
	int (*quota_off)(struct super_block___47 *, int);
	int (*quota_sync)(struct super_block___47 *, int);
	int (*get_info)(struct super_block___47 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___47 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___47 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___47 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___47 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___47 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___47 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___47 *, unsigned int);
};

struct nsproxy___19 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___19 *pid_ns;
	struct net *net_ns;
};

struct xol_area___46 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___46 *page;
	long unsigned int vaddr;
};

typedef long unsigned int vm_flags_t;

struct vm_fault___37;

struct vm_operations_struct___40 {
	void (*open)(struct vm_area_struct___50 *);
	void (*close)(struct vm_area_struct___50 *);
	int (*fault)(struct vm_area_struct___50 *, struct vm_fault___37 *);
	int (*page_mkwrite)(struct vm_area_struct___50 *, struct vm_fault___37 *);
	int (*access)(struct vm_area_struct___50 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___50 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___50 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___50 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___50 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___46 {
	struct task_struct___47 *task;
	struct core_thread___46 *next;
};

struct core_state___46 {
	atomic_t nr_threads;
	struct core_thread___46 dumper;
	struct completion startup;
};

struct vm_fault___37 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___46 *page;
};

struct zap_details {
	struct vm_area_struct___50 *nonlinear_vma;
	struct address_space___46 *check_mapping;
	long unsigned int first_index;
	long unsigned int last_index;
};

struct seq_operations___29;

struct seq_file___29 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___47 lock;
	const struct seq_operations___29 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___29 {
	void * (*start)(struct seq_file___29 *, loff_t *);
	void (*stop)(struct seq_file___29 *, void *);
	void * (*next)(struct seq_file___29 *, void *, loff_t *);
	int (*show)(struct seq_file___29 *, void *);
};

struct dentry___47 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___47 *d_parent;
	struct qstr d_name;
	struct inode___47 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___46 *d_op;
	struct super_block___47 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___46 {
	int (*d_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_hash)(const struct dentry___47 *, struct qstr *);
	int (*d_compare)(const struct dentry___47 *, const struct dentry___47 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___47 *);
	void (*d_release)(struct dentry___47 *);
	void (*d_prune)(struct dentry___47 *);
	void (*d_iput)(struct dentry___47 *, struct inode___47 *);
	char * (*d_dname)(struct dentry___47 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___46 *);
	int (*d_manage)(struct dentry___47 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___19 {
	int nr;
	struct pid_namespace___19 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___19 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___47 *child_reaper;
	struct kmem_cache___37 *pid_cachep;
	unsigned int level;
	struct pid_namespace___19 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___47 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___19 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___19 numbers[1];
};

struct block_device___46 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___47 *bd_inode;
	struct super_block___47 *bd_super;
	struct mutex___47 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___46 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___47 bd_fsfreeze_mutex;
};

struct cgroup___21;

struct cgroup_subsys_state___21 {
	struct cgroup___21 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___47 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___46 *ia_file;
};

struct address_space_operations___46 {
	int (*writepage)(struct page___46 *, struct writeback_control *);
	int (*readpage)(struct file___46 *, struct page___46 *);
	int (*writepages)(struct address_space___46 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___46 *);
	int (*readpages)(struct file___46 *, struct address_space___46 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___46 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___46 **, void **);
	int (*write_end)(struct file___46 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___46 *, void *);
	sector_t (*bmap)(struct address_space___46 *, sector_t);
	void (*invalidatepage)(struct page___46 *, long unsigned int);
	int (*releasepage)(struct page___46 *, gfp_t);
	void (*freepage)(struct page___46 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___46 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___46 *, struct page___46 *, struct page___46 *, enum migrate_mode);
	int (*launder_page)(struct page___46 *);
	int (*is_partially_uptodate)(struct page___46 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___46 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___46 *, struct page___46 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___46 *, sector_t *);
	void (*swap_deactivate)(struct file___46 *);
	void (*invalidatepage_range)(struct page___46 *, unsigned int, unsigned int);
};

struct inode_operations___46 {
	struct dentry___47 * (*lookup)(struct inode___47 *, struct dentry___47 *, unsigned int);
	void * (*follow_link)(struct dentry___47 *, struct nameidata *);
	int (*permission)(struct inode___47 *, int);
	struct posix_acl * (*get_acl)(struct inode___47 *, int);
	int (*readlink)(struct dentry___47 *, char *, int);
	void (*put_link)(struct dentry___47 *, struct nameidata *, void *);
	int (*create)(struct inode___47 *, struct dentry___47 *, umode_t, bool);
	int (*link)(struct dentry___47 *, struct inode___47 *, struct dentry___47 *);
	int (*unlink)(struct inode___47 *, struct dentry___47 *);
	int (*symlink)(struct inode___47 *, struct dentry___47 *, const char *);
	int (*mkdir)(struct inode___47 *, struct dentry___47 *, umode_t);
	int (*rmdir)(struct inode___47 *, struct dentry___47 *);
	int (*mknod)(struct inode___47 *, struct dentry___47 *, umode_t, dev_t);
	int (*rename)(struct inode___47 *, struct dentry___47 *, struct inode___47 *, struct dentry___47 *);
	int (*setattr)(struct dentry___47 *, struct iattr___47 *);
	int (*getattr)(struct vfsmount *, struct dentry___47 *, struct kstat *);
	int (*setxattr)(struct dentry___47 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___47 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___47 *, char *, size_t);
	int (*removexattr)(struct dentry___47 *, const char *);
	int (*fiemap)(struct inode___47 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___47 *, struct timespec *, int);
	int (*atomic_open)(struct inode___47 *, struct dentry___47 *, struct file___46 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___25;

struct file_operations___46 {
	struct module *owner;
	loff_t (*llseek)(struct file___46 *, loff_t, int);
	ssize_t (*read)(struct file___46 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___46 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___46 *, void *, filldir_t);
	unsigned int (*poll)(struct file___46 *, struct poll_table_struct___25 *);
	long int (*unlocked_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___46 *, struct vm_area_struct___50 *);
	int (*open)(struct inode___47 *, struct file___46 *);
	int (*flush)(struct file___46 *, fl_owner_t);
	int (*release)(struct inode___47 *, struct file___46 *);
	int (*fsync)(struct file___46 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___46 *, int);
	int (*lock)(struct file___46 *, int, struct file_lock___46 *);
	ssize_t (*sendpage)(struct file___46 *, struct page___46 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___46 *, int, struct file_lock___46 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___46 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___46 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___46 *, long int, struct file_lock___46 **, void **);
		struct {
			int (*setlease)(struct file___46 *, long int, struct file_lock___46 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___46 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___29 *, struct file___46 *);
};

struct file_lock_operations___46;

struct lock_manager_operations___46;

struct file_lock___46 {
	struct file_lock___46 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___19 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___46 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___46 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___46 *fl_ops;
	const struct lock_manager_operations___46 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___46 {
	void (*fl_copy_lock)(struct file_lock___46 *, struct file_lock___46 *);
	void (*fl_release_private)(struct file_lock___46 *);
};

struct lock_manager_operations___46 {
	int (*lm_compare_owner)(struct file_lock___46 *, struct file_lock___46 *);
	long unsigned int (*lm_owner_key)(struct file_lock___46 *);
	void (*lm_notify)(struct file_lock___46 *);
	int (*lm_grant)(struct file_lock___46 *, struct file_lock___46 *, int);
	void (*lm_break)(struct file_lock___46 *);
	int (*lm_change)(struct file_lock___46 **, int);
};

struct fasync_struct___46 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___46 *fa_next;
	struct file___46 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___46 {
	const char *name;
	int fs_flags;
	struct dentry___47 * (*mount)(struct file_system_type___46 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___47 *);
	struct module *owner;
	struct file_system_type___46 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___46 {
	struct inode___47 * (*alloc_inode)(struct super_block___47 *);
	void (*destroy_inode)(struct inode___47 *);
	void (*dirty_inode)(struct inode___47 *, int);
	int (*write_inode)(struct inode___47 *, struct writeback_control *);
	int (*drop_inode)(struct inode___47 *);
	void (*evict_inode)(struct inode___47 *);
	void (*put_super)(struct super_block___47 *);
	int (*sync_fs)(struct super_block___47 *, int);
	int (*freeze_fs)(struct super_block___47 *);
	int (*unfreeze_fs)(struct super_block___47 *);
	int (*statfs)(struct dentry___47 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___47 *, int *, char *);
	void (*umount_begin)(struct super_block___47 *);
	int (*show_options)(struct seq_file___29 *, struct dentry___47 *);
	int (*show_devname)(struct seq_file___29 *, struct dentry___47 *);
	int (*show_path)(struct seq_file___29 *, struct dentry___47 *);
	int (*show_stats)(struct seq_file___29 *, struct dentry___47 *);
	ssize_t (*quota_read)(struct super_block___47 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___47 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___47 *);
	int (*bdev_try_to_free_page)(struct super_block___47 *, struct page___46 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___47 *);
	void (*free_cached_objects)(struct super_block___47 *, int);
};

struct xattr_handler___21 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___47 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___47 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___47 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___25)(struct file___46 *, wait_queue_head_t *, struct poll_table_struct___25 *);

struct poll_table_struct___25 {
	poll_queue_proc___25 _qproc;
	long unsigned int _key;
};

struct irq_chip___30 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___30 *);
	void (*irq_shutdown)(struct irq_data___30 *);
	void (*irq_enable)(struct irq_data___30 *);
	void (*irq_disable)(struct irq_data___30 *);
	void (*irq_ack)(struct irq_data___30 *);
	void (*irq_mask)(struct irq_data___30 *);
	void (*irq_mask_ack)(struct irq_data___30 *);
	void (*irq_unmask)(struct irq_data___30 *);
	void (*irq_eoi)(struct irq_data___30 *);
	int (*irq_set_affinity)(struct irq_data___30 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___30 *);
	int (*irq_set_type)(struct irq_data___30 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___30 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___30 *);
	void (*irq_bus_sync_unlock)(struct irq_data___30 *);
	void (*irq_cpu_online)(struct irq_data___30 *);
	void (*irq_cpu_offline)(struct irq_data___30 *);
	void (*irq_suspend)(struct irq_data___30 *);
	void (*irq_resume)(struct irq_data___30 *);
	void (*irq_pm_shutdown)(struct irq_data___30 *);
	void (*irq_print_chip)(struct irq_data___30 *, struct seq_file___29 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___30 *, void *);
	long unsigned int flags;
};

struct signal_struct___46 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___47 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___47 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___19 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___47 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___21 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___21 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___18 {
	struct pmu___18 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___47 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___47 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___18 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bus_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___37 *, char *);
	ssize_t (*store)(struct bus_type___37 *, const char *, size_t);
};

struct device_attribute___37;

struct driver_attribute___37;

struct bus_type___37 {
	const char *name;
	const char *dev_name;
	struct device___37 *dev_root;
	struct bus_attribute___37 *bus_attrs;
	struct device_attribute___37 *dev_attrs;
	struct driver_attribute___37 *drv_attrs;
	const struct attribute_group___32 **bus_groups;
	const struct attribute_group___32 **dev_groups;
	const struct attribute_group___32 **drv_groups;
	int (*match)(struct device___37 *, struct device_driver___37 *);
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	int (*probe)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*online)(struct device___37 *);
	int (*offline)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct device___37 *, struct device_attribute___37 *, char *);
	ssize_t (*store)(struct device___37 *, struct device_attribute___37 *, const char *, size_t);
};

struct driver_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___37 *, char *);
	ssize_t (*store)(struct device_driver___37 *, const char *, size_t);
};

struct device_driver___37 {
	const char *name;
	struct bus_type___37 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct attribute_group___32 **groups;
	const struct dev_pm_ops___37 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___37 {
	const char *name;
	const struct attribute_group___32 **groups;
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
};

struct class_attribute___37;

struct class___37 {
	const char *name;
	struct module *owner;
	struct class_attribute___37 *class_attrs;
	struct device_attribute___37 *dev_attrs;
	const struct attribute_group___32 **dev_groups;
	struct bin_attribute___32 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *);
	void (*class_release)(struct class___37 *);
	void (*dev_release)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	struct subsys_private *p;
};

struct class_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct class___37 *, struct class_attribute___37 *, char *);
	ssize_t (*store)(struct class___37 *, struct class_attribute___37 *, const char *, size_t);
	const void * (*namespace)(struct class___37 *, const struct class_attribute___37 *);
};

struct device_rh___37 {
	struct dev_pm_info_rh___37 power;
};

struct cgroupfs_root___21;

struct cgroup___21 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___21 *parent;
	struct dentry___47 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___21 *subsys[11];
	struct cgroupfs_root___21 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___47 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___21 {
	struct super_block___47 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___21 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___18;

struct pmu___18 {
	struct list_head entry;
	struct device___37 *dev;
	const struct attribute_group___32 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___18 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___18 *);
	void (*pmu_disable)(struct pmu___18 *);
	int (*event_init)(struct perf_event___18 *);
	int (*add)(struct perf_event___18 *, int);
	void (*del)(struct perf_event___18 *, int);
	void (*start)(struct perf_event___18 *, int);
	void (*stop)(struct perf_event___18 *, int);
	void (*read)(struct perf_event___18 *);
	void (*start_txn)(struct pmu___18 *);
	int (*commit_txn)(struct pmu___18 *);
	void (*cancel_txn)(struct pmu___18 *);
	int (*event_idx)(struct perf_event___18 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___18 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___18 *);
};

struct perf_cpu_context___18 {
	struct perf_event_context___18 ctx;
	struct perf_event_context___18 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___18 *unique_pmu;
	struct perf_cgroup___18 *cgrp;
};

struct trace_event_functions___10;

struct trace_event___10 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___10 *funcs;
};

struct ftrace_event_class___10;

struct ftrace_event_call___10 {
	struct list_head list;
	struct ftrace_event_class___10 *class;
	char *name;
	struct trace_event___10 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___18 {
	struct cgroup_subsys_state___21 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___10 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___47 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___10)(struct trace_iterator___10 *, int, struct trace_event___10 *);

struct trace_event_functions___10 {
	trace_print_func___10 trace;
	trace_print_func___10 raw;
	trace_print_func___10 hex;
	trace_print_func___10 binary;
};

struct ftrace_event_class___10 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___10 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___10 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___10 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___10 *);
};

struct ftrace_event_file___5 {
	struct list_head list;
	struct ftrace_event_call___10 *event_call;
	struct dentry___47 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct tlb_state___17 {
	struct mm_struct___50 *active_mm;
	int state;
};

struct ftrace_raw_mpx_bounds_register_exception {
	struct trace_entry ent;
	void *addr_referenced;
	u64 lower_bound;
	u64 upper_bound;
	char __data[0];
};

struct ftrace_raw_bounds_exception_mpx {
	struct trace_entry ent;
	u64 bndcfgu;
	u64 bndstatus;
	char __data[0];
};

struct ftrace_raw_mpx_range_trace {
	struct trace_entry ent;
	long unsigned int start;
	long unsigned int end;
	char __data[0];
};

struct ftrace_raw_mpx_new_bounds_table {
	struct trace_entry ent;
	long unsigned int table_vaddr;
	char __data[0];
};

struct ftrace_data_offsets_mpx_bounds_register_exception {};

struct ftrace_data_offsets_bounds_exception_mpx {};

struct ftrace_data_offsets_mpx_range_trace {};

struct ftrace_data_offsets_mpx_new_bounds_table {};

enum reg_type {
	REG_TYPE_RM = 0,
	REG_TYPE_INDEX = 1,
	REG_TYPE_BASE = 2,
};

struct crypto_async_request;

typedef void (*crypto_completion_t)(struct crypto_async_request *, int);

struct crypto_tfm;

struct crypto_async_request {
	struct list_head list;
	crypto_completion_t complete;
	void *data;
	struct crypto_tfm *tfm;
	u32 flags;
};

struct crypto_ablkcipher;

struct ablkcipher_request;

struct skcipher_givcrypt_request;

struct ablkcipher_tfm {
	int (*setkey)(struct crypto_ablkcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request *);
	int (*decrypt)(struct ablkcipher_request *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead;

struct aead_request;

struct aead_givcrypt_request;

struct aead_tfm {
	int (*setkey)(struct crypto_aead *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request *);
	int (*decrypt)(struct aead_request *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc;

struct blkcipher_tfm {
	void *iv;
	int (*setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm {
	int (*cit_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm *, u8 *, const u8 *);
};

struct hash_desc;

struct crypto_hash;

struct hash_tfm {
	int (*init)(struct hash_desc *);
	int (*update)(struct hash_desc *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc *, u8 *);
	int (*digest)(struct hash_desc *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm {
	int (*cot_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng;

struct rng_tfm {
	int (*rng_gen_random)(struct crypto_rng *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng *, u8 *, unsigned int);
};

struct crypto_alg;

struct crypto_tfm {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm ablkcipher;
		struct aead_tfm aead;
		struct blkcipher_tfm blkcipher;
		struct cipher_tfm cipher;
		struct hash_tfm hash;
		struct compress_tfm compress;
		struct rng_tfm rng;
	} crt_u;
	void (*exit)(struct crypto_tfm *);
	struct crypto_alg *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request {
	struct crypto_async_request base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request {
	struct crypto_async_request base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher;

struct blkcipher_desc {
	struct crypto_blkcipher *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher {
	struct crypto_tfm base;
};

struct hash_desc {
	struct crypto_hash *tfm;
	u32 flags;
};

struct crypto_hash {
	struct crypto_tfm base;
};

struct ablkcipher_alg {
	int (*setkey)(struct crypto_ablkcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request *);
	int (*decrypt)(struct ablkcipher_request *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher {
	struct crypto_tfm base;
};

struct aead_alg {
	int (*setkey)(struct crypto_aead *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead *, unsigned int);
	int (*encrypt)(struct aead_request *);
	int (*decrypt)(struct aead_request *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead {
	struct crypto_tfm base;
};

struct blkcipher_alg {
	int (*setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm *, u8 *, const u8 *);
};

struct compress_alg {
	int (*coa_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg {
	int (*rng_make_random)(struct crypto_rng *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng {
	struct crypto_tfm base;
};

struct crypto_type;

struct crypto_alg {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg ablkcipher;
		struct aead_alg aead;
		struct blkcipher_alg blkcipher;
		struct cipher_alg cipher;
		struct compress_alg compress;
		struct rng_alg rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm *);
	void (*cra_exit)(struct crypto_tfm *);
	void (*cra_destroy)(struct crypto_alg *);
	struct module___30 *cra_module;
};

struct crypto_alg___2;

struct crypto_tfm___2;

struct seq_file___30;

struct sk_buff___4;

struct crypto_type {
	unsigned int (*ctxsize)(struct crypto_alg___2 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___2 *);
	int (*init)(struct crypto_tfm___2 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___2 *);
	void (*show)(struct seq_file___30 *, struct crypto_alg___2 *);
	int (*report)(struct sk_buff___4 *, struct crypto_alg___2 *);
	struct crypto_alg___2 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_aes_ctx {
	u32 key_enc[60];
	u32 key_dec[60];
	u32 key_length;
};

struct linux_binprm;

typedef struct ctl_table ctl_table;

typedef __u32 Elf32_Addr;

typedef __u16 Elf32_Half;

typedef __u32 Elf32_Off;

typedef __s32 Elf32_Sword;

typedef __u32 Elf32_Word;

struct dynamic {
	Elf32_Sword d_tag;
	union {
		Elf32_Sword d_val;
		Elf32_Addr d_ptr;
	} d_un;
};

typedef struct dynamic Elf32_Dyn;

struct elf32_sym {
	Elf32_Word st_name;
	Elf32_Addr st_value;
	Elf32_Word st_size;
	unsigned char st_info;
	unsigned char st_other;
	Elf32_Half st_shndx;
};

typedef struct elf32_sym Elf32_Sym;

struct elf32_hdr {
	unsigned char e_ident[16];
	Elf32_Half e_type;
	Elf32_Half e_machine;
	Elf32_Word e_version;
	Elf32_Addr e_entry;
	Elf32_Off e_phoff;
	Elf32_Off e_shoff;
	Elf32_Word e_flags;
	Elf32_Half e_ehsize;
	Elf32_Half e_phentsize;
	Elf32_Half e_phnum;
	Elf32_Half e_shentsize;
	Elf32_Half e_shnum;
	Elf32_Half e_shstrndx;
};

typedef struct elf32_hdr Elf32_Ehdr;

struct elf32_phdr {
	Elf32_Word p_type;
	Elf32_Off p_offset;
	Elf32_Addr p_vaddr;
	Elf32_Addr p_paddr;
	Elf32_Word p_filesz;
	Elf32_Word p_memsz;
	Elf32_Word p_flags;
	Elf32_Word p_align;
};

typedef struct elf32_phdr Elf32_Phdr;

struct elf32_shdr {
	Elf32_Word sh_name;
	Elf32_Word sh_type;
	Elf32_Word sh_flags;
	Elf32_Addr sh_addr;
	Elf32_Off sh_offset;
	Elf32_Word sh_size;
	Elf32_Word sh_link;
	Elf32_Word sh_info;
	Elf32_Word sh_addralign;
	Elf32_Word sh_entsize;
};

typedef struct elf32_shdr Elf32_Shdr;

enum {
	VDSO_DISABLED = 0,
	VDSO_ENABLED = 1,
	VDSO_COMPAT = 2,
};

typedef short unsigned int __kernel_old_uid_t;

typedef short unsigned int __kernel_old_gid_t;

typedef struct {
	int val[2];
} __kernel_fsid_t;

typedef __kernel_old_uid_t old_uid_t;

typedef __kernel_old_gid_t old_gid_t;

struct kstatfs {
	long int f_type;
	long int f_bsize;
	u64 f_blocks;
	u64 f_bfree;
	u64 f_bavail;
	u64 f_files;
	u64 f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

typedef s32 compat_pid_t;

struct compat_timeval {
	compat_time_t tv_sec;
	s32 tv_usec;
};

struct compat_rusage {
	struct compat_timeval ru_utime;
	struct compat_timeval ru_stime;
	compat_long_t ru_maxrss;
	compat_long_t ru_ixrss;
	compat_long_t ru_idrss;
	compat_long_t ru_isrss;
	compat_long_t ru_minflt;
	compat_long_t ru_majflt;
	compat_long_t ru_nswap;
	compat_long_t ru_inblock;
	compat_long_t ru_oublock;
	compat_long_t ru_msgsnd;
	compat_long_t ru_msgrcv;
	compat_long_t ru_nsignals;
	compat_long_t ru_nvcsw;
	compat_long_t ru_nivcsw;
};

struct stat64 {
	long long unsigned int st_dev;
	unsigned char __pad0[4];
	unsigned int __st_ino;
	unsigned int st_mode;
	unsigned int st_nlink;
	unsigned int st_uid;
	unsigned int st_gid;
	long long unsigned int st_rdev;
	unsigned char __pad3[4];
	long long int st_size;
	unsigned int st_blksize;
	long long int st_blocks;
	unsigned int st_atime;
	unsigned int st_atime_nsec;
	unsigned int st_mtime;
	unsigned int st_mtime_nsec;
	unsigned int st_ctime;
	unsigned int st_ctime_nsec;
	long long unsigned int st_ino;
} __attribute__((packed));

struct mmap_arg_struct32 {
	unsigned int addr;
	unsigned int len;
	unsigned int prot;
	unsigned int flags;
	unsigned int fd;
	unsigned int offset;
};

struct linux_binprm___2;

struct coredump_params;

struct linux_binfmt {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___2 *);
	int (*load_shlib)(struct file___43 *);
	int (*core_dump)(struct coredump_params *);
	long unsigned int min_coredump;
};

typedef u32 compat_size_t;

typedef s32 compat_clock_t;

typedef s32 compat_timer_t;

typedef s32 compat_int_t;

typedef s64 compat_s64;

union compat_sigval {
	compat_int_t sival_int;
	compat_uptr_t sival_ptr;
};

typedef union compat_sigval compat_sigval_t;

struct compat_siginfo {
	int si_signo;
	int si_errno;
	int si_code;
	union {
		int _pad[29];
		struct {
			unsigned int _pid;
			unsigned int _uid;
		} _kill;
		struct {
			compat_timer_t _tid;
			int _overrun;
			compat_sigval_t _sigval;
			int _sys_private;
			int _overrun_incr;
		} _timer;
		struct {
			unsigned int _pid;
			unsigned int _uid;
			compat_sigval_t _sigval;
		} _rt;
		struct {
			unsigned int _pid;
			unsigned int _uid;
			int _status;
			compat_clock_t _utime;
			compat_clock_t _stime;
		} _sigchld;
		struct {
			unsigned int _pid;
			unsigned int _uid;
			int _status;
			compat_s64 _utime;
			compat_s64 _stime;
		} __attribute__((packed)) _sigchld_x32;
		struct {
			unsigned int _addr;
		} _sigfault;
		struct {
			int _band;
			int _fd;
		} _sigpoll;
		struct {
			unsigned int _call_addr;
			int _syscall;
			unsigned int _arch;
		} _sigsys;
	} _sifields;
} __attribute__((packed));

typedef struct compat_siginfo compat_siginfo_t;

struct compat_sigaltstack {
	compat_uptr_t ss_sp;
	int ss_flags;
	compat_size_t ss_size;
};

typedef struct compat_sigaltstack compat_stack_t;

struct linux_binprm___2 {
	char buf[128];
	struct vm_area_struct___47 *vma;
	long unsigned int vma_pages;
	struct mm_struct___47 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___43 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___43 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct sigcontext_ia32 {
	short unsigned int gs;
	short unsigned int __gsh;
	short unsigned int fs;
	short unsigned int __fsh;
	short unsigned int es;
	short unsigned int __esh;
	short unsigned int ds;
	short unsigned int __dsh;
	unsigned int di;
	unsigned int si;
	unsigned int bp;
	unsigned int sp;
	unsigned int bx;
	unsigned int dx;
	unsigned int cx;
	unsigned int ax;
	unsigned int trapno;
	unsigned int err;
	unsigned int ip;
	short unsigned int cs;
	short unsigned int __csh;
	unsigned int flags;
	unsigned int sp_at_signal;
	short unsigned int ss;
	short unsigned int __ssh;
	unsigned int fpstate;
	unsigned int oldmask;
	unsigned int cr2;
};

struct ucontext_ia32 {
	unsigned int uc_flags;
	unsigned int uc_link;
	compat_stack_t uc_stack;
	struct sigcontext_ia32 uc_mcontext;
	compat_sigset_t uc_sigmask;
};

struct sigframe_ia32 {
	u32 pretcode;
	int sig;
	struct sigcontext_ia32 sc;
	struct _fpstate_ia32 fpstate_unused;
	unsigned int extramask[1];
	char retcode[8];
};

struct rt_sigframe_ia32 {
	u32 pretcode;
	int sig;
	u32 pinfo;
	u32 puc;
	compat_siginfo_t info;
	struct ucontext_ia32 uc;
	char retcode[8];
} __attribute__((packed));

struct page___47;

typedef struct page___47 *pgtable_t___47;

struct address_space___47;

struct kmem_cache___38;

struct page___47 {
	long unsigned int flags;
	struct address_space___47 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___47 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___47 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___38 *slab_cache;
		struct page___47 *first_page;
	};
	long: 64;
};

struct task_struct___48;

struct pv_cpu_ops___47 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___18 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___18 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___48 *);
	void (*end_context_switch)(struct task_struct___48 *);
};

struct mutex___48 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___48 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___44 {
	struct page___47 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___51;

struct signal_struct___47;

struct task_struct___48 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___48 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___51 *mm;
	struct mm_struct___51 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___48 *real_parent;
	struct task_struct___48 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___48 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___19 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___47 = 0,
		VTIME_USER___47 = 1,
		VTIME_SYS___47 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___18 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___47 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___48 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___44 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___51 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___51 *, struct mm_struct___51 *);
	void (*dup_mmap)(struct mm_struct___51 *, struct mm_struct___51 *);
	void (*exit_mmap)(struct mm_struct___51 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___51 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___51 *);
	void (*pgd_free)(struct mm_struct___51 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___51 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___51 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___51 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___51 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___51 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___51 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___51 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___51 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___51 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___51 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___51 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___48 lock;
	void *vdso;
} mm_context_t___48;

struct xol_area___47;

struct uprobes_state___47 {
	struct xol_area___47 *xol_area;
};

struct vm_area_struct___51;

struct file___47;

struct core_state___47;

struct mm_struct___51 {
	struct vm_area_struct___51 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___51 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___51 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___48 context;
	long unsigned int flags;
	struct core_state___47 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___48 *owner;
	struct file___47 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___47 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___48;

struct dentry_operations___47;

struct super_block___48;

struct dentry___48 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___48 *d_parent;
	struct qstr d_name;
	struct inode___48 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___47 *d_op;
	struct super_block___48 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___47;

struct address_space___47 {
	struct inode___48 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___48 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___47 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___47;

struct file_operations___47;

struct file_lock___47;

struct dquot___47;

struct block_device___47;

struct cdev___19;

struct inode___48 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___47 *i_op;
	struct super_block___48 *i_sb;
	struct address_space___47 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___48 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___47 *i_fop;
	struct file_lock___47 *i_flock;
	struct address_space___47 i_data;
	struct dquot___47 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___47 *i_bdev;
		struct cdev___19 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___47;

struct dentry_operations___47 {
	int (*d_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_hash)(const struct dentry___48 *, struct qstr *);
	int (*d_compare)(const struct dentry___48 *, const struct dentry___48 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___48 *);
	void (*d_release)(struct dentry___48 *);
	void (*d_prune)(struct dentry___48 *);
	void (*d_iput)(struct dentry___48 *, struct inode___48 *);
	char * (*d_dname)(struct dentry___48 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___47 *);
	int (*d_manage)(struct dentry___48 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___47;

struct mem_dqinfo___47 {
	struct quota_format_type___47 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___47;

struct quota_info___47 {
	unsigned int flags;
	struct mutex___48 dqio_mutex;
	struct mutex___48 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___48 *files[2];
	struct mem_dqinfo___47 info[2];
	const struct quota_format_ops___47 *ops[2];
};

struct file_system_type___47;

struct super_operations___47;

struct dquot_operations___47;

struct quotactl_ops___47;

struct super_block___48 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___47 *s_type;
	const struct super_operations___47 *s_op;
	const struct dquot_operations___47 *dq_op;
	const struct quotactl_ops___47 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___48 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___47 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___47 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___48 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___47 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___47 {
	struct vfsmount *mnt;
	struct dentry___48 *dentry;
};

struct irq_data___31;

struct x86_io_apic_ops___31 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___31 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___31;

struct irq_data___31 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___31 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___47 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___48 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___47 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___48 *bd_inode;
	struct super_block___48 *bd_super;
	struct mutex___48 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___47 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___48 bd_fsfreeze_mutex;
};

struct iattr___48 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___47 *ia_file;
};

struct file___47 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___47 f_path;
	struct inode___48 *f_inode;
	const struct file_operations___47 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___47 *f_mapping;
	struct mutex___48 f_pos_lock;
};

struct zone___47;

struct lruvec___47 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___47 *zone;
};

struct pglist_data___47;

struct zone___47 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___47 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___47 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___47 {
	struct zone___47 *zone;
	int zone_idx;
};

struct zonelist___47 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___47 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___47 {
	struct zone___47 node_zones[4];
	struct zonelist___47 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___48 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___47 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___48 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___48 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___47 {
	int qf_fmt_id;
	const struct quota_format_ops___47 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___47 *qf_next;
};

struct quota_format_ops___47 {
	int (*check_quota_file)(struct super_block___48 *, int);
	int (*read_file_info)(struct super_block___48 *, int);
	int (*write_file_info)(struct super_block___48 *, int);
	int (*free_file_info)(struct super_block___48 *, int);
	int (*read_dqblk)(struct dquot___47 *);
	int (*commit_dqblk)(struct dquot___47 *);
	int (*release_dqblk)(struct dquot___47 *);
};

struct dquot_operations___47 {
	int (*write_dquot)(struct dquot___47 *);
	struct dquot___47 * (*alloc_dquot)(struct super_block___48 *, int);
	void (*destroy_dquot)(struct dquot___47 *);
	int (*acquire_dquot)(struct dquot___47 *);
	int (*release_dquot)(struct dquot___47 *);
	int (*mark_dirty)(struct dquot___47 *);
	int (*write_info)(struct super_block___48 *, int);
	qsize_t * (*get_reserved_space)(struct inode___48 *);
};

struct quotactl_ops___47 {
	int (*quota_on)(struct super_block___48 *, int, int, struct path___47 *);
	int (*quota_on_meta)(struct super_block___48 *, int, int);
	int (*quota_off)(struct super_block___48 *, int);
	int (*quota_sync)(struct super_block___48 *, int);
	int (*get_info)(struct super_block___48 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___48 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___48 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___48 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___48 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___48 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___48 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___48 *, unsigned int);
};

struct address_space_operations___47 {
	int (*writepage)(struct page___47 *, struct writeback_control *);
	int (*readpage)(struct file___47 *, struct page___47 *);
	int (*writepages)(struct address_space___47 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___47 *);
	int (*readpages)(struct file___47 *, struct address_space___47 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___47 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___47 **, void **);
	int (*write_end)(struct file___47 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___47 *, void *);
	sector_t (*bmap)(struct address_space___47 *, sector_t);
	void (*invalidatepage)(struct page___47 *, long unsigned int);
	int (*releasepage)(struct page___47 *, gfp_t);
	void (*freepage)(struct page___47 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___47 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___47 *, struct page___47 *, struct page___47 *, enum migrate_mode);
	int (*launder_page)(struct page___47 *);
	int (*is_partially_uptodate)(struct page___47 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___47 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___47 *, struct page___47 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___47 *, sector_t *);
	void (*swap_deactivate)(struct file___47 *);
	void (*invalidatepage_range)(struct page___47 *, unsigned int, unsigned int);
};

struct cdev___19 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___47 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___47 {
	struct dentry___48 * (*lookup)(struct inode___48 *, struct dentry___48 *, unsigned int);
	void * (*follow_link)(struct dentry___48 *, struct nameidata *);
	int (*permission)(struct inode___48 *, int);
	struct posix_acl * (*get_acl)(struct inode___48 *, int);
	int (*readlink)(struct dentry___48 *, char *, int);
	void (*put_link)(struct dentry___48 *, struct nameidata *, void *);
	int (*create)(struct inode___48 *, struct dentry___48 *, umode_t, bool);
	int (*link)(struct dentry___48 *, struct inode___48 *, struct dentry___48 *);
	int (*unlink)(struct inode___48 *, struct dentry___48 *);
	int (*symlink)(struct inode___48 *, struct dentry___48 *, const char *);
	int (*mkdir)(struct inode___48 *, struct dentry___48 *, umode_t);
	int (*rmdir)(struct inode___48 *, struct dentry___48 *);
	int (*mknod)(struct inode___48 *, struct dentry___48 *, umode_t, dev_t);
	int (*rename)(struct inode___48 *, struct dentry___48 *, struct inode___48 *, struct dentry___48 *);
	int (*setattr)(struct dentry___48 *, struct iattr___48 *);
	int (*getattr)(struct vfsmount *, struct dentry___48 *, struct kstat *);
	int (*setxattr)(struct dentry___48 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___48 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___48 *, char *, size_t);
	int (*removexattr)(struct dentry___48 *, const char *);
	int (*fiemap)(struct inode___48 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___48 *, struct timespec *, int);
	int (*atomic_open)(struct inode___48 *, struct dentry___48 *, struct file___47 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___26;

struct seq_file___31;

struct file_operations___47 {
	struct module *owner;
	loff_t (*llseek)(struct file___47 *, loff_t, int);
	ssize_t (*read)(struct file___47 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___47 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___47 *, void *, filldir_t);
	unsigned int (*poll)(struct file___47 *, struct poll_table_struct___26 *);
	long int (*unlocked_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___47 *, struct vm_area_struct___51 *);
	int (*open)(struct inode___48 *, struct file___47 *);
	int (*flush)(struct file___47 *, fl_owner_t);
	int (*release)(struct inode___48 *, struct file___47 *);
	int (*fsync)(struct file___47 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___47 *, int);
	int (*lock)(struct file___47 *, int, struct file_lock___47 *);
	ssize_t (*sendpage)(struct file___47 *, struct page___47 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___47 *, int, struct file_lock___47 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___47 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___47 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___47 *, long int, struct file_lock___47 **, void **);
		struct {
			int (*setlease)(struct file___47 *, long int, struct file_lock___47 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___47 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___31 *, struct file___47 *);
};

struct fasync_struct___47;

struct file_lock_operations___47;

struct lock_manager_operations___47;

struct file_lock___47 {
	struct file_lock___47 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___19 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___47 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___47 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___47 *fl_ops;
	const struct lock_manager_operations___47 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___47 {
	void (*fl_copy_lock)(struct file_lock___47 *, struct file_lock___47 *);
	void (*fl_release_private)(struct file_lock___47 *);
};

struct lock_manager_operations___47 {
	int (*lm_compare_owner)(struct file_lock___47 *, struct file_lock___47 *);
	long unsigned int (*lm_owner_key)(struct file_lock___47 *);
	void (*lm_notify)(struct file_lock___47 *);
	int (*lm_grant)(struct file_lock___47 *, struct file_lock___47 *, int);
	void (*lm_break)(struct file_lock___47 *);
	int (*lm_change)(struct file_lock___47 **, int);
};

struct fasync_struct___47 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___47 *fa_next;
	struct file___47 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___47 {
	const char *name;
	int fs_flags;
	struct dentry___48 * (*mount)(struct file_system_type___47 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___48 *);
	struct module *owner;
	struct file_system_type___47 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___47 {
	struct inode___48 * (*alloc_inode)(struct super_block___48 *);
	void (*destroy_inode)(struct inode___48 *);
	void (*dirty_inode)(struct inode___48 *, int);
	int (*write_inode)(struct inode___48 *, struct writeback_control *);
	int (*drop_inode)(struct inode___48 *);
	void (*evict_inode)(struct inode___48 *);
	void (*put_super)(struct super_block___48 *);
	int (*sync_fs)(struct super_block___48 *, int);
	int (*freeze_fs)(struct super_block___48 *);
	int (*unfreeze_fs)(struct super_block___48 *);
	int (*statfs)(struct dentry___48 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___48 *, int *, char *);
	void (*umount_begin)(struct super_block___48 *);
	int (*show_options)(struct seq_file___31 *, struct dentry___48 *);
	int (*show_devname)(struct seq_file___31 *, struct dentry___48 *);
	int (*show_path)(struct seq_file___31 *, struct dentry___48 *);
	int (*show_stats)(struct seq_file___31 *, struct dentry___48 *);
	ssize_t (*quota_read)(struct super_block___48 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___48 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___48 *);
	int (*bdev_try_to_free_page)(struct super_block___48 *, struct page___47 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___48 *);
	void (*free_cached_objects)(struct super_block___48 *, int);
};

typedef void (*poll_queue_proc___26)(struct file___47 *, wait_queue_head_t *, struct poll_table_struct___26 *);

struct poll_table_struct___26 {
	poll_queue_proc___26 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___41;

struct vm_area_struct___51 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___51 *vm_next;
	struct vm_area_struct___51 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___51 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___41 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___47 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___30;

struct seq_file___31 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___48 lock;
	const struct seq_operations___30 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___31 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___31 *);
	void (*irq_shutdown)(struct irq_data___31 *);
	void (*irq_enable)(struct irq_data___31 *);
	void (*irq_disable)(struct irq_data___31 *);
	void (*irq_ack)(struct irq_data___31 *);
	void (*irq_mask)(struct irq_data___31 *);
	void (*irq_mask_ack)(struct irq_data___31 *);
	void (*irq_unmask)(struct irq_data___31 *);
	void (*irq_eoi)(struct irq_data___31 *);
	int (*irq_set_affinity)(struct irq_data___31 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___31 *);
	int (*irq_set_type)(struct irq_data___31 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___31 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___31 *);
	void (*irq_bus_sync_unlock)(struct irq_data___31 *);
	void (*irq_cpu_online)(struct irq_data___31 *);
	void (*irq_cpu_offline)(struct irq_data___31 *);
	void (*irq_suspend)(struct irq_data___31 *);
	void (*irq_resume)(struct irq_data___31 *);
	void (*irq_pm_shutdown)(struct irq_data___31 *);
	void (*irq_print_chip)(struct irq_data___31 *, struct seq_file___31 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___31 *, void *);
	long unsigned int flags;
};

struct seq_operations___30 {
	void * (*start)(struct seq_file___31 *, loff_t *);
	void (*stop)(struct seq_file___31 *, void *);
	void * (*next)(struct seq_file___31 *, void *, loff_t *);
	int (*show)(struct seq_file___31 *, void *);
};

typedef struct {
	efi_guid_t guid;
	u64 table;
} efi_config_table_64_t;

typedef struct {
	efi_guid_t guid;
	const char *name;
	long unsigned int *ptr;
} efi_config_table_type_t;

typedef struct {
	efi_table_hdr_t hdr;
	u64 fw_vendor;
	u32 fw_revision;
	u32 __pad1;
	u64 con_in_handle;
	u64 con_in;
	u64 con_out_handle;
	u64 con_out;
	u64 stderr_handle;
	u64 stderr;
	u64 runtime;
	u64 boottime;
	u32 nr_tables;
	u32 __pad2;
	u64 tables;
} efi_system_table_64_t;

typedef struct {
	efi_table_hdr_t hdr;
	u32 fw_vendor;
	u32 fw_revision;
	u32 con_in_handle;
	u32 con_in;
	u32 con_out_handle;
	u32 con_out;
	u32 stderr_handle;
	u32 stderr;
	u32 runtime;
	u32 boottime;
	u32 nr_tables;
	u32 tables;
} efi_system_table_32_t;

struct xol_area___47 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___47 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___38;

struct memcg_cache_params___38;

struct kmem_cache___38 {
	struct kmem_cache_cpu___38 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___38 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___38;

struct vm_operations_struct___41 {
	void (*open)(struct vm_area_struct___51 *);
	void (*close)(struct vm_area_struct___51 *);
	int (*fault)(struct vm_area_struct___51 *, struct vm_fault___38 *);
	int (*page_mkwrite)(struct vm_area_struct___51 *, struct vm_fault___38 *);
	int (*access)(struct vm_area_struct___51 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___51 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___51 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___51 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___51 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___47 {
	struct task_struct___48 *task;
	struct core_thread___47 *next;
};

struct core_state___47 {
	atomic_t nr_threads;
	struct core_thread___47 dumper;
	struct completion startup;
};

struct signal_struct___47 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___48 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___48 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___19 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___48 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___38 {
	void **freelist;
	long unsigned int tid;
	struct page___47 *page;
	struct page___47 *partial;
};

struct memcg_cache_params___38 {
	bool is_root_cache;
	union {
		struct kmem_cache___38 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___38 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___38 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___47 *page;
};

struct tlb_state___18 {
	struct mm_struct___51 *active_mm;
	int state;
};

struct page___48;

typedef struct page___48 *pgtable_t___48;

struct address_space___48;

struct kmem_cache___39;

struct page___48 {
	long unsigned int flags;
	struct address_space___48 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___48 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___48 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___39 *slab_cache;
		struct page___48 *first_page;
	};
	long: 64;
};

struct task_struct___49;

struct pv_cpu_ops___48 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___18 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___18 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___49 *);
	void (*end_context_switch)(struct task_struct___49 *);
};

struct mutex___49 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___49 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___45 {
	struct page___48 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___52;

struct signal_struct___48;

struct task_struct___49 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___49 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___52 *mm;
	struct mm_struct___52 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___49 *real_parent;
	struct task_struct___49 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___49 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___19 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___48 = 0,
		VTIME_USER___48 = 1,
		VTIME_SYS___48 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___18 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___48 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___49 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___45 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___52 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___52 *, struct mm_struct___52 *);
	void (*dup_mmap)(struct mm_struct___52 *, struct mm_struct___52 *);
	void (*exit_mmap)(struct mm_struct___52 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___52 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___52 *);
	void (*pgd_free)(struct mm_struct___52 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___52 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___52 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___52 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___52 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___52 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___52 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___52 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___52 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___52 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___52 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___52 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___49 lock;
	void *vdso;
} mm_context_t___49;

struct xol_area___48;

struct uprobes_state___48 {
	struct xol_area___48 *xol_area;
};

struct vm_area_struct___52;

struct file___48;

struct core_state___48;

struct mm_struct___52 {
	struct vm_area_struct___52 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___52 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___52 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___49 context;
	long unsigned int flags;
	struct core_state___48 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___49 *owner;
	struct file___48 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___48 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___31;

struct module_kobject___30 {
	struct kobject kobj;
	struct module___31 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___30;

struct module___31 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___30 mkobj;
	struct module_attribute___30 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___49 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___48;

struct lruvec___48 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___48 *zone;
};

struct pglist_data___48;

struct zone___48 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___48 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___48 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___48 {
	struct zone___48 *zone;
	int zone_idx;
};

struct zonelist___48 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___48 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___48 {
	struct zone___48 node_zones[4];
	struct zonelist___48 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___49 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___32;

struct x86_io_apic_ops___32 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___32 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___32;

struct irq_data___32 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___32 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___48 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___49 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___48 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___48 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___39;

struct memcg_cache_params___39;

struct kmem_cache___39 {
	struct kmem_cache_cpu___39 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___39 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___49;

struct address_space_operations___48;

struct address_space___48 {
	struct inode___49 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___49 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___48 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___49;

struct path___48 {
	struct vfsmount *mnt;
	struct dentry___49 *dentry;
};

struct file_operations___48;

struct file___48 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___48 f_path;
	struct inode___49 *f_inode;
	const struct file_operations___48 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___48 *f_mapping;
	struct mutex___49 f_pos_lock;
};

struct vm_operations_struct___42;

struct vm_area_struct___52 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___52 *vm_next;
	struct vm_area_struct___52 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___52 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___42 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___48 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___39;

struct vm_operations_struct___42 {
	void (*open)(struct vm_area_struct___52 *);
	void (*close)(struct vm_area_struct___52 *);
	int (*fault)(struct vm_area_struct___52 *, struct vm_fault___39 *);
	int (*page_mkwrite)(struct vm_area_struct___52 *, struct vm_fault___39 *);
	int (*access)(struct vm_area_struct___52 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___52 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___52 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___52 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___52 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___48 {
	struct task_struct___49 *task;
	struct core_thread___48 *next;
};

struct core_state___48 {
	atomic_t nr_threads;
	struct core_thread___48 dumper;
	struct completion startup;
};

struct vm_fault___39 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___48 *page;
};

struct module_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___30 *, struct module_kobject___30 *, char *);
	ssize_t (*store)(struct module_attribute___30 *, struct module_kobject___30 *, const char *, size_t);
	void (*setup)(struct module___31 *, const char *);
	int (*test)(struct module___31 *);
	void (*free)(struct module___31 *);
};

struct dentry_operations___48;

struct super_block___49;

struct dentry___49 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___49 *d_parent;
	struct qstr d_name;
	struct inode___49 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___48 *d_op;
	struct super_block___49 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___48;

struct file_lock___48;

struct dquot___48;

struct block_device___48;

struct cdev___20;

struct inode___49 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___48 *i_op;
	struct super_block___49 *i_sb;
	struct address_space___48 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___49 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___48 *i_fop;
	struct file_lock___48 *i_flock;
	struct address_space___48 i_data;
	struct dquot___48 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___48 *i_bdev;
		struct cdev___20 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___48 {
	int (*d_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_hash)(const struct dentry___49 *, struct qstr *);
	int (*d_compare)(const struct dentry___49 *, const struct dentry___49 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___49 *);
	void (*d_release)(struct dentry___49 *);
	void (*d_prune)(struct dentry___49 *);
	void (*d_iput)(struct dentry___49 *, struct inode___49 *);
	char * (*d_dname)(struct dentry___49 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___48 *);
	int (*d_manage)(struct dentry___49 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___48;

struct mem_dqinfo___48 {
	struct quota_format_type___48 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___48;

struct quota_info___48 {
	unsigned int flags;
	struct mutex___49 dqio_mutex;
	struct mutex___49 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___49 *files[2];
	struct mem_dqinfo___48 info[2];
	const struct quota_format_ops___48 *ops[2];
};

struct file_system_type___48;

struct super_operations___48;

struct dquot_operations___48;

struct quotactl_ops___48;

struct super_block___49 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___48 *s_type;
	const struct super_operations___48 *s_op;
	const struct dquot_operations___48 *dq_op;
	const struct quotactl_ops___48 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___49 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___48 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___48 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___49 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___48 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___48 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___49 *bd_inode;
	struct super_block___49 *bd_super;
	struct mutex___49 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___48 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___49 bd_fsfreeze_mutex;
};

struct iattr___49 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___48 *ia_file;
};

struct dquot___48 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___49 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___49 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___48 {
	int qf_fmt_id;
	const struct quota_format_ops___48 *qf_ops;
	struct module___31 *qf_owner;
	struct quota_format_type___48 *qf_next;
};

struct quota_format_ops___48 {
	int (*check_quota_file)(struct super_block___49 *, int);
	int (*read_file_info)(struct super_block___49 *, int);
	int (*write_file_info)(struct super_block___49 *, int);
	int (*free_file_info)(struct super_block___49 *, int);
	int (*read_dqblk)(struct dquot___48 *);
	int (*commit_dqblk)(struct dquot___48 *);
	int (*release_dqblk)(struct dquot___48 *);
};

struct dquot_operations___48 {
	int (*write_dquot)(struct dquot___48 *);
	struct dquot___48 * (*alloc_dquot)(struct super_block___49 *, int);
	void (*destroy_dquot)(struct dquot___48 *);
	int (*acquire_dquot)(struct dquot___48 *);
	int (*release_dquot)(struct dquot___48 *);
	int (*mark_dirty)(struct dquot___48 *);
	int (*write_info)(struct super_block___49 *, int);
	qsize_t * (*get_reserved_space)(struct inode___49 *);
};

struct quotactl_ops___48 {
	int (*quota_on)(struct super_block___49 *, int, int, struct path___48 *);
	int (*quota_on_meta)(struct super_block___49 *, int, int);
	int (*quota_off)(struct super_block___49 *, int);
	int (*quota_sync)(struct super_block___49 *, int);
	int (*get_info)(struct super_block___49 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___49 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___49 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___49 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___49 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___49 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___49 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___49 *, unsigned int);
};

struct address_space_operations___48 {
	int (*writepage)(struct page___48 *, struct writeback_control *);
	int (*readpage)(struct file___48 *, struct page___48 *);
	int (*writepages)(struct address_space___48 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___48 *);
	int (*readpages)(struct file___48 *, struct address_space___48 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___48 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___48 **, void **);
	int (*write_end)(struct file___48 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___48 *, void *);
	sector_t (*bmap)(struct address_space___48 *, sector_t);
	void (*invalidatepage)(struct page___48 *, long unsigned int);
	int (*releasepage)(struct page___48 *, gfp_t);
	void (*freepage)(struct page___48 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___48 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___48 *, struct page___48 *, struct page___48 *, enum migrate_mode);
	int (*launder_page)(struct page___48 *);
	int (*is_partially_uptodate)(struct page___48 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___48 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___48 *, struct page___48 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___48 *, sector_t *);
	void (*swap_deactivate)(struct file___48 *);
	void (*invalidatepage_range)(struct page___48 *, unsigned int, unsigned int);
};

struct cdev___20 {
	struct kobject kobj;
	struct module___31 *owner;
	const struct file_operations___48 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___48 {
	struct dentry___49 * (*lookup)(struct inode___49 *, struct dentry___49 *, unsigned int);
	void * (*follow_link)(struct dentry___49 *, struct nameidata *);
	int (*permission)(struct inode___49 *, int);
	struct posix_acl * (*get_acl)(struct inode___49 *, int);
	int (*readlink)(struct dentry___49 *, char *, int);
	void (*put_link)(struct dentry___49 *, struct nameidata *, void *);
	int (*create)(struct inode___49 *, struct dentry___49 *, umode_t, bool);
	int (*link)(struct dentry___49 *, struct inode___49 *, struct dentry___49 *);
	int (*unlink)(struct inode___49 *, struct dentry___49 *);
	int (*symlink)(struct inode___49 *, struct dentry___49 *, const char *);
	int (*mkdir)(struct inode___49 *, struct dentry___49 *, umode_t);
	int (*rmdir)(struct inode___49 *, struct dentry___49 *);
	int (*mknod)(struct inode___49 *, struct dentry___49 *, umode_t, dev_t);
	int (*rename)(struct inode___49 *, struct dentry___49 *, struct inode___49 *, struct dentry___49 *);
	int (*setattr)(struct dentry___49 *, struct iattr___49 *);
	int (*getattr)(struct vfsmount *, struct dentry___49 *, struct kstat *);
	int (*setxattr)(struct dentry___49 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___49 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___49 *, char *, size_t);
	int (*removexattr)(struct dentry___49 *, const char *);
	int (*fiemap)(struct inode___49 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___49 *, struct timespec *, int);
	int (*atomic_open)(struct inode___49 *, struct dentry___49 *, struct file___48 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___27;

struct seq_file___32;

struct file_operations___48 {
	struct module___31 *owner;
	loff_t (*llseek)(struct file___48 *, loff_t, int);
	ssize_t (*read)(struct file___48 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___48 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___48 *, void *, filldir_t);
	unsigned int (*poll)(struct file___48 *, struct poll_table_struct___27 *);
	long int (*unlocked_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___48 *, struct vm_area_struct___52 *);
	int (*open)(struct inode___49 *, struct file___48 *);
	int (*flush)(struct file___48 *, fl_owner_t);
	int (*release)(struct inode___49 *, struct file___48 *);
	int (*fsync)(struct file___48 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___48 *, int);
	int (*lock)(struct file___48 *, int, struct file_lock___48 *);
	ssize_t (*sendpage)(struct file___48 *, struct page___48 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___48 *, int, struct file_lock___48 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___48 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___48 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___48 *, long int, struct file_lock___48 **, void **);
		struct {
			int (*setlease)(struct file___48 *, long int, struct file_lock___48 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___48 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___32 *, struct file___48 *);
};

struct fasync_struct___48;

struct file_lock_operations___48;

struct lock_manager_operations___48;

struct file_lock___48 {
	struct file_lock___48 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___19 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___48 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___48 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___48 *fl_ops;
	const struct lock_manager_operations___48 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___48 {
	void (*fl_copy_lock)(struct file_lock___48 *, struct file_lock___48 *);
	void (*fl_release_private)(struct file_lock___48 *);
};

struct lock_manager_operations___48 {
	int (*lm_compare_owner)(struct file_lock___48 *, struct file_lock___48 *);
	long unsigned int (*lm_owner_key)(struct file_lock___48 *);
	void (*lm_notify)(struct file_lock___48 *);
	int (*lm_grant)(struct file_lock___48 *, struct file_lock___48 *, int);
	void (*lm_break)(struct file_lock___48 *);
	int (*lm_change)(struct file_lock___48 **, int);
};

struct fasync_struct___48 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___48 *fa_next;
	struct file___48 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___48 {
	const char *name;
	int fs_flags;
	struct dentry___49 * (*mount)(struct file_system_type___48 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___49 *);
	struct module___31 *owner;
	struct file_system_type___48 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___48 {
	struct inode___49 * (*alloc_inode)(struct super_block___49 *);
	void (*destroy_inode)(struct inode___49 *);
	void (*dirty_inode)(struct inode___49 *, int);
	int (*write_inode)(struct inode___49 *, struct writeback_control *);
	int (*drop_inode)(struct inode___49 *);
	void (*evict_inode)(struct inode___49 *);
	void (*put_super)(struct super_block___49 *);
	int (*sync_fs)(struct super_block___49 *, int);
	int (*freeze_fs)(struct super_block___49 *);
	int (*unfreeze_fs)(struct super_block___49 *);
	int (*statfs)(struct dentry___49 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___49 *, int *, char *);
	void (*umount_begin)(struct super_block___49 *);
	int (*show_options)(struct seq_file___32 *, struct dentry___49 *);
	int (*show_devname)(struct seq_file___32 *, struct dentry___49 *);
	int (*show_path)(struct seq_file___32 *, struct dentry___49 *);
	int (*show_stats)(struct seq_file___32 *, struct dentry___49 *);
	ssize_t (*quota_read)(struct super_block___49 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___49 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___49 *);
	int (*bdev_try_to_free_page)(struct super_block___49 *, struct page___48 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___49 *);
	void (*free_cached_objects)(struct super_block___49 *, int);
};

typedef void (*poll_queue_proc___27)(struct file___48 *, wait_queue_head_t *, struct poll_table_struct___27 *);

struct poll_table_struct___27 {
	poll_queue_proc___27 _qproc;
	long unsigned int _key;
};

struct seq_operations___31;

struct seq_file___32 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___49 lock;
	const struct seq_operations___31 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___32 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___32 *);
	void (*irq_shutdown)(struct irq_data___32 *);
	void (*irq_enable)(struct irq_data___32 *);
	void (*irq_disable)(struct irq_data___32 *);
	void (*irq_ack)(struct irq_data___32 *);
	void (*irq_mask)(struct irq_data___32 *);
	void (*irq_mask_ack)(struct irq_data___32 *);
	void (*irq_unmask)(struct irq_data___32 *);
	void (*irq_eoi)(struct irq_data___32 *);
	int (*irq_set_affinity)(struct irq_data___32 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___32 *);
	int (*irq_set_type)(struct irq_data___32 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___32 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___32 *);
	void (*irq_bus_sync_unlock)(struct irq_data___32 *);
	void (*irq_cpu_online)(struct irq_data___32 *);
	void (*irq_cpu_offline)(struct irq_data___32 *);
	void (*irq_suspend)(struct irq_data___32 *);
	void (*irq_resume)(struct irq_data___32 *);
	void (*irq_pm_shutdown)(struct irq_data___32 *);
	void (*irq_print_chip)(struct irq_data___32 *, struct seq_file___32 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___32 *, void *);
	long unsigned int flags;
};

struct seq_operations___31 {
	void * (*start)(struct seq_file___32 *, loff_t *);
	void (*stop)(struct seq_file___32 *, void *);
	void * (*next)(struct seq_file___32 *, void *, loff_t *);
	int (*show)(struct seq_file___32 *, void *);
};

struct kmem_cache_cpu___39 {
	void **freelist;
	long unsigned int tid;
	struct page___48 *page;
	struct page___48 *partial;
};

struct memcg_cache_params___39 {
	bool is_root_cache;
	union {
		struct kmem_cache___39 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___39 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___48 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___49 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___49 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___19 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___49 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tlb_state___19 {
	struct mm_struct___52 *active_mm;
	int state;
};

struct efi_scratch {
	u64 r15;
	u64 prev_cr3;
	pgd_t *efi_pgt;
	bool use_pgd;
};

typedef u32 acpi_status;

typedef char *acpi_string;

struct acpi_table_bgrt {
	struct acpi_table_header header;
	u16 version;
	u8 status;
	u8 image_type;
	u64 image_address;
	u32 image_offset_x;
	u32 image_offset_y;
};

struct bmp_header {
	u16 id;
	u32 size;
} __attribute__((packed));

struct font_desc {
	int idx;
	const char *name;
	int width;
	int height;
	const void *data;
	int pref;
};

struct sfi_table_header {
	char sig[4];
	u32 len;
	u8 rev;
	u8 csum;
	char oem_id[6];
	char oem_table_id[8];
};

struct sfi_table_simple {
	struct sfi_table_header header;
	u64 pentry[1];
};

struct sfi_cpu_table_entry {
	u32 apic_id;
};

struct sfi_apic_table_entry {
	u64 phys_addr;
};

typedef int (*sfi_table_handler)(struct sfi_table_header *);

struct pnmask {
	long unsigned int bits[4];
};

struct bau_msg_payload {
	long unsigned int address;
	short unsigned int sending_cpu;
	short unsigned int acknowledge_count;
	unsigned int reserved1: 32;
};

struct uv1_bau_msg_header {
	unsigned int dest_subnodeid: 6;
	unsigned int base_dest_nasid: 15;
	unsigned int command: 8;
	unsigned int rsvd_1: 3;
	unsigned int rsvd_2: 9;
	unsigned int sequence: 16;
	unsigned int rsvd_3: 1;
	unsigned int replied_to: 1;
	unsigned int msg_type: 3;
	unsigned int canceled: 1;
	unsigned int payload_1a: 1;
	unsigned int payload_1b: 2;
	unsigned int payload_1ca: 6;
	unsigned int payload_1c: 2;
	unsigned int payload_1d: 6;
	unsigned int payload_1e: 2;
	unsigned int rsvd_4: 7;
	unsigned int swack_flag: 1;
	unsigned int rsvd_5: 6;
	unsigned int rsvd_6: 5;
	unsigned int int_both: 1;
	unsigned int fairness: 3;
	unsigned int multilevel: 1;
	unsigned int chaining: 1;
	unsigned int rsvd_7: 21;
};

struct uv2_3_bau_msg_header {
	unsigned int base_dest_nasid: 15;
	unsigned int dest_subnodeid: 5;
	unsigned int rsvd_1: 1;
	unsigned int replied_to: 1;
	unsigned int msg_type: 3;
	unsigned int canceled: 1;
	unsigned int payload_1: 3;
	unsigned int payload_2a: 3;
	unsigned int payload_2b: 5;
	unsigned int payload_3: 8;
	unsigned int rsvd_2: 7;
	unsigned int swack_flag: 1;
	unsigned int rsvd_3a: 3;
	unsigned int rsvd_3b: 8;
	unsigned int rsvd_3c: 8;
	unsigned int rsvd_3d: 3;
	unsigned int fairness: 3;
	unsigned int sequence: 16;
	unsigned int chaining: 1;
	unsigned int multilevel: 1;
	unsigned int rsvd_4: 24;
	unsigned int command: 8;
};

union bau_msg_header {
	struct uv1_bau_msg_header uv1_hdr;
	struct uv2_3_bau_msg_header uv2_3_hdr;
};

struct bau_desc {
	struct pnmask distribution;
	union bau_msg_header header;
	struct bau_msg_payload payload;
};

struct bau_pq_entry {
	long unsigned int address;
	short unsigned int sending_cpu;
	short unsigned int acknowledge_count;
	short unsigned int replied_to: 1;
	short unsigned int msg_type: 3;
	short unsigned int canceled: 1;
	short unsigned int unused1: 3;
	unsigned char unused2a;
	unsigned char unused2;
	unsigned char swack_vec;
	short unsigned int sequence;
	unsigned char unused4[2];
	int number_of_cpus;
	unsigned char unused5[8];
};

struct msg_desc {
	struct bau_pq_entry *msg;
	int msg_slot;
	struct bau_pq_entry *queue_first;
	struct bau_pq_entry *queue_last;
};

struct reset_args {
	int sender;
};

struct ptc_stats {
	long unsigned int s_giveup;
	long unsigned int s_requestor;
	long unsigned int s_stimeout;
	long unsigned int s_dtimeout;
	long unsigned int s_strongnacks;
	long unsigned int s_time;
	long unsigned int s_retriesok;
	long unsigned int s_ntargcpu;
	long unsigned int s_ntargself;
	long unsigned int s_ntarglocals;
	long unsigned int s_ntargremotes;
	long unsigned int s_ntarglocaluvhub;
	long unsigned int s_ntargremoteuvhub;
	long unsigned int s_ntarguvhub;
	long unsigned int s_ntarguvhub16;
	long unsigned int s_ntarguvhub8;
	long unsigned int s_ntarguvhub4;
	long unsigned int s_ntarguvhub2;
	long unsigned int s_ntarguvhub1;
	long unsigned int s_resets_plug;
	long unsigned int s_resets_timeout;
	long unsigned int s_busy;
	long unsigned int s_throttles;
	long unsigned int s_retry_messages;
	long unsigned int s_bau_reenabled;
	long unsigned int s_bau_disabled;
	long unsigned int s_uv2_wars;
	long unsigned int s_uv2_wars_hw;
	long unsigned int s_uv2_war_waits;
	long unsigned int s_overipilimit;
	long unsigned int s_giveuplimit;
	long unsigned int s_enters;
	long unsigned int s_ipifordisabled;
	long unsigned int s_plugged;
	long unsigned int s_congested;
	long unsigned int d_alltlb;
	long unsigned int d_onetlb;
	long unsigned int d_multmsg;
	long unsigned int d_nomsg;
	long unsigned int d_time;
	long unsigned int d_requestee;
	long unsigned int d_retries;
	long unsigned int d_canceled;
	long unsigned int d_nocanceled;
	long unsigned int d_resets;
	long unsigned int d_rcanceled;
};

struct tunables {
	int *tunp;
	int deflt;
};

struct hub_and_pnode {
	short int uvhub;
	short int pnode;
};

struct socket_desc {
	short int num_cpus;
	short int cpu_number[64];
};

struct uvhub_desc {
	short unsigned int socket_mask;
	short int num_cpus;
	short int uvhub;
	short int pnode;
	struct socket_desc socket[2];
};

struct bau_control {
	struct bau_desc *descriptor_base;
	struct bau_pq_entry *queue_first;
	struct bau_pq_entry *queue_last;
	struct bau_pq_entry *bau_msg_head;
	struct bau_control *uvhub_master;
	struct bau_control *socket_master;
	struct ptc_stats *statp;
	cpumask_t *cpumask;
	long unsigned int timeout_interval;
	long unsigned int set_bau_on_time;
	atomic_t active_descriptor_count;
	int plugged_tries;
	int timeout_tries;
	int ipi_attempts;
	int conseccompletes;
	short int nobau;
	short int baudisabled;
	short int cpu;
	short int osnode;
	short int uvhub_cpu;
	short int uvhub;
	short int uvhub_version;
	short int cpus_in_socket;
	short int cpus_in_uvhub;
	short int partition_base_pnode;
	short int busy;
	short unsigned int message_number;
	short unsigned int uvhub_quiesce;
	short int socket_acknowledge_count[20];
	cycles_t send_message;
	cycles_t period_end;
	cycles_t period_time;
	spinlock_t uvhub_lock;
	spinlock_t queue_lock;
	spinlock_t disable_lock;
	int max_concurr;
	int max_concurr_const;
	int plugged_delay;
	int plugsb4reset;
	int timeoutsb4reset;
	int ipi_reset_limit;
	int complete_threshold;
	int cong_response_us;
	int cong_reps;
	cycles_t disabled_period;
	int period_giveups;
	int giveup_limit;
	long int period_requests;
	struct hub_and_pnode *thp;
};

struct atomic_short {
	short int counter;
};

enum uv_bios_cmd {
	UV_BIOS_COMMON = 0,
	UV_BIOS_GET_SN_INFO = 1,
	UV_BIOS_FREQ_BASE = 2,
	UV_BIOS_WATCHLIST_ALLOC = 3,
	UV_BIOS_WATCHLIST_FREE = 4,
	UV_BIOS_MEMPROTECT = 5,
	UV_BIOS_GET_PARTITION_ADDR = 6,
	UV_BIOS_SET_LEGACY_VGA_TARGET = 7,
};

struct uv_systab {
	char signature[4];
	u32 revision;
	u64 function;
};

union partition_info_u {
	u64 val;
	struct {
		u64 hub_version: 8;
		u64 partition_id: 16;
		u64 coherence_id: 16;
		u64 region_size: 24;
	};
};

enum uv_memprotect {
	UV_MEMPROT_RESTRICT_ACCESS = 0,
	UV_MEMPROT_ALLOW_AMO = 1,
	UV_MEMPROT_ALLOW_RW = 2,
};

struct uv_IO_APIC_route_entry {
	__u64 vector: 8;
	__u64 delivery_mode: 3;
	__u64 dest_mode: 1;
	__u64 delivery_status: 1;
	__u64 polarity: 1;
	__u64 __reserved_1: 1;
	__u64 trigger: 1;
	__u64 mask: 1;
	__u64 __reserved_2: 15;
	__u64 dest: 32;
};

enum {
	UV_AFFINITY_ALL = 0,
	UV_AFFINITY_NODE = 1,
	UV_AFFINITY_CPU = 2,
};

struct uv_irq_2_mmr_pnode {
	struct rb_node list;
	long unsigned int offset;
	int pnode;
	int irq;
};

struct uv_rtc_timer_head {
	spinlock_t lock;
	int next_cpu;
	int ncpus;
	struct {
		int lcpu;
		u64 expires;
	} cpu[1];
};

struct kexec_file_ops___4;

struct kimage___4 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int destination;
	long unsigned int start;
	struct page___6 *control_code_page;
	struct page___6 *swap_page;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	struct kexec_file_ops___4 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef void *kexec_load_t___4(struct kimage___4 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___4 {
	kexec_probe_t *probe;
	kexec_load_t___4 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct uv_hub_nmi_s {
	raw_spinlock_t nmi_lock;
	atomic_t in_nmi;
	atomic_t cpu_owner;
	atomic_t read_mmr_count;
	atomic_t nmi_count;
	long unsigned int nmi_value;
};

struct uv_cpu_nmi_s {
	struct uv_hub_nmi_s *hub;
	atomic_t state;
	atomic_t pinging;
	int queries;
	int pings;
};

struct page___49;

typedef struct page___49 *pgtable_t___49;

struct address_space___49;

struct kmem_cache___40;

struct page___49 {
	long unsigned int flags;
	struct address_space___49 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___49 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___49 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___40 *slab_cache;
		struct page___49 *first_page;
	};
	long: 64;
};

struct task_struct___50;

struct pv_cpu_ops___49 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___18 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___18 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___50 *);
	void (*end_context_switch)(struct task_struct___50 *);
};

struct mutex___50 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___50 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___46 {
	struct page___49 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___53;

struct nsproxy___20;

struct signal_struct___49;

struct css_set___22;

struct task_struct___50 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___50 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___53 *mm;
	struct mm_struct___53 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___50 *real_parent;
	struct task_struct___50 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___50 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___19 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___49 = 0,
		VTIME_USER___49 = 1,
		VTIME_SYS___49 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___18 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___20 *nsproxy;
	struct signal_struct___49 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___22 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___50 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___46 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___53 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___53 *, struct mm_struct___53 *);
	void (*dup_mmap)(struct mm_struct___53 *, struct mm_struct___53 *);
	void (*exit_mmap)(struct mm_struct___53 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___53 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___53 *);
	void (*pgd_free)(struct mm_struct___53 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___53 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___53 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___53 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___53 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___53 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___53 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___53 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___53 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___53 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___53 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___53 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___50 lock;
	void *vdso;
} mm_context_t___50;

struct xol_area___49;

struct uprobes_state___49 {
	struct xol_area___49 *xol_area;
};

struct vm_area_struct___53;

struct file___49;

struct core_state___49;

struct mm_struct___53 {
	struct vm_area_struct___53 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___53 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___53 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___50 context;
	long unsigned int flags;
	struct core_state___49 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___50 *owner;
	struct file___49 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___49 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___32;

struct exec_domain___12 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___32 *module;
	struct exec_domain___12 *next;
};

struct module_kobject___31 {
	struct kobject kobj;
	struct module___32 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___31;

struct module___32 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___31 mkobj;
	struct module_attribute___31 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___50 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___19 {
	struct task_struct___50 *task;
	struct exec_domain___12 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___49;

struct lruvec___49 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___49 *zone;
};

struct pglist_data___49;

struct zone___49 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___49 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___49 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___49 {
	struct zone___49 *zone;
	int zone_idx;
};

struct zonelist___49 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___49 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___49 {
	struct zone___49 node_zones[4];
	struct zonelist___49 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___50 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___33;

struct x86_io_apic_ops___33 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___33 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___33;

struct irq_data___33 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___33 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___38;

struct dev_pm_ops___38 {
	int (*prepare)(struct device___38 *);
	void (*complete)(struct device___38 *);
	int (*suspend)(struct device___38 *);
	int (*resume)(struct device___38 *);
	int (*freeze)(struct device___38 *);
	int (*thaw)(struct device___38 *);
	int (*poweroff)(struct device___38 *);
	int (*restore)(struct device___38 *);
	int (*suspend_late)(struct device___38 *);
	int (*resume_early)(struct device___38 *);
	int (*freeze_late)(struct device___38 *);
	int (*thaw_early)(struct device___38 *);
	int (*poweroff_late)(struct device___38 *);
	int (*restore_early)(struct device___38 *);
	int (*suspend_noirq)(struct device___38 *);
	int (*resume_noirq)(struct device___38 *);
	int (*freeze_noirq)(struct device___38 *);
	int (*thaw_noirq)(struct device___38 *);
	int (*poweroff_noirq)(struct device___38 *);
	int (*restore_noirq)(struct device___38 *);
	int (*runtime_suspend)(struct device___38 *);
	int (*runtime_resume)(struct device___38 *);
	int (*runtime_idle)(struct device___38 *);
};

struct dev_pm_qos___3;

struct dev_pm_info___3 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___3 *qos;
};

struct dma_map_ops___19;

struct dev_archdata___19 {
	struct dma_map_ops___19 *dma_ops;
	void *iommu;
};

struct device_type___38;

struct bus_type___38;

struct device_driver___38;

struct dev_pm_domain___38;

struct class___38;

struct attribute_group___33;

struct device_rh___38;

struct device___38 {
	struct device___38 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___38 *type;
	struct mutex___50 mutex;
	struct bus_type___38 *bus;
	struct device_driver___38 *driver;
	void *platform_data;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___38 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___19 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___38 *class;
	const struct attribute_group___33 **groups;
	void (*release)(struct device___38 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___38 *device_rh;
};

struct dev_pm_qos_request___3;

struct dev_pm_qos___3 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___3 *latency_req;
	struct dev_pm_qos_request___3 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___3 *latency_tolerance_req;
};

struct dev_pm_info_rh___38 {
	void (*set_latency_tolerance)(struct device___38 *, s32);
};

struct dev_pm_domain___38 {
	struct dev_pm_ops___38 ops;
};

struct smp_ops___49 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___50 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___3;

struct ctl_node___3 {
	struct rb_node node;
	struct ctl_table_header___3 *header;
};

struct ctl_table_root___3;

struct ctl_table_set___3;

struct ctl_dir___3;

struct ctl_table_header___3 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___3 *root;
	struct ctl_table_set___3 *set;
	struct ctl_dir___3 *parent;
	struct ctl_node___3 *node;
};

struct ctl_dir___3 {
	struct ctl_table_header___3 header;
	struct rb_root root;
};

struct ctl_table_set___3 {
	int (*is_seen)(struct ctl_table_set___3 *);
	struct ctl_dir___3 dir;
};

struct ctl_table_root___3 {
	struct ctl_table_set___3 default_set;
	struct ctl_table_set___3 * (*lookup)(struct ctl_table_root___3 *, struct nsproxy___20 *);
	int (*permissions)(struct ctl_table_header___3 *, struct ctl_table *);
};

struct net___4;

struct nsproxy___20 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___4 *net_ns;
};

struct bin_attribute___33;

struct attribute_group___33 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___33 **bin_attrs;
};

struct bin_attribute___33 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___49 *, struct kobject *, struct bin_attribute___33 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___49 *, struct kobject *, struct bin_attribute___33 *, char *, loff_t, size_t);
	int (*mmap)(struct file___49 *, struct kobject *, struct bin_attribute___33 *, struct vm_area_struct___53 *);
};

struct dentry___50;

struct path___49 {
	struct vfsmount *mnt;
	struct dentry___50 *dentry;
};

struct inode___50;

struct file_operations___49;

struct file___49 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___49 f_path;
	struct inode___50 *f_inode;
	const struct file_operations___49 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___49 *f_mapping;
	struct mutex___50 f_pos_lock;
};

struct vm_operations_struct___43;

struct vm_area_struct___53 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___53 *vm_next;
	struct vm_area_struct___53 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___53 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___43 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___49 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___31 *, struct module_kobject___31 *, char *);
	ssize_t (*store)(struct module_attribute___31 *, struct module_kobject___31 *, const char *, size_t);
	void (*setup)(struct module___32 *, const char *);
	int (*test)(struct module___32 *);
	void (*free)(struct module___32 *);
};

struct xol_area___49 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___49 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___40;

struct memcg_cache_params___40;

struct kmem_cache___40 {
	struct kmem_cache_cpu___40 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___40 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___49;

struct address_space___49 {
	struct inode___50 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___50 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___49 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___40;

struct vm_operations_struct___43 {
	void (*open)(struct vm_area_struct___53 *);
	void (*close)(struct vm_area_struct___53 *);
	int (*fault)(struct vm_area_struct___53 *, struct vm_fault___40 *);
	int (*page_mkwrite)(struct vm_area_struct___53 *, struct vm_fault___40 *);
	int (*access)(struct vm_area_struct___53 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___53 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___53 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___53 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___53 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___49 {
	struct task_struct___50 *task;
	struct core_thread___49 *next;
};

struct core_state___49 {
	atomic_t nr_threads;
	struct core_thread___49 dumper;
	struct completion startup;
};

struct vm_fault___40 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___49 *page;
};

struct file_lock___49;

struct seq_file___33;

struct file_operations___49 {
	struct module___32 *owner;
	loff_t (*llseek)(struct file___49 *, loff_t, int);
	ssize_t (*read)(struct file___49 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___49 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___49 *, void *, filldir_t);
	unsigned int (*poll)(struct file___49 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___49 *, struct vm_area_struct___53 *);
	int (*open)(struct inode___50 *, struct file___49 *);
	int (*flush)(struct file___49 *, fl_owner_t);
	int (*release)(struct inode___50 *, struct file___49 *);
	int (*fsync)(struct file___49 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___49 *, int);
	int (*lock)(struct file___49 *, int, struct file_lock___49 *);
	ssize_t (*sendpage)(struct file___49 *, struct page___49 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___49 *, int, struct file_lock___49 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___49 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___49 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___49 *, long int, struct file_lock___49 **, void **);
		struct {
			int (*setlease)(struct file___49 *, long int, struct file_lock___49 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___49 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___33 *, struct file___49 *);
};

struct dma_map_ops___19 {
	void * (*alloc)(struct device___38 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___38 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___38 *, struct vm_area_struct___53 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___38 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___38 *, struct page___49 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___38 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___38 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___38 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___38 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___38 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___38 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___38 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___38 *, dma_addr_t);
	int (*dma_supported)(struct device___38 *, u64);
	int (*set_dma_mask)(struct device___38 *, u64);
	int is_phys;
};

struct bus_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___38 *, char *);
	ssize_t (*store)(struct bus_type___38 *, const char *, size_t);
};

struct device_attribute___38;

struct driver_attribute___38;

struct bus_type___38 {
	const char *name;
	const char *dev_name;
	struct device___38 *dev_root;
	struct bus_attribute___38 *bus_attrs;
	struct device_attribute___38 *dev_attrs;
	struct driver_attribute___38 *drv_attrs;
	const struct attribute_group___33 **bus_groups;
	const struct attribute_group___33 **dev_groups;
	const struct attribute_group___33 **drv_groups;
	int (*match)(struct device___38 *, struct device_driver___38 *);
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	int (*probe)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*online)(struct device___38 *);
	int (*offline)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct device___38 *, struct device_attribute___38 *, char *);
	ssize_t (*store)(struct device___38 *, struct device_attribute___38 *, const char *, size_t);
};

struct driver_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___38 *, char *);
	ssize_t (*store)(struct device_driver___38 *, const char *, size_t);
};

struct device_driver___38 {
	const char *name;
	struct bus_type___38 *bus;
	struct module___32 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct attribute_group___33 **groups;
	const struct dev_pm_ops___38 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___38 {
	const char *name;
	const struct attribute_group___33 **groups;
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
};

struct class_attribute___38;

struct class___38 {
	const char *name;
	struct module___32 *owner;
	struct class_attribute___38 *class_attrs;
	struct device_attribute___38 *dev_attrs;
	const struct attribute_group___33 **dev_groups;
	struct bin_attribute___33 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *);
	void (*class_release)(struct class___38 *);
	void (*dev_release)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	struct subsys_private *p;
};

struct class_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct class___38 *, struct class_attribute___38 *, char *);
	ssize_t (*store)(struct class___38 *, struct class_attribute___38 *, const char *, size_t);
	const void * (*namespace)(struct class___38 *, const struct class_attribute___38 *);
};

struct device_rh___38 {
	struct dev_pm_info_rh___38 power;
};

struct dev_pm_qos_request___3 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___38 *dev;
};

struct dentry_operations___49;

struct super_block___50;

struct dentry___50 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___50 *d_parent;
	struct qstr d_name;
	struct inode___50 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___49 *d_op;
	struct super_block___50 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___49;

struct dquot___49;

struct block_device___49;

struct inode___50 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___49 *i_op;
	struct super_block___50 *i_sb;
	struct address_space___49 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___50 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___49 *i_fop;
	struct file_lock___49 *i_flock;
	struct address_space___49 i_data;
	struct dquot___49 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___49 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___49 {
	int (*d_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_hash)(const struct dentry___50 *, struct qstr *);
	int (*d_compare)(const struct dentry___50 *, const struct dentry___50 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___50 *);
	void (*d_release)(struct dentry___50 *);
	void (*d_prune)(struct dentry___50 *);
	void (*d_iput)(struct dentry___50 *, struct inode___50 *);
	char * (*d_dname)(struct dentry___50 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___49 *);
	int (*d_manage)(struct dentry___50 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___49;

struct mem_dqinfo___49 {
	struct quota_format_type___49 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___49;

struct quota_info___49 {
	unsigned int flags;
	struct mutex___50 dqio_mutex;
	struct mutex___50 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___50 *files[2];
	struct mem_dqinfo___49 info[2];
	const struct quota_format_ops___49 *ops[2];
};

struct file_system_type___49;

struct super_operations___49;

struct dquot_operations___49;

struct quotactl_ops___49;

struct xattr_handler___22;

struct super_block___50 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___49 *s_type;
	const struct super_operations___49 *s_op;
	const struct dquot_operations___49 *dq_op;
	const struct quotactl_ops___49 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___50 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___22 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___49 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___49 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___50 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___49 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___49 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___50 *bd_inode;
	struct super_block___50 *bd_super;
	struct mutex___50 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___49 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___50 bd_fsfreeze_mutex;
};

struct cgroup___22;

struct cgroup_subsys_state___22 {
	struct cgroup___22 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___50 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___49 *ia_file;
};

struct dquot___49 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___50 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___50 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___49 {
	int qf_fmt_id;
	const struct quota_format_ops___49 *qf_ops;
	struct module___32 *qf_owner;
	struct quota_format_type___49 *qf_next;
};

struct quota_format_ops___49 {
	int (*check_quota_file)(struct super_block___50 *, int);
	int (*read_file_info)(struct super_block___50 *, int);
	int (*write_file_info)(struct super_block___50 *, int);
	int (*free_file_info)(struct super_block___50 *, int);
	int (*read_dqblk)(struct dquot___49 *);
	int (*commit_dqblk)(struct dquot___49 *);
	int (*release_dqblk)(struct dquot___49 *);
};

struct dquot_operations___49 {
	int (*write_dquot)(struct dquot___49 *);
	struct dquot___49 * (*alloc_dquot)(struct super_block___50 *, int);
	void (*destroy_dquot)(struct dquot___49 *);
	int (*acquire_dquot)(struct dquot___49 *);
	int (*release_dquot)(struct dquot___49 *);
	int (*mark_dirty)(struct dquot___49 *);
	int (*write_info)(struct super_block___50 *, int);
	qsize_t * (*get_reserved_space)(struct inode___50 *);
};

struct quotactl_ops___49 {
	int (*quota_on)(struct super_block___50 *, int, int, struct path___49 *);
	int (*quota_on_meta)(struct super_block___50 *, int, int);
	int (*quota_off)(struct super_block___50 *, int);
	int (*quota_sync)(struct super_block___50 *, int);
	int (*get_info)(struct super_block___50 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___50 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___50 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___50 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___50 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___50 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___50 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___50 *, unsigned int);
};

struct address_space_operations___49 {
	int (*writepage)(struct page___49 *, struct writeback_control *);
	int (*readpage)(struct file___49 *, struct page___49 *);
	int (*writepages)(struct address_space___49 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___49 *);
	int (*readpages)(struct file___49 *, struct address_space___49 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___49 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___49 **, void **);
	int (*write_end)(struct file___49 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___49 *, void *);
	sector_t (*bmap)(struct address_space___49 *, sector_t);
	void (*invalidatepage)(struct page___49 *, long unsigned int);
	int (*releasepage)(struct page___49 *, gfp_t);
	void (*freepage)(struct page___49 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___49 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___49 *, struct page___49 *, struct page___49 *, enum migrate_mode);
	int (*launder_page)(struct page___49 *);
	int (*is_partially_uptodate)(struct page___49 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___49 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___49 *, struct page___49 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___49 *, sector_t *);
	void (*swap_deactivate)(struct file___49 *);
	void (*invalidatepage_range)(struct page___49 *, unsigned int, unsigned int);
};

struct inode_operations___49 {
	struct dentry___50 * (*lookup)(struct inode___50 *, struct dentry___50 *, unsigned int);
	void * (*follow_link)(struct dentry___50 *, struct nameidata *);
	int (*permission)(struct inode___50 *, int);
	struct posix_acl * (*get_acl)(struct inode___50 *, int);
	int (*readlink)(struct dentry___50 *, char *, int);
	void (*put_link)(struct dentry___50 *, struct nameidata *, void *);
	int (*create)(struct inode___50 *, struct dentry___50 *, umode_t, bool);
	int (*link)(struct dentry___50 *, struct inode___50 *, struct dentry___50 *);
	int (*unlink)(struct inode___50 *, struct dentry___50 *);
	int (*symlink)(struct inode___50 *, struct dentry___50 *, const char *);
	int (*mkdir)(struct inode___50 *, struct dentry___50 *, umode_t);
	int (*rmdir)(struct inode___50 *, struct dentry___50 *);
	int (*mknod)(struct inode___50 *, struct dentry___50 *, umode_t, dev_t);
	int (*rename)(struct inode___50 *, struct dentry___50 *, struct inode___50 *, struct dentry___50 *);
	int (*setattr)(struct dentry___50 *, struct iattr___50 *);
	int (*getattr)(struct vfsmount *, struct dentry___50 *, struct kstat *);
	int (*setxattr)(struct dentry___50 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___50 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___50 *, char *, size_t);
	int (*removexattr)(struct dentry___50 *, const char *);
	int (*fiemap)(struct inode___50 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___50 *, struct timespec *, int);
	int (*atomic_open)(struct inode___50 *, struct dentry___50 *, struct file___49 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___49;

struct file_lock_operations___49;

struct lock_manager_operations___49;

struct file_lock___49 {
	struct file_lock___49 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___19 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___49 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___49 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___49 *fl_ops;
	const struct lock_manager_operations___49 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___49 {
	void (*fl_copy_lock)(struct file_lock___49 *, struct file_lock___49 *);
	void (*fl_release_private)(struct file_lock___49 *);
};

struct lock_manager_operations___49 {
	int (*lm_compare_owner)(struct file_lock___49 *, struct file_lock___49 *);
	long unsigned int (*lm_owner_key)(struct file_lock___49 *);
	void (*lm_notify)(struct file_lock___49 *);
	int (*lm_grant)(struct file_lock___49 *, struct file_lock___49 *, int);
	void (*lm_break)(struct file_lock___49 *);
	int (*lm_change)(struct file_lock___49 **, int);
};

struct fasync_struct___49 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___49 *fa_next;
	struct file___49 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___49 {
	const char *name;
	int fs_flags;
	struct dentry___50 * (*mount)(struct file_system_type___49 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___50 *);
	struct module___32 *owner;
	struct file_system_type___49 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___49 {
	struct inode___50 * (*alloc_inode)(struct super_block___50 *);
	void (*destroy_inode)(struct inode___50 *);
	void (*dirty_inode)(struct inode___50 *, int);
	int (*write_inode)(struct inode___50 *, struct writeback_control *);
	int (*drop_inode)(struct inode___50 *);
	void (*evict_inode)(struct inode___50 *);
	void (*put_super)(struct super_block___50 *);
	int (*sync_fs)(struct super_block___50 *, int);
	int (*freeze_fs)(struct super_block___50 *);
	int (*unfreeze_fs)(struct super_block___50 *);
	int (*statfs)(struct dentry___50 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___50 *, int *, char *);
	void (*umount_begin)(struct super_block___50 *);
	int (*show_options)(struct seq_file___33 *, struct dentry___50 *);
	int (*show_devname)(struct seq_file___33 *, struct dentry___50 *);
	int (*show_path)(struct seq_file___33 *, struct dentry___50 *);
	int (*show_stats)(struct seq_file___33 *, struct dentry___50 *);
	ssize_t (*quota_read)(struct super_block___50 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___50 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___50 *);
	int (*bdev_try_to_free_page)(struct super_block___50 *, struct page___49 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___50 *);
	void (*free_cached_objects)(struct super_block___50 *, int);
};

struct xattr_handler___22 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___50 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___50 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___50 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___32;

struct seq_file___33 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___50 lock;
	const struct seq_operations___32 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___49 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___50 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___50 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___19 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___50 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___22 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___22 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___3 {
	struct ctl_table_header___3 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___3 {
	struct mutex___50 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___3 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___3 *ctl;
};

struct netns_ipv4___3 {
	struct ctl_table_header___3 *forw_hdr;
	struct ctl_table_header___3 *frags_hdr;
	struct ctl_table_header___3 *ipv4_hdr;
	struct ctl_table_header___3 *route_hdr;
	struct ctl_table_header___3 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___3 {
	struct ctl_table_header___3 *hdr;
	struct ctl_table_header___3 *route_hdr;
	struct ctl_table_header___3 *icmp_hdr;
	struct ctl_table_header___3 *frags_hdr;
	struct ctl_table_header___3 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___5;

struct sk_buff___5;

struct dst_ops___4 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___4 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___5 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *);
	int (*local_out)(struct sk_buff___5 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___5 *, const void *);
	struct kmem_cache___40 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___3 {
	struct netns_sysctl_ipv6___3 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___3 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___3 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___3 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___3 *nf_log_dir_header;
};

struct nf_proto_net___3 {
	struct ctl_table_header___3 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___3 {
	struct nf_proto_net___3 pn;
	unsigned int timeout;
};

struct nf_tcp_net___3 {
	struct nf_proto_net___3 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___3 {
	struct nf_proto_net___3 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___3 {
	struct nf_proto_net___3 pn;
	unsigned int timeout;
};

struct nf_ip_net___3 {
	struct nf_generic_net___3 generic;
	struct nf_tcp_net___3 tcp;
	struct nf_udp_net___3 udp;
	struct nf_icmp_net___3 icmp;
	struct nf_icmp_net___3 icmpv6;
};

struct netns_ct___3 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___3 *sysctl_header;
	struct ctl_table_header___3 *acct_sysctl_header;
	struct ctl_table_header___3 *tstamp_sysctl_header;
	struct ctl_table_header___3 *event_sysctl_header;
	struct ctl_table_header___3 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___40 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___3 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___3 {
	struct netns_sysctl_ipv6___3 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___2 {
	struct sk_buff___5 *next;
	struct sk_buff___5 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___3 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___3 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 xfrm4_dst_ops;
	struct dst_ops___4 xfrm6_dst_ops;
};

struct net___4 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___3 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___5 *loopback_dev;
	struct netns_core___3 core;
	struct netns_mib mib;
	struct netns_packet___3 packet;
	struct netns_unix___3 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___3 ipv4;
	struct netns_ipv6___3 ipv6;
	struct netns_sctp___3 sctp;
	struct netns_dccp dccp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct___3 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___3 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___3 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___50 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___50 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___40 {
	void **freelist;
	long unsigned int tid;
	struct page___49 *page;
	struct page___49 *partial;
};

struct memcg_cache_params___40 {
	bool is_root_cache;
	union {
		struct kmem_cache___40 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___40 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___2 {
	atomic_t use;
	unsigned int mask;
	struct net_device___5 *physindev;
	struct net_device___5 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___2(struct sk_buff___5 **);

struct net_device_ops___2;

struct ethtool_ops___2;

struct header_ops___2;

struct inet6_dev___2;

struct netdev_rx_queue___2;

struct netdev_queue___2;

struct rtnl_link_ops___2;

struct dcbnl_rtnl_ops___2;

struct net_device___5 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___2 *netdev_ops;
	const struct ethtool_ops___2 *ethtool_ops;
	const struct header_ops___2 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___2 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___2 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___2 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___2 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___2 = 0,
		NETREG_REGISTERED___2 = 1,
		NETREG_UNREGISTERING___2 = 2,
		NETREG_UNREGISTERED___2 = 3,
		NETREG_RELEASED___2 = 4,
		NETREG_DUMMY___2 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___2 = 0,
		RTNL_LINK_INITIALIZING___2 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___5 *);
	struct netpoll_info *npinfo;
	struct net___4 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___38 dev;
	const struct attribute_group___33 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___2 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___5 {
	struct sk_buff___5 *next;
	struct sk_buff___5 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___5 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___5 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___2 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___2 {
	int (*get_settings)(struct net_device___5 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___5 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___5 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___5 *);
	void (*get_regs)(struct net_device___5 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___5 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___5 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___5 *);
	void (*set_msglevel)(struct net_device___5 *, u32);
	int (*nway_reset)(struct net_device___5 *);
	u32 (*get_link)(struct net_device___5 *);
	int (*get_eeprom_len)(struct net_device___5 *);
	int (*get_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___5 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___5 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___5 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___5 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___5 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___5 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___5 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___5 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___5 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___5 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___5 *);
	void (*complete)(struct net_device___5 *);
	u32 (*get_priv_flags)(struct net_device___5 *);
	int (*set_priv_flags)(struct net_device___5 *, u32);
	int (*get_sset_count)(struct net_device___5 *, int);
	int (*get_rxnfc)(struct net_device___5 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___5 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___5 *, struct ethtool_flash *);
	int (*reset)(struct net_device___5 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___5 *);
	int (*get_rxfh_indir)(struct net_device___5 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___5 *, const u32 *);
	void (*get_channels)(struct net_device___5 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___5 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___5 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___5 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___5 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___5 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___5 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___5 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___5 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___5 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___5 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___5 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___3 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___5 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___5 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___4 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___5 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___5 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___33 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___33 *);
	void (*irq_shutdown)(struct irq_data___33 *);
	void (*irq_enable)(struct irq_data___33 *);
	void (*irq_disable)(struct irq_data___33 *);
	void (*irq_ack)(struct irq_data___33 *);
	void (*irq_mask)(struct irq_data___33 *);
	void (*irq_mask_ack)(struct irq_data___33 *);
	void (*irq_unmask)(struct irq_data___33 *);
	void (*irq_eoi)(struct irq_data___33 *);
	int (*irq_set_affinity)(struct irq_data___33 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___33 *);
	int (*irq_set_type)(struct irq_data___33 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___33 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___33 *);
	void (*irq_bus_sync_unlock)(struct irq_data___33 *);
	void (*irq_cpu_online)(struct irq_data___33 *);
	void (*irq_cpu_offline)(struct irq_data___33 *);
	void (*irq_suspend)(struct irq_data___33 *);
	void (*irq_resume)(struct irq_data___33 *);
	void (*irq_pm_shutdown)(struct irq_data___33 *);
	void (*irq_print_chip)(struct irq_data___33 *, struct seq_file___33 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___33 *, void *);
	long unsigned int flags;
};

struct seq_operations___32 {
	void * (*start)(struct seq_file___33 *, loff_t *);
	void (*stop)(struct seq_file___33 *, void *);
	void * (*next)(struct seq_file___33 *, void *, loff_t *);
	int (*show)(struct seq_file___33 *, void *);
};

struct dcbnl_rtnl_ops___2 {
	int (*ieee_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___5 *);
	u8 (*setstate)(struct net_device___5 *, u8);
	void (*getpermhwaddr)(struct net_device___5 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___5 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___5 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___5 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___5 *, int, u8 *);
	void (*setpfccfg)(struct net_device___5 *, int, u8);
	void (*getpfccfg)(struct net_device___5 *, int, u8 *);
	u8 (*setall)(struct net_device___5 *);
	u8 (*getcap)(struct net_device___5 *, int, u8 *);
	int (*getnumtcs)(struct net_device___5 *, int, u8 *);
	int (*setnumtcs)(struct net_device___5 *, int, u8);
	u8 (*getpfcstate)(struct net_device___5 *);
	void (*setpfcstate)(struct net_device___5 *, u8);
	void (*getbcncfg)(struct net_device___5 *, int, u32 *);
	void (*setbcncfg)(struct net_device___5 *, int, u32);
	void (*getbcnrp)(struct net_device___5 *, int, u8 *);
	void (*setbcnrp)(struct net_device___5 *, int, u8);
	u8 (*setapp)(struct net_device___5 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___5 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___5 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___5 *, int, u8);
	u8 (*getdcbx)(struct net_device___5 *);
	u8 (*setdcbx)(struct net_device___5 *, u8);
	int (*peer_getappinfo)(struct net_device___5 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___5 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___5 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___5 *, struct cee_pfc *);
};

struct cgroupfs_root___22;

struct cgroup___22 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___22 *parent;
	struct dentry___50 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___22 *subsys[11];
	struct cgroupfs_root___22 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___50 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___22 {
	struct super_block___50 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___22 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___2 {
	struct sk_buff___5 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___5 *, struct netlink_callback___2 *);
	int (*done)(struct netlink_callback___2 *);
	void *data;
	struct module___32 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___2 {
	int (*create)(struct sk_buff___5 *, struct net_device___5 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___5 *, unsigned char *);
	int (*rebuild)(struct sk_buff___5 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___5 *, const unsigned char *);
};

struct sk_buff_head___3 {
	struct sk_buff___3 *next;
	struct sk_buff___3 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct neigh_table___2;

struct neigh_parms___2;

struct neigh_ops___2;

struct neighbour___2 {
	struct neighbour___2 *next;
	struct neigh_table___2 *tbl;
	struct neigh_parms___2 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___3 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___2 *, struct sk_buff___3 *);
	const struct neigh_ops___2 *ops;
	struct callback_head rcu;
	struct net_device___4 *dev;
	u8 primary_key[0];
};

struct napi_struct___2 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___2 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___5 *dev;
	struct sk_buff___5 *gro_list;
	struct sk_buff___5 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___2 {
	struct net_device___5 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___2 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject kobj;
	struct net_device___5 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___2 {
	int (*ndo_init)(struct net_device___5 *);
	void (*ndo_uninit)(struct net_device___5 *);
	int (*ndo_open)(struct net_device___5 *);
	int (*ndo_stop)(struct net_device___5 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___5 *, struct net_device___5 *);
	u16 (*ndo_select_queue)(struct net_device___5 *, struct sk_buff___5 *);
	void (*ndo_change_rx_flags)(struct net_device___5 *, int);
	void (*ndo_set_rx_mode)(struct net_device___5 *);
	int (*ndo_set_mac_address)(struct net_device___5 *, void *);
	int (*ndo_validate_addr)(struct net_device___5 *);
	int (*ndo_do_ioctl)(struct net_device___5 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___5 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___5 *, int);
	int (*ndo_neigh_setup)(struct net_device___5 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___5 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___5 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___5 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___5 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___5 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___5 *);
	int (*ndo_netpoll_setup)(struct net_device___5 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___5 *);
	int (*ndo_busy_poll)(struct napi_struct___2 *);
	int (*ndo_set_vf_mac)(struct net_device___5 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___5 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___5 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___5 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___5 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___5 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___5 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___5 *, int, struct sk_buff___5 *);
	int (*ndo_setup_tc)(struct net_device___5 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___5 *);
	int (*ndo_fcoe_disable)(struct net_device___5 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___5 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___5 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___5 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___5 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___5 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___5 *, const struct sk_buff___5 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___5 *, struct net_device___5 *);
	int (*ndo_del_slave)(struct net_device___5 *, struct net_device___5 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___5 *, struct netlink_callback___2 *, struct net_device___5 *, int);
	int (*ndo_bridge_setlink)(struct net_device___5 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___5 *, u32, u32, struct net_device___5 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___5 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___5 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___5 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___5 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___5 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___5 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___5 *, struct net_device___5 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___5 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___5 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___5 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct net___5;

struct rtnl_link_ops___2 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___4 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___5 *, struct net_device___4 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___4 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___4 *, struct list_head *);
	size_t (*get_size)(const struct net_device___4 *);
	int (*fill_info)(struct sk_buff___3 *, const struct net_device___4 *);
	size_t (*get_xstats_size)(const struct net_device___4 *);
	int (*fill_xstats)(struct sk_buff___3 *, const struct net_device___4 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___5 * (*get_link_net)(const struct net_device___4 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___4 *, struct net_device___4 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___4 *, const struct net_device___4 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___3 *, const struct net_device___4 *, const struct net_device___4 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___2 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___5 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

enum {
	BPF_S_RET_K = 1,
	BPF_S_RET_A = 2,
	BPF_S_ALU_ADD_K = 3,
	BPF_S_ALU_ADD_X = 4,
	BPF_S_ALU_SUB_K = 5,
	BPF_S_ALU_SUB_X = 6,
	BPF_S_ALU_MUL_K = 7,
	BPF_S_ALU_MUL_X = 8,
	BPF_S_ALU_DIV_X = 9,
	BPF_S_ALU_MOD_K = 10,
	BPF_S_ALU_MOD_X = 11,
	BPF_S_ALU_AND_K = 12,
	BPF_S_ALU_AND_X = 13,
	BPF_S_ALU_OR_K = 14,
	BPF_S_ALU_OR_X = 15,
	BPF_S_ALU_XOR_K = 16,
	BPF_S_ALU_XOR_X = 17,
	BPF_S_ALU_LSH_K = 18,
	BPF_S_ALU_LSH_X = 19,
	BPF_S_ALU_RSH_K = 20,
	BPF_S_ALU_RSH_X = 21,
	BPF_S_ALU_NEG = 22,
	BPF_S_LD_W_ABS = 23,
	BPF_S_LD_H_ABS = 24,
	BPF_S_LD_B_ABS = 25,
	BPF_S_LD_W_LEN = 26,
	BPF_S_LD_W_IND = 27,
	BPF_S_LD_H_IND = 28,
	BPF_S_LD_B_IND = 29,
	BPF_S_LD_IMM = 30,
	BPF_S_LDX_W_LEN = 31,
	BPF_S_LDX_B_MSH = 32,
	BPF_S_LDX_IMM = 33,
	BPF_S_MISC_TAX = 34,
	BPF_S_MISC_TXA = 35,
	BPF_S_ALU_DIV_K = 36,
	BPF_S_LD_MEM = 37,
	BPF_S_LDX_MEM = 38,
	BPF_S_ST = 39,
	BPF_S_STX = 40,
	BPF_S_JMP_JA = 41,
	BPF_S_JMP_JEQ_K = 42,
	BPF_S_JMP_JEQ_X = 43,
	BPF_S_JMP_JGE_K = 44,
	BPF_S_JMP_JGE_X = 45,
	BPF_S_JMP_JGT_K = 46,
	BPF_S_JMP_JGT_X = 47,
	BPF_S_JMP_JSET_K = 48,
	BPF_S_JMP_JSET_X = 49,
	BPF_S_ANC_PROTOCOL = 50,
	BPF_S_ANC_PKTTYPE = 51,
	BPF_S_ANC_IFINDEX = 52,
	BPF_S_ANC_NLATTR = 53,
	BPF_S_ANC_NLATTR_NEST = 54,
	BPF_S_ANC_MARK = 55,
	BPF_S_ANC_QUEUE = 56,
	BPF_S_ANC_HATYPE = 57,
	BPF_S_ANC_RXHASH = 58,
	BPF_S_ANC_CPU = 59,
	BPF_S_ANC_ALU_XOR_X = 60,
	BPF_S_ANC_SECCOMP_LD_W = 61,
	BPF_S_ANC_VLAN_TAG = 62,
	BPF_S_ANC_VLAN_TAG_PRESENT = 63,
	BPF_S_ANC_PAY_OFFSET = 64,
};

struct page___50;

typedef struct page___50 *pgtable_t___50;

struct address_space___50;

struct kmem_cache___41;

struct page___50 {
	long unsigned int flags;
	struct address_space___50 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___50 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___50 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___41 *slab_cache;
		struct page___50 *first_page;
	};
	long: 64;
};

struct thread_struct___19;

struct task_struct___51;

struct pv_cpu_ops___50 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___19 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___19 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___51 *);
	void (*end_context_switch)(struct task_struct___51 *);
};

struct perf_event___19;

struct thread_struct___19 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___19 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___20;

struct pid_link___20 {
	struct hlist_node node;
	struct pid___20 *pid;
};

struct mutex___51 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___51 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___47 {
	struct page___50 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___54;

struct fs_struct___2;

struct nsproxy___21;

struct signal_struct___50;

struct bio_list___5;

struct backing_dev_info___5;

struct io_context___5;

struct css_set___23;

struct perf_event_context___19;

struct task_struct___51 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___51 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___54 *mm;
	struct mm_struct___54 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___51 *real_parent;
	struct task_struct___51 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___51 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___20 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___50 = 0,
		VTIME_USER___50 = 1,
		VTIME_SYS___50 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___19 thread;
	struct fs_struct___2 *fs;
	struct files_struct *files;
	struct nsproxy___21 *nsproxy;
	struct signal_struct___50 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___5 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___5 *backing_dev_info;
	struct io_context___5 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___23 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___19 *perf_event_ctxp[2];
	struct mutex___51 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___47 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___54 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___54 *, struct mm_struct___54 *);
	void (*dup_mmap)(struct mm_struct___54 *, struct mm_struct___54 *);
	void (*exit_mmap)(struct mm_struct___54 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___54 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___54 *);
	void (*pgd_free)(struct mm_struct___54 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___54 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___54 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___54 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___54 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___54 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___54 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___54 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___54 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___54 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___54 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___54 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___51 lock;
	void *vdso;
} mm_context_t___51;

struct xol_area___50;

struct uprobes_state___50 {
	struct xol_area___50 *xol_area;
};

struct vm_area_struct___54;

struct file___50;

struct linux_binfmt___2;

struct core_state___50;

struct mm_struct___54 {
	struct vm_area_struct___54 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___54 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___54 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___2 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___51 context;
	long unsigned int flags;
	struct core_state___50 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___51 *owner;
	struct file___50 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___50 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___33;

struct exec_domain___13 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___33 *module;
	struct exec_domain___13 *next;
};

struct module_kobject___32 {
	struct kobject kobj;
	struct module___33 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___32;

struct ftrace_event_call___11;

struct module___33 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___32 mkobj;
	struct module_attribute___32 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___11 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___51 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___19 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___51 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___51 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___51 *target;
};

typedef void (*perf_overflow_handler_t___19)(struct perf_event___19 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___19;

typedef void (*ftrace_func_t___19)(long unsigned int, long unsigned int, struct ftrace_ops___19 *, struct pt_regs *);

struct ftrace_ops___19 {
	ftrace_func_t___19 func;
	struct ftrace_ops___19 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___51 regex_lock;
};

struct pmu___19;

struct fasync_struct___50;

struct pid_namespace___20;

struct perf_cgroup___19;

struct perf_event___19 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___19 *group_leader;
	struct pmu___19 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___19 hw;
	struct perf_event_context___19 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___51 child_mutex;
	struct list_head child_list;
	struct perf_event___19 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___51 *owner;
	struct mutex___51 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___50 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___19 *);
	struct callback_head callback_head;
	struct pid_namespace___20 *ns;
	u64 id;
	perf_overflow_handler_t___19 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___11 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___19 ftrace_ops;
	struct perf_cgroup___19 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___20 {
	struct task_struct___51 *task;
	struct exec_domain___13 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___50;

struct lruvec___50 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___50 *zone;
};

struct pglist_data___50;

struct zone___50 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___50 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___50 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___50 {
	struct zone___50 *zone;
	int zone_idx;
};

struct zonelist___50 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___50 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___50 {
	struct zone___50 node_zones[4];
	struct zonelist___50 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___51 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___34;

struct x86_io_apic_ops___34 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___34 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___34;

struct irq_data___34 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___34 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___39;

struct dev_pm_ops___39 {
	int (*prepare)(struct device___39 *);
	void (*complete)(struct device___39 *);
	int (*suspend)(struct device___39 *);
	int (*resume)(struct device___39 *);
	int (*freeze)(struct device___39 *);
	int (*thaw)(struct device___39 *);
	int (*poweroff)(struct device___39 *);
	int (*restore)(struct device___39 *);
	int (*suspend_late)(struct device___39 *);
	int (*resume_early)(struct device___39 *);
	int (*freeze_late)(struct device___39 *);
	int (*thaw_early)(struct device___39 *);
	int (*poweroff_late)(struct device___39 *);
	int (*restore_early)(struct device___39 *);
	int (*suspend_noirq)(struct device___39 *);
	int (*resume_noirq)(struct device___39 *);
	int (*freeze_noirq)(struct device___39 *);
	int (*thaw_noirq)(struct device___39 *);
	int (*poweroff_noirq)(struct device___39 *);
	int (*restore_noirq)(struct device___39 *);
	int (*runtime_suspend)(struct device___39 *);
	int (*runtime_resume)(struct device___39 *);
	int (*runtime_idle)(struct device___39 *);
};

struct dma_map_ops___20;

struct dev_archdata___20 {
	struct dma_map_ops___20 *dma_ops;
	void *iommu;
};

struct device_type___39;

struct bus_type___39;

struct device_driver___39;

struct dev_pm_domain___39;

struct class___39;

struct attribute_group___34;

struct device_rh___39;

struct device___39 {
	struct device___39 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___39 *type;
	struct mutex___51 mutex;
	struct bus_type___39 *bus;
	struct device_driver___39 *driver;
	void *platform_data;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___39 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___20 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___39 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___39 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___39 *device_rh;
};

struct dev_pm_info_rh___39 {
	void (*set_latency_tolerance)(struct device___39 *, s32);
};

struct dev_pm_domain___39 {
	struct dev_pm_ops___39 ops;
};

struct smp_ops___50 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___51 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___34;

struct attribute_group___34 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___34 **bin_attrs;
};

struct bin_attribute___34 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___50 *, struct kobject *, struct bin_attribute___34 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___50 *, struct kobject *, struct bin_attribute___34 *, char *, loff_t, size_t);
	int (*mmap)(struct file___50 *, struct kobject *, struct bin_attribute___34 *, struct vm_area_struct___54 *);
};

struct vfsmount___4;

struct dentry___51;

struct path___50 {
	struct vfsmount___4 *mnt;
	struct dentry___51 *dentry;
};

struct fown_struct___20 {
	rwlock_t lock;
	struct pid___20 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___51;

struct file_operations___50;

struct file___50 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___50 f_path;
	struct inode___51 *f_inode;
	const struct file_operations___50 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___20 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___50 *f_mapping;
	struct mutex___51 f_pos_lock;
};

struct vm_operations_struct___44;

struct vm_area_struct___54 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___54 *vm_next;
	struct vm_area_struct___54 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___54 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___44 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___50 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___41 {
	void **freelist;
	long unsigned int tid;
	struct page___50 *page;
	struct page___50 *partial;
};

struct memcg_cache_params___41;

struct kmem_cache___41 {
	struct kmem_cache_cpu___41 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___41 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___41 {
	bool is_root_cache;
	union {
		struct kmem_cache___41 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___41 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct ctl_table_header___4;

struct ctl_node___4 {
	struct rb_node node;
	struct ctl_table_header___4 *header;
};

struct ctl_table_root___4;

struct ctl_table_set___4;

struct ctl_dir___4;

struct ctl_table_header___4 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___4 *root;
	struct ctl_table_set___4 *set;
	struct ctl_dir___4 *parent;
	struct ctl_node___4 *node;
};

struct ctl_dir___4 {
	struct ctl_table_header___4 header;
	struct rb_root root;
};

struct ctl_table_set___4 {
	int (*is_seen)(struct ctl_table_set___4 *);
	struct ctl_dir___4 dir;
};

struct ctl_table_root___4 {
	struct ctl_table_set___4 default_set;
	struct ctl_table_set___4 * (*lookup)(struct ctl_table_root___4 *, struct nsproxy___21 *);
	int (*permissions)(struct ctl_table_header___4 *, struct ctl_table *);
};

struct net___6;

struct nsproxy___21 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___20 *pid_ns;
	struct net___6 *net_ns;
};

struct module_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___32 *, struct module_kobject___32 *, char *);
	ssize_t (*store)(struct module_attribute___32 *, struct module_kobject___32 *, const char *, size_t);
	void (*setup)(struct module___33 *, const char *);
	int (*test)(struct module___33 *);
	void (*free)(struct module___33 *);
};

struct trace_event_functions___11;

struct trace_event___11 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___11 *funcs;
};

struct ftrace_event_class___11;

struct ftrace_event_call___11 {
	struct list_head list;
	struct ftrace_event_class___11 *class;
	char *name;
	struct trace_event___11 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct xol_area___50 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___50 *page;
	long unsigned int vaddr;
};

struct address_space_operations___50;

struct address_space___50 {
	struct inode___51 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___51 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___50 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___5 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___41;

struct vm_operations_struct___44 {
	void (*open)(struct vm_area_struct___54 *);
	void (*close)(struct vm_area_struct___54 *);
	int (*fault)(struct vm_area_struct___54 *, struct vm_fault___41 *);
	int (*page_mkwrite)(struct vm_area_struct___54 *, struct vm_fault___41 *);
	int (*access)(struct vm_area_struct___54 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___54 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___54 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___54 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___54 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___50 {
	struct task_struct___51 *task;
	struct core_thread___50 *next;
};

struct core_state___50 {
	atomic_t nr_threads;
	struct core_thread___50 dumper;
	struct completion startup;
};

struct linux_binprm___3;

struct coredump_params___2;

struct linux_binfmt___2 {
	struct list_head lh;
	struct module___33 *module;
	int (*load_binary)(struct linux_binprm___3 *);
	int (*load_shlib)(struct file___50 *);
	int (*core_dump)(struct coredump_params___2 *);
	long unsigned int min_coredump;
};

struct mmu_notifier_mm {
	struct hlist_head list;
	spinlock_t lock;
};

struct vm_fault___41 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___50 *page;
};

struct dentry_operations___50;

struct super_block___51;

struct dentry___51 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___51 *d_parent;
	struct qstr d_name;
	struct inode___51 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___50 *d_op;
	struct super_block___51 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___50;

struct file_lock___50;

struct dquot___50;

struct block_device___50;

struct cdev___21;

struct inode___51 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___50 *i_op;
	struct super_block___51 *i_sb;
	struct address_space___50 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___51 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___50 *i_fop;
	struct file_lock___50 *i_flock;
	struct address_space___50 i_data;
	struct dquot___50 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___50 *i_bdev;
		struct cdev___21 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___50 {
	int (*d_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_hash)(const struct dentry___51 *, struct qstr *);
	int (*d_compare)(const struct dentry___51 *, const struct dentry___51 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___51 *);
	void (*d_release)(struct dentry___51 *);
	void (*d_prune)(struct dentry___51 *);
	void (*d_iput)(struct dentry___51 *, struct inode___51 *);
	char * (*d_dname)(struct dentry___51 *, char *, int);
	struct vfsmount___4 * (*d_automount)(struct path___50 *);
	int (*d_manage)(struct dentry___51 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___50;

struct mem_dqinfo___50 {
	struct quota_format_type___50 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___50;

struct quota_info___50 {
	unsigned int flags;
	struct mutex___51 dqio_mutex;
	struct mutex___51 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___51 *files[2];
	struct mem_dqinfo___50 info[2];
	const struct quota_format_ops___50 *ops[2];
};

struct file_system_type___50;

struct super_operations___50;

struct dquot_operations___50;

struct quotactl_ops___50;

struct xattr_handler___23;

struct super_block___51 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___50 *s_type;
	const struct super_operations___50 *s_op;
	const struct dquot_operations___50 *dq_op;
	const struct quotactl_ops___50 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___51 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___23 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___50 *s_bdev;
	struct backing_dev_info___5 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___50 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___51 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___50 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___4 {
	struct dentry___51 *mnt_root;
	struct super_block___51 *mnt_sb;
	int mnt_flags;
};

struct upid___20 {
	int nr;
	struct pid_namespace___20 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___20 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___51 *child_reaper;
	struct kmem_cache___41 *pid_cachep;
	unsigned int level;
	struct pid_namespace___20 *parent;
	struct vfsmount___4 *proc_mnt;
	struct dentry___51 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___20 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___20 numbers[1];
};

struct bio___5;

typedef void bio_end_io_t___5(struct bio___5 *, int);

struct bio_vec___5 {
	struct page___50 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___23;

struct bio_integrity_payload___5;

struct bio_set___5;

struct bio___5 {
	sector_t bi_sector;
	struct bio___5 *bi_next;
	struct block_device___50 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___5 *bi_end_io;
	void *bi_private;
	struct io_context___5 *bi_ioc;
	struct cgroup_subsys_state___23 *bi_css;
	struct bio_integrity_payload___5 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___5 *bi_io_vec;
	struct bio_set___5 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___5 bi_inline_vecs[0];
};

struct hd_struct___5;

struct gendisk___5;

struct request_queue___5;

struct block_device___50 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___51 *bd_inode;
	struct super_block___51 *bd_super;
	struct mutex___51 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___50 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___5 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___5 *bd_disk;
	struct request_queue___5 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___51 bd_fsfreeze_mutex;
};

struct io_cq___5;

struct io_context___5 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___5 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___23;

struct cgroup_subsys_state___23 {
	struct cgroup___23 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___5 {
	struct bio___5 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___5 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___5 *bip_vec;
	struct bio_vec___5 bip_inline_vecs[0];
};

struct bio_list___5 {
	struct bio___5 *head;
	struct bio___5 *tail;
};

struct bio_set___5 {
	struct kmem_cache___41 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___5 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct kiocb___2;

typedef int kiocb_cancel_fn___2(struct kiocb___2 *, struct io_event *);

struct kiocb___2 {
	atomic_t ki_users;
	struct file___50 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___2 *ki_cancel;
	void (*ki_dtor)(struct kiocb___2 *);
	union {
		void *user;
		struct task_struct___51 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___51 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___50 *ia_file;
};

struct dquot___50 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___51 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___51 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___50 {
	int qf_fmt_id;
	const struct quota_format_ops___50 *qf_ops;
	struct module___33 *qf_owner;
	struct quota_format_type___50 *qf_next;
};

struct quota_format_ops___50 {
	int (*check_quota_file)(struct super_block___51 *, int);
	int (*read_file_info)(struct super_block___51 *, int);
	int (*write_file_info)(struct super_block___51 *, int);
	int (*free_file_info)(struct super_block___51 *, int);
	int (*read_dqblk)(struct dquot___50 *);
	int (*commit_dqblk)(struct dquot___50 *);
	int (*release_dqblk)(struct dquot___50 *);
};

struct dquot_operations___50 {
	int (*write_dquot)(struct dquot___50 *);
	struct dquot___50 * (*alloc_dquot)(struct super_block___51 *, int);
	void (*destroy_dquot)(struct dquot___50 *);
	int (*acquire_dquot)(struct dquot___50 *);
	int (*release_dquot)(struct dquot___50 *);
	int (*mark_dirty)(struct dquot___50 *);
	int (*write_info)(struct super_block___51 *, int);
	qsize_t * (*get_reserved_space)(struct inode___51 *);
};

struct quotactl_ops___50 {
	int (*quota_on)(struct super_block___51 *, int, int, struct path___50 *);
	int (*quota_on_meta)(struct super_block___51 *, int, int);
	int (*quota_off)(struct super_block___51 *, int);
	int (*quota_sync)(struct super_block___51 *, int);
	int (*get_info)(struct super_block___51 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___51 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___51 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___51 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___51 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___51 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___51 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___51 *, unsigned int);
};

struct swap_info_struct___6;

struct address_space_operations___50 {
	int (*writepage)(struct page___50 *, struct writeback_control *);
	int (*readpage)(struct file___50 *, struct page___50 *);
	int (*writepages)(struct address_space___50 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___50 *);
	int (*readpages)(struct file___50 *, struct address_space___50 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___50 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___50 **, void **);
	int (*write_end)(struct file___50 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___50 *, void *);
	sector_t (*bmap)(struct address_space___50 *, sector_t);
	void (*invalidatepage)(struct page___50 *, long unsigned int);
	int (*releasepage)(struct page___50 *, gfp_t);
	void (*freepage)(struct page___50 *);
	ssize_t (*direct_IO)(int, struct kiocb___2 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___50 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___50 *, struct page___50 *, struct page___50 *, enum migrate_mode);
	int (*launder_page)(struct page___50 *);
	int (*is_partially_uptodate)(struct page___50 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___50 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___50 *, struct page___50 *);
	int (*swap_activate)(struct swap_info_struct___6 *, struct file___50 *, sector_t *);
	void (*swap_deactivate)(struct file___50 *);
	void (*invalidatepage_range)(struct page___50 *, unsigned int, unsigned int);
};

struct swap_info_struct___6 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___50 *bdev;
	struct file___50 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___5 {
	struct backing_dev_info___5 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___5 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___5 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___39 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___51 *debug_dir;
	struct dentry___51 *debug_stats;
};

struct hd_struct___5 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___39 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___5;

struct block_device_operations___5;

struct gendisk___5 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___5 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___5 *part_tbl;
	struct hd_struct___5 part0;
	const struct block_device_operations___5 *fops;
	struct request_queue___5 *queue;
	void *private_data;
	int flags;
	struct device___39 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___5 {
	struct request_queue___5 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___5(struct request_queue___5 *);

typedef void make_request_fn___5(struct request_queue___5 *, struct bio___5 *);

struct request___5;

typedef int prep_rq_fn___5(struct request_queue___5 *, struct request___5 *);

struct bvec_merge_data___5;

typedef int merge_bvec_fn___5(struct request_queue___5 *, struct bvec_merge_data___5 *, struct bio_vec___5 *);

typedef void softirq_done_fn___5(struct request___5 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___5(struct request___5 *);

typedef int dma_drain_needed_fn___5(struct request___5 *);

typedef int lld_busy_fn___5(struct request_queue___5 *);

struct bsg_class_device___5 {
	struct device___39 *class_dev;
	struct device___39 *parent;
	int minor;
	struct request_queue___5 *queue;
	struct kref ref;
	void (*release)(struct device___39 *);
};

typedef void unprep_rq_fn___5(struct request_queue___5 *, struct request___5 *);

struct elevator_queue___5;

struct blk_queue_tag___5;

struct request_queue___5 {
	struct list_head queue_head;
	struct request___5 *last_merge;
	struct elevator_queue___5 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___5 root_rl;
	request_fn_proc___5 *request_fn;
	make_request_fn___5 *make_request_fn;
	prep_rq_fn___5 *prep_rq_fn;
	merge_bvec_fn___5 *merge_bvec_fn;
	softirq_done_fn___5 *softirq_done_fn;
	rq_timed_out_fn___5 *rq_timed_out_fn;
	dma_drain_needed_fn___5 *dma_drain_needed;
	lld_busy_fn___5 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___5 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___5 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___39 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___5 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___5 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___51 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___5 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___5 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___5 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___21 {
	struct kobject kobj;
	struct module___33 *owner;
	const struct file_operations___50 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___50 {
	struct dentry___51 * (*lookup)(struct inode___51 *, struct dentry___51 *, unsigned int);
	void * (*follow_link)(struct dentry___51 *, struct nameidata *);
	int (*permission)(struct inode___51 *, int);
	struct posix_acl * (*get_acl)(struct inode___51 *, int);
	int (*readlink)(struct dentry___51 *, char *, int);
	void (*put_link)(struct dentry___51 *, struct nameidata *, void *);
	int (*create)(struct inode___51 *, struct dentry___51 *, umode_t, bool);
	int (*link)(struct dentry___51 *, struct inode___51 *, struct dentry___51 *);
	int (*unlink)(struct inode___51 *, struct dentry___51 *);
	int (*symlink)(struct inode___51 *, struct dentry___51 *, const char *);
	int (*mkdir)(struct inode___51 *, struct dentry___51 *, umode_t);
	int (*rmdir)(struct inode___51 *, struct dentry___51 *);
	int (*mknod)(struct inode___51 *, struct dentry___51 *, umode_t, dev_t);
	int (*rename)(struct inode___51 *, struct dentry___51 *, struct inode___51 *, struct dentry___51 *);
	int (*setattr)(struct dentry___51 *, struct iattr___51 *);
	int (*getattr)(struct vfsmount___4 *, struct dentry___51 *, struct kstat *);
	int (*setxattr)(struct dentry___51 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___51 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___51 *, char *, size_t);
	int (*removexattr)(struct dentry___51 *, const char *);
	int (*fiemap)(struct inode___51 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___51 *, struct timespec *, int);
	int (*atomic_open)(struct inode___51 *, struct dentry___51 *, struct file___50 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___28;

struct seq_file___34;

struct file_operations___50 {
	struct module___33 *owner;
	loff_t (*llseek)(struct file___50 *, loff_t, int);
	ssize_t (*read)(struct file___50 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___50 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___2 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___2 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___50 *, void *, filldir_t);
	unsigned int (*poll)(struct file___50 *, struct poll_table_struct___28 *);
	long int (*unlocked_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___50 *, struct vm_area_struct___54 *);
	int (*open)(struct inode___51 *, struct file___50 *);
	int (*flush)(struct file___50 *, fl_owner_t);
	int (*release)(struct inode___51 *, struct file___50 *);
	int (*fsync)(struct file___50 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___2 *, int);
	int (*fasync)(int, struct file___50 *, int);
	int (*lock)(struct file___50 *, int, struct file_lock___50 *);
	ssize_t (*sendpage)(struct file___50 *, struct page___50 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___50 *, int, struct file_lock___50 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___50 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___50 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___50 *, long int, struct file_lock___50 **, void **);
		struct {
			int (*setlease)(struct file___50 *, long int, struct file_lock___50 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___50 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___34 *, struct file___50 *);
};

struct file_lock_operations___50;

struct lock_manager_operations___50;

struct file_lock___50 {
	struct file_lock___50 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___20 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___50 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___50 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___50 *fl_ops;
	const struct lock_manager_operations___50 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable {
	unsigned int max_fds;
	struct file___50 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct {
	atomic_t count;
	struct fdtable *fdt;
	struct fdtable fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___50 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___50 {
	void (*fl_copy_lock)(struct file_lock___50 *, struct file_lock___50 *);
	void (*fl_release_private)(struct file_lock___50 *);
};

struct lock_manager_operations___50 {
	int (*lm_compare_owner)(struct file_lock___50 *, struct file_lock___50 *);
	long unsigned int (*lm_owner_key)(struct file_lock___50 *);
	void (*lm_notify)(struct file_lock___50 *);
	int (*lm_grant)(struct file_lock___50 *, struct file_lock___50 *, int);
	void (*lm_break)(struct file_lock___50 *);
	int (*lm_change)(struct file_lock___50 **, int);
};

struct fasync_struct___50 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___50 *fa_next;
	struct file___50 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___50 {
	const char *name;
	int fs_flags;
	struct dentry___51 * (*mount)(struct file_system_type___50 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___51 *);
	struct module___33 *owner;
	struct file_system_type___50 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___50 {
	struct inode___51 * (*alloc_inode)(struct super_block___51 *);
	void (*destroy_inode)(struct inode___51 *);
	void (*dirty_inode)(struct inode___51 *, int);
	int (*write_inode)(struct inode___51 *, struct writeback_control *);
	int (*drop_inode)(struct inode___51 *);
	void (*evict_inode)(struct inode___51 *);
	void (*put_super)(struct super_block___51 *);
	int (*sync_fs)(struct super_block___51 *, int);
	int (*freeze_fs)(struct super_block___51 *);
	int (*unfreeze_fs)(struct super_block___51 *);
	int (*statfs)(struct dentry___51 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___51 *, int *, char *);
	void (*umount_begin)(struct super_block___51 *);
	int (*show_options)(struct seq_file___34 *, struct dentry___51 *);
	int (*show_devname)(struct seq_file___34 *, struct dentry___51 *);
	int (*show_path)(struct seq_file___34 *, struct dentry___51 *);
	int (*show_stats)(struct seq_file___34 *, struct dentry___51 *);
	ssize_t (*quota_read)(struct super_block___51 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___51 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___51 *);
	int (*bdev_try_to_free_page)(struct super_block___51 *, struct page___50 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___51 *);
	void (*free_cached_objects)(struct super_block___51 *, int);
};

struct xattr_handler___23 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___51 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___51 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___51 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___28)(struct file___50 *, wait_queue_head_t *, struct poll_table_struct___28 *);

struct poll_table_struct___28 {
	poll_queue_proc___28 _qproc;
	long unsigned int _key;
};

struct seq_operations___33;

struct seq_file___34 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___51 lock;
	const struct seq_operations___33 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___34 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___34 *);
	void (*irq_shutdown)(struct irq_data___34 *);
	void (*irq_enable)(struct irq_data___34 *);
	void (*irq_disable)(struct irq_data___34 *);
	void (*irq_ack)(struct irq_data___34 *);
	void (*irq_mask)(struct irq_data___34 *);
	void (*irq_mask_ack)(struct irq_data___34 *);
	void (*irq_unmask)(struct irq_data___34 *);
	void (*irq_eoi)(struct irq_data___34 *);
	int (*irq_set_affinity)(struct irq_data___34 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___34 *);
	int (*irq_set_type)(struct irq_data___34 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___34 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___34 *);
	void (*irq_bus_sync_unlock)(struct irq_data___34 *);
	void (*irq_cpu_online)(struct irq_data___34 *);
	void (*irq_cpu_offline)(struct irq_data___34 *);
	void (*irq_suspend)(struct irq_data___34 *);
	void (*irq_resume)(struct irq_data___34 *);
	void (*irq_pm_shutdown)(struct irq_data___34 *);
	void (*irq_print_chip)(struct irq_data___34 *, struct seq_file___34 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___34 *, void *);
	long unsigned int flags;
};

struct io_cq___5 {
	struct request_queue___5 *q;
	struct io_context___5 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___41 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct tty_struct___3;

struct signal_struct___50 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___51 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___51 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___20 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___20 *tty_old_pgrp;
	int leader;
	struct tty_struct___3 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___51 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_operations___3;

struct tty_ldisc___3;

struct tty_port___3;

struct tty_struct___3 {
	int magic;
	struct kref kref;
	struct device___39 *dev;
	struct tty_driver___3 *driver;
	const struct tty_operations___3 *ops;
	int index;
	struct mutex___51 ldisc_mutex;
	struct tty_ldisc___3 *ldisc;
	struct mutex___51 atomic_write_lock;
	struct mutex___51 legacy_mutex;
	struct mutex___51 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___20 *pgrp;
	struct pid___20 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___3 *link;
	struct fasync_struct___50 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___3 *port;
	struct ld_semaphore ldisc_sem;
};

struct fs_struct___2 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___50 root;
	struct path___50 pwd;
};

struct css_set___23 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___23 *subsys[11];
	struct callback_head callback_head;
};

struct robust_list {
	struct robust_list *next;
};

struct robust_list_head {
	struct robust_list list;
	long int futex_offset;
	struct robust_list *list_op_pending;
};

struct perf_event_context___19 {
	struct pmu___19 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___51 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___51 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___19 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct linux_binprm___3 {
	char buf[128];
	struct vm_area_struct___54 *vma;
	long unsigned int vma_pages;
	struct mm_struct___54 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___50 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___2 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___50 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct netns_core___4 {
	struct ctl_table_header___4 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___4 {
	struct mutex___51 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___4 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___4 *ctl;
};

struct netns_ipv4___4 {
	struct ctl_table_header___4 *forw_hdr;
	struct ctl_table_header___4 *frags_hdr;
	struct ctl_table_header___4 *ipv4_hdr;
	struct ctl_table_header___4 *route_hdr;
	struct ctl_table_header___4 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___4 {
	struct ctl_table_header___4 *hdr;
	struct ctl_table_header___4 *route_hdr;
	struct ctl_table_header___4 *icmp_hdr;
	struct ctl_table_header___4 *frags_hdr;
	struct ctl_table_header___4 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct sk_buff___6;

struct dst_ops___5 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___5 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___6 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *);
	int (*local_out)(struct sk_buff___6 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___6 *, const void *);
	struct kmem_cache___41 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___4 {
	struct netns_sysctl_ipv6___4 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___4 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___4 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___4 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___4 *nf_log_dir_header;
};

struct nf_proto_net___4 {
	struct ctl_table_header___4 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___4 {
	struct nf_proto_net___4 pn;
	unsigned int timeout;
};

struct nf_tcp_net___4 {
	struct nf_proto_net___4 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___4 {
	struct nf_proto_net___4 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___4 {
	struct nf_proto_net___4 pn;
	unsigned int timeout;
};

struct nf_ip_net___4 {
	struct nf_generic_net___4 generic;
	struct nf_tcp_net___4 tcp;
	struct nf_udp_net___4 udp;
	struct nf_icmp_net___4 icmp;
	struct nf_icmp_net___4 icmpv6;
};

struct netns_ct___4 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___4 *sysctl_header;
	struct ctl_table_header___4 *acct_sysctl_header;
	struct ctl_table_header___4 *tstamp_sysctl_header;
	struct ctl_table_header___4 *event_sysctl_header;
	struct ctl_table_header___4 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___41 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___4 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___4 {
	struct netns_sysctl_ipv6___4 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___4 {
	struct sk_buff___6 *next;
	struct sk_buff___6 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___4 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___4 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 xfrm4_dst_ops;
	struct dst_ops___5 xfrm6_dst_ops;
};

struct net___6 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___4 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___4 core;
	struct netns_mib mib;
	struct netns_packet___4 packet;
	struct netns_unix___4 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___4 ipv4;
	struct netns_ipv6___4 ipv6;
	struct netns_sctp___4 sctp;
	struct netns_dccp dccp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct___4 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___4 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___4 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___51 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___51 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___20 {
	void * (*alloc)(struct device___39 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___39 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___39 *, struct vm_area_struct___54 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___39 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___39 *, struct page___50 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___39 *, dma_addr_t);
	int (*dma_supported)(struct device___39 *, u64);
	int (*set_dma_mask)(struct device___39 *, u64);
	int is_phys;
};

struct bus_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___39 *, char *);
	ssize_t (*store)(struct bus_type___39 *, const char *, size_t);
};

struct device_attribute___39;

struct driver_attribute___39;

struct bus_type___39 {
	const char *name;
	const char *dev_name;
	struct device___39 *dev_root;
	struct bus_attribute___39 *bus_attrs;
	struct device_attribute___39 *dev_attrs;
	struct driver_attribute___39 *drv_attrs;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___39 *, struct device_driver___39 *);
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	int (*probe)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*online)(struct device___39 *);
	int (*offline)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct device___39 *, struct device_attribute___39 *, char *);
	ssize_t (*store)(struct device___39 *, struct device_attribute___39 *, const char *, size_t);
};

struct driver_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___39 *, char *);
	ssize_t (*store)(struct device_driver___39 *, const char *, size_t);
};

struct device_driver___39 {
	const char *name;
	struct bus_type___39 *bus;
	struct module___33 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct attribute_group___34 **groups;
	const struct dev_pm_ops___39 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___39 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
};

struct class_attribute___39;

struct class___39 {
	const char *name;
	struct module___33 *owner;
	struct class_attribute___39 *class_attrs;
	struct device_attribute___39 *dev_attrs;
	const struct attribute_group___34 **dev_groups;
	struct bin_attribute___34 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *);
	void (*class_release)(struct class___39 *);
	void (*dev_release)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	struct subsys_private *p;
};

struct class_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct class___39 *, struct class_attribute___39 *, char *);
	ssize_t (*store)(struct class___39 *, struct class_attribute___39 *, const char *, size_t);
	const void * (*namespace)(struct class___39 *, const struct class_attribute___39 *);
};

struct device_rh___39 {
	struct dev_pm_info_rh___39 power;
};

struct cgroupfs_root___23;

struct cgroup___23 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___23 *parent;
	struct dentry___51 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___23 *subsys[11];
	struct cgroupfs_root___23 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___51 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___23 {
	struct super_block___51 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___23 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___7 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___51 *, struct file___50 *);
	ssize_t (*read)(struct cgroup___23 *, struct cftype___7 *, struct file___50 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___23 *, struct cftype___7 *);
	s64 (*read_s64)(struct cgroup___23 *, struct cftype___7 *);
	int (*read_map)(struct cgroup___23 *, struct cftype___7 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___23 *, struct cftype___7 *, struct seq_file___34 *);
	ssize_t (*write)(struct cgroup___23 *, struct cftype___7 *, struct file___50 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___23 *, struct cftype___7 *, u64);
	int (*write_s64)(struct cgroup___23 *, struct cftype___7 *, s64);
	int (*write_string)(struct cgroup___23 *, struct cftype___7 *, const char *);
	int (*trigger)(struct cgroup___23 *, unsigned int);
	int (*release)(struct inode___51 *, struct file___50 *);
	int (*register_event)(struct cgroup___23 *, struct cftype___7 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___23 *, struct cftype___7 *, struct eventfd_ctx *);
};

struct cftype_set___6 {
	struct list_head node;
	struct cftype___7 *cfts;
};

struct task_and_cgroup___6 {
	struct task_struct___51 *task;
	struct cgroup___23 *cgrp;
	struct css_set___23 *cg;
};

struct cgroup_taskset___6 {
	struct task_and_cgroup___6 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___23 *cur_cgrp;
};

struct cgroup_subsys___6 {
	struct cgroup_subsys_state___23 * (*css_alloc)(struct cgroup___23 *);
	int (*css_online)(struct cgroup___23 *);
	void (*css_offline)(struct cgroup___23 *);
	void (*css_free)(struct cgroup___23 *);
	int (*can_attach)(struct cgroup___23 *, struct cgroup_taskset___6 *);
	void (*cancel_attach)(struct cgroup___23 *, struct cgroup_taskset___6 *);
	void (*attach)(struct cgroup___23 *, struct cgroup_taskset___6 *);
	void (*fork)(struct task_struct___51 *);
	void (*exit)(struct cgroup___23 *, struct cgroup___23 *, struct task_struct___51 *);
	void (*bind)(struct cgroup___23 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___23 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___7 *base_cftypes;
	struct cftype_set___6 base_cftset;
	struct module___33 *module;
};

struct sk_buff___6 {
	struct sk_buff___6 *next;
	struct sk_buff___6 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___6 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___2 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct tlb_state___20 {
	struct mm_struct___54 *active_mm;
	int state;
};

struct hstate___3 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___7 cgroup_files[5];
	char name[32];
};

struct seq_operations___33 {
	void * (*start)(struct seq_file___34 *, loff_t *);
	void (*stop)(struct seq_file___34 *, void *);
	void * (*next)(struct seq_file___34 *, void *, loff_t *);
	int (*show)(struct seq_file___34 *, void *);
};

struct perf_cpu_context___19;

struct pmu___19 {
	struct list_head entry;
	struct device___39 *dev;
	const struct attribute_group___34 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___19 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___19 *);
	void (*pmu_disable)(struct pmu___19 *);
	int (*event_init)(struct perf_event___19 *);
	int (*add)(struct perf_event___19 *, int);
	void (*del)(struct perf_event___19 *, int);
	void (*start)(struct perf_event___19 *, int);
	void (*stop)(struct perf_event___19 *, int);
	void (*read)(struct perf_event___19 *);
	void (*start_txn)(struct pmu___19 *);
	int (*commit_txn)(struct pmu___19 *);
	void (*cancel_txn)(struct pmu___19 *);
	int (*event_idx)(struct perf_event___19 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___33 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___19 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___19 *);
};

struct perf_cpu_context___19 {
	struct perf_event_context___19 ctx;
	struct perf_event_context___19 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___19 *unique_pmu;
	struct perf_cgroup___19 *cgrp;
};

struct perf_cgroup___19 {
	struct cgroup_subsys_state___23 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___11 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___51 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___11)(struct trace_iterator___11 *, int, struct trace_event___11 *);

struct trace_event_functions___11 {
	trace_print_func___11 trace;
	trace_print_func___11 raw;
	trace_print_func___11 hex;
	trace_print_func___11 binary;
};

struct ftrace_event_class___11 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___11 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___11 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___11 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___11 *);
};

struct ftrace_event_file___6 {
	struct list_head list;
	struct ftrace_event_call___11 *event_call;
	struct dentry___51 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct syscall_metadata___2 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___11 *enter_event;
	struct ftrace_event_call___11 *exit_event;
};

struct tty_operations___3 {
	struct tty_struct___3 * (*lookup)(struct tty_driver___3 *, struct inode___51 *, int);
	int (*install)(struct tty_driver___3 *, struct tty_struct___3 *);
	void (*remove)(struct tty_driver___3 *, struct tty_struct___3 *);
	int (*open)(struct tty_struct___3 *, struct file___50 *);
	void (*close)(struct tty_struct___3 *, struct file___50 *);
	void (*shutdown)(struct tty_struct___3 *);
	void (*cleanup)(struct tty_struct___3 *);
	int (*write)(struct tty_struct___3 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___3 *, unsigned char);
	void (*flush_chars)(struct tty_struct___3 *);
	int (*write_room)(struct tty_struct___3 *);
	int (*chars_in_buffer)(struct tty_struct___3 *);
	int (*ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	void (*throttle)(struct tty_struct___3 *);
	void (*unthrottle)(struct tty_struct___3 *);
	void (*stop)(struct tty_struct___3 *);
	void (*start)(struct tty_struct___3 *);
	void (*hangup)(struct tty_struct___3 *);
	int (*break_ctl)(struct tty_struct___3 *, int);
	void (*flush_buffer)(struct tty_struct___3 *);
	void (*set_ldisc)(struct tty_struct___3 *);
	void (*wait_until_sent)(struct tty_struct___3 *, int);
	void (*send_xchar)(struct tty_struct___3 *, char);
	int (*tiocmget)(struct tty_struct___3 *);
	int (*tiocmset)(struct tty_struct___3 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___3 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___3 *, struct termiox *);
	int (*get_icount)(struct tty_struct___3 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___3 *, int, char *);
	int (*poll_get_char)(struct tty_driver___3 *, int);
	void (*poll_put_char)(struct tty_driver___3 *, int, char);
	const struct file_operations___50 *proc_fops;
};

struct tty_driver___3 {
	int magic;
	struct kref kref;
	struct cdev___21 *cdevs;
	struct module___33 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___3 *other;
	struct tty_struct___3 **ttys;
	struct tty_port___3 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___3 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___3;

struct tty_port___3 {
	struct tty_bufhead buf;
	struct tty_struct___3 *tty;
	struct tty_struct___3 *itty;
	const struct tty_port_operations___3 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___51 mutex;
	struct mutex___51 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___3 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___3 *);
	void (*close)(struct tty_struct___3 *);
	void (*flush_buffer)(struct tty_struct___3 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___3 *);
	ssize_t (*read)(struct tty_struct___3 *, struct file___50 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___3 *, struct file___50 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___3 *, struct file___50 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, struct file___50 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___3 *, struct file___50 *, struct poll_table_struct___28 *);
	int (*hangup)(struct tty_struct___3 *);
	void (*receive_buf)(struct tty_struct___3 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___3 *);
	void (*dcd_change)(struct tty_struct___3 *, unsigned int);
	struct module___33 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___3 *, int);
};

struct tty_ldisc___3 {
	struct tty_ldisc_ops___3 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___3 *tty;
};

struct tty_port_operations___3 {
	int (*carrier_raised)(struct tty_port___3 *);
	void (*dtr_rts)(struct tty_port___3 *, int);
	void (*shutdown)(struct tty_port___3 *);
	void (*drop)(struct tty_port___3 *);
	int (*activate)(struct tty_port___3 *, struct tty_struct___3 *);
	void (*destruct)(struct tty_port___3 *);
};

struct disk_part_tbl___5 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___5 *last_lookup;
	struct hd_struct___5 *part[0];
};

struct block_device_operations___5 {
	int (*open)(struct block_device___50 *, fmode_t);
	void (*release)(struct gendisk___5 *, fmode_t);
	int (*ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___50 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___5 *, unsigned int);
	int (*media_changed)(struct gendisk___5 *);
	void (*unlock_native_capacity)(struct gendisk___5 *);
	int (*revalidate_disk)(struct gendisk___5 *);
	int (*getgeo)(struct block_device___50 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___50 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___33 *owner;
};

enum {
	IOPRIO_CLASS_NONE = 0,
	IOPRIO_CLASS_RT = 1,
	IOPRIO_CLASS_BE = 2,
	IOPRIO_CLASS_IDLE = 3,
};

typedef void rq_end_io_fn___5(struct request___5 *, int);

struct request___5 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue___5 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___5 *bio;
	struct bio___5 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___5 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___5 *saved_end_io;
		} flush;
	};
	struct gendisk___5 *rq_disk;
	struct hd_struct___5 *part;
	long unsigned int start_time;
	struct request_list___5 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___5 *end_io;
	void *end_io_data;
	struct request___5 *next_rq;
};

typedef int elevator_merge_fn___5(struct request_queue___5 *, struct request___5 **, struct bio___5 *);

typedef void elevator_merge_req_fn___5(struct request_queue___5 *, struct request___5 *, struct request___5 *);

typedef void elevator_merged_fn___5(struct request_queue___5 *, struct request___5 *, int);

typedef int elevator_allow_merge_fn___5(struct request_queue___5 *, struct request___5 *, struct bio___5 *);

typedef void elevator_bio_merged_fn___5(struct request_queue___5 *, struct request___5 *, struct bio___5 *);

typedef int elevator_dispatch_fn___5(struct request_queue___5 *, int);

typedef void elevator_add_req_fn___5(struct request_queue___5 *, struct request___5 *);

typedef struct request___5 *elevator_request_list_fn___5(struct request_queue___5 *, struct request___5 *);

typedef void elevator_completed_req_fn___5(struct request_queue___5 *, struct request___5 *);

typedef int elevator_may_queue_fn___5(struct request_queue___5 *, int);

typedef void elevator_init_icq_fn___5(struct io_cq___5 *);

typedef void elevator_exit_icq_fn___5(struct io_cq___5 *);

typedef int elevator_set_req_fn___5(struct request_queue___5 *, struct request___5 *, struct bio___5 *, gfp_t);

typedef void elevator_put_req_fn___5(struct request___5 *);

typedef void elevator_activate_req_fn___5(struct request_queue___5 *, struct request___5 *);

typedef void elevator_deactivate_req_fn___5(struct request_queue___5 *, struct request___5 *);

struct elevator_type___5;

typedef int elevator_init_fn___5(struct request_queue___5 *, struct elevator_type___5 *);

typedef void elevator_exit_fn___5(struct elevator_queue___5 *);

struct elevator_ops___5 {
	elevator_merge_fn___5 *elevator_merge_fn;
	elevator_merged_fn___5 *elevator_merged_fn;
	elevator_merge_req_fn___5 *elevator_merge_req_fn;
	elevator_allow_merge_fn___5 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___5 *elevator_bio_merged_fn;
	elevator_dispatch_fn___5 *elevator_dispatch_fn;
	elevator_add_req_fn___5 *elevator_add_req_fn;
	elevator_activate_req_fn___5 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___5 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___5 *elevator_completed_req_fn;
	elevator_request_list_fn___5 *elevator_former_req_fn;
	elevator_request_list_fn___5 *elevator_latter_req_fn;
	elevator_init_icq_fn___5 *elevator_init_icq_fn;
	elevator_exit_icq_fn___5 *elevator_exit_icq_fn;
	elevator_set_req_fn___5 *elevator_set_req_fn;
	elevator_put_req_fn___5 *elevator_put_req_fn;
	elevator_may_queue_fn___5 *elevator_may_queue_fn;
	elevator_init_fn___5 *elevator_init_fn;
	elevator_exit_fn___5 *elevator_exit_fn;
};

struct elv_fs_entry___5;

struct elevator_type___5 {
	struct kmem_cache___41 *icq_cache;
	struct elevator_ops___5 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___5 *elevator_attrs;
	char elevator_name[16];
	struct module___33 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___5 {
	struct elevator_type___5 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___51 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___5 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___5 *, char *);
	ssize_t (*store)(struct elevator_queue___5 *, const char *, size_t);
};

struct bvec_merge_data___5 {
	struct block_device___50 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___5 {
	struct request___5 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct ftrace_raw_task_newtask {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	long unsigned int clone_flags;
	short int oom_score_adj;
	char __data[0];
};

struct ftrace_raw_task_rename {
	struct trace_entry ent;
	pid_t pid;
	char oldcomm[16];
	char newcomm[16];
	short int oom_score_adj;
	char __data[0];
};

struct ftrace_data_offsets_task_newtask {};

struct ftrace_data_offsets_task_rename {};

struct nf_afinfo___4 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___6 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___6 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___6 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___6 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___6 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct page___51;

typedef struct page___51 *pgtable_t___51;

struct address_space___51;

struct kmem_cache___42;

struct page___51 {
	long unsigned int flags;
	struct address_space___51 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___51 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___51 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___42 *slab_cache;
		struct page___51 *first_page;
	};
	long: 64;
};

struct thread_struct___20;

struct task_struct___52;

struct pv_cpu_ops___51 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___20 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___20 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___52 *);
	void (*end_context_switch)(struct task_struct___52 *);
};

struct perf_event___20;

struct thread_struct___20 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___20 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___21;

struct pid_link___21 {
	struct hlist_node node;
	struct pid___21 *pid;
};

struct mutex___52 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___52 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___48 {
	struct page___51 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___55;

struct fs_struct___3;

struct nsproxy___22;

struct signal_struct___51;

struct css_set___24;

struct perf_event_context___20;

struct task_struct___52 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___52 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___55 *mm;
	struct mm_struct___55 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___52 *real_parent;
	struct task_struct___52 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___52 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___21 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___51 = 0,
		VTIME_USER___51 = 1,
		VTIME_SYS___51 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___20 thread;
	struct fs_struct___3 *fs;
	struct files_struct *files;
	struct nsproxy___22 *nsproxy;
	struct signal_struct___51 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___24 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___20 *perf_event_ctxp[2];
	struct mutex___52 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___48 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___55 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___55 *, struct mm_struct___55 *);
	void (*dup_mmap)(struct mm_struct___55 *, struct mm_struct___55 *);
	void (*exit_mmap)(struct mm_struct___55 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___55 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___55 *);
	void (*pgd_free)(struct mm_struct___55 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___55 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___55 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___55 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___55 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___55 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___55 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___55 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___55 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___55 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___55 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___55 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___52 lock;
	void *vdso;
} mm_context_t___52;

struct xol_area___51;

struct uprobes_state___51 {
	struct xol_area___51 *xol_area;
};

struct vm_area_struct___55;

struct file___51;

struct core_state___51;

struct mm_struct___55 {
	struct vm_area_struct___55 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___55 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___55 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___52 context;
	long unsigned int flags;
	struct core_state___51 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___52 *owner;
	struct file___51 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___51 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

enum {
	PER_LINUX = 0,
	PER_LINUX_32BIT = 8388608,
	PER_LINUX_FDPIC = 524288,
	PER_SVR4 = 68157441,
	PER_SVR3 = 83886082,
	PER_SCOSVR3 = 117440515,
	PER_OSR5 = 100663299,
	PER_WYSEV386 = 83886084,
	PER_ISCR4 = 67108869,
	PER_BSD = 6,
	PER_SUNOS = 67108870,
	PER_XENIX = 83886087,
	PER_LINUX32 = 8,
	PER_LINUX32_3GB = 134217736,
	PER_IRIX32 = 67108873,
	PER_IRIXN32 = 67108874,
	PER_IRIX64 = 67108875,
	PER_RISCOS = 12,
	PER_SOLARIS = 67108877,
	PER_UW7 = 68157454,
	PER_OSF4 = 15,
	PER_HPUX = 16,
	PER_MASK = 255,
};

struct module___34;

struct exec_domain___14 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___34 *module;
	struct exec_domain___14 *next;
};

struct module_kobject___33 {
	struct kobject kobj;
	struct module___34 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___33;

struct ftrace_event_call___12;

struct module___34 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___33 mkobj;
	struct module_attribute___33 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___12 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___52 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___20 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___52 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___52 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___52 *target;
};

typedef void (*perf_overflow_handler_t___20)(struct perf_event___20 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___20;

typedef void (*ftrace_func_t___20)(long unsigned int, long unsigned int, struct ftrace_ops___20 *, struct pt_regs *);

struct ftrace_ops___20 {
	ftrace_func_t___20 func;
	struct ftrace_ops___20 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___52 regex_lock;
};

struct pmu___20;

struct fasync_struct___51;

struct pid_namespace___21;

struct perf_cgroup___20;

struct perf_event___20 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___20 *group_leader;
	struct pmu___20 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___20 hw;
	struct perf_event_context___20 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___52 child_mutex;
	struct list_head child_list;
	struct perf_event___20 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___52 *owner;
	struct mutex___52 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___51 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___20 *);
	struct callback_head callback_head;
	struct pid_namespace___21 *ns;
	u64 id;
	perf_overflow_handler_t___20 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___12 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___20 ftrace_ops;
	struct perf_cgroup___20 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___21 {
	struct task_struct___52 *task;
	struct exec_domain___14 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___51;

struct lruvec___51 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___51 *zone;
};

struct pglist_data___51;

struct zone___51 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___51 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___51 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___51 {
	struct zone___51 *zone;
	int zone_idx;
};

struct zonelist___51 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___51 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___51 {
	struct zone___51 node_zones[4];
	struct zonelist___51 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___52 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___35;

struct x86_io_apic_ops___35 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___35 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___35;

struct irq_data___35 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___35 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___40;

struct dev_pm_ops___40 {
	int (*prepare)(struct device___40 *);
	void (*complete)(struct device___40 *);
	int (*suspend)(struct device___40 *);
	int (*resume)(struct device___40 *);
	int (*freeze)(struct device___40 *);
	int (*thaw)(struct device___40 *);
	int (*poweroff)(struct device___40 *);
	int (*restore)(struct device___40 *);
	int (*suspend_late)(struct device___40 *);
	int (*resume_early)(struct device___40 *);
	int (*freeze_late)(struct device___40 *);
	int (*thaw_early)(struct device___40 *);
	int (*poweroff_late)(struct device___40 *);
	int (*restore_early)(struct device___40 *);
	int (*suspend_noirq)(struct device___40 *);
	int (*resume_noirq)(struct device___40 *);
	int (*freeze_noirq)(struct device___40 *);
	int (*thaw_noirq)(struct device___40 *);
	int (*poweroff_noirq)(struct device___40 *);
	int (*restore_noirq)(struct device___40 *);
	int (*runtime_suspend)(struct device___40 *);
	int (*runtime_resume)(struct device___40 *);
	int (*runtime_idle)(struct device___40 *);
};

struct device_type___40;

struct bus_type___40;

struct device_driver___40;

struct dev_pm_domain___40;

struct class___40;

struct attribute_group___35;

struct device_rh___40;

struct device___40 {
	struct device___40 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___40 *type;
	struct mutex___52 mutex;
	struct bus_type___40 *bus;
	struct device_driver___40 *driver;
	void *platform_data;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___40 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___20 archdata;
	struct device_node *of_node;
	struct acpi_dev_node acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___40 *class;
	const struct attribute_group___35 **groups;
	void (*release)(struct device___40 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___40 *device_rh;
};

struct dev_pm_info_rh___40 {
	void (*set_latency_tolerance)(struct device___40 *, s32);
};

struct dev_pm_domain___40 {
	struct dev_pm_ops___40 ops;
};

struct smp_ops___51 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___52 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___22 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___21 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___35;

struct attribute_group___35 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___35 **bin_attrs;
};

struct bin_attribute___35 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___51 *, struct kobject *, struct bin_attribute___35 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___51 *, struct kobject *, struct bin_attribute___35 *, char *, loff_t, size_t);
	int (*mmap)(struct file___51 *, struct kobject *, struct bin_attribute___35 *, struct vm_area_struct___55 *);
};

struct dentry___52;

struct path___51 {
	struct vfsmount *mnt;
	struct dentry___52 *dentry;
};

struct fown_struct___21 {
	rwlock_t lock;
	struct pid___21 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___52;

struct file_operations___51;

struct file___51 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___51 f_path;
	struct inode___52 *f_inode;
	const struct file_operations___51 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___21 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___51 *f_mapping;
	struct mutex___52 f_pos_lock;
};

struct vm_operations_struct___45;

struct vm_area_struct___55 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___55 *vm_next;
	struct vm_area_struct___55 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___55 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___45 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___51 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___33 *, struct module_kobject___33 *, char *);
	ssize_t (*store)(struct module_attribute___33 *, struct module_kobject___33 *, const char *, size_t);
	void (*setup)(struct module___34 *, const char *);
	int (*test)(struct module___34 *);
	void (*free)(struct module___34 *);
};

struct trace_event_functions___12;

struct trace_event___12 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___12 *funcs;
};

struct ftrace_event_class___12;

struct ftrace_event_call___12 {
	struct list_head list;
	struct ftrace_event_class___12 *class;
	char *name;
	struct trace_event___12 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct dentry_operations___51;

struct super_block___52;

struct dentry___52 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___52 *d_parent;
	struct qstr d_name;
	struct inode___52 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___51 *d_op;
	struct super_block___52 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___51;

struct address_space___51 {
	struct inode___52 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___52 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___51 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___51;

struct file_lock___51;

struct dquot___51;

struct block_device___51;

struct inode___52 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___51 *i_op;
	struct super_block___52 *i_sb;
	struct address_space___51 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___52 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___51 *i_fop;
	struct file_lock___51 *i_flock;
	struct address_space___51 i_data;
	struct dquot___51 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___51 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___51 {
	int (*d_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_hash)(const struct dentry___52 *, struct qstr *);
	int (*d_compare)(const struct dentry___52 *, const struct dentry___52 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___52 *);
	void (*d_release)(struct dentry___52 *);
	void (*d_prune)(struct dentry___52 *);
	void (*d_iput)(struct dentry___52 *, struct inode___52 *);
	char * (*d_dname)(struct dentry___52 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___51 *);
	int (*d_manage)(struct dentry___52 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___51;

struct mem_dqinfo___51 {
	struct quota_format_type___51 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___51;

struct quota_info___51 {
	unsigned int flags;
	struct mutex___52 dqio_mutex;
	struct mutex___52 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___52 *files[2];
	struct mem_dqinfo___51 info[2];
	const struct quota_format_ops___51 *ops[2];
};

struct file_system_type___51;

struct super_operations___51;

struct dquot_operations___51;

struct quotactl_ops___51;

struct xattr_handler___24;

struct super_block___52 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___51 *s_type;
	const struct super_operations___51 *s_op;
	const struct dquot_operations___51 *dq_op;
	const struct quotactl_ops___51 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___52 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___24 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___51 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___51 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___52 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___51 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___21 {
	int nr;
	struct pid_namespace___21 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___21 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___52 *child_reaper;
	struct kmem_cache___42 *pid_cachep;
	unsigned int level;
	struct pid_namespace___21 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___52 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___21 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___21 numbers[1];
};

struct block_device___51 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___52 *bd_inode;
	struct super_block___52 *bd_super;
	struct mutex___52 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___51 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___52 bd_fsfreeze_mutex;
};

struct cgroup___24;

struct cgroup_subsys_state___24 {
	struct cgroup___24 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___52 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___51 *ia_file;
};

struct dquot___51 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___52 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___52 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___51 {
	int qf_fmt_id;
	const struct quota_format_ops___51 *qf_ops;
	struct module___34 *qf_owner;
	struct quota_format_type___51 *qf_next;
};

struct quota_format_ops___51 {
	int (*check_quota_file)(struct super_block___52 *, int);
	int (*read_file_info)(struct super_block___52 *, int);
	int (*write_file_info)(struct super_block___52 *, int);
	int (*free_file_info)(struct super_block___52 *, int);
	int (*read_dqblk)(struct dquot___51 *);
	int (*commit_dqblk)(struct dquot___51 *);
	int (*release_dqblk)(struct dquot___51 *);
};

struct dquot_operations___51 {
	int (*write_dquot)(struct dquot___51 *);
	struct dquot___51 * (*alloc_dquot)(struct super_block___52 *, int);
	void (*destroy_dquot)(struct dquot___51 *);
	int (*acquire_dquot)(struct dquot___51 *);
	int (*release_dquot)(struct dquot___51 *);
	int (*mark_dirty)(struct dquot___51 *);
	int (*write_info)(struct super_block___52 *, int);
	qsize_t * (*get_reserved_space)(struct inode___52 *);
};

struct quotactl_ops___51 {
	int (*quota_on)(struct super_block___52 *, int, int, struct path___51 *);
	int (*quota_on_meta)(struct super_block___52 *, int, int);
	int (*quota_off)(struct super_block___52 *, int);
	int (*quota_sync)(struct super_block___52 *, int);
	int (*get_info)(struct super_block___52 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___52 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___52 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___52 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___52 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___52 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___52 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___52 *, unsigned int);
};

struct address_space_operations___51 {
	int (*writepage)(struct page___51 *, struct writeback_control *);
	int (*readpage)(struct file___51 *, struct page___51 *);
	int (*writepages)(struct address_space___51 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___51 *);
	int (*readpages)(struct file___51 *, struct address_space___51 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___51 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___51 **, void **);
	int (*write_end)(struct file___51 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___51 *, void *);
	sector_t (*bmap)(struct address_space___51 *, sector_t);
	void (*invalidatepage)(struct page___51 *, long unsigned int);
	int (*releasepage)(struct page___51 *, gfp_t);
	void (*freepage)(struct page___51 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___51 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___51 *, struct page___51 *, struct page___51 *, enum migrate_mode);
	int (*launder_page)(struct page___51 *);
	int (*is_partially_uptodate)(struct page___51 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___51 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___51 *, struct page___51 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___51 *, sector_t *);
	void (*swap_deactivate)(struct file___51 *);
	void (*invalidatepage_range)(struct page___51 *, unsigned int, unsigned int);
};

struct inode_operations___51 {
	struct dentry___52 * (*lookup)(struct inode___52 *, struct dentry___52 *, unsigned int);
	void * (*follow_link)(struct dentry___52 *, struct nameidata *);
	int (*permission)(struct inode___52 *, int);
	struct posix_acl * (*get_acl)(struct inode___52 *, int);
	int (*readlink)(struct dentry___52 *, char *, int);
	void (*put_link)(struct dentry___52 *, struct nameidata *, void *);
	int (*create)(struct inode___52 *, struct dentry___52 *, umode_t, bool);
	int (*link)(struct dentry___52 *, struct inode___52 *, struct dentry___52 *);
	int (*unlink)(struct inode___52 *, struct dentry___52 *);
	int (*symlink)(struct inode___52 *, struct dentry___52 *, const char *);
	int (*mkdir)(struct inode___52 *, struct dentry___52 *, umode_t);
	int (*rmdir)(struct inode___52 *, struct dentry___52 *);
	int (*mknod)(struct inode___52 *, struct dentry___52 *, umode_t, dev_t);
	int (*rename)(struct inode___52 *, struct dentry___52 *, struct inode___52 *, struct dentry___52 *);
	int (*setattr)(struct dentry___52 *, struct iattr___52 *);
	int (*getattr)(struct vfsmount *, struct dentry___52 *, struct kstat *);
	int (*setxattr)(struct dentry___52 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___52 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___52 *, char *, size_t);
	int (*removexattr)(struct dentry___52 *, const char *);
	int (*fiemap)(struct inode___52 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___52 *, struct timespec *, int);
	int (*atomic_open)(struct inode___52 *, struct dentry___52 *, struct file___51 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___29;

struct seq_file___35;

struct file_operations___51 {
	struct module___34 *owner;
	loff_t (*llseek)(struct file___51 *, loff_t, int);
	ssize_t (*read)(struct file___51 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___51 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___51 *, void *, filldir_t);
	unsigned int (*poll)(struct file___51 *, struct poll_table_struct___29 *);
	long int (*unlocked_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___51 *, struct vm_area_struct___55 *);
	int (*open)(struct inode___52 *, struct file___51 *);
	int (*flush)(struct file___51 *, fl_owner_t);
	int (*release)(struct inode___52 *, struct file___51 *);
	int (*fsync)(struct file___51 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___51 *, int);
	int (*lock)(struct file___51 *, int, struct file_lock___51 *);
	ssize_t (*sendpage)(struct file___51 *, struct page___51 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___51 *, int, struct file_lock___51 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___51 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___51 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___51 *, long int, struct file_lock___51 **, void **);
		struct {
			int (*setlease)(struct file___51 *, long int, struct file_lock___51 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___51 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___35 *, struct file___51 *);
};

struct file_lock_operations___51;

struct lock_manager_operations___51;

struct file_lock___51 {
	struct file_lock___51 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___21 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___51 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___51 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___51 *fl_ops;
	const struct lock_manager_operations___51 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___51 {
	void (*fl_copy_lock)(struct file_lock___51 *, struct file_lock___51 *);
	void (*fl_release_private)(struct file_lock___51 *);
};

struct lock_manager_operations___51 {
	int (*lm_compare_owner)(struct file_lock___51 *, struct file_lock___51 *);
	long unsigned int (*lm_owner_key)(struct file_lock___51 *);
	void (*lm_notify)(struct file_lock___51 *);
	int (*lm_grant)(struct file_lock___51 *, struct file_lock___51 *, int);
	void (*lm_break)(struct file_lock___51 *);
	int (*lm_change)(struct file_lock___51 **, int);
};

struct fasync_struct___51 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___51 *fa_next;
	struct file___51 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___51 {
	const char *name;
	int fs_flags;
	struct dentry___52 * (*mount)(struct file_system_type___51 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___52 *);
	struct module___34 *owner;
	struct file_system_type___51 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___51 {
	struct inode___52 * (*alloc_inode)(struct super_block___52 *);
	void (*destroy_inode)(struct inode___52 *);
	void (*dirty_inode)(struct inode___52 *, int);
	int (*write_inode)(struct inode___52 *, struct writeback_control *);
	int (*drop_inode)(struct inode___52 *);
	void (*evict_inode)(struct inode___52 *);
	void (*put_super)(struct super_block___52 *);
	int (*sync_fs)(struct super_block___52 *, int);
	int (*freeze_fs)(struct super_block___52 *);
	int (*unfreeze_fs)(struct super_block___52 *);
	int (*statfs)(struct dentry___52 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___52 *, int *, char *);
	void (*umount_begin)(struct super_block___52 *);
	int (*show_options)(struct seq_file___35 *, struct dentry___52 *);
	int (*show_devname)(struct seq_file___35 *, struct dentry___52 *);
	int (*show_path)(struct seq_file___35 *, struct dentry___52 *);
	int (*show_stats)(struct seq_file___35 *, struct dentry___52 *);
	ssize_t (*quota_read)(struct super_block___52 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___52 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___52 *);
	int (*bdev_try_to_free_page)(struct super_block___52 *, struct page___51 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___52 *);
	void (*free_cached_objects)(struct super_block___52 *, int);
};

struct xattr_handler___24 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___52 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___52 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___52 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___29)(struct file___51 *, wait_queue_head_t *, struct poll_table_struct___29 *);

struct poll_table_struct___29 {
	poll_queue_proc___29 _qproc;
	long unsigned int _key;
};

struct seq_operations___34;

struct seq_file___35 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___52 lock;
	const struct seq_operations___34 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___51 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___51 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___42;

struct memcg_cache_params___42;

struct kmem_cache___42 {
	struct kmem_cache_cpu___42 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___42 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___42;

struct vm_operations_struct___45 {
	void (*open)(struct vm_area_struct___55 *);
	void (*close)(struct vm_area_struct___55 *);
	int (*fault)(struct vm_area_struct___55 *, struct vm_fault___42 *);
	int (*page_mkwrite)(struct vm_area_struct___55 *, struct vm_fault___42 *);
	int (*access)(struct vm_area_struct___55 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___55 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___55 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___55 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___55 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___51 {
	struct task_struct___52 *task;
	struct core_thread___51 *next;
};

struct core_state___51 {
	atomic_t nr_threads;
	struct core_thread___51 dumper;
	struct completion startup;
};

struct signal_struct___51 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___52 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___52 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___21 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___21 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___52 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___3 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___51 root;
	struct path___51 pwd;
};

struct css_set___24 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___24 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___20 {
	struct pmu___20 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___52 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___52 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___20 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct seq_operations___34 {
	void * (*start)(struct seq_file___35 *, loff_t *);
	void (*stop)(struct seq_file___35 *, void *);
	void * (*next)(struct seq_file___35 *, void *, loff_t *);
	int (*show)(struct seq_file___35 *, void *);
};

struct vm_fault___42 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___51 *page;
};

struct irq_chip___35 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___35 *);
	void (*irq_shutdown)(struct irq_data___35 *);
	void (*irq_enable)(struct irq_data___35 *);
	void (*irq_disable)(struct irq_data___35 *);
	void (*irq_ack)(struct irq_data___35 *);
	void (*irq_mask)(struct irq_data___35 *);
	void (*irq_mask_ack)(struct irq_data___35 *);
	void (*irq_unmask)(struct irq_data___35 *);
	void (*irq_eoi)(struct irq_data___35 *);
	int (*irq_set_affinity)(struct irq_data___35 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___35 *);
	int (*irq_set_type)(struct irq_data___35 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___35 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___35 *);
	void (*irq_bus_sync_unlock)(struct irq_data___35 *);
	void (*irq_cpu_online)(struct irq_data___35 *);
	void (*irq_cpu_offline)(struct irq_data___35 *);
	void (*irq_suspend)(struct irq_data___35 *);
	void (*irq_resume)(struct irq_data___35 *);
	void (*irq_pm_shutdown)(struct irq_data___35 *);
	void (*irq_print_chip)(struct irq_data___35 *, struct seq_file___35 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___35 *, void *);
	long unsigned int flags;
};

struct bus_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___40 *, char *);
	ssize_t (*store)(struct bus_type___40 *, const char *, size_t);
};

struct device_attribute___40;

struct driver_attribute___40;

struct bus_type___40 {
	const char *name;
	const char *dev_name;
	struct device___40 *dev_root;
	struct bus_attribute___40 *bus_attrs;
	struct device_attribute___40 *dev_attrs;
	struct driver_attribute___40 *drv_attrs;
	const struct attribute_group___35 **bus_groups;
	const struct attribute_group___35 **dev_groups;
	const struct attribute_group___35 **drv_groups;
	int (*match)(struct device___40 *, struct device_driver___40 *);
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	int (*probe)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*online)(struct device___40 *);
	int (*offline)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct device___40 *, struct device_attribute___40 *, char *);
	ssize_t (*store)(struct device___40 *, struct device_attribute___40 *, const char *, size_t);
};

struct driver_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___40 *, char *);
	ssize_t (*store)(struct device_driver___40 *, const char *, size_t);
};

struct device_driver___40 {
	const char *name;
	struct bus_type___40 *bus;
	struct module___34 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct attribute_group___35 **groups;
	const struct dev_pm_ops___40 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___40 {
	const char *name;
	const struct attribute_group___35 **groups;
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
};

struct class_attribute___40;

struct class___40 {
	const char *name;
	struct module___34 *owner;
	struct class_attribute___40 *class_attrs;
	struct device_attribute___40 *dev_attrs;
	const struct attribute_group___35 **dev_groups;
	struct bin_attribute___35 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *);
	void (*class_release)(struct class___40 *);
	void (*dev_release)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	struct subsys_private *p;
};

struct class_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct class___40 *, struct class_attribute___40 *, char *);
	ssize_t (*store)(struct class___40 *, struct class_attribute___40 *, const char *, size_t);
	const void * (*namespace)(struct class___40 *, const struct class_attribute___40 *);
};

struct device_rh___40 {
	struct dev_pm_info_rh___40 power;
};

struct kmem_cache_cpu___42 {
	void **freelist;
	long unsigned int tid;
	struct page___51 *page;
	struct page___51 *partial;
};

struct memcg_cache_params___42 {
	bool is_root_cache;
	union {
		struct kmem_cache___42 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___42 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___24;

struct cgroup___24 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___24 *parent;
	struct dentry___52 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___24 *subsys[11];
	struct cgroupfs_root___24 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___52 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___24 {
	struct super_block___52 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___24 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___20;

struct pmu___20 {
	struct list_head entry;
	struct device___40 *dev;
	const struct attribute_group___35 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___20 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___20 *);
	void (*pmu_disable)(struct pmu___20 *);
	int (*event_init)(struct perf_event___20 *);
	int (*add)(struct perf_event___20 *, int);
	void (*del)(struct perf_event___20 *, int);
	void (*start)(struct perf_event___20 *, int);
	void (*stop)(struct perf_event___20 *, int);
	void (*read)(struct perf_event___20 *);
	void (*start_txn)(struct pmu___20 *);
	int (*commit_txn)(struct pmu___20 *);
	void (*cancel_txn)(struct pmu___20 *);
	int (*event_idx)(struct perf_event___20 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___34 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___20 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___20 *);
};

struct perf_cpu_context___20 {
	struct perf_event_context___20 ctx;
	struct perf_event_context___20 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___20 *unique_pmu;
	struct perf_cgroup___20 *cgrp;
};

struct perf_cgroup___20 {
	struct cgroup_subsys_state___24 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___12 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___52 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___12)(struct trace_iterator___12 *, int, struct trace_event___12 *);

struct trace_event_functions___12 {
	trace_print_func___12 trace;
	trace_print_func___12 raw;
	trace_print_func___12 hex;
	trace_print_func___12 binary;
};

struct ftrace_event_class___12 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___12 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___12 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___12 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___12 *);
};

struct syscall_metadata___3 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___12 *enter_event;
	struct ftrace_event_call___12 *exit_event;
};

struct __va_list_tag {
	unsigned int gp_offset;
	unsigned int fp_offset;
	void *overflow_arg_area;
	void *reg_save_area;
};

typedef struct __va_list_tag __gnuc_va_list[1];

typedef __gnuc_va_list va_list;

enum kmsg_dump_reason {
	KMSG_DUMP_UNDEF = 0,
	KMSG_DUMP_PANIC = 1,
	KMSG_DUMP_OOPS = 2,
	KMSG_DUMP_EMERG = 3,
	KMSG_DUMP_RESTART = 4,
	KMSG_DUMP_HALT = 5,
	KMSG_DUMP_POWEROFF = 6,
};

struct tnt {
	u8 bit;
	char true;
	char false;
};

struct slowpath_args {
	const char *fmt;
	va_list args;
};

struct semaphore {
	raw_spinlock_t lock;
	unsigned int count;
	struct list_head wait_list;
};

typedef struct poll_table_struct___28 poll_table___2;

struct kmsg_dumper {
	struct list_head list;
	void (*dump)(struct kmsg_dumper *, enum kmsg_dump_reason);
	enum kmsg_dump_reason max_reason;
	bool active;
	bool registered;
	u32 cur_idx;
	u32 next_idx;
	u64 cur_seq;
	u64 next_seq;
};

struct ftrace_raw_console {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct ftrace_data_offsets_console {
	u32 msg;
};

struct console_cmdline {
	char name[8];
	int index;
	char *options;
};

enum log_flags {
	LOG_NOCONS = 1,
	LOG_NEWLINE = 2,
	LOG_PREFIX = 4,
	LOG_CONT = 8,
};

struct log {
	u64 ts_nsec;
	u16 len;
	u16 text_len;
	u16 dict_len;
	u8 facility;
	u8 flags: 5;
	u8 level: 3;
};

struct devkmsg_user {
	u64 seq;
	u32 idx;
	enum log_flags prev;
	struct mutex___51 lock;
	char buf[8192];
};

struct cont {
	char buf[992];
	size_t len;
	size_t cons;
	struct task_struct___51 *owner;
	u64 ts_nsec;
	u8 level;
	u8 facility;
	enum log_flags flags;
	bool flushed: 1;
};

typedef struct pglist_data___51 pg_data_t___3;

struct raw_notifier_head {
	struct notifier_block *head;
};

struct take_cpu_down_param {
	long unsigned int mod;
	void *hcpu;
};

struct page___52;

typedef struct page___52 *pgtable_t___52;

struct address_space___52;

struct kmem_cache___43;

struct page___52 {
	long unsigned int flags;
	struct address_space___52 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___52 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___52 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___43 *slab_cache;
		struct page___52 *first_page;
	};
	long: 64;
};

struct thread_struct___21;

struct task_struct___53;

struct pv_cpu_ops___52 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___21 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___21 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___53 *);
	void (*end_context_switch)(struct task_struct___53 *);
};

struct perf_event___21;

struct thread_struct___21 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___21 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___22;

struct pid_link___22 {
	struct hlist_node node;
	struct pid___22 *pid;
};

struct mutex___53 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___53 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___49 {
	struct page___52 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___56;

struct fs_struct___4;

struct files_struct___2;

struct nsproxy___23;

struct signal_struct___52;

struct bio_list___6;

struct backing_dev_info___6;

struct io_context___6;

struct css_set___25;

struct perf_event_context___21;

struct pipe_inode_info___2;

struct task_struct___53 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___53 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___56 *mm;
	struct mm_struct___56 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___53 *real_parent;
	struct task_struct___53 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___53 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___22 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___52 = 0,
		VTIME_USER___52 = 1,
		VTIME_SYS___52 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___21 thread;
	struct fs_struct___4 *fs;
	struct files_struct___2 *files;
	struct nsproxy___23 *nsproxy;
	struct signal_struct___52 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___6 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___6 *backing_dev_info;
	struct io_context___6 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___25 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___21 *perf_event_ctxp[2];
	struct mutex___53 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___49 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___56 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___56 *, struct mm_struct___56 *);
	void (*dup_mmap)(struct mm_struct___56 *, struct mm_struct___56 *);
	void (*exit_mmap)(struct mm_struct___56 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___56 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___56 *);
	void (*pgd_free)(struct mm_struct___56 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___56 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___56 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___56 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___56 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___56 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___56 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___56 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___56 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___56 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___56 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___56 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___53 lock;
	void *vdso;
} mm_context_t___53;

struct xol_area___52;

struct uprobes_state___52 {
	struct xol_area___52 *xol_area;
};

struct vm_area_struct___56;

struct file___52;

struct linux_binfmt___3;

struct core_state___52;

struct mm_struct___56 {
	struct vm_area_struct___56 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___56 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___56 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___3 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___53 context;
	long unsigned int flags;
	struct core_state___52 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___53 *owner;
	struct file___52 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___52 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___35;

struct exec_domain___15 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___35 *module;
	struct exec_domain___15 *next;
};

struct module_kobject___34 {
	struct kobject kobj;
	struct module___35 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___34;

struct ftrace_event_call___13;

struct module___35 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___34 mkobj;
	struct module_attribute___34 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___13 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___53 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___21 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___53 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___53 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___53 *target;
};

typedef void (*perf_overflow_handler_t___21)(struct perf_event___21 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___21;

typedef void (*ftrace_func_t___21)(long unsigned int, long unsigned int, struct ftrace_ops___21 *, struct pt_regs *);

struct ftrace_ops___21 {
	ftrace_func_t___21 func;
	struct ftrace_ops___21 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___53 regex_lock;
};

struct pmu___21;

struct fasync_struct___52;

struct pid_namespace___22;

struct perf_cgroup___21;

struct perf_event___21 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___21 *group_leader;
	struct pmu___21 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___21 hw;
	struct perf_event_context___21 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___53 child_mutex;
	struct list_head child_list;
	struct perf_event___21 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___53 *owner;
	struct mutex___53 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___52 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___21 *);
	struct callback_head callback_head;
	struct pid_namespace___22 *ns;
	u64 id;
	perf_overflow_handler_t___21 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___13 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___21 ftrace_ops;
	struct perf_cgroup___21 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___22 {
	struct task_struct___53 *task;
	struct exec_domain___15 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___52;

struct lruvec___52 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___52 *zone;
};

struct pglist_data___52;

struct zone___52 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___52 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___52 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___52 {
	struct zone___52 *zone;
	int zone_idx;
};

struct zonelist___52 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___52 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___52 {
	struct zone___52 node_zones[4];
	struct zonelist___52 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___53 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___36;

struct x86_io_apic_ops___36 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___36 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___36;

struct irq_data___36 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___36 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___41;

struct dev_pm_ops___41 {
	int (*prepare)(struct device___41 *);
	void (*complete)(struct device___41 *);
	int (*suspend)(struct device___41 *);
	int (*resume)(struct device___41 *);
	int (*freeze)(struct device___41 *);
	int (*thaw)(struct device___41 *);
	int (*poweroff)(struct device___41 *);
	int (*restore)(struct device___41 *);
	int (*suspend_late)(struct device___41 *);
	int (*resume_early)(struct device___41 *);
	int (*freeze_late)(struct device___41 *);
	int (*thaw_early)(struct device___41 *);
	int (*poweroff_late)(struct device___41 *);
	int (*restore_early)(struct device___41 *);
	int (*suspend_noirq)(struct device___41 *);
	int (*resume_noirq)(struct device___41 *);
	int (*freeze_noirq)(struct device___41 *);
	int (*thaw_noirq)(struct device___41 *);
	int (*poweroff_noirq)(struct device___41 *);
	int (*restore_noirq)(struct device___41 *);
	int (*runtime_suspend)(struct device___41 *);
	int (*runtime_resume)(struct device___41 *);
	int (*runtime_idle)(struct device___41 *);
};

struct dma_map_ops___21;

struct dev_archdata___21 {
	struct dma_map_ops___21 *dma_ops;
	void *iommu;
};

struct acpi_dev_node___14 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct device_type___41;

struct bus_type___41;

struct device_driver___41;

struct dev_pm_domain___41;

struct class___41;

struct attribute_group___36;

struct device_rh___41;

struct device___41 {
	struct device___41 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___41 *type;
	struct mutex___53 mutex;
	struct bus_type___41 *bus;
	struct device_driver___41 *driver;
	void *platform_data;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___41 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___21 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___14 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___41 *class;
	const struct attribute_group___36 **groups;
	void (*release)(struct device___41 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___41 *device_rh;
};

struct dev_pm_info_rh___41 {
	void (*set_latency_tolerance)(struct device___41 *, s32);
};

struct dev_pm_domain___41 {
	struct dev_pm_ops___41 ops;
};

struct smp_ops___52 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___53 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___52 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___52 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___43;

struct memcg_cache_params___43;

struct kmem_cache___43 {
	struct kmem_cache_cpu___43 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___43 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___53;

struct address_space_operations___52;

struct address_space___52 {
	struct inode___53 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___53 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___52 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___6 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___5;

struct dentry___53;

struct path___52 {
	struct vfsmount___5 *mnt;
	struct dentry___53 *dentry;
};

struct fown_struct___22 {
	rwlock_t lock;
	struct pid___22 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___52;

struct file___52 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___52 f_path;
	struct inode___53 *f_inode;
	const struct file_operations___52 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___22 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___52 *f_mapping;
	struct mutex___53 f_pos_lock;
};

struct vm_operations_struct___46;

struct vm_area_struct___56 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___56 *vm_next;
	struct vm_area_struct___56 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___56 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___46 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___52 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___43;

struct vm_operations_struct___46 {
	void (*open)(struct vm_area_struct___56 *);
	void (*close)(struct vm_area_struct___56 *);
	int (*fault)(struct vm_area_struct___56 *, struct vm_fault___43 *);
	int (*page_mkwrite)(struct vm_area_struct___56 *, struct vm_fault___43 *);
	int (*access)(struct vm_area_struct___56 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___56 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___56 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___56 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___56 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___52 {
	struct task_struct___53 *task;
	struct core_thread___52 *next;
};

struct core_state___52 {
	atomic_t nr_threads;
	struct core_thread___52 dumper;
	struct completion startup;
};

struct linux_binprm___4;

struct coredump_params___3;

struct linux_binfmt___3 {
	struct list_head lh;
	struct module___35 *module;
	int (*load_binary)(struct linux_binprm___4 *);
	int (*load_shlib)(struct file___52 *);
	int (*core_dump)(struct coredump_params___3 *);
	long unsigned int min_coredump;
};

struct rusage {
	struct timeval ru_utime;
	struct timeval ru_stime;
	long int ru_maxrss;
	long int ru_ixrss;
	long int ru_idrss;
	long int ru_isrss;
	long int ru_minflt;
	long int ru_majflt;
	long int ru_nswap;
	long int ru_inblock;
	long int ru_oublock;
	long int ru_msgsnd;
	long int ru_msgrcv;
	long int ru_nsignals;
	long int ru_nvcsw;
	long int ru_nivcsw;
};

struct vm_fault___43 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___52 *page;
};

struct bin_attribute___36;

struct attribute_group___36 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___36 **bin_attrs;
};

struct bin_attribute___36 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___52 *, struct kobject *, struct bin_attribute___36 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___52 *, struct kobject *, struct bin_attribute___36 *, char *, loff_t, size_t);
	int (*mmap)(struct file___52 *, struct kobject *, struct bin_attribute___36 *, struct vm_area_struct___56 *);
};

struct kmem_cache_cpu___43 {
	void **freelist;
	long unsigned int tid;
	struct page___52 *page;
	struct page___52 *partial;
};

struct memcg_cache_params___43 {
	bool is_root_cache;
	union {
		struct kmem_cache___43 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___43 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct seq_file___36;

struct irq_chip___36 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___36 *);
	void (*irq_shutdown)(struct irq_data___36 *);
	void (*irq_enable)(struct irq_data___36 *);
	void (*irq_disable)(struct irq_data___36 *);
	void (*irq_ack)(struct irq_data___36 *);
	void (*irq_mask)(struct irq_data___36 *);
	void (*irq_mask_ack)(struct irq_data___36 *);
	void (*irq_unmask)(struct irq_data___36 *);
	void (*irq_eoi)(struct irq_data___36 *);
	int (*irq_set_affinity)(struct irq_data___36 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___36 *);
	int (*irq_set_type)(struct irq_data___36 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___36 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___36 *);
	void (*irq_bus_sync_unlock)(struct irq_data___36 *);
	void (*irq_cpu_online)(struct irq_data___36 *);
	void (*irq_cpu_offline)(struct irq_data___36 *);
	void (*irq_suspend)(struct irq_data___36 *);
	void (*irq_resume)(struct irq_data___36 *);
	void (*irq_pm_shutdown)(struct irq_data___36 *);
	void (*irq_print_chip)(struct irq_data___36 *, struct seq_file___36 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___36 *, void *);
	long unsigned int flags;
};

struct seq_operations___35;

struct seq_file___36 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___53 lock;
	const struct seq_operations___35 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_table_header___5;

struct ctl_node___5 {
	struct rb_node node;
	struct ctl_table_header___5 *header;
};

struct ctl_table_root___5;

struct ctl_table_set___5;

struct ctl_dir___5;

struct ctl_table_header___5 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___5 *root;
	struct ctl_table_set___5 *set;
	struct ctl_dir___5 *parent;
	struct ctl_node___5 *node;
};

struct ctl_dir___5 {
	struct ctl_table_header___5 header;
	struct rb_root root;
};

struct ctl_table_set___5 {
	int (*is_seen)(struct ctl_table_set___5 *);
	struct ctl_dir___5 dir;
};

struct ctl_table_root___5 {
	struct ctl_table_set___5 default_set;
	struct ctl_table_set___5 * (*lookup)(struct ctl_table_root___5 *, struct nsproxy___23 *);
	int (*permissions)(struct ctl_table_header___5 *, struct ctl_table *);
};

struct net___7;

struct nsproxy___23 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___22 *pid_ns;
	struct net___7 *net_ns;
};

struct module_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___34 *, struct module_kobject___34 *, char *);
	ssize_t (*store)(struct module_attribute___34 *, struct module_kobject___34 *, const char *, size_t);
	void (*setup)(struct module___35 *, const char *);
	int (*test)(struct module___35 *);
	void (*free)(struct module___35 *);
};

struct trace_event_functions___13;

struct trace_event___13 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___13 *funcs;
};

struct ftrace_event_class___13;

struct ftrace_event_call___13 {
	struct list_head list;
	struct ftrace_event_class___13 *class;
	char *name;
	struct trace_event___13 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct dentry_operations___52;

struct super_block___53;

struct dentry___53 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___53 *d_parent;
	struct qstr d_name;
	struct inode___53 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___52 *d_op;
	struct super_block___53 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___52;

struct file_lock___52;

struct dquot___52;

struct block_device___52;

struct cdev___22;

struct inode___53 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___52 *i_op;
	struct super_block___53 *i_sb;
	struct address_space___52 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___53 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___52 *i_fop;
	struct file_lock___52 *i_flock;
	struct address_space___52 i_data;
	struct dquot___52 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct block_device___52 *i_bdev;
		struct cdev___22 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___52 {
	int (*d_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_hash)(const struct dentry___53 *, struct qstr *);
	int (*d_compare)(const struct dentry___53 *, const struct dentry___53 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___53 *);
	void (*d_release)(struct dentry___53 *);
	void (*d_prune)(struct dentry___53 *);
	void (*d_iput)(struct dentry___53 *, struct inode___53 *);
	char * (*d_dname)(struct dentry___53 *, char *, int);
	struct vfsmount___5 * (*d_automount)(struct path___52 *);
	int (*d_manage)(struct dentry___53 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___52;

struct mem_dqinfo___52 {
	struct quota_format_type___52 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___52;

struct quota_info___52 {
	unsigned int flags;
	struct mutex___53 dqio_mutex;
	struct mutex___53 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___53 *files[2];
	struct mem_dqinfo___52 info[2];
	const struct quota_format_ops___52 *ops[2];
};

struct file_system_type___52;

struct super_operations___52;

struct dquot_operations___52;

struct quotactl_ops___52;

struct xattr_handler___25;

struct super_block___53 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___52 *s_type;
	const struct super_operations___52 *s_op;
	const struct dquot_operations___52 *dq_op;
	const struct quotactl_ops___52 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___53 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___25 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___52 *s_bdev;
	struct backing_dev_info___6 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___52 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___53 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___52 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___5 {
	struct dentry___53 *mnt_root;
	struct super_block___53 *mnt_sb;
	int mnt_flags;
};

struct upid___22 {
	int nr;
	struct pid_namespace___22 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___22 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___53 *child_reaper;
	struct kmem_cache___43 *pid_cachep;
	unsigned int level;
	struct pid_namespace___22 *parent;
	struct vfsmount___5 *proc_mnt;
	struct dentry___53 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___22 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___22 numbers[1];
};

struct bio___6;

typedef void bio_end_io_t___6(struct bio___6 *, int);

struct bio_vec___6 {
	struct page___52 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___25;

struct bio_integrity_payload___6;

struct bio_set___6;

struct bio___6 {
	sector_t bi_sector;
	struct bio___6 *bi_next;
	struct block_device___52 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___6 *bi_end_io;
	void *bi_private;
	struct io_context___6 *bi_ioc;
	struct cgroup_subsys_state___25 *bi_css;
	struct bio_integrity_payload___6 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___6 *bi_io_vec;
	struct bio_set___6 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___6 bi_inline_vecs[0];
};

struct hd_struct___6;

struct gendisk___6;

struct request_queue___6;

struct block_device___52 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___53 *bd_inode;
	struct super_block___53 *bd_super;
	struct mutex___53 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___52 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___6 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___6 *bd_disk;
	struct request_queue___6 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___53 bd_fsfreeze_mutex;
};

struct io_cq___6;

struct io_context___6 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___6 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___25;

struct cgroup_subsys_state___25 {
	struct cgroup___25 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___6 {
	struct bio___6 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___6 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___6 *bip_vec;
	struct bio_vec___6 bip_inline_vecs[0];
};

struct bio_list___6 {
	struct bio___6 *head;
	struct bio___6 *tail;
};

struct bio_set___6 {
	struct kmem_cache___43 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___6 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___53 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___52 *ia_file;
};

struct dquot___52 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___53 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___53 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___52 {
	int qf_fmt_id;
	const struct quota_format_ops___52 *qf_ops;
	struct module___35 *qf_owner;
	struct quota_format_type___52 *qf_next;
};

struct quota_format_ops___52 {
	int (*check_quota_file)(struct super_block___53 *, int);
	int (*read_file_info)(struct super_block___53 *, int);
	int (*write_file_info)(struct super_block___53 *, int);
	int (*free_file_info)(struct super_block___53 *, int);
	int (*read_dqblk)(struct dquot___52 *);
	int (*commit_dqblk)(struct dquot___52 *);
	int (*release_dqblk)(struct dquot___52 *);
};

struct dquot_operations___52 {
	int (*write_dquot)(struct dquot___52 *);
	struct dquot___52 * (*alloc_dquot)(struct super_block___53 *, int);
	void (*destroy_dquot)(struct dquot___52 *);
	int (*acquire_dquot)(struct dquot___52 *);
	int (*release_dquot)(struct dquot___52 *);
	int (*mark_dirty)(struct dquot___52 *);
	int (*write_info)(struct super_block___53 *, int);
	qsize_t * (*get_reserved_space)(struct inode___53 *);
};

struct quotactl_ops___52 {
	int (*quota_on)(struct super_block___53 *, int, int, struct path___52 *);
	int (*quota_on_meta)(struct super_block___53 *, int, int);
	int (*quota_off)(struct super_block___53 *, int);
	int (*quota_sync)(struct super_block___53 *, int);
	int (*get_info)(struct super_block___53 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___53 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___53 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___53 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___53 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___53 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___53 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___53 *, unsigned int);
};

struct address_space_operations___52 {
	int (*writepage)(struct page___52 *, struct writeback_control *);
	int (*readpage)(struct file___52 *, struct page___52 *);
	int (*writepages)(struct address_space___52 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___52 *);
	int (*readpages)(struct file___52 *, struct address_space___52 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___52 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___52 **, void **);
	int (*write_end)(struct file___52 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___52 *, void *);
	sector_t (*bmap)(struct address_space___52 *, sector_t);
	void (*invalidatepage)(struct page___52 *, long unsigned int);
	int (*releasepage)(struct page___52 *, gfp_t);
	void (*freepage)(struct page___52 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___52 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___52 *, struct page___52 *, struct page___52 *, enum migrate_mode);
	int (*launder_page)(struct page___52 *);
	int (*is_partially_uptodate)(struct page___52 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___52 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___52 *, struct page___52 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___52 *, sector_t *);
	void (*swap_deactivate)(struct file___52 *);
	void (*invalidatepage_range)(struct page___52 *, unsigned int, unsigned int);
};

struct bdi_writeback___6 {
	struct backing_dev_info___6 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___6 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___6 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___41 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___53 *debug_dir;
	struct dentry___53 *debug_stats;
};

struct hd_struct___6 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___41 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___6;

struct block_device_operations___6;

struct gendisk___6 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___6 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___6 *part_tbl;
	struct hd_struct___6 part0;
	const struct block_device_operations___6 *fops;
	struct request_queue___6 *queue;
	void *private_data;
	int flags;
	struct device___41 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___6 {
	struct request_queue___6 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___6(struct request_queue___6 *);

typedef void make_request_fn___6(struct request_queue___6 *, struct bio___6 *);

struct request___6;

typedef int prep_rq_fn___6(struct request_queue___6 *, struct request___6 *);

struct bvec_merge_data___6;

typedef int merge_bvec_fn___6(struct request_queue___6 *, struct bvec_merge_data___6 *, struct bio_vec___6 *);

typedef void softirq_done_fn___6(struct request___6 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___6(struct request___6 *);

typedef int dma_drain_needed_fn___6(struct request___6 *);

typedef int lld_busy_fn___6(struct request_queue___6 *);

struct bsg_class_device___6 {
	struct device___41 *class_dev;
	struct device___41 *parent;
	int minor;
	struct request_queue___6 *queue;
	struct kref ref;
	void (*release)(struct device___41 *);
};

typedef void unprep_rq_fn___6(struct request_queue___6 *, struct request___6 *);

struct elevator_queue___6;

struct blk_queue_tag___6;

struct request_queue___6 {
	struct list_head queue_head;
	struct request___6 *last_merge;
	struct elevator_queue___6 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___6 root_rl;
	request_fn_proc___6 *request_fn;
	make_request_fn___6 *make_request_fn;
	prep_rq_fn___6 *prep_rq_fn;
	merge_bvec_fn___6 *merge_bvec_fn;
	softirq_done_fn___6 *softirq_done_fn;
	rq_timed_out_fn___6 *rq_timed_out_fn;
	dma_drain_needed_fn___6 *dma_drain_needed;
	lld_busy_fn___6 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___6 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___6 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___41 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___6 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___6 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___53 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___6 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___6 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___6 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct pipe_buffer;

struct pipe_inode_info___2 {
	struct mutex___53 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___52 *tmp_page;
	struct fasync_struct___52 *fasync_readers;
	struct fasync_struct___52 *fasync_writers;
	struct pipe_buffer *bufs;
};

struct cdev___22 {
	struct kobject kobj;
	struct module___35 *owner;
	const struct file_operations___52 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___52 {
	struct dentry___53 * (*lookup)(struct inode___53 *, struct dentry___53 *, unsigned int);
	void * (*follow_link)(struct dentry___53 *, struct nameidata *);
	int (*permission)(struct inode___53 *, int);
	struct posix_acl * (*get_acl)(struct inode___53 *, int);
	int (*readlink)(struct dentry___53 *, char *, int);
	void (*put_link)(struct dentry___53 *, struct nameidata *, void *);
	int (*create)(struct inode___53 *, struct dentry___53 *, umode_t, bool);
	int (*link)(struct dentry___53 *, struct inode___53 *, struct dentry___53 *);
	int (*unlink)(struct inode___53 *, struct dentry___53 *);
	int (*symlink)(struct inode___53 *, struct dentry___53 *, const char *);
	int (*mkdir)(struct inode___53 *, struct dentry___53 *, umode_t);
	int (*rmdir)(struct inode___53 *, struct dentry___53 *);
	int (*mknod)(struct inode___53 *, struct dentry___53 *, umode_t, dev_t);
	int (*rename)(struct inode___53 *, struct dentry___53 *, struct inode___53 *, struct dentry___53 *);
	int (*setattr)(struct dentry___53 *, struct iattr___53 *);
	int (*getattr)(struct vfsmount___5 *, struct dentry___53 *, struct kstat *);
	int (*setxattr)(struct dentry___53 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___53 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___53 *, char *, size_t);
	int (*removexattr)(struct dentry___53 *, const char *);
	int (*fiemap)(struct inode___53 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___53 *, struct timespec *, int);
	int (*atomic_open)(struct inode___53 *, struct dentry___53 *, struct file___52 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___2 *fl_owner_t___2;

struct poll_table_struct___30;

struct file_operations___52 {
	struct module___35 *owner;
	loff_t (*llseek)(struct file___52 *, loff_t, int);
	ssize_t (*read)(struct file___52 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___52 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___52 *, void *, filldir_t);
	unsigned int (*poll)(struct file___52 *, struct poll_table_struct___30 *);
	long int (*unlocked_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___52 *, struct vm_area_struct___56 *);
	int (*open)(struct inode___53 *, struct file___52 *);
	int (*flush)(struct file___52 *, fl_owner_t___2);
	int (*release)(struct inode___53 *, struct file___52 *);
	int (*fsync)(struct file___52 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___52 *, int);
	int (*lock)(struct file___52 *, int, struct file_lock___52 *);
	ssize_t (*sendpage)(struct file___52 *, struct page___52 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___52 *, int, struct file_lock___52 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___52 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___52 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___52 *, long int, struct file_lock___52 **, void **);
		struct {
			int (*setlease)(struct file___52 *, long int, struct file_lock___52 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___52 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___36 *, struct file___52 *);
};

struct file_lock_operations___52;

struct lock_manager_operations___52;

struct file_lock___52 {
	struct file_lock___52 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___2 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___22 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___52 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___52 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___52 *fl_ops;
	const struct lock_manager_operations___52 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___2 {
	unsigned int max_fds;
	struct file___52 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___2 {
	atomic_t count;
	struct fdtable___2 *fdt;
	struct fdtable___2 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___52 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___52 {
	void (*fl_copy_lock)(struct file_lock___52 *, struct file_lock___52 *);
	void (*fl_release_private)(struct file_lock___52 *);
};

struct lock_manager_operations___52 {
	int (*lm_compare_owner)(struct file_lock___52 *, struct file_lock___52 *);
	long unsigned int (*lm_owner_key)(struct file_lock___52 *);
	void (*lm_notify)(struct file_lock___52 *);
	int (*lm_grant)(struct file_lock___52 *, struct file_lock___52 *, int);
	void (*lm_break)(struct file_lock___52 *);
	int (*lm_change)(struct file_lock___52 **, int);
};

struct fasync_struct___52 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___52 *fa_next;
	struct file___52 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___52 {
	const char *name;
	int fs_flags;
	struct dentry___53 * (*mount)(struct file_system_type___52 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___53 *);
	struct module___35 *owner;
	struct file_system_type___52 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___52 {
	struct inode___53 * (*alloc_inode)(struct super_block___53 *);
	void (*destroy_inode)(struct inode___53 *);
	void (*dirty_inode)(struct inode___53 *, int);
	int (*write_inode)(struct inode___53 *, struct writeback_control *);
	int (*drop_inode)(struct inode___53 *);
	void (*evict_inode)(struct inode___53 *);
	void (*put_super)(struct super_block___53 *);
	int (*sync_fs)(struct super_block___53 *, int);
	int (*freeze_fs)(struct super_block___53 *);
	int (*unfreeze_fs)(struct super_block___53 *);
	int (*statfs)(struct dentry___53 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___53 *, int *, char *);
	void (*umount_begin)(struct super_block___53 *);
	int (*show_options)(struct seq_file___36 *, struct dentry___53 *);
	int (*show_devname)(struct seq_file___36 *, struct dentry___53 *);
	int (*show_path)(struct seq_file___36 *, struct dentry___53 *);
	int (*show_stats)(struct seq_file___36 *, struct dentry___53 *);
	ssize_t (*quota_read)(struct super_block___53 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___53 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___53 *);
	int (*bdev_try_to_free_page)(struct super_block___53 *, struct page___52 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___53 *);
	void (*free_cached_objects)(struct super_block___53 *, int);
};

struct xattr_handler___25 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___53 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___53 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___53 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___30)(struct file___52 *, wait_queue_head_t *, struct poll_table_struct___30 *);

struct poll_table_struct___30 {
	poll_queue_proc___30 _qproc;
	long unsigned int _key;
};

struct tty_struct___4;

struct tty_driver___4;

struct tty_operations___4 {
	struct tty_struct___4 * (*lookup)(struct tty_driver___4 *, struct inode___53 *, int);
	int (*install)(struct tty_driver___4 *, struct tty_struct___4 *);
	void (*remove)(struct tty_driver___4 *, struct tty_struct___4 *);
	int (*open)(struct tty_struct___4 *, struct file___52 *);
	void (*close)(struct tty_struct___4 *, struct file___52 *);
	void (*shutdown)(struct tty_struct___4 *);
	void (*cleanup)(struct tty_struct___4 *);
	int (*write)(struct tty_struct___4 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___4 *, unsigned char);
	void (*flush_chars)(struct tty_struct___4 *);
	int (*write_room)(struct tty_struct___4 *);
	int (*chars_in_buffer)(struct tty_struct___4 *);
	int (*ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	void (*throttle)(struct tty_struct___4 *);
	void (*unthrottle)(struct tty_struct___4 *);
	void (*stop)(struct tty_struct___4 *);
	void (*start)(struct tty_struct___4 *);
	void (*hangup)(struct tty_struct___4 *);
	int (*break_ctl)(struct tty_struct___4 *, int);
	void (*flush_buffer)(struct tty_struct___4 *);
	void (*set_ldisc)(struct tty_struct___4 *);
	void (*wait_until_sent)(struct tty_struct___4 *, int);
	void (*send_xchar)(struct tty_struct___4 *, char);
	int (*tiocmget)(struct tty_struct___4 *);
	int (*tiocmset)(struct tty_struct___4 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___4 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___4 *, struct termiox *);
	int (*get_icount)(struct tty_struct___4 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___4 *, int, char *);
	int (*poll_get_char)(struct tty_driver___4 *, int);
	void (*poll_put_char)(struct tty_driver___4 *, int, char);
	const struct file_operations___52 *proc_fops;
};

struct tty_ldisc___4;

struct tty_port___4;

struct tty_struct___4 {
	int magic;
	struct kref kref;
	struct device___41 *dev;
	struct tty_driver___4 *driver;
	const struct tty_operations___4 *ops;
	int index;
	struct mutex___53 ldisc_mutex;
	struct tty_ldisc___4 *ldisc;
	struct mutex___53 atomic_write_lock;
	struct mutex___53 legacy_mutex;
	struct mutex___53 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___22 *pgrp;
	struct pid___22 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___4 *link;
	struct fasync_struct___52 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___4 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___4 {
	int magic;
	struct kref kref;
	struct cdev___22 *cdevs;
	struct module___35 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___4 *other;
	struct tty_struct___4 **ttys;
	struct tty_port___4 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___4 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___4;

struct tty_port___4 {
	struct tty_bufhead buf;
	struct tty_struct___4 *tty;
	struct tty_struct___4 *itty;
	const struct tty_port_operations___4 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___53 mutex;
	struct mutex___53 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___4 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___4 *);
	void (*close)(struct tty_struct___4 *);
	void (*flush_buffer)(struct tty_struct___4 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___4 *);
	ssize_t (*read)(struct tty_struct___4 *, struct file___52 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___4 *, struct file___52 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___4 *, struct file___52 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, struct file___52 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___4 *, struct file___52 *, struct poll_table_struct___30 *);
	int (*hangup)(struct tty_struct___4 *);
	void (*receive_buf)(struct tty_struct___4 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___4 *);
	void (*dcd_change)(struct tty_struct___4 *, unsigned int);
	struct module___35 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___4 *, int);
};

struct tty_ldisc___4 {
	struct tty_ldisc_ops___4 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___4 *tty;
};

struct tty_port_operations___4 {
	int (*carrier_raised)(struct tty_port___4 *);
	void (*dtr_rts)(struct tty_port___4 *, int);
	void (*shutdown)(struct tty_port___4 *);
	void (*drop)(struct tty_port___4 *);
	int (*activate)(struct tty_port___4 *, struct tty_struct___4 *);
	void (*destruct)(struct tty_port___4 *);
};

struct io_cq___6 {
	struct request_queue___6 *q;
	struct io_context___6 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___43 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct linux_binprm___4 {
	char buf[128];
	struct vm_area_struct___56 *vma;
	long unsigned int vma_pages;
	struct mm_struct___56 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___52 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct dma_map_ops___21 {
	void * (*alloc)(struct device___41 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___41 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___41 *, struct vm_area_struct___56 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___41 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___41 *, struct page___52 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___41 *, dma_addr_t);
	int (*dma_supported)(struct device___41 *, u64);
	int (*set_dma_mask)(struct device___41 *, u64);
	int is_phys;
};

struct bus_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___41 *, char *);
	ssize_t (*store)(struct bus_type___41 *, const char *, size_t);
};

struct device_attribute___41;

struct driver_attribute___41;

struct bus_type___41 {
	const char *name;
	const char *dev_name;
	struct device___41 *dev_root;
	struct bus_attribute___41 *bus_attrs;
	struct device_attribute___41 *dev_attrs;
	struct driver_attribute___41 *drv_attrs;
	const struct attribute_group___36 **bus_groups;
	const struct attribute_group___36 **dev_groups;
	const struct attribute_group___36 **drv_groups;
	int (*match)(struct device___41 *, struct device_driver___41 *);
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	int (*probe)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*online)(struct device___41 *);
	int (*offline)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct device___41 *, struct device_attribute___41 *, char *);
	ssize_t (*store)(struct device___41 *, struct device_attribute___41 *, const char *, size_t);
};

struct driver_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___41 *, char *);
	ssize_t (*store)(struct device_driver___41 *, const char *, size_t);
};

struct device_driver___41 {
	const char *name;
	struct bus_type___41 *bus;
	struct module___35 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct attribute_group___36 **groups;
	const struct dev_pm_ops___41 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___41 {
	const char *name;
	const struct attribute_group___36 **groups;
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
};

struct class_attribute___41;

struct class___41 {
	const char *name;
	struct module___35 *owner;
	struct class_attribute___41 *class_attrs;
	struct device_attribute___41 *dev_attrs;
	const struct attribute_group___36 **dev_groups;
	struct bin_attribute___36 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *);
	void (*class_release)(struct class___41 *);
	void (*dev_release)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	struct subsys_private *p;
};

struct class_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct class___41 *, struct class_attribute___41 *, char *);
	ssize_t (*store)(struct class___41 *, struct class_attribute___41 *, const char *, size_t);
	const void * (*namespace)(struct class___41 *, const struct class_attribute___41 *);
};

struct device_rh___41 {
	struct dev_pm_info_rh___41 power;
};

struct signal_struct___52 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___53 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___53 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___22 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___22 *tty_old_pgrp;
	int leader;
	struct tty_struct___4 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___53 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___4 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___52 root;
	struct path___52 pwd;
};

struct css_set___25 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___25 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___21 {
	struct pmu___21 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___53 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___53 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___21 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct coredump_params___3 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___52 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct netns_core___5 {
	struct ctl_table_header___5 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___5 {
	struct mutex___53 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___5 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___5 *ctl;
};

struct netns_ipv4___5 {
	struct ctl_table_header___5 *forw_hdr;
	struct ctl_table_header___5 *frags_hdr;
	struct ctl_table_header___5 *ipv4_hdr;
	struct ctl_table_header___5 *route_hdr;
	struct ctl_table_header___5 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___5 {
	struct ctl_table_header___5 *hdr;
	struct ctl_table_header___5 *route_hdr;
	struct ctl_table_header___5 *icmp_hdr;
	struct ctl_table_header___5 *frags_hdr;
	struct ctl_table_header___5 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___6 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___6 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___6 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *);
	int (*local_out)(struct sk_buff___6 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___6 *, const void *);
	struct kmem_cache___43 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___5 {
	struct netns_sysctl_ipv6___5 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___5 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___5 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___5 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___5 *nf_log_dir_header;
};

struct nf_proto_net___5 {
	struct ctl_table_header___5 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___5 {
	struct nf_proto_net___5 pn;
	unsigned int timeout;
};

struct nf_tcp_net___5 {
	struct nf_proto_net___5 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___5 {
	struct nf_proto_net___5 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___5 {
	struct nf_proto_net___5 pn;
	unsigned int timeout;
};

struct nf_ip_net___5 {
	struct nf_generic_net___5 generic;
	struct nf_tcp_net___5 tcp;
	struct nf_udp_net___5 udp;
	struct nf_icmp_net___5 icmp;
	struct nf_icmp_net___5 icmpv6;
};

struct netns_ct___5 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___5 *sysctl_header;
	struct ctl_table_header___5 *acct_sysctl_header;
	struct ctl_table_header___5 *tstamp_sysctl_header;
	struct ctl_table_header___5 *event_sysctl_header;
	struct ctl_table_header___5 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___43 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___5 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___5 {
	struct netns_sysctl_ipv6___5 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___5 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___5 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 xfrm4_dst_ops;
	struct dst_ops___6 xfrm6_dst_ops;
};

struct net___7 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___5 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___5 core;
	struct netns_mib mib;
	struct netns_packet___5 packet;
	struct netns_unix___5 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___5 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_dccp dccp;
	struct netns_nf___5 nf;
	struct netns_xt xt;
	struct netns_ct___5 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___5 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___5 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___53 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___53 flow_flush_sem;
	long: 64;
	long: 64;
};

struct cgroupfs_root___25;

struct cgroup___25 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___25 *parent;
	struct dentry___53 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___25 *subsys[11];
	struct cgroupfs_root___25 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___53 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___25 {
	struct super_block___53 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___25 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct seq_operations___35 {
	void * (*start)(struct seq_file___36 *, loff_t *);
	void (*stop)(struct seq_file___36 *, void *);
	void * (*next)(struct seq_file___36 *, void *, loff_t *);
	int (*show)(struct seq_file___36 *, void *);
};

struct perf_cpu_context___21;

struct pmu___21 {
	struct list_head entry;
	struct device___41 *dev;
	const struct attribute_group___36 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___21 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___21 *);
	void (*pmu_disable)(struct pmu___21 *);
	int (*event_init)(struct perf_event___21 *);
	int (*add)(struct perf_event___21 *, int);
	void (*del)(struct perf_event___21 *, int);
	void (*start)(struct perf_event___21 *, int);
	void (*stop)(struct perf_event___21 *, int);
	void (*read)(struct perf_event___21 *);
	void (*start_txn)(struct pmu___21 *);
	int (*commit_txn)(struct pmu___21 *);
	void (*cancel_txn)(struct pmu___21 *);
	int (*event_idx)(struct perf_event___21 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___35 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___21 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___21 *);
};

struct perf_cpu_context___21 {
	struct perf_event_context___21 ctx;
	struct perf_event_context___21 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___21 *unique_pmu;
	struct perf_cgroup___21 *cgrp;
};

struct perf_cgroup___21 {
	struct cgroup_subsys_state___25 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___13 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___53 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___13)(struct trace_iterator___13 *, int, struct trace_event___13 *);

struct trace_event_functions___13 {
	trace_print_func___13 trace;
	trace_print_func___13 raw;
	trace_print_func___13 hex;
	trace_print_func___13 binary;
};

struct ftrace_event_class___13 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___13 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___13 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___13 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___13 *);
};

struct syscall_metadata___4 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___13 *enter_event;
	struct ftrace_event_call___13 *exit_event;
};

struct pipe_buf_operations;

struct pipe_buffer {
	struct page___52 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations {
	int can_merge;
	void * (*map)(struct pipe_inode_info___2 *, struct pipe_buffer *, int);
	void (*unmap)(struct pipe_inode_info___2 *, struct pipe_buffer *, void *);
	int (*confirm)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	void (*release)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	int (*steal)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	void (*get)(struct pipe_inode_info___2 *, struct pipe_buffer *);
};

struct disk_part_tbl___6 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___6 *last_lookup;
	struct hd_struct___6 *part[0];
};

struct block_device_operations___6 {
	int (*open)(struct block_device___52 *, fmode_t);
	void (*release)(struct gendisk___6 *, fmode_t);
	int (*ioctl)(struct block_device___52 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___52 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___52 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___6 *, unsigned int);
	int (*media_changed)(struct gendisk___6 *);
	void (*unlock_native_capacity)(struct gendisk___6 *);
	int (*revalidate_disk)(struct gendisk___6 *);
	int (*getgeo)(struct block_device___52 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___52 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___35 *owner;
};

typedef void rq_end_io_fn___6(struct request___6 *, int);

struct request___6 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue___6 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___6 *bio;
	struct bio___6 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___6 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___6 *saved_end_io;
		} flush;
	};
	struct gendisk___6 *rq_disk;
	struct hd_struct___6 *part;
	long unsigned int start_time;
	struct request_list___6 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___6 *end_io;
	void *end_io_data;
	struct request___6 *next_rq;
};

typedef int elevator_merge_fn___6(struct request_queue___6 *, struct request___6 **, struct bio___6 *);

typedef void elevator_merge_req_fn___6(struct request_queue___6 *, struct request___6 *, struct request___6 *);

typedef void elevator_merged_fn___6(struct request_queue___6 *, struct request___6 *, int);

typedef int elevator_allow_merge_fn___6(struct request_queue___6 *, struct request___6 *, struct bio___6 *);

typedef void elevator_bio_merged_fn___6(struct request_queue___6 *, struct request___6 *, struct bio___6 *);

typedef int elevator_dispatch_fn___6(struct request_queue___6 *, int);

typedef void elevator_add_req_fn___6(struct request_queue___6 *, struct request___6 *);

typedef struct request___6 *elevator_request_list_fn___6(struct request_queue___6 *, struct request___6 *);

typedef void elevator_completed_req_fn___6(struct request_queue___6 *, struct request___6 *);

typedef int elevator_may_queue_fn___6(struct request_queue___6 *, int);

typedef void elevator_init_icq_fn___6(struct io_cq___6 *);

typedef void elevator_exit_icq_fn___6(struct io_cq___6 *);

typedef int elevator_set_req_fn___6(struct request_queue___6 *, struct request___6 *, struct bio___6 *, gfp_t);

typedef void elevator_put_req_fn___6(struct request___6 *);

typedef void elevator_activate_req_fn___6(struct request_queue___6 *, struct request___6 *);

typedef void elevator_deactivate_req_fn___6(struct request_queue___6 *, struct request___6 *);

struct elevator_type___6;

typedef int elevator_init_fn___6(struct request_queue___6 *, struct elevator_type___6 *);

typedef void elevator_exit_fn___6(struct elevator_queue___6 *);

struct elevator_ops___6 {
	elevator_merge_fn___6 *elevator_merge_fn;
	elevator_merged_fn___6 *elevator_merged_fn;
	elevator_merge_req_fn___6 *elevator_merge_req_fn;
	elevator_allow_merge_fn___6 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___6 *elevator_bio_merged_fn;
	elevator_dispatch_fn___6 *elevator_dispatch_fn;
	elevator_add_req_fn___6 *elevator_add_req_fn;
	elevator_activate_req_fn___6 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___6 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___6 *elevator_completed_req_fn;
	elevator_request_list_fn___6 *elevator_former_req_fn;
	elevator_request_list_fn___6 *elevator_latter_req_fn;
	elevator_init_icq_fn___6 *elevator_init_icq_fn;
	elevator_exit_icq_fn___6 *elevator_exit_icq_fn;
	elevator_set_req_fn___6 *elevator_set_req_fn;
	elevator_put_req_fn___6 *elevator_put_req_fn;
	elevator_may_queue_fn___6 *elevator_may_queue_fn;
	elevator_init_fn___6 *elevator_init_fn;
	elevator_exit_fn___6 *elevator_exit_fn;
};

struct elv_fs_entry___6;

struct elevator_type___6 {
	struct kmem_cache___43 *icq_cache;
	struct elevator_ops___6 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___6 *elevator_attrs;
	char elevator_name[16];
	struct module___35 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___6 {
	struct elevator_type___6 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___53 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___6 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___6 *, char *);
	ssize_t (*store)(struct elevator_queue___6 *, const char *, size_t);
};

struct bvec_merge_data___6 {
	struct block_device___52 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___6 {
	struct request___6 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct nf_afinfo___5 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___6 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___6 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___7 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___6 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___6 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct tlb_state___21 {
	struct mm_struct___56 *active_mm;
	int state;
};

struct wait_opts {
	enum pid_type wo_type;
	int wo_flags;
	struct pid___22 *wo_pid;
	struct siginfo *wo_info;
	int *wo_stat;
	struct rusage *wo_rusage;
	wait_queue_t child_wait;
	int notask_error;
};

struct itimerval {
	struct timeval it_interval;
	struct timeval it_value;
};

typedef __kernel_suseconds_t suseconds_t;

typedef __kernel_clock_t clock_t;

struct timex {
	unsigned int modes;
	long int offset;
	long int freq;
	long int maxerror;
	long int esterror;
	int status;
	long int constant;
	long int precision;
	long int tolerance;
	struct timeval time;
	long int tick;
	long int ppsfreq;
	long int jitter;
	int shift;
	long int stabil;
	long int jitcnt;
	long int calcnt;
	long int errcnt;
	long int stbcnt;
	int tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page___53;

typedef struct page___53 *pgtable_t___53;

struct address_space___53;

struct kmem_cache___44;

struct page___53 {
	long unsigned int flags;
	struct address_space___53 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___53 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___53 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___44 *slab_cache;
		struct page___53 *first_page;
	};
	long: 64;
};

struct thread_struct___22;

struct task_struct___54;

struct pv_cpu_ops___53 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___22 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___22 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___54 *);
	void (*end_context_switch)(struct task_struct___54 *);
};

struct perf_event___22;

struct thread_struct___22 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___22 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___23;

struct pid_link___23 {
	struct hlist_node node;
	struct pid___23 *pid;
};

struct mutex___54 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___54 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___50 {
	struct page___53 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___57;

struct nsproxy___24;

struct signal_struct___53;

struct css_set___26;

struct perf_event_context___22;

struct task_struct___54 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___54 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___57 *mm;
	struct mm_struct___57 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___54 *real_parent;
	struct task_struct___54 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___54 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___23 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___53 = 0,
		VTIME_USER___53 = 1,
		VTIME_SYS___53 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___22 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___24 *nsproxy;
	struct signal_struct___53 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___26 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___22 *perf_event_ctxp[2];
	struct mutex___54 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___50 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___57 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___57 *, struct mm_struct___57 *);
	void (*dup_mmap)(struct mm_struct___57 *, struct mm_struct___57 *);
	void (*exit_mmap)(struct mm_struct___57 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___57 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___57 *);
	void (*pgd_free)(struct mm_struct___57 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___57 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___57 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___57 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___57 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___57 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___57 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___57 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___57 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___57 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___57 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___57 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___54 lock;
	void *vdso;
} mm_context_t___54;

struct xol_area___53;

struct uprobes_state___53 {
	struct xol_area___53 *xol_area;
};

struct vm_area_struct___57;

struct file___53;

struct core_state___53;

struct mm_struct___57 {
	struct vm_area_struct___57 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___57 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___57 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___54 context;
	long unsigned int flags;
	struct core_state___53 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___54 *owner;
	struct file___53 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___53 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___22 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___54 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___54 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___54 *target;
};

typedef void (*perf_overflow_handler_t___22)(struct perf_event___22 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___22;

typedef void (*ftrace_func_t___22)(long unsigned int, long unsigned int, struct ftrace_ops___22 *, struct pt_regs *);

struct ftrace_ops___22 {
	ftrace_func_t___22 func;
	struct ftrace_ops___22 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___54 regex_lock;
};

struct pmu___22;

struct fasync_struct___53;

struct pid_namespace___23;

struct ftrace_event_call___14;

struct perf_cgroup___22;

struct perf_event___22 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___22 *group_leader;
	struct pmu___22 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___22 hw;
	struct perf_event_context___22 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___54 child_mutex;
	struct list_head child_list;
	struct perf_event___22 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___54 *owner;
	struct mutex___54 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___53 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___22 *);
	struct callback_head callback_head;
	struct pid_namespace___23 *ns;
	u64 id;
	perf_overflow_handler_t___22 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___14 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___22 ftrace_ops;
	struct perf_cgroup___22 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___23 {
	struct task_struct___54 *task;
	struct exec_domain___15 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___37;

struct x86_io_apic_ops___37 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___37 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___37;

struct irq_data___37 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___37 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___42;

struct dev_pm_ops___42 {
	int (*prepare)(struct device___42 *);
	void (*complete)(struct device___42 *);
	int (*suspend)(struct device___42 *);
	int (*resume)(struct device___42 *);
	int (*freeze)(struct device___42 *);
	int (*thaw)(struct device___42 *);
	int (*poweroff)(struct device___42 *);
	int (*restore)(struct device___42 *);
	int (*suspend_late)(struct device___42 *);
	int (*resume_early)(struct device___42 *);
	int (*freeze_late)(struct device___42 *);
	int (*thaw_early)(struct device___42 *);
	int (*poweroff_late)(struct device___42 *);
	int (*restore_early)(struct device___42 *);
	int (*suspend_noirq)(struct device___42 *);
	int (*resume_noirq)(struct device___42 *);
	int (*freeze_noirq)(struct device___42 *);
	int (*thaw_noirq)(struct device___42 *);
	int (*poweroff_noirq)(struct device___42 *);
	int (*restore_noirq)(struct device___42 *);
	int (*runtime_suspend)(struct device___42 *);
	int (*runtime_resume)(struct device___42 *);
	int (*runtime_idle)(struct device___42 *);
};

struct device_type___42;

struct bus_type___42;

struct device_driver___42;

struct dev_pm_domain___42;

struct class___42;

struct attribute_group___37;

struct device_rh___42;

struct device___42 {
	struct device___42 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___42 *type;
	struct mutex___54 mutex;
	struct bus_type___42 *bus;
	struct device_driver___42 *driver;
	void *platform_data;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___42 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___21 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___42 *class;
	const struct attribute_group___37 **groups;
	void (*release)(struct device___42 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___42 *device_rh;
};

struct dev_pm_info_rh___42 {
	void (*set_latency_tolerance)(struct device___42 *, s32);
};

struct dev_pm_domain___42 {
	struct dev_pm_ops___42 ops;
};

struct smp_ops___53 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___54 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___53;

struct lruvec___53 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___53 *zone;
};

struct pglist_data___53;

struct zone___53 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___53 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___53 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___53 {
	struct zone___53 *zone;
	int zone_idx;
};

struct zonelist___53 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___53 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___53 {
	struct zone___53 node_zones[4];
	struct zonelist___53 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___54 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___37;

struct irq_chip___37 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___37 *);
	void (*irq_shutdown)(struct irq_data___37 *);
	void (*irq_enable)(struct irq_data___37 *);
	void (*irq_disable)(struct irq_data___37 *);
	void (*irq_ack)(struct irq_data___37 *);
	void (*irq_mask)(struct irq_data___37 *);
	void (*irq_mask_ack)(struct irq_data___37 *);
	void (*irq_unmask)(struct irq_data___37 *);
	void (*irq_eoi)(struct irq_data___37 *);
	int (*irq_set_affinity)(struct irq_data___37 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___37 *);
	int (*irq_set_type)(struct irq_data___37 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___37 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___37 *);
	void (*irq_bus_sync_unlock)(struct irq_data___37 *);
	void (*irq_cpu_online)(struct irq_data___37 *);
	void (*irq_cpu_offline)(struct irq_data___37 *);
	void (*irq_suspend)(struct irq_data___37 *);
	void (*irq_resume)(struct irq_data___37 *);
	void (*irq_pm_shutdown)(struct irq_data___37 *);
	void (*irq_print_chip)(struct irq_data___37 *, struct seq_file___37 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___37 *, void *);
	long unsigned int flags;
};

struct seq_operations___36;

struct seq_file___37 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___54 lock;
	const struct seq_operations___36 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irqaction___7 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___7 *next;
	irq_handler_t thread_fn;
	struct task_struct___54 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct softirq_action {
	void (*action)(struct softirq_action *);
};

enum {
	TASKLET_STATE_SCHED = 0,
	TASKLET_STATE_RUN = 1,
};

struct tasklet_hrtimer {
	struct hrtimer timer;
	struct tasklet_struct tasklet;
	enum hrtimer_restart (*function)(struct hrtimer *);
};

struct xol_area___53 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___53 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___44;

struct memcg_cache_params___44;

struct kmem_cache___44 {
	struct kmem_cache_cpu___44 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___44 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___54;

struct address_space_operations___53;

struct address_space___53 {
	struct inode___54 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___54 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___53 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___54;

struct path___53 {
	struct vfsmount *mnt;
	struct dentry___54 *dentry;
};

struct fown_struct___23 {
	rwlock_t lock;
	struct pid___23 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___53;

struct file___53 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___53 f_path;
	struct inode___54 *f_inode;
	const struct file_operations___53 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___23 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___53 *f_mapping;
	struct mutex___54 f_pos_lock;
};

struct vm_operations_struct___47;

struct vm_area_struct___57 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___57 *vm_next;
	struct vm_area_struct___57 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___57 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___47 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___53 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___44;

struct vm_operations_struct___47 {
	void (*open)(struct vm_area_struct___57 *);
	void (*close)(struct vm_area_struct___57 *);
	int (*fault)(struct vm_area_struct___57 *, struct vm_fault___44 *);
	int (*page_mkwrite)(struct vm_area_struct___57 *, struct vm_fault___44 *);
	int (*access)(struct vm_area_struct___57 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___57 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___57 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___57 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___57 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___53 {
	struct task_struct___54 *task;
	struct core_thread___53 *next;
};

struct core_state___53 {
	atomic_t nr_threads;
	struct core_thread___53 dumper;
	struct completion startup;
};

struct upid___23 {
	int nr;
	struct pid_namespace___23 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___23 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___54 *child_reaper;
	struct kmem_cache___44 *pid_cachep;
	unsigned int level;
	struct pid_namespace___23 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___54 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___23 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___23 numbers[1];
};

struct nsproxy___24 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___23 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___53 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___54 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___54 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___23 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___23 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___54 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___26;

struct css_set___26 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___26 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___22 {
	struct pmu___22 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___54 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___54 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___22 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___44 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___53 *page;
};

struct bin_attribute___37;

struct attribute_group___37 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___37 **bin_attrs;
};

struct bin_attribute___37 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___53 *, struct kobject *, struct bin_attribute___37 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___53 *, struct kobject *, struct bin_attribute___37 *, char *, loff_t, size_t);
	int (*mmap)(struct file___53 *, struct kobject *, struct bin_attribute___37 *, struct vm_area_struct___57 *);
};

struct bus_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___42 *, char *);
	ssize_t (*store)(struct bus_type___42 *, const char *, size_t);
};

struct device_attribute___42;

struct driver_attribute___42;

struct bus_type___42 {
	const char *name;
	const char *dev_name;
	struct device___42 *dev_root;
	struct bus_attribute___42 *bus_attrs;
	struct device_attribute___42 *dev_attrs;
	struct driver_attribute___42 *drv_attrs;
	const struct attribute_group___37 **bus_groups;
	const struct attribute_group___37 **dev_groups;
	const struct attribute_group___37 **drv_groups;
	int (*match)(struct device___42 *, struct device_driver___42 *);
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	int (*probe)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*online)(struct device___42 *);
	int (*offline)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct device___42 *, struct device_attribute___42 *, char *);
	ssize_t (*store)(struct device___42 *, struct device_attribute___42 *, const char *, size_t);
};

struct driver_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___42 *, char *);
	ssize_t (*store)(struct device_driver___42 *, const char *, size_t);
};

struct device_driver___42 {
	const char *name;
	struct bus_type___42 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct attribute_group___37 **groups;
	const struct dev_pm_ops___42 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___42 {
	const char *name;
	const struct attribute_group___37 **groups;
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
};

struct class_attribute___42;

struct class___42 {
	const char *name;
	struct module *owner;
	struct class_attribute___42 *class_attrs;
	struct device_attribute___42 *dev_attrs;
	const struct attribute_group___37 **dev_groups;
	struct bin_attribute___37 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *);
	void (*class_release)(struct class___42 *);
	void (*dev_release)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	struct subsys_private *p;
};

struct class_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct class___42 *, struct class_attribute___42 *, char *);
	ssize_t (*store)(struct class___42 *, struct class_attribute___42 *, const char *, size_t);
	const void * (*namespace)(struct class___42 *, const struct class_attribute___42 *);
};

struct device_rh___42 {
	struct dev_pm_info_rh___42 power;
};

struct dentry_operations___53;

struct super_block___54;

struct dentry___54 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___54 *d_parent;
	struct qstr d_name;
	struct inode___54 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___53 *d_op;
	struct super_block___54 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___53;

struct file_lock___53;

struct dquot___53;

struct block_device___53;

struct inode___54 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___53 *i_op;
	struct super_block___54 *i_sb;
	struct address_space___53 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___54 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___53 *i_fop;
	struct file_lock___53 *i_flock;
	struct address_space___53 i_data;
	struct dquot___53 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___53 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___53 {
	int (*d_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_hash)(const struct dentry___54 *, struct qstr *);
	int (*d_compare)(const struct dentry___54 *, const struct dentry___54 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___54 *);
	void (*d_release)(struct dentry___54 *);
	void (*d_prune)(struct dentry___54 *);
	void (*d_iput)(struct dentry___54 *, struct inode___54 *);
	char * (*d_dname)(struct dentry___54 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___53 *);
	int (*d_manage)(struct dentry___54 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___53;

struct mem_dqinfo___53 {
	struct quota_format_type___53 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___53;

struct quota_info___53 {
	unsigned int flags;
	struct mutex___54 dqio_mutex;
	struct mutex___54 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___54 *files[2];
	struct mem_dqinfo___53 info[2];
	const struct quota_format_ops___53 *ops[2];
};

struct file_system_type___53;

struct super_operations___53;

struct dquot_operations___53;

struct quotactl_ops___53;

struct xattr_handler___26;

struct super_block___54 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___53 *s_type;
	const struct super_operations___53 *s_op;
	const struct dquot_operations___53 *dq_op;
	const struct quotactl_ops___53 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___54 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___26 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___53 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___53 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___54 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___53 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___53 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___54 *bd_inode;
	struct super_block___54 *bd_super;
	struct mutex___54 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___53 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___54 bd_fsfreeze_mutex;
};

struct cgroup___26;

struct cgroup_subsys_state___26 {
	struct cgroup___26 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___54 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___53 *ia_file;
};

struct dquot___53 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___54 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___54 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___53 {
	int qf_fmt_id;
	const struct quota_format_ops___53 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___53 *qf_next;
};

struct quota_format_ops___53 {
	int (*check_quota_file)(struct super_block___54 *, int);
	int (*read_file_info)(struct super_block___54 *, int);
	int (*write_file_info)(struct super_block___54 *, int);
	int (*free_file_info)(struct super_block___54 *, int);
	int (*read_dqblk)(struct dquot___53 *);
	int (*commit_dqblk)(struct dquot___53 *);
	int (*release_dqblk)(struct dquot___53 *);
};

struct dquot_operations___53 {
	int (*write_dquot)(struct dquot___53 *);
	struct dquot___53 * (*alloc_dquot)(struct super_block___54 *, int);
	void (*destroy_dquot)(struct dquot___53 *);
	int (*acquire_dquot)(struct dquot___53 *);
	int (*release_dquot)(struct dquot___53 *);
	int (*mark_dirty)(struct dquot___53 *);
	int (*write_info)(struct super_block___54 *, int);
	qsize_t * (*get_reserved_space)(struct inode___54 *);
};

struct quotactl_ops___53 {
	int (*quota_on)(struct super_block___54 *, int, int, struct path___53 *);
	int (*quota_on_meta)(struct super_block___54 *, int, int);
	int (*quota_off)(struct super_block___54 *, int);
	int (*quota_sync)(struct super_block___54 *, int);
	int (*get_info)(struct super_block___54 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___54 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___54 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___54 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___54 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___54 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___54 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___54 *, unsigned int);
};

struct address_space_operations___53 {
	int (*writepage)(struct page___53 *, struct writeback_control *);
	int (*readpage)(struct file___53 *, struct page___53 *);
	int (*writepages)(struct address_space___53 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___53 *);
	int (*readpages)(struct file___53 *, struct address_space___53 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___53 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___53 **, void **);
	int (*write_end)(struct file___53 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___53 *, void *);
	sector_t (*bmap)(struct address_space___53 *, sector_t);
	void (*invalidatepage)(struct page___53 *, long unsigned int);
	int (*releasepage)(struct page___53 *, gfp_t);
	void (*freepage)(struct page___53 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___53 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___53 *, struct page___53 *, struct page___53 *, enum migrate_mode);
	int (*launder_page)(struct page___53 *);
	int (*is_partially_uptodate)(struct page___53 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___53 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___53 *, struct page___53 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___53 *, sector_t *);
	void (*swap_deactivate)(struct file___53 *);
	void (*invalidatepage_range)(struct page___53 *, unsigned int, unsigned int);
};

struct inode_operations___53 {
	struct dentry___54 * (*lookup)(struct inode___54 *, struct dentry___54 *, unsigned int);
	void * (*follow_link)(struct dentry___54 *, struct nameidata *);
	int (*permission)(struct inode___54 *, int);
	struct posix_acl * (*get_acl)(struct inode___54 *, int);
	int (*readlink)(struct dentry___54 *, char *, int);
	void (*put_link)(struct dentry___54 *, struct nameidata *, void *);
	int (*create)(struct inode___54 *, struct dentry___54 *, umode_t, bool);
	int (*link)(struct dentry___54 *, struct inode___54 *, struct dentry___54 *);
	int (*unlink)(struct inode___54 *, struct dentry___54 *);
	int (*symlink)(struct inode___54 *, struct dentry___54 *, const char *);
	int (*mkdir)(struct inode___54 *, struct dentry___54 *, umode_t);
	int (*rmdir)(struct inode___54 *, struct dentry___54 *);
	int (*mknod)(struct inode___54 *, struct dentry___54 *, umode_t, dev_t);
	int (*rename)(struct inode___54 *, struct dentry___54 *, struct inode___54 *, struct dentry___54 *);
	int (*setattr)(struct dentry___54 *, struct iattr___54 *);
	int (*getattr)(struct vfsmount *, struct dentry___54 *, struct kstat *);
	int (*setxattr)(struct dentry___54 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___54 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___54 *, char *, size_t);
	int (*removexattr)(struct dentry___54 *, const char *);
	int (*fiemap)(struct inode___54 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___54 *, struct timespec *, int);
	int (*atomic_open)(struct inode___54 *, struct dentry___54 *, struct file___53 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___31;

struct file_operations___53 {
	struct module *owner;
	loff_t (*llseek)(struct file___53 *, loff_t, int);
	ssize_t (*read)(struct file___53 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___53 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___53 *, void *, filldir_t);
	unsigned int (*poll)(struct file___53 *, struct poll_table_struct___31 *);
	long int (*unlocked_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___53 *, struct vm_area_struct___57 *);
	int (*open)(struct inode___54 *, struct file___53 *);
	int (*flush)(struct file___53 *, fl_owner_t);
	int (*release)(struct inode___54 *, struct file___53 *);
	int (*fsync)(struct file___53 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___53 *, int);
	int (*lock)(struct file___53 *, int, struct file_lock___53 *);
	ssize_t (*sendpage)(struct file___53 *, struct page___53 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___53 *, int, struct file_lock___53 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___53 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___53 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___53 *, long int, struct file_lock___53 **, void **);
		struct {
			int (*setlease)(struct file___53 *, long int, struct file_lock___53 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___53 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___37 *, struct file___53 *);
};

struct file_lock_operations___53;

struct lock_manager_operations___53;

struct file_lock___53 {
	struct file_lock___53 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___23 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___53 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___53 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___53 *fl_ops;
	const struct lock_manager_operations___53 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___53 {
	void (*fl_copy_lock)(struct file_lock___53 *, struct file_lock___53 *);
	void (*fl_release_private)(struct file_lock___53 *);
};

struct lock_manager_operations___53 {
	int (*lm_compare_owner)(struct file_lock___53 *, struct file_lock___53 *);
	long unsigned int (*lm_owner_key)(struct file_lock___53 *);
	void (*lm_notify)(struct file_lock___53 *);
	int (*lm_grant)(struct file_lock___53 *, struct file_lock___53 *, int);
	void (*lm_break)(struct file_lock___53 *);
	int (*lm_change)(struct file_lock___53 **, int);
};

struct fasync_struct___53 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___53 *fa_next;
	struct file___53 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___53 {
	const char *name;
	int fs_flags;
	struct dentry___54 * (*mount)(struct file_system_type___53 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___54 *);
	struct module *owner;
	struct file_system_type___53 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___53 {
	struct inode___54 * (*alloc_inode)(struct super_block___54 *);
	void (*destroy_inode)(struct inode___54 *);
	void (*dirty_inode)(struct inode___54 *, int);
	int (*write_inode)(struct inode___54 *, struct writeback_control *);
	int (*drop_inode)(struct inode___54 *);
	void (*evict_inode)(struct inode___54 *);
	void (*put_super)(struct super_block___54 *);
	int (*sync_fs)(struct super_block___54 *, int);
	int (*freeze_fs)(struct super_block___54 *);
	int (*unfreeze_fs)(struct super_block___54 *);
	int (*statfs)(struct dentry___54 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___54 *, int *, char *);
	void (*umount_begin)(struct super_block___54 *);
	int (*show_options)(struct seq_file___37 *, struct dentry___54 *);
	int (*show_devname)(struct seq_file___37 *, struct dentry___54 *);
	int (*show_path)(struct seq_file___37 *, struct dentry___54 *);
	int (*show_stats)(struct seq_file___37 *, struct dentry___54 *);
	ssize_t (*quota_read)(struct super_block___54 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___54 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___54 *);
	int (*bdev_try_to_free_page)(struct super_block___54 *, struct page___53 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___54 *);
	void (*free_cached_objects)(struct super_block___54 *, int);
};

struct xattr_handler___26 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___54 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___54 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___54 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___31)(struct file___53 *, wait_queue_head_t *, struct poll_table_struct___31 *);

struct poll_table_struct___31 {
	poll_queue_proc___31 _qproc;
	long unsigned int _key;
};

struct smp_hotplug_thread {
	struct task_struct___54 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	void (*pre_unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct seq_operations___36 {
	void * (*start)(struct seq_file___37 *, loff_t *);
	void (*stop)(struct seq_file___37 *, void *);
	void * (*next)(struct seq_file___37 *, void *, loff_t *);
	int (*show)(struct seq_file___37 *, void *);
};

struct kmem_cache_cpu___44 {
	void **freelist;
	long unsigned int tid;
	struct page___53 *page;
	struct page___53 *partial;
};

struct memcg_cache_params___44 {
	bool is_root_cache;
	union {
		struct kmem_cache___44 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___44 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___26;

struct cgroup___26 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___26 *parent;
	struct dentry___54 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___26 *subsys[11];
	struct cgroupfs_root___26 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___54 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___26 {
	struct super_block___54 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___26 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___22;

struct pmu___22 {
	struct list_head entry;
	struct device___42 *dev;
	const struct attribute_group___37 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___22 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___22 *);
	void (*pmu_disable)(struct pmu___22 *);
	int (*event_init)(struct perf_event___22 *);
	int (*add)(struct perf_event___22 *, int);
	void (*del)(struct perf_event___22 *, int);
	void (*start)(struct perf_event___22 *, int);
	void (*stop)(struct perf_event___22 *, int);
	void (*read)(struct perf_event___22 *);
	void (*start_txn)(struct pmu___22 *);
	int (*commit_txn)(struct pmu___22 *);
	void (*cancel_txn)(struct pmu___22 *);
	int (*event_idx)(struct perf_event___22 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___22 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___22 *);
};

struct perf_cpu_context___22 {
	struct perf_event_context___22 ctx;
	struct perf_event_context___22 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___22 *unique_pmu;
	struct perf_cgroup___22 *cgrp;
};

struct trace_event_functions___14;

struct trace_event___14 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___14 *funcs;
};

struct ftrace_event_class___14;

struct ftrace_event_call___14 {
	struct list_head list;
	struct ftrace_event_class___14 *class;
	char *name;
	struct trace_event___14 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___22 {
	struct cgroup_subsys_state___26 css;
	struct perf_cgroup_info *info;
};

struct trace_print_flags {
	long unsigned int mask;
	const char *name;
};

struct trace_iterator___14 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___54 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___14)(struct trace_iterator___14 *, int, struct trace_event___14 *);

struct trace_event_functions___14 {
	trace_print_func___14 trace;
	trace_print_func___14 raw;
	trace_print_func___14 hex;
	trace_print_func___14 binary;
};

struct ftrace_event_class___14 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___14 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___14 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___14 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___14 *);
};

struct ftrace_event_file___7 {
	struct list_head list;
	struct ftrace_event_call___14 *event_call;
	struct dentry___54 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_irq_handler_entry {
	struct trace_entry ent;
	int irq;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_irq_handler_exit {
	struct trace_entry ent;
	int irq;
	int ret;
	char __data[0];
};

struct ftrace_raw_softirq {
	struct trace_entry ent;
	unsigned int vec;
	char __data[0];
};

struct ftrace_data_offsets_irq_handler_entry {
	u32 name;
};

struct ftrace_data_offsets_irq_handler_exit {};

struct ftrace_data_offsets_softirq {};

struct tasklet_head {
	struct tasklet_struct *head;
	struct tasklet_struct **tail;
};

typedef unsigned int pto_T_____5;

typedef struct tasklet_struct *pto_T_____6;

typedef void (*dr_release_t)(struct device___40 *, void *);

typedef int (*dr_match_t)(struct device___40 *, void *, void *);

struct resource_constraint {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t (*alignf)(void *, const struct resource *, resource_size_t, resource_size_t);
	void *alignf_data;
};

enum {
	MAX_IORES_LEVEL = 5,
};

struct region_devres {
	struct resource *parent;
	resource_size_t start;
	resource_size_t n;
};

enum ftrace_dump_mode {
	DUMP_NONE = 0,
	DUMP_ALL = 1,
	DUMP_ORIG = 2,
};

struct page___54;

typedef struct page___54 *pgtable_t___54;

struct address_space___54;

struct kmem_cache___45;

struct page___54 {
	long unsigned int flags;
	struct address_space___54 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___54 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___54 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___45 *slab_cache;
		struct page___54 *first_page;
	};
	long: 64;
};

struct thread_struct___23;

struct task_struct___55;

struct pv_cpu_ops___54 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___23 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___23 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___55 *);
	void (*end_context_switch)(struct task_struct___55 *);
};

struct perf_event___23;

struct thread_struct___23 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___23 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___24;

struct pid_link___24 {
	struct hlist_node node;
	struct pid___24 *pid;
};

struct mutex___55 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___55 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___51 {
	struct page___54 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___58;

struct nsproxy___25;

struct signal_struct___54;

struct backing_dev_info___7;

struct css_set___27;

struct perf_event_context___23;

struct task_struct___55 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___55 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___58 *mm;
	struct mm_struct___58 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___55 *real_parent;
	struct task_struct___55 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___55 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___24 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___54 = 0,
		VTIME_USER___54 = 1,
		VTIME_SYS___54 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___23 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___25 *nsproxy;
	struct signal_struct___54 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___7 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___27 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___23 *perf_event_ctxp[2];
	struct mutex___55 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___51 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___58 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___58 *, struct mm_struct___58 *);
	void (*dup_mmap)(struct mm_struct___58 *, struct mm_struct___58 *);
	void (*exit_mmap)(struct mm_struct___58 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___58 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___58 *);
	void (*pgd_free)(struct mm_struct___58 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___58 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___58 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___58 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___58 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___58 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___58 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___58 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___58 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___58 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___58 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___58 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___55 lock;
	void *vdso;
} mm_context_t___55;

struct xol_area___54;

struct uprobes_state___54 {
	struct xol_area___54 *xol_area;
};

struct vm_area_struct___58;

struct file___54;

struct linux_binfmt___4;

struct core_state___54;

struct mm_struct___58 {
	struct vm_area_struct___58 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___58 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___58 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___4 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___55 context;
	long unsigned int flags;
	struct core_state___54 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___55 *owner;
	struct file___54 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___54 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___2;

struct kobj_type___2;

struct kobject___2 {
	const char *name;
	struct list_head entry;
	struct kobject___2 *parent;
	struct kset___2 *kset;
	struct kobj_type___2 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___36;

struct module_kobject___35 {
	struct kobject___2 kobj;
	struct module___36 *mod;
	struct kobject___2 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___35;

struct ftrace_event_call___15;

struct module___36 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___35 mkobj;
	struct module_attribute___35 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___2 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___15 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___55 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___23 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___55 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___55 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___55 *target;
};

struct perf_sample_data___4;

typedef void (*perf_overflow_handler_t___23)(struct perf_event___23 *, struct perf_sample_data___4 *, struct pt_regs *);

struct ftrace_ops___23;

typedef void (*ftrace_func_t___23)(long unsigned int, long unsigned int, struct ftrace_ops___23 *, struct pt_regs *);

struct ftrace_ops___23 {
	ftrace_func_t___23 func;
	struct ftrace_ops___23 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___55 regex_lock;
};

struct pmu___23;

struct fasync_struct___54;

struct pid_namespace___24;

struct perf_cgroup___23;

struct perf_event___23 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___23 *group_leader;
	struct pmu___23 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___23 hw;
	struct perf_event_context___23 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___55 child_mutex;
	struct list_head child_list;
	struct perf_event___23 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___55 *owner;
	struct mutex___55 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___54 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___23 *);
	struct callback_head callback_head;
	struct pid_namespace___24 *ns;
	u64 id;
	perf_overflow_handler_t___23 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___15 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___23 ftrace_ops;
	struct perf_cgroup___23 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___54;

struct lruvec___54 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___54 *zone;
};

struct pglist_data___54;

struct zone___54 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___54 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___54 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___54 {
	struct zone___54 *zone;
	int zone_idx;
};

struct zonelist___54 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___54 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___54 {
	struct zone___54 node_zones[4];
	struct zonelist___54 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___55 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___38;

struct x86_io_apic_ops___38 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___38 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___38;

struct irq_data___38 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___38 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___43;

struct dev_pm_ops___43 {
	int (*prepare)(struct device___43 *);
	void (*complete)(struct device___43 *);
	int (*suspend)(struct device___43 *);
	int (*resume)(struct device___43 *);
	int (*freeze)(struct device___43 *);
	int (*thaw)(struct device___43 *);
	int (*poweroff)(struct device___43 *);
	int (*restore)(struct device___43 *);
	int (*suspend_late)(struct device___43 *);
	int (*resume_early)(struct device___43 *);
	int (*freeze_late)(struct device___43 *);
	int (*thaw_early)(struct device___43 *);
	int (*poweroff_late)(struct device___43 *);
	int (*restore_early)(struct device___43 *);
	int (*suspend_noirq)(struct device___43 *);
	int (*resume_noirq)(struct device___43 *);
	int (*freeze_noirq)(struct device___43 *);
	int (*thaw_noirq)(struct device___43 *);
	int (*poweroff_noirq)(struct device___43 *);
	int (*restore_noirq)(struct device___43 *);
	int (*runtime_suspend)(struct device___43 *);
	int (*runtime_resume)(struct device___43 *);
	int (*runtime_idle)(struct device___43 *);
};

struct dev_pm_qos___4;

struct dev_pm_info___4 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___4 *qos;
};

struct dma_map_ops___22;

struct dev_archdata___22 {
	struct dma_map_ops___22 *dma_ops;
	void *iommu;
};

struct acpi_device___11;

struct acpi_dev_node___15 {
	union {
		struct acpi_device___11 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct device_type___43;

struct bus_type___43;

struct device_driver___43;

struct dev_pm_domain___43;

struct class___43;

struct attribute_group___38;

struct device_rh___43;

struct device___43 {
	struct device___43 *parent;
	struct device_private *p;
	struct kobject___2 kobj;
	const char *init_name;
	const struct device_type___43 *type;
	struct mutex___55 mutex;
	struct bus_type___43 *bus;
	struct device_driver___43 *driver;
	void *platform_data;
	struct dev_pm_info___4 power;
	struct dev_pm_domain___43 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___22 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___43 *class;
	const struct attribute_group___38 **groups;
	void (*release)(struct device___43 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___43 *device_rh;
};

struct dev_pm_qos_request___4;

struct dev_pm_qos___4 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___4 *latency_req;
	struct dev_pm_qos_request___4 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___4 *latency_tolerance_req;
};

struct dev_pm_info_rh___43 {
	void (*set_latency_tolerance)(struct device___43 *, s32);
};

struct dev_pm_domain___43 {
	struct dev_pm_ops___43 ops;
};

struct smp_ops___54 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___55 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___6;

struct ctl_node___6 {
	struct rb_node node;
	struct ctl_table_header___6 *header;
};

struct ctl_table_root___6;

struct ctl_table_set___6;

struct ctl_dir___6;

struct ctl_table_header___6 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___6 *root;
	struct ctl_table_set___6 *set;
	struct ctl_dir___6 *parent;
	struct ctl_node___6 *node;
};

struct ctl_dir___6 {
	struct ctl_table_header___6 header;
	struct rb_root root;
};

struct ctl_table_set___6 {
	int (*is_seen)(struct ctl_table_set___6 *);
	struct ctl_dir___6 dir;
};

struct ctl_table_root___6 {
	struct ctl_table_set___6 default_set;
	struct ctl_table_set___6 * (*lookup)(struct ctl_table_root___6 *, struct nsproxy___25 *);
	int (*permissions)(struct ctl_table_header___6 *, struct ctl_table *);
};

struct net___8;

struct nsproxy___25 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___24 *pid_ns;
	struct net___8 *net_ns;
};

struct sock___4;

struct kobj_ns_type_operations___2 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___4 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___2;

struct sock_common___2 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___2 *skc_prot;
	struct net___8 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___7;

struct sk_buff_head___5 {
	struct sk_buff___7 *next;
	struct sk_buff___7 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___3;

struct socket_wq___2;

struct dst_entry___3;

struct socket___2;

struct cg_proto___2;

struct sock___4 {
	struct sock_common___2 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___5 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___7 *head;
		struct sk_buff___7 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___3 *sk_filter;
	struct socket_wq___2 *sk_wq;
	struct sk_buff_head___5 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___3 *sk_rx_dst;
	struct dst_entry___3 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___5 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___5 sk_error_queue;
	struct proto___2 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___24 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___2 *sk_socket;
	void *sk_user_data;
	struct page_frag___51 sk_frag;
	struct sk_buff___7 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___2 *sk_cgrp;
	void (*sk_state_change)(struct sock___4 *);
	void (*sk_data_ready)(struct sock___4 *, int);
	void (*sk_write_space)(struct sock___4 *);
	void (*sk_error_report)(struct sock___4 *);
	int (*sk_backlog_rcv)(struct sock___4 *, struct sk_buff___7 *);
	void (*sk_destruct)(struct sock___4 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___38;

struct attribute_group___38 {
	const char *name;
	umode_t (*is_visible)(struct kobject___2 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___38 **bin_attrs;
};

struct bin_attribute___38 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___54 *, struct kobject___2 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___54 *, struct kobject___2 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	int (*mmap)(struct file___54 *, struct kobject___2 *, struct bin_attribute___38 *, struct vm_area_struct___58 *);
};

struct dentry___55;

struct path___54 {
	struct vfsmount *mnt;
	struct dentry___55 *dentry;
};

struct fown_struct___24 {
	rwlock_t lock;
	struct pid___24 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___55;

struct file_operations___54;

struct file___54 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___54 f_path;
	struct inode___55 *f_inode;
	const struct file_operations___54 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___24 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___54 *f_mapping;
	struct mutex___55 f_pos_lock;
};

struct vm_operations_struct___48;

struct vm_area_struct___58 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___58 *vm_next;
	struct vm_area_struct___58 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___58 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___48 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___54 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___2 {
	ssize_t (*show)(struct kobject___2 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___2 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___2 *, const struct attribute *);
};

struct kset_uevent_ops___2;

struct kset___2 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___2 kobj;
	const struct kset_uevent_ops___2 *uevent_ops;
};

struct kobj_type___2 {
	void (*release)(struct kobject___2 *);
	const struct sysfs_ops___2 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___2 *);
	const void * (*namespace)(struct kobject___2 *);
};

struct kset_uevent_ops___2 {
	int (* const filter)(struct kset___2 *, struct kobject___2 *);
	const char * (* const name)(struct kset___2 *, struct kobject___2 *);
	int (* const uevent)(struct kset___2 *, struct kobject___2 *, struct kobj_uevent_env *);
};

struct module_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___35 *, struct module_kobject___35 *, char *);
	ssize_t (*store)(struct module_attribute___35 *, struct module_kobject___35 *, const char *, size_t);
	void (*setup)(struct module___36 *, const char *);
	int (*test)(struct module___36 *);
	void (*free)(struct module___36 *);
};

struct trace_event_functions___15;

struct trace_event___15 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___15 *funcs;
};

struct ftrace_event_class___15;

struct ftrace_event_call___15 {
	struct list_head list;
	struct ftrace_event_class___15 *class;
	char *name;
	struct trace_event___15 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct xol_area___54 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___54 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___45;

struct memcg_cache_params___45;

struct kmem_cache___45 {
	struct kmem_cache_cpu___45 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___2 kobj;
	struct memcg_cache_params___45 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___54;

struct address_space___54 {
	struct inode___55 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___55 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___54 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___7 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___45;

struct vm_operations_struct___48 {
	void (*open)(struct vm_area_struct___58 *);
	void (*close)(struct vm_area_struct___58 *);
	int (*fault)(struct vm_area_struct___58 *, struct vm_fault___45 *);
	int (*page_mkwrite)(struct vm_area_struct___58 *, struct vm_fault___45 *);
	int (*access)(struct vm_area_struct___58 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___58 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___58 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___58 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___58 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___54 {
	struct task_struct___55 *task;
	struct core_thread___54 *next;
};

struct core_state___54 {
	atomic_t nr_threads;
	struct core_thread___54 dumper;
	struct completion startup;
};

struct linux_binprm___5;

struct coredump_params___4;

struct linux_binfmt___4 {
	struct list_head lh;
	struct module___36 *module;
	int (*load_binary)(struct linux_binprm___5 *);
	int (*load_shlib)(struct file___54 *);
	int (*core_dump)(struct coredump_params___4 *);
	long unsigned int min_coredump;
};

struct vm_fault___45 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___54 *page;
};

struct upid___24 {
	int nr;
	struct pid_namespace___24 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___24 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___55 *child_reaper;
	struct kmem_cache___45 *pid_cachep;
	unsigned int level;
	struct pid_namespace___24 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___55 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___24 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___24 numbers[1];
};

struct signal_struct___54 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___55 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___55 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___24 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___24 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___55 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback___7 {
	struct backing_dev_info___7 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___7 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___7 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___43 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___55 *debug_dir;
	struct dentry___55 *debug_stats;
};

struct cgroup_subsys_state___27;

struct css_set___27 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___27 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___23 {
	struct pmu___23 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___55 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___55 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___23 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct pipe_buffer___2;

struct pipe_inode_info {
	struct mutex___55 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___54 *tmp_page;
	struct fasync_struct___54 *fasync_readers;
	struct fasync_struct___54 *fasync_writers;
	struct pipe_buffer___2 *bufs;
};

struct kmem_cache_cpu___45 {
	void **freelist;
	long unsigned int tid;
	struct page___54 *page;
	struct page___54 *partial;
};

struct memcg_cache_params___45 {
	bool is_root_cache;
	union {
		struct kmem_cache___45 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___45 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___27 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___55 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___55 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___55 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___54;

struct super_block___55;

struct dentry___55 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___55 *d_parent;
	struct qstr d_name;
	struct inode___55 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___54 *d_op;
	struct super_block___55 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_stat_t {
	int nr_dentry;
	int nr_unused;
	int age_limit;
	int want_pages;
	int dummy[2];
};

struct inode_operations___54;

struct file_lock___54;

struct dquot___54;

struct block_device___54;

struct inode___55 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___54 *i_op;
	struct super_block___55 *i_sb;
	struct address_space___54 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___55 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___54 *i_fop;
	struct file_lock___54 *i_flock;
	struct address_space___54 i_data;
	struct dquot___54 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___54 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___54 {
	int (*d_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_hash)(const struct dentry___55 *, struct qstr *);
	int (*d_compare)(const struct dentry___55 *, const struct dentry___55 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___55 *);
	void (*d_release)(struct dentry___55 *);
	void (*d_prune)(struct dentry___55 *);
	void (*d_iput)(struct dentry___55 *, struct inode___55 *);
	char * (*d_dname)(struct dentry___55 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___54 *);
	int (*d_manage)(struct dentry___55 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___54;

struct mem_dqinfo___54 {
	struct quota_format_type___54 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___54;

struct quota_info___54 {
	unsigned int flags;
	struct mutex___55 dqio_mutex;
	struct mutex___55 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___55 *files[2];
	struct mem_dqinfo___54 info[2];
	const struct quota_format_ops___54 *ops[2];
};

struct file_system_type___54;

struct super_operations___54;

struct dquot_operations___54;

struct quotactl_ops___54;

struct super_block___55 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___54 *s_type;
	const struct super_operations___54 *s_op;
	const struct dquot_operations___54 *dq_op;
	const struct quotactl_ops___54 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___55 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___27 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___54 *s_bdev;
	struct backing_dev_info___7 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___54 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___55 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___54 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___54 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___55 *bd_inode;
	struct super_block___55 *bd_super;
	struct mutex___55 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___54 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___55 bd_fsfreeze_mutex;
};

struct cgroup___27;

struct cgroup_subsys_state___27 {
	struct cgroup___27 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct files_stat_struct {
	long unsigned int nr_files;
	long unsigned int nr_free_files;
	long unsigned int max_files;
};

struct inodes_stat_t {
	int nr_inodes;
	int nr_unused;
	int dummy[5];
};

struct kiocb___3;

typedef int kiocb_cancel_fn___3(struct kiocb___3 *, struct io_event *);

struct kiocb___3 {
	atomic_t ki_users;
	struct file___54 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___3 *ki_cancel;
	void (*ki_dtor)(struct kiocb___3 *);
	union {
		void *user;
		struct task_struct___55 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___55 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___54 *ia_file;
};

struct dquot___54 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___55 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___55 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___54 {
	int qf_fmt_id;
	const struct quota_format_ops___54 *qf_ops;
	struct module___36 *qf_owner;
	struct quota_format_type___54 *qf_next;
};

struct quota_format_ops___54 {
	int (*check_quota_file)(struct super_block___55 *, int);
	int (*read_file_info)(struct super_block___55 *, int);
	int (*write_file_info)(struct super_block___55 *, int);
	int (*free_file_info)(struct super_block___55 *, int);
	int (*read_dqblk)(struct dquot___54 *);
	int (*commit_dqblk)(struct dquot___54 *);
	int (*release_dqblk)(struct dquot___54 *);
};

struct dquot_operations___54 {
	int (*write_dquot)(struct dquot___54 *);
	struct dquot___54 * (*alloc_dquot)(struct super_block___55 *, int);
	void (*destroy_dquot)(struct dquot___54 *);
	int (*acquire_dquot)(struct dquot___54 *);
	int (*release_dquot)(struct dquot___54 *);
	int (*mark_dirty)(struct dquot___54 *);
	int (*write_info)(struct super_block___55 *, int);
	qsize_t * (*get_reserved_space)(struct inode___55 *);
};

struct quotactl_ops___54 {
	int (*quota_on)(struct super_block___55 *, int, int, struct path___54 *);
	int (*quota_on_meta)(struct super_block___55 *, int, int);
	int (*quota_off)(struct super_block___55 *, int);
	int (*quota_sync)(struct super_block___55 *, int);
	int (*get_info)(struct super_block___55 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___55 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___55 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___55 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___55 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___55 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___55 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___55 *, unsigned int);
};

struct swap_info_struct___7;

struct address_space_operations___54 {
	int (*writepage)(struct page___54 *, struct writeback_control *);
	int (*readpage)(struct file___54 *, struct page___54 *);
	int (*writepages)(struct address_space___54 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___54 *);
	int (*readpages)(struct file___54 *, struct address_space___54 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___54 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___54 **, void **);
	int (*write_end)(struct file___54 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___54 *, void *);
	sector_t (*bmap)(struct address_space___54 *, sector_t);
	void (*invalidatepage)(struct page___54 *, long unsigned int);
	int (*releasepage)(struct page___54 *, gfp_t);
	void (*freepage)(struct page___54 *);
	ssize_t (*direct_IO)(int, struct kiocb___3 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___54 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___54 *, struct page___54 *, struct page___54 *, enum migrate_mode);
	int (*launder_page)(struct page___54 *);
	int (*is_partially_uptodate)(struct page___54 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___54 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___54 *, struct page___54 *);
	int (*swap_activate)(struct swap_info_struct___7 *, struct file___54 *, sector_t *);
	void (*swap_deactivate)(struct file___54 *);
	void (*invalidatepage_range)(struct page___54 *, unsigned int, unsigned int);
};

struct swap_info_struct___7 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___54 *bdev;
	struct file___54 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___54 {
	struct dentry___55 * (*lookup)(struct inode___55 *, struct dentry___55 *, unsigned int);
	void * (*follow_link)(struct dentry___55 *, struct nameidata *);
	int (*permission)(struct inode___55 *, int);
	struct posix_acl * (*get_acl)(struct inode___55 *, int);
	int (*readlink)(struct dentry___55 *, char *, int);
	void (*put_link)(struct dentry___55 *, struct nameidata *, void *);
	int (*create)(struct inode___55 *, struct dentry___55 *, umode_t, bool);
	int (*link)(struct dentry___55 *, struct inode___55 *, struct dentry___55 *);
	int (*unlink)(struct inode___55 *, struct dentry___55 *);
	int (*symlink)(struct inode___55 *, struct dentry___55 *, const char *);
	int (*mkdir)(struct inode___55 *, struct dentry___55 *, umode_t);
	int (*rmdir)(struct inode___55 *, struct dentry___55 *);
	int (*mknod)(struct inode___55 *, struct dentry___55 *, umode_t, dev_t);
	int (*rename)(struct inode___55 *, struct dentry___55 *, struct inode___55 *, struct dentry___55 *);
	int (*setattr)(struct dentry___55 *, struct iattr___55 *);
	int (*getattr)(struct vfsmount *, struct dentry___55 *, struct kstat *);
	int (*setxattr)(struct dentry___55 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___55 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___55 *, char *, size_t);
	int (*removexattr)(struct dentry___55 *, const char *);
	int (*fiemap)(struct inode___55 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___55 *, struct timespec *, int);
	int (*atomic_open)(struct inode___55 *, struct dentry___55 *, struct file___54 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___32;

struct seq_file___38;

struct file_operations___54 {
	struct module___36 *owner;
	loff_t (*llseek)(struct file___54 *, loff_t, int);
	ssize_t (*read)(struct file___54 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___54 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___3 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___3 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___54 *, void *, filldir_t);
	unsigned int (*poll)(struct file___54 *, struct poll_table_struct___32 *);
	long int (*unlocked_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___54 *, struct vm_area_struct___58 *);
	int (*open)(struct inode___55 *, struct file___54 *);
	int (*flush)(struct file___54 *, fl_owner_t);
	int (*release)(struct inode___55 *, struct file___54 *);
	int (*fsync)(struct file___54 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___3 *, int);
	int (*fasync)(int, struct file___54 *, int);
	int (*lock)(struct file___54 *, int, struct file_lock___54 *);
	ssize_t (*sendpage)(struct file___54 *, struct page___54 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___54 *, int, struct file_lock___54 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___54 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___54 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___54 *, long int, struct file_lock___54 **, void **);
		struct {
			int (*setlease)(struct file___54 *, long int, struct file_lock___54 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___54 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___38 *, struct file___54 *);
};

struct file_lock_operations___54;

struct lock_manager_operations___54;

struct file_lock___54 {
	struct file_lock___54 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___24 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___54 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___54 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___54 *fl_ops;
	const struct lock_manager_operations___54 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___54 {
	void (*fl_copy_lock)(struct file_lock___54 *, struct file_lock___54 *);
	void (*fl_release_private)(struct file_lock___54 *);
};

struct lock_manager_operations___54 {
	int (*lm_compare_owner)(struct file_lock___54 *, struct file_lock___54 *);
	long unsigned int (*lm_owner_key)(struct file_lock___54 *);
	void (*lm_notify)(struct file_lock___54 *);
	int (*lm_grant)(struct file_lock___54 *, struct file_lock___54 *, int);
	void (*lm_break)(struct file_lock___54 *);
	int (*lm_change)(struct file_lock___54 **, int);
};

struct fasync_struct___54 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___54 *fa_next;
	struct file___54 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___54 {
	const char *name;
	int fs_flags;
	struct dentry___55 * (*mount)(struct file_system_type___54 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___55 *);
	struct module___36 *owner;
	struct file_system_type___54 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___54 {
	struct inode___55 * (*alloc_inode)(struct super_block___55 *);
	void (*destroy_inode)(struct inode___55 *);
	void (*dirty_inode)(struct inode___55 *, int);
	int (*write_inode)(struct inode___55 *, struct writeback_control *);
	int (*drop_inode)(struct inode___55 *);
	void (*evict_inode)(struct inode___55 *);
	void (*put_super)(struct super_block___55 *);
	int (*sync_fs)(struct super_block___55 *, int);
	int (*freeze_fs)(struct super_block___55 *);
	int (*unfreeze_fs)(struct super_block___55 *);
	int (*statfs)(struct dentry___55 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___55 *, int *, char *);
	void (*umount_begin)(struct super_block___55 *);
	int (*show_options)(struct seq_file___38 *, struct dentry___55 *);
	int (*show_devname)(struct seq_file___38 *, struct dentry___55 *);
	int (*show_path)(struct seq_file___38 *, struct dentry___55 *);
	int (*show_stats)(struct seq_file___38 *, struct dentry___55 *);
	ssize_t (*quota_read)(struct super_block___55 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___55 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___55 *);
	int (*bdev_try_to_free_page)(struct super_block___55 *, struct page___54 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___55 *);
	void (*free_cached_objects)(struct super_block___55 *, int);
};

typedef void (*poll_queue_proc___32)(struct file___54 *, wait_queue_head_t *, struct poll_table_struct___32 *);

struct poll_table_struct___32 {
	poll_queue_proc___32 _qproc;
	long unsigned int _key;
};

struct seq_operations___37;

struct seq_file___38 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___55 lock;
	const struct seq_operations___37 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___27;

struct cgroup___27 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___27 *parent;
	struct dentry___55 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___27 *subsys[11];
	struct cgroupfs_root___27 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___55 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___27 {
	struct super_block___55 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___27 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___8 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___55 *, struct file___54 *);
	ssize_t (*read)(struct cgroup___27 *, struct cftype___8 *, struct file___54 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___27 *, struct cftype___8 *);
	s64 (*read_s64)(struct cgroup___27 *, struct cftype___8 *);
	int (*read_map)(struct cgroup___27 *, struct cftype___8 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___27 *, struct cftype___8 *, struct seq_file___38 *);
	ssize_t (*write)(struct cgroup___27 *, struct cftype___8 *, struct file___54 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___27 *, struct cftype___8 *, u64);
	int (*write_s64)(struct cgroup___27 *, struct cftype___8 *, s64);
	int (*write_string)(struct cgroup___27 *, struct cftype___8 *, const char *);
	int (*trigger)(struct cgroup___27 *, unsigned int);
	int (*release)(struct inode___55 *, struct file___54 *);
	int (*register_event)(struct cgroup___27 *, struct cftype___8 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___27 *, struct cftype___8 *, struct eventfd_ctx *);
};

struct cftype_set___7 {
	struct list_head node;
	struct cftype___8 *cfts;
};

struct task_and_cgroup___7 {
	struct task_struct___55 *task;
	struct cgroup___27 *cgrp;
	struct css_set___27 *cg;
};

struct cgroup_taskset___7 {
	struct task_and_cgroup___7 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___27 *cur_cgrp;
};

struct cgroup_subsys___7 {
	struct cgroup_subsys_state___27 * (*css_alloc)(struct cgroup___27 *);
	int (*css_online)(struct cgroup___27 *);
	void (*css_offline)(struct cgroup___27 *);
	void (*css_free)(struct cgroup___27 *);
	int (*can_attach)(struct cgroup___27 *, struct cgroup_taskset___7 *);
	void (*cancel_attach)(struct cgroup___27 *, struct cgroup_taskset___7 *);
	void (*attach)(struct cgroup___27 *, struct cgroup_taskset___7 *);
	void (*fork)(struct task_struct___55 *);
	void (*exit)(struct cgroup___27 *, struct cgroup___27 *, struct task_struct___55 *);
	void (*bind)(struct cgroup___27 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___27 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___8 *base_cftypes;
	struct cftype_set___7 base_cftset;
	struct module___36 *module;
};

struct irq_chip___38 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___38 *);
	void (*irq_shutdown)(struct irq_data___38 *);
	void (*irq_enable)(struct irq_data___38 *);
	void (*irq_disable)(struct irq_data___38 *);
	void (*irq_ack)(struct irq_data___38 *);
	void (*irq_mask)(struct irq_data___38 *);
	void (*irq_mask_ack)(struct irq_data___38 *);
	void (*irq_unmask)(struct irq_data___38 *);
	void (*irq_eoi)(struct irq_data___38 *);
	int (*irq_set_affinity)(struct irq_data___38 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___38 *);
	int (*irq_set_type)(struct irq_data___38 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___38 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___38 *);
	void (*irq_bus_sync_unlock)(struct irq_data___38 *);
	void (*irq_cpu_online)(struct irq_data___38 *);
	void (*irq_cpu_offline)(struct irq_data___38 *);
	void (*irq_suspend)(struct irq_data___38 *);
	void (*irq_resume)(struct irq_data___38 *);
	void (*irq_pm_shutdown)(struct irq_data___38 *);
	void (*irq_print_chip)(struct irq_data___38 *, struct seq_file___38 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___38 *, void *);
	long unsigned int flags;
};

struct dma_map_ops___22 {
	void * (*alloc)(struct device___43 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___43 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___43 *, struct vm_area_struct___58 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___43 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___43 *, struct page___54 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___43 *, dma_addr_t);
	int (*dma_supported)(struct device___43 *, u64);
	int (*set_dma_mask)(struct device___43 *, u64);
	int is_phys;
};

struct bus_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___43 *, char *);
	ssize_t (*store)(struct bus_type___43 *, const char *, size_t);
};

struct device_attribute___43;

struct driver_attribute___43;

struct bus_type___43 {
	const char *name;
	const char *dev_name;
	struct device___43 *dev_root;
	struct bus_attribute___43 *bus_attrs;
	struct device_attribute___43 *dev_attrs;
	struct driver_attribute___43 *drv_attrs;
	const struct attribute_group___38 **bus_groups;
	const struct attribute_group___38 **dev_groups;
	const struct attribute_group___38 **drv_groups;
	int (*match)(struct device___43 *, struct device_driver___43 *);
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	int (*probe)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*online)(struct device___43 *);
	int (*offline)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct device___43 *, struct device_attribute___43 *, char *);
	ssize_t (*store)(struct device___43 *, struct device_attribute___43 *, const char *, size_t);
};

struct driver_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___43 *, char *);
	ssize_t (*store)(struct device_driver___43 *, const char *, size_t);
};

struct device_driver___43 {
	const char *name;
	struct bus_type___43 *bus;
	struct module___36 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct attribute_group___38 **groups;
	const struct dev_pm_ops___43 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___43 {
	const char *name;
	const struct attribute_group___38 **groups;
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
};

struct class_attribute___43;

struct class___43 {
	const char *name;
	struct module___36 *owner;
	struct class_attribute___43 *class_attrs;
	struct device_attribute___43 *dev_attrs;
	const struct attribute_group___38 **dev_groups;
	struct bin_attribute___38 *dev_bin_attrs;
	struct kobject___2 *dev_kobj;
	int (*dev_uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *);
	void (*class_release)(struct class___43 *);
	void (*dev_release)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	struct subsys_private *p;
};

struct class_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct class___43 *, struct class_attribute___43 *, char *);
	ssize_t (*store)(struct class___43 *, struct class_attribute___43 *, const char *, size_t);
	const void * (*namespace)(struct class___43 *, const struct class_attribute___43 *);
};

struct acpi_scan_handler___11;

struct acpi_hotplug_context___11;

struct acpi_driver___11;

struct acpi_device___11 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___11 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___11 *handler;
	struct acpi_hotplug_context___11 *hp;
	struct acpi_driver___11 *driver;
	void *driver_data;
	struct device___43 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___55 physical_node_lock;
	void (*remove)(struct acpi_device___11 *);
};

struct device_rh___43 {
	struct dev_pm_info_rh___43 power;
};

struct linux_binprm___5 {
	char buf[128];
	struct vm_area_struct___58 *vma;
	long unsigned int vma_pages;
	struct mm_struct___58 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___54 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct net_device___6;

struct nf_bridge_info___3;

struct sk_buff___7 {
	struct sk_buff___7 *next;
	struct sk_buff___7 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___4 *sk;
	struct net_device___6 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___7 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___3 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct proto_ops___2;

struct socket___2 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___2 *wq;
	struct file___54 *file;
	struct sock___4 *sk;
	const struct proto_ops___2 *ops;
};

struct request_sock_ops___2;

struct request_sock___2 {
	struct sock_common___2 __req_common;
	struct request_sock___2 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___2 *rsk_ops;
	struct sock___4 *sk;
	u32 secid;
	u32 peer_secid;
};

struct socket_wq___2 {
	wait_queue_head_t wait;
	struct fasync_struct___54 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___2 {
	int family;
	struct module___36 *owner;
	int (*release)(struct socket___2 *);
	int (*bind)(struct socket___2 *, struct sockaddr *, int);
	int (*connect)(struct socket___2 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___2 *, struct socket___2 *);
	int (*accept)(struct socket___2 *, struct socket___2 *, int);
	int (*getname)(struct socket___2 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___54 *, struct socket___2 *, struct poll_table_struct___32 *);
	int (*ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___2 *, int);
	int (*shutdown)(struct socket___2 *, int);
	int (*setsockopt)(struct socket___2 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___2 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___2 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___2 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___3 *, struct socket___2 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___3 *, struct socket___2 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___54 *, struct socket___2 *, struct vm_area_struct___58 *);
	ssize_t (*sendpage)(struct socket___2 *, struct page___54 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___2 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___4 *, int);
		struct {
			void (*set_peek_off)(struct sock___4 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___6 {
	struct ctl_table_header___6 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___6 {
	struct mutex___55 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___6 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___6 *ctl;
};

struct netns_ipv4___6 {
	struct ctl_table_header___6 *forw_hdr;
	struct ctl_table_header___6 *frags_hdr;
	struct ctl_table_header___6 *ipv4_hdr;
	struct ctl_table_header___6 *route_hdr;
	struct ctl_table_header___6 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___4 *fibnl;
	struct sock___4 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___6 {
	struct ctl_table_header___6 *hdr;
	struct ctl_table_header___6 *route_hdr;
	struct ctl_table_header___6 *icmp_hdr;
	struct ctl_table_header___6 *frags_hdr;
	struct ctl_table_header___6 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___3;

struct dst_ops___7 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___7 *);
	struct dst_entry___3 * (*check)(struct dst_entry___3 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___3 *);
	unsigned int (*mtu)(const struct dst_entry___3 *);
	u32 * (*cow_metrics)(struct dst_entry___3 *, long unsigned int);
	void (*destroy)(struct dst_entry___3 *);
	void (*ifdown)(struct dst_entry___3 *, struct net_device___6 *, int);
	struct dst_entry___3 * (*negative_advice)(struct dst_entry___3 *);
	void (*link_failure)(struct sk_buff___7 *);
	void (*update_pmtu)(struct dst_entry___3 *, struct sock___4 *, struct sk_buff___7 *, u32);
	void (*redirect)(struct dst_entry___3 *, struct sock___4 *, struct sk_buff___7 *);
	int (*local_out)(struct sk_buff___7 *);
	struct neighbour___3 * (*neigh_lookup)(const struct dst_entry___3 *, struct sk_buff___7 *, const void *);
	struct kmem_cache___45 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___6 {
	struct netns_sysctl_ipv6___6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___7 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___4 **icmp_sk;
	struct sock___4 *ndisc_sk;
	struct sock___4 *tcp_sk;
	struct sock___4 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___6 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___6 *sysctl_header;
	struct sock___4 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___2 {
	struct sock___4 *v4_ctl_sk;
	struct sock___4 *v6_ctl_sk;
};

struct netns_nf___6 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___6 *nf_log_dir_header;
};

struct nf_proto_net___6 {
	struct ctl_table_header___6 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___6 {
	struct nf_proto_net___6 pn;
	unsigned int timeout;
};

struct nf_tcp_net___6 {
	struct nf_proto_net___6 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___6 {
	struct nf_proto_net___6 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___6 {
	struct nf_proto_net___6 pn;
	unsigned int timeout;
};

struct nf_ip_net___6 {
	struct nf_generic_net___6 generic;
	struct nf_tcp_net___6 tcp;
	struct nf_udp_net___6 udp;
	struct nf_icmp_net___6 icmp;
	struct nf_icmp_net___6 icmpv6;
};

struct netns_ct___6 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___6 *sysctl_header;
	struct ctl_table_header___6 *acct_sysctl_header;
	struct ctl_table_header___6 *tstamp_sysctl_header;
	struct ctl_table_header___6 *event_sysctl_header;
	struct ctl_table_header___6 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___45 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___6 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___6 {
	struct netns_sysctl_ipv6___6 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___6 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___4 *nlsk;
	struct sock___4 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___6 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___7 xfrm4_dst_ops;
	struct dst_ops___7 xfrm6_dst_ops;
};

struct net___8 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___6 sysctls;
	struct sock___4 *rtnl;
	struct sock___4 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___6 *loopback_dev;
	struct netns_core___6 core;
	struct netns_mib mib;
	struct netns_packet___6 packet;
	struct netns_unix___6 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___6 ipv4;
	struct netns_ipv6___6 ipv6;
	struct netns_sctp___6 sctp;
	struct netns_dccp___2 dccp;
	struct netns_nf___6 nf;
	struct netns_xt xt;
	struct netns_ct___6 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___6 nf_frag;
	struct sock___4 *nfnl;
	struct sock___4 *nfnl_stash;
	struct sk_buff_head___5 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___6 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___4 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___4 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___55 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___55 flow_flush_sem;
	long: 64;
	long: 64;
};

struct tlb_state___22 {
	struct mm_struct___58 *active_mm;
	int state;
};

struct hstate___4 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___8 cgroup_files[5];
	char name[32];
};

struct seq_operations___37 {
	void * (*start)(struct seq_file___38 *, loff_t *);
	void (*stop)(struct seq_file___38 *, void *);
	void * (*next)(struct seq_file___38 *, void *, loff_t *);
	int (*show)(struct seq_file___38 *, void *);
};

struct perf_cpu_context___23;

struct pmu___23 {
	struct list_head entry;
	struct device___43 *dev;
	const struct attribute_group___38 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___23 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___23 *);
	void (*pmu_disable)(struct pmu___23 *);
	int (*event_init)(struct perf_event___23 *);
	int (*add)(struct perf_event___23 *, int);
	void (*del)(struct perf_event___23 *, int);
	void (*start)(struct perf_event___23 *, int);
	void (*stop)(struct perf_event___23 *, int);
	void (*read)(struct perf_event___23 *);
	void (*start_txn)(struct pmu___23 *);
	int (*commit_txn)(struct pmu___23 *);
	void (*cancel_txn)(struct pmu___23 *);
	int (*event_idx)(struct perf_event___23 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___36 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___23 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___23 *);
};

struct perf_cpu_context___23 {
	struct perf_event_context___23 ctx;
	struct perf_event_context___23 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___23 *unique_pmu;
	struct perf_cgroup___23 *cgrp;
};

struct perf_sample_data___4 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___23 {
	struct cgroup_subsys_state___27 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___15 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___55 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___15)(struct trace_iterator___15 *, int, struct trace_event___15 *);

struct trace_event_functions___15 {
	trace_print_func___15 trace;
	trace_print_func___15 raw;
	trace_print_func___15 hex;
	trace_print_func___15 binary;
};

struct ftrace_event_class___15 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___15 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___15 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___15 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___15 *);
};

struct nf_bridge_info___3 {
	atomic_t use;
	unsigned int mask;
	struct net_device___6 *physindev;
	struct net_device___6 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___3(struct sk_buff___7 **);

struct net_device_ops___3;

struct ethtool_ops___3;

struct header_ops___3;

struct inet6_dev___3;

struct netdev_rx_queue___3;

struct netdev_queue___3;

struct rtnl_link_ops___3;

struct dcbnl_rtnl_ops___3;

struct net_device___6 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___3 *netdev_ops;
	const struct ethtool_ops___3 *ethtool_ops;
	const struct header_ops___3 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___2 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___3 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___3 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___3 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___3 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___3 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___3 = 0,
		NETREG_REGISTERED___3 = 1,
		NETREG_UNREGISTERING___3 = 2,
		NETREG_UNREGISTERED___3 = 3,
		NETREG_RELEASED___3 = 4,
		NETREG_DUMMY___3 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___3 = 0,
		RTNL_LINK_INITIALIZING___3 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___6 *);
	struct netpoll_info *npinfo;
	struct net___8 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide22;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___43 dev;
	const struct attribute_group___38 *sysfs_groups[4];
	const struct rtnl_link_ops___3 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___3 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___4 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___43 *dev;
};

struct ethtool_ops___3 {
	int (*get_settings)(struct net_device___6 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___6 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___6 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___6 *);
	void (*get_regs)(struct net_device___6 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___6 *);
	void (*set_msglevel)(struct net_device___6 *, u32);
	int (*nway_reset)(struct net_device___6 *);
	u32 (*get_link)(struct net_device___6 *);
	int (*get_eeprom_len)(struct net_device___6 *);
	int (*get_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___6 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___6 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___6 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___6 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___6 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___6 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___6 *);
	void (*complete)(struct net_device___6 *);
	u32 (*get_priv_flags)(struct net_device___6 *);
	int (*set_priv_flags)(struct net_device___6 *, u32);
	int (*get_sset_count)(struct net_device___6 *, int);
	int (*get_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___6 *, struct ethtool_flash *);
	int (*reset)(struct net_device___6 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___6 *);
	int (*get_rxfh_indir)(struct net_device___6 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___6 *, const u32 *);
	void (*get_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___6 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___6 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___6 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___6 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___6 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___6 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___6 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___6 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___3 {
	struct callback_head callback_head;
	struct dst_entry___3 *child;
	struct net_device___6 *dev;
	struct dst_ops___7 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___3 *path;
	struct dst_entry___3 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___7 *);
	union {
		int (*output)(struct sock___4 *, struct sk_buff___7 *);
		struct {
			int (*output)(struct sk_buff___7 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___3 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___3;

struct neigh_parms___3;

struct neigh_ops___3;

struct neighbour___3 {
	struct neighbour___3 *next;
	struct neigh_table___3 *tbl;
	struct neigh_parms___3 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___5 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___3 *, struct sk_buff___7 *);
	const struct neigh_ops___3 *ops;
	struct callback_head rcu;
	struct net_device___6 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___6 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___7 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___7 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___8 *, struct dst_entry___3 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___7 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___7 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___3 {
	int (*ieee_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___6 *);
	u8 (*setstate)(struct net_device___6 *, u8);
	void (*getpermhwaddr)(struct net_device___6 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___6 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___6 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___6 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___6 *, int, u8 *);
	void (*setpfccfg)(struct net_device___6 *, int, u8);
	void (*getpfccfg)(struct net_device___6 *, int, u8 *);
	u8 (*setall)(struct net_device___6 *);
	u8 (*getcap)(struct net_device___6 *, int, u8 *);
	int (*getnumtcs)(struct net_device___6 *, int, u8 *);
	int (*setnumtcs)(struct net_device___6 *, int, u8);
	u8 (*getpfcstate)(struct net_device___6 *);
	void (*setpfcstate)(struct net_device___6 *, u8);
	void (*getbcncfg)(struct net_device___6 *, int, u32 *);
	void (*setbcncfg)(struct net_device___6 *, int, u32);
	void (*getbcnrp)(struct net_device___6 *, int, u8 *);
	void (*setbcnrp)(struct net_device___6 *, int, u8);
	u8 (*setapp)(struct net_device___6 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___6 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___6 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___6 *, int, u8);
	u8 (*getdcbx)(struct net_device___6 *);
	u8 (*setdcbx)(struct net_device___6 *, u8);
	int (*peer_getappinfo)(struct net_device___6 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___6 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___6 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___6 *, struct cee_pfc *);
};

struct netlink_callback___3 {
	struct sk_buff___7 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___7 *, struct netlink_callback___3 *);
	int (*done)(struct netlink_callback___3 *);
	void *data;
	struct module___36 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct ifla_vf_info___2 {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	union {
		__u32 max_tx_rate;
		struct {
			__u32 tx_rate;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 rss_query_en;
};

struct header_ops___3 {
	int (*create)(struct sk_buff___7 *, struct net_device___6 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___7 *, unsigned char *);
	int (*rebuild)(struct sk_buff___7 *);
	int (*cache)(const struct neighbour___3 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___6 *, const unsigned char *);
};

struct napi_struct___3 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___3 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___6 *dev;
	struct sk_buff___7 *gro_list;
	struct sk_buff___7 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___3 {
	struct net_device___6 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___2 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___3 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___2 kobj;
	struct net_device___6 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___3 {
	int (*ndo_init)(struct net_device___6 *);
	void (*ndo_uninit)(struct net_device___6 *);
	int (*ndo_open)(struct net_device___6 *);
	int (*ndo_stop)(struct net_device___6 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___7 *, struct net_device___6 *);
	u16 (*ndo_select_queue)(struct net_device___6 *, struct sk_buff___7 *);
	void (*ndo_change_rx_flags)(struct net_device___6 *, int);
	void (*ndo_set_rx_mode)(struct net_device___6 *);
	int (*ndo_set_mac_address)(struct net_device___6 *, void *);
	int (*ndo_validate_addr)(struct net_device___6 *);
	int (*ndo_do_ioctl)(struct net_device___6 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___6 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___6 *, int);
	int (*ndo_neigh_setup)(struct net_device___6 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___6 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___6 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___6 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___6 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___6 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___6 *);
	int (*ndo_netpoll_setup)(struct net_device___6 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___6 *);
	int (*ndo_busy_poll)(struct napi_struct___3 *);
	int (*ndo_set_vf_mac)(struct net_device___6 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___6 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___6 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___6 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___6 *, int, struct ifla_vf_info___2 *);
	int (*ndo_set_vf_link_state)(struct net_device___6 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___6 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___6 *, int, struct sk_buff___7 *);
	int (*ndo_setup_tc)(struct net_device___6 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___6 *);
	int (*ndo_fcoe_disable)(struct net_device___6 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___6 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___6 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___6 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___6 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___6 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___6 *, const struct sk_buff___7 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___6 *, struct net_device___6 *);
	int (*ndo_del_slave)(struct net_device___6 *, struct net_device___6 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___3 *);
	void (*ndo_neigh_destroy)(struct neighbour___3 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___7 *, struct netlink_callback___3 *, struct net_device___6 *, int);
	int (*ndo_bridge_setlink)(struct net_device___6 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___7 *, u32, u32, struct net_device___6 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___6 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___6 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___6 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___6 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___6 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___6 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___7 *, struct net_device___6 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___6 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___6 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___6 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___3 {
	struct net___8 *net;
	struct net_device___6 *dev;
	struct neigh_parms___3 *next;
	int (*neigh_setup)(struct neighbour___3 *);
	void (*neigh_cleanup)(struct neighbour___3 *);
	struct neigh_table___3 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___2;

struct ifacaddr6___2;

struct inet6_dev___3 {
	struct net_device___6 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___2 *mc_list;
	struct ifmcaddr6___2 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___3 *nd_parms;
	struct inet6_dev___3 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___3 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___6 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___8 *, struct net_device___6 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___6 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___6 *, struct list_head *);
	size_t (*get_size)(const struct net_device___6 *);
	int (*fill_info)(struct sk_buff___7 *, const struct net_device___6 *);
	size_t (*get_xstats_size)(const struct net_device___6 *);
	int (*fill_xstats)(struct sk_buff___7 *, const struct net_device___6 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___8 * (*get_link_net)(const struct net_device___6 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___6 *, struct net_device___6 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___6 *, const struct net_device___6 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___7 *, const struct net_device___6 *, const struct net_device___6 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___3 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___7 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___2;

struct neigh_hash_table___2;

struct neigh_table___3 {
	struct neigh_table___3 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___6 *, __u32 *);
	int (*constructor)(struct neighbour___3 *);
	int (*pconstructor)(struct pneigh_entry___2 *);
	void (*pdestructor)(struct pneigh_entry___2 *);
	void (*proxy_redo)(struct sk_buff___7 *);
	char *id;
	struct neigh_parms___3 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___5 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___2 *nht;
	struct pneigh_entry___2 **phash_buckets;
};

struct neigh_ops___3 {
	int family;
	void (*solicit)(struct neighbour___3 *, struct sk_buff___7 *);
	void (*error_report)(struct neighbour___3 *, struct sk_buff___7 *);
	int (*output)(struct neighbour___3 *, struct sk_buff___7 *);
	int (*connected_output)(struct neighbour___3 *, struct sk_buff___7 *);
};

struct pneigh_entry___2 {
	struct pneigh_entry___2 *next;
	struct net___8 *net;
	struct net_device___6 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___2 {
	struct neighbour___3 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___2;

struct proto___2 {
	void (*close)(struct sock___4 *, long int);
	int (*connect)(struct sock___4 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___4 *, int);
	struct sock___4 * (*accept)(struct sock___4 *, int, int *);
	int (*ioctl)(struct sock___4 *, int, long unsigned int);
	int (*init)(struct sock___4 *);
	void (*destroy)(struct sock___4 *);
	void (*shutdown)(struct sock___4 *, int);
	int (*setsockopt)(struct sock___4 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___4 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___4 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___4 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___4 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___3 *, struct sock___4 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___3 *, struct sock___4 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___4 *, struct page___54 *, int, size_t, int);
	int (*bind)(struct sock___4 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___4 *, struct sk_buff___7 *);
	void (*release_cb)(struct sock___4 *);
	void (*mtu_reduced)(struct sock___4 *);
	void (*hash)(struct sock___4 *);
	void (*unhash)(struct sock___4 *);
	void (*rehash)(struct sock___4 *);
	int (*get_port)(struct sock___4 *, short unsigned int);
	void (*clear_sk)(struct sock___4 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___4 *);
	void (*enter_memory_pressure)(struct sock___4 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___45 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___2 *rsk_prot;
	struct timewait_sock_ops___2 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___36 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___7 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___2 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___2 {
	void (*enter_memory_pressure)(struct sock___4 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___2 {
	int family;
	int obj_size;
	struct kmem_cache___45 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___4 *, struct request_sock___2 *);
	void (*send_ack)(struct sock___4 *, struct sk_buff___7 *, struct request_sock___2 *);
	void (*send_reset)(struct sock___4 *, struct sk_buff___7 *);
	void (*destructor)(struct request_sock___2 *);
	void (*syn_ack_timeout)(struct sock___4 *, struct request_sock___2 *);
};

struct timewait_sock_ops___2 {
	struct kmem_cache___45 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___4 *, struct sock___4 *, void *);
	void (*twsk_destructor)(struct sock___4 *);
};

struct ifmcaddr6___2 {
	struct in6_addr mca_addr;
	struct inet6_dev___3 *idev;
	struct ifmcaddr6___2 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___2 {
	struct in6_addr aca_addr;
	struct inet6_dev___3 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___2 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct acpi_hotplug_profile___11 {
	struct kobject___2 kobj;
	int (*scan_dependent)(struct acpi_device___11 *);
	void (*notify_online)(struct acpi_device___11 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___11 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___11 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___11 *);
	void (*bind)(struct device___43 *);
	void (*unbind)(struct device___43 *);
	struct acpi_hotplug_profile___11 hotplug;
};

struct acpi_hotplug_context___11 {
	struct acpi_device___11 *self;
	int (*notify)(struct acpi_device___11 *, u32);
	void (*uevent)(struct acpi_device___11 *, u32);
	void (*fixup)(struct acpi_device___11 *);
};

typedef int (*acpi_op_add___11)(struct acpi_device___11 *);

typedef int (*acpi_op_remove___11)(struct acpi_device___11 *);

typedef void (*acpi_op_notify___11)(struct acpi_device___11 *, u32);

struct acpi_device_ops___11 {
	acpi_op_add___11 add;
	acpi_op_remove___11 remove;
	acpi_op_notify___11 notify;
};

struct acpi_driver___11 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___11 ops;
	struct device_driver___43 drv;
	struct module___36 *owner;
};

struct kprobe_insn_cache___11 {
	struct mutex___55 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct pipe_buf_operations___2;

struct pipe_buffer___2 {
	struct page___54 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___2 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___2 {
	int can_merge;
	void * (*map)(struct pipe_inode_info *, struct pipe_buffer___2 *, int);
	void (*unmap)(struct pipe_inode_info *, struct pipe_buffer___2 *, void *);
	int (*confirm)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	void (*release)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	int (*steal)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	void (*get)(struct pipe_inode_info *, struct pipe_buffer___2 *);
};

struct coredump_params___4 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___54 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

enum sched_tunable_scaling {
	SCHED_TUNABLESCALING_NONE = 0,
	SCHED_TUNABLESCALING_LOG = 1,
	SCHED_TUNABLESCALING_LINEAR = 2,
	SCHED_TUNABLESCALING_END = 3,
};

struct do_proc_dointvec_minmax_conv_param {
	int *min;
	int *max;
};

struct do_proc_dointvec_jiffies_minmax_conv_param {
	int *min;
	int *max;
};

typedef __u16 u_int16_t;

typedef __u32 u_int32_t;

typedef __u64 u_int64_t;

struct page___55;

typedef struct page___55 *pgtable_t___55;

struct address_space___55;

struct kmem_cache___46;

struct page___55 {
	long unsigned int flags;
	struct address_space___55 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___55 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___55 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___46 *slab_cache;
		struct page___55 *first_page;
	};
	long: 64;
};

struct thread_struct___24;

struct task_struct___56;

struct pv_cpu_ops___55 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___24 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___24 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___56 *);
	void (*end_context_switch)(struct task_struct___56 *);
};

struct perf_event___24;

struct thread_struct___24 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___24 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___25;

struct pid_link___25 {
	struct hlist_node node;
	struct pid___25 *pid;
};

struct mutex___56 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___56 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___52 {
	struct page___55 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___59;

struct nsproxy___26;

struct signal_struct___55;

struct css_set___28;

struct perf_event_context___24;

struct task_struct___56 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___56 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___59 *mm;
	struct mm_struct___59 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___56 *real_parent;
	struct task_struct___56 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___56 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___25 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___55 = 0,
		VTIME_USER___55 = 1,
		VTIME_SYS___55 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___24 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___26 *nsproxy;
	struct signal_struct___55 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___28 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___24 *perf_event_ctxp[2];
	struct mutex___56 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___52 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___59 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___59 *, struct mm_struct___59 *);
	void (*dup_mmap)(struct mm_struct___59 *, struct mm_struct___59 *);
	void (*exit_mmap)(struct mm_struct___59 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___59 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___59 *);
	void (*pgd_free)(struct mm_struct___59 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___59 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___59 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___59 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___59 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___59 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___59 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___59 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___59 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___59 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___59 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___59 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___56 lock;
	void *vdso;
} mm_context_t___56;

struct xol_area___55;

struct uprobes_state___55 {
	struct xol_area___55 *xol_area;
};

struct vm_area_struct___59;

struct file___55;

struct core_state___55;

struct mm_struct___59 {
	struct vm_area_struct___59 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___59 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___59 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___56 context;
	long unsigned int flags;
	struct core_state___55 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___56 *owner;
	struct file___55 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___55 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___24 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___56 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___56 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___56 *target;
};

struct perf_sample_data___5;

typedef void (*perf_overflow_handler_t___24)(struct perf_event___24 *, struct perf_sample_data___5 *, struct pt_regs *);

struct ftrace_ops___24;

typedef void (*ftrace_func_t___24)(long unsigned int, long unsigned int, struct ftrace_ops___24 *, struct pt_regs *);

struct ftrace_ops___24 {
	ftrace_func_t___24 func;
	struct ftrace_ops___24 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___56 regex_lock;
};

struct pmu___24;

struct fasync_struct___55;

struct pid_namespace___25;

struct ftrace_event_call___16;

struct perf_cgroup___24;

struct perf_event___24 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___24 *group_leader;
	struct pmu___24 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___24 hw;
	struct perf_event_context___24 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___56 child_mutex;
	struct list_head child_list;
	struct perf_event___24 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___56 *owner;
	struct mutex___56 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___55 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___24 *);
	struct callback_head callback_head;
	struct pid_namespace___25 *ns;
	u64 id;
	perf_overflow_handler_t___24 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___16 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___24 ftrace_ops;
	struct perf_cgroup___24 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct __sysctl_args {
	int *name;
	int nlen;
	void *oldval;
	size_t *oldlenp;
	void *newval;
	size_t newlen;
	long unsigned int __unused[4];
};

enum {
	CTL_KERN = 1,
	CTL_VM = 2,
	CTL_NET = 3,
	CTL_PROC = 4,
	CTL_FS = 5,
	CTL_DEBUG = 6,
	CTL_DEV = 7,
	CTL_BUS = 8,
	CTL_ABI = 9,
	CTL_CPU = 10,
	CTL_ARLAN = 254,
	CTL_S390DBF = 5677,
	CTL_SUNRPC = 7249,
	CTL_PM = 9899,
	CTL_FRV = 9898,
};

enum {
	KERN_OSTYPE = 1,
	KERN_OSRELEASE = 2,
	KERN_OSREV = 3,
	KERN_VERSION = 4,
	KERN_SECUREMASK = 5,
	KERN_PROF = 6,
	KERN_NODENAME = 7,
	KERN_DOMAINNAME = 8,
	KERN_PANIC = 15,
	KERN_REALROOTDEV = 16,
	KERN_SPARC_REBOOT = 21,
	KERN_CTLALTDEL = 22,
	KERN_PRINTK = 23,
	KERN_NAMETRANS = 24,
	KERN_PPC_HTABRECLAIM = 25,
	KERN_PPC_ZEROPAGED = 26,
	KERN_PPC_POWERSAVE_NAP = 27,
	KERN_MODPROBE = 28,
	KERN_SG_BIG_BUFF = 29,
	KERN_ACCT = 30,
	KERN_PPC_L2CR = 31,
	KERN_RTSIGNR = 32,
	KERN_RTSIGMAX = 33,
	KERN_SHMMAX = 34,
	KERN_MSGMAX = 35,
	KERN_MSGMNB = 36,
	KERN_MSGPOOL = 37,
	KERN_SYSRQ = 38,
	KERN_MAX_THREADS = 39,
	KERN_RANDOM = 40,
	KERN_SHMALL = 41,
	KERN_MSGMNI = 42,
	KERN_SEM = 43,
	KERN_SPARC_STOP_A = 44,
	KERN_SHMMNI = 45,
	KERN_OVERFLOWUID = 46,
	KERN_OVERFLOWGID = 47,
	KERN_SHMPATH = 48,
	KERN_HOTPLUG = 49,
	KERN_IEEE_EMULATION_WARNINGS = 50,
	KERN_S390_USER_DEBUG_LOGGING = 51,
	KERN_CORE_USES_PID = 52,
	KERN_TAINTED = 53,
	KERN_CADPID = 54,
	KERN_PIDMAX = 55,
	KERN_CORE_PATTERN = 56,
	KERN_PANIC_ON_OOPS = 57,
	KERN_HPPA_PWRSW = 58,
	KERN_HPPA_UNALIGNED = 59,
	KERN_PRINTK_RATELIMIT = 60,
	KERN_PRINTK_RATELIMIT_BURST = 61,
	KERN_PTY = 62,
	KERN_NGROUPS_MAX = 63,
	KERN_SPARC_SCONS_PWROFF = 64,
	KERN_HZ_TIMER = 65,
	KERN_UNKNOWN_NMI_PANIC = 66,
	KERN_BOOTLOADER_TYPE = 67,
	KERN_RANDOMIZE = 68,
	KERN_SETUID_DUMPABLE = 69,
	KERN_SPIN_RETRY = 70,
	KERN_ACPI_VIDEO_FLAGS = 71,
	KERN_IA64_UNALIGNED = 72,
	KERN_COMPAT_LOG = 73,
	KERN_MAX_LOCK_DEPTH = 74,
	KERN_NMI_WATCHDOG = 75,
	KERN_PANIC_ON_NMI = 76,
	KERN_PANIC_ON_WARN = 77,
};

struct ctl_table_header___7;

struct ctl_node___7 {
	struct rb_node node;
	struct ctl_table_header___7 *header;
};

struct ctl_table_root___7;

struct ctl_table_set___7;

struct ctl_dir___7;

struct ctl_table_header___7 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___7 *root;
	struct ctl_table_set___7 *set;
	struct ctl_dir___7 *parent;
	struct ctl_node___7 *node;
};

struct ctl_dir___7 {
	struct ctl_table_header___7 header;
	struct rb_root root;
};

struct ctl_table_set___7 {
	int (*is_seen)(struct ctl_table_set___7 *);
	struct ctl_dir___7 dir;
};

struct ctl_table_root___7 {
	struct ctl_table_set___7 default_set;
	struct ctl_table_set___7 * (*lookup)(struct ctl_table_root___7 *, struct nsproxy___26 *);
	int (*permissions)(struct ctl_table_header___7 *, struct ctl_table *);
};

struct nsproxy___26 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___25 *pid_ns;
	struct net___5 *net_ns;
};

struct ip_vs_stats_user {
	__u32 conns;
	__u32 inpkts;
	__u32 outpkts;
	__u64 inbytes;
	__u64 outbytes;
	__u32 cps;
	__u32 inpps;
	__u32 outpps;
	__u32 inbps;
	__u32 outbps;
};

struct xol_area___55 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___55 *page;
	long unsigned int vaddr;
};

struct kset___3;

struct kobj_type___3;

struct kobject___3 {
	const char *name;
	struct list_head entry;
	struct kobject___3 *parent;
	struct kset___3 *kset;
	struct kobj_type___3 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___46;

struct memcg_cache_params___46;

struct kmem_cache___46 {
	struct kmem_cache_cpu___46 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___46 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___56;

struct address_space_operations___55;

struct address_space___55 {
	struct inode___56 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___56 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___55 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___6;

struct dentry___56;

struct path___55 {
	struct vfsmount___6 *mnt;
	struct dentry___56 *dentry;
};

struct fown_struct___25 {
	rwlock_t lock;
	struct pid___25 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___55;

struct file___55 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___55 f_path;
	struct inode___56 *f_inode;
	const struct file_operations___55 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___25 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___55 *f_mapping;
	struct mutex___56 f_pos_lock;
};

struct vm_operations_struct___49;

struct vm_area_struct___59 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___59 *vm_next;
	struct vm_area_struct___59 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___59 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___49 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___55 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___46;

struct vm_operations_struct___49 {
	void (*open)(struct vm_area_struct___59 *);
	void (*close)(struct vm_area_struct___59 *);
	int (*fault)(struct vm_area_struct___59 *, struct vm_fault___46 *);
	int (*page_mkwrite)(struct vm_area_struct___59 *, struct vm_fault___46 *);
	int (*access)(struct vm_area_struct___59 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___59 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___59 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___59 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___59 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___55 {
	struct task_struct___56 *task;
	struct core_thread___55 *next;
};

struct core_state___55 {
	atomic_t nr_threads;
	struct core_thread___55 dumper;
	struct completion startup;
};

struct socket_wq___3 {
	wait_queue_head_t wait;
	struct fasync_struct___55 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___55 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___55 *fa_next;
	struct file___55 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___3;

struct socket___3 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___3 *wq;
	struct file___55 *file;
	struct sock___3 *sk;
	const struct proto_ops___3 *ops;
};

struct proto___3;

struct sock_common___3 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___3 *skc_prot;
	struct net___5 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_filter___4;

struct cg_proto___3;

struct sock___3 {
	struct sock_common___3 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___3 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___3 *head;
		struct sk_buff___3 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___4 *sk_filter;
	struct socket_wq___3 *sk_wq;
	struct sk_buff_head___3 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___2 *sk_rx_dst;
	struct dst_entry___2 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___3 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___3 sk_error_queue;
	struct proto___3 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___25 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___3 *sk_socket;
	void *sk_user_data;
	struct page_frag___52 sk_frag;
	struct sk_buff___3 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___3 *sk_cgrp;
	void (*sk_state_change)(struct sock___3 *);
	void (*sk_data_ready)(struct sock___3 *, int);
	void (*sk_write_space)(struct sock___3 *);
	void (*sk_error_report)(struct sock___3 *);
	int (*sk_backlog_rcv)(struct sock___3 *, struct sk_buff___3 *);
	void (*sk_destruct)(struct sock___3 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___33;

struct kiocb___4;

struct proto_ops___3 {
	int family;
	struct module *owner;
	int (*release)(struct socket___3 *);
	int (*bind)(struct socket___3 *, struct sockaddr *, int);
	int (*connect)(struct socket___3 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___3 *, struct socket___3 *);
	int (*accept)(struct socket___3 *, struct socket___3 *, int);
	int (*getname)(struct socket___3 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___55 *, struct socket___3 *, struct poll_table_struct___33 *);
	int (*ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___3 *, int);
	int (*shutdown)(struct socket___3 *, int);
	int (*setsockopt)(struct socket___3 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___3 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___3 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___3 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___4 *, struct socket___3 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___4 *, struct socket___3 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___55 *, struct socket___3 *, struct vm_area_struct___59 *);
	ssize_t (*sendpage)(struct socket___3 *, struct page___55 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___3 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___3 *, int);
		struct {
			void (*set_peek_off)(struct sock___3 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___33)(struct file___55 *, wait_queue_head_t *, struct poll_table_struct___33 *);

struct poll_table_struct___33 {
	poll_queue_proc___33 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___4(struct kiocb___4 *, struct io_event *);

struct kiocb___4 {
	atomic_t ki_users;
	struct file___55 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___4 *ki_cancel;
	void (*ki_dtor)(struct kiocb___4 *);
	union {
		void *user;
		struct task_struct___56 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___7 {
	struct ctl_table_header___7 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___7 {
	struct mutex___56 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___7 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___7 *ctl;
};

struct netns_ipv4___7 {
	struct ctl_table_header___7 *forw_hdr;
	struct ctl_table_header___7 *frags_hdr;
	struct ctl_table_header___7 *ipv4_hdr;
	struct ctl_table_header___7 *route_hdr;
	struct ctl_table_header___7 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___3 *fibnl;
	struct sock___3 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___7 {
	struct ctl_table_header___7 *hdr;
	struct ctl_table_header___7 *route_hdr;
	struct ctl_table_header___7 *icmp_hdr;
	struct ctl_table_header___7 *frags_hdr;
	struct ctl_table_header___7 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___3 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___3 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___4 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock___3 *, struct sk_buff___3 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock___3 *, struct sk_buff___3 *);
	int (*local_out)(struct sk_buff___3 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___3 *, const void *);
	struct kmem_cache___46 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___7 {
	struct netns_sysctl_ipv6___7 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___3 **icmp_sk;
	struct sock___3 *ndisc_sk;
	struct sock___3 *tcp_sk;
	struct sock___3 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___7 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___7 *sysctl_header;
	struct sock___3 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___3 {
	struct sock___3 *v4_ctl_sk;
	struct sock___3 *v6_ctl_sk;
};

struct netns_nf___7 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___7 *nf_log_dir_header;
};

struct nf_proto_net___7 {
	struct ctl_table_header___7 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___7 {
	struct nf_proto_net___7 pn;
	unsigned int timeout;
};

struct nf_tcp_net___7 {
	struct nf_proto_net___7 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___7 {
	struct nf_proto_net___7 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___7 {
	struct nf_proto_net___7 pn;
	unsigned int timeout;
};

struct nf_ip_net___7 {
	struct nf_generic_net___7 generic;
	struct nf_tcp_net___7 tcp;
	struct nf_udp_net___7 udp;
	struct nf_icmp_net___7 icmp;
	struct nf_icmp_net___7 icmpv6;
};

struct netns_ct___7 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___7 *sysctl_header;
	struct ctl_table_header___7 *acct_sysctl_header;
	struct ctl_table_header___7 *tstamp_sysctl_header;
	struct ctl_table_header___7 *event_sysctl_header;
	struct ctl_table_header___7 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___46 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___7 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___7 {
	struct netns_sysctl_ipv6___7 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___7 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___3 *nlsk;
	struct sock___3 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___7 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 xfrm4_dst_ops;
	struct dst_ops___3 xfrm6_dst_ops;
};

struct net___5 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___7 sysctls;
	struct sock___3 *rtnl;
	struct sock___3 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___4 *loopback_dev;
	struct netns_core___7 core;
	struct netns_mib mib;
	struct netns_packet___7 packet;
	struct netns_unix___7 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___7 ipv4;
	struct netns_ipv6___7 ipv6;
	struct netns_sctp___7 sctp;
	struct netns_dccp___3 dccp;
	struct netns_nf___7 nf;
	struct netns_xt xt;
	struct netns_ct___7 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___7 nf_frag;
	struct sock___3 *nfnl;
	struct sock___3 *nfnl_stash;
	struct sk_buff_head___3 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___7 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___3 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___3 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___56 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___56 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___55;

struct lruvec___55 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___55 *zone;
};

struct pglist_data___55;

struct zone___55 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___55 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___55 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___55 {
	struct zone___55 *zone;
	int zone_idx;
};

struct zonelist___55 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___55 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___55 {
	struct zone___55 node_zones[4];
	struct zonelist___55 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___56 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___39;

struct x86_io_apic_ops___39 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___39 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___39;

struct irq_data___39 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___39 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___44;

struct dev_pm_ops___44 {
	int (*prepare)(struct device___44 *);
	void (*complete)(struct device___44 *);
	int (*suspend)(struct device___44 *);
	int (*resume)(struct device___44 *);
	int (*freeze)(struct device___44 *);
	int (*thaw)(struct device___44 *);
	int (*poweroff)(struct device___44 *);
	int (*restore)(struct device___44 *);
	int (*suspend_late)(struct device___44 *);
	int (*resume_early)(struct device___44 *);
	int (*freeze_late)(struct device___44 *);
	int (*thaw_early)(struct device___44 *);
	int (*poweroff_late)(struct device___44 *);
	int (*restore_early)(struct device___44 *);
	int (*suspend_noirq)(struct device___44 *);
	int (*resume_noirq)(struct device___44 *);
	int (*freeze_noirq)(struct device___44 *);
	int (*thaw_noirq)(struct device___44 *);
	int (*poweroff_noirq)(struct device___44 *);
	int (*restore_noirq)(struct device___44 *);
	int (*runtime_suspend)(struct device___44 *);
	int (*runtime_resume)(struct device___44 *);
	int (*runtime_idle)(struct device___44 *);
};

struct dev_pm_qos___5;

struct dev_pm_info___5 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___5 *qos;
};

struct dma_map_ops___23;

struct dev_archdata___23 {
	struct dma_map_ops___23 *dma_ops;
	void *iommu;
};

struct acpi_dev_node___16 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
};

struct device_type___44;

struct bus_type___44;

struct device_driver___44;

struct dev_pm_domain___44;

struct class___44;

struct attribute_group___39;

struct device_rh___44;

struct device___44 {
	struct device___44 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___44 *type;
	struct mutex___56 mutex;
	struct bus_type___44 *bus;
	struct device_driver___44 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___44 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___23 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___44 *class;
	const struct attribute_group___39 **groups;
	void (*release)(struct device___44 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___44 *device_rh;
};

struct dev_pm_qos_request___5;

struct dev_pm_qos___5 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___5 *latency_req;
	struct dev_pm_qos_request___5 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___5 *latency_tolerance_req;
};

struct dev_pm_info_rh___44 {
	void (*set_latency_tolerance)(struct device___44 *, s32);
};

struct dev_pm_domain___44 {
	struct dev_pm_ops___44 ops;
};

struct smp_ops___55 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___56 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___3 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___3 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___39;

struct attribute_group___39 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___39 **bin_attrs;
};

struct bin_attribute___39 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___55 *, struct kobject___3 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___55 *, struct kobject___3 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	int (*mmap)(struct file___55 *, struct kobject___3 *, struct bin_attribute___39 *, struct vm_area_struct___59 *);
};

struct sysfs_ops___3 {
	ssize_t (*show)(struct kobject___3 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___3 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___3 *, const struct attribute *);
};

struct kset_uevent_ops___3;

struct kset___3 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___3 kobj;
	const struct kset_uevent_ops___3 *uevent_ops;
};

struct kobj_type___3 {
	void (*release)(struct kobject___3 *);
	const struct sysfs_ops___3 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___3 *);
	const void * (*namespace)(struct kobject___3 *);
};

struct kset_uevent_ops___3 {
	int (* const filter)(struct kset___3 *, struct kobject___3 *);
	const char * (* const name)(struct kset___3 *, struct kobject___3 *);
	int (* const uevent)(struct kset___3 *, struct kobject___3 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___46 {
	void **freelist;
	long unsigned int tid;
	struct page___55 *page;
	struct page___55 *partial;
};

struct memcg_cache_params___46 {
	bool is_root_cache;
	union {
		struct kmem_cache___46 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___46 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___23 {
	void * (*alloc)(struct device___44 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___44 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___44 *, struct vm_area_struct___59 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___44 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___44 *, struct page___55 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___44 *, dma_addr_t);
	int (*dma_supported)(struct device___44 *, u64);
	int (*set_dma_mask)(struct device___44 *, u64);
	int is_phys;
};

struct bus_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___44 *, char *);
	ssize_t (*store)(struct bus_type___44 *, const char *, size_t);
};

struct device_attribute___44;

struct driver_attribute___44;

struct bus_type___44 {
	const char *name;
	const char *dev_name;
	struct device___44 *dev_root;
	struct bus_attribute___44 *bus_attrs;
	struct device_attribute___44 *dev_attrs;
	struct driver_attribute___44 *drv_attrs;
	const struct attribute_group___39 **bus_groups;
	const struct attribute_group___39 **dev_groups;
	const struct attribute_group___39 **drv_groups;
	int (*match)(struct device___44 *, struct device_driver___44 *);
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	int (*probe)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*online)(struct device___44 *);
	int (*offline)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct device___44 *, struct device_attribute___44 *, char *);
	ssize_t (*store)(struct device___44 *, struct device_attribute___44 *, const char *, size_t);
};

struct driver_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___44 *, char *);
	ssize_t (*store)(struct device_driver___44 *, const char *, size_t);
};

struct device_driver___44 {
	const char *name;
	struct bus_type___44 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct attribute_group___39 **groups;
	const struct dev_pm_ops___44 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___44 {
	const char *name;
	const struct attribute_group___39 **groups;
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
};

struct class_attribute___44;

struct class___44 {
	const char *name;
	struct module *owner;
	struct class_attribute___44 *class_attrs;
	struct device_attribute___44 *dev_attrs;
	const struct attribute_group___39 **dev_groups;
	struct bin_attribute___39 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *);
	void (*class_release)(struct class___44 *);
	void (*dev_release)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	struct subsys_private *p;
};

struct class_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct class___44 *, struct class_attribute___44 *, char *);
	ssize_t (*store)(struct class___44 *, struct class_attribute___44 *, const char *, size_t);
	const void * (*namespace)(struct class___44 *, const struct class_attribute___44 *);
};

struct device_rh___44 {
	struct dev_pm_info_rh___44 power;
};

struct vm_fault___46 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___55 *page;
};

struct upid___25 {
	int nr;
	struct pid_namespace___25 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___25 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___56 *child_reaper;
	struct kmem_cache___46 *pid_cachep;
	unsigned int level;
	struct pid_namespace___25 *parent;
	struct vfsmount___6 *proc_mnt;
	struct dentry___56 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___25 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___25 numbers[1];
};

struct signal_struct___55 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___56 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___56 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___25 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___25 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___56 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___28;

struct css_set___28 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___28 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___24 {
	struct pmu___24 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___56 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___56 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___24 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct nf_bridge_info___4 {
	atomic_t use;
	unsigned int mask;
	struct net_device___4 *physindev;
	struct net_device___4 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___4(struct sk_buff___3 **);

struct net_device_ops___4;

struct ethtool_ops___4;

struct header_ops___4;

struct netdev_rx_queue___4;

struct netdev_queue___4;

struct dcbnl_rtnl_ops___4;

struct net_device___4 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___4 *netdev_ops;
	const struct ethtool_ops___4 *ethtool_ops;
	const struct header_ops___4 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___3 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___4 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___4 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___4 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___4 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___4 = 0,
		NETREG_REGISTERED___4 = 1,
		NETREG_UNREGISTERING___4 = 2,
		NETREG_UNREGISTERED___4 = 3,
		NETREG_RELEASED___4 = 4,
		NETREG_DUMMY___4 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___4 = 0,
		RTNL_LINK_INITIALIZING___4 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___4 *);
	struct netpoll_info *npinfo;
	struct net___5 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___44 dev;
	const struct attribute_group___39 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___4 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___3 {
	struct sk_buff___3 *next;
	struct sk_buff___3 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___3 *sk;
	struct net_device___4 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___3 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___4 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct in_addr {
	__be32 s_addr;
};

enum nf_inet_hooks {
	NF_INET_PRE_ROUTING = 0,
	NF_INET_LOCAL_IN = 1,
	NF_INET_FORWARD = 2,
	NF_INET_LOCAL_OUT = 3,
	NF_INET_POST_ROUTING = 4,
	NF_INET_NUMHOOKS = 5,
};

union nf_inet_addr {
	__u32 all[4];
	__be32 ip;
	__be32 ip6[4];
	struct in_addr in;
	struct in6_addr in6;
};

struct nf_afinfo___7 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___3 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___3 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___5 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___3 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___3 *, const struct nf_queue_entry *);
	int route_key_size;
};

union nf_conntrack_man_proto {
	__be16 all;
	struct {
		__be16 port;
	} tcp;
	struct {
		__be16 port;
	} udp;
	struct {
		__be16 id;
	} icmp;
	struct {
		__be16 port;
	} dccp;
	struct {
		__be16 port;
	} sctp;
	struct {
		__be16 key;
	} gre;
};

struct nf_conntrack_man {
	union nf_inet_addr u3;
	union nf_conntrack_man_proto u;
	u_int16_t l3num;
};

struct nf_conntrack_tuple {
	struct nf_conntrack_man src;
	struct {
		union nf_inet_addr u3;
		union {
			__be16 all;
			struct {
				__be16 port;
			} tcp;
			struct {
				__be16 port;
			} udp;
			struct {
				u_int8_t type;
				u_int8_t code;
			} icmp;
			struct {
				__be16 port;
			} dccp;
			struct {
				__be16 port;
			} sctp;
			struct {
				__be16 key;
			} gre;
		} u;
		u_int8_t protonum;
		u_int8_t dir;
	} dst;
};

struct nf_conntrack_tuple_hash {
	struct hlist_nulls_node hnnode;
	struct nf_conntrack_tuple tuple;
};

struct nf_ct_ext;

struct nf_ct_dccp {
	u_int8_t role[2];
	u_int8_t state;
	u_int8_t last_pkt;
	u_int8_t last_dir;
	u_int64_t handshake_seq;
};

enum sctp_conntrack {
	SCTP_CONNTRACK_NONE = 0,
	SCTP_CONNTRACK_CLOSED = 1,
	SCTP_CONNTRACK_COOKIE_WAIT = 2,
	SCTP_CONNTRACK_COOKIE_ECHOED = 3,
	SCTP_CONNTRACK_ESTABLISHED = 4,
	SCTP_CONNTRACK_SHUTDOWN_SENT = 5,
	SCTP_CONNTRACK_SHUTDOWN_RECD = 6,
	SCTP_CONNTRACK_SHUTDOWN_ACK_SENT = 7,
	SCTP_CONNTRACK_HEARTBEAT_SENT = 8,
	SCTP_CONNTRACK_HEARTBEAT_ACKED = 9,
	SCTP_CONNTRACK_MAX = 10,
};

struct ip_ct_sctp {
	enum sctp_conntrack state;
	__be32 vtag[2];
};

struct ip_ct_tcp_state {
	u_int32_t td_end;
	u_int32_t td_maxend;
	u_int32_t td_maxwin;
	u_int32_t td_maxack;
	u_int8_t td_scale;
	u_int8_t flags;
};

struct ip_ct_tcp {
	struct ip_ct_tcp_state seen[2];
	u_int8_t state;
	u_int8_t last_dir;
	u_int8_t retrans;
	u_int8_t last_index;
	u_int32_t last_seq;
	u_int32_t last_ack;
	u_int32_t last_end;
	u_int16_t last_win;
	u_int8_t last_wscale;
	u_int8_t last_flags;
};

struct nf_ct_gre {
	unsigned int stream_timeout;
	unsigned int timeout;
};

union nf_conntrack_proto {
	struct nf_ct_dccp dccp;
	struct ip_ct_sctp sctp;
	struct ip_ct_tcp tcp;
	struct nf_ct_gre gre;
};

struct nf_conn {
	struct nf_conntrack ct_general;
	spinlock_t lock;
	u16 cpu;
	struct nf_conntrack_tuple_hash tuplehash[2];
	long unsigned int status;
	struct nf_conn *master;
	struct timer_list timeout;
	u_int32_t mark;
	u_int32_t secmark;
	struct nf_ct_ext *ext;
	struct net___5 *ct_net;
	union nf_conntrack_proto proto;
};

struct iphdr {
	__u8 ihl: 4;
	__u8 version: 4;
	__u8 tos;
	__be16 tot_len;
	__be16 id;
	__be16 frag_off;
	__u8 ttl;
	__u8 protocol;
	__sum16 check;
	__be32 saddr;
	__be32 daddr;
};

struct file_lock___55;

struct seq_file___39;

struct file_operations___55 {
	struct module *owner;
	loff_t (*llseek)(struct file___55 *, loff_t, int);
	ssize_t (*read)(struct file___55 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___55 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___4 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___4 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___55 *, void *, filldir_t);
	unsigned int (*poll)(struct file___55 *, struct poll_table_struct___33 *);
	long int (*unlocked_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___55 *, struct vm_area_struct___59 *);
	int (*open)(struct inode___56 *, struct file___55 *);
	int (*flush)(struct file___55 *, fl_owner_t);
	int (*release)(struct inode___56 *, struct file___55 *);
	int (*fsync)(struct file___55 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___4 *, int);
	int (*fasync)(int, struct file___55 *, int);
	int (*lock)(struct file___55 *, int, struct file_lock___55 *);
	ssize_t (*sendpage)(struct file___55 *, struct page___55 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___55 *, int, struct file_lock___55 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___55 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___55 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___55 *, long int, struct file_lock___55 **, void **);
		struct {
			int (*setlease)(struct file___55 *, long int, struct file_lock___55 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___55 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___39 *, struct file___55 *);
};

struct dev_pm_qos_request___5 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___44 *dev;
};

struct dentry_operations___55;

struct super_block___56;

struct dentry___56 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___56 *d_parent;
	struct qstr d_name;
	struct inode___56 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___55 *d_op;
	struct super_block___56 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___55;

struct dquot___55;

struct block_device___55;

struct inode___56 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___55 *i_op;
	struct super_block___56 *i_sb;
	struct address_space___55 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___56 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___55 *i_fop;
	struct file_lock___55 *i_flock;
	struct address_space___55 i_data;
	struct dquot___55 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___55 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___55 {
	int (*d_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_hash)(const struct dentry___56 *, struct qstr *);
	int (*d_compare)(const struct dentry___56 *, const struct dentry___56 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___56 *);
	void (*d_release)(struct dentry___56 *);
	void (*d_prune)(struct dentry___56 *);
	void (*d_iput)(struct dentry___56 *, struct inode___56 *);
	char * (*d_dname)(struct dentry___56 *, char *, int);
	struct vfsmount___6 * (*d_automount)(struct path___55 *);
	int (*d_manage)(struct dentry___56 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___55;

struct mem_dqinfo___55 {
	struct quota_format_type___55 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___55;

struct quota_info___55 {
	unsigned int flags;
	struct mutex___56 dqio_mutex;
	struct mutex___56 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___56 *files[2];
	struct mem_dqinfo___55 info[2];
	const struct quota_format_ops___55 *ops[2];
};

struct file_system_type___55;

struct super_operations___55;

struct dquot_operations___55;

struct quotactl_ops___55;

struct xattr_handler___28;

struct super_block___56 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___55 *s_type;
	const struct super_operations___55 *s_op;
	const struct dquot_operations___55 *dq_op;
	const struct quotactl_ops___55 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___56 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___28 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___55 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___55 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___56 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___55 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___6 {
	struct dentry___56 *mnt_root;
	struct super_block___56 *mnt_sb;
	int mnt_flags;
};

struct block_device___55 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___56 *bd_inode;
	struct super_block___56 *bd_super;
	struct mutex___56 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___55 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___56 bd_fsfreeze_mutex;
};

struct cgroup___28;

struct cgroup_subsys_state___28 {
	struct cgroup___28 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___56 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___55 *ia_file;
};

struct dquot___55 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___56 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___56 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___55 {
	int qf_fmt_id;
	const struct quota_format_ops___55 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___55 *qf_next;
};

struct quota_format_ops___55 {
	int (*check_quota_file)(struct super_block___56 *, int);
	int (*read_file_info)(struct super_block___56 *, int);
	int (*write_file_info)(struct super_block___56 *, int);
	int (*free_file_info)(struct super_block___56 *, int);
	int (*read_dqblk)(struct dquot___55 *);
	int (*commit_dqblk)(struct dquot___55 *);
	int (*release_dqblk)(struct dquot___55 *);
};

struct dquot_operations___55 {
	int (*write_dquot)(struct dquot___55 *);
	struct dquot___55 * (*alloc_dquot)(struct super_block___56 *, int);
	void (*destroy_dquot)(struct dquot___55 *);
	int (*acquire_dquot)(struct dquot___55 *);
	int (*release_dquot)(struct dquot___55 *);
	int (*mark_dirty)(struct dquot___55 *);
	int (*write_info)(struct super_block___56 *, int);
	qsize_t * (*get_reserved_space)(struct inode___56 *);
};

struct quotactl_ops___55 {
	int (*quota_on)(struct super_block___56 *, int, int, struct path___55 *);
	int (*quota_on_meta)(struct super_block___56 *, int, int);
	int (*quota_off)(struct super_block___56 *, int);
	int (*quota_sync)(struct super_block___56 *, int);
	int (*get_info)(struct super_block___56 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___56 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___56 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___56 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___56 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___56 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___56 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___56 *, unsigned int);
};

struct address_space_operations___55 {
	int (*writepage)(struct page___55 *, struct writeback_control *);
	int (*readpage)(struct file___55 *, struct page___55 *);
	int (*writepages)(struct address_space___55 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___55 *);
	int (*readpages)(struct file___55 *, struct address_space___55 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___55 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___55 **, void **);
	int (*write_end)(struct file___55 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___55 *, void *);
	sector_t (*bmap)(struct address_space___55 *, sector_t);
	void (*invalidatepage)(struct page___55 *, long unsigned int);
	int (*releasepage)(struct page___55 *, gfp_t);
	void (*freepage)(struct page___55 *);
	ssize_t (*direct_IO)(int, struct kiocb___4 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___55 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___55 *, struct page___55 *, struct page___55 *, enum migrate_mode);
	int (*launder_page)(struct page___55 *);
	int (*is_partially_uptodate)(struct page___55 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___55 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___55 *, struct page___55 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___55 *, sector_t *);
	void (*swap_deactivate)(struct file___55 *);
	void (*invalidatepage_range)(struct page___55 *, unsigned int, unsigned int);
};

struct nameidata___2;

struct inode_operations___55 {
	struct dentry___56 * (*lookup)(struct inode___56 *, struct dentry___56 *, unsigned int);
	void * (*follow_link)(struct dentry___56 *, struct nameidata___2 *);
	int (*permission)(struct inode___56 *, int);
	struct posix_acl * (*get_acl)(struct inode___56 *, int);
	int (*readlink)(struct dentry___56 *, char *, int);
	void (*put_link)(struct dentry___56 *, struct nameidata___2 *, void *);
	int (*create)(struct inode___56 *, struct dentry___56 *, umode_t, bool);
	int (*link)(struct dentry___56 *, struct inode___56 *, struct dentry___56 *);
	int (*unlink)(struct inode___56 *, struct dentry___56 *);
	int (*symlink)(struct inode___56 *, struct dentry___56 *, const char *);
	int (*mkdir)(struct inode___56 *, struct dentry___56 *, umode_t);
	int (*rmdir)(struct inode___56 *, struct dentry___56 *);
	int (*mknod)(struct inode___56 *, struct dentry___56 *, umode_t, dev_t);
	int (*rename)(struct inode___56 *, struct dentry___56 *, struct inode___56 *, struct dentry___56 *);
	int (*setattr)(struct dentry___56 *, struct iattr___56 *);
	int (*getattr)(struct vfsmount___6 *, struct dentry___56 *, struct kstat *);
	int (*setxattr)(struct dentry___56 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___56 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___56 *, char *, size_t);
	int (*removexattr)(struct dentry___56 *, const char *);
	int (*fiemap)(struct inode___56 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___56 *, struct timespec *, int);
	int (*atomic_open)(struct inode___56 *, struct dentry___56 *, struct file___55 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___55;

struct lock_manager_operations___55;

struct file_lock___55 {
	struct file_lock___55 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___25 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___55 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___55 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___55 *fl_ops;
	const struct lock_manager_operations___55 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___55 {
	void (*fl_copy_lock)(struct file_lock___55 *, struct file_lock___55 *);
	void (*fl_release_private)(struct file_lock___55 *);
};

struct lock_manager_operations___55 {
	int (*lm_compare_owner)(struct file_lock___55 *, struct file_lock___55 *);
	long unsigned int (*lm_owner_key)(struct file_lock___55 *);
	void (*lm_notify)(struct file_lock___55 *);
	int (*lm_grant)(struct file_lock___55 *, struct file_lock___55 *, int);
	void (*lm_break)(struct file_lock___55 *);
	int (*lm_change)(struct file_lock___55 **, int);
};

struct file_system_type___55 {
	const char *name;
	int fs_flags;
	struct dentry___56 * (*mount)(struct file_system_type___55 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___56 *);
	struct module *owner;
	struct file_system_type___55 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___55 {
	struct inode___56 * (*alloc_inode)(struct super_block___56 *);
	void (*destroy_inode)(struct inode___56 *);
	void (*dirty_inode)(struct inode___56 *, int);
	int (*write_inode)(struct inode___56 *, struct writeback_control *);
	int (*drop_inode)(struct inode___56 *);
	void (*evict_inode)(struct inode___56 *);
	void (*put_super)(struct super_block___56 *);
	int (*sync_fs)(struct super_block___56 *, int);
	int (*freeze_fs)(struct super_block___56 *);
	int (*unfreeze_fs)(struct super_block___56 *);
	int (*statfs)(struct dentry___56 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___56 *, int *, char *);
	void (*umount_begin)(struct super_block___56 *);
	int (*show_options)(struct seq_file___39 *, struct dentry___56 *);
	int (*show_devname)(struct seq_file___39 *, struct dentry___56 *);
	int (*show_path)(struct seq_file___39 *, struct dentry___56 *);
	int (*show_stats)(struct seq_file___39 *, struct dentry___56 *);
	ssize_t (*quota_read)(struct super_block___56 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___56 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___56 *);
	int (*bdev_try_to_free_page)(struct super_block___56 *, struct page___55 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___56 *);
	void (*free_cached_objects)(struct super_block___56 *, int);
};

struct xattr_handler___28 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___56 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___56 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___56 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___38;

struct seq_file___39 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___56 lock;
	const struct seq_operations___38 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___2 {
	struct path___55 path;
	struct qstr last;
	struct path___55 root;
	struct inode___56 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct ethtool_ops___4 {
	int (*get_settings)(struct net_device___4 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___4 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___4 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___4 *);
	void (*get_regs)(struct net_device___4 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___4 *);
	void (*set_msglevel)(struct net_device___4 *, u32);
	int (*nway_reset)(struct net_device___4 *);
	u32 (*get_link)(struct net_device___4 *);
	int (*get_eeprom_len)(struct net_device___4 *);
	int (*get_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___4 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___4 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___4 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___4 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___4 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___4 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___4 *);
	void (*complete)(struct net_device___4 *);
	u32 (*get_priv_flags)(struct net_device___4 *);
	int (*set_priv_flags)(struct net_device___4 *, u32);
	int (*get_sset_count)(struct net_device___4 *, int);
	int (*get_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___4 *, struct ethtool_flash *);
	int (*reset)(struct net_device___4 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___4 *);
	int (*get_rxfh_indir)(struct net_device___4 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___4 *, const u32 *);
	void (*get_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___4 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___4 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___4 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___4 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___4 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___4 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___4 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___4 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct xt_table_info;

struct xt_table {
	struct list_head list;
	unsigned int valid_hooks;
	struct xt_table_info *private;
	struct module *me;
	u_int8_t af;
	int priority;
	char name[32];
};

struct ip_conntrack_stat {
	unsigned int searched;
	unsigned int found;
	unsigned int new;
	unsigned int invalid;
	unsigned int ignore;
	unsigned int delete;
	unsigned int delete_list;
	unsigned int insert;
	unsigned int insert_failed;
	unsigned int drop;
	unsigned int early_drop;
	unsigned int error;
	unsigned int expect_new;
	unsigned int expect_create;
	unsigned int expect_delete;
	unsigned int search_restart;
};

struct irq_chip___39 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___39 *);
	void (*irq_shutdown)(struct irq_data___39 *);
	void (*irq_enable)(struct irq_data___39 *);
	void (*irq_disable)(struct irq_data___39 *);
	void (*irq_ack)(struct irq_data___39 *);
	void (*irq_mask)(struct irq_data___39 *);
	void (*irq_mask_ack)(struct irq_data___39 *);
	void (*irq_unmask)(struct irq_data___39 *);
	void (*irq_eoi)(struct irq_data___39 *);
	int (*irq_set_affinity)(struct irq_data___39 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___39 *);
	int (*irq_set_type)(struct irq_data___39 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___39 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___39 *);
	void (*irq_bus_sync_unlock)(struct irq_data___39 *);
	void (*irq_cpu_online)(struct irq_data___39 *);
	void (*irq_cpu_offline)(struct irq_data___39 *);
	void (*irq_suspend)(struct irq_data___39 *);
	void (*irq_resume)(struct irq_data___39 *);
	void (*irq_pm_shutdown)(struct irq_data___39 *);
	void (*irq_print_chip)(struct irq_data___39 *, struct seq_file___39 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___39 *, void *);
	long unsigned int flags;
};

struct ip_vs_estimator {
	struct list_head list;
	u64 last_inbytes;
	u64 last_outbytes;
	u32 last_conns;
	u32 last_inpkts;
	u32 last_outpkts;
	u32 cps;
	u32 inpps;
	u32 outpps;
	u32 inbps;
	u32 outbps;
};

struct ip_vs_cpu_stats;

struct ip_vs_stats {
	struct ip_vs_stats_user ustats;
	struct ip_vs_estimator est;
	struct ip_vs_cpu_stats *cpustats;
	spinlock_t lock;
	struct ip_vs_stats_user ustats0;
};

struct ip_vs_proto_data;

struct ipvs_master_sync_state;

struct netns_ipvs {
	int gen;
	int enable;
	struct hlist_head rs_table[16];
	struct list_head app_list;
	struct ip_vs_proto_data *proto_data_table[32];
	struct list_head tcp_apps[16];
	struct list_head udp_apps[16];
	struct list_head sctp_apps[16];
	atomic_t conn_count;
	struct ip_vs_stats tot_stats;
	int num_services;
	struct list_head dest_trash;
	spinlock_t dest_trash_lock;
	struct timer_list dest_trash_timer;
	atomic_t ftpsvc_counter;
	atomic_t nullsvc_counter;
	struct delayed_work defense_work;
	int drop_rate;
	int drop_counter;
	atomic_t dropentry;
	spinlock_t dropentry_lock;
	spinlock_t droppacket_lock;
	spinlock_t securetcp_lock;
	struct ctl_table_header___7 *sysctl_hdr;
	struct ctl_table *sysctl_tbl;
	int sysctl_amemthresh;
	int sysctl_am_droprate;
	int sysctl_drop_entry;
	int sysctl_drop_packet;
	int sysctl_secure_tcp;
	int sysctl_conntrack;
	int sysctl_snat_reroute;
	int sysctl_sync_ver;
	int sysctl_sync_ports;
	int sysctl_sync_qlen_max;
	int sysctl_sync_sock_size;
	int sysctl_cache_bypass;
	int sysctl_expire_nodest_conn;
	int sysctl_expire_quiescent_template;
	int sysctl_sync_threshold[2];
	unsigned int sysctl_sync_refresh_period;
	int sysctl_sync_retries;
	int sysctl_nat_icmp_send;
	int sysctl_pmtu_disc;
	int sysctl_backup_only;
	int sysctl_conn_reuse_mode;
	int sysctl_lblc_expiration;
	struct ctl_table_header___7 *lblc_ctl_header;
	struct ctl_table *lblc_ctl_table;
	int sysctl_lblcr_expiration;
	struct ctl_table_header___7 *lblcr_ctl_header;
	struct ctl_table *lblcr_ctl_table;
	struct list_head est_list;
	spinlock_t est_lock;
	struct timer_list est_timer;
	spinlock_t sync_lock;
	struct ipvs_master_sync_state *ms;
	spinlock_t sync_buff_lock;
	struct task_struct___56 **backup_threads;
	int threads_mask;
	int send_mesg_maxlen;
	int recv_mesg_maxlen;
	volatile int sync_state;
	volatile int master_syncid;
	volatile int backup_syncid;
	struct mutex___56 sync_mutex;
	char master_mcast_ifn[16];
	char backup_mcast_ifn[16];
	struct net___5 *net;
};

struct seq_operations___38 {
	void * (*start)(struct seq_file___39 *, loff_t *);
	void (*stop)(struct seq_file___39 *, void *);
	void * (*next)(struct seq_file___39 *, void *, loff_t *);
	int (*show)(struct seq_file___39 *, void *);
};

struct dcbnl_rtnl_ops___4 {
	int (*ieee_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___4 *);
	u8 (*setstate)(struct net_device___4 *, u8);
	void (*getpermhwaddr)(struct net_device___4 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___4 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___4 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___4 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___4 *, int, u8 *);
	void (*setpfccfg)(struct net_device___4 *, int, u8);
	void (*getpfccfg)(struct net_device___4 *, int, u8 *);
	u8 (*setall)(struct net_device___4 *);
	u8 (*getcap)(struct net_device___4 *, int, u8 *);
	int (*getnumtcs)(struct net_device___4 *, int, u8 *);
	int (*setnumtcs)(struct net_device___4 *, int, u8);
	u8 (*getpfcstate)(struct net_device___4 *);
	void (*setpfcstate)(struct net_device___4 *, u8);
	void (*getbcncfg)(struct net_device___4 *, int, u32 *);
	void (*setbcncfg)(struct net_device___4 *, int, u32);
	void (*getbcnrp)(struct net_device___4 *, int, u8 *);
	void (*setbcnrp)(struct net_device___4 *, int, u8);
	u8 (*setapp)(struct net_device___4 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___4 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___4 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___4 *, int, u8);
	u8 (*getdcbx)(struct net_device___4 *);
	u8 (*setdcbx)(struct net_device___4 *, u8);
	int (*peer_getappinfo)(struct net_device___4 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___4 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___4 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___4 *, struct cee_pfc *);
};

struct cgroupfs_root___28;

struct cgroup___28 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___28 *parent;
	struct dentry___56 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___28 *subsys[11];
	struct cgroupfs_root___28 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___56 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___28 {
	struct super_block___56 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___28 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___9 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___56 *, struct file___55 *);
	ssize_t (*read)(struct cgroup___28 *, struct cftype___9 *, struct file___55 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___28 *, struct cftype___9 *);
	s64 (*read_s64)(struct cgroup___28 *, struct cftype___9 *);
	int (*read_map)(struct cgroup___28 *, struct cftype___9 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___28 *, struct cftype___9 *, struct seq_file___39 *);
	ssize_t (*write)(struct cgroup___28 *, struct cftype___9 *, struct file___55 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___28 *, struct cftype___9 *, u64);
	int (*write_s64)(struct cgroup___28 *, struct cftype___9 *, s64);
	int (*write_string)(struct cgroup___28 *, struct cftype___9 *, const char *);
	int (*trigger)(struct cgroup___28 *, unsigned int);
	int (*release)(struct inode___56 *, struct file___55 *);
	int (*register_event)(struct cgroup___28 *, struct cftype___9 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___28 *, struct cftype___9 *, struct eventfd_ctx *);
};

struct cftype_set___8 {
	struct list_head node;
	struct cftype___9 *cfts;
};

struct task_and_cgroup___8 {
	struct task_struct___56 *task;
	struct cgroup___28 *cgrp;
	struct css_set___28 *cg;
};

struct cgroup_taskset___8 {
	struct task_and_cgroup___8 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___28 *cur_cgrp;
};

struct cgroup_subsys___8 {
	struct cgroup_subsys_state___28 * (*css_alloc)(struct cgroup___28 *);
	int (*css_online)(struct cgroup___28 *);
	void (*css_offline)(struct cgroup___28 *);
	void (*css_free)(struct cgroup___28 *);
	int (*can_attach)(struct cgroup___28 *, struct cgroup_taskset___8 *);
	void (*cancel_attach)(struct cgroup___28 *, struct cgroup_taskset___8 *);
	void (*attach)(struct cgroup___28 *, struct cgroup_taskset___8 *);
	void (*fork)(struct task_struct___56 *);
	void (*exit)(struct cgroup___28 *, struct cgroup___28 *, struct task_struct___56 *);
	void (*bind)(struct cgroup___28 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___28 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___9 *base_cftypes;
	struct cftype_set___8 base_cftset;
	struct module *module;
};

struct request_sock_ops___3;

struct request_sock___3 {
	struct sock_common___3 __req_common;
	struct request_sock___3 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___3 *rsk_ops;
	struct sock___3 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___4 {
	struct sk_buff___3 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___3 *, struct netlink_callback___4 *);
	int (*done)(struct netlink_callback___4 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___4 {
	int (*create)(struct sk_buff___3 *, struct net_device___4 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___3 *, unsigned char *);
	int (*rebuild)(struct sk_buff___3 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___4 *, const unsigned char *);
};

struct napi_struct___4 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___4 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___4 *dev;
	struct sk_buff___3 *gro_list;
	struct sk_buff___3 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___4 {
	struct net_device___4 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___3 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___4 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___3 kobj;
	struct net_device___4 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___4 {
	int (*ndo_init)(struct net_device___4 *);
	void (*ndo_uninit)(struct net_device___4 *);
	int (*ndo_open)(struct net_device___4 *);
	int (*ndo_stop)(struct net_device___4 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___3 *, struct net_device___4 *);
	u16 (*ndo_select_queue)(struct net_device___4 *, struct sk_buff___3 *);
	void (*ndo_change_rx_flags)(struct net_device___4 *, int);
	void (*ndo_set_rx_mode)(struct net_device___4 *);
	int (*ndo_set_mac_address)(struct net_device___4 *, void *);
	int (*ndo_validate_addr)(struct net_device___4 *);
	int (*ndo_do_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___4 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___4 *, int);
	int (*ndo_neigh_setup)(struct net_device___4 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___4 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___4 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___4 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___4 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___4 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___4 *);
	int (*ndo_netpoll_setup)(struct net_device___4 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___4 *);
	int (*ndo_busy_poll)(struct napi_struct___4 *);
	int (*ndo_set_vf_mac)(struct net_device___4 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___4 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___4 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___4 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___4 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___4 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___4 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___4 *, int, struct sk_buff___3 *);
	int (*ndo_setup_tc)(struct net_device___4 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___4 *);
	int (*ndo_fcoe_disable)(struct net_device___4 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___4 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___4 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___4 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___4 *, const struct sk_buff___3 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___4 *, struct net_device___4 *);
	int (*ndo_del_slave)(struct net_device___4 *, struct net_device___4 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___3 *, struct netlink_callback___4 *, struct net_device___4 *, int);
	int (*ndo_bridge_setlink)(struct net_device___4 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___3 *, u32, u32, struct net_device___4 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___4 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___4 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___4 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___4 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___4 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___4 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___3 *, struct net_device___4 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___4 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___4 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___4 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___2 {
	struct net___5 *net;
	struct net_device___4 *dev;
	struct neigh_parms___2 *next;
	int (*neigh_setup)(struct neighbour___2 *);
	void (*neigh_cleanup)(struct neighbour___2 *);
	struct neigh_table___2 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___3;

struct ifacaddr6___3;

struct inet6_dev___2 {
	struct net_device___4 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___3 *mc_list;
	struct ifmcaddr6___3 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___3 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___2 *nd_parms;
	struct inet6_dev___2 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct sk_filter___4 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___3 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___3;

struct neigh_hash_table___3;

struct neigh_table___2 {
	struct neigh_table___2 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___4 *, __u32 *);
	int (*constructor)(struct neighbour___2 *);
	int (*pconstructor)(struct pneigh_entry___3 *);
	void (*pdestructor)(struct pneigh_entry___3 *);
	void (*proxy_redo)(struct sk_buff___3 *);
	char *id;
	struct neigh_parms___2 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___3 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___3 *nht;
	struct pneigh_entry___3 **phash_buckets;
};

struct neigh_ops___2 {
	int family;
	void (*solicit)(struct neighbour___2 *, struct sk_buff___3 *);
	void (*error_report)(struct neighbour___2 *, struct sk_buff___3 *);
	int (*output)(struct neighbour___2 *, struct sk_buff___3 *);
	int (*connected_output)(struct neighbour___2 *, struct sk_buff___3 *);
};

struct pneigh_entry___3 {
	struct pneigh_entry___3 *next;
	struct net___5 *net;
	struct net_device___4 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___3 {
	struct neighbour___2 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___3;

struct proto___3 {
	void (*close)(struct sock___3 *, long int);
	int (*connect)(struct sock___3 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___3 *, int);
	struct sock___3 * (*accept)(struct sock___3 *, int, int *);
	int (*ioctl)(struct sock___3 *, int, long unsigned int);
	int (*init)(struct sock___3 *);
	void (*destroy)(struct sock___3 *);
	void (*shutdown)(struct sock___3 *, int);
	int (*setsockopt)(struct sock___3 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___3 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___3 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___3 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___3 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___4 *, struct sock___3 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___4 *, struct sock___3 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___3 *, struct page___55 *, int, size_t, int);
	int (*bind)(struct sock___3 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___3 *, struct sk_buff___3 *);
	void (*release_cb)(struct sock___3 *);
	void (*mtu_reduced)(struct sock___3 *);
	void (*hash)(struct sock___3 *);
	void (*unhash)(struct sock___3 *);
	void (*rehash)(struct sock___3 *);
	int (*get_port)(struct sock___3 *, short unsigned int);
	void (*clear_sk)(struct sock___3 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___3 *);
	void (*enter_memory_pressure)(struct sock___3 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___46 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___8 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___3 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___3 {
	void (*enter_memory_pressure)(struct sock___3 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___3 {
	int family;
	int obj_size;
	struct kmem_cache___46 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___3 *, struct request_sock___3 *);
	void (*send_ack)(struct sock___3 *, struct sk_buff___3 *, struct request_sock___3 *);
	void (*send_reset)(struct sock___3 *, struct sk_buff___3 *);
	void (*destructor)(struct request_sock___3 *);
	void (*syn_ack_timeout)(struct sock___3 *, struct request_sock___3 *);
};

struct timewait_sock_ops___3 {
	struct kmem_cache___46 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___3 *, struct sock___3 *, void *);
	void (*twsk_destructor)(struct sock___3 *);
};

struct ifmcaddr6___3 {
	struct in6_addr mca_addr;
	struct inet6_dev___2 *idev;
	struct ifmcaddr6___3 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___3 {
	struct in6_addr aca_addr;
	struct inet6_dev___2 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___3 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct nf_ipv6_ops {
	int (*chk_addr)(struct net___5 *, const struct in6_addr *, const struct net_device___4 *, int);
};

struct xt_table_info {
	unsigned int size;
	unsigned int number;
	unsigned int initial_entries;
	unsigned int hook_entry[5];
	unsigned int underflow[5];
	unsigned int stacksize;
	unsigned int *stackptr;
	void ***jumpstack;
	unsigned char entries[0];
};

enum ip_conntrack_dir {
	IP_CT_DIR_ORIGINAL = 0,
	IP_CT_DIR_REPLY = 1,
	IP_CT_DIR_MAX = 2,
};

struct ip_vs_iphdr {
	__u32 len;
	__u16 fragoffs;
	__s16 protocol;
	__s32 flags;
	union nf_inet_addr saddr;
	union nf_inet_addr daddr;
};

struct ip_vs_seq {
	__u32 init_seq;
	__u32 delta;
	__u32 previous_delta;
};

struct ip_vs_counters {
	__u32 conns;
	__u32 inpkts;
	__u32 outpkts;
	__u64 inbytes;
	__u64 outbytes;
};

struct ip_vs_cpu_stats {
	struct ip_vs_counters ustats;
	struct u64_stats_sync syncp;
};

struct ip_vs_conn;

struct ip_vs_app;

struct ip_vs_protocol {
	struct ip_vs_protocol *next;
	char *name;
	u16 protocol;
	u16 num_states;
	int dont_defrag;
	void (*init)(struct ip_vs_protocol *);
	void (*exit)(struct ip_vs_protocol *);
	int (*init_netns)(struct net___5 *, struct ip_vs_proto_data *);
	void (*exit_netns)(struct net___5 *, struct ip_vs_proto_data *);
	int (*conn_schedule)(int, struct sk_buff___3 *, struct ip_vs_proto_data *, int *, struct ip_vs_conn **, struct ip_vs_iphdr *);
	struct ip_vs_conn * (*conn_in_get)(int, const struct sk_buff___3 *, const struct ip_vs_iphdr *, int);
	struct ip_vs_conn * (*conn_out_get)(int, const struct sk_buff___3 *, const struct ip_vs_iphdr *, int);
	int (*snat_handler)(struct sk_buff___3 *, struct ip_vs_protocol *, struct ip_vs_conn *, struct ip_vs_iphdr *);
	int (*dnat_handler)(struct sk_buff___3 *, struct ip_vs_protocol *, struct ip_vs_conn *, struct ip_vs_iphdr *);
	int (*csum_check)(int, struct sk_buff___3 *, struct ip_vs_protocol *);
	const char * (*state_name)(int);
	void (*state_transition)(struct ip_vs_conn *, int, const struct sk_buff___3 *, struct ip_vs_proto_data *);
	int (*register_app)(struct net___5 *, struct ip_vs_app *);
	void (*unregister_app)(struct net___5 *, struct ip_vs_app *);
	int (*app_conn_bind)(struct ip_vs_conn *);
	void (*debug_packet)(int, struct ip_vs_protocol *, const struct sk_buff___3 *, int, const char *);
	void (*timeout_change)(struct ip_vs_proto_data *, int);
};

struct tcp_states_t;

struct ip_vs_proto_data {
	struct ip_vs_proto_data *next;
	struct ip_vs_protocol *pp;
	int *timeout_table;
	atomic_t appcnt;
	struct tcp_states_t *tcp_state_table;
};

struct ip_vs_dest;

struct ip_vs_pe;

struct ip_vs_conn {
	struct hlist_node c_list;
	__be16 cport;
	__be16 dport;
	__be16 vport;
	u16 af;
	union nf_inet_addr caddr;
	union nf_inet_addr vaddr;
	union nf_inet_addr daddr;
	volatile __u32 flags;
	__u16 protocol;
	struct net___5 *net;
	atomic_t refcnt;
	struct timer_list timer;
	volatile long unsigned int timeout;
	spinlock_t lock;
	volatile __u16 state;
	volatile __u16 old_state;
	__u32 fwmark;
	long unsigned int sync_endtime;
	struct ip_vs_conn *control;
	atomic_t n_control;
	struct ip_vs_dest *dest;
	atomic_t in_pkts;
	int (*packet_xmit)(struct sk_buff___3 *, struct ip_vs_conn *, struct ip_vs_protocol *, struct ip_vs_iphdr *);
	struct ip_vs_app *app;
	void *app_data;
	struct ip_vs_seq in_seq;
	struct ip_vs_seq out_seq;
	const struct ip_vs_pe *pe;
	char *pe_data;
	__u8 pe_data_len;
	struct callback_head callback_head;
};

struct ip_vs_app {
	struct list_head a_list;
	int type;
	char *name;
	__u16 protocol;
	struct module *module;
	struct list_head incs_list;
	struct list_head p_list;
	struct ip_vs_app *app;
	__be16 port;
	atomic_t usecnt;
	struct callback_head callback_head;
	int (*pkt_out)(struct ip_vs_app *, struct ip_vs_conn *, struct sk_buff___3 *, int *);
	int (*pkt_in)(struct ip_vs_app *, struct ip_vs_conn *, struct sk_buff___3 *, int *);
	int (*init_conn)(struct ip_vs_app *, struct ip_vs_conn *);
	int (*done_conn)(struct ip_vs_app *, struct ip_vs_conn *);
	int (*bind_conn)(struct ip_vs_app *, struct ip_vs_conn *, struct ip_vs_protocol *);
	void (*unbind_conn)(struct ip_vs_app *, struct ip_vs_conn *);
	int *timeout_table;
	int *timeouts;
	int timeouts_size;
	int (*conn_schedule)(struct sk_buff___3 *, struct ip_vs_app *, int *, struct ip_vs_conn **);
	struct ip_vs_conn * (*conn_in_get)(const struct sk_buff___3 *, struct ip_vs_app *, const struct iphdr *, int);
	struct ip_vs_conn * (*conn_out_get)(const struct sk_buff___3 *, struct ip_vs_app *, const struct iphdr *, int);
	int (*state_transition)(struct ip_vs_conn *, int, const struct sk_buff___3 *, struct ip_vs_app *);
	void (*timeout_change)(struct ip_vs_app *, int);
};

struct ip_vs_conn_param {
	struct net___5 *net;
	const union nf_inet_addr *caddr;
	const union nf_inet_addr *vaddr;
	__be16 cport;
	__be16 vport;
	__u16 protocol;
	u16 af;
	const struct ip_vs_pe *pe;
	char *pe_data;
	__u8 pe_data_len;
};

struct ip_vs_pe {
	struct list_head n_list;
	char *name;
	atomic_t refcnt;
	struct module *module;
	int (*fill_param)(struct ip_vs_conn_param *, struct sk_buff___3 *);
	bool (*ct_match)(const struct ip_vs_conn_param *, struct ip_vs_conn *);
	u32 (*hashkey_raw)(const struct ip_vs_conn_param *, u32, bool);
	int (*show_pe_data)(const struct ip_vs_conn *, char *);
};

struct ip_vs_dest_dst;

struct ip_vs_service;

struct ip_vs_dest {
	struct list_head n_list;
	struct hlist_node d_list;
	u16 af;
	__be16 port;
	union nf_inet_addr addr;
	volatile unsigned int flags;
	atomic_t conn_flags;
	atomic_t weight;
	atomic_t refcnt;
	struct ip_vs_stats stats;
	long unsigned int state;
	atomic_t activeconns;
	atomic_t inactconns;
	atomic_t persistconns;
	__u32 u_threshold;
	__u32 l_threshold;
	spinlock_t dst_lock;
	struct ip_vs_dest_dst *dest_dst;
	struct ip_vs_service *svc;
	__u16 protocol;
	__be16 vport;
	union nf_inet_addr vaddr;
	__u32 vfwmark;
	struct list_head t_list;
	struct callback_head callback_head;
	unsigned int in_rs_table: 1;
};

struct ip_vs_scheduler;

struct ip_vs_service {
	struct hlist_node s_list;
	struct hlist_node f_list;
	atomic_t refcnt;
	u16 af;
	__u16 protocol;
	union nf_inet_addr addr;
	__be16 port;
	__u32 fwmark;
	unsigned int flags;
	unsigned int timeout;
	__be32 netmask;
	struct net___5 *net;
	struct list_head destinations;
	__u32 num_dests;
	struct ip_vs_stats stats;
	struct ip_vs_scheduler *scheduler;
	spinlock_t sched_lock;
	void *sched_data;
	struct ip_vs_pe *pe;
	struct callback_head callback_head;
};

struct ip_vs_scheduler {
	struct list_head n_list;
	char *name;
	atomic_t refcnt;
	struct module *module;
	int (*init_service)(struct ip_vs_service *);
	void (*done_service)(struct ip_vs_service *);
	int (*add_dest)(struct ip_vs_service *, struct ip_vs_dest *);
	int (*del_dest)(struct ip_vs_service *, struct ip_vs_dest *);
	int (*upd_dest)(struct ip_vs_service *, struct ip_vs_dest *);
	struct ip_vs_dest * (*schedule)(struct ip_vs_service *, const struct sk_buff___3 *);
};

struct ip_vs_dest_dst {
	struct dst_entry___2 *dst_cache;
	u32 dst_cookie;
	union nf_inet_addr dst_saddr;
	struct callback_head callback_head;
};

struct ip_vs_sync_buff;

struct ipvs_master_sync_state {
	struct list_head sync_queue;
	struct ip_vs_sync_buff *sync_buff;
	int sync_queue_len;
	unsigned int sync_queue_delay;
	struct task_struct___56 *master_thread;
	struct delayed_work master_wakeup_work;
	struct netns_ipvs *ipvs;
};

struct perf_cpu_context___24;

struct pmu___24 {
	struct list_head entry;
	struct device___44 *dev;
	const struct attribute_group___39 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___24 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___24 *);
	void (*pmu_disable)(struct pmu___24 *);
	int (*event_init)(struct perf_event___24 *);
	int (*add)(struct perf_event___24 *, int);
	void (*del)(struct perf_event___24 *, int);
	void (*start)(struct perf_event___24 *, int);
	void (*stop)(struct perf_event___24 *, int);
	void (*read)(struct perf_event___24 *);
	void (*start_txn)(struct pmu___24 *);
	int (*commit_txn)(struct pmu___24 *);
	void (*cancel_txn)(struct pmu___24 *);
	int (*event_idx)(struct perf_event___24 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___24 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___24 *);
};

struct perf_cpu_context___24 {
	struct perf_event_context___24 ctx;
	struct perf_event_context___24 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___24 *unique_pmu;
	struct perf_cgroup___24 *cgrp;
};

struct perf_sample_data___5 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_functions___16;

struct trace_event___16 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___16 *funcs;
};

struct ftrace_event_class___16;

struct ftrace_event_call___16 {
	struct list_head list;
	struct ftrace_event_class___16 *class;
	char *name;
	struct trace_event___16 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___24 {
	struct cgroup_subsys_state___28 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___16 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___56 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___16)(struct trace_iterator___16 *, int, struct trace_event___16 *);

struct trace_event_functions___16 {
	trace_print_func___16 trace;
	trace_print_func___16 raw;
	trace_print_func___16 hex;
	trace_print_func___16 binary;
};

struct ftrace_event_class___16 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___16 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___16 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___16 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___16 *);
};

struct syscall_metadata___5 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___16 *enter_event;
	struct ftrace_event_call___16 *exit_event;
};

enum {
	MAX_NESTED_LINKS = 8,
};

struct compat_sysctl_args {
	compat_uptr_t name;
	int nlen;
	compat_uptr_t oldval;
	compat_uptr_t oldlenp;
	compat_uptr_t newval;
	compat_size_t newlen;
	compat_ulong_t __unused[4];
};

struct __user_cap_header_struct {
	__u32 version;
	int pid;
};

typedef struct __user_cap_header_struct *cap_user_header_t;

struct __user_cap_data_struct {
	__u32 effective;
	__u32 permitted;
	__u32 inheritable;
};

typedef struct __user_cap_data_struct *cap_user_data_t;

struct sigqueue {
	struct list_head list;
	int flags;
	siginfo_t info;
	struct user_struct *user;
};

struct ptrace_peeksiginfo_args {
	__u64 off;
	__u32 flags;
	__s32 nr;
};

typedef int user_regset_active_fn___3(struct task_struct___44 *, const struct user_regset___2 *);

typedef int user_regset_get_fn___3(struct task_struct___44 *, const struct user_regset___2 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___3(struct task_struct___44 *, const struct user_regset___2 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___3(struct task_struct___44 *, const struct user_regset___2 *, int);

struct compat_iovec {
	compat_uptr_t iov_base;
	compat_size_t iov_len;
};

struct page___56;

typedef struct page___56 *pgtable_t___56;

struct address_space___56;

struct kmem_cache___47;

struct page___56 {
	long unsigned int flags;
	struct address_space___56 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___56 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___56 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___47 *slab_cache;
		struct page___56 *first_page;
	};
	long: 64;
};

struct thread_struct___25;

struct task_struct___57;

struct pv_cpu_ops___56 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___25 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___25 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___57 *);
	void (*end_context_switch)(struct task_struct___57 *);
};

struct perf_event___25;

struct thread_struct___25 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___25 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___26;

struct pid_link___26 {
	struct hlist_node node;
	struct pid___26 *pid;
};

struct mutex___57 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___57 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___53 {
	struct page___56 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___60;

struct nsproxy___27;

struct signal_struct___56;

struct css_set___29;

struct perf_event_context___25;

struct task_struct___57 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___57 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___60 *mm;
	struct mm_struct___60 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___57 *real_parent;
	struct task_struct___57 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___57 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___26 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___56 = 0,
		VTIME_USER___56 = 1,
		VTIME_SYS___56 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___25 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___27 *nsproxy;
	struct signal_struct___56 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___29 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___25 *perf_event_ctxp[2];
	struct mutex___57 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___53 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___60 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___60 *, struct mm_struct___60 *);
	void (*dup_mmap)(struct mm_struct___60 *, struct mm_struct___60 *);
	void (*exit_mmap)(struct mm_struct___60 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___60 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___60 *);
	void (*pgd_free)(struct mm_struct___60 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___60 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___60 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___60 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___60 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___60 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___60 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___60 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___60 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___60 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___60 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___60 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___57 lock;
	void *vdso;
} mm_context_t___57;

struct xol_area___56;

struct uprobes_state___56 {
	struct xol_area___56 *xol_area;
};

struct vm_area_struct___60;

struct file___56;

struct core_state___56;

struct mm_struct___60 {
	struct vm_area_struct___60 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___60 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___60 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___57 context;
	long unsigned int flags;
	struct core_state___56 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___57 *owner;
	struct file___56 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___56 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___25 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___57 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___57 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___57 *target;
};

typedef void (*perf_overflow_handler_t___25)(struct perf_event___25 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___25;

typedef void (*ftrace_func_t___25)(long unsigned int, long unsigned int, struct ftrace_ops___25 *, struct pt_regs *);

struct ftrace_ops___25 {
	ftrace_func_t___25 func;
	struct ftrace_ops___25 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___57 regex_lock;
};

struct pmu___25;

struct fasync_struct___56;

struct pid_namespace___26;

struct ftrace_event_call___17;

struct perf_cgroup___25;

struct perf_event___25 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___25 *group_leader;
	struct pmu___25 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___25 hw;
	struct perf_event_context___25 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___57 child_mutex;
	struct list_head child_list;
	struct perf_event___25 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___57 *owner;
	struct mutex___57 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___56 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___25 *);
	struct callback_head callback_head;
	struct pid_namespace___26 *ns;
	u64 id;
	perf_overflow_handler_t___25 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___17 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___25 ftrace_ops;
	struct perf_cgroup___25 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___24 {
	struct task_struct___57 *task;
	struct exec_domain___15 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___40;

struct x86_io_apic_ops___40 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___40 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___40;

struct irq_data___40 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___40 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct tvec_root {
	struct list_head vec[256];
};

struct tvec {
	struct list_head vec[64];
};

struct tvec_base {
	spinlock_t lock;
	struct timer_list *running_timer;
	long unsigned int timer_jiffies;
	long unsigned int next_timer;
	long unsigned int active_timers;
	struct tvec_root tv1;
	struct tvec tv2;
	struct tvec tv3;
	struct tvec tv4;
	struct tvec tv5;
	long unsigned int all_timers;
	long: 64;
	long: 64;
};

struct device___45;

struct dev_pm_ops___45 {
	int (*prepare)(struct device___45 *);
	void (*complete)(struct device___45 *);
	int (*suspend)(struct device___45 *);
	int (*resume)(struct device___45 *);
	int (*freeze)(struct device___45 *);
	int (*thaw)(struct device___45 *);
	int (*poweroff)(struct device___45 *);
	int (*restore)(struct device___45 *);
	int (*suspend_late)(struct device___45 *);
	int (*resume_early)(struct device___45 *);
	int (*freeze_late)(struct device___45 *);
	int (*thaw_early)(struct device___45 *);
	int (*poweroff_late)(struct device___45 *);
	int (*restore_early)(struct device___45 *);
	int (*suspend_noirq)(struct device___45 *);
	int (*resume_noirq)(struct device___45 *);
	int (*freeze_noirq)(struct device___45 *);
	int (*thaw_noirq)(struct device___45 *);
	int (*poweroff_noirq)(struct device___45 *);
	int (*restore_noirq)(struct device___45 *);
	int (*runtime_suspend)(struct device___45 *);
	int (*runtime_resume)(struct device___45 *);
	int (*runtime_idle)(struct device___45 *);
};

struct device_type___45;

struct bus_type___45;

struct device_driver___45;

struct dev_pm_domain___45;

struct class___45;

struct attribute_group___40;

struct device_rh___45;

struct device___45 {
	struct device___45 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___45 *type;
	struct mutex___57 mutex;
	struct bus_type___45 *bus;
	struct device_driver___45 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___45 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___23 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___45 *class;
	const struct attribute_group___40 **groups;
	void (*release)(struct device___45 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___45 *device_rh;
};

struct dev_pm_info_rh___45 {
	void (*set_latency_tolerance)(struct device___45 *, s32);
};

struct dev_pm_domain___45 {
	struct dev_pm_ops___45 ops;
};

struct smp_ops___56 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___57 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___56;

struct lruvec___56 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___56 *zone;
};

struct pglist_data___56;

struct zone___56 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___56 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___56 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___56 {
	struct zone___56 *zone;
	int zone_idx;
};

struct zonelist___56 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___56 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___56 {
	struct zone___56 node_zones[4];
	struct zonelist___56 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___57 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___40;

struct irq_chip___40 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___40 *);
	void (*irq_shutdown)(struct irq_data___40 *);
	void (*irq_enable)(struct irq_data___40 *);
	void (*irq_disable)(struct irq_data___40 *);
	void (*irq_ack)(struct irq_data___40 *);
	void (*irq_mask)(struct irq_data___40 *);
	void (*irq_mask_ack)(struct irq_data___40 *);
	void (*irq_unmask)(struct irq_data___40 *);
	void (*irq_eoi)(struct irq_data___40 *);
	int (*irq_set_affinity)(struct irq_data___40 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___40 *);
	int (*irq_set_type)(struct irq_data___40 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___40 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___40 *);
	void (*irq_bus_sync_unlock)(struct irq_data___40 *);
	void (*irq_cpu_online)(struct irq_data___40 *);
	void (*irq_cpu_offline)(struct irq_data___40 *);
	void (*irq_suspend)(struct irq_data___40 *);
	void (*irq_resume)(struct irq_data___40 *);
	void (*irq_pm_shutdown)(struct irq_data___40 *);
	void (*irq_print_chip)(struct irq_data___40 *, struct seq_file___40 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___40 *, void *);
	long unsigned int flags;
};

struct seq_operations___39;

struct seq_file___40 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___57 lock;
	const struct seq_operations___39 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___56 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___56 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___47;

struct memcg_cache_params___47;

struct kmem_cache___47 {
	struct kmem_cache_cpu___47 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___47 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___57;

struct address_space_operations___56;

struct address_space___56 {
	struct inode___57 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___57 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___56 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___57;

struct path___56 {
	struct vfsmount *mnt;
	struct dentry___57 *dentry;
};

struct fown_struct___26 {
	rwlock_t lock;
	struct pid___26 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___56;

struct file___56 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___56 f_path;
	struct inode___57 *f_inode;
	const struct file_operations___56 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___26 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___56 *f_mapping;
	struct mutex___57 f_pos_lock;
};

struct vm_operations_struct___50;

struct vm_area_struct___60 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___60 *vm_next;
	struct vm_area_struct___60 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___60 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___50 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___56 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___47;

struct vm_operations_struct___50 {
	void (*open)(struct vm_area_struct___60 *);
	void (*close)(struct vm_area_struct___60 *);
	int (*fault)(struct vm_area_struct___60 *, struct vm_fault___47 *);
	int (*page_mkwrite)(struct vm_area_struct___60 *, struct vm_fault___47 *);
	int (*access)(struct vm_area_struct___60 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___60 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___60 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___60 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___60 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___56 {
	struct task_struct___57 *task;
	struct core_thread___56 *next;
};

struct core_state___56 {
	atomic_t nr_threads;
	struct core_thread___56 dumper;
	struct completion startup;
};

struct upid___26 {
	int nr;
	struct pid_namespace___26 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___26 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___57 *child_reaper;
	struct kmem_cache___47 *pid_cachep;
	unsigned int level;
	struct pid_namespace___26 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___57 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___26 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___26 numbers[1];
};

struct nsproxy___27 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___26 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___56 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___57 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___57 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___26 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___26 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___57 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___29;

struct css_set___29 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___29 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___25 {
	struct pmu___25 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___57 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___57 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___25 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___47 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___56 *page;
};

struct bin_attribute___40;

struct attribute_group___40 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___40 **bin_attrs;
};

struct bin_attribute___40 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___56 *, struct kobject___3 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___56 *, struct kobject___3 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	int (*mmap)(struct file___56 *, struct kobject___3 *, struct bin_attribute___40 *, struct vm_area_struct___60 *);
};

struct kmem_cache_cpu___47 {
	void **freelist;
	long unsigned int tid;
	struct page___56 *page;
	struct page___56 *partial;
};

struct memcg_cache_params___47 {
	bool is_root_cache;
	union {
		struct kmem_cache___47 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___47 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___29 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___57 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___57 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___57 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___56;

struct super_block___57;

struct dentry___57 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___57 *d_parent;
	struct qstr d_name;
	struct inode___57 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___56 *d_op;
	struct super_block___57 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___56;

struct file_lock___56;

struct dquot___56;

struct block_device___56;

struct cdev___23;

struct inode___57 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___56 *i_op;
	struct super_block___57 *i_sb;
	struct address_space___56 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___57 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___56 *i_fop;
	struct file_lock___56 *i_flock;
	struct address_space___56 i_data;
	struct dquot___56 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___56 *i_bdev;
		struct cdev___23 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___56 {
	int (*d_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_hash)(const struct dentry___57 *, struct qstr *);
	int (*d_compare)(const struct dentry___57 *, const struct dentry___57 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___57 *);
	void (*d_release)(struct dentry___57 *);
	void (*d_prune)(struct dentry___57 *);
	void (*d_iput)(struct dentry___57 *, struct inode___57 *);
	char * (*d_dname)(struct dentry___57 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___56 *);
	int (*d_manage)(struct dentry___57 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___56;

struct mem_dqinfo___56 {
	struct quota_format_type___56 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___56;

struct quota_info___56 {
	unsigned int flags;
	struct mutex___57 dqio_mutex;
	struct mutex___57 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___57 *files[2];
	struct mem_dqinfo___56 info[2];
	const struct quota_format_ops___56 *ops[2];
};

struct file_system_type___56;

struct super_operations___56;

struct dquot_operations___56;

struct quotactl_ops___56;

struct super_block___57 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___56 *s_type;
	const struct super_operations___56 *s_op;
	const struct dquot_operations___56 *dq_op;
	const struct quotactl_ops___56 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___57 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___29 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___56 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___56 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___57 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___56 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___56 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___57 *bd_inode;
	struct super_block___57 *bd_super;
	struct mutex___57 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___56 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___57 bd_fsfreeze_mutex;
};

struct cgroup___29;

struct cgroup_subsys_state___29 {
	struct cgroup___29 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___57 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___56 *ia_file;
};

struct dquot___56 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___57 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___57 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___56 {
	int qf_fmt_id;
	const struct quota_format_ops___56 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___56 *qf_next;
};

struct quota_format_ops___56 {
	int (*check_quota_file)(struct super_block___57 *, int);
	int (*read_file_info)(struct super_block___57 *, int);
	int (*write_file_info)(struct super_block___57 *, int);
	int (*free_file_info)(struct super_block___57 *, int);
	int (*read_dqblk)(struct dquot___56 *);
	int (*commit_dqblk)(struct dquot___56 *);
	int (*release_dqblk)(struct dquot___56 *);
};

struct dquot_operations___56 {
	int (*write_dquot)(struct dquot___56 *);
	struct dquot___56 * (*alloc_dquot)(struct super_block___57 *, int);
	void (*destroy_dquot)(struct dquot___56 *);
	int (*acquire_dquot)(struct dquot___56 *);
	int (*release_dquot)(struct dquot___56 *);
	int (*mark_dirty)(struct dquot___56 *);
	int (*write_info)(struct super_block___57 *, int);
	qsize_t * (*get_reserved_space)(struct inode___57 *);
};

struct quotactl_ops___56 {
	int (*quota_on)(struct super_block___57 *, int, int, struct path___56 *);
	int (*quota_on_meta)(struct super_block___57 *, int, int);
	int (*quota_off)(struct super_block___57 *, int);
	int (*quota_sync)(struct super_block___57 *, int);
	int (*get_info)(struct super_block___57 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___57 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___57 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___57 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___57 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___57 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___57 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___57 *, unsigned int);
};

struct swap_info_struct___8;

struct address_space_operations___56 {
	int (*writepage)(struct page___56 *, struct writeback_control *);
	int (*readpage)(struct file___56 *, struct page___56 *);
	int (*writepages)(struct address_space___56 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___56 *);
	int (*readpages)(struct file___56 *, struct address_space___56 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___56 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___56 **, void **);
	int (*write_end)(struct file___56 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___56 *, void *);
	sector_t (*bmap)(struct address_space___56 *, sector_t);
	void (*invalidatepage)(struct page___56 *, long unsigned int);
	int (*releasepage)(struct page___56 *, gfp_t);
	void (*freepage)(struct page___56 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___56 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___56 *, struct page___56 *, struct page___56 *, enum migrate_mode);
	int (*launder_page)(struct page___56 *);
	int (*is_partially_uptodate)(struct page___56 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___56 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___56 *, struct page___56 *);
	int (*swap_activate)(struct swap_info_struct___8 *, struct file___56 *, sector_t *);
	void (*swap_deactivate)(struct file___56 *);
	void (*invalidatepage_range)(struct page___56 *, unsigned int, unsigned int);
};

struct swap_info_struct___8 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___56 *bdev;
	struct file___56 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___23 {
	struct kobject___3 kobj;
	struct module *owner;
	const struct file_operations___56 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___56 {
	struct dentry___57 * (*lookup)(struct inode___57 *, struct dentry___57 *, unsigned int);
	void * (*follow_link)(struct dentry___57 *, struct nameidata *);
	int (*permission)(struct inode___57 *, int);
	struct posix_acl * (*get_acl)(struct inode___57 *, int);
	int (*readlink)(struct dentry___57 *, char *, int);
	void (*put_link)(struct dentry___57 *, struct nameidata *, void *);
	int (*create)(struct inode___57 *, struct dentry___57 *, umode_t, bool);
	int (*link)(struct dentry___57 *, struct inode___57 *, struct dentry___57 *);
	int (*unlink)(struct inode___57 *, struct dentry___57 *);
	int (*symlink)(struct inode___57 *, struct dentry___57 *, const char *);
	int (*mkdir)(struct inode___57 *, struct dentry___57 *, umode_t);
	int (*rmdir)(struct inode___57 *, struct dentry___57 *);
	int (*mknod)(struct inode___57 *, struct dentry___57 *, umode_t, dev_t);
	int (*rename)(struct inode___57 *, struct dentry___57 *, struct inode___57 *, struct dentry___57 *);
	int (*setattr)(struct dentry___57 *, struct iattr___57 *);
	int (*getattr)(struct vfsmount *, struct dentry___57 *, struct kstat *);
	int (*setxattr)(struct dentry___57 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___57 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___57 *, char *, size_t);
	int (*removexattr)(struct dentry___57 *, const char *);
	int (*fiemap)(struct inode___57 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___57 *, struct timespec *, int);
	int (*atomic_open)(struct inode___57 *, struct dentry___57 *, struct file___56 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___34;

struct file_operations___56 {
	struct module *owner;
	loff_t (*llseek)(struct file___56 *, loff_t, int);
	ssize_t (*read)(struct file___56 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___56 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___56 *, void *, filldir_t);
	unsigned int (*poll)(struct file___56 *, struct poll_table_struct___34 *);
	long int (*unlocked_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___56 *, struct vm_area_struct___60 *);
	int (*open)(struct inode___57 *, struct file___56 *);
	int (*flush)(struct file___56 *, fl_owner_t);
	int (*release)(struct inode___57 *, struct file___56 *);
	int (*fsync)(struct file___56 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___56 *, int);
	int (*lock)(struct file___56 *, int, struct file_lock___56 *);
	ssize_t (*sendpage)(struct file___56 *, struct page___56 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___56 *, int, struct file_lock___56 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___56 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___56 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___56 *, long int, struct file_lock___56 **, void **);
		struct {
			int (*setlease)(struct file___56 *, long int, struct file_lock___56 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___56 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___40 *, struct file___56 *);
};

struct file_lock_operations___56;

struct lock_manager_operations___56;

struct file_lock___56 {
	struct file_lock___56 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___26 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___56 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___56 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___56 *fl_ops;
	const struct lock_manager_operations___56 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___56 {
	void (*fl_copy_lock)(struct file_lock___56 *, struct file_lock___56 *);
	void (*fl_release_private)(struct file_lock___56 *);
};

struct lock_manager_operations___56 {
	int (*lm_compare_owner)(struct file_lock___56 *, struct file_lock___56 *);
	long unsigned int (*lm_owner_key)(struct file_lock___56 *);
	void (*lm_notify)(struct file_lock___56 *);
	int (*lm_grant)(struct file_lock___56 *, struct file_lock___56 *, int);
	void (*lm_break)(struct file_lock___56 *);
	int (*lm_change)(struct file_lock___56 **, int);
};

struct fasync_struct___56 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___56 *fa_next;
	struct file___56 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___56 {
	const char *name;
	int fs_flags;
	struct dentry___57 * (*mount)(struct file_system_type___56 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___57 *);
	struct module *owner;
	struct file_system_type___56 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___56 {
	struct inode___57 * (*alloc_inode)(struct super_block___57 *);
	void (*destroy_inode)(struct inode___57 *);
	void (*dirty_inode)(struct inode___57 *, int);
	int (*write_inode)(struct inode___57 *, struct writeback_control *);
	int (*drop_inode)(struct inode___57 *);
	void (*evict_inode)(struct inode___57 *);
	void (*put_super)(struct super_block___57 *);
	int (*sync_fs)(struct super_block___57 *, int);
	int (*freeze_fs)(struct super_block___57 *);
	int (*unfreeze_fs)(struct super_block___57 *);
	int (*statfs)(struct dentry___57 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___57 *, int *, char *);
	void (*umount_begin)(struct super_block___57 *);
	int (*show_options)(struct seq_file___40 *, struct dentry___57 *);
	int (*show_devname)(struct seq_file___40 *, struct dentry___57 *);
	int (*show_path)(struct seq_file___40 *, struct dentry___57 *);
	int (*show_stats)(struct seq_file___40 *, struct dentry___57 *);
	ssize_t (*quota_read)(struct super_block___57 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___57 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___57 *);
	int (*bdev_try_to_free_page)(struct super_block___57 *, struct page___56 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___57 *);
	void (*free_cached_objects)(struct super_block___57 *, int);
};

typedef void (*poll_queue_proc___34)(struct file___56 *, wait_queue_head_t *, struct poll_table_struct___34 *);

struct poll_table_struct___34 {
	poll_queue_proc___34 _qproc;
	long unsigned int _key;
};

struct cgroupfs_root___29;

struct cgroup___29 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___29 *parent;
	struct dentry___57 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___29 *subsys[11];
	struct cgroupfs_root___29 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___57 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___29 {
	struct super_block___57 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___29 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___10 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___57 *, struct file___56 *);
	ssize_t (*read)(struct cgroup___29 *, struct cftype___10 *, struct file___56 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___29 *, struct cftype___10 *);
	s64 (*read_s64)(struct cgroup___29 *, struct cftype___10 *);
	int (*read_map)(struct cgroup___29 *, struct cftype___10 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___29 *, struct cftype___10 *, struct seq_file___40 *);
	ssize_t (*write)(struct cgroup___29 *, struct cftype___10 *, struct file___56 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___29 *, struct cftype___10 *, u64);
	int (*write_s64)(struct cgroup___29 *, struct cftype___10 *, s64);
	int (*write_string)(struct cgroup___29 *, struct cftype___10 *, const char *);
	int (*trigger)(struct cgroup___29 *, unsigned int);
	int (*release)(struct inode___57 *, struct file___56 *);
	int (*register_event)(struct cgroup___29 *, struct cftype___10 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___29 *, struct cftype___10 *, struct eventfd_ctx *);
};

struct cftype_set___9 {
	struct list_head node;
	struct cftype___10 *cfts;
};

struct task_and_cgroup___9 {
	struct task_struct___57 *task;
	struct cgroup___29 *cgrp;
	struct css_set___29 *cg;
};

struct cgroup_taskset___9 {
	struct task_and_cgroup___9 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___29 *cur_cgrp;
};

struct cgroup_subsys___9 {
	struct cgroup_subsys_state___29 * (*css_alloc)(struct cgroup___29 *);
	int (*css_online)(struct cgroup___29 *);
	void (*css_offline)(struct cgroup___29 *);
	void (*css_free)(struct cgroup___29 *);
	int (*can_attach)(struct cgroup___29 *, struct cgroup_taskset___9 *);
	void (*cancel_attach)(struct cgroup___29 *, struct cgroup_taskset___9 *);
	void (*attach)(struct cgroup___29 *, struct cgroup_taskset___9 *);
	void (*fork)(struct task_struct___57 *);
	void (*exit)(struct cgroup___29 *, struct cgroup___29 *, struct task_struct___57 *);
	void (*bind)(struct cgroup___29 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___29 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___10 *base_cftypes;
	struct cftype_set___9 base_cftset;
	struct module *module;
};

struct bus_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___45 *, char *);
	ssize_t (*store)(struct bus_type___45 *, const char *, size_t);
};

struct device_attribute___45;

struct driver_attribute___45;

struct bus_type___45 {
	const char *name;
	const char *dev_name;
	struct device___45 *dev_root;
	struct bus_attribute___45 *bus_attrs;
	struct device_attribute___45 *dev_attrs;
	struct driver_attribute___45 *drv_attrs;
	const struct attribute_group___40 **bus_groups;
	const struct attribute_group___40 **dev_groups;
	const struct attribute_group___40 **drv_groups;
	int (*match)(struct device___45 *, struct device_driver___45 *);
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	int (*probe)(struct device___45 *);
	int (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*online)(struct device___45 *);
	int (*offline)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct device___45 *, struct device_attribute___45 *, char *);
	ssize_t (*store)(struct device___45 *, struct device_attribute___45 *, const char *, size_t);
};

struct driver_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___45 *, char *);
	ssize_t (*store)(struct device_driver___45 *, const char *, size_t);
};

struct device_driver___45 {
	const char *name;
	struct bus_type___45 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___45 *);
	int (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	const struct attribute_group___40 **groups;
	const struct dev_pm_ops___45 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___45 {
	const char *name;
	const struct attribute_group___40 **groups;
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
};

struct class_attribute___45;

struct class___45 {
	const char *name;
	struct module *owner;
	struct class_attribute___45 *class_attrs;
	struct device_attribute___45 *dev_attrs;
	const struct attribute_group___40 **dev_groups;
	struct bin_attribute___40 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *);
	void (*class_release)(struct class___45 *);
	void (*dev_release)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
	struct subsys_private *p;
};

struct class_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct class___45 *, struct class_attribute___45 *, char *);
	ssize_t (*store)(struct class___45 *, struct class_attribute___45 *, const char *, size_t);
	const void * (*namespace)(struct class___45 *, const struct class_attribute___45 *);
};

struct device_rh___45 {
	struct dev_pm_info_rh___45 power;
};

struct seq_operations___39 {
	void * (*start)(struct seq_file___40 *, loff_t *);
	void (*stop)(struct seq_file___40 *, void *);
	void * (*next)(struct seq_file___40 *, void *, loff_t *);
	int (*show)(struct seq_file___40 *, void *);
};

struct perf_cpu_context___25;

struct pmu___25 {
	struct list_head entry;
	struct device___45 *dev;
	const struct attribute_group___40 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___25 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___25 *);
	void (*pmu_disable)(struct pmu___25 *);
	int (*event_init)(struct perf_event___25 *);
	int (*add)(struct perf_event___25 *, int);
	void (*del)(struct perf_event___25 *, int);
	void (*start)(struct perf_event___25 *, int);
	void (*stop)(struct perf_event___25 *, int);
	void (*read)(struct perf_event___25 *);
	void (*start_txn)(struct pmu___25 *);
	int (*commit_txn)(struct pmu___25 *);
	void (*cancel_txn)(struct pmu___25 *);
	int (*event_idx)(struct perf_event___25 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___25 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___25 *);
};

struct perf_cpu_context___25 {
	struct perf_event_context___25 ctx;
	struct perf_event_context___25 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___25 *unique_pmu;
	struct perf_cgroup___25 *cgrp;
};

struct trace_event_functions___17;

struct trace_event___17 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___17 *funcs;
};

struct ftrace_event_class___17;

struct ftrace_event_call___17 {
	struct list_head list;
	struct ftrace_event_class___17 *class;
	char *name;
	struct trace_event___17 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___25 {
	struct cgroup_subsys_state___29 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___17 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___57 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___17)(struct trace_iterator___17 *, int, struct trace_event___17 *);

struct trace_event_functions___17 {
	trace_print_func___17 trace;
	trace_print_func___17 raw;
	trace_print_func___17 hex;
	trace_print_func___17 binary;
};

struct ftrace_event_class___17 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___17 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___17 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___17 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___17 *);
};

struct ftrace_event_file___8 {
	struct list_head list;
	struct ftrace_event_call___17 *event_call;
	struct dentry___57 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct syscall_metadata___6 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___17 *enter_event;
	struct ftrace_event_call___17 *exit_event;
};

struct ftrace_raw_timer_class {
	struct trace_entry ent;
	void *timer;
	char __data[0];
};

struct ftrace_raw_timer_start {
	struct trace_entry ent;
	void *timer;
	void *function;
	long unsigned int expires;
	long unsigned int now;
	char __data[0];
};

struct ftrace_raw_timer_expire_entry {
	struct trace_entry ent;
	void *timer;
	long unsigned int now;
	void *function;
	char __data[0];
};

struct ftrace_raw_hrtimer_init {
	struct trace_entry ent;
	void *hrtimer;
	clockid_t clockid;
	enum hrtimer_mode mode;
	char __data[0];
};

struct ftrace_raw_hrtimer_start {
	struct trace_entry ent;
	void *hrtimer;
	void *function;
	s64 expires;
	s64 softexpires;
	char __data[0];
};

struct ftrace_raw_hrtimer_expire_entry {
	struct trace_entry ent;
	void *hrtimer;
	s64 now;
	void *function;
	char __data[0];
};

struct ftrace_raw_hrtimer_class {
	struct trace_entry ent;
	void *hrtimer;
	char __data[0];
};

struct ftrace_raw_itimer_state {
	struct trace_entry ent;
	int which;
	cputime_t expires;
	long int value_sec;
	long int value_usec;
	long int interval_sec;
	long int interval_usec;
	char __data[0];
};

struct ftrace_raw_itimer_expire {
	struct trace_entry ent;
	int which;
	pid_t pid;
	cputime_t now;
	char __data[0];
};

struct ftrace_raw_tick_stop {
	struct trace_entry ent;
	int success;
	u32 __data_loc_msg;
	char __data[0];
};

struct ftrace_data_offsets_timer_class {};

struct ftrace_data_offsets_timer_start {};

struct ftrace_data_offsets_timer_expire_entry {};

struct ftrace_data_offsets_hrtimer_init {};

struct ftrace_data_offsets_hrtimer_start {};

struct ftrace_data_offsets_hrtimer_expire_entry {};

struct ftrace_data_offsets_hrtimer_class {};

struct ftrace_data_offsets_itimer_state {};

struct ftrace_data_offsets_itimer_expire {};

struct ftrace_data_offsets_tick_stop {
	u32 msg;
};

typedef int __kernel_mqd_t;

typedef __kernel_mqd_t mqd_t;

struct page___57;

typedef struct page___57 *pgtable_t___57;

struct address_space___57;

struct kmem_cache___48;

struct page___57 {
	long unsigned int flags;
	struct address_space___57 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___57 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___57 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___48 *slab_cache;
		struct page___57 *first_page;
	};
	long: 64;
};

struct thread_struct___26;

struct task_struct___58;

struct pv_cpu_ops___57 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___26 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___26 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___58 *);
	void (*end_context_switch)(struct task_struct___58 *);
};

struct perf_event___26;

struct thread_struct___26 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___26 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___27;

struct pid_link___27 {
	struct hlist_node node;
	struct pid___27 *pid;
};

struct mutex___58 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___58 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___54 {
	struct page___57 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___61;

struct nsproxy___28;

struct signal_struct___57;

struct audit_context___2;

struct css_set___30;

struct perf_event_context___26;

struct task_struct___58 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___58 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___61 *mm;
	struct mm_struct___61 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___58 *real_parent;
	struct task_struct___58 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___58 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___27 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___57 = 0,
		VTIME_USER___57 = 1,
		VTIME_SYS___57 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___26 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___28 *nsproxy;
	struct signal_struct___57 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context___2 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___30 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___26 *perf_event_ctxp[2];
	struct mutex___58 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___54 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___61 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___61 *, struct mm_struct___61 *);
	void (*dup_mmap)(struct mm_struct___61 *, struct mm_struct___61 *);
	void (*exit_mmap)(struct mm_struct___61 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___61 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___61 *);
	void (*pgd_free)(struct mm_struct___61 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___61 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___61 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___61 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___61 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___61 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___61 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___61 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___61 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___61 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___61 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___61 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___58 lock;
	void *vdso;
} mm_context_t___58;

struct xol_area___57;

struct uprobes_state___57 {
	struct xol_area___57 *xol_area;
};

struct vm_area_struct___61;

struct file___57;

struct linux_binfmt___5;

struct core_state___57;

struct mm_struct___61 {
	struct vm_area_struct___61 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___61 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___61 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___5 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___58 context;
	long unsigned int flags;
	struct core_state___57 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___58 *owner;
	struct file___57 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___57 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___26 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___58 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___58 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___58 *target;
};

typedef void (*perf_overflow_handler_t___26)(struct perf_event___26 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___26;

typedef void (*ftrace_func_t___26)(long unsigned int, long unsigned int, struct ftrace_ops___26 *, struct pt_regs *);

struct ftrace_ops___26 {
	ftrace_func_t___26 func;
	struct ftrace_ops___26 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___58 regex_lock;
};

struct pmu___26;

struct fasync_struct___57;

struct pid_namespace___27;

struct ftrace_event_call___18;

struct perf_cgroup___26;

struct perf_event___26 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___26 *group_leader;
	struct pmu___26 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___26 hw;
	struct perf_event_context___26 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___58 child_mutex;
	struct list_head child_list;
	struct perf_event___26 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___58 *owner;
	struct mutex___58 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___57 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___26 *);
	struct callback_head callback_head;
	struct pid_namespace___27 *ns;
	u64 id;
	perf_overflow_handler_t___26 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___18 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___26 ftrace_ops;
	struct perf_cgroup___26 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___25 {
	struct task_struct___58 *task;
	struct exec_domain___15 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___57;

struct lruvec___57 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___57 *zone;
};

struct pglist_data___57;

struct zone___57 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___57 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___57 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___57 {
	struct zone___57 *zone;
	int zone_idx;
};

struct zonelist___57 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___57 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___57 {
	struct zone___57 node_zones[4];
	struct zonelist___57 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___58 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___41;

struct x86_io_apic_ops___41 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___41 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___41;

struct irq_data___41 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___41 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___46;

struct dev_pm_ops___46 {
	int (*prepare)(struct device___46 *);
	void (*complete)(struct device___46 *);
	int (*suspend)(struct device___46 *);
	int (*resume)(struct device___46 *);
	int (*freeze)(struct device___46 *);
	int (*thaw)(struct device___46 *);
	int (*poweroff)(struct device___46 *);
	int (*restore)(struct device___46 *);
	int (*suspend_late)(struct device___46 *);
	int (*resume_early)(struct device___46 *);
	int (*freeze_late)(struct device___46 *);
	int (*thaw_early)(struct device___46 *);
	int (*poweroff_late)(struct device___46 *);
	int (*restore_early)(struct device___46 *);
	int (*suspend_noirq)(struct device___46 *);
	int (*resume_noirq)(struct device___46 *);
	int (*freeze_noirq)(struct device___46 *);
	int (*thaw_noirq)(struct device___46 *);
	int (*poweroff_noirq)(struct device___46 *);
	int (*restore_noirq)(struct device___46 *);
	int (*runtime_suspend)(struct device___46 *);
	int (*runtime_resume)(struct device___46 *);
	int (*runtime_idle)(struct device___46 *);
};

struct dma_map_ops___24;

struct dev_archdata___24 {
	struct dma_map_ops___24 *dma_ops;
	void *iommu;
};

struct device_type___46;

struct bus_type___46;

struct device_driver___46;

struct dev_pm_domain___46;

struct class___46;

struct attribute_group___41;

struct device_rh___46;

struct device___46 {
	struct device___46 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___46 *type;
	struct mutex___58 mutex;
	struct bus_type___46 *bus;
	struct device_driver___46 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___46 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___24 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___46 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___46 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___46 *device_rh;
};

struct dev_pm_info_rh___46 {
	void (*set_latency_tolerance)(struct device___46 *, s32);
};

struct dev_pm_domain___46 {
	struct dev_pm_ops___46 ops;
};

struct smp_ops___57 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___58 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___41;

struct attribute_group___41 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___41 **bin_attrs;
};

struct bin_attribute___41 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___57 *, struct kobject___3 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___57 *, struct kobject___3 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	int (*mmap)(struct file___57 *, struct kobject___3 *, struct bin_attribute___41 *, struct vm_area_struct___61 *);
};

struct dentry___58;

struct path___57 {
	struct vfsmount *mnt;
	struct dentry___58 *dentry;
};

struct fown_struct___27 {
	rwlock_t lock;
	struct pid___27 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___58;

struct file_operations___57;

struct file___57 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___57 f_path;
	struct inode___58 *f_inode;
	const struct file_operations___57 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___27 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___57 *f_mapping;
	struct mutex___58 f_pos_lock;
};

struct vm_operations_struct___51;

struct vm_area_struct___61 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___61 *vm_next;
	struct vm_area_struct___61 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___61 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___51 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___57 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___48 {
	void **freelist;
	long unsigned int tid;
	struct page___57 *page;
	struct page___57 *partial;
};

struct memcg_cache_params___48;

struct kmem_cache___48 {
	struct kmem_cache_cpu___48 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___48 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___48 {
	bool is_root_cache;
	union {
		struct kmem_cache___48 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___48 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___57 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___57 *page;
	long unsigned int vaddr;
};

struct address_space_operations___57;

struct address_space___57 {
	struct inode___58 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___58 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___57 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___48;

struct vm_operations_struct___51 {
	void (*open)(struct vm_area_struct___61 *);
	void (*close)(struct vm_area_struct___61 *);
	int (*fault)(struct vm_area_struct___61 *, struct vm_fault___48 *);
	int (*page_mkwrite)(struct vm_area_struct___61 *, struct vm_fault___48 *);
	int (*access)(struct vm_area_struct___61 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___61 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___61 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___61 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___61 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___57 {
	struct task_struct___58 *task;
	struct core_thread___57 *next;
};

struct core_state___57 {
	atomic_t nr_threads;
	struct core_thread___57 dumper;
	struct completion startup;
};

struct linux_binprm___6;

struct coredump_params___5;

struct linux_binfmt___5 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___6 *);
	int (*load_shlib)(struct file___57 *);
	int (*core_dump)(struct coredump_params___5 *);
	long unsigned int min_coredump;
};

typedef long unsigned int old_sigset_t;

struct upid___27 {
	int nr;
	struct pid_namespace___27 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___27 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___58 *child_reaper;
	struct kmem_cache___48 *pid_cachep;
	unsigned int level;
	struct pid_namespace___27 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___58 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___27 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___27 numbers[1];
};

struct nsproxy___28 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___27 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___5;

struct signal_struct___57 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___58 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___58 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___27 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___27 *tty_old_pgrp;
	int leader;
	struct tty_struct___5 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___58 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___5;

struct tty_operations___5;

struct tty_ldisc___5;

struct tty_port___5;

struct tty_struct___5 {
	int magic;
	struct kref kref;
	struct device___46 *dev;
	struct tty_driver___5 *driver;
	const struct tty_operations___5 *ops;
	int index;
	struct mutex___58 ldisc_mutex;
	struct tty_ldisc___5 *ldisc;
	struct mutex___58 atomic_write_lock;
	struct mutex___58 legacy_mutex;
	struct mutex___58 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___27 *pgrp;
	struct pid___27 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___5 *link;
	struct fasync_struct___57 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___5 *port;
	struct ld_semaphore ldisc_sem;
};

enum audit_state {
	AUDIT_DISABLED = 0,
	AUDIT_BUILD_CONTEXT = 1,
	AUDIT_RECORD_CONTEXT = 2,
};

struct audit_cap_data {
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
	union {
		unsigned int fE;
		kernel_cap_t effective;
	};
};

struct audit_names {
	struct list_head list;
	struct filename *name;
	int name_len;
	long unsigned int ino;
	dev_t dev;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	u32 osid;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	unsigned char type;
	bool hidden;
	bool should_free;
};

struct mq_attr {
	long int mq_flags;
	long int mq_maxmsg;
	long int mq_msgsize;
	long int mq_curmsgs;
	long int __reserved[4];
};

struct audit_aux_data;

struct __kernel_sockaddr_storage;

struct audit_tree_refs;

struct audit_context___2 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___57 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
	};
	int fds[2];
};

struct cgroup_subsys_state___30;

struct css_set___30 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___30 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___26 {
	struct pmu___26 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___58 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___58 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___26 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___57;

struct super_block___58;

struct dentry___58 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___58 *d_parent;
	struct qstr d_name;
	struct inode___58 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___57 *d_op;
	struct super_block___58 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___57;

struct file_lock___57;

struct dquot___57;

struct block_device___57;

struct cdev___24;

struct inode___58 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___57 *i_op;
	struct super_block___58 *i_sb;
	struct address_space___57 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___58 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___57 *i_fop;
	struct file_lock___57 *i_flock;
	struct address_space___57 i_data;
	struct dquot___57 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___57 *i_bdev;
		struct cdev___24 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___57 {
	int (*d_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_hash)(const struct dentry___58 *, struct qstr *);
	int (*d_compare)(const struct dentry___58 *, const struct dentry___58 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___58 *);
	void (*d_release)(struct dentry___58 *);
	void (*d_prune)(struct dentry___58 *);
	void (*d_iput)(struct dentry___58 *, struct inode___58 *);
	char * (*d_dname)(struct dentry___58 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___57 *);
	int (*d_manage)(struct dentry___58 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___57;

struct mem_dqinfo___57 {
	struct quota_format_type___57 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___57;

struct quota_info___57 {
	unsigned int flags;
	struct mutex___58 dqio_mutex;
	struct mutex___58 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___58 *files[2];
	struct mem_dqinfo___57 info[2];
	const struct quota_format_ops___57 *ops[2];
};

struct file_system_type___57;

struct super_operations___57;

struct dquot_operations___57;

struct quotactl_ops___57;

struct xattr_handler___30;

struct super_block___58 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___57 *s_type;
	const struct super_operations___57 *s_op;
	const struct dquot_operations___57 *dq_op;
	const struct quotactl_ops___57 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___58 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___30 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___57 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___57 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___58 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___57 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___57 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___58 *bd_inode;
	struct super_block___58 *bd_super;
	struct mutex___58 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___57 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___58 bd_fsfreeze_mutex;
};

struct cgroup___30;

struct cgroup_subsys_state___30 {
	struct cgroup___30 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___58 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___57 *ia_file;
};

struct dquot___57 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___58 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___58 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___57 {
	int qf_fmt_id;
	const struct quota_format_ops___57 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___57 *qf_next;
};

struct quota_format_ops___57 {
	int (*check_quota_file)(struct super_block___58 *, int);
	int (*read_file_info)(struct super_block___58 *, int);
	int (*write_file_info)(struct super_block___58 *, int);
	int (*free_file_info)(struct super_block___58 *, int);
	int (*read_dqblk)(struct dquot___57 *);
	int (*commit_dqblk)(struct dquot___57 *);
	int (*release_dqblk)(struct dquot___57 *);
};

struct dquot_operations___57 {
	int (*write_dquot)(struct dquot___57 *);
	struct dquot___57 * (*alloc_dquot)(struct super_block___58 *, int);
	void (*destroy_dquot)(struct dquot___57 *);
	int (*acquire_dquot)(struct dquot___57 *);
	int (*release_dquot)(struct dquot___57 *);
	int (*mark_dirty)(struct dquot___57 *);
	int (*write_info)(struct super_block___58 *, int);
	qsize_t * (*get_reserved_space)(struct inode___58 *);
};

struct quotactl_ops___57 {
	int (*quota_on)(struct super_block___58 *, int, int, struct path___57 *);
	int (*quota_on_meta)(struct super_block___58 *, int, int);
	int (*quota_off)(struct super_block___58 *, int);
	int (*quota_sync)(struct super_block___58 *, int);
	int (*get_info)(struct super_block___58 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___58 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___58 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___58 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___58 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___58 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___58 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___58 *, unsigned int);
};

struct address_space_operations___57 {
	int (*writepage)(struct page___57 *, struct writeback_control *);
	int (*readpage)(struct file___57 *, struct page___57 *);
	int (*writepages)(struct address_space___57 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___57 *);
	int (*readpages)(struct file___57 *, struct address_space___57 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___57 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___57 **, void **);
	int (*write_end)(struct file___57 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___57 *, void *);
	sector_t (*bmap)(struct address_space___57 *, sector_t);
	void (*invalidatepage)(struct page___57 *, long unsigned int);
	int (*releasepage)(struct page___57 *, gfp_t);
	void (*freepage)(struct page___57 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___57 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___57 *, struct page___57 *, struct page___57 *, enum migrate_mode);
	int (*launder_page)(struct page___57 *);
	int (*is_partially_uptodate)(struct page___57 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___57 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___57 *, struct page___57 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___57 *, sector_t *);
	void (*swap_deactivate)(struct file___57 *);
	void (*invalidatepage_range)(struct page___57 *, unsigned int, unsigned int);
};

struct cdev___24 {
	struct kobject___3 kobj;
	struct module *owner;
	const struct file_operations___57 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___57 {
	struct dentry___58 * (*lookup)(struct inode___58 *, struct dentry___58 *, unsigned int);
	void * (*follow_link)(struct dentry___58 *, struct nameidata *);
	int (*permission)(struct inode___58 *, int);
	struct posix_acl * (*get_acl)(struct inode___58 *, int);
	int (*readlink)(struct dentry___58 *, char *, int);
	void (*put_link)(struct dentry___58 *, struct nameidata *, void *);
	int (*create)(struct inode___58 *, struct dentry___58 *, umode_t, bool);
	int (*link)(struct dentry___58 *, struct inode___58 *, struct dentry___58 *);
	int (*unlink)(struct inode___58 *, struct dentry___58 *);
	int (*symlink)(struct inode___58 *, struct dentry___58 *, const char *);
	int (*mkdir)(struct inode___58 *, struct dentry___58 *, umode_t);
	int (*rmdir)(struct inode___58 *, struct dentry___58 *);
	int (*mknod)(struct inode___58 *, struct dentry___58 *, umode_t, dev_t);
	int (*rename)(struct inode___58 *, struct dentry___58 *, struct inode___58 *, struct dentry___58 *);
	int (*setattr)(struct dentry___58 *, struct iattr___58 *);
	int (*getattr)(struct vfsmount *, struct dentry___58 *, struct kstat *);
	int (*setxattr)(struct dentry___58 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___58 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___58 *, char *, size_t);
	int (*removexattr)(struct dentry___58 *, const char *);
	int (*fiemap)(struct inode___58 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___58 *, struct timespec *, int);
	int (*atomic_open)(struct inode___58 *, struct dentry___58 *, struct file___57 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___35;

struct seq_file___41;

struct file_operations___57 {
	struct module *owner;
	loff_t (*llseek)(struct file___57 *, loff_t, int);
	ssize_t (*read)(struct file___57 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___57 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___57 *, void *, filldir_t);
	unsigned int (*poll)(struct file___57 *, struct poll_table_struct___35 *);
	long int (*unlocked_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___57 *, struct vm_area_struct___61 *);
	int (*open)(struct inode___58 *, struct file___57 *);
	int (*flush)(struct file___57 *, fl_owner_t);
	int (*release)(struct inode___58 *, struct file___57 *);
	int (*fsync)(struct file___57 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___57 *, int);
	int (*lock)(struct file___57 *, int, struct file_lock___57 *);
	ssize_t (*sendpage)(struct file___57 *, struct page___57 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___57 *, int, struct file_lock___57 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___57 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___57 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___57 *, long int, struct file_lock___57 **, void **);
		struct {
			int (*setlease)(struct file___57 *, long int, struct file_lock___57 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___57 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___41 *, struct file___57 *);
};

struct file_lock_operations___57;

struct lock_manager_operations___57;

struct file_lock___57 {
	struct file_lock___57 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___27 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___57 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___57 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___57 *fl_ops;
	const struct lock_manager_operations___57 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___57 {
	void (*fl_copy_lock)(struct file_lock___57 *, struct file_lock___57 *);
	void (*fl_release_private)(struct file_lock___57 *);
};

struct lock_manager_operations___57 {
	int (*lm_compare_owner)(struct file_lock___57 *, struct file_lock___57 *);
	long unsigned int (*lm_owner_key)(struct file_lock___57 *);
	void (*lm_notify)(struct file_lock___57 *);
	int (*lm_grant)(struct file_lock___57 *, struct file_lock___57 *, int);
	void (*lm_break)(struct file_lock___57 *);
	int (*lm_change)(struct file_lock___57 **, int);
};

struct fasync_struct___57 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___57 *fa_next;
	struct file___57 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___57 {
	const char *name;
	int fs_flags;
	struct dentry___58 * (*mount)(struct file_system_type___57 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___58 *);
	struct module *owner;
	struct file_system_type___57 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___57 {
	struct inode___58 * (*alloc_inode)(struct super_block___58 *);
	void (*destroy_inode)(struct inode___58 *);
	void (*dirty_inode)(struct inode___58 *, int);
	int (*write_inode)(struct inode___58 *, struct writeback_control *);
	int (*drop_inode)(struct inode___58 *);
	void (*evict_inode)(struct inode___58 *);
	void (*put_super)(struct super_block___58 *);
	int (*sync_fs)(struct super_block___58 *, int);
	int (*freeze_fs)(struct super_block___58 *);
	int (*unfreeze_fs)(struct super_block___58 *);
	int (*statfs)(struct dentry___58 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___58 *, int *, char *);
	void (*umount_begin)(struct super_block___58 *);
	int (*show_options)(struct seq_file___41 *, struct dentry___58 *);
	int (*show_devname)(struct seq_file___41 *, struct dentry___58 *);
	int (*show_path)(struct seq_file___41 *, struct dentry___58 *);
	int (*show_stats)(struct seq_file___41 *, struct dentry___58 *);
	ssize_t (*quota_read)(struct super_block___58 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___58 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___58 *);
	int (*bdev_try_to_free_page)(struct super_block___58 *, struct page___57 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___58 *);
	void (*free_cached_objects)(struct super_block___58 *, int);
};

struct xattr_handler___30 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___58 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___58 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___58 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___35)(struct file___57 *, wait_queue_head_t *, struct poll_table_struct___35 *);

struct poll_table_struct___35 {
	poll_queue_proc___35 _qproc;
	long unsigned int _key;
};

struct seq_operations___40;

struct seq_file___41 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___58 lock;
	const struct seq_operations___40 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct tty_operations___5 {
	struct tty_struct___5 * (*lookup)(struct tty_driver___5 *, struct inode___58 *, int);
	int (*install)(struct tty_driver___5 *, struct tty_struct___5 *);
	void (*remove)(struct tty_driver___5 *, struct tty_struct___5 *);
	int (*open)(struct tty_struct___5 *, struct file___57 *);
	void (*close)(struct tty_struct___5 *, struct file___57 *);
	void (*shutdown)(struct tty_struct___5 *);
	void (*cleanup)(struct tty_struct___5 *);
	int (*write)(struct tty_struct___5 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___5 *, unsigned char);
	void (*flush_chars)(struct tty_struct___5 *);
	int (*write_room)(struct tty_struct___5 *);
	int (*chars_in_buffer)(struct tty_struct___5 *);
	int (*ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	void (*throttle)(struct tty_struct___5 *);
	void (*unthrottle)(struct tty_struct___5 *);
	void (*stop)(struct tty_struct___5 *);
	void (*start)(struct tty_struct___5 *);
	void (*hangup)(struct tty_struct___5 *);
	int (*break_ctl)(struct tty_struct___5 *, int);
	void (*flush_buffer)(struct tty_struct___5 *);
	void (*set_ldisc)(struct tty_struct___5 *);
	void (*wait_until_sent)(struct tty_struct___5 *, int);
	void (*send_xchar)(struct tty_struct___5 *, char);
	int (*tiocmget)(struct tty_struct___5 *);
	int (*tiocmset)(struct tty_struct___5 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___5 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___5 *, struct termiox *);
	int (*get_icount)(struct tty_struct___5 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___5 *, int, char *);
	int (*poll_get_char)(struct tty_driver___5 *, int);
	void (*poll_put_char)(struct tty_driver___5 *, int, char);
	const struct file_operations___57 *proc_fops;
};

struct tty_driver___5 {
	int magic;
	struct kref kref;
	struct cdev___24 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___5 *other;
	struct tty_struct___5 **ttys;
	struct tty_port___5 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___5 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___5;

struct tty_port___5 {
	struct tty_bufhead buf;
	struct tty_struct___5 *tty;
	struct tty_struct___5 *itty;
	const struct tty_port_operations___5 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___58 mutex;
	struct mutex___58 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___5 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___5 *);
	void (*close)(struct tty_struct___5 *);
	void (*flush_buffer)(struct tty_struct___5 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___5 *);
	ssize_t (*read)(struct tty_struct___5 *, struct file___57 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___5 *, struct file___57 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___5 *, struct file___57 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, struct file___57 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___5 *, struct file___57 *, struct poll_table_struct___35 *);
	int (*hangup)(struct tty_struct___5 *);
	void (*receive_buf)(struct tty_struct___5 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___5 *);
	void (*dcd_change)(struct tty_struct___5 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___5 *, int);
};

struct tty_ldisc___5 {
	struct tty_ldisc_ops___5 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___5 *tty;
};

struct tty_port_operations___5 {
	int (*carrier_raised)(struct tty_port___5 *);
	void (*dtr_rts)(struct tty_port___5 *, int);
	void (*shutdown)(struct tty_port___5 *);
	void (*drop)(struct tty_port___5 *);
	int (*activate)(struct tty_port___5 *, struct tty_struct___5 *);
	void (*destruct)(struct tty_port___5 *);
};

struct linux_binprm___6 {
	char buf[128];
	struct vm_area_struct___61 *vma;
	long unsigned int vma_pages;
	struct mm_struct___61 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___57 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___5 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___57 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct vm_fault___48 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___57 *page;
};

struct seq_operations___40 {
	void * (*start)(struct seq_file___41 *, loff_t *);
	void (*stop)(struct seq_file___41 *, void *);
	void * (*next)(struct seq_file___41 *, void *, loff_t *);
	int (*show)(struct seq_file___41 *, void *);
};

struct irq_chip___41 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___41 *);
	void (*irq_shutdown)(struct irq_data___41 *);
	void (*irq_enable)(struct irq_data___41 *);
	void (*irq_disable)(struct irq_data___41 *);
	void (*irq_ack)(struct irq_data___41 *);
	void (*irq_mask)(struct irq_data___41 *);
	void (*irq_mask_ack)(struct irq_data___41 *);
	void (*irq_unmask)(struct irq_data___41 *);
	void (*irq_eoi)(struct irq_data___41 *);
	int (*irq_set_affinity)(struct irq_data___41 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___41 *);
	int (*irq_set_type)(struct irq_data___41 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___41 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___41 *);
	void (*irq_bus_sync_unlock)(struct irq_data___41 *);
	void (*irq_cpu_online)(struct irq_data___41 *);
	void (*irq_cpu_offline)(struct irq_data___41 *);
	void (*irq_suspend)(struct irq_data___41 *);
	void (*irq_resume)(struct irq_data___41 *);
	void (*irq_pm_shutdown)(struct irq_data___41 *);
	void (*irq_print_chip)(struct irq_data___41 *, struct seq_file___41 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___41 *, void *);
	long unsigned int flags;
};

typedef u32 compat_old_sigset_t;

struct dma_map_ops___24 {
	void * (*alloc)(struct device___46 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___46 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___46 *, struct vm_area_struct___61 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___46 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___46 *, struct page___57 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___46 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___46 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___46 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___46 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___46 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___46 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___46 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___46 *, dma_addr_t);
	int (*dma_supported)(struct device___46 *, u64);
	int (*set_dma_mask)(struct device___46 *, u64);
	int is_phys;
};

struct bus_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___46 *, char *);
	ssize_t (*store)(struct bus_type___46 *, const char *, size_t);
};

struct device_attribute___46;

struct driver_attribute___46;

struct bus_type___46 {
	const char *name;
	const char *dev_name;
	struct device___46 *dev_root;
	struct bus_attribute___46 *bus_attrs;
	struct device_attribute___46 *dev_attrs;
	struct driver_attribute___46 *drv_attrs;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___46 *, struct device_driver___46 *);
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	int (*probe)(struct device___46 *);
	int (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*online)(struct device___46 *);
	int (*offline)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct device___46 *, struct device_attribute___46 *, char *);
	ssize_t (*store)(struct device___46 *, struct device_attribute___46 *, const char *, size_t);
};

struct driver_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___46 *, char *);
	ssize_t (*store)(struct device_driver___46 *, const char *, size_t);
};

struct device_driver___46 {
	const char *name;
	struct bus_type___46 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___46 *);
	int (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	const struct attribute_group___41 **groups;
	const struct dev_pm_ops___46 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___46 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
};

struct class_attribute___46;

struct class___46 {
	const char *name;
	struct module *owner;
	struct class_attribute___46 *class_attrs;
	struct device_attribute___46 *dev_attrs;
	const struct attribute_group___41 **dev_groups;
	struct bin_attribute___41 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *);
	void (*class_release)(struct class___46 *);
	void (*dev_release)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
	struct subsys_private *p;
};

struct class_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct class___46 *, struct class_attribute___46 *, char *);
	ssize_t (*store)(struct class___46 *, struct class_attribute___46 *, const char *, size_t);
	const void * (*namespace)(struct class___46 *, const struct class_attribute___46 *);
};

struct device_rh___46 {
	struct dev_pm_info_rh___46 power;
};

struct cgroupfs_root___30;

struct cgroup___30 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___30 *parent;
	struct dentry___58 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___30 *subsys[11];
	struct cgroupfs_root___30 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___58 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___30 {
	struct super_block___58 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___30 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___26;

struct pmu___26 {
	struct list_head entry;
	struct device___46 *dev;
	const struct attribute_group___41 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___26 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___26 *);
	void (*pmu_disable)(struct pmu___26 *);
	int (*event_init)(struct perf_event___26 *);
	int (*add)(struct perf_event___26 *, int);
	void (*del)(struct perf_event___26 *, int);
	void (*start)(struct perf_event___26 *, int);
	void (*stop)(struct perf_event___26 *, int);
	void (*read)(struct perf_event___26 *);
	void (*start_txn)(struct pmu___26 *);
	int (*commit_txn)(struct pmu___26 *);
	void (*cancel_txn)(struct pmu___26 *);
	int (*event_idx)(struct perf_event___26 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___26 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___26 *);
};

struct perf_cpu_context___26 {
	struct perf_event_context___26 ctx;
	struct perf_event_context___26 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___26 *unique_pmu;
	struct perf_cgroup___26 *cgrp;
};

struct trace_event_functions___18;

struct trace_event___18 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___18 *funcs;
};

struct ftrace_event_class___18;

struct ftrace_event_call___18 {
	struct list_head list;
	struct ftrace_event_class___18 *class;
	char *name;
	struct trace_event___18 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___26 {
	struct cgroup_subsys_state___30 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___18 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___58 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___18)(struct trace_iterator___18 *, int, struct trace_event___18 *);

struct trace_event_functions___18 {
	trace_print_func___18 trace;
	trace_print_func___18 raw;
	trace_print_func___18 hex;
	trace_print_func___18 binary;
};

struct ftrace_event_class___18 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___18 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___18 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___18 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___18 *);
};

struct ftrace_event_file___9 {
	struct list_head list;
	struct ftrace_event_call___18 *event_call;
	struct dentry___58 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct syscall_metadata___7 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___18 *enter_event;
	struct ftrace_event_call___18 *exit_event;
};

struct __kernel_sockaddr_storage {
	__kernel_sa_family_t ss_family;
	char __data[126];
};

struct compat_sigaction {
	compat_uptr_t sa_handler;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
	compat_sigset_t sa_mask;
};

struct compat_old_sigaction {
	compat_uptr_t sa_handler;
	compat_old_sigset_t sa_mask;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
};

enum {
	TRACE_SIGNAL_DELIVERED = 0,
	TRACE_SIGNAL_IGNORED = 1,
	TRACE_SIGNAL_ALREADY_PENDING = 2,
	TRACE_SIGNAL_OVERFLOW_FAIL = 3,
	TRACE_SIGNAL_LOSE_INFO = 4,
};

struct ftrace_raw_signal_generate {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	char comm[16];
	pid_t pid;
	int group;
	int result;
	char __data[0];
};

struct ftrace_raw_signal_deliver {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	long unsigned int sa_handler;
	long unsigned int sa_flags;
	char __data[0];
};

struct ftrace_data_offsets_signal_generate {};

struct ftrace_data_offsets_signal_deliver {};

struct sysinfo {
	__kernel_long_t uptime;
	__kernel_ulong_t loads[3];
	__kernel_ulong_t totalram;
	__kernel_ulong_t freeram;
	__kernel_ulong_t sharedram;
	__kernel_ulong_t bufferram;
	__kernel_ulong_t totalswap;
	__kernel_ulong_t freeswap;
	__u16 procs;
	__u16 pad;
	__kernel_ulong_t totalhigh;
	__kernel_ulong_t freehigh;
	__u32 mem_unit;
	char _f[0];
};

struct page___58;

typedef struct page___58 *pgtable_t___58;

struct address_space___58;

struct kmem_cache___49;

struct page___58 {
	long unsigned int flags;
	struct address_space___58 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___58 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___58 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___49 *slab_cache;
		struct page___58 *first_page;
	};
	long: 64;
};

struct thread_struct___27;

struct task_struct___59;

struct pv_cpu_ops___58 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___27 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___27 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___59 *);
	void (*end_context_switch)(struct task_struct___59 *);
};

struct perf_event___27;

struct thread_struct___27 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___27 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___28;

struct pid_link___28 {
	struct hlist_node node;
	struct pid___28 *pid;
};

struct mutex___59 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___59 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___55 {
	struct page___58 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___62;

struct fs_struct___5;

struct nsproxy___29;

struct signal_struct___58;

struct css_set___31;

struct perf_event_context___27;

struct task_struct___59 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___59 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___62 *mm;
	struct mm_struct___62 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___59 *real_parent;
	struct task_struct___59 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___59 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___28 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___58 = 0,
		VTIME_USER___58 = 1,
		VTIME_SYS___58 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___27 thread;
	struct fs_struct___5 *fs;
	struct files_struct *files;
	struct nsproxy___29 *nsproxy;
	struct signal_struct___58 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___31 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___27 *perf_event_ctxp[2];
	struct mutex___59 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___55 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___62 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___62 *, struct mm_struct___62 *);
	void (*dup_mmap)(struct mm_struct___62 *, struct mm_struct___62 *);
	void (*exit_mmap)(struct mm_struct___62 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___62 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___62 *);
	void (*pgd_free)(struct mm_struct___62 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___62 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___62 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___62 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___62 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___62 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___62 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___62 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___62 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___62 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___62 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___62 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___59 lock;
	void *vdso;
} mm_context_t___59;

struct xol_area___58;

struct uprobes_state___58 {
	struct xol_area___58 *xol_area;
};

struct vm_area_struct___62;

struct file___58;

struct linux_binfmt___6;

struct core_state___58;

struct mm_struct___62 {
	struct vm_area_struct___62 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___62 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___62 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___6 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___59 context;
	long unsigned int flags;
	struct core_state___58 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___59 *owner;
	struct file___58 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___58 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___37;

struct exec_domain___16 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___37 *module;
	struct exec_domain___16 *next;
};

struct module_kobject___36 {
	struct kobject___3 kobj;
	struct module___37 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___36;

struct ftrace_event_call___19;

struct module___37 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___36 mkobj;
	struct module_attribute___36 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___19 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___59 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___27 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___59 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___59 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___59 *target;
};

typedef void (*perf_overflow_handler_t___27)(struct perf_event___27 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___27;

typedef void (*ftrace_func_t___27)(long unsigned int, long unsigned int, struct ftrace_ops___27 *, struct pt_regs *);

struct ftrace_ops___27 {
	ftrace_func_t___27 func;
	struct ftrace_ops___27 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___59 regex_lock;
};

struct pmu___27;

struct fasync_struct___58;

struct pid_namespace___28;

struct perf_cgroup___27;

struct perf_event___27 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___27 *group_leader;
	struct pmu___27 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___27 hw;
	struct perf_event_context___27 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___59 child_mutex;
	struct list_head child_list;
	struct perf_event___27 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___59 *owner;
	struct mutex___59 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___58 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___27 *);
	struct callback_head callback_head;
	struct pid_namespace___28 *ns;
	u64 id;
	perf_overflow_handler_t___27 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___19 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___27 ftrace_ops;
	struct perf_cgroup___27 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___26 {
	struct task_struct___59 *task;
	struct exec_domain___16 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___58;

struct lruvec___58 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___58 *zone;
};

struct pglist_data___58;

struct zone___58 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___58 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___58 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___58 {
	struct zone___58 *zone;
	int zone_idx;
};

struct zonelist___58 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___58 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___58 {
	struct zone___58 node_zones[4];
	struct zonelist___58 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___59 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___42;

struct x86_io_apic_ops___42 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___42 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___42;

struct irq_data___42 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___42 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___47;

struct dev_pm_ops___47 {
	int (*prepare)(struct device___47 *);
	void (*complete)(struct device___47 *);
	int (*suspend)(struct device___47 *);
	int (*resume)(struct device___47 *);
	int (*freeze)(struct device___47 *);
	int (*thaw)(struct device___47 *);
	int (*poweroff)(struct device___47 *);
	int (*restore)(struct device___47 *);
	int (*suspend_late)(struct device___47 *);
	int (*resume_early)(struct device___47 *);
	int (*freeze_late)(struct device___47 *);
	int (*thaw_early)(struct device___47 *);
	int (*poweroff_late)(struct device___47 *);
	int (*restore_early)(struct device___47 *);
	int (*suspend_noirq)(struct device___47 *);
	int (*resume_noirq)(struct device___47 *);
	int (*freeze_noirq)(struct device___47 *);
	int (*thaw_noirq)(struct device___47 *);
	int (*poweroff_noirq)(struct device___47 *);
	int (*restore_noirq)(struct device___47 *);
	int (*runtime_suspend)(struct device___47 *);
	int (*runtime_resume)(struct device___47 *);
	int (*runtime_idle)(struct device___47 *);
};

struct device_type___47;

struct bus_type___47;

struct device_driver___47;

struct dev_pm_domain___47;

struct class___47;

struct attribute_group___42;

struct device_rh___47;

struct device___47 {
	struct device___47 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___47 *type;
	struct mutex___59 mutex;
	struct bus_type___47 *bus;
	struct device_driver___47 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___47 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___24 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___47 *class;
	const struct attribute_group___42 **groups;
	void (*release)(struct device___47 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___47 *device_rh;
};

struct dev_pm_info_rh___47 {
	void (*set_latency_tolerance)(struct device___47 *, s32);
};

struct dev_pm_domain___47 {
	struct dev_pm_ops___47 ops;
};

struct smp_ops___58 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___59 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___58 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___58 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___49;

struct memcg_cache_params___49;

struct kmem_cache___49 {
	struct kmem_cache_cpu___49 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___49 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___59;

struct address_space_operations___58;

struct address_space___58 {
	struct inode___59 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___59 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___58 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___7;

struct dentry___59;

struct path___58 {
	struct vfsmount___7 *mnt;
	struct dentry___59 *dentry;
};

struct fown_struct___28 {
	rwlock_t lock;
	struct pid___28 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___58;

struct file___58 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___58 f_path;
	struct inode___59 *f_inode;
	const struct file_operations___58 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___28 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___58 *f_mapping;
	struct mutex___59 f_pos_lock;
};

struct vm_operations_struct___52;

struct vm_area_struct___62 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___62 *vm_next;
	struct vm_area_struct___62 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___62 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___52 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___58 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___49;

struct vm_operations_struct___52 {
	void (*open)(struct vm_area_struct___62 *);
	void (*close)(struct vm_area_struct___62 *);
	int (*fault)(struct vm_area_struct___62 *, struct vm_fault___49 *);
	int (*page_mkwrite)(struct vm_area_struct___62 *, struct vm_fault___49 *);
	int (*access)(struct vm_area_struct___62 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___62 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___62 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___62 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___62 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___58 {
	struct task_struct___59 *task;
	struct core_thread___58 *next;
};

struct core_state___58 {
	atomic_t nr_threads;
	struct core_thread___58 dumper;
	struct completion startup;
};

struct linux_binprm___7;

struct coredump_params___6;

struct linux_binfmt___6 {
	struct list_head lh;
	struct module___37 *module;
	int (*load_binary)(struct linux_binprm___7 *);
	int (*load_shlib)(struct file___58 *);
	int (*core_dump)(struct coredump_params___6 *);
	long unsigned int min_coredump;
};

struct rlimit64 {
	__u64 rlim_cur;
	__u64 rlim_max;
};

struct vm_fault___49 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___58 *page;
};

struct upid___28 {
	int nr;
	struct pid_namespace___28 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___28 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___59 *child_reaper;
	struct kmem_cache___49 *pid_cachep;
	unsigned int level;
	struct pid_namespace___28 *parent;
	struct vfsmount___7 *proc_mnt;
	struct dentry___59 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___28 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___28 numbers[1];
};

struct nsproxy___29 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___28 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___6;

struct signal_struct___58 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___59 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___59 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___28 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___28 *tty_old_pgrp;
	int leader;
	struct tty_struct___6 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___59 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___6;

struct tty_operations___6;

struct tty_ldisc___6;

struct tty_port___6;

struct tty_struct___6 {
	int magic;
	struct kref kref;
	struct device___47 *dev;
	struct tty_driver___6 *driver;
	const struct tty_operations___6 *ops;
	int index;
	struct mutex___59 ldisc_mutex;
	struct tty_ldisc___6 *ldisc;
	struct mutex___59 atomic_write_lock;
	struct mutex___59 legacy_mutex;
	struct mutex___59 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___28 *pgrp;
	struct pid___28 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___6 *link;
	struct fasync_struct___58 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___6 *port;
	struct ld_semaphore ldisc_sem;
};

struct fs_struct___5 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___58 root;
	struct path___58 pwd;
};

struct cgroup_subsys_state___31;

struct css_set___31 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___31 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___27 {
	struct pmu___27 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___59 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___59 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___27 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct oldold_utsname {
	char sysname[9];
	char nodename[9];
	char release[9];
	char version[9];
	char machine[9];
};

struct old_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
};

enum uts_proc {
	UTS_PROC_OSTYPE = 0,
	UTS_PROC_OSRELEASE = 1,
	UTS_PROC_VERSION = 2,
	UTS_PROC_HOSTNAME = 3,
	UTS_PROC_DOMAINNAME = 4,
};

struct dentry_operations___58;

struct super_block___59;

struct dentry___59 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___59 *d_parent;
	struct qstr d_name;
	struct inode___59 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___58 *d_op;
	struct super_block___59 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___58;

struct file_lock___58;

struct dquot___58;

struct block_device___58;

struct cdev___25;

struct inode___59 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___58 *i_op;
	struct super_block___59 *i_sb;
	struct address_space___58 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___59 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___58 *i_fop;
	struct file_lock___58 *i_flock;
	struct address_space___58 i_data;
	struct dquot___58 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___58 *i_bdev;
		struct cdev___25 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___58 {
	int (*d_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_hash)(const struct dentry___59 *, struct qstr *);
	int (*d_compare)(const struct dentry___59 *, const struct dentry___59 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___59 *);
	void (*d_release)(struct dentry___59 *);
	void (*d_prune)(struct dentry___59 *);
	void (*d_iput)(struct dentry___59 *, struct inode___59 *);
	char * (*d_dname)(struct dentry___59 *, char *, int);
	struct vfsmount___7 * (*d_automount)(struct path___58 *);
	int (*d_manage)(struct dentry___59 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___58;

struct mem_dqinfo___58 {
	struct quota_format_type___58 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___58;

struct quota_info___58 {
	unsigned int flags;
	struct mutex___59 dqio_mutex;
	struct mutex___59 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___59 *files[2];
	struct mem_dqinfo___58 info[2];
	const struct quota_format_ops___58 *ops[2];
};

struct file_system_type___58;

struct super_operations___58;

struct dquot_operations___58;

struct quotactl_ops___58;

struct xattr_handler___31;

struct super_block___59 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___58 *s_type;
	const struct super_operations___58 *s_op;
	const struct dquot_operations___58 *dq_op;
	const struct quotactl_ops___58 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___59 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___31 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___58 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___58 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___59 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___58 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___7 {
	struct dentry___59 *mnt_root;
	struct super_block___59 *mnt_sb;
	int mnt_flags;
};

struct block_device___58 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___59 *bd_inode;
	struct super_block___59 *bd_super;
	struct mutex___59 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___58 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___59 bd_fsfreeze_mutex;
};

struct cgroup___31;

struct cgroup_subsys_state___31 {
	struct cgroup___31 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___59 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___58 *ia_file;
};

struct dquot___58 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___59 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___59 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___58 {
	int qf_fmt_id;
	const struct quota_format_ops___58 *qf_ops;
	struct module___37 *qf_owner;
	struct quota_format_type___58 *qf_next;
};

struct quota_format_ops___58 {
	int (*check_quota_file)(struct super_block___59 *, int);
	int (*read_file_info)(struct super_block___59 *, int);
	int (*write_file_info)(struct super_block___59 *, int);
	int (*free_file_info)(struct super_block___59 *, int);
	int (*read_dqblk)(struct dquot___58 *);
	int (*commit_dqblk)(struct dquot___58 *);
	int (*release_dqblk)(struct dquot___58 *);
};

struct dquot_operations___58 {
	int (*write_dquot)(struct dquot___58 *);
	struct dquot___58 * (*alloc_dquot)(struct super_block___59 *, int);
	void (*destroy_dquot)(struct dquot___58 *);
	int (*acquire_dquot)(struct dquot___58 *);
	int (*release_dquot)(struct dquot___58 *);
	int (*mark_dirty)(struct dquot___58 *);
	int (*write_info)(struct super_block___59 *, int);
	qsize_t * (*get_reserved_space)(struct inode___59 *);
};

struct quotactl_ops___58 {
	int (*quota_on)(struct super_block___59 *, int, int, struct path___58 *);
	int (*quota_on_meta)(struct super_block___59 *, int, int);
	int (*quota_off)(struct super_block___59 *, int);
	int (*quota_sync)(struct super_block___59 *, int);
	int (*get_info)(struct super_block___59 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___59 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___59 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___59 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___59 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___59 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___59 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___59 *, unsigned int);
};

struct swap_info_struct___9;

struct address_space_operations___58 {
	int (*writepage)(struct page___58 *, struct writeback_control *);
	int (*readpage)(struct file___58 *, struct page___58 *);
	int (*writepages)(struct address_space___58 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___58 *);
	int (*readpages)(struct file___58 *, struct address_space___58 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___58 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___58 **, void **);
	int (*write_end)(struct file___58 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___58 *, void *);
	sector_t (*bmap)(struct address_space___58 *, sector_t);
	void (*invalidatepage)(struct page___58 *, long unsigned int);
	int (*releasepage)(struct page___58 *, gfp_t);
	void (*freepage)(struct page___58 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___58 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___58 *, struct page___58 *, struct page___58 *, enum migrate_mode);
	int (*launder_page)(struct page___58 *);
	int (*is_partially_uptodate)(struct page___58 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___58 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___58 *, struct page___58 *);
	int (*swap_activate)(struct swap_info_struct___9 *, struct file___58 *, sector_t *);
	void (*swap_deactivate)(struct file___58 *);
	void (*invalidatepage_range)(struct page___58 *, unsigned int, unsigned int);
};

struct swap_info_struct___9 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___58 *bdev;
	struct file___58 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___25 {
	struct kobject___3 kobj;
	struct module___37 *owner;
	const struct file_operations___58 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___58 {
	struct dentry___59 * (*lookup)(struct inode___59 *, struct dentry___59 *, unsigned int);
	void * (*follow_link)(struct dentry___59 *, struct nameidata *);
	int (*permission)(struct inode___59 *, int);
	struct posix_acl * (*get_acl)(struct inode___59 *, int);
	int (*readlink)(struct dentry___59 *, char *, int);
	void (*put_link)(struct dentry___59 *, struct nameidata *, void *);
	int (*create)(struct inode___59 *, struct dentry___59 *, umode_t, bool);
	int (*link)(struct dentry___59 *, struct inode___59 *, struct dentry___59 *);
	int (*unlink)(struct inode___59 *, struct dentry___59 *);
	int (*symlink)(struct inode___59 *, struct dentry___59 *, const char *);
	int (*mkdir)(struct inode___59 *, struct dentry___59 *, umode_t);
	int (*rmdir)(struct inode___59 *, struct dentry___59 *);
	int (*mknod)(struct inode___59 *, struct dentry___59 *, umode_t, dev_t);
	int (*rename)(struct inode___59 *, struct dentry___59 *, struct inode___59 *, struct dentry___59 *);
	int (*setattr)(struct dentry___59 *, struct iattr___59 *);
	int (*getattr)(struct vfsmount___7 *, struct dentry___59 *, struct kstat *);
	int (*setxattr)(struct dentry___59 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___59 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___59 *, char *, size_t);
	int (*removexattr)(struct dentry___59 *, const char *);
	int (*fiemap)(struct inode___59 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___59 *, struct timespec *, int);
	int (*atomic_open)(struct inode___59 *, struct dentry___59 *, struct file___58 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___36;

struct seq_file___42;

struct file_operations___58 {
	struct module___37 *owner;
	loff_t (*llseek)(struct file___58 *, loff_t, int);
	ssize_t (*read)(struct file___58 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___58 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___58 *, void *, filldir_t);
	unsigned int (*poll)(struct file___58 *, struct poll_table_struct___36 *);
	long int (*unlocked_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___58 *, struct vm_area_struct___62 *);
	int (*open)(struct inode___59 *, struct file___58 *);
	int (*flush)(struct file___58 *, fl_owner_t);
	int (*release)(struct inode___59 *, struct file___58 *);
	int (*fsync)(struct file___58 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___58 *, int);
	int (*lock)(struct file___58 *, int, struct file_lock___58 *);
	ssize_t (*sendpage)(struct file___58 *, struct page___58 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___58 *, int, struct file_lock___58 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___58 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___58 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___58 *, long int, struct file_lock___58 **, void **);
		struct {
			int (*setlease)(struct file___58 *, long int, struct file_lock___58 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___58 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___42 *, struct file___58 *);
};

struct file_lock_operations___58;

struct lock_manager_operations___58;

struct file_lock___58 {
	struct file_lock___58 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___28 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___58 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___58 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___58 *fl_ops;
	const struct lock_manager_operations___58 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___58 {
	void (*fl_copy_lock)(struct file_lock___58 *, struct file_lock___58 *);
	void (*fl_release_private)(struct file_lock___58 *);
};

struct lock_manager_operations___58 {
	int (*lm_compare_owner)(struct file_lock___58 *, struct file_lock___58 *);
	long unsigned int (*lm_owner_key)(struct file_lock___58 *);
	void (*lm_notify)(struct file_lock___58 *);
	int (*lm_grant)(struct file_lock___58 *, struct file_lock___58 *, int);
	void (*lm_break)(struct file_lock___58 *);
	int (*lm_change)(struct file_lock___58 **, int);
};

struct fasync_struct___58 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___58 *fa_next;
	struct file___58 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___58 {
	const char *name;
	int fs_flags;
	struct dentry___59 * (*mount)(struct file_system_type___58 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___59 *);
	struct module___37 *owner;
	struct file_system_type___58 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___58 {
	struct inode___59 * (*alloc_inode)(struct super_block___59 *);
	void (*destroy_inode)(struct inode___59 *);
	void (*dirty_inode)(struct inode___59 *, int);
	int (*write_inode)(struct inode___59 *, struct writeback_control *);
	int (*drop_inode)(struct inode___59 *);
	void (*evict_inode)(struct inode___59 *);
	void (*put_super)(struct super_block___59 *);
	int (*sync_fs)(struct super_block___59 *, int);
	int (*freeze_fs)(struct super_block___59 *);
	int (*unfreeze_fs)(struct super_block___59 *);
	int (*statfs)(struct dentry___59 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___59 *, int *, char *);
	void (*umount_begin)(struct super_block___59 *);
	int (*show_options)(struct seq_file___42 *, struct dentry___59 *);
	int (*show_devname)(struct seq_file___42 *, struct dentry___59 *);
	int (*show_path)(struct seq_file___42 *, struct dentry___59 *);
	int (*show_stats)(struct seq_file___42 *, struct dentry___59 *);
	ssize_t (*quota_read)(struct super_block___59 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___59 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___59 *);
	int (*bdev_try_to_free_page)(struct super_block___59 *, struct page___58 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___59 *);
	void (*free_cached_objects)(struct super_block___59 *, int);
};

struct xattr_handler___31 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___59 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___59 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___59 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___36)(struct file___58 *, wait_queue_head_t *, struct poll_table_struct___36 *);

struct poll_table_struct___36 {
	poll_queue_proc___36 _qproc;
	long unsigned int _key;
};

struct seq_operations___41;

struct seq_file___42 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___59 lock;
	const struct seq_operations___41 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___42;

struct attribute_group___42 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___42 **bin_attrs;
};

struct bin_attribute___42 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___58 *, struct kobject___3 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___58 *, struct kobject___3 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	int (*mmap)(struct file___58 *, struct kobject___3 *, struct bin_attribute___42 *, struct vm_area_struct___62 *);
};

struct bus_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___47 *, char *);
	ssize_t (*store)(struct bus_type___47 *, const char *, size_t);
};

struct device_attribute___47;

struct driver_attribute___47;

struct bus_type___47 {
	const char *name;
	const char *dev_name;
	struct device___47 *dev_root;
	struct bus_attribute___47 *bus_attrs;
	struct device_attribute___47 *dev_attrs;
	struct driver_attribute___47 *drv_attrs;
	const struct attribute_group___42 **bus_groups;
	const struct attribute_group___42 **dev_groups;
	const struct attribute_group___42 **drv_groups;
	int (*match)(struct device___47 *, struct device_driver___47 *);
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	int (*probe)(struct device___47 *);
	int (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*online)(struct device___47 *);
	int (*offline)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct device___47 *, struct device_attribute___47 *, char *);
	ssize_t (*store)(struct device___47 *, struct device_attribute___47 *, const char *, size_t);
};

struct driver_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___47 *, char *);
	ssize_t (*store)(struct device_driver___47 *, const char *, size_t);
};

struct device_driver___47 {
	const char *name;
	struct bus_type___47 *bus;
	struct module___37 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___47 *);
	int (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	const struct attribute_group___42 **groups;
	const struct dev_pm_ops___47 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___47 {
	const char *name;
	const struct attribute_group___42 **groups;
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
};

struct class_attribute___47;

struct class___47 {
	const char *name;
	struct module___37 *owner;
	struct class_attribute___47 *class_attrs;
	struct device_attribute___47 *dev_attrs;
	const struct attribute_group___42 **dev_groups;
	struct bin_attribute___42 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *);
	void (*class_release)(struct class___47 *);
	void (*dev_release)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
	struct subsys_private *p;
};

struct class_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct class___47 *, struct class_attribute___47 *, char *);
	ssize_t (*store)(struct class___47 *, struct class_attribute___47 *, const char *, size_t);
	const void * (*namespace)(struct class___47 *, const struct class_attribute___47 *);
};

struct device_rh___47 {
	struct dev_pm_info_rh___47 power;
};

struct kmem_cache_cpu___49 {
	void **freelist;
	long unsigned int tid;
	struct page___58 *page;
	struct page___58 *partial;
};

struct memcg_cache_params___49 {
	bool is_root_cache;
	union {
		struct kmem_cache___49 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___49 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___31;

struct cgroup___31 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___31 *parent;
	struct dentry___59 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___31 *subsys[11];
	struct cgroupfs_root___31 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___59 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___31 {
	struct super_block___59 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___31 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___11 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___59 *, struct file___58 *);
	ssize_t (*read)(struct cgroup___31 *, struct cftype___11 *, struct file___58 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___31 *, struct cftype___11 *);
	s64 (*read_s64)(struct cgroup___31 *, struct cftype___11 *);
	int (*read_map)(struct cgroup___31 *, struct cftype___11 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___31 *, struct cftype___11 *, struct seq_file___42 *);
	ssize_t (*write)(struct cgroup___31 *, struct cftype___11 *, struct file___58 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___31 *, struct cftype___11 *, u64);
	int (*write_s64)(struct cgroup___31 *, struct cftype___11 *, s64);
	int (*write_string)(struct cgroup___31 *, struct cftype___11 *, const char *);
	int (*trigger)(struct cgroup___31 *, unsigned int);
	int (*release)(struct inode___59 *, struct file___58 *);
	int (*register_event)(struct cgroup___31 *, struct cftype___11 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___31 *, struct cftype___11 *, struct eventfd_ctx *);
};

struct cftype_set___10 {
	struct list_head node;
	struct cftype___11 *cfts;
};

struct task_and_cgroup___10 {
	struct task_struct___59 *task;
	struct cgroup___31 *cgrp;
	struct css_set___31 *cg;
};

struct cgroup_taskset___10 {
	struct task_and_cgroup___10 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___31 *cur_cgrp;
};

struct cgroup_subsys___10 {
	struct cgroup_subsys_state___31 * (*css_alloc)(struct cgroup___31 *);
	int (*css_online)(struct cgroup___31 *);
	void (*css_offline)(struct cgroup___31 *);
	void (*css_free)(struct cgroup___31 *);
	int (*can_attach)(struct cgroup___31 *, struct cgroup_taskset___10 *);
	void (*cancel_attach)(struct cgroup___31 *, struct cgroup_taskset___10 *);
	void (*attach)(struct cgroup___31 *, struct cgroup_taskset___10 *);
	void (*fork)(struct task_struct___59 *);
	void (*exit)(struct cgroup___31 *, struct cgroup___31 *, struct task_struct___59 *);
	void (*bind)(struct cgroup___31 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___31 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___11 *base_cftypes;
	struct cftype_set___10 base_cftset;
	struct module___37 *module;
};

struct perf_cpu_context___27;

struct pmu___27 {
	struct list_head entry;
	struct device___47 *dev;
	const struct attribute_group___42 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___27 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___27 *);
	void (*pmu_disable)(struct pmu___27 *);
	int (*event_init)(struct perf_event___27 *);
	int (*add)(struct perf_event___27 *, int);
	void (*del)(struct perf_event___27 *, int);
	void (*start)(struct perf_event___27 *, int);
	void (*stop)(struct perf_event___27 *, int);
	void (*read)(struct perf_event___27 *);
	void (*start_txn)(struct pmu___27 *);
	int (*commit_txn)(struct pmu___27 *);
	void (*cancel_txn)(struct pmu___27 *);
	int (*event_idx)(struct perf_event___27 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___37 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___27 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___27 *);
};

struct perf_cpu_context___27 {
	struct perf_event_context___27 ctx;
	struct perf_event_context___27 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___27 *unique_pmu;
	struct perf_cgroup___27 *cgrp;
};

struct trace_event_functions___19;

struct trace_event___19 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___19 *funcs;
};

struct ftrace_event_class___19;

struct ftrace_event_call___19 {
	struct list_head list;
	struct ftrace_event_class___19 *class;
	char *name;
	struct trace_event___19 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___27 {
	struct cgroup_subsys_state___31 css;
	struct perf_cgroup_info *info;
};

struct module_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___36 *, struct module_kobject___36 *, char *);
	ssize_t (*store)(struct module_attribute___36 *, struct module_kobject___36 *, const char *, size_t);
	void (*setup)(struct module___37 *, const char *);
	int (*test)(struct module___37 *);
	void (*free)(struct module___37 *);
};

struct tms {
	__kernel_clock_t tms_utime;
	__kernel_clock_t tms_stime;
	__kernel_clock_t tms_cutime;
	__kernel_clock_t tms_cstime;
};

struct irq_chip___42 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___42 *);
	void (*irq_shutdown)(struct irq_data___42 *);
	void (*irq_enable)(struct irq_data___42 *);
	void (*irq_disable)(struct irq_data___42 *);
	void (*irq_ack)(struct irq_data___42 *);
	void (*irq_mask)(struct irq_data___42 *);
	void (*irq_mask_ack)(struct irq_data___42 *);
	void (*irq_unmask)(struct irq_data___42 *);
	void (*irq_eoi)(struct irq_data___42 *);
	int (*irq_set_affinity)(struct irq_data___42 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___42 *);
	int (*irq_set_type)(struct irq_data___42 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___42 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___42 *);
	void (*irq_bus_sync_unlock)(struct irq_data___42 *);
	void (*irq_cpu_online)(struct irq_data___42 *);
	void (*irq_cpu_offline)(struct irq_data___42 *);
	void (*irq_suspend)(struct irq_data___42 *);
	void (*irq_resume)(struct irq_data___42 *);
	void (*irq_pm_shutdown)(struct irq_data___42 *);
	void (*irq_print_chip)(struct irq_data___42 *, struct seq_file___42 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___42 *, void *);
	long unsigned int flags;
};

struct seq_operations___41 {
	void * (*start)(struct seq_file___42 *, loff_t *);
	void (*stop)(struct seq_file___42 *, void *);
	void * (*next)(struct seq_file___42 *, void *, loff_t *);
	int (*show)(struct seq_file___42 *, void *);
};

struct linux_binprm___7 {
	char buf[128];
	struct vm_area_struct___62 *vma;
	long unsigned int vma_pages;
	struct mm_struct___62 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___58 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct tty_operations___6 {
	struct tty_struct___6 * (*lookup)(struct tty_driver___6 *, struct inode___59 *, int);
	int (*install)(struct tty_driver___6 *, struct tty_struct___6 *);
	void (*remove)(struct tty_driver___6 *, struct tty_struct___6 *);
	int (*open)(struct tty_struct___6 *, struct file___58 *);
	void (*close)(struct tty_struct___6 *, struct file___58 *);
	void (*shutdown)(struct tty_struct___6 *);
	void (*cleanup)(struct tty_struct___6 *);
	int (*write)(struct tty_struct___6 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___6 *, unsigned char);
	void (*flush_chars)(struct tty_struct___6 *);
	int (*write_room)(struct tty_struct___6 *);
	int (*chars_in_buffer)(struct tty_struct___6 *);
	int (*ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	void (*throttle)(struct tty_struct___6 *);
	void (*unthrottle)(struct tty_struct___6 *);
	void (*stop)(struct tty_struct___6 *);
	void (*start)(struct tty_struct___6 *);
	void (*hangup)(struct tty_struct___6 *);
	int (*break_ctl)(struct tty_struct___6 *, int);
	void (*flush_buffer)(struct tty_struct___6 *);
	void (*set_ldisc)(struct tty_struct___6 *);
	void (*wait_until_sent)(struct tty_struct___6 *, int);
	void (*send_xchar)(struct tty_struct___6 *, char);
	int (*tiocmget)(struct tty_struct___6 *);
	int (*tiocmset)(struct tty_struct___6 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___6 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___6 *, struct termiox *);
	int (*get_icount)(struct tty_struct___6 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___6 *, int, char *);
	int (*poll_get_char)(struct tty_driver___6 *, int);
	void (*poll_put_char)(struct tty_driver___6 *, int, char);
	const struct file_operations___58 *proc_fops;
};

struct tty_driver___6 {
	int magic;
	struct kref kref;
	struct cdev___25 *cdevs;
	struct module___37 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___6 *other;
	struct tty_struct___6 **ttys;
	struct tty_port___6 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___6 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___6;

struct tty_port___6 {
	struct tty_bufhead buf;
	struct tty_struct___6 *tty;
	struct tty_struct___6 *itty;
	const struct tty_port_operations___6 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___59 mutex;
	struct mutex___59 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___6 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___6 *);
	void (*close)(struct tty_struct___6 *);
	void (*flush_buffer)(struct tty_struct___6 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___6 *);
	ssize_t (*read)(struct tty_struct___6 *, struct file___58 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___6 *, struct file___58 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___6 *, struct file___58 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, struct file___58 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___6 *, struct file___58 *, struct poll_table_struct___36 *);
	int (*hangup)(struct tty_struct___6 *);
	void (*receive_buf)(struct tty_struct___6 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___6 *);
	void (*dcd_change)(struct tty_struct___6 *, unsigned int);
	struct module___37 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___6 *, int);
};

struct tty_ldisc___6 {
	struct tty_ldisc_ops___6 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___6 *tty;
};

struct tty_port_operations___6 {
	int (*carrier_raised)(struct tty_port___6 *);
	void (*dtr_rts)(struct tty_port___6 *, int);
	void (*shutdown)(struct tty_port___6 *);
	void (*drop)(struct tty_port___6 *);
	int (*activate)(struct tty_port___6 *, struct tty_struct___6 *);
	void (*destruct)(struct tty_port___6 *);
};

struct fd {
	struct file___58 *file;
	unsigned int flags;
};

struct trace_iterator___19 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___59 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___19)(struct trace_iterator___19 *, int, struct trace_event___19 *);

struct trace_event_functions___19 {
	trace_print_func___19 trace;
	trace_print_func___19 raw;
	trace_print_func___19 hex;
	trace_print_func___19 binary;
};

struct ftrace_event_class___19 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___19 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___19 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___19 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___19 *);
};

struct syscall_metadata___8 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___19 *enter_event;
	struct ftrace_event_call___19 *exit_event;
};

struct kprobe_insn_cache___12 {
	struct mutex___59 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct coredump_params___6 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___58 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct compat_sysinfo {
	s32 uptime;
	u32 loads[3];
	u32 totalram;
	u32 freeram;
	u32 sharedram;
	u32 bufferram;
	u32 totalswap;
	u32 freeswap;
	u16 procs;
	u16 pad;
	u32 totalhigh;
	u32 freehigh;
	u32 mem_unit;
	char _f[8];
};

struct page___59;

typedef struct page___59 *pgtable_t___59;

struct address_space___59;

struct kmem_cache___50;

struct page___59 {
	long unsigned int flags;
	struct address_space___59 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___59 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___59 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___50 *slab_cache;
		struct page___59 *first_page;
	};
	long: 64;
};

struct thread_struct___28;

struct task_struct___60;

struct pv_cpu_ops___59 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___28 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___28 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___60 *);
	void (*end_context_switch)(struct task_struct___60 *);
};

struct perf_event___28;

struct thread_struct___28 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___28 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___29;

struct pid_link___29 {
	struct hlist_node node;
	struct pid___29 *pid;
};

struct mutex___60 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___60 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___56 {
	struct page___59 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___63;

struct files_struct___3;

struct nsproxy___30;

struct signal_struct___59;

struct css_set___32;

struct perf_event_context___28;

struct task_struct___60 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___60 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___63 *mm;
	struct mm_struct___63 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___60 *real_parent;
	struct task_struct___60 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___60 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___29 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___59 = 0,
		VTIME_USER___59 = 1,
		VTIME_SYS___59 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___28 thread;
	struct fs_struct *fs;
	struct files_struct___3 *files;
	struct nsproxy___30 *nsproxy;
	struct signal_struct___59 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___32 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___28 *perf_event_ctxp[2];
	struct mutex___60 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___56 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___63 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___63 *, struct mm_struct___63 *);
	void (*dup_mmap)(struct mm_struct___63 *, struct mm_struct___63 *);
	void (*exit_mmap)(struct mm_struct___63 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___63 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___63 *);
	void (*pgd_free)(struct mm_struct___63 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___63 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___63 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___63 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___63 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___63 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___63 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___63 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___63 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___63 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___63 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___63 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___60 lock;
	void *vdso;
} mm_context_t___60;

struct xol_area___59;

struct uprobes_state___59 {
	struct xol_area___59 *xol_area;
};

struct vm_area_struct___63;

struct file___59;

struct core_state___59;

struct mm_struct___63 {
	struct vm_area_struct___63 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___63 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___63 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___60 context;
	long unsigned int flags;
	struct core_state___59 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___60 *owner;
	struct file___59 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___59 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___38;

struct module_kobject___37 {
	struct kobject___3 kobj;
	struct module___38 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___37;

struct ftrace_event_call___20;

struct module___38 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___37 mkobj;
	struct module_attribute___37 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___20 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___60 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___28 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___60 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___60 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___60 *target;
};

typedef void (*perf_overflow_handler_t___28)(struct perf_event___28 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___28;

typedef void (*ftrace_func_t___28)(long unsigned int, long unsigned int, struct ftrace_ops___28 *, struct pt_regs *);

struct ftrace_ops___28 {
	ftrace_func_t___28 func;
	struct ftrace_ops___28 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___60 regex_lock;
};

struct pmu___28;

struct fasync_struct___59;

struct pid_namespace___29;

struct perf_cgroup___28;

struct perf_event___28 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___28 *group_leader;
	struct pmu___28 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___28 hw;
	struct perf_event_context___28 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___60 child_mutex;
	struct list_head child_list;
	struct perf_event___28 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___60 *owner;
	struct mutex___60 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___59 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___28 *);
	struct callback_head callback_head;
	struct pid_namespace___29 *ns;
	u64 id;
	perf_overflow_handler_t___28 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___20 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___28 ftrace_ops;
	struct perf_cgroup___28 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___59;

struct lruvec___59 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___59 *zone;
};

struct pglist_data___59;

struct zone___59 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___59 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___59 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___59 {
	struct zone___59 *zone;
	int zone_idx;
};

struct zonelist___59 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___59 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___59 {
	struct zone___59 node_zones[4];
	struct zonelist___59 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___60 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	WQ_NON_REENTRANT = 1,
	WQ_UNBOUND = 2,
	WQ_FREEZABLE = 4,
	WQ_MEM_RECLAIM = 8,
	WQ_HIGHPRI = 16,
	WQ_CPU_INTENSIVE = 32,
	WQ_SYSFS = 64,
	__WQ_DRAINING = 65536,
	__WQ_ORDERED = 131072,
	WQ_MAX_ACTIVE = 512,
	WQ_MAX_UNBOUND_PER_CPU = 4,
	WQ_DFL_ACTIVE = 256,
};

struct irq_data___43;

struct x86_io_apic_ops___43 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___43 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___43;

struct irq_data___43 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___43 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___48;

struct dev_pm_ops___48 {
	int (*prepare)(struct device___48 *);
	void (*complete)(struct device___48 *);
	int (*suspend)(struct device___48 *);
	int (*resume)(struct device___48 *);
	int (*freeze)(struct device___48 *);
	int (*thaw)(struct device___48 *);
	int (*poweroff)(struct device___48 *);
	int (*restore)(struct device___48 *);
	int (*suspend_late)(struct device___48 *);
	int (*resume_early)(struct device___48 *);
	int (*freeze_late)(struct device___48 *);
	int (*thaw_early)(struct device___48 *);
	int (*poweroff_late)(struct device___48 *);
	int (*restore_early)(struct device___48 *);
	int (*suspend_noirq)(struct device___48 *);
	int (*resume_noirq)(struct device___48 *);
	int (*freeze_noirq)(struct device___48 *);
	int (*thaw_noirq)(struct device___48 *);
	int (*poweroff_noirq)(struct device___48 *);
	int (*restore_noirq)(struct device___48 *);
	int (*runtime_suspend)(struct device___48 *);
	int (*runtime_resume)(struct device___48 *);
	int (*runtime_idle)(struct device___48 *);
};

struct device_type___48;

struct bus_type___48;

struct device_driver___48;

struct dev_pm_domain___48;

struct class___48;

struct attribute_group___43;

struct device_rh___48;

struct device___48 {
	struct device___48 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___48 *type;
	struct mutex___60 mutex;
	struct bus_type___48 *bus;
	struct device_driver___48 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___48 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___24 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___48 *class;
	const struct attribute_group___43 **groups;
	void (*release)(struct device___48 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___48 *device_rh;
};

struct dev_pm_info_rh___48 {
	void (*set_latency_tolerance)(struct device___48 *, s32);
};

struct dev_pm_domain___48 {
	struct dev_pm_ops___48 ops;
};

struct smp_ops___59 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___60 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___30 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___29 *pid_ns;
	struct net *net_ns;
};

struct subprocess_info {
	struct work_struct work;
	struct completion *complete;
	char *path;
	char **argv;
	char **envp;
	int wait;
	int retval;
	int (*init)(struct subprocess_info *, struct cred *);
	void (*cleanup)(struct subprocess_info *);
	void *data;
};

struct bin_attribute___43;

struct attribute_group___43 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___43 **bin_attrs;
};

struct bin_attribute___43 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___59 *, struct kobject___3 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___59 *, struct kobject___3 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	int (*mmap)(struct file___59 *, struct kobject___3 *, struct bin_attribute___43 *, struct vm_area_struct___63 *);
};

struct vfsmount___8;

struct dentry___60;

struct path___59 {
	struct vfsmount___8 *mnt;
	struct dentry___60 *dentry;
};

struct fown_struct___29 {
	rwlock_t lock;
	struct pid___29 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___60;

struct file_operations___59;

struct file___59 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___59 f_path;
	struct inode___60 *f_inode;
	const struct file_operations___59 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___29 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___59 *f_mapping;
	struct mutex___60 f_pos_lock;
};

struct vm_operations_struct___53;

struct vm_area_struct___63 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___63 *vm_next;
	struct vm_area_struct___63 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___63 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___53 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___59 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___37 *, struct module_kobject___37 *, char *);
	ssize_t (*store)(struct module_attribute___37 *, struct module_kobject___37 *, const char *, size_t);
	void (*setup)(struct module___38 *, const char *);
	int (*test)(struct module___38 *);
	void (*free)(struct module___38 *);
};

struct trace_event_functions___20;

struct trace_event___20 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___20 *funcs;
};

struct ftrace_event_class___20;

struct ftrace_event_call___20 {
	struct list_head list;
	struct ftrace_event_class___20 *class;
	char *name;
	struct trace_event___20 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct xol_area___59 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___59 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___50;

struct memcg_cache_params___50;

struct kmem_cache___50 {
	struct kmem_cache_cpu___50 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___50 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___59;

struct address_space___59 {
	struct inode___60 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___60 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___59 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___50;

struct vm_operations_struct___53 {
	void (*open)(struct vm_area_struct___63 *);
	void (*close)(struct vm_area_struct___63 *);
	int (*fault)(struct vm_area_struct___63 *, struct vm_fault___50 *);
	int (*page_mkwrite)(struct vm_area_struct___63 *, struct vm_fault___50 *);
	int (*access)(struct vm_area_struct___63 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___63 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___63 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___63 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___63 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___59 {
	struct task_struct___60 *task;
	struct core_thread___59 *next;
};

struct core_state___59 {
	atomic_t nr_threads;
	struct core_thread___59 dumper;
	struct completion startup;
};

struct upid___29 {
	int nr;
	struct pid_namespace___29 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___29 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___60 *child_reaper;
	struct kmem_cache___50 *pid_cachep;
	unsigned int level;
	struct pid_namespace___29 *parent;
	struct vfsmount___8 *proc_mnt;
	struct dentry___60 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___29 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___29 numbers[1];
};

struct signal_struct___59 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___60 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___60 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___29 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___29 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___60 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fdtable___3 {
	unsigned int max_fds;
	struct file___59 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___3 {
	atomic_t count;
	struct fdtable___3 *fdt;
	struct fdtable___3 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___59 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_subsys_state___32;

struct css_set___32 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___32 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___28 {
	struct pmu___28 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___60 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___60 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___28 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct super_block___60;

struct dquot___59 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___60 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___60 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___59;

struct mem_dqinfo___59 {
	struct quota_format_type___59 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___59;

struct quota_info___59 {
	unsigned int flags;
	struct mutex___60 dqio_mutex;
	struct mutex___60 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___60 *files[2];
	struct mem_dqinfo___59 info[2];
	const struct quota_format_ops___59 *ops[2];
};

struct file_system_type___59;

struct super_operations___59;

struct dquot_operations___59;

struct quotactl_ops___59;

struct xattr_handler___32;

struct block_device___59;

struct dentry_operations___59;

struct super_block___60 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___59 *s_type;
	const struct super_operations___59 *s_op;
	const struct dquot_operations___59 *dq_op;
	const struct quotactl_ops___59 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___60 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___32 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___59 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___59 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___60 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___59 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___59 {
	int qf_fmt_id;
	const struct quota_format_ops___59 *qf_ops;
	struct module___38 *qf_owner;
	struct quota_format_type___59 *qf_next;
};

struct quota_format_ops___59 {
	int (*check_quota_file)(struct super_block___60 *, int);
	int (*read_file_info)(struct super_block___60 *, int);
	int (*write_file_info)(struct super_block___60 *, int);
	int (*free_file_info)(struct super_block___60 *, int);
	int (*read_dqblk)(struct dquot___59 *);
	int (*commit_dqblk)(struct dquot___59 *);
	int (*release_dqblk)(struct dquot___59 *);
};

struct dquot_operations___59 {
	int (*write_dquot)(struct dquot___59 *);
	struct dquot___59 * (*alloc_dquot)(struct super_block___60 *, int);
	void (*destroy_dquot)(struct dquot___59 *);
	int (*acquire_dquot)(struct dquot___59 *);
	int (*release_dquot)(struct dquot___59 *);
	int (*mark_dirty)(struct dquot___59 *);
	int (*write_info)(struct super_block___60 *, int);
	qsize_t * (*get_reserved_space)(struct inode___60 *);
};

struct inode_operations___59;

struct file_lock___59;

struct inode___60 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___59 *i_op;
	struct super_block___60 *i_sb;
	struct address_space___59 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___60 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___59 *i_fop;
	struct file_lock___59 *i_flock;
	struct address_space___59 i_data;
	struct dquot___59 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___59 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___59 {
	int (*quota_on)(struct super_block___60 *, int, int, struct path___59 *);
	int (*quota_on_meta)(struct super_block___60 *, int, int);
	int (*quota_off)(struct super_block___60 *, int);
	int (*quota_sync)(struct super_block___60 *, int);
	int (*get_info)(struct super_block___60 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___60 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___60 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___60 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___60 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___60 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___60 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___60 *, unsigned int);
};

struct vm_fault___50 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___59 *page;
};

struct seq_operations___42;

struct seq_file___43 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___60 lock;
	const struct seq_operations___42 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___42 {
	void * (*start)(struct seq_file___43 *, loff_t *);
	void (*stop)(struct seq_file___43 *, void *);
	void * (*next)(struct seq_file___43 *, void *, loff_t *);
	int (*show)(struct seq_file___43 *, void *);
};

struct dentry___60 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___60 *d_parent;
	struct qstr d_name;
	struct inode___60 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___59 *d_op;
	struct super_block___60 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___59 {
	int (*d_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_hash)(const struct dentry___60 *, struct qstr *);
	int (*d_compare)(const struct dentry___60 *, const struct dentry___60 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___60 *);
	void (*d_release)(struct dentry___60 *);
	void (*d_prune)(struct dentry___60 *);
	void (*d_iput)(struct dentry___60 *, struct inode___60 *);
	char * (*d_dname)(struct dentry___60 *, char *, int);
	struct vfsmount___8 * (*d_automount)(struct path___59 *);
	int (*d_manage)(struct dentry___60 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___8 {
	struct dentry___60 *mnt_root;
	struct super_block___60 *mnt_sb;
	int mnt_flags;
};

struct block_device___59 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___60 *bd_inode;
	struct super_block___60 *bd_super;
	struct mutex___60 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___59 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___60 bd_fsfreeze_mutex;
};

struct cgroup___32;

struct cgroup_subsys_state___32 {
	struct cgroup___32 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___60 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___59 *ia_file;
};

struct swap_info_struct___10;

struct address_space_operations___59 {
	int (*writepage)(struct page___59 *, struct writeback_control *);
	int (*readpage)(struct file___59 *, struct page___59 *);
	int (*writepages)(struct address_space___59 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___59 *);
	int (*readpages)(struct file___59 *, struct address_space___59 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___59 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___59 **, void **);
	int (*write_end)(struct file___59 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___59 *, void *);
	sector_t (*bmap)(struct address_space___59 *, sector_t);
	void (*invalidatepage)(struct page___59 *, long unsigned int);
	int (*releasepage)(struct page___59 *, gfp_t);
	void (*freepage)(struct page___59 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___59 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___59 *, struct page___59 *, struct page___59 *, enum migrate_mode);
	int (*launder_page)(struct page___59 *);
	int (*is_partially_uptodate)(struct page___59 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___59 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___59 *, struct page___59 *);
	int (*swap_activate)(struct swap_info_struct___10 *, struct file___59 *, sector_t *);
	void (*swap_deactivate)(struct file___59 *);
	void (*invalidatepage_range)(struct page___59 *, unsigned int, unsigned int);
};

struct swap_info_struct___10 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___59 *bdev;
	struct file___59 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___59 {
	struct dentry___60 * (*lookup)(struct inode___60 *, struct dentry___60 *, unsigned int);
	void * (*follow_link)(struct dentry___60 *, struct nameidata *);
	int (*permission)(struct inode___60 *, int);
	struct posix_acl * (*get_acl)(struct inode___60 *, int);
	int (*readlink)(struct dentry___60 *, char *, int);
	void (*put_link)(struct dentry___60 *, struct nameidata *, void *);
	int (*create)(struct inode___60 *, struct dentry___60 *, umode_t, bool);
	int (*link)(struct dentry___60 *, struct inode___60 *, struct dentry___60 *);
	int (*unlink)(struct inode___60 *, struct dentry___60 *);
	int (*symlink)(struct inode___60 *, struct dentry___60 *, const char *);
	int (*mkdir)(struct inode___60 *, struct dentry___60 *, umode_t);
	int (*rmdir)(struct inode___60 *, struct dentry___60 *);
	int (*mknod)(struct inode___60 *, struct dentry___60 *, umode_t, dev_t);
	int (*rename)(struct inode___60 *, struct dentry___60 *, struct inode___60 *, struct dentry___60 *);
	int (*setattr)(struct dentry___60 *, struct iattr___60 *);
	int (*getattr)(struct vfsmount___8 *, struct dentry___60 *, struct kstat *);
	int (*setxattr)(struct dentry___60 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___60 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___60 *, char *, size_t);
	int (*removexattr)(struct dentry___60 *, const char *);
	int (*fiemap)(struct inode___60 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___60 *, struct timespec *, int);
	int (*atomic_open)(struct inode___60 *, struct dentry___60 *, struct file___59 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___3 *fl_owner_t___3;

struct poll_table_struct___37;

struct file_operations___59 {
	struct module___38 *owner;
	loff_t (*llseek)(struct file___59 *, loff_t, int);
	ssize_t (*read)(struct file___59 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___59 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___59 *, void *, filldir_t);
	unsigned int (*poll)(struct file___59 *, struct poll_table_struct___37 *);
	long int (*unlocked_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___59 *, struct vm_area_struct___63 *);
	int (*open)(struct inode___60 *, struct file___59 *);
	int (*flush)(struct file___59 *, fl_owner_t___3);
	int (*release)(struct inode___60 *, struct file___59 *);
	int (*fsync)(struct file___59 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___59 *, int);
	int (*lock)(struct file___59 *, int, struct file_lock___59 *);
	ssize_t (*sendpage)(struct file___59 *, struct page___59 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___59 *, int, struct file_lock___59 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___59 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___59 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___59 *, long int, struct file_lock___59 **, void **);
		struct {
			int (*setlease)(struct file___59 *, long int, struct file_lock___59 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___59 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___43 *, struct file___59 *);
};

struct file_lock_operations___59;

struct lock_manager_operations___59;

struct file_lock___59 {
	struct file_lock___59 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___3 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___29 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___59 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___59 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___59 *fl_ops;
	const struct lock_manager_operations___59 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___59 {
	void (*fl_copy_lock)(struct file_lock___59 *, struct file_lock___59 *);
	void (*fl_release_private)(struct file_lock___59 *);
};

struct lock_manager_operations___59 {
	int (*lm_compare_owner)(struct file_lock___59 *, struct file_lock___59 *);
	long unsigned int (*lm_owner_key)(struct file_lock___59 *);
	void (*lm_notify)(struct file_lock___59 *);
	int (*lm_grant)(struct file_lock___59 *, struct file_lock___59 *, int);
	void (*lm_break)(struct file_lock___59 *);
	int (*lm_change)(struct file_lock___59 **, int);
};

struct fasync_struct___59 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___59 *fa_next;
	struct file___59 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___59 {
	const char *name;
	int fs_flags;
	struct dentry___60 * (*mount)(struct file_system_type___59 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___60 *);
	struct module___38 *owner;
	struct file_system_type___59 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___59 {
	struct inode___60 * (*alloc_inode)(struct super_block___60 *);
	void (*destroy_inode)(struct inode___60 *);
	void (*dirty_inode)(struct inode___60 *, int);
	int (*write_inode)(struct inode___60 *, struct writeback_control *);
	int (*drop_inode)(struct inode___60 *);
	void (*evict_inode)(struct inode___60 *);
	void (*put_super)(struct super_block___60 *);
	int (*sync_fs)(struct super_block___60 *, int);
	int (*freeze_fs)(struct super_block___60 *);
	int (*unfreeze_fs)(struct super_block___60 *);
	int (*statfs)(struct dentry___60 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___60 *, int *, char *);
	void (*umount_begin)(struct super_block___60 *);
	int (*show_options)(struct seq_file___43 *, struct dentry___60 *);
	int (*show_devname)(struct seq_file___43 *, struct dentry___60 *);
	int (*show_path)(struct seq_file___43 *, struct dentry___60 *);
	int (*show_stats)(struct seq_file___43 *, struct dentry___60 *);
	ssize_t (*quota_read)(struct super_block___60 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___60 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___60 *);
	int (*bdev_try_to_free_page)(struct super_block___60 *, struct page___59 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___60 *);
	void (*free_cached_objects)(struct super_block___60 *, int);
};

struct xattr_handler___32 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___60 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___60 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___60 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___37)(struct file___59 *, wait_queue_head_t *, struct poll_table_struct___37 *);

struct poll_table_struct___37 {
	poll_queue_proc___37 _qproc;
	long unsigned int _key;
};

struct irq_chip___43 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___43 *);
	void (*irq_shutdown)(struct irq_data___43 *);
	void (*irq_enable)(struct irq_data___43 *);
	void (*irq_disable)(struct irq_data___43 *);
	void (*irq_ack)(struct irq_data___43 *);
	void (*irq_mask)(struct irq_data___43 *);
	void (*irq_mask_ack)(struct irq_data___43 *);
	void (*irq_unmask)(struct irq_data___43 *);
	void (*irq_eoi)(struct irq_data___43 *);
	int (*irq_set_affinity)(struct irq_data___43 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___43 *);
	int (*irq_set_type)(struct irq_data___43 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___43 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___43 *);
	void (*irq_bus_sync_unlock)(struct irq_data___43 *);
	void (*irq_cpu_online)(struct irq_data___43 *);
	void (*irq_cpu_offline)(struct irq_data___43 *);
	void (*irq_suspend)(struct irq_data___43 *);
	void (*irq_resume)(struct irq_data___43 *);
	void (*irq_pm_shutdown)(struct irq_data___43 *);
	void (*irq_print_chip)(struct irq_data___43 *, struct seq_file___43 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___43 *, void *);
	long unsigned int flags;
};

struct bus_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___48 *, char *);
	ssize_t (*store)(struct bus_type___48 *, const char *, size_t);
};

struct device_attribute___48;

struct driver_attribute___48;

struct bus_type___48 {
	const char *name;
	const char *dev_name;
	struct device___48 *dev_root;
	struct bus_attribute___48 *bus_attrs;
	struct device_attribute___48 *dev_attrs;
	struct driver_attribute___48 *drv_attrs;
	const struct attribute_group___43 **bus_groups;
	const struct attribute_group___43 **dev_groups;
	const struct attribute_group___43 **drv_groups;
	int (*match)(struct device___48 *, struct device_driver___48 *);
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	int (*probe)(struct device___48 *);
	int (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*online)(struct device___48 *);
	int (*offline)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct device___48 *, struct device_attribute___48 *, char *);
	ssize_t (*store)(struct device___48 *, struct device_attribute___48 *, const char *, size_t);
};

struct driver_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___48 *, char *);
	ssize_t (*store)(struct device_driver___48 *, const char *, size_t);
};

struct device_driver___48 {
	const char *name;
	struct bus_type___48 *bus;
	struct module___38 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___48 *);
	int (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	const struct attribute_group___43 **groups;
	const struct dev_pm_ops___48 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___48 {
	const char *name;
	const struct attribute_group___43 **groups;
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
};

struct class_attribute___48;

struct class___48 {
	const char *name;
	struct module___38 *owner;
	struct class_attribute___48 *class_attrs;
	struct device_attribute___48 *dev_attrs;
	const struct attribute_group___43 **dev_groups;
	struct bin_attribute___43 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *);
	void (*class_release)(struct class___48 *);
	void (*dev_release)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
	struct subsys_private *p;
};

struct class_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct class___48 *, struct class_attribute___48 *, char *);
	ssize_t (*store)(struct class___48 *, struct class_attribute___48 *, const char *, size_t);
	const void * (*namespace)(struct class___48 *, const struct class_attribute___48 *);
};

struct device_rh___48 {
	struct dev_pm_info_rh___48 power;
};

struct kmem_cache_cpu___50 {
	void **freelist;
	long unsigned int tid;
	struct page___59 *page;
	struct page___59 *partial;
};

struct memcg_cache_params___50 {
	bool is_root_cache;
	union {
		struct kmem_cache___50 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___50 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___32;

struct cgroup___32 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___32 *parent;
	struct dentry___60 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___32 *subsys[11];
	struct cgroupfs_root___32 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___60 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___32 {
	struct super_block___60 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___32 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___12 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___60 *, struct file___59 *);
	ssize_t (*read)(struct cgroup___32 *, struct cftype___12 *, struct file___59 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___32 *, struct cftype___12 *);
	s64 (*read_s64)(struct cgroup___32 *, struct cftype___12 *);
	int (*read_map)(struct cgroup___32 *, struct cftype___12 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___32 *, struct cftype___12 *, struct seq_file___43 *);
	ssize_t (*write)(struct cgroup___32 *, struct cftype___12 *, struct file___59 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___32 *, struct cftype___12 *, u64);
	int (*write_s64)(struct cgroup___32 *, struct cftype___12 *, s64);
	int (*write_string)(struct cgroup___32 *, struct cftype___12 *, const char *);
	int (*trigger)(struct cgroup___32 *, unsigned int);
	int (*release)(struct inode___60 *, struct file___59 *);
	int (*register_event)(struct cgroup___32 *, struct cftype___12 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___32 *, struct cftype___12 *, struct eventfd_ctx *);
};

struct cftype_set___11 {
	struct list_head node;
	struct cftype___12 *cfts;
};

struct task_and_cgroup___11 {
	struct task_struct___60 *task;
	struct cgroup___32 *cgrp;
	struct css_set___32 *cg;
};

struct cgroup_taskset___11 {
	struct task_and_cgroup___11 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___32 *cur_cgrp;
};

struct cgroup_subsys___11 {
	struct cgroup_subsys_state___32 * (*css_alloc)(struct cgroup___32 *);
	int (*css_online)(struct cgroup___32 *);
	void (*css_offline)(struct cgroup___32 *);
	void (*css_free)(struct cgroup___32 *);
	int (*can_attach)(struct cgroup___32 *, struct cgroup_taskset___11 *);
	void (*cancel_attach)(struct cgroup___32 *, struct cgroup_taskset___11 *);
	void (*attach)(struct cgroup___32 *, struct cgroup_taskset___11 *);
	void (*fork)(struct task_struct___60 *);
	void (*exit)(struct cgroup___32 *, struct cgroup___32 *, struct task_struct___60 *);
	void (*bind)(struct cgroup___32 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___32 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___12 *base_cftypes;
	struct cftype_set___11 base_cftset;
	struct module___38 *module;
};

struct perf_cpu_context___28;

struct pmu___28 {
	struct list_head entry;
	struct device___48 *dev;
	const struct attribute_group___43 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___28 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___28 *);
	void (*pmu_disable)(struct pmu___28 *);
	int (*event_init)(struct perf_event___28 *);
	int (*add)(struct perf_event___28 *, int);
	void (*del)(struct perf_event___28 *, int);
	void (*start)(struct perf_event___28 *, int);
	void (*stop)(struct perf_event___28 *, int);
	void (*read)(struct perf_event___28 *);
	void (*start_txn)(struct pmu___28 *);
	int (*commit_txn)(struct pmu___28 *);
	void (*cancel_txn)(struct pmu___28 *);
	int (*event_idx)(struct perf_event___28 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___38 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___28 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___28 *);
};

struct perf_cpu_context___28 {
	struct perf_event_context___28 ctx;
	struct perf_event_context___28 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___28 *unique_pmu;
	struct perf_cgroup___28 *cgrp;
};

struct perf_cgroup___28 {
	struct cgroup_subsys_state___32 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___20 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___60 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___20)(struct trace_iterator___20 *, int, struct trace_event___20 *);

struct trace_event_functions___20 {
	trace_print_func___20 trace;
	trace_print_func___20 raw;
	trace_print_func___20 hex;
	trace_print_func___20 binary;
};

struct ftrace_event_class___20 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___20 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___20 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___20 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___20 *);
};

struct page___60;

typedef struct page___60 *pgtable_t___60;

struct address_space___60;

struct kmem_cache___51;

struct page___60 {
	long unsigned int flags;
	struct address_space___60 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___60 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___60 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___51 *slab_cache;
		struct page___60 *first_page;
	};
	long: 64;
};

struct thread_struct___29;

struct task_struct___61;

struct pv_cpu_ops___60 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___29 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___29 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___61 *);
	void (*end_context_switch)(struct task_struct___61 *);
};

struct perf_event___29;

struct thread_struct___29 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___29 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___30;

struct pid_link___30 {
	struct hlist_node node;
	struct pid___30 *pid;
};

struct mutex___61 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___61 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___57 {
	struct page___60 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___64;

struct nsproxy___31;

struct signal_struct___60;

struct css_set___33;

struct perf_event_context___29;

struct task_struct___61 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___61 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___64 *mm;
	struct mm_struct___64 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___61 *real_parent;
	struct task_struct___61 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___61 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___30 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___60 = 0,
		VTIME_USER___60 = 1,
		VTIME_SYS___60 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___29 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___31 *nsproxy;
	struct signal_struct___60 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___33 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___29 *perf_event_ctxp[2];
	struct mutex___61 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___57 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___64 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___64 *, struct mm_struct___64 *);
	void (*dup_mmap)(struct mm_struct___64 *, struct mm_struct___64 *);
	void (*exit_mmap)(struct mm_struct___64 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___64 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___64 *);
	void (*pgd_free)(struct mm_struct___64 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___64 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___64 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___64 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___64 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___64 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___64 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___64 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___64 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___64 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___64 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___64 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___61 lock;
	void *vdso;
} mm_context_t___61;

struct xol_area___60;

struct uprobes_state___60 {
	struct xol_area___60 *xol_area;
};

struct vm_area_struct___64;

struct file___60;

struct core_state___60;

struct mm_struct___64 {
	struct vm_area_struct___64 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___64 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___64 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___61 context;
	long unsigned int flags;
	struct core_state___60 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___61 *owner;
	struct file___60 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___60 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___29 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___61 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___61 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___61 *target;
};

typedef void (*perf_overflow_handler_t___29)(struct perf_event___29 *, struct perf_sample_data___4 *, struct pt_regs *);

struct ftrace_ops___29;

typedef void (*ftrace_func_t___29)(long unsigned int, long unsigned int, struct ftrace_ops___29 *, struct pt_regs *);

struct ftrace_ops___29 {
	ftrace_func_t___29 func;
	struct ftrace_ops___29 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___61 regex_lock;
};

struct pmu___29;

struct fasync_struct___60;

struct pid_namespace___30;

struct ftrace_event_call___21;

struct perf_cgroup___29;

struct perf_event___29 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___29 *group_leader;
	struct pmu___29 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___29 hw;
	struct perf_event_context___29 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___61 child_mutex;
	struct list_head child_list;
	struct perf_event___29 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___61 *owner;
	struct mutex___61 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___60 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___29 *);
	struct callback_head callback_head;
	struct pid_namespace___30 *ns;
	u64 id;
	perf_overflow_handler_t___29 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___21 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___29 ftrace_ops;
	struct perf_cgroup___29 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___27 {
	struct task_struct___61 *task;
	struct exec_domain___16 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct wq_flusher;

struct worker;

struct workqueue_attrs;

struct pool_workqueue;

struct wq_device;

struct workqueue_struct {
	struct list_head pwqs;
	struct list_head list;
	struct mutex___61 mutex;
	int work_color;
	int flush_color;
	atomic_t nr_pwqs_to_flush;
	struct wq_flusher *first_flusher;
	struct list_head flusher_queue;
	struct list_head flusher_overflow;
	struct list_head maydays;
	struct worker *rescuer;
	int nr_drainers;
	int saved_max_active;
	struct workqueue_attrs *unbound_attrs;
	struct pool_workqueue *dfl_pwq;
	struct wq_device *wq_dev;
	char name[24];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int flags;
	struct pool_workqueue *cpu_pwqs;
	struct pool_workqueue *numa_pwq_tbl[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct workqueue_attrs {
	int nice;
	cpumask_var_t cpumask;
	bool no_numa;
};

struct execute_work {
	struct work_struct work;
};

struct xol_area___60 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___60 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___51;

struct memcg_cache_params___51;

struct kmem_cache___51 {
	struct kmem_cache_cpu___51 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___51 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___61;

struct address_space_operations___60;

struct address_space___60 {
	struct inode___61 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___61 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___60 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___61;

struct path___60 {
	struct vfsmount *mnt;
	struct dentry___61 *dentry;
};

struct fown_struct___30 {
	rwlock_t lock;
	struct pid___30 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___60;

struct file___60 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___60 f_path;
	struct inode___61 *f_inode;
	const struct file_operations___60 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___30 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___60 *f_mapping;
	struct mutex___61 f_pos_lock;
};

struct vm_operations_struct___54;

struct vm_area_struct___64 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___64 *vm_next;
	struct vm_area_struct___64 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___64 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___54 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___60 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___51;

struct vm_operations_struct___54 {
	void (*open)(struct vm_area_struct___64 *);
	void (*close)(struct vm_area_struct___64 *);
	int (*fault)(struct vm_area_struct___64 *, struct vm_fault___51 *);
	int (*page_mkwrite)(struct vm_area_struct___64 *, struct vm_fault___51 *);
	int (*access)(struct vm_area_struct___64 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___64 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___64 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___64 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___64 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___60 {
	struct task_struct___61 *task;
	struct core_thread___60 *next;
};

struct core_state___60 {
	atomic_t nr_threads;
	struct core_thread___60 dumper;
	struct completion startup;
};

struct irq_data___44;

struct x86_io_apic_ops___44 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___44 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___44;

struct irq_data___44 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___44 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___49;

struct dev_pm_ops___49 {
	int (*prepare)(struct device___49 *);
	void (*complete)(struct device___49 *);
	int (*suspend)(struct device___49 *);
	int (*resume)(struct device___49 *);
	int (*freeze)(struct device___49 *);
	int (*thaw)(struct device___49 *);
	int (*poweroff)(struct device___49 *);
	int (*restore)(struct device___49 *);
	int (*suspend_late)(struct device___49 *);
	int (*resume_early)(struct device___49 *);
	int (*freeze_late)(struct device___49 *);
	int (*thaw_early)(struct device___49 *);
	int (*poweroff_late)(struct device___49 *);
	int (*restore_early)(struct device___49 *);
	int (*suspend_noirq)(struct device___49 *);
	int (*resume_noirq)(struct device___49 *);
	int (*freeze_noirq)(struct device___49 *);
	int (*thaw_noirq)(struct device___49 *);
	int (*poweroff_noirq)(struct device___49 *);
	int (*restore_noirq)(struct device___49 *);
	int (*runtime_suspend)(struct device___49 *);
	int (*runtime_resume)(struct device___49 *);
	int (*runtime_idle)(struct device___49 *);
};

struct device_type___49;

struct bus_type___49;

struct device_driver___49;

struct dev_pm_domain___49;

struct class___49;

struct attribute_group___44;

struct device_rh___49;

struct device___49 {
	struct device___49 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___49 *type;
	struct mutex___61 mutex;
	struct bus_type___49 *bus;
	struct device_driver___49 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___49 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___24 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___49 *class;
	const struct attribute_group___44 **groups;
	void (*release)(struct device___49 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___49 *device_rh;
};

struct dev_pm_info_rh___49 {
	void (*set_latency_tolerance)(struct device___49 *, s32);
};

struct dev_pm_domain___49 {
	struct dev_pm_ops___49 ops;
};

struct smp_ops___60 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___61 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___30 {
	int nr;
	struct pid_namespace___30 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___30 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___61 *child_reaper;
	struct kmem_cache___51 *pid_cachep;
	unsigned int level;
	struct pid_namespace___30 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___61 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___30 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___30 numbers[1];
};

struct zone___60;

struct lruvec___60 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___60 *zone;
};

struct pglist_data___60;

struct zone___60 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___60 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___60 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___60 {
	struct zone___60 *zone;
	int zone_idx;
};

struct zonelist___60 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___60 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___60 {
	struct zone___60 node_zones[4];
	struct zonelist___60 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___61 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___31 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___30 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___60 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___61 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___61 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___30 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___30 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___61 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___33;

struct css_set___33 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___33 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___29 {
	struct pmu___29 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___61 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___61 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___29 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___44;

struct attribute_group___44 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___44 **bin_attrs;
};

struct bin_attribute___44 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___60 *, struct kobject___3 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___60 *, struct kobject___3 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	int (*mmap)(struct file___60 *, struct kobject___3 *, struct bin_attribute___44 *, struct vm_area_struct___64 *);
};

struct kmem_cache_cpu___51 {
	void **freelist;
	long unsigned int tid;
	struct page___60 *page;
	struct page___60 *partial;
};

struct memcg_cache_params___51 {
	bool is_root_cache;
	union {
		struct kmem_cache___51 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___51 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___49 *, char *);
	ssize_t (*store)(struct bus_type___49 *, const char *, size_t);
};

struct device_attribute___49;

struct driver_attribute___49;

struct bus_type___49 {
	const char *name;
	const char *dev_name;
	struct device___49 *dev_root;
	struct bus_attribute___49 *bus_attrs;
	struct device_attribute___49 *dev_attrs;
	struct driver_attribute___49 *drv_attrs;
	const struct attribute_group___44 **bus_groups;
	const struct attribute_group___44 **dev_groups;
	const struct attribute_group___44 **drv_groups;
	int (*match)(struct device___49 *, struct device_driver___49 *);
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	int (*probe)(struct device___49 *);
	int (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*online)(struct device___49 *);
	int (*offline)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct device___49 *, struct device_attribute___49 *, char *);
	ssize_t (*store)(struct device___49 *, struct device_attribute___49 *, const char *, size_t);
};

struct driver_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___49 *, char *);
	ssize_t (*store)(struct device_driver___49 *, const char *, size_t);
};

struct device_driver___49 {
	const char *name;
	struct bus_type___49 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___49 *);
	int (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	const struct attribute_group___44 **groups;
	const struct dev_pm_ops___49 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___49 {
	const char *name;
	const struct attribute_group___44 **groups;
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
};

struct class_attribute___49;

struct class___49 {
	const char *name;
	struct module *owner;
	struct class_attribute___49 *class_attrs;
	struct device_attribute___49 *dev_attrs;
	const struct attribute_group___44 **dev_groups;
	struct bin_attribute___44 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *);
	void (*class_release)(struct class___49 *);
	void (*dev_release)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
	struct subsys_private *p;
};

struct class_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct class___49 *, struct class_attribute___49 *, char *);
	ssize_t (*store)(struct class___49 *, struct class_attribute___49 *, const char *, size_t);
	const void * (*namespace)(struct class___49 *, const struct class_attribute___49 *);
};

struct device_rh___49 {
	struct dev_pm_info_rh___49 power;
};

struct seq_file___44;

struct irq_chip___44 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___44 *);
	void (*irq_shutdown)(struct irq_data___44 *);
	void (*irq_enable)(struct irq_data___44 *);
	void (*irq_disable)(struct irq_data___44 *);
	void (*irq_ack)(struct irq_data___44 *);
	void (*irq_mask)(struct irq_data___44 *);
	void (*irq_mask_ack)(struct irq_data___44 *);
	void (*irq_unmask)(struct irq_data___44 *);
	void (*irq_eoi)(struct irq_data___44 *);
	int (*irq_set_affinity)(struct irq_data___44 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___44 *);
	int (*irq_set_type)(struct irq_data___44 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___44 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___44 *);
	void (*irq_bus_sync_unlock)(struct irq_data___44 *);
	void (*irq_cpu_online)(struct irq_data___44 *);
	void (*irq_cpu_offline)(struct irq_data___44 *);
	void (*irq_suspend)(struct irq_data___44 *);
	void (*irq_resume)(struct irq_data___44 *);
	void (*irq_pm_shutdown)(struct irq_data___44 *);
	void (*irq_print_chip)(struct irq_data___44 *, struct seq_file___44 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___44 *, void *);
	long unsigned int flags;
};

struct seq_operations___43;

struct seq_file___44 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___61 lock;
	const struct seq_operations___43 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___51 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___60 *page;
};

struct dentry_operations___60;

struct super_block___61;

struct dentry___61 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___61 *d_parent;
	struct qstr d_name;
	struct inode___61 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___60 *d_op;
	struct super_block___61 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___60;

struct file_lock___60;

struct dquot___60;

struct block_device___60;

struct inode___61 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___60 *i_op;
	struct super_block___61 *i_sb;
	struct address_space___60 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___61 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___60 *i_fop;
	struct file_lock___60 *i_flock;
	struct address_space___60 i_data;
	struct dquot___60 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___60 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___60 {
	int (*d_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_hash)(const struct dentry___61 *, struct qstr *);
	int (*d_compare)(const struct dentry___61 *, const struct dentry___61 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___61 *);
	void (*d_release)(struct dentry___61 *);
	void (*d_prune)(struct dentry___61 *);
	void (*d_iput)(struct dentry___61 *, struct inode___61 *);
	char * (*d_dname)(struct dentry___61 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___60 *);
	int (*d_manage)(struct dentry___61 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___60;

struct mem_dqinfo___60 {
	struct quota_format_type___60 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___60;

struct quota_info___60 {
	unsigned int flags;
	struct mutex___61 dqio_mutex;
	struct mutex___61 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___61 *files[2];
	struct mem_dqinfo___60 info[2];
	const struct quota_format_ops___60 *ops[2];
};

struct file_system_type___60;

struct super_operations___60;

struct dquot_operations___60;

struct quotactl_ops___60;

struct xattr_handler___33;

struct super_block___61 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___60 *s_type;
	const struct super_operations___60 *s_op;
	const struct dquot_operations___60 *dq_op;
	const struct quotactl_ops___60 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___61 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___33 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___60 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___60 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___61 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___60 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___60 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___61 *bd_inode;
	struct super_block___61 *bd_super;
	struct mutex___61 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___60 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___61 bd_fsfreeze_mutex;
};

struct cgroup___33;

struct cgroup_subsys_state___33 {
	struct cgroup___33 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___61 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___60 *ia_file;
};

struct dquot___60 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___61 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___61 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___60 {
	int qf_fmt_id;
	const struct quota_format_ops___60 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___60 *qf_next;
};

struct quota_format_ops___60 {
	int (*check_quota_file)(struct super_block___61 *, int);
	int (*read_file_info)(struct super_block___61 *, int);
	int (*write_file_info)(struct super_block___61 *, int);
	int (*free_file_info)(struct super_block___61 *, int);
	int (*read_dqblk)(struct dquot___60 *);
	int (*commit_dqblk)(struct dquot___60 *);
	int (*release_dqblk)(struct dquot___60 *);
};

struct dquot_operations___60 {
	int (*write_dquot)(struct dquot___60 *);
	struct dquot___60 * (*alloc_dquot)(struct super_block___61 *, int);
	void (*destroy_dquot)(struct dquot___60 *);
	int (*acquire_dquot)(struct dquot___60 *);
	int (*release_dquot)(struct dquot___60 *);
	int (*mark_dirty)(struct dquot___60 *);
	int (*write_info)(struct super_block___61 *, int);
	qsize_t * (*get_reserved_space)(struct inode___61 *);
};

struct quotactl_ops___60 {
	int (*quota_on)(struct super_block___61 *, int, int, struct path___60 *);
	int (*quota_on_meta)(struct super_block___61 *, int, int);
	int (*quota_off)(struct super_block___61 *, int);
	int (*quota_sync)(struct super_block___61 *, int);
	int (*get_info)(struct super_block___61 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___61 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___61 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___61 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___61 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___61 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___61 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___61 *, unsigned int);
};

struct address_space_operations___60 {
	int (*writepage)(struct page___60 *, struct writeback_control *);
	int (*readpage)(struct file___60 *, struct page___60 *);
	int (*writepages)(struct address_space___60 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___60 *);
	int (*readpages)(struct file___60 *, struct address_space___60 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___60 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___60 **, void **);
	int (*write_end)(struct file___60 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___60 *, void *);
	sector_t (*bmap)(struct address_space___60 *, sector_t);
	void (*invalidatepage)(struct page___60 *, long unsigned int);
	int (*releasepage)(struct page___60 *, gfp_t);
	void (*freepage)(struct page___60 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___60 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___60 *, struct page___60 *, struct page___60 *, enum migrate_mode);
	int (*launder_page)(struct page___60 *);
	int (*is_partially_uptodate)(struct page___60 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___60 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___60 *, struct page___60 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___60 *, sector_t *);
	void (*swap_deactivate)(struct file___60 *);
	void (*invalidatepage_range)(struct page___60 *, unsigned int, unsigned int);
};

struct inode_operations___60 {
	struct dentry___61 * (*lookup)(struct inode___61 *, struct dentry___61 *, unsigned int);
	void * (*follow_link)(struct dentry___61 *, struct nameidata *);
	int (*permission)(struct inode___61 *, int);
	struct posix_acl * (*get_acl)(struct inode___61 *, int);
	int (*readlink)(struct dentry___61 *, char *, int);
	void (*put_link)(struct dentry___61 *, struct nameidata *, void *);
	int (*create)(struct inode___61 *, struct dentry___61 *, umode_t, bool);
	int (*link)(struct dentry___61 *, struct inode___61 *, struct dentry___61 *);
	int (*unlink)(struct inode___61 *, struct dentry___61 *);
	int (*symlink)(struct inode___61 *, struct dentry___61 *, const char *);
	int (*mkdir)(struct inode___61 *, struct dentry___61 *, umode_t);
	int (*rmdir)(struct inode___61 *, struct dentry___61 *);
	int (*mknod)(struct inode___61 *, struct dentry___61 *, umode_t, dev_t);
	int (*rename)(struct inode___61 *, struct dentry___61 *, struct inode___61 *, struct dentry___61 *);
	int (*setattr)(struct dentry___61 *, struct iattr___61 *);
	int (*getattr)(struct vfsmount *, struct dentry___61 *, struct kstat *);
	int (*setxattr)(struct dentry___61 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___61 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___61 *, char *, size_t);
	int (*removexattr)(struct dentry___61 *, const char *);
	int (*fiemap)(struct inode___61 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___61 *, struct timespec *, int);
	int (*atomic_open)(struct inode___61 *, struct dentry___61 *, struct file___60 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___38;

struct file_operations___60 {
	struct module *owner;
	loff_t (*llseek)(struct file___60 *, loff_t, int);
	ssize_t (*read)(struct file___60 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___60 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___60 *, void *, filldir_t);
	unsigned int (*poll)(struct file___60 *, struct poll_table_struct___38 *);
	long int (*unlocked_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___60 *, struct vm_area_struct___64 *);
	int (*open)(struct inode___61 *, struct file___60 *);
	int (*flush)(struct file___60 *, fl_owner_t);
	int (*release)(struct inode___61 *, struct file___60 *);
	int (*fsync)(struct file___60 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___60 *, int);
	int (*lock)(struct file___60 *, int, struct file_lock___60 *);
	ssize_t (*sendpage)(struct file___60 *, struct page___60 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___60 *, int, struct file_lock___60 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___60 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___60 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___60 *, long int, struct file_lock___60 **, void **);
		struct {
			int (*setlease)(struct file___60 *, long int, struct file_lock___60 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___60 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___44 *, struct file___60 *);
};

struct file_lock_operations___60;

struct lock_manager_operations___60;

struct file_lock___60 {
	struct file_lock___60 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___30 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___60 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___60 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___60 *fl_ops;
	const struct lock_manager_operations___60 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___60 {
	void (*fl_copy_lock)(struct file_lock___60 *, struct file_lock___60 *);
	void (*fl_release_private)(struct file_lock___60 *);
};

struct lock_manager_operations___60 {
	int (*lm_compare_owner)(struct file_lock___60 *, struct file_lock___60 *);
	long unsigned int (*lm_owner_key)(struct file_lock___60 *);
	void (*lm_notify)(struct file_lock___60 *);
	int (*lm_grant)(struct file_lock___60 *, struct file_lock___60 *, int);
	void (*lm_break)(struct file_lock___60 *);
	int (*lm_change)(struct file_lock___60 **, int);
};

struct fasync_struct___60 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___60 *fa_next;
	struct file___60 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___60 {
	const char *name;
	int fs_flags;
	struct dentry___61 * (*mount)(struct file_system_type___60 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___61 *);
	struct module *owner;
	struct file_system_type___60 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___60 {
	struct inode___61 * (*alloc_inode)(struct super_block___61 *);
	void (*destroy_inode)(struct inode___61 *);
	void (*dirty_inode)(struct inode___61 *, int);
	int (*write_inode)(struct inode___61 *, struct writeback_control *);
	int (*drop_inode)(struct inode___61 *);
	void (*evict_inode)(struct inode___61 *);
	void (*put_super)(struct super_block___61 *);
	int (*sync_fs)(struct super_block___61 *, int);
	int (*freeze_fs)(struct super_block___61 *);
	int (*unfreeze_fs)(struct super_block___61 *);
	int (*statfs)(struct dentry___61 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___61 *, int *, char *);
	void (*umount_begin)(struct super_block___61 *);
	int (*show_options)(struct seq_file___44 *, struct dentry___61 *);
	int (*show_devname)(struct seq_file___44 *, struct dentry___61 *);
	int (*show_path)(struct seq_file___44 *, struct dentry___61 *);
	int (*show_stats)(struct seq_file___44 *, struct dentry___61 *);
	ssize_t (*quota_read)(struct super_block___61 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___61 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___61 *);
	int (*bdev_try_to_free_page)(struct super_block___61 *, struct page___60 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___61 *);
	void (*free_cached_objects)(struct super_block___61 *, int);
};

struct xattr_handler___33 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___61 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___61 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___61 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___38)(struct file___60 *, wait_queue_head_t *, struct poll_table_struct___38 *);

struct poll_table_struct___38 {
	poll_queue_proc___38 _qproc;
	long unsigned int _key;
};

struct __una_u32 {
	u32 x;
};

struct worker_pool;

struct worker {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue *current_pwq;
	bool desc_valid;
	struct list_head scheduled;
	struct task_struct___61 *task;
	struct worker_pool *pool;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	char desc[24];
	struct workqueue_struct *rescue_wq;
};

struct pool_workqueue {
	struct worker_pool *pool;
	struct workqueue_struct *wq;
	int work_color;
	int flush_color;
	int refcnt;
	int nr_in_flight[15];
	int nr_active;
	int max_active;
	struct list_head delayed_works;
	struct list_head pwqs_node;
	struct list_head mayday_node;
	struct work_struct unbound_release_work;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct worker_pool {
	spinlock_t lock;
	int cpu;
	int node;
	int id;
	unsigned int flags;
	struct list_head worklist;
	int nr_workers;
	int nr_idle;
	struct list_head idle_list;
	struct timer_list idle_timer;
	struct timer_list mayday_timer;
	struct hlist_head busy_hash[64];
	struct mutex___61 manager_arb;
	struct mutex___61 manager_mutex;
	struct idr worker_idr;
	struct workqueue_attrs *attrs;
	struct hlist_node hash_node;
	int refcnt;
	long: 32;
	long: 64;
	atomic_t nr_running;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	POOL_MANAGE_WORKERS = 1,
	POOL_DISASSOCIATED = 4,
	POOL_FREEZING = 8,
	WORKER_STARTED = 1,
	WORKER_DIE = 2,
	WORKER_IDLE = 4,
	WORKER_PREP = 8,
	WORKER_CPU_INTENSIVE = 64,
	WORKER_UNBOUND = 128,
	WORKER_REBOUND = 256,
	WORKER_NOT_RUNNING = 456,
	NR_STD_WORKER_POOLS = 2,
	UNBOUND_POOL_HASH_ORDER = 6,
	BUSY_WORKER_HASH_ORDER = 6,
	MAX_IDLE_WORKERS_RATIO = 4,
	IDLE_WORKER_TIMEOUT = 300000,
	MAYDAY_INITIAL_TIMEOUT = 10,
	MAYDAY_INTERVAL = 100,
	CREATE_COOLDOWN = 1000,
	RESCUER_NICE_LEVEL = 4294967276,
	HIGHPRI_NICE_LEVEL = 4294967276,
	WQ_NAME_LEN = 24,
};

struct wq_flusher {
	struct list_head list;
	int flush_color;
	struct completion done;
};

struct wq_device {
	struct workqueue_struct *wq;
	struct device___49 dev;
};

struct apply_wqattrs_ctx {
	struct workqueue_struct *wq;
	struct workqueue_attrs *attrs;
	struct list_head list;
	struct pool_workqueue *dfl_pwq;
	struct pool_workqueue *pwq_tbl[0];
};

struct seq_operations___43 {
	void * (*start)(struct seq_file___44 *, loff_t *);
	void (*stop)(struct seq_file___44 *, void *);
	void * (*next)(struct seq_file___44 *, void *, loff_t *);
	int (*show)(struct seq_file___44 *, void *);
};

struct cgroupfs_root___33;

struct cgroup___33 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___33 *parent;
	struct dentry___61 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___33 *subsys[11];
	struct cgroupfs_root___33 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___61 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___33 {
	struct super_block___61 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___33 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___29;

struct pmu___29 {
	struct list_head entry;
	struct device___49 *dev;
	const struct attribute_group___44 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___29 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___29 *);
	void (*pmu_disable)(struct pmu___29 *);
	int (*event_init)(struct perf_event___29 *);
	int (*add)(struct perf_event___29 *, int);
	void (*del)(struct perf_event___29 *, int);
	void (*start)(struct perf_event___29 *, int);
	void (*stop)(struct perf_event___29 *, int);
	void (*read)(struct perf_event___29 *);
	void (*start_txn)(struct pmu___29 *);
	int (*commit_txn)(struct pmu___29 *);
	void (*cancel_txn)(struct pmu___29 *);
	int (*event_idx)(struct perf_event___29 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___29 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___29 *);
};

struct perf_cpu_context___29 {
	struct perf_event_context___29 ctx;
	struct perf_event_context___29 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___29 *unique_pmu;
	struct perf_cgroup___29 *cgrp;
};

struct trace_event_functions___21;

struct trace_event___21 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___21 *funcs;
};

struct ftrace_event_class___21;

struct ftrace_event_call___21 {
	struct list_head list;
	struct ftrace_event_class___21 *class;
	char *name;
	struct trace_event___21 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___29 {
	struct cgroup_subsys_state___33 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___21 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___61 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___21)(struct trace_iterator___21 *, int, struct trace_event___21 *);

struct trace_event_functions___21 {
	trace_print_func___21 trace;
	trace_print_func___21 raw;
	trace_print_func___21 hex;
	trace_print_func___21 binary;
};

struct ftrace_event_class___21 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___21 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___21 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___21 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___21 *);
};

struct ftrace_event_file___10 {
	struct list_head list;
	struct ftrace_event_call___21 *event_call;
	struct dentry___61 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_workqueue_work {
	struct trace_entry ent;
	void *work;
	char __data[0];
};

struct ftrace_raw_workqueue_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	void *workqueue;
	unsigned int req_cpu;
	unsigned int cpu;
	char __data[0];
};

struct ftrace_raw_workqueue_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct ftrace_data_offsets_workqueue_work {};

struct ftrace_data_offsets_workqueue_queue_work {};

struct ftrace_data_offsets_workqueue_execute_start {};

struct wq_barrier {
	struct work_struct work;
	struct completion done;
};

struct work_for_cpu {
	struct work_struct work;
	long int (*fn)(void *);
	void *arg;
	long int ret;
};

struct page___61;

typedef struct page___61 *pgtable_t___61;

struct address_space___61;

struct kmem_cache___52;

struct page___61 {
	long unsigned int flags;
	struct address_space___61 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___61 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___61 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___52 *slab_cache;
		struct page___61 *first_page;
	};
	long: 64;
};

struct thread_struct___30;

struct task_struct___62;

struct pv_cpu_ops___61 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___30 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___30 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___62 *);
	void (*end_context_switch)(struct task_struct___62 *);
};

struct perf_event___30;

struct thread_struct___30 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___30 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___31;

struct pid_link___31 {
	struct hlist_node node;
	struct pid___31 *pid;
};

struct mutex___62 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___62 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___58 {
	struct page___61 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___65;

struct nsproxy___32;

struct signal_struct___61;

struct css_set___34;

struct perf_event_context___30;

struct task_struct___62 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___62 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___65 *mm;
	struct mm_struct___65 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___62 *real_parent;
	struct task_struct___62 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___62 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___31 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___61 = 0,
		VTIME_USER___61 = 1,
		VTIME_SYS___61 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___30 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___32 *nsproxy;
	struct signal_struct___61 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___34 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___30 *perf_event_ctxp[2];
	struct mutex___62 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___58 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___65 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___65 *, struct mm_struct___65 *);
	void (*dup_mmap)(struct mm_struct___65 *, struct mm_struct___65 *);
	void (*exit_mmap)(struct mm_struct___65 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___65 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___65 *);
	void (*pgd_free)(struct mm_struct___65 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___65 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___65 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___65 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___65 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___65 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___65 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___65 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___65 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___65 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___65 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___65 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___62 lock;
	void *vdso;
} mm_context_t___62;

struct xol_area___61;

struct uprobes_state___61 {
	struct xol_area___61 *xol_area;
};

struct vm_area_struct___65;

struct file___61;

struct core_state___61;

struct mm_struct___65 {
	struct vm_area_struct___65 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___65 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___65 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___62 context;
	long unsigned int flags;
	struct core_state___61 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___62 *owner;
	struct file___61 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___61 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___30 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___62 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___62 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___62 *target;
};

struct perf_sample_data___6;

typedef void (*perf_overflow_handler_t___30)(struct perf_event___30 *, struct perf_sample_data___6 *, struct pt_regs *);

struct ftrace_ops___30;

typedef void (*ftrace_func_t___30)(long unsigned int, long unsigned int, struct ftrace_ops___30 *, struct pt_regs *);

struct ftrace_ops___30 {
	ftrace_func_t___30 func;
	struct ftrace_ops___30 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___62 regex_lock;
};

struct pmu___30;

struct fasync_struct___61;

struct pid_namespace___31;

struct ftrace_event_call___22;

struct perf_cgroup___30;

struct perf_event___30 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___30 *group_leader;
	struct pmu___30 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___30 hw;
	struct perf_event_context___30 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___62 child_mutex;
	struct list_head child_list;
	struct perf_event___30 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___62 *owner;
	struct mutex___62 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___61 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___30 *);
	struct callback_head callback_head;
	struct pid_namespace___31 *ns;
	u64 id;
	perf_overflow_handler_t___30 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___22 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___30 ftrace_ops;
	struct perf_cgroup___30 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___61;

struct lruvec___61 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___61 *zone;
};

struct pglist_data___61;

struct zone___61 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___61 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___61 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___61 {
	struct zone___61 *zone;
	int zone_idx;
};

struct zonelist___61 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___61 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___61 {
	struct zone___61 node_zones[4];
	struct zonelist___61 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___62 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___45;

struct x86_io_apic_ops___45 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___45 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___45;

struct irq_data___45 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___45 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___50;

struct dev_pm_ops___50 {
	int (*prepare)(struct device___50 *);
	void (*complete)(struct device___50 *);
	int (*suspend)(struct device___50 *);
	int (*resume)(struct device___50 *);
	int (*freeze)(struct device___50 *);
	int (*thaw)(struct device___50 *);
	int (*poweroff)(struct device___50 *);
	int (*restore)(struct device___50 *);
	int (*suspend_late)(struct device___50 *);
	int (*resume_early)(struct device___50 *);
	int (*freeze_late)(struct device___50 *);
	int (*thaw_early)(struct device___50 *);
	int (*poweroff_late)(struct device___50 *);
	int (*restore_early)(struct device___50 *);
	int (*suspend_noirq)(struct device___50 *);
	int (*resume_noirq)(struct device___50 *);
	int (*freeze_noirq)(struct device___50 *);
	int (*thaw_noirq)(struct device___50 *);
	int (*poweroff_noirq)(struct device___50 *);
	int (*restore_noirq)(struct device___50 *);
	int (*runtime_suspend)(struct device___50 *);
	int (*runtime_resume)(struct device___50 *);
	int (*runtime_idle)(struct device___50 *);
};

struct dma_map_ops___25;

struct dev_archdata___25 {
	struct dma_map_ops___25 *dma_ops;
	void *iommu;
};

struct device_type___50;

struct bus_type___50;

struct device_driver___50;

struct dev_pm_domain___50;

struct class___50;

struct attribute_group___45;

struct device_rh___50;

struct device___50 {
	struct device___50 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___50 *type;
	struct mutex___62 mutex;
	struct bus_type___50 *bus;
	struct device_driver___50 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___50 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___25 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___50 *class;
	const struct attribute_group___45 **groups;
	void (*release)(struct device___50 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___50 *device_rh;
};

struct dev_pm_info_rh___50 {
	void (*set_latency_tolerance)(struct device___50 *, s32);
};

struct dev_pm_domain___50 {
	struct dev_pm_ops___50 ops;
};

struct smp_ops___61 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___62 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___61 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___61 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___52;

struct memcg_cache_params___52;

struct kmem_cache___52 {
	struct kmem_cache_cpu___52 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___52 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___62;

struct address_space_operations___61;

struct address_space___61 {
	struct inode___62 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___62 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___61 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___62;

struct path___61 {
	struct vfsmount *mnt;
	struct dentry___62 *dentry;
};

struct fown_struct___31 {
	rwlock_t lock;
	struct pid___31 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___61;

struct file___61 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___61 f_path;
	struct inode___62 *f_inode;
	const struct file_operations___61 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___31 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___61 *f_mapping;
	struct mutex___62 f_pos_lock;
};

struct vm_operations_struct___55;

struct vm_area_struct___65 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___65 *vm_next;
	struct vm_area_struct___65 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___65 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___55 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___61 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___52;

struct vm_operations_struct___55 {
	void (*open)(struct vm_area_struct___65 *);
	void (*close)(struct vm_area_struct___65 *);
	int (*fault)(struct vm_area_struct___65 *, struct vm_fault___52 *);
	int (*page_mkwrite)(struct vm_area_struct___65 *, struct vm_fault___52 *);
	int (*access)(struct vm_area_struct___65 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___65 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___65 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___65 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___65 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___61 {
	struct task_struct___62 *task;
	struct core_thread___61 *next;
};

struct core_state___61 {
	atomic_t nr_threads;
	struct core_thread___61 dumper;
	struct completion startup;
};

struct vm_fault___52 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___61 *page;
};

struct bin_attribute___45;

struct attribute_group___45 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___45 **bin_attrs;
};

struct bin_attribute___45 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___61 *, struct kobject___3 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___61 *, struct kobject___3 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	int (*mmap)(struct file___61 *, struct kobject___3 *, struct bin_attribute___45 *, struct vm_area_struct___65 *);
};

struct kmem_cache_cpu___52 {
	void **freelist;
	long unsigned int tid;
	struct page___61 *page;
	struct page___61 *partial;
};

struct memcg_cache_params___52 {
	bool is_root_cache;
	union {
		struct kmem_cache___52 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___52 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct upid___31 {
	int nr;
	struct pid_namespace___31 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___31 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___62 *child_reaper;
	struct kmem_cache___52 *pid_cachep;
	unsigned int level;
	struct pid_namespace___31 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___62 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___31 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___31 numbers[1];
};

struct ctl_table_header___8;

struct ctl_node___8 {
	struct rb_node node;
	struct ctl_table_header___8 *header;
};

struct ctl_table_root___8;

struct ctl_table_set___8;

struct ctl_dir___8;

struct ctl_table_header___8 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___8 *root;
	struct ctl_table_set___8 *set;
	struct ctl_dir___8 *parent;
	struct ctl_node___8 *node;
};

struct ctl_dir___8 {
	struct ctl_table_header___8 header;
	struct rb_root root;
};

struct ctl_table_set___8 {
	int (*is_seen)(struct ctl_table_set___8 *);
	struct ctl_dir___8 dir;
};

struct ctl_table_root___8 {
	struct ctl_table_set___8 default_set;
	struct ctl_table_set___8 * (*lookup)(struct ctl_table_root___8 *, struct nsproxy___32 *);
	int (*permissions)(struct ctl_table_header___8 *, struct ctl_table *);
};

struct net___9;

struct nsproxy___32 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___31 *pid_ns;
	struct net___9 *net_ns;
};

struct signal_struct___61 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___62 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___62 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___31 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___31 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___62 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___34;

struct css_set___34 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___34 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___30 {
	struct pmu___30 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___62 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___62 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___30 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct netns_core___8 {
	struct ctl_table_header___8 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___8 {
	struct mutex___62 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___8 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___8 *ctl;
};

struct netns_ipv4___8 {
	struct ctl_table_header___8 *forw_hdr;
	struct ctl_table_header___8 *frags_hdr;
	struct ctl_table_header___8 *ipv4_hdr;
	struct ctl_table_header___8 *route_hdr;
	struct ctl_table_header___8 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___8 {
	struct ctl_table_header___8 *hdr;
	struct ctl_table_header___8 *route_hdr;
	struct ctl_table_header___8 *icmp_hdr;
	struct ctl_table_header___8 *frags_hdr;
	struct ctl_table_header___8 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___8 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___8 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *);
	int (*local_out)(struct sk_buff___5 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___5 *, const void *);
	struct kmem_cache___52 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___8 {
	struct netns_sysctl_ipv6___8 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___8 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___8 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___8 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___8 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___8 *nf_log_dir_header;
};

struct nf_proto_net___8 {
	struct ctl_table_header___8 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___8 {
	struct nf_proto_net___8 pn;
	unsigned int timeout;
};

struct nf_tcp_net___8 {
	struct nf_proto_net___8 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___8 {
	struct nf_proto_net___8 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___8 {
	struct nf_proto_net___8 pn;
	unsigned int timeout;
};

struct nf_ip_net___8 {
	struct nf_generic_net___8 generic;
	struct nf_tcp_net___8 tcp;
	struct nf_udp_net___8 udp;
	struct nf_icmp_net___8 icmp;
	struct nf_icmp_net___8 icmpv6;
};

struct netns_ct___8 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___8 *sysctl_header;
	struct ctl_table_header___8 *acct_sysctl_header;
	struct ctl_table_header___8 *tstamp_sysctl_header;
	struct ctl_table_header___8 *event_sysctl_header;
	struct ctl_table_header___8 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___52 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___8 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___8 {
	struct netns_sysctl_ipv6___8 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___8 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___8 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___8 xfrm4_dst_ops;
	struct dst_ops___8 xfrm6_dst_ops;
};

struct net___9 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___8 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___8 core;
	struct netns_mib mib;
	struct netns_packet___8 packet;
	struct netns_unix___8 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___8 ipv4;
	struct netns_ipv6___8 ipv6;
	struct netns_sctp___8 sctp;
	struct netns_dccp___3 dccp;
	struct netns_nf___8 nf;
	struct netns_xt xt;
	struct netns_ct___8 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___8 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___8 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___62 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___62 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___61;

struct super_block___62;

struct dentry___62 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___62 *d_parent;
	struct qstr d_name;
	struct inode___62 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___61 *d_op;
	struct super_block___62 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___61;

struct file_lock___61;

struct dquot___61;

struct block_device___61;

struct inode___62 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___61 *i_op;
	struct super_block___62 *i_sb;
	struct address_space___61 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___62 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___61 *i_fop;
	struct file_lock___61 *i_flock;
	struct address_space___61 i_data;
	struct dquot___61 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___61 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___61 {
	int (*d_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_hash)(const struct dentry___62 *, struct qstr *);
	int (*d_compare)(const struct dentry___62 *, const struct dentry___62 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___62 *);
	void (*d_release)(struct dentry___62 *);
	void (*d_prune)(struct dentry___62 *);
	void (*d_iput)(struct dentry___62 *, struct inode___62 *);
	char * (*d_dname)(struct dentry___62 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___61 *);
	int (*d_manage)(struct dentry___62 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___61;

struct mem_dqinfo___61 {
	struct quota_format_type___61 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___61;

struct quota_info___61 {
	unsigned int flags;
	struct mutex___62 dqio_mutex;
	struct mutex___62 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___62 *files[2];
	struct mem_dqinfo___61 info[2];
	const struct quota_format_ops___61 *ops[2];
};

struct file_system_type___61;

struct super_operations___61;

struct dquot_operations___61;

struct quotactl_ops___61;

struct xattr_handler___34;

struct super_block___62 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___61 *s_type;
	const struct super_operations___61 *s_op;
	const struct dquot_operations___61 *dq_op;
	const struct quotactl_ops___61 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___62 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___34 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___61 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___61 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___62 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___61 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___61 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___62 *bd_inode;
	struct super_block___62 *bd_super;
	struct mutex___62 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___61 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___62 bd_fsfreeze_mutex;
};

struct cgroup___34;

struct cgroup_subsys_state___34 {
	struct cgroup___34 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___62 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___61 *ia_file;
};

struct dquot___61 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___62 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___62 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___61 {
	int qf_fmt_id;
	const struct quota_format_ops___61 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___61 *qf_next;
};

struct quota_format_ops___61 {
	int (*check_quota_file)(struct super_block___62 *, int);
	int (*read_file_info)(struct super_block___62 *, int);
	int (*write_file_info)(struct super_block___62 *, int);
	int (*free_file_info)(struct super_block___62 *, int);
	int (*read_dqblk)(struct dquot___61 *);
	int (*commit_dqblk)(struct dquot___61 *);
	int (*release_dqblk)(struct dquot___61 *);
};

struct dquot_operations___61 {
	int (*write_dquot)(struct dquot___61 *);
	struct dquot___61 * (*alloc_dquot)(struct super_block___62 *, int);
	void (*destroy_dquot)(struct dquot___61 *);
	int (*acquire_dquot)(struct dquot___61 *);
	int (*release_dquot)(struct dquot___61 *);
	int (*mark_dirty)(struct dquot___61 *);
	int (*write_info)(struct super_block___62 *, int);
	qsize_t * (*get_reserved_space)(struct inode___62 *);
};

struct quotactl_ops___61 {
	int (*quota_on)(struct super_block___62 *, int, int, struct path___61 *);
	int (*quota_on_meta)(struct super_block___62 *, int, int);
	int (*quota_off)(struct super_block___62 *, int);
	int (*quota_sync)(struct super_block___62 *, int);
	int (*get_info)(struct super_block___62 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___62 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___62 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___62 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___62 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___62 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___62 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___62 *, unsigned int);
};

struct address_space_operations___61 {
	int (*writepage)(struct page___61 *, struct writeback_control *);
	int (*readpage)(struct file___61 *, struct page___61 *);
	int (*writepages)(struct address_space___61 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___61 *);
	int (*readpages)(struct file___61 *, struct address_space___61 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___61 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___61 **, void **);
	int (*write_end)(struct file___61 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___61 *, void *);
	sector_t (*bmap)(struct address_space___61 *, sector_t);
	void (*invalidatepage)(struct page___61 *, long unsigned int);
	int (*releasepage)(struct page___61 *, gfp_t);
	void (*freepage)(struct page___61 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___61 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___61 *, struct page___61 *, struct page___61 *, enum migrate_mode);
	int (*launder_page)(struct page___61 *);
	int (*is_partially_uptodate)(struct page___61 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___61 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___61 *, struct page___61 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___61 *, sector_t *);
	void (*swap_deactivate)(struct file___61 *);
	void (*invalidatepage_range)(struct page___61 *, unsigned int, unsigned int);
};

struct inode_operations___61 {
	struct dentry___62 * (*lookup)(struct inode___62 *, struct dentry___62 *, unsigned int);
	void * (*follow_link)(struct dentry___62 *, struct nameidata *);
	int (*permission)(struct inode___62 *, int);
	struct posix_acl * (*get_acl)(struct inode___62 *, int);
	int (*readlink)(struct dentry___62 *, char *, int);
	void (*put_link)(struct dentry___62 *, struct nameidata *, void *);
	int (*create)(struct inode___62 *, struct dentry___62 *, umode_t, bool);
	int (*link)(struct dentry___62 *, struct inode___62 *, struct dentry___62 *);
	int (*unlink)(struct inode___62 *, struct dentry___62 *);
	int (*symlink)(struct inode___62 *, struct dentry___62 *, const char *);
	int (*mkdir)(struct inode___62 *, struct dentry___62 *, umode_t);
	int (*rmdir)(struct inode___62 *, struct dentry___62 *);
	int (*mknod)(struct inode___62 *, struct dentry___62 *, umode_t, dev_t);
	int (*rename)(struct inode___62 *, struct dentry___62 *, struct inode___62 *, struct dentry___62 *);
	int (*setattr)(struct dentry___62 *, struct iattr___62 *);
	int (*getattr)(struct vfsmount *, struct dentry___62 *, struct kstat *);
	int (*setxattr)(struct dentry___62 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___62 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___62 *, char *, size_t);
	int (*removexattr)(struct dentry___62 *, const char *);
	int (*fiemap)(struct inode___62 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___62 *, struct timespec *, int);
	int (*atomic_open)(struct inode___62 *, struct dentry___62 *, struct file___61 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___39;

struct seq_file___45;

struct file_operations___61 {
	struct module *owner;
	loff_t (*llseek)(struct file___61 *, loff_t, int);
	ssize_t (*read)(struct file___61 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___61 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___61 *, void *, filldir_t);
	unsigned int (*poll)(struct file___61 *, struct poll_table_struct___39 *);
	long int (*unlocked_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___61 *, struct vm_area_struct___65 *);
	int (*open)(struct inode___62 *, struct file___61 *);
	int (*flush)(struct file___61 *, fl_owner_t);
	int (*release)(struct inode___62 *, struct file___61 *);
	int (*fsync)(struct file___61 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___61 *, int);
	int (*lock)(struct file___61 *, int, struct file_lock___61 *);
	ssize_t (*sendpage)(struct file___61 *, struct page___61 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___61 *, int, struct file_lock___61 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___61 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___61 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___61 *, long int, struct file_lock___61 **, void **);
		struct {
			int (*setlease)(struct file___61 *, long int, struct file_lock___61 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___61 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___45 *, struct file___61 *);
};

struct file_lock_operations___61;

struct lock_manager_operations___61;

struct file_lock___61 {
	struct file_lock___61 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___31 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___61 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___61 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___61 *fl_ops;
	const struct lock_manager_operations___61 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___61 {
	void (*fl_copy_lock)(struct file_lock___61 *, struct file_lock___61 *);
	void (*fl_release_private)(struct file_lock___61 *);
};

struct lock_manager_operations___61 {
	int (*lm_compare_owner)(struct file_lock___61 *, struct file_lock___61 *);
	long unsigned int (*lm_owner_key)(struct file_lock___61 *);
	void (*lm_notify)(struct file_lock___61 *);
	int (*lm_grant)(struct file_lock___61 *, struct file_lock___61 *, int);
	void (*lm_break)(struct file_lock___61 *);
	int (*lm_change)(struct file_lock___61 **, int);
};

struct fasync_struct___61 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___61 *fa_next;
	struct file___61 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___61 {
	const char *name;
	int fs_flags;
	struct dentry___62 * (*mount)(struct file_system_type___61 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___62 *);
	struct module *owner;
	struct file_system_type___61 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___61 {
	struct inode___62 * (*alloc_inode)(struct super_block___62 *);
	void (*destroy_inode)(struct inode___62 *);
	void (*dirty_inode)(struct inode___62 *, int);
	int (*write_inode)(struct inode___62 *, struct writeback_control *);
	int (*drop_inode)(struct inode___62 *);
	void (*evict_inode)(struct inode___62 *);
	void (*put_super)(struct super_block___62 *);
	int (*sync_fs)(struct super_block___62 *, int);
	int (*freeze_fs)(struct super_block___62 *);
	int (*unfreeze_fs)(struct super_block___62 *);
	int (*statfs)(struct dentry___62 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___62 *, int *, char *);
	void (*umount_begin)(struct super_block___62 *);
	int (*show_options)(struct seq_file___45 *, struct dentry___62 *);
	int (*show_devname)(struct seq_file___45 *, struct dentry___62 *);
	int (*show_path)(struct seq_file___45 *, struct dentry___62 *);
	int (*show_stats)(struct seq_file___45 *, struct dentry___62 *);
	ssize_t (*quota_read)(struct super_block___62 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___62 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___62 *);
	int (*bdev_try_to_free_page)(struct super_block___62 *, struct page___61 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___62 *);
	void (*free_cached_objects)(struct super_block___62 *, int);
};

struct xattr_handler___34 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___62 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___62 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___62 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___39)(struct file___61 *, wait_queue_head_t *, struct poll_table_struct___39 *);

struct poll_table_struct___39 {
	poll_queue_proc___39 _qproc;
	long unsigned int _key;
};

struct seq_operations___44;

struct seq_file___45 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___62 lock;
	const struct seq_operations___44 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dma_map_ops___25 {
	void * (*alloc)(struct device___50 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___50 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___50 *, struct vm_area_struct___65 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___50 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___50 *, struct page___61 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___50 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___50 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___50 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___50 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___50 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___50 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___50 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___50 *, dma_addr_t);
	int (*dma_supported)(struct device___50 *, u64);
	int (*set_dma_mask)(struct device___50 *, u64);
	int is_phys;
};

struct bus_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___50 *, char *);
	ssize_t (*store)(struct bus_type___50 *, const char *, size_t);
};

struct device_attribute___50;

struct driver_attribute___50;

struct bus_type___50 {
	const char *name;
	const char *dev_name;
	struct device___50 *dev_root;
	struct bus_attribute___50 *bus_attrs;
	struct device_attribute___50 *dev_attrs;
	struct driver_attribute___50 *drv_attrs;
	const struct attribute_group___45 **bus_groups;
	const struct attribute_group___45 **dev_groups;
	const struct attribute_group___45 **drv_groups;
	int (*match)(struct device___50 *, struct device_driver___50 *);
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	int (*probe)(struct device___50 *);
	int (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*online)(struct device___50 *);
	int (*offline)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct device___50 *, struct device_attribute___50 *, char *);
	ssize_t (*store)(struct device___50 *, struct device_attribute___50 *, const char *, size_t);
};

struct driver_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___50 *, char *);
	ssize_t (*store)(struct device_driver___50 *, const char *, size_t);
};

struct device_driver___50 {
	const char *name;
	struct bus_type___50 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___50 *);
	int (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	const struct attribute_group___45 **groups;
	const struct dev_pm_ops___50 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___50 {
	const char *name;
	const struct attribute_group___45 **groups;
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
};

struct class_attribute___50;

struct class___50 {
	const char *name;
	struct module *owner;
	struct class_attribute___50 *class_attrs;
	struct device_attribute___50 *dev_attrs;
	const struct attribute_group___45 **dev_groups;
	struct bin_attribute___45 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *);
	void (*class_release)(struct class___50 *);
	void (*dev_release)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
	struct subsys_private *p;
};

struct class_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct class___50 *, struct class_attribute___50 *, char *);
	ssize_t (*store)(struct class___50 *, struct class_attribute___50 *, const char *, size_t);
	const void * (*namespace)(struct class___50 *, const struct class_attribute___50 *);
};

struct device_rh___50 {
	struct dev_pm_info_rh___50 power;
};

struct nf_afinfo___8 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___5 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___5 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___9 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___5 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___5 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___45 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___45 *);
	void (*irq_shutdown)(struct irq_data___45 *);
	void (*irq_enable)(struct irq_data___45 *);
	void (*irq_disable)(struct irq_data___45 *);
	void (*irq_ack)(struct irq_data___45 *);
	void (*irq_mask)(struct irq_data___45 *);
	void (*irq_mask_ack)(struct irq_data___45 *);
	void (*irq_unmask)(struct irq_data___45 *);
	void (*irq_eoi)(struct irq_data___45 *);
	int (*irq_set_affinity)(struct irq_data___45 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___45 *);
	int (*irq_set_type)(struct irq_data___45 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___45 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___45 *);
	void (*irq_bus_sync_unlock)(struct irq_data___45 *);
	void (*irq_cpu_online)(struct irq_data___45 *);
	void (*irq_cpu_offline)(struct irq_data___45 *);
	void (*irq_suspend)(struct irq_data___45 *);
	void (*irq_resume)(struct irq_data___45 *);
	void (*irq_pm_shutdown)(struct irq_data___45 *);
	void (*irq_print_chip)(struct irq_data___45 *, struct seq_file___45 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___45 *, void *);
	long unsigned int flags;
};

struct seq_operations___44 {
	void * (*start)(struct seq_file___45 *, loff_t *);
	void (*stop)(struct seq_file___45 *, void *);
	void * (*next)(struct seq_file___45 *, void *, loff_t *);
	int (*show)(struct seq_file___45 *, void *);
};

struct cgroupfs_root___34;

struct cgroup___34 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___34 *parent;
	struct dentry___62 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___34 *subsys[11];
	struct cgroupfs_root___34 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___62 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___34 {
	struct super_block___62 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___34 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___30;

struct pmu___30 {
	struct list_head entry;
	struct device___50 *dev;
	const struct attribute_group___45 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___30 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___30 *);
	void (*pmu_disable)(struct pmu___30 *);
	int (*event_init)(struct perf_event___30 *);
	int (*add)(struct perf_event___30 *, int);
	void (*del)(struct perf_event___30 *, int);
	void (*start)(struct perf_event___30 *, int);
	void (*stop)(struct perf_event___30 *, int);
	void (*read)(struct perf_event___30 *);
	void (*start_txn)(struct pmu___30 *);
	int (*commit_txn)(struct pmu___30 *);
	void (*cancel_txn)(struct pmu___30 *);
	int (*event_idx)(struct perf_event___30 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___30 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___30 *);
};

struct perf_cpu_context___30 {
	struct perf_event_context___30 ctx;
	struct perf_event_context___30 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___30 *unique_pmu;
	struct perf_cgroup___30 *cgrp;
};

struct perf_sample_data___6 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_functions___22;

struct trace_event___22 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___22 *funcs;
};

struct ftrace_event_class___22;

struct ftrace_event_call___22 {
	struct list_head list;
	struct ftrace_event_class___22 *class;
	char *name;
	struct trace_event___22 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___30 {
	struct cgroup_subsys_state___34 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___22 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___62 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___22)(struct trace_iterator___22 *, int, struct trace_event___22 *);

struct trace_event_functions___22 {
	trace_print_func___22 trace;
	trace_print_func___22 raw;
	trace_print_func___22 hex;
	trace_print_func___22 binary;
};

struct ftrace_event_class___22 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___22 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___22 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___22 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___22 *);
};

typedef void (*task_work_func_t)(struct callback_head *);

struct page___62;

typedef struct page___62 *pgtable_t___62;

struct address_space___62;

struct kmem_cache___53;

struct page___62 {
	long unsigned int flags;
	struct address_space___62 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___62 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___62 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___53 *slab_cache;
		struct page___62 *first_page;
	};
	long: 64;
};

struct thread_struct___31;

struct task_struct___63;

struct pv_cpu_ops___62 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___31 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___31 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___63 *);
	void (*end_context_switch)(struct task_struct___63 *);
};

struct perf_event___31;

struct thread_struct___31 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___31 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___32;

struct pid_link___32 {
	struct hlist_node node;
	struct pid___32 *pid;
};

struct mutex___63 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___63 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___59 {
	struct page___62 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___66;

struct nsproxy___33;

struct signal_struct___62;

struct css_set___35;

struct perf_event_context___31;

struct task_struct___63 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___63 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___66 *mm;
	struct mm_struct___66 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___63 *real_parent;
	struct task_struct___63 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___63 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___32 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___62 = 0,
		VTIME_USER___62 = 1,
		VTIME_SYS___62 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___31 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___33 *nsproxy;
	struct signal_struct___62 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___35 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___31 *perf_event_ctxp[2];
	struct mutex___63 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___59 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___66 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___66 *, struct mm_struct___66 *);
	void (*dup_mmap)(struct mm_struct___66 *, struct mm_struct___66 *);
	void (*exit_mmap)(struct mm_struct___66 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___66 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___66 *);
	void (*pgd_free)(struct mm_struct___66 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___66 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___66 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___66 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___66 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___66 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___66 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___66 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___66 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___66 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___66 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___66 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___63 lock;
	void *vdso;
} mm_context_t___63;

struct xol_area___62;

struct uprobes_state___62 {
	struct xol_area___62 *xol_area;
};

struct vm_area_struct___66;

struct file___62;

struct core_state___62;

struct mm_struct___66 {
	struct vm_area_struct___66 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___66 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___66 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___63 context;
	long unsigned int flags;
	struct core_state___62 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___63 *owner;
	struct file___62 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___62 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___39;

struct exec_domain___17 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___39 *module;
	struct exec_domain___17 *next;
};

struct module_kobject___38 {
	struct kobject___3 kobj;
	struct module___39 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___38;

struct ftrace_event_call___23;

struct module___39 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___38 mkobj;
	struct module_attribute___38 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___23 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___63 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___31 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___63 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___63 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___63 *target;
};

typedef void (*perf_overflow_handler_t___31)(struct perf_event___31 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___31;

typedef void (*ftrace_func_t___31)(long unsigned int, long unsigned int, struct ftrace_ops___31 *, struct pt_regs *);

struct ftrace_ops___31 {
	ftrace_func_t___31 func;
	struct ftrace_ops___31 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___63 regex_lock;
};

struct pmu___31;

struct fasync_struct___62;

struct pid_namespace___32;

struct perf_cgroup___31;

struct perf_event___31 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___31 *group_leader;
	struct pmu___31 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___31 hw;
	struct perf_event_context___31 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___63 child_mutex;
	struct list_head child_list;
	struct perf_event___31 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___63 *owner;
	struct mutex___63 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___62 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___31 *);
	struct callback_head callback_head;
	struct pid_namespace___32 *ns;
	u64 id;
	perf_overflow_handler_t___31 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___23 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___31 ftrace_ops;
	struct perf_cgroup___31 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___28 {
	struct task_struct___63 *task;
	struct exec_domain___17 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___46;

struct x86_io_apic_ops___46 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___46 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___46;

struct irq_data___46 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___46 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___51;

struct dev_pm_ops___51 {
	int (*prepare)(struct device___51 *);
	void (*complete)(struct device___51 *);
	int (*suspend)(struct device___51 *);
	int (*resume)(struct device___51 *);
	int (*freeze)(struct device___51 *);
	int (*thaw)(struct device___51 *);
	int (*poweroff)(struct device___51 *);
	int (*restore)(struct device___51 *);
	int (*suspend_late)(struct device___51 *);
	int (*resume_early)(struct device___51 *);
	int (*freeze_late)(struct device___51 *);
	int (*thaw_early)(struct device___51 *);
	int (*poweroff_late)(struct device___51 *);
	int (*restore_early)(struct device___51 *);
	int (*suspend_noirq)(struct device___51 *);
	int (*resume_noirq)(struct device___51 *);
	int (*freeze_noirq)(struct device___51 *);
	int (*thaw_noirq)(struct device___51 *);
	int (*poweroff_noirq)(struct device___51 *);
	int (*restore_noirq)(struct device___51 *);
	int (*runtime_suspend)(struct device___51 *);
	int (*runtime_resume)(struct device___51 *);
	int (*runtime_idle)(struct device___51 *);
};

struct device_type___51;

struct bus_type___51;

struct device_driver___51;

struct dev_pm_domain___51;

struct class___51;

struct attribute_group___46;

struct device_rh___51;

struct device___51 {
	struct device___51 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___51 *type;
	struct mutex___63 mutex;
	struct bus_type___51 *bus;
	struct device_driver___51 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___51 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___25 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___51 *class;
	const struct attribute_group___46 **groups;
	void (*release)(struct device___51 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___51 *device_rh;
};

struct dev_pm_info_rh___51 {
	void (*set_latency_tolerance)(struct device___51 *, s32);
};

struct dev_pm_domain___51 {
	struct dev_pm_ops___51 ops;
};

struct smp_ops___62 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___63 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___62;

struct lruvec___62 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___62 *zone;
};

struct pglist_data___62;

struct zone___62 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___62 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___62 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___62 {
	struct zone___62 *zone;
	int zone_idx;
};

struct zonelist___62 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___62 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___62 {
	struct zone___62 node_zones[4];
	struct zonelist___62 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___63 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void call_rcu_func_t(struct callback_head *, void (*)(struct callback_head *));

struct seq_file___46;

struct irq_chip___46 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___46 *);
	void (*irq_shutdown)(struct irq_data___46 *);
	void (*irq_enable)(struct irq_data___46 *);
	void (*irq_disable)(struct irq_data___46 *);
	void (*irq_ack)(struct irq_data___46 *);
	void (*irq_mask)(struct irq_data___46 *);
	void (*irq_mask_ack)(struct irq_data___46 *);
	void (*irq_unmask)(struct irq_data___46 *);
	void (*irq_eoi)(struct irq_data___46 *);
	int (*irq_set_affinity)(struct irq_data___46 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___46 *);
	int (*irq_set_type)(struct irq_data___46 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___46 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___46 *);
	void (*irq_bus_sync_unlock)(struct irq_data___46 *);
	void (*irq_cpu_online)(struct irq_data___46 *);
	void (*irq_cpu_offline)(struct irq_data___46 *);
	void (*irq_suspend)(struct irq_data___46 *);
	void (*irq_resume)(struct irq_data___46 *);
	void (*irq_pm_shutdown)(struct irq_data___46 *);
	void (*irq_print_chip)(struct irq_data___46 *, struct seq_file___46 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___46 *, void *);
	long unsigned int flags;
};

struct seq_operations___45;

struct seq_file___46 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___63 lock;
	const struct seq_operations___45 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___62 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___62 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___53;

struct memcg_cache_params___53;

struct kmem_cache___53 {
	struct kmem_cache_cpu___53 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___53 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___63;

struct address_space_operations___62;

struct address_space___62 {
	struct inode___63 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___63 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___62 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___63;

struct path___62 {
	struct vfsmount *mnt;
	struct dentry___63 *dentry;
};

struct fown_struct___32 {
	rwlock_t lock;
	struct pid___32 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___62;

struct file___62 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___62 f_path;
	struct inode___63 *f_inode;
	const struct file_operations___62 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___32 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___62 *f_mapping;
	struct mutex___63 f_pos_lock;
};

struct vm_operations_struct___56;

struct vm_area_struct___66 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___66 *vm_next;
	struct vm_area_struct___66 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___66 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___56 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___62 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___53;

struct vm_operations_struct___56 {
	void (*open)(struct vm_area_struct___66 *);
	void (*close)(struct vm_area_struct___66 *);
	int (*fault)(struct vm_area_struct___66 *, struct vm_fault___53 *);
	int (*page_mkwrite)(struct vm_area_struct___66 *, struct vm_fault___53 *);
	int (*access)(struct vm_area_struct___66 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___66 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___66 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___66 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___66 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___62 {
	struct task_struct___63 *task;
	struct core_thread___62 *next;
};

struct core_state___62 {
	atomic_t nr_threads;
	struct core_thread___62 dumper;
	struct completion startup;
};

struct upid___32 {
	int nr;
	struct pid_namespace___32 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___32 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___63 *child_reaper;
	struct kmem_cache___53 *pid_cachep;
	unsigned int level;
	struct pid_namespace___32 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___63 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___32 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___32 numbers[1];
};

struct nsproxy___33 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___32 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___62 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___63 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___63 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___32 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___32 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___63 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___35;

struct css_set___35 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___35 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___31 {
	struct pmu___31 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___63 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___63 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___31 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___46;

struct attribute_group___46 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___46 **bin_attrs;
};

struct bin_attribute___46 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___62 *, struct kobject___3 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___62 *, struct kobject___3 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	int (*mmap)(struct file___62 *, struct kobject___3 *, struct bin_attribute___46 *, struct vm_area_struct___66 *);
};

struct bus_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___51 *, char *);
	ssize_t (*store)(struct bus_type___51 *, const char *, size_t);
};

struct device_attribute___51;

struct driver_attribute___51;

struct bus_type___51 {
	const char *name;
	const char *dev_name;
	struct device___51 *dev_root;
	struct bus_attribute___51 *bus_attrs;
	struct device_attribute___51 *dev_attrs;
	struct driver_attribute___51 *drv_attrs;
	const struct attribute_group___46 **bus_groups;
	const struct attribute_group___46 **dev_groups;
	const struct attribute_group___46 **drv_groups;
	int (*match)(struct device___51 *, struct device_driver___51 *);
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	int (*probe)(struct device___51 *);
	int (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*online)(struct device___51 *);
	int (*offline)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct device___51 *, struct device_attribute___51 *, char *);
	ssize_t (*store)(struct device___51 *, struct device_attribute___51 *, const char *, size_t);
};

struct driver_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___51 *, char *);
	ssize_t (*store)(struct device_driver___51 *, const char *, size_t);
};

struct device_driver___51 {
	const char *name;
	struct bus_type___51 *bus;
	struct module___39 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___51 *);
	int (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	const struct attribute_group___46 **groups;
	const struct dev_pm_ops___51 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___51 {
	const char *name;
	const struct attribute_group___46 **groups;
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
};

struct class_attribute___51;

struct class___51 {
	const char *name;
	struct module___39 *owner;
	struct class_attribute___51 *class_attrs;
	struct device_attribute___51 *dev_attrs;
	const struct attribute_group___46 **dev_groups;
	struct bin_attribute___46 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *);
	void (*class_release)(struct class___51 *);
	void (*dev_release)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
	struct subsys_private *p;
};

struct class_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct class___51 *, struct class_attribute___51 *, char *);
	ssize_t (*store)(struct class___51 *, struct class_attribute___51 *, const char *, size_t);
	const void * (*namespace)(struct class___51 *, const struct class_attribute___51 *);
};

struct device_rh___51 {
	struct dev_pm_info_rh___51 power;
};

struct module_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___38 *, struct module_kobject___38 *, char *);
	ssize_t (*store)(struct module_attribute___38 *, struct module_kobject___38 *, const char *, size_t);
	void (*setup)(struct module___39 *, const char *);
	int (*test)(struct module___39 *);
	void (*free)(struct module___39 *);
};

struct trace_event_functions___23;

struct trace_event___23 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___23 *funcs;
};

struct ftrace_event_class___23;

struct ftrace_event_call___23 {
	struct list_head list;
	struct ftrace_event_class___23 *class;
	char *name;
	struct trace_event___23 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct vm_fault___53 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___62 *page;
};

struct seq_operations___45 {
	void * (*start)(struct seq_file___46 *, loff_t *);
	void (*stop)(struct seq_file___46 *, void *);
	void * (*next)(struct seq_file___46 *, void *, loff_t *);
	int (*show)(struct seq_file___46 *, void *);
};

struct dentry_operations___62;

struct super_block___63;

struct dentry___63 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___63 *d_parent;
	struct qstr d_name;
	struct inode___63 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___62 *d_op;
	struct super_block___63 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___62;

struct file_lock___62;

struct dquot___62;

struct block_device___62;

struct inode___63 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___62 *i_op;
	struct super_block___63 *i_sb;
	struct address_space___62 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___63 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___62 *i_fop;
	struct file_lock___62 *i_flock;
	struct address_space___62 i_data;
	struct dquot___62 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___62 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___62 {
	int (*d_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_hash)(const struct dentry___63 *, struct qstr *);
	int (*d_compare)(const struct dentry___63 *, const struct dentry___63 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___63 *);
	void (*d_release)(struct dentry___63 *);
	void (*d_prune)(struct dentry___63 *);
	void (*d_iput)(struct dentry___63 *, struct inode___63 *);
	char * (*d_dname)(struct dentry___63 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___62 *);
	int (*d_manage)(struct dentry___63 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___62;

struct mem_dqinfo___62 {
	struct quota_format_type___62 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___62;

struct quota_info___62 {
	unsigned int flags;
	struct mutex___63 dqio_mutex;
	struct mutex___63 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___63 *files[2];
	struct mem_dqinfo___62 info[2];
	const struct quota_format_ops___62 *ops[2];
};

struct file_system_type___62;

struct super_operations___62;

struct dquot_operations___62;

struct quotactl_ops___62;

struct xattr_handler___35;

struct super_block___63 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___62 *s_type;
	const struct super_operations___62 *s_op;
	const struct dquot_operations___62 *dq_op;
	const struct quotactl_ops___62 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___63 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___35 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___62 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___62 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___63 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___62 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___62 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___63 *bd_inode;
	struct super_block___63 *bd_super;
	struct mutex___63 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___62 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___63 bd_fsfreeze_mutex;
};

struct cgroup___35;

struct cgroup_subsys_state___35 {
	struct cgroup___35 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___63 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___62 *ia_file;
};

struct dquot___62 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___63 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___63 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___62 {
	int qf_fmt_id;
	const struct quota_format_ops___62 *qf_ops;
	struct module___39 *qf_owner;
	struct quota_format_type___62 *qf_next;
};

struct quota_format_ops___62 {
	int (*check_quota_file)(struct super_block___63 *, int);
	int (*read_file_info)(struct super_block___63 *, int);
	int (*write_file_info)(struct super_block___63 *, int);
	int (*free_file_info)(struct super_block___63 *, int);
	int (*read_dqblk)(struct dquot___62 *);
	int (*commit_dqblk)(struct dquot___62 *);
	int (*release_dqblk)(struct dquot___62 *);
};

struct dquot_operations___62 {
	int (*write_dquot)(struct dquot___62 *);
	struct dquot___62 * (*alloc_dquot)(struct super_block___63 *, int);
	void (*destroy_dquot)(struct dquot___62 *);
	int (*acquire_dquot)(struct dquot___62 *);
	int (*release_dquot)(struct dquot___62 *);
	int (*mark_dirty)(struct dquot___62 *);
	int (*write_info)(struct super_block___63 *, int);
	qsize_t * (*get_reserved_space)(struct inode___63 *);
};

struct quotactl_ops___62 {
	int (*quota_on)(struct super_block___63 *, int, int, struct path___62 *);
	int (*quota_on_meta)(struct super_block___63 *, int, int);
	int (*quota_off)(struct super_block___63 *, int);
	int (*quota_sync)(struct super_block___63 *, int);
	int (*get_info)(struct super_block___63 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___63 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___63 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___63 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___63 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___63 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___63 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___63 *, unsigned int);
};

struct address_space_operations___62 {
	int (*writepage)(struct page___62 *, struct writeback_control *);
	int (*readpage)(struct file___62 *, struct page___62 *);
	int (*writepages)(struct address_space___62 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___62 *);
	int (*readpages)(struct file___62 *, struct address_space___62 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___62 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___62 **, void **);
	int (*write_end)(struct file___62 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___62 *, void *);
	sector_t (*bmap)(struct address_space___62 *, sector_t);
	void (*invalidatepage)(struct page___62 *, long unsigned int);
	int (*releasepage)(struct page___62 *, gfp_t);
	void (*freepage)(struct page___62 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___62 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___62 *, struct page___62 *, struct page___62 *, enum migrate_mode);
	int (*launder_page)(struct page___62 *);
	int (*is_partially_uptodate)(struct page___62 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___62 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___62 *, struct page___62 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___62 *, sector_t *);
	void (*swap_deactivate)(struct file___62 *);
	void (*invalidatepage_range)(struct page___62 *, unsigned int, unsigned int);
};

struct inode_operations___62 {
	struct dentry___63 * (*lookup)(struct inode___63 *, struct dentry___63 *, unsigned int);
	void * (*follow_link)(struct dentry___63 *, struct nameidata *);
	int (*permission)(struct inode___63 *, int);
	struct posix_acl * (*get_acl)(struct inode___63 *, int);
	int (*readlink)(struct dentry___63 *, char *, int);
	void (*put_link)(struct dentry___63 *, struct nameidata *, void *);
	int (*create)(struct inode___63 *, struct dentry___63 *, umode_t, bool);
	int (*link)(struct dentry___63 *, struct inode___63 *, struct dentry___63 *);
	int (*unlink)(struct inode___63 *, struct dentry___63 *);
	int (*symlink)(struct inode___63 *, struct dentry___63 *, const char *);
	int (*mkdir)(struct inode___63 *, struct dentry___63 *, umode_t);
	int (*rmdir)(struct inode___63 *, struct dentry___63 *);
	int (*mknod)(struct inode___63 *, struct dentry___63 *, umode_t, dev_t);
	int (*rename)(struct inode___63 *, struct dentry___63 *, struct inode___63 *, struct dentry___63 *);
	int (*setattr)(struct dentry___63 *, struct iattr___63 *);
	int (*getattr)(struct vfsmount *, struct dentry___63 *, struct kstat *);
	int (*setxattr)(struct dentry___63 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___63 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___63 *, char *, size_t);
	int (*removexattr)(struct dentry___63 *, const char *);
	int (*fiemap)(struct inode___63 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___63 *, struct timespec *, int);
	int (*atomic_open)(struct inode___63 *, struct dentry___63 *, struct file___62 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___40;

struct file_operations___62 {
	struct module___39 *owner;
	loff_t (*llseek)(struct file___62 *, loff_t, int);
	ssize_t (*read)(struct file___62 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___62 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___62 *, void *, filldir_t);
	unsigned int (*poll)(struct file___62 *, struct poll_table_struct___40 *);
	long int (*unlocked_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___62 *, struct vm_area_struct___66 *);
	int (*open)(struct inode___63 *, struct file___62 *);
	int (*flush)(struct file___62 *, fl_owner_t);
	int (*release)(struct inode___63 *, struct file___62 *);
	int (*fsync)(struct file___62 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___62 *, int);
	int (*lock)(struct file___62 *, int, struct file_lock___62 *);
	ssize_t (*sendpage)(struct file___62 *, struct page___62 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___62 *, int, struct file_lock___62 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___62 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___62 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___62 *, long int, struct file_lock___62 **, void **);
		struct {
			int (*setlease)(struct file___62 *, long int, struct file_lock___62 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___62 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___46 *, struct file___62 *);
};

struct file_lock_operations___62;

struct lock_manager_operations___62;

struct file_lock___62 {
	struct file_lock___62 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___32 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___62 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___62 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___62 *fl_ops;
	const struct lock_manager_operations___62 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___62 {
	void (*fl_copy_lock)(struct file_lock___62 *, struct file_lock___62 *);
	void (*fl_release_private)(struct file_lock___62 *);
};

struct lock_manager_operations___62 {
	int (*lm_compare_owner)(struct file_lock___62 *, struct file_lock___62 *);
	long unsigned int (*lm_owner_key)(struct file_lock___62 *);
	void (*lm_notify)(struct file_lock___62 *);
	int (*lm_grant)(struct file_lock___62 *, struct file_lock___62 *, int);
	void (*lm_break)(struct file_lock___62 *);
	int (*lm_change)(struct file_lock___62 **, int);
};

struct fasync_struct___62 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___62 *fa_next;
	struct file___62 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___62 {
	const char *name;
	int fs_flags;
	struct dentry___63 * (*mount)(struct file_system_type___62 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___63 *);
	struct module___39 *owner;
	struct file_system_type___62 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___62 {
	struct inode___63 * (*alloc_inode)(struct super_block___63 *);
	void (*destroy_inode)(struct inode___63 *);
	void (*dirty_inode)(struct inode___63 *, int);
	int (*write_inode)(struct inode___63 *, struct writeback_control *);
	int (*drop_inode)(struct inode___63 *);
	void (*evict_inode)(struct inode___63 *);
	void (*put_super)(struct super_block___63 *);
	int (*sync_fs)(struct super_block___63 *, int);
	int (*freeze_fs)(struct super_block___63 *);
	int (*unfreeze_fs)(struct super_block___63 *);
	int (*statfs)(struct dentry___63 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___63 *, int *, char *);
	void (*umount_begin)(struct super_block___63 *);
	int (*show_options)(struct seq_file___46 *, struct dentry___63 *);
	int (*show_devname)(struct seq_file___46 *, struct dentry___63 *);
	int (*show_path)(struct seq_file___46 *, struct dentry___63 *);
	int (*show_stats)(struct seq_file___46 *, struct dentry___63 *);
	ssize_t (*quota_read)(struct super_block___63 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___63 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___63 *);
	int (*bdev_try_to_free_page)(struct super_block___63 *, struct page___62 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___63 *);
	void (*free_cached_objects)(struct super_block___63 *, int);
};

struct xattr_handler___35 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___63 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___63 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___63 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___40)(struct file___62 *, wait_queue_head_t *, struct poll_table_struct___40 *);

struct poll_table_struct___40 {
	poll_queue_proc___40 _qproc;
	long unsigned int _key;
};

struct kmem_cache_cpu___53 {
	void **freelist;
	long unsigned int tid;
	struct page___62 *page;
	struct page___62 *partial;
};

struct memcg_cache_params___53 {
	bool is_root_cache;
	union {
		struct kmem_cache___53 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___53 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___35;

struct cgroup___35 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___35 *parent;
	struct dentry___63 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___35 *subsys[11];
	struct cgroupfs_root___35 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___63 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___35 {
	struct super_block___63 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___35 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___31;

struct pmu___31 {
	struct list_head entry;
	struct device___51 *dev;
	const struct attribute_group___46 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___31 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___31 *);
	void (*pmu_disable)(struct pmu___31 *);
	int (*event_init)(struct perf_event___31 *);
	int (*add)(struct perf_event___31 *, int);
	void (*del)(struct perf_event___31 *, int);
	void (*start)(struct perf_event___31 *, int);
	void (*stop)(struct perf_event___31 *, int);
	void (*read)(struct perf_event___31 *);
	void (*start_txn)(struct pmu___31 *);
	int (*commit_txn)(struct pmu___31 *);
	void (*cancel_txn)(struct pmu___31 *);
	int (*event_idx)(struct perf_event___31 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___39 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___31 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___31 *);
};

struct perf_cpu_context___31 {
	struct perf_event_context___31 ctx;
	struct perf_event_context___31 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___31 *unique_pmu;
	struct perf_cgroup___31 *cgrp;
};

struct perf_cgroup___31 {
	struct cgroup_subsys_state___35 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___23 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___63 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___23)(struct trace_iterator___23 *, int, struct trace_event___23 *);

struct trace_event_functions___23 {
	trace_print_func___23 trace;
	trace_print_func___23 raw;
	trace_print_func___23 hex;
	trace_print_func___23 binary;
};

struct ftrace_event_class___23 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___23 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___23 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___23 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___23 *);
};

struct ftrace_event_file___11 {
	struct list_head list;
	struct ftrace_event_call___23 *event_call;
	struct dentry___63 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_rcu_utilization {
	struct trace_entry ent;
	char *s;
	char __data[0];
};

struct ftrace_data_offsets_rcu_utilization {};

struct rcu_synchronize {
	struct callback_head head;
	struct completion completion;
};

struct param_attribute {
	struct module_attribute___38 mattr;
	const struct kernel_param *param;
};

struct module_param_attrs {
	unsigned int num;
	struct attribute_group___46 grp;
	struct param_attribute attrs[0];
};

struct module_version_attribute {
	struct module_attribute___38 mattr;
	const char *module_name;
	const char *version;
};

struct kmalloced_param {
	struct list_head list;
	char val[0];
};

typedef __kernel_timer_t timer_t;

struct itimerspec {
	struct timespec it_interval;
	struct timespec it_value;
};

struct sigevent {
	sigval_t sigev_value;
	int sigev_signo;
	int sigev_notify;
	union {
		int _pad[12];
		int _tid;
		struct {
			void (*_function)(sigval_t);
			void *_attribute;
		} _sigev_thread;
	} _sigev_un;
};

typedef struct sigevent sigevent_t;

enum alarmtimer_type {
	ALARM_REALTIME = 0,
	ALARM_BOOTTIME = 1,
	ALARM_NUMTYPE = 2,
};

enum alarmtimer_restart {
	ALARMTIMER_NORESTART = 0,
	ALARMTIMER_RESTART = 1,
};

struct alarm {
	struct timerqueue_node node;
	struct hrtimer timer;
	enum alarmtimer_restart (*function)(struct alarm *, ktime_t);
	enum alarmtimer_type type;
	int state;
	void *data;
};

union cpu_time_count {
	cputime_t cpu;
	long long unsigned int sched;
};

struct cpu_timer_list {
	struct list_head entry;
	union cpu_time_count expires;
	union cpu_time_count incr;
	struct task_struct___51 *task;
	int firing;
};

struct k_itimer {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	clockid_t it_clock;
	timer_t it_id;
	int it_overrun;
	int it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	struct signal_struct___50 *it_signal;
	union {
		struct pid___20 *it_pid;
		struct task_struct___51 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
			ktime_t interval;
		} real;
		struct cpu_timer_list cpu;
		struct {
			unsigned int clock;
			unsigned int node;
			long unsigned int incr;
			long unsigned int expires;
		} mmtimer;
		struct {
			struct alarm alarmtimer;
			ktime_t interval;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock {
	int (*clock_getres)(const clockid_t, struct timespec *);
	int (*clock_set)(const clockid_t, const struct timespec *);
	int (*clock_get)(const clockid_t, struct timespec *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer *);
	int (*nsleep)(const clockid_t, int, struct timespec *, struct timespec *);
	long int (*nsleep_restart)(struct restart_block *);
	int (*timer_set)(struct k_itimer *, int, struct itimerspec *, struct itimerspec *);
	int (*timer_del)(struct k_itimer *);
	void (*timer_get)(struct k_itimer *, struct itimerspec *);
};

struct sched_param {
	int sched_priority;
};

struct page___63;

typedef struct page___63 *pgtable_t___63;

struct address_space___63;

struct kmem_cache___54;

struct page___63 {
	long unsigned int flags;
	struct address_space___63 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___63 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___63 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___54 *slab_cache;
		struct page___63 *first_page;
	};
	long: 64;
};

struct task_struct___64;

struct pv_cpu_ops___63 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___31 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___31 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___64 *);
	void (*end_context_switch)(struct task_struct___64 *);
};

struct mutex___64 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___64 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___60 {
	struct page___63 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___67;

struct signal_struct___63;

struct css_set___36;

struct task_struct___64 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___64 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___67 *mm;
	struct mm_struct___67 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___64 *real_parent;
	struct task_struct___64 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___64 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___32 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___63 = 0,
		VTIME_USER___63 = 1,
		VTIME_SYS___63 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___31 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___63 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___36 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___64 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___60 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___67 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___67 *, struct mm_struct___67 *);
	void (*dup_mmap)(struct mm_struct___67 *, struct mm_struct___67 *);
	void (*exit_mmap)(struct mm_struct___67 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___67 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___67 *);
	void (*pgd_free)(struct mm_struct___67 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___67 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___67 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___67 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___67 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___67 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___67 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___67 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___67 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___67 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___67 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___67 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___64 lock;
	void *vdso;
} mm_context_t___64;

struct xol_area___63;

struct uprobes_state___63 {
	struct xol_area___63 *xol_area;
};

struct vm_area_struct___67;

struct file___63;

struct linux_binfmt___7;

struct core_state___63;

struct mm_struct___67 {
	struct vm_area_struct___67 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___67 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___67 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___7 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___64 context;
	long unsigned int flags;
	struct core_state___63 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___64 *owner;
	struct file___63 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___63 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___63 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___63 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___54;

struct memcg_cache_params___54;

struct kmem_cache___54 {
	struct kmem_cache_cpu___54 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___54 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___64;

struct address_space_operations___63;

struct address_space___63 {
	struct inode___64 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___64 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___63 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___64;

struct path___63 {
	struct vfsmount *mnt;
	struct dentry___64 *dentry;
};

struct file_operations___63;

struct file___63 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___63 f_path;
	struct inode___64 *f_inode;
	const struct file_operations___63 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___32 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___63 *f_mapping;
	struct mutex___64 f_pos_lock;
};

struct vm_operations_struct___57;

struct vm_area_struct___67 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___67 *vm_next;
	struct vm_area_struct___67 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___67 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___57 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___63 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___54;

struct vm_operations_struct___57 {
	void (*open)(struct vm_area_struct___67 *);
	void (*close)(struct vm_area_struct___67 *);
	int (*fault)(struct vm_area_struct___67 *, struct vm_fault___54 *);
	int (*page_mkwrite)(struct vm_area_struct___67 *, struct vm_fault___54 *);
	int (*access)(struct vm_area_struct___67 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___67 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___67 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___67 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___67 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___63 {
	struct task_struct___64 *task;
	struct core_thread___63 *next;
};

struct core_state___63 {
	atomic_t nr_threads;
	struct core_thread___63 dumper;
	struct completion startup;
};

struct linux_binprm___8;

struct coredump_params___7;

struct linux_binfmt___7 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___8 *);
	int (*load_shlib)(struct file___63 *);
	int (*core_dump)(struct coredump_params___7 *);
	long unsigned int min_coredump;
};

struct smp_ops___63 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___64 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___63;

struct lruvec___63 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___63 *zone;
};

struct pglist_data___63;

struct zone___63 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___63 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___63 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___63 {
	struct zone___63 *zone;
	int zone_idx;
};

struct zonelist___63 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___63 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___63 {
	struct zone___63 node_zones[4];
	struct zonelist___63 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___64 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___63 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___64 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___64 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___32 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___32 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___64 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___36;

struct css_set___36 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___36 *subsys[11];
	struct callback_head callback_head;
};

struct kthread_work;

typedef void (*kthread_work_func_t)(struct kthread_work *);

struct kthread_worker;

struct kthread_work {
	struct list_head node;
	kthread_work_func_t func;
	wait_queue_head_t done;
	struct kthread_worker *worker;
};

struct kthread_worker {
	spinlock_t lock;
	struct list_head work_list;
	struct task_struct___64 *task;
	struct kthread_work *current_work;
};

struct vm_fault___54 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___63 *page;
};

struct kmem_cache_cpu___54 {
	void **freelist;
	long unsigned int tid;
	struct page___63 *page;
	struct page___63 *partial;
};

struct memcg_cache_params___54 {
	bool is_root_cache;
	union {
		struct kmem_cache___54 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___54 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___36 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___64 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___64 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___64 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___63;

struct super_block___64;

struct dentry___64 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___64 *d_parent;
	struct qstr d_name;
	struct inode___64 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___63 *d_op;
	struct super_block___64 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___63;

struct file_lock___63;

struct dquot___63;

struct block_device___63;

struct inode___64 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___63 *i_op;
	struct super_block___64 *i_sb;
	struct address_space___63 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___64 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___63 *i_fop;
	struct file_lock___63 *i_flock;
	struct address_space___63 i_data;
	struct dquot___63 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___63 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___63 {
	int (*d_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_hash)(const struct dentry___64 *, struct qstr *);
	int (*d_compare)(const struct dentry___64 *, const struct dentry___64 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___64 *);
	void (*d_release)(struct dentry___64 *);
	void (*d_prune)(struct dentry___64 *);
	void (*d_iput)(struct dentry___64 *, struct inode___64 *);
	char * (*d_dname)(struct dentry___64 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___63 *);
	int (*d_manage)(struct dentry___64 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___63;

struct mem_dqinfo___63 {
	struct quota_format_type___63 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___63;

struct quota_info___63 {
	unsigned int flags;
	struct mutex___64 dqio_mutex;
	struct mutex___64 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___64 *files[2];
	struct mem_dqinfo___63 info[2];
	const struct quota_format_ops___63 *ops[2];
};

struct file_system_type___63;

struct super_operations___63;

struct dquot_operations___63;

struct quotactl_ops___63;

struct super_block___64 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___63 *s_type;
	const struct super_operations___63 *s_op;
	const struct dquot_operations___63 *dq_op;
	const struct quotactl_ops___63 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___64 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___36 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___63 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___63 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___64 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___63 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___63 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___64 *bd_inode;
	struct super_block___64 *bd_super;
	struct mutex___64 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___63 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___64 bd_fsfreeze_mutex;
};

struct cgroup___36;

struct cgroup_subsys_state___36 {
	struct cgroup___36 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___64 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___63 *ia_file;
};

struct dquot___63 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___64 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___64 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___63 {
	int qf_fmt_id;
	const struct quota_format_ops___63 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___63 *qf_next;
};

struct quota_format_ops___63 {
	int (*check_quota_file)(struct super_block___64 *, int);
	int (*read_file_info)(struct super_block___64 *, int);
	int (*write_file_info)(struct super_block___64 *, int);
	int (*free_file_info)(struct super_block___64 *, int);
	int (*read_dqblk)(struct dquot___63 *);
	int (*commit_dqblk)(struct dquot___63 *);
	int (*release_dqblk)(struct dquot___63 *);
};

struct dquot_operations___63 {
	int (*write_dquot)(struct dquot___63 *);
	struct dquot___63 * (*alloc_dquot)(struct super_block___64 *, int);
	void (*destroy_dquot)(struct dquot___63 *);
	int (*acquire_dquot)(struct dquot___63 *);
	int (*release_dquot)(struct dquot___63 *);
	int (*mark_dirty)(struct dquot___63 *);
	int (*write_info)(struct super_block___64 *, int);
	qsize_t * (*get_reserved_space)(struct inode___64 *);
};

struct quotactl_ops___63 {
	int (*quota_on)(struct super_block___64 *, int, int, struct path___63 *);
	int (*quota_on_meta)(struct super_block___64 *, int, int);
	int (*quota_off)(struct super_block___64 *, int);
	int (*quota_sync)(struct super_block___64 *, int);
	int (*get_info)(struct super_block___64 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___64 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___64 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___64 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___64 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___64 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___64 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___64 *, unsigned int);
};

struct address_space_operations___63 {
	int (*writepage)(struct page___63 *, struct writeback_control *);
	int (*readpage)(struct file___63 *, struct page___63 *);
	int (*writepages)(struct address_space___63 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___63 *);
	int (*readpages)(struct file___63 *, struct address_space___63 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___63 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___63 **, void **);
	int (*write_end)(struct file___63 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___63 *, void *);
	sector_t (*bmap)(struct address_space___63 *, sector_t);
	void (*invalidatepage)(struct page___63 *, long unsigned int);
	int (*releasepage)(struct page___63 *, gfp_t);
	void (*freepage)(struct page___63 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___63 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___63 *, struct page___63 *, struct page___63 *, enum migrate_mode);
	int (*launder_page)(struct page___63 *);
	int (*is_partially_uptodate)(struct page___63 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___63 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___63 *, struct page___63 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___63 *, sector_t *);
	void (*swap_deactivate)(struct file___63 *);
	void (*invalidatepage_range)(struct page___63 *, unsigned int, unsigned int);
};

struct inode_operations___63 {
	struct dentry___64 * (*lookup)(struct inode___64 *, struct dentry___64 *, unsigned int);
	void * (*follow_link)(struct dentry___64 *, struct nameidata *);
	int (*permission)(struct inode___64 *, int);
	struct posix_acl * (*get_acl)(struct inode___64 *, int);
	int (*readlink)(struct dentry___64 *, char *, int);
	void (*put_link)(struct dentry___64 *, struct nameidata *, void *);
	int (*create)(struct inode___64 *, struct dentry___64 *, umode_t, bool);
	int (*link)(struct dentry___64 *, struct inode___64 *, struct dentry___64 *);
	int (*unlink)(struct inode___64 *, struct dentry___64 *);
	int (*symlink)(struct inode___64 *, struct dentry___64 *, const char *);
	int (*mkdir)(struct inode___64 *, struct dentry___64 *, umode_t);
	int (*rmdir)(struct inode___64 *, struct dentry___64 *);
	int (*mknod)(struct inode___64 *, struct dentry___64 *, umode_t, dev_t);
	int (*rename)(struct inode___64 *, struct dentry___64 *, struct inode___64 *, struct dentry___64 *);
	int (*setattr)(struct dentry___64 *, struct iattr___64 *);
	int (*getattr)(struct vfsmount *, struct dentry___64 *, struct kstat *);
	int (*setxattr)(struct dentry___64 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___64 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___64 *, char *, size_t);
	int (*removexattr)(struct dentry___64 *, const char *);
	int (*fiemap)(struct inode___64 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___64 *, struct timespec *, int);
	int (*atomic_open)(struct inode___64 *, struct dentry___64 *, struct file___63 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___63 {
	struct module *owner;
	loff_t (*llseek)(struct file___63 *, loff_t, int);
	ssize_t (*read)(struct file___63 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___63 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___63 *, void *, filldir_t);
	unsigned int (*poll)(struct file___63 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___63 *, struct vm_area_struct___67 *);
	int (*open)(struct inode___64 *, struct file___63 *);
	int (*flush)(struct file___63 *, fl_owner_t);
	int (*release)(struct inode___64 *, struct file___63 *);
	int (*fsync)(struct file___63 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___63 *, int);
	int (*lock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*sendpage)(struct file___63 *, struct page___63 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___63 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___63 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___63 *, long int, struct file_lock___63 **, void **);
		struct {
			int (*setlease)(struct file___63 *, long int, struct file_lock___63 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___63 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___63 *);
};

struct fasync_struct___63;

struct file_lock_operations___63;

struct lock_manager_operations___63;

struct file_lock___63 {
	struct file_lock___63 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___32 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___63 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___63 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___63 *fl_ops;
	const struct lock_manager_operations___63 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___63 {
	void (*fl_copy_lock)(struct file_lock___63 *, struct file_lock___63 *);
	void (*fl_release_private)(struct file_lock___63 *);
};

struct lock_manager_operations___63 {
	int (*lm_compare_owner)(struct file_lock___63 *, struct file_lock___63 *);
	long unsigned int (*lm_owner_key)(struct file_lock___63 *);
	void (*lm_notify)(struct file_lock___63 *);
	int (*lm_grant)(struct file_lock___63 *, struct file_lock___63 *, int);
	void (*lm_break)(struct file_lock___63 *);
	int (*lm_change)(struct file_lock___63 **, int);
};

struct fasync_struct___63 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___63 *fa_next;
	struct file___63 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___63 {
	const char *name;
	int fs_flags;
	struct dentry___64 * (*mount)(struct file_system_type___63 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___64 *);
	struct module *owner;
	struct file_system_type___63 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___63 {
	struct inode___64 * (*alloc_inode)(struct super_block___64 *);
	void (*destroy_inode)(struct inode___64 *);
	void (*dirty_inode)(struct inode___64 *, int);
	int (*write_inode)(struct inode___64 *, struct writeback_control *);
	int (*drop_inode)(struct inode___64 *);
	void (*evict_inode)(struct inode___64 *);
	void (*put_super)(struct super_block___64 *);
	int (*sync_fs)(struct super_block___64 *, int);
	int (*freeze_fs)(struct super_block___64 *);
	int (*unfreeze_fs)(struct super_block___64 *);
	int (*statfs)(struct dentry___64 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___64 *, int *, char *);
	void (*umount_begin)(struct super_block___64 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___64 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___64 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___64 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___64 *);
	ssize_t (*quota_read)(struct super_block___64 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___64 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___64 *);
	int (*bdev_try_to_free_page)(struct super_block___64 *, struct page___63 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___64 *);
	void (*free_cached_objects)(struct super_block___64 *, int);
};

struct cgroupfs_root___36;

struct cgroup___36 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___36 *parent;
	struct dentry___64 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___36 *subsys[11];
	struct cgroupfs_root___36 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___64 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___36 {
	struct super_block___64 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___36 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct linux_binprm___8 {
	char buf[128];
	struct vm_area_struct___67 *vma;
	long unsigned int vma_pages;
	struct mm_struct___67 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___63 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___7 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___63 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct kthread_create_info {
	int (*threadfn)(void *);
	void *data;
	int node;
	struct task_struct___64 *result;
	struct completion done;
	struct list_head list;
};

struct kthread {
	long unsigned int flags;
	unsigned int cpu;
	void *data;
	struct completion parked;
	struct completion exited;
};

enum KTHREAD_BITS {
	KTHREAD_IS_PER_CPU = 0,
	KTHREAD_SHOULD_STOP = 1,
	KTHREAD_SHOULD_PARK = 2,
	KTHREAD_IS_PARKED = 3,
};

struct kthread_flush_work {
	struct kthread_work work;
	struct completion done;
};

struct wait_bit_key {
	void *flags;
	int bit_nr;
};

struct wait_bit_queue {
	struct wait_bit_key key;
	wait_queue_t wait;
};

struct cpu_timer_list___2 {
	struct list_head entry;
	union cpu_time_count expires;
	union cpu_time_count incr;
	struct task_struct___16 *task;
	int firing;
};

struct k_itimer___2 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	clockid_t it_clock;
	timer_t it_id;
	int it_overrun;
	int it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	struct signal_struct___15 *it_signal;
	union {
		struct pid___7 *it_pid;
		struct task_struct___16 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
			ktime_t interval;
		} real;
		struct cpu_timer_list___2 cpu;
		struct {
			unsigned int clock;
			unsigned int node;
			long unsigned int incr;
			long unsigned int expires;
		} mmtimer;
		struct {
			struct alarm alarmtimer;
			ktime_t interval;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___2 {
	int (*clock_getres)(const clockid_t, struct timespec *);
	int (*clock_set)(const clockid_t, const struct timespec *);
	int (*clock_get)(const clockid_t, struct timespec *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___2 *);
	int (*nsleep)(const clockid_t, int, struct timespec *, struct timespec *);
	long int (*nsleep_restart)(struct restart_block *);
	int (*timer_set)(struct k_itimer___2 *, int, struct itimerspec *, struct itimerspec *);
	int (*timer_del)(struct k_itimer___2 *);
	void (*timer_get)(struct k_itimer___2 *, struct itimerspec *);
};

struct optimistic_spin_queue {
	struct optimistic_spin_queue *next;
	struct optimistic_spin_queue *prev;
	int locked;
};

struct mutex_waiter {
	struct list_head list;
	struct task_struct___64 *task;
};

struct ww_acquire_ctx {
	struct task_struct___64 *task;
	long unsigned int stamp;
	unsigned int acquired;
};

struct ww_mutex {
	struct mutex___64 base;
	struct ww_acquire_ctx *ctx;
};

struct lockdep_map;

struct hrtimer_sleeper {
	struct hrtimer timer;
	struct task_struct___17 *task;
};

struct syscall_metadata___9 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___7 *enter_event;
	struct ftrace_event_call___7 *exit_event;
};

enum tick_device_mode {
	TICKDEV_MODE_PERIODIC = 0,
	TICKDEV_MODE_ONESHOT = 1,
};

struct tick_device {
	struct clock_event_device *evtdev;
	enum tick_device_mode mode;
};

struct ipc_ids {
	int in_use;
	short unsigned int seq;
	short unsigned int seq_max;
	struct rw_semaphore rwsem;
	struct idr ipcs_idr;
	int next_id;
};

struct ipc_namespace {
	atomic_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	int auto_msgmni;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

struct proc_ns_operations {
	const char *name;
	int type;
	void * (*get)(struct task_struct___62 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___32 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns {
	void *ns;
	const struct proc_ns_operations *ns_ops;
};

struct syscall_metadata___10 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___22 *enter_event;
	struct ftrace_event_call___22 *exit_event;
};

struct srcu_struct_array {
	long unsigned int c[2];
	long unsigned int seq[2];
};

struct rcu_batch {
	struct callback_head *head;
	struct callback_head **tail;
};

struct srcu_struct {
	unsigned int completed;
	struct srcu_struct_array *per_cpu_ref;
	spinlock_t queue_lock;
	bool running;
	struct rcu_batch batch_queue;
	struct rcu_batch batch_check0;
	struct rcu_batch batch_check1;
	struct rcu_batch batch_done;
	struct delayed_work work;
};

struct semaphore_waiter {
	struct list_head list;
	struct task_struct___64 *task;
	bool up;
};

struct srcu_notifier_head {
	struct mutex___62 mutex;
	struct srcu_struct srcu;
	struct notifier_block *head;
};

struct page___64;

typedef struct page___64 *pgtable_t___64;

struct address_space___64;

struct kmem_cache___55;

struct page___64 {
	long unsigned int flags;
	struct address_space___64 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___64 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___64 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___55 *slab_cache;
		struct page___64 *first_page;
	};
	long: 64;
};

struct task_struct___65;

struct pv_cpu_ops___64 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___31 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___31 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___65 *);
	void (*end_context_switch)(struct task_struct___65 *);
};

struct pid___33;

struct pid_link___33 {
	struct hlist_node node;
	struct pid___33 *pid;
};

struct mutex___65 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___65 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___61 {
	struct page___64 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___68;

struct nsproxy___34;

struct signal_struct___64;

struct task_struct___65 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___65 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___68 *mm;
	struct mm_struct___68 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___65 *real_parent;
	struct task_struct___65 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___65 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___33 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___64 = 0,
		VTIME_USER___64 = 1,
		VTIME_SYS___64 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___31 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___34 *nsproxy;
	struct signal_struct___64 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___65 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___61 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___68 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___68 *, struct mm_struct___68 *);
	void (*dup_mmap)(struct mm_struct___68 *, struct mm_struct___68 *);
	void (*exit_mmap)(struct mm_struct___68 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___68 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___68 *);
	void (*pgd_free)(struct mm_struct___68 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___68 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___68 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___68 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___68 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___68 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___68 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___68 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___68 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___68 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___68 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___68 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___65 lock;
	void *vdso;
} mm_context_t___65;

struct xol_area___64;

struct uprobes_state___64 {
	struct xol_area___64 *xol_area;
};

struct vm_area_struct___68;

struct file___64;

struct linux_binfmt___8;

struct core_state___64;

struct mm_struct___68 {
	struct vm_area_struct___68 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___68 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___68 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___8 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___65 context;
	long unsigned int flags;
	struct core_state___64 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___65 *owner;
	struct file___64 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___64 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct ctl_table_header___9;

struct ctl_node___9 {
	struct rb_node node;
	struct ctl_table_header___9 *header;
};

struct ctl_table_root___9;

struct ctl_table_set___9;

struct ctl_dir___9;

struct ctl_table_header___9 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___9 *root;
	struct ctl_table_set___9 *set;
	struct ctl_dir___9 *parent;
	struct ctl_node___9 *node;
};

struct ctl_dir___9 {
	struct ctl_table_header___9 header;
	struct rb_root root;
};

struct ctl_table_set___9 {
	int (*is_seen)(struct ctl_table_set___9 *);
	struct ctl_dir___9 dir;
};

struct ctl_table_root___9 {
	struct ctl_table_set___9 default_set;
	struct ctl_table_set___9 * (*lookup)(struct ctl_table_root___9 *, struct nsproxy___34 *);
	int (*permissions)(struct ctl_table_header___9 *, struct ctl_table *);
};

struct pid_namespace___33;

struct net___10;

struct nsproxy___34 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___33 *pid_ns;
	struct net___10 *net_ns;
};

struct zone___64;

struct lruvec___64 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___64 *zone;
};

struct pglist_data___64;

struct zone___64 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___64 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___64 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___64 {
	struct zone___64 *zone;
	int zone_idx;
};

struct zonelist___64 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___64 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___64 {
	struct zone___64 node_zones[4];
	struct zonelist___64 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___65 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___47;

struct x86_io_apic_ops___47 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___47 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___47;

struct irq_data___47 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___47 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___52;

struct dev_pm_ops___52 {
	int (*prepare)(struct device___52 *);
	void (*complete)(struct device___52 *);
	int (*suspend)(struct device___52 *);
	int (*resume)(struct device___52 *);
	int (*freeze)(struct device___52 *);
	int (*thaw)(struct device___52 *);
	int (*poweroff)(struct device___52 *);
	int (*restore)(struct device___52 *);
	int (*suspend_late)(struct device___52 *);
	int (*resume_early)(struct device___52 *);
	int (*freeze_late)(struct device___52 *);
	int (*thaw_early)(struct device___52 *);
	int (*poweroff_late)(struct device___52 *);
	int (*restore_early)(struct device___52 *);
	int (*suspend_noirq)(struct device___52 *);
	int (*resume_noirq)(struct device___52 *);
	int (*freeze_noirq)(struct device___52 *);
	int (*thaw_noirq)(struct device___52 *);
	int (*poweroff_noirq)(struct device___52 *);
	int (*restore_noirq)(struct device___52 *);
	int (*runtime_suspend)(struct device___52 *);
	int (*runtime_resume)(struct device___52 *);
	int (*runtime_idle)(struct device___52 *);
};

struct dma_map_ops___26;

struct dev_archdata___26 {
	struct dma_map_ops___26 *dma_ops;
	void *iommu;
};

struct device_type___52;

struct bus_type___52;

struct device_driver___52;

struct dev_pm_domain___52;

struct class___52;

struct attribute_group___47;

struct device_rh___52;

struct device___52 {
	struct device___52 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___52 *type;
	struct mutex___65 mutex;
	struct bus_type___52 *bus;
	struct device_driver___52 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___52 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___26 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___52 *class;
	const struct attribute_group___47 **groups;
	void (*release)(struct device___52 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___52 *device_rh;
};

struct dev_pm_info_rh___52 {
	void (*set_latency_tolerance)(struct device___52 *, s32);
};

struct dev_pm_domain___52 {
	struct dev_pm_ops___52 ops;
};

struct smp_ops___64 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___65 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___47;

struct attribute_group___47 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___47 **bin_attrs;
};

struct bin_attribute___47 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___64 *, struct kobject___3 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___64 *, struct kobject___3 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	int (*mmap)(struct file___64 *, struct kobject___3 *, struct bin_attribute___47 *, struct vm_area_struct___68 *);
};

struct dentry___65;

struct path___64 {
	struct vfsmount *mnt;
	struct dentry___65 *dentry;
};

struct fown_struct___33 {
	rwlock_t lock;
	struct pid___33 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___65;

struct file_operations___64;

struct file___64 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___64 f_path;
	struct inode___65 *f_inode;
	const struct file_operations___64 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___33 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___64 *f_mapping;
	struct mutex___65 f_pos_lock;
};

struct vm_operations_struct___58;

struct vm_area_struct___68 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___68 *vm_next;
	struct vm_area_struct___68 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___68 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___58 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___64 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___55 {
	void **freelist;
	long unsigned int tid;
	struct page___64 *page;
	struct page___64 *partial;
};

struct memcg_cache_params___55;

struct kmem_cache___55 {
	struct kmem_cache_cpu___55 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___55 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___55 {
	bool is_root_cache;
	union {
		struct kmem_cache___55 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___55 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___64 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___64 *page;
	long unsigned int vaddr;
};

struct address_space_operations___64;

struct address_space___64 {
	struct inode___65 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___65 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___64 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___55;

struct vm_operations_struct___58 {
	void (*open)(struct vm_area_struct___68 *);
	void (*close)(struct vm_area_struct___68 *);
	int (*fault)(struct vm_area_struct___68 *, struct vm_fault___55 *);
	int (*page_mkwrite)(struct vm_area_struct___68 *, struct vm_fault___55 *);
	int (*access)(struct vm_area_struct___68 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___68 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___68 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___68 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___68 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___64 {
	struct task_struct___65 *task;
	struct core_thread___64 *next;
};

struct core_state___64 {
	atomic_t nr_threads;
	struct core_thread___64 dumper;
	struct completion startup;
};

struct linux_binprm___9;

struct coredump_params___8;

struct linux_binfmt___8 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___9 *);
	int (*load_shlib)(struct file___64 *);
	int (*core_dump)(struct coredump_params___8 *);
	long unsigned int min_coredump;
};

struct upid___33 {
	int nr;
	struct pid_namespace___33 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___33 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___65 *child_reaper;
	struct kmem_cache___55 *pid_cachep;
	unsigned int level;
	struct pid_namespace___33 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___65 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___33 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___33 numbers[1];
};

struct signal_struct___64 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___65 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___65 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___33 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___33 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___65 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct netns_core___9 {
	struct ctl_table_header___9 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___9 {
	struct mutex___65 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___9 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___9 *ctl;
};

struct netns_ipv4___9 {
	struct ctl_table_header___9 *forw_hdr;
	struct ctl_table_header___9 *frags_hdr;
	struct ctl_table_header___9 *ipv4_hdr;
	struct ctl_table_header___9 *route_hdr;
	struct ctl_table_header___9 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___9 {
	struct ctl_table_header___9 *hdr;
	struct ctl_table_header___9 *route_hdr;
	struct ctl_table_header___9 *icmp_hdr;
	struct ctl_table_header___9 *frags_hdr;
	struct ctl_table_header___9 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___9 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___9 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *);
	int (*local_out)(struct sk_buff___5 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___5 *, const void *);
	struct kmem_cache___55 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___9 {
	struct netns_sysctl_ipv6___9 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___9 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___9 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___9 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___9 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___9 *nf_log_dir_header;
};

struct nf_proto_net___9 {
	struct ctl_table_header___9 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___9 {
	struct nf_proto_net___9 pn;
	unsigned int timeout;
};

struct nf_tcp_net___9 {
	struct nf_proto_net___9 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___9 {
	struct nf_proto_net___9 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___9 {
	struct nf_proto_net___9 pn;
	unsigned int timeout;
};

struct nf_ip_net___9 {
	struct nf_generic_net___9 generic;
	struct nf_tcp_net___9 tcp;
	struct nf_udp_net___9 udp;
	struct nf_icmp_net___9 icmp;
	struct nf_icmp_net___9 icmpv6;
};

struct netns_ct___9 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___9 *sysctl_header;
	struct ctl_table_header___9 *acct_sysctl_header;
	struct ctl_table_header___9 *tstamp_sysctl_header;
	struct ctl_table_header___9 *event_sysctl_header;
	struct ctl_table_header___9 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___55 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___9 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___9 {
	struct netns_sysctl_ipv6___9 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___9 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___9 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___9 xfrm4_dst_ops;
	struct dst_ops___9 xfrm6_dst_ops;
};

struct net___10 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___9 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___9 core;
	struct netns_mib mib;
	struct netns_packet___9 packet;
	struct netns_unix___9 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___9 ipv4;
	struct netns_ipv6___9 ipv6;
	struct netns_sctp___9 sctp;
	struct netns_dccp___3 dccp;
	struct netns_nf___9 nf;
	struct netns_xt xt;
	struct netns_ct___9 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___9 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___9 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___65 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___65 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___64;

struct super_block___65;

struct dentry___65 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___65 *d_parent;
	struct qstr d_name;
	struct inode___65 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___64 *d_op;
	struct super_block___65 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___64;

struct file_lock___64;

struct dquot___64;

struct block_device___64;

struct inode___65 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___64 *i_op;
	struct super_block___65 *i_sb;
	struct address_space___64 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___65 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___64 *i_fop;
	struct file_lock___64 *i_flock;
	struct address_space___64 i_data;
	struct dquot___64 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___64 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___64 {
	int (*d_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_hash)(const struct dentry___65 *, struct qstr *);
	int (*d_compare)(const struct dentry___65 *, const struct dentry___65 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___65 *);
	void (*d_release)(struct dentry___65 *);
	void (*d_prune)(struct dentry___65 *);
	void (*d_iput)(struct dentry___65 *, struct inode___65 *);
	char * (*d_dname)(struct dentry___65 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___64 *);
	int (*d_manage)(struct dentry___65 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___64;

struct mem_dqinfo___64 {
	struct quota_format_type___64 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___64;

struct quota_info___64 {
	unsigned int flags;
	struct mutex___65 dqio_mutex;
	struct mutex___65 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___65 *files[2];
	struct mem_dqinfo___64 info[2];
	const struct quota_format_ops___64 *ops[2];
};

struct file_system_type___64;

struct super_operations___64;

struct dquot_operations___64;

struct quotactl_ops___64;

struct super_block___65 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___64 *s_type;
	const struct super_operations___64 *s_op;
	const struct dquot_operations___64 *dq_op;
	const struct quotactl_ops___64 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___65 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___64 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___64 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___65 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___64 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___64 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___65 *bd_inode;
	struct super_block___65 *bd_super;
	struct mutex___65 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___64 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___65 bd_fsfreeze_mutex;
};

struct iattr___65 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___64 *ia_file;
};

struct dquot___64 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___65 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___65 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___64 {
	int qf_fmt_id;
	const struct quota_format_ops___64 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___64 *qf_next;
};

struct quota_format_ops___64 {
	int (*check_quota_file)(struct super_block___65 *, int);
	int (*read_file_info)(struct super_block___65 *, int);
	int (*write_file_info)(struct super_block___65 *, int);
	int (*free_file_info)(struct super_block___65 *, int);
	int (*read_dqblk)(struct dquot___64 *);
	int (*commit_dqblk)(struct dquot___64 *);
	int (*release_dqblk)(struct dquot___64 *);
};

struct dquot_operations___64 {
	int (*write_dquot)(struct dquot___64 *);
	struct dquot___64 * (*alloc_dquot)(struct super_block___65 *, int);
	void (*destroy_dquot)(struct dquot___64 *);
	int (*acquire_dquot)(struct dquot___64 *);
	int (*release_dquot)(struct dquot___64 *);
	int (*mark_dirty)(struct dquot___64 *);
	int (*write_info)(struct super_block___65 *, int);
	qsize_t * (*get_reserved_space)(struct inode___65 *);
};

struct quotactl_ops___64 {
	int (*quota_on)(struct super_block___65 *, int, int, struct path___64 *);
	int (*quota_on_meta)(struct super_block___65 *, int, int);
	int (*quota_off)(struct super_block___65 *, int);
	int (*quota_sync)(struct super_block___65 *, int);
	int (*get_info)(struct super_block___65 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___65 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___65 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___65 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___65 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___65 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___65 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___65 *, unsigned int);
};

struct address_space_operations___64 {
	int (*writepage)(struct page___64 *, struct writeback_control *);
	int (*readpage)(struct file___64 *, struct page___64 *);
	int (*writepages)(struct address_space___64 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___64 *);
	int (*readpages)(struct file___64 *, struct address_space___64 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___64 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___64 **, void **);
	int (*write_end)(struct file___64 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___64 *, void *);
	sector_t (*bmap)(struct address_space___64 *, sector_t);
	void (*invalidatepage)(struct page___64 *, long unsigned int);
	int (*releasepage)(struct page___64 *, gfp_t);
	void (*freepage)(struct page___64 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___64 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___64 *, struct page___64 *, struct page___64 *, enum migrate_mode);
	int (*launder_page)(struct page___64 *);
	int (*is_partially_uptodate)(struct page___64 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___64 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___64 *, struct page___64 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___64 *, sector_t *);
	void (*swap_deactivate)(struct file___64 *);
	void (*invalidatepage_range)(struct page___64 *, unsigned int, unsigned int);
};

struct inode_operations___64 {
	struct dentry___65 * (*lookup)(struct inode___65 *, struct dentry___65 *, unsigned int);
	void * (*follow_link)(struct dentry___65 *, struct nameidata *);
	int (*permission)(struct inode___65 *, int);
	struct posix_acl * (*get_acl)(struct inode___65 *, int);
	int (*readlink)(struct dentry___65 *, char *, int);
	void (*put_link)(struct dentry___65 *, struct nameidata *, void *);
	int (*create)(struct inode___65 *, struct dentry___65 *, umode_t, bool);
	int (*link)(struct dentry___65 *, struct inode___65 *, struct dentry___65 *);
	int (*unlink)(struct inode___65 *, struct dentry___65 *);
	int (*symlink)(struct inode___65 *, struct dentry___65 *, const char *);
	int (*mkdir)(struct inode___65 *, struct dentry___65 *, umode_t);
	int (*rmdir)(struct inode___65 *, struct dentry___65 *);
	int (*mknod)(struct inode___65 *, struct dentry___65 *, umode_t, dev_t);
	int (*rename)(struct inode___65 *, struct dentry___65 *, struct inode___65 *, struct dentry___65 *);
	int (*setattr)(struct dentry___65 *, struct iattr___65 *);
	int (*getattr)(struct vfsmount *, struct dentry___65 *, struct kstat *);
	int (*setxattr)(struct dentry___65 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___65 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___65 *, char *, size_t);
	int (*removexattr)(struct dentry___65 *, const char *);
	int (*fiemap)(struct inode___65 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___65 *, struct timespec *, int);
	int (*atomic_open)(struct inode___65 *, struct dentry___65 *, struct file___64 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___47;

struct file_operations___64 {
	struct module *owner;
	loff_t (*llseek)(struct file___64 *, loff_t, int);
	ssize_t (*read)(struct file___64 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___64 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___64 *, void *, filldir_t);
	unsigned int (*poll)(struct file___64 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___64 *, struct vm_area_struct___68 *);
	int (*open)(struct inode___65 *, struct file___64 *);
	int (*flush)(struct file___64 *, fl_owner_t);
	int (*release)(struct inode___65 *, struct file___64 *);
	int (*fsync)(struct file___64 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___64 *, int);
	int (*lock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*sendpage)(struct file___64 *, struct page___64 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___64 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___64 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___64 *, long int, struct file_lock___64 **, void **);
		struct {
			int (*setlease)(struct file___64 *, long int, struct file_lock___64 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___64 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___47 *, struct file___64 *);
};

struct fasync_struct___64;

struct file_lock_operations___64;

struct lock_manager_operations___64;

struct file_lock___64 {
	struct file_lock___64 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___33 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___64 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___64 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___64 *fl_ops;
	const struct lock_manager_operations___64 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___64 {
	void (*fl_copy_lock)(struct file_lock___64 *, struct file_lock___64 *);
	void (*fl_release_private)(struct file_lock___64 *);
};

struct lock_manager_operations___64 {
	int (*lm_compare_owner)(struct file_lock___64 *, struct file_lock___64 *);
	long unsigned int (*lm_owner_key)(struct file_lock___64 *);
	void (*lm_notify)(struct file_lock___64 *);
	int (*lm_grant)(struct file_lock___64 *, struct file_lock___64 *, int);
	void (*lm_break)(struct file_lock___64 *);
	int (*lm_change)(struct file_lock___64 **, int);
};

struct fasync_struct___64 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___64 *fa_next;
	struct file___64 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___64 {
	const char *name;
	int fs_flags;
	struct dentry___65 * (*mount)(struct file_system_type___64 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___65 *);
	struct module *owner;
	struct file_system_type___64 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___64 {
	struct inode___65 * (*alloc_inode)(struct super_block___65 *);
	void (*destroy_inode)(struct inode___65 *);
	void (*dirty_inode)(struct inode___65 *, int);
	int (*write_inode)(struct inode___65 *, struct writeback_control *);
	int (*drop_inode)(struct inode___65 *);
	void (*evict_inode)(struct inode___65 *);
	void (*put_super)(struct super_block___65 *);
	int (*sync_fs)(struct super_block___65 *, int);
	int (*freeze_fs)(struct super_block___65 *);
	int (*unfreeze_fs)(struct super_block___65 *);
	int (*statfs)(struct dentry___65 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___65 *, int *, char *);
	void (*umount_begin)(struct super_block___65 *);
	int (*show_options)(struct seq_file___47 *, struct dentry___65 *);
	int (*show_devname)(struct seq_file___47 *, struct dentry___65 *);
	int (*show_path)(struct seq_file___47 *, struct dentry___65 *);
	int (*show_stats)(struct seq_file___47 *, struct dentry___65 *);
	ssize_t (*quota_read)(struct super_block___65 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___65 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___65 *);
	int (*bdev_try_to_free_page)(struct super_block___65 *, struct page___64 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___65 *);
	void (*free_cached_objects)(struct super_block___65 *, int);
};

struct seq_operations___46;

struct seq_file___47 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___65 lock;
	const struct seq_operations___46 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vm_fault___55 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___64 *page;
};

struct dma_map_ops___26 {
	void * (*alloc)(struct device___52 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___52 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___52 *, struct vm_area_struct___68 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___52 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___52 *, struct page___64 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___52 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___52 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___52 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___52 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___52 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___52 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___52 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___52 *, dma_addr_t);
	int (*dma_supported)(struct device___52 *, u64);
	int (*set_dma_mask)(struct device___52 *, u64);
	int is_phys;
};

struct bus_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___52 *, char *);
	ssize_t (*store)(struct bus_type___52 *, const char *, size_t);
};

struct device_attribute___52;

struct driver_attribute___52;

struct bus_type___52 {
	const char *name;
	const char *dev_name;
	struct device___52 *dev_root;
	struct bus_attribute___52 *bus_attrs;
	struct device_attribute___52 *dev_attrs;
	struct driver_attribute___52 *drv_attrs;
	const struct attribute_group___47 **bus_groups;
	const struct attribute_group___47 **dev_groups;
	const struct attribute_group___47 **drv_groups;
	int (*match)(struct device___52 *, struct device_driver___52 *);
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	int (*probe)(struct device___52 *);
	int (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*online)(struct device___52 *);
	int (*offline)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct device___52 *, struct device_attribute___52 *, char *);
	ssize_t (*store)(struct device___52 *, struct device_attribute___52 *, const char *, size_t);
};

struct driver_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___52 *, char *);
	ssize_t (*store)(struct device_driver___52 *, const char *, size_t);
};

struct device_driver___52 {
	const char *name;
	struct bus_type___52 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___52 *);
	int (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	const struct attribute_group___47 **groups;
	const struct dev_pm_ops___52 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___52 {
	const char *name;
	const struct attribute_group___47 **groups;
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
};

struct class_attribute___52;

struct class___52 {
	const char *name;
	struct module *owner;
	struct class_attribute___52 *class_attrs;
	struct device_attribute___52 *dev_attrs;
	const struct attribute_group___47 **dev_groups;
	struct bin_attribute___47 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *);
	void (*class_release)(struct class___52 *);
	void (*dev_release)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
	struct subsys_private *p;
};

struct class_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct class___52 *, struct class_attribute___52 *, char *);
	ssize_t (*store)(struct class___52 *, struct class_attribute___52 *, const char *, size_t);
	const void * (*namespace)(struct class___52 *, const struct class_attribute___52 *);
};

struct device_rh___52 {
	struct dev_pm_info_rh___52 power;
};

struct nf_afinfo___9 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___5 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___5 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___10 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___5 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___5 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___47 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___47 *);
	void (*irq_shutdown)(struct irq_data___47 *);
	void (*irq_enable)(struct irq_data___47 *);
	void (*irq_disable)(struct irq_data___47 *);
	void (*irq_ack)(struct irq_data___47 *);
	void (*irq_mask)(struct irq_data___47 *);
	void (*irq_mask_ack)(struct irq_data___47 *);
	void (*irq_unmask)(struct irq_data___47 *);
	void (*irq_eoi)(struct irq_data___47 *);
	int (*irq_set_affinity)(struct irq_data___47 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___47 *);
	int (*irq_set_type)(struct irq_data___47 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___47 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___47 *);
	void (*irq_bus_sync_unlock)(struct irq_data___47 *);
	void (*irq_cpu_online)(struct irq_data___47 *);
	void (*irq_cpu_offline)(struct irq_data___47 *);
	void (*irq_suspend)(struct irq_data___47 *);
	void (*irq_resume)(struct irq_data___47 *);
	void (*irq_pm_shutdown)(struct irq_data___47 *);
	void (*irq_print_chip)(struct irq_data___47 *, struct seq_file___47 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___47 *, void *);
	long unsigned int flags;
};

struct seq_operations___46 {
	void * (*start)(struct seq_file___47 *, loff_t *);
	void (*stop)(struct seq_file___47 *, void *);
	void * (*next)(struct seq_file___47 *, void *, loff_t *);
	int (*show)(struct seq_file___47 *, void *);
};

struct linux_binprm___9 {
	char buf[128];
	struct vm_area_struct___68 *vma;
	long unsigned int vma_pages;
	struct mm_struct___68 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___64 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___8 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___64 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

enum what {
	PROC_EVENT_NONE = 0,
	PROC_EVENT_FORK = 1,
	PROC_EVENT_EXEC = 2,
	PROC_EVENT_UID = 4,
	PROC_EVENT_GID = 64,
	PROC_EVENT_SID = 128,
	PROC_EVENT_PTRACE = 256,
	PROC_EVENT_COMM = 512,
	PROC_EVENT_COREDUMP = 1073741824,
	PROC_EVENT_EXIT = 2147483648,
};

typedef u64 async_cookie_t;

typedef void (*async_func_t)(void *, async_cookie_t);

struct async_domain {
	struct list_head pending;
	unsigned int registered: 1;
};

struct async_entry {
	struct list_head domain_list;
	struct list_head global_list;
	struct work_struct work;
	async_cookie_t cookie;
	async_func_t func;
	void *data;
	struct async_domain *domain;
};

struct lglock {
	arch_spinlock_t *lock;
};

struct smp_hotplug_thread___2 {
	struct task_struct___9 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	void (*pre_unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct smpboot_thread_data {
	unsigned int cpu;
	unsigned int status;
	struct smp_hotplug_thread___2 *ht;
};

enum {
	HP_THREAD_NONE = 0,
	HP_THREAD_ACTIVE = 1,
	HP_THREAD_PARKED = 2,
};

struct device___53;

struct dev_pm_ops___53 {
	int (*prepare)(struct device___53 *);
	void (*complete)(struct device___53 *);
	int (*suspend)(struct device___53 *);
	int (*resume)(struct device___53 *);
	int (*freeze)(struct device___53 *);
	int (*thaw)(struct device___53 *);
	int (*poweroff)(struct device___53 *);
	int (*restore)(struct device___53 *);
	int (*suspend_late)(struct device___53 *);
	int (*resume_early)(struct device___53 *);
	int (*freeze_late)(struct device___53 *);
	int (*thaw_early)(struct device___53 *);
	int (*poweroff_late)(struct device___53 *);
	int (*restore_early)(struct device___53 *);
	int (*suspend_noirq)(struct device___53 *);
	int (*resume_noirq)(struct device___53 *);
	int (*freeze_noirq)(struct device___53 *);
	int (*thaw_noirq)(struct device___53 *);
	int (*poweroff_noirq)(struct device___53 *);
	int (*restore_noirq)(struct device___53 *);
	int (*runtime_suspend)(struct device___53 *);
	int (*runtime_resume)(struct device___53 *);
	int (*runtime_idle)(struct device___53 *);
};

struct dma_map_ops___27;

struct dev_archdata___27 {
	struct dma_map_ops___27 *dma_ops;
	void *iommu;
};

struct device_type___53;

struct bus_type___53;

struct device_driver___53;

struct dev_pm_domain___53;

struct class___53;

struct device_rh___53;

struct device___53 {
	struct device___53 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___53 *type;
	struct mutex___51 mutex;
	struct bus_type___53 *bus;
	struct device_driver___53 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___53 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___27 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___53 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___53 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___53 *device_rh;
};

struct dev_pm_info_rh___53 {
	void (*set_latency_tolerance)(struct device___53 *, s32);
};

struct dev_pm_domain___53 {
	struct dev_pm_ops___53 ops;
};

struct dma_map_ops___27 {
	void * (*alloc)(struct device___53 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___53 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___53 *, struct vm_area_struct___54 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___53 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___53 *, struct page___64 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___53 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___53 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___53 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___53 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___53 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___53 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___53 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___53 *, dma_addr_t);
	int (*dma_supported)(struct device___53 *, u64);
	int (*set_dma_mask)(struct device___53 *, u64);
	int is_phys;
};

struct bus_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___53 *, char *);
	ssize_t (*store)(struct bus_type___53 *, const char *, size_t);
};

struct device_attribute___53;

struct driver_attribute___53;

struct bus_type___53 {
	const char *name;
	const char *dev_name;
	struct device___53 *dev_root;
	struct bus_attribute___53 *bus_attrs;
	struct device_attribute___53 *dev_attrs;
	struct driver_attribute___53 *drv_attrs;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___53 *, struct device_driver___53 *);
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	int (*probe)(struct device___53 *);
	int (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*online)(struct device___53 *);
	int (*offline)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct device___53 *, struct device_attribute___53 *, char *);
	ssize_t (*store)(struct device___53 *, struct device_attribute___53 *, const char *, size_t);
};

struct driver_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___53 *, char *);
	ssize_t (*store)(struct device_driver___53 *, const char *, size_t);
};

struct device_driver___53 {
	const char *name;
	struct bus_type___53 *bus;
	struct module___33 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___53 *);
	int (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	const struct attribute_group___34 **groups;
	const struct dev_pm_ops___53 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___53 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
};

struct class_attribute___53;

struct class___53 {
	const char *name;
	struct module___33 *owner;
	struct class_attribute___53 *class_attrs;
	struct device_attribute___53 *dev_attrs;
	const struct attribute_group___34 **dev_groups;
	struct bin_attribute___34 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *);
	void (*class_release)(struct class___53 *);
	void (*dev_release)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
	struct subsys_private *p;
};

struct class_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct class___53 *, struct class_attribute___53 *, char *);
	ssize_t (*store)(struct class___53 *, struct class_attribute___53 *, const char *, size_t);
	const void * (*namespace)(struct class___53 *, const struct class_attribute___53 *);
};

struct device_rh___53 {
	struct dev_pm_info_rh___53 power;
};

struct nf_hook_state___2 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device *in;
	struct net_device *out;
	struct sock *sk;
	int (*okfn)(struct sock *, struct sk_buff___3 *);
};

struct rh_kabi_structs_7_0 {
	int pad;
};

struct rh_kabi_structs_7_2 {
	struct nf_hook_state___2 *nf_hook_state;
};

struct page___65;

typedef struct page___65 *pgtable_t___65;

struct address_space___65;

struct kmem_cache___56;

struct page___65 {
	long unsigned int flags;
	struct address_space___65 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___65 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___65 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___56 *slab_cache;
		struct page___65 *first_page;
	};
	long: 64;
};

struct thread_struct___32;

struct pv_cpu_ops___65 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___2 *);
	void (*end_context_switch)(struct task_struct___2 *);
};

struct perf_event___32;

struct thread_struct___32 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___32 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___34;

struct pid_link___34 {
	struct hlist_node node;
	struct pid___34 *pid;
};

struct mutex___66 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___2 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___62 {
	struct page___65 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___69;

struct nsproxy___35;

struct signal_struct___65;

struct bio_list___7;

struct backing_dev_info___8;

struct io_context___7;

struct css_set___37;

struct perf_event_context___32;

struct task_struct___2 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___2 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___69 *mm;
	struct mm_struct___69 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___2 *real_parent;
	struct task_struct___2 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___2 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___65 = 0,
		VTIME_USER___65 = 1,
		VTIME_SYS___65 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___65 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___7 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___8 *backing_dev_info;
	struct io_context___7 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___37 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___32 *perf_event_ctxp[2];
	struct mutex___66 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___62 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___69 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___69 *, struct mm_struct___69 *);
	void (*dup_mmap)(struct mm_struct___69 *, struct mm_struct___69 *);
	void (*exit_mmap)(struct mm_struct___69 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___69 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___69 *);
	void (*pgd_free)(struct mm_struct___69 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___69 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___69 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___69 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___69 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___69 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___69 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___69 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___69 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___69 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___69 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___69 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___66 lock;
	void *vdso;
} mm_context_t___66;

struct xol_area___65;

struct uprobes_state___65 {
	struct xol_area___65 *xol_area;
};

struct vm_area_struct___69;

struct file___65;

struct linux_binfmt___9;

struct core_state___65;

struct mm_struct___69 {
	struct vm_area_struct___69 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___69 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___69 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___9 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___66 context;
	long unsigned int flags;
	struct core_state___65 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___2 *owner;
	struct file___65 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___65 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___40;

struct exec_domain___18 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___40 *module;
	struct exec_domain___18 *next;
};

struct module_kobject___39 {
	struct kobject___3 kobj;
	struct module___40 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___39;

struct ftrace_event_call___24;

struct module___40 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___39 mkobj;
	struct module_attribute___39 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___24 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___2 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___32 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___2 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___2 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___2 *target;
};

typedef void (*perf_overflow_handler_t___32)(struct perf_event___32 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___32;

typedef void (*ftrace_func_t___32)(long unsigned int, long unsigned int, struct ftrace_ops___32 *, struct pt_regs *);

struct ftrace_ops___32 {
	ftrace_func_t___32 func;
	struct ftrace_ops___32 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___66 regex_lock;
};

struct pmu___32;

struct fasync_struct___65;

struct pid_namespace___34;

struct perf_cgroup___32;

struct perf_event___32 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___32 *group_leader;
	struct pmu___32 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___32 hw;
	struct perf_event_context___32 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___66 child_mutex;
	struct list_head child_list;
	struct perf_event___32 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___2 *owner;
	struct mutex___66 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___65 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___32 *);
	struct callback_head callback_head;
	struct pid_namespace___34 *ns;
	u64 id;
	perf_overflow_handler_t___32 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___24 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___32 ftrace_ops;
	struct perf_cgroup___32 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___29 {
	struct task_struct___2 *task;
	struct exec_domain___18 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct preempt_notifier;

struct preempt_ops {
	void (*sched_in)(struct preempt_notifier *, int);
	void (*sched_out)(struct preempt_notifier *, struct task_struct___2 *);
};

struct preempt_notifier {
	struct hlist_node link;
	struct preempt_ops *ops;
};

struct zone___65;

struct lruvec___65 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___65 *zone;
};

struct pglist_data___65;

struct zone___65 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___65 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___65 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___65 {
	struct zone___65 *zone;
	int zone_idx;
};

struct zonelist___65 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___65 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___65 {
	struct zone___65 node_zones[4];
	struct zonelist___65 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___2 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___48;

struct x86_io_apic_ops___48 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___48 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___48;

struct irq_data___48 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___48 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___54;

struct dev_pm_ops___54 {
	int (*prepare)(struct device___54 *);
	void (*complete)(struct device___54 *);
	int (*suspend)(struct device___54 *);
	int (*resume)(struct device___54 *);
	int (*freeze)(struct device___54 *);
	int (*thaw)(struct device___54 *);
	int (*poweroff)(struct device___54 *);
	int (*restore)(struct device___54 *);
	int (*suspend_late)(struct device___54 *);
	int (*resume_early)(struct device___54 *);
	int (*freeze_late)(struct device___54 *);
	int (*thaw_early)(struct device___54 *);
	int (*poweroff_late)(struct device___54 *);
	int (*restore_early)(struct device___54 *);
	int (*suspend_noirq)(struct device___54 *);
	int (*resume_noirq)(struct device___54 *);
	int (*freeze_noirq)(struct device___54 *);
	int (*thaw_noirq)(struct device___54 *);
	int (*poweroff_noirq)(struct device___54 *);
	int (*restore_noirq)(struct device___54 *);
	int (*runtime_suspend)(struct device___54 *);
	int (*runtime_resume)(struct device___54 *);
	int (*runtime_idle)(struct device___54 *);
};

struct dma_map_ops___28;

struct dev_archdata___28 {
	struct dma_map_ops___28 *dma_ops;
	void *iommu;
};

struct device_type___54;

struct bus_type___54;

struct device_driver___54;

struct dev_pm_domain___54;

struct class___54;

struct attribute_group___48;

struct device_rh___54;

struct device___54 {
	struct device___54 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___54 *type;
	struct mutex___66 mutex;
	struct bus_type___54 *bus;
	struct device_driver___54 *driver;
	void *platform_data;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___54 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___54 *class;
	const struct attribute_group___48 **groups;
	void (*release)(struct device___54 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___54 *device_rh;
};

struct dev_pm_info_rh___54 {
	void (*set_latency_tolerance)(struct device___54 *, s32);
};

struct dev_pm_domain___54 {
	struct dev_pm_ops___54 ops;
};

struct smp_ops___65 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___2 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct llist_head {
	struct llist_node *first;
};

struct xol_area___65 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___65 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___56;

struct memcg_cache_params___56;

struct kmem_cache___56 {
	struct kmem_cache_cpu___56 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___56 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___66;

struct address_space_operations___65;

struct address_space___65 {
	struct inode___66 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___66 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___65 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___8 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___66;

struct path___65 {
	struct vfsmount *mnt;
	struct dentry___66 *dentry;
};

struct fown_struct___34 {
	rwlock_t lock;
	struct pid___34 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___65;

struct file___65 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___65 f_path;
	struct inode___66 *f_inode;
	const struct file_operations___65 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___65 *f_mapping;
	struct mutex___66 f_pos_lock;
};

struct vm_operations_struct___59;

struct vm_area_struct___69 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___69 *vm_next;
	struct vm_area_struct___69 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___69 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___59 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___65 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___56;

struct vm_operations_struct___59 {
	void (*open)(struct vm_area_struct___69 *);
	void (*close)(struct vm_area_struct___69 *);
	int (*fault)(struct vm_area_struct___69 *, struct vm_fault___56 *);
	int (*page_mkwrite)(struct vm_area_struct___69 *, struct vm_fault___56 *);
	int (*access)(struct vm_area_struct___69 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___69 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___69 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___69 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___69 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___65 {
	struct task_struct___2 *task;
	struct core_thread___65 *next;
};

struct core_state___65 {
	atomic_t nr_threads;
	struct core_thread___65 dumper;
	struct completion startup;
};

struct linux_binprm___10;

struct coredump_params___9;

struct linux_binfmt___9 {
	struct list_head lh;
	struct module___40 *module;
	int (*load_binary)(struct linux_binprm___10 *);
	int (*load_shlib)(struct file___65 *);
	int (*core_dump)(struct coredump_params___9 *);
	long unsigned int min_coredump;
};

struct vm_fault___56 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___65 *page;
};

struct ctl_table_header___10;

struct ctl_node___10 {
	struct rb_node node;
	struct ctl_table_header___10 *header;
};

struct ctl_table_root___10;

struct ctl_table_set___10;

struct ctl_dir___10;

struct ctl_table_header___10 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___10 *root;
	struct ctl_table_set___10 *set;
	struct ctl_dir___10 *parent;
	struct ctl_node___10 *node;
};

struct ctl_dir___10 {
	struct ctl_table_header___10 header;
	struct rb_root root;
};

struct ctl_table_set___10 {
	int (*is_seen)(struct ctl_table_set___10 *);
	struct ctl_dir___10 dir;
};

struct ctl_table_root___10 {
	struct ctl_table_set___10 default_set;
	struct ctl_table_set___10 * (*lookup)(struct ctl_table_root___10 *, struct nsproxy___35 *);
	int (*permissions)(struct ctl_table_header___10 *, struct ctl_table *);
};

struct net___11;

struct nsproxy___35 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___34 *pid_ns;
	struct net___11 *net_ns;
};

struct bin_attribute___48;

struct attribute_group___48 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___48 **bin_attrs;
};

struct bin_attribute___48 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___65 *, struct kobject___3 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___65 *, struct kobject___3 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	int (*mmap)(struct file___65 *, struct kobject___3 *, struct bin_attribute___48 *, struct vm_area_struct___69 *);
};

struct module_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___39 *, struct module_kobject___39 *, char *);
	ssize_t (*store)(struct module_attribute___39 *, struct module_kobject___39 *, const char *, size_t);
	void (*setup)(struct module___40 *, const char *);
	int (*test)(struct module___40 *);
	void (*free)(struct module___40 *);
};

struct trace_event_functions___24;

struct trace_event___24 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___24 *funcs;
};

struct ftrace_event_class___24;

struct ftrace_event_call___24 {
	struct list_head list;
	struct ftrace_event_class___24 *class;
	char *name;
	struct trace_event___24 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct upid___34 {
	int nr;
	struct pid_namespace___34 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___34 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___2 *child_reaper;
	struct kmem_cache___56 *pid_cachep;
	unsigned int level;
	struct pid_namespace___34 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___66 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___34 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___34 numbers[1];
};

struct idle_stat {
	long unsigned int ctx_jiff;
	u64 last_switches;
	int status;
};

struct signal_struct___65 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___2 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___2 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___66 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup {
	struct kref kref;
	struct task_group *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct wake_q_head {
	struct wake_q_node *first;
	struct wake_q_node **lastp;
};

struct sched_domain_attr {
	int relax_domain_level;
};

struct sched_group {
	struct sched_group *next;
	atomic_t ref;
	unsigned int group_weight;
	struct sched_group_power *sgp;
	long unsigned int cpumask[0];
};

struct sched_group_power {
	atomic_t ref;
	unsigned int power;
	unsigned int power_orig;
	long unsigned int next_update;
	int imbalance;
	atomic_t nr_busy_cpus;
	long unsigned int cpumask[0];
};

struct cfs_rq {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity *curr;
	struct sched_entity *next;
	struct sched_entity *last;
	struct sched_entity *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_prio_array {
	long unsigned int bitmap[2];
	struct list_head queue[100];
};

struct rt_rq {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group *tg;
};

struct cgroup___37;

struct cgroup_subsys_state___37 {
	struct cgroup___37 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct rt_bandwidth {
	raw_spinlock_t rt_runtime_lock;
	ktime_t rt_period;
	u64 rt_runtime;
	struct hrtimer rt_period_timer;
};

struct cfs_bandwidth {
	raw_spinlock_t lock;
	ktime_t period;
	u64 quota;
	u64 runtime;
	s64 hierarchal_quota;
	u64 runtime_expires;
	int idle;
	int timer_active;
	struct hrtimer period_timer;
	struct hrtimer slack_timer;
	struct list_head throttled_cfs_rq;
	int nr_periods;
	int nr_throttled;
	u64 throttled_time;
};

struct task_group {
	struct cgroup_subsys_state___37 css;
	struct sched_entity **se;
	struct cfs_rq **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity **rt_se;
	struct rt_rq **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct bio___7;

struct bio_list___7 {
	struct bio___7 *head;
	struct bio___7 *tail;
};

struct bdi_writeback___8 {
	struct backing_dev_info___8 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___8 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___8 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___54 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___66 *debug_dir;
	struct dentry___66 *debug_stats;
};

struct io_cq___7;

struct io_context___7 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___7 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___37 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___37 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___32 {
	struct pmu___32 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___66 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___2 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___32 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___65;

struct super_block___66;

struct dentry___66 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___66 *d_parent;
	struct qstr d_name;
	struct inode___66 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___65 *d_op;
	struct super_block___66 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___65;

struct file_lock___65;

struct dquot___65;

struct block_device___65;

struct inode___66 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___65 *i_op;
	struct super_block___66 *i_sb;
	struct address_space___65 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___66 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___65 *i_fop;
	struct file_lock___65 *i_flock;
	struct address_space___65 i_data;
	struct dquot___65 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___65 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___65 {
	int (*d_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_hash)(const struct dentry___66 *, struct qstr *);
	int (*d_compare)(const struct dentry___66 *, const struct dentry___66 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___66 *);
	void (*d_release)(struct dentry___66 *);
	void (*d_prune)(struct dentry___66 *);
	void (*d_iput)(struct dentry___66 *, struct inode___66 *);
	char * (*d_dname)(struct dentry___66 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___65 *);
	int (*d_manage)(struct dentry___66 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___65;

struct mem_dqinfo___65 {
	struct quota_format_type___65 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___65;

struct quota_info___65 {
	unsigned int flags;
	struct mutex___66 dqio_mutex;
	struct mutex___66 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___66 *files[2];
	struct mem_dqinfo___65 info[2];
	const struct quota_format_ops___65 *ops[2];
};

struct file_system_type___65;

struct super_operations___65;

struct dquot_operations___65;

struct quotactl_ops___65;

struct xattr_handler___37;

struct super_block___66 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___65 *s_type;
	const struct super_operations___65 *s_op;
	const struct dquot_operations___65 *dq_op;
	const struct quotactl_ops___65 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___66 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___37 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___65 *s_bdev;
	struct backing_dev_info___8 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___65 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___66 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___65 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___7(struct bio___7 *, int);

struct bio_vec___7 {
	struct page___65 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___7;

struct bio_set___7;

struct bio___7 {
	sector_t bi_sector;
	struct bio___7 *bi_next;
	struct block_device___65 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___7 *bi_end_io;
	void *bi_private;
	struct io_context___7 *bi_ioc;
	struct cgroup_subsys_state___37 *bi_css;
	struct bio_integrity_payload___7 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___7 *bi_io_vec;
	struct bio_set___7 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	struct bio_vec___7 bi_inline_vecs[0];
};

struct hd_struct___7;

struct gendisk___7;

struct request_queue___7;

struct block_device___65 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___66 *bd_inode;
	struct super_block___66 *bd_super;
	struct mutex___66 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___65 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___7 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___7 *bd_disk;
	struct request_queue___7 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___66 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___7 {
	struct bio___7 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___7 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___7 *bip_vec;
	struct bio_vec___7 bip_inline_vecs[0];
};

struct bio_set___7 {
	struct kmem_cache___56 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___7 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___66 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___65 *ia_file;
};

struct dquot___65 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___66 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___66 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___65 {
	int qf_fmt_id;
	const struct quota_format_ops___65 *qf_ops;
	struct module___40 *qf_owner;
	struct quota_format_type___65 *qf_next;
};

struct quota_format_ops___65 {
	int (*check_quota_file)(struct super_block___66 *, int);
	int (*read_file_info)(struct super_block___66 *, int);
	int (*write_file_info)(struct super_block___66 *, int);
	int (*free_file_info)(struct super_block___66 *, int);
	int (*read_dqblk)(struct dquot___65 *);
	int (*commit_dqblk)(struct dquot___65 *);
	int (*release_dqblk)(struct dquot___65 *);
};

struct dquot_operations___65 {
	int (*write_dquot)(struct dquot___65 *);
	struct dquot___65 * (*alloc_dquot)(struct super_block___66 *, int);
	void (*destroy_dquot)(struct dquot___65 *);
	int (*acquire_dquot)(struct dquot___65 *);
	int (*release_dquot)(struct dquot___65 *);
	int (*mark_dirty)(struct dquot___65 *);
	int (*write_info)(struct super_block___66 *, int);
	qsize_t * (*get_reserved_space)(struct inode___66 *);
};

struct quotactl_ops___65 {
	int (*quota_on)(struct super_block___66 *, int, int, struct path___65 *);
	int (*quota_on_meta)(struct super_block___66 *, int, int);
	int (*quota_off)(struct super_block___66 *, int);
	int (*quota_sync)(struct super_block___66 *, int);
	int (*get_info)(struct super_block___66 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___66 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___66 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___66 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___66 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___66 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___66 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___66 *, unsigned int);
};

struct swap_info_struct___11;

struct address_space_operations___65 {
	int (*writepage)(struct page___65 *, struct writeback_control *);
	int (*readpage)(struct file___65 *, struct page___65 *);
	int (*writepages)(struct address_space___65 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___65 *);
	int (*readpages)(struct file___65 *, struct address_space___65 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___65 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___65 **, void **);
	int (*write_end)(struct file___65 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___65 *, void *);
	sector_t (*bmap)(struct address_space___65 *, sector_t);
	void (*invalidatepage)(struct page___65 *, long unsigned int);
	int (*releasepage)(struct page___65 *, gfp_t);
	void (*freepage)(struct page___65 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___65 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___65 *, struct page___65 *, struct page___65 *, enum migrate_mode);
	int (*launder_page)(struct page___65 *);
	int (*is_partially_uptodate)(struct page___65 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___65 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___65 *, struct page___65 *);
	int (*swap_activate)(struct swap_info_struct___11 *, struct file___65 *, sector_t *);
	void (*swap_deactivate)(struct file___65 *);
	void (*invalidatepage_range)(struct page___65 *, unsigned int, unsigned int);
};

struct swap_info_struct___11 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___65 *bdev;
	struct file___65 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___7 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___54 __dev;
	struct kobject___3 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___7;

struct block_device_operations___7;

struct gendisk___7 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___7 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___7 *part_tbl;
	struct hd_struct___7 part0;
	const struct block_device_operations___7 *fops;
	struct request_queue___7 *queue;
	void *private_data;
	int flags;
	struct device___54 *driverfs_dev;
	struct kobject___3 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___7 {
	struct request_queue___7 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___7(struct request_queue___7 *);

typedef void make_request_fn___7(struct request_queue___7 *, struct bio___7 *);

struct request___7;

typedef int prep_rq_fn___7(struct request_queue___7 *, struct request___7 *);

struct bvec_merge_data___7;

typedef int merge_bvec_fn___7(struct request_queue___7 *, struct bvec_merge_data___7 *, struct bio_vec___7 *);

typedef void softirq_done_fn___7(struct request___7 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___7(struct request___7 *);

typedef int dma_drain_needed_fn___7(struct request___7 *);

typedef int lld_busy_fn___7(struct request_queue___7 *);

struct bsg_class_device___7 {
	struct device___54 *class_dev;
	struct device___54 *parent;
	int minor;
	struct request_queue___7 *queue;
	struct kref ref;
	void (*release)(struct device___54 *);
};

typedef void unprep_rq_fn___7(struct request_queue___7 *, struct request___7 *);

struct elevator_queue___7;

struct blk_queue_tag___7;

struct request_queue___7 {
	struct list_head queue_head;
	struct request___7 *last_merge;
	struct elevator_queue___7 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___7 root_rl;
	request_fn_proc___7 *request_fn;
	make_request_fn___7 *make_request_fn;
	prep_rq_fn___7 *prep_rq_fn;
	merge_bvec_fn___7 *merge_bvec_fn;
	softirq_done_fn___7 *softirq_done_fn;
	rq_timed_out_fn___7 *rq_timed_out_fn;
	dma_drain_needed_fn___7 *dma_drain_needed;
	lld_busy_fn___7 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___7 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___8 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___3 kobj;
	struct kobject___3 mq_kobj;
	struct device___54 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___7 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___7 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___66 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___7 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___7 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___7 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___65 {
	struct dentry___66 * (*lookup)(struct inode___66 *, struct dentry___66 *, unsigned int);
	void * (*follow_link)(struct dentry___66 *, struct nameidata *);
	int (*permission)(struct inode___66 *, int);
	struct posix_acl * (*get_acl)(struct inode___66 *, int);
	int (*readlink)(struct dentry___66 *, char *, int);
	void (*put_link)(struct dentry___66 *, struct nameidata *, void *);
	int (*create)(struct inode___66 *, struct dentry___66 *, umode_t, bool);
	int (*link)(struct dentry___66 *, struct inode___66 *, struct dentry___66 *);
	int (*unlink)(struct inode___66 *, struct dentry___66 *);
	int (*symlink)(struct inode___66 *, struct dentry___66 *, const char *);
	int (*mkdir)(struct inode___66 *, struct dentry___66 *, umode_t);
	int (*rmdir)(struct inode___66 *, struct dentry___66 *);
	int (*mknod)(struct inode___66 *, struct dentry___66 *, umode_t, dev_t);
	int (*rename)(struct inode___66 *, struct dentry___66 *, struct inode___66 *, struct dentry___66 *);
	int (*setattr)(struct dentry___66 *, struct iattr___66 *);
	int (*getattr)(struct vfsmount *, struct dentry___66 *, struct kstat *);
	int (*setxattr)(struct dentry___66 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___66 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___66 *, char *, size_t);
	int (*removexattr)(struct dentry___66 *, const char *);
	int (*fiemap)(struct inode___66 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___66 *, struct timespec *, int);
	int (*atomic_open)(struct inode___66 *, struct dentry___66 *, struct file___65 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___41;

struct seq_file___48;

struct file_operations___65 {
	struct module___40 *owner;
	loff_t (*llseek)(struct file___65 *, loff_t, int);
	ssize_t (*read)(struct file___65 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___65 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___65 *, void *, filldir_t);
	unsigned int (*poll)(struct file___65 *, struct poll_table_struct___41 *);
	long int (*unlocked_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___65 *, struct vm_area_struct___69 *);
	int (*open)(struct inode___66 *, struct file___65 *);
	int (*flush)(struct file___65 *, fl_owner_t);
	int (*release)(struct inode___66 *, struct file___65 *);
	int (*fsync)(struct file___65 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___65 *, int);
	int (*lock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*sendpage)(struct file___65 *, struct page___65 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___65 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___65 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___65 *, long int, struct file_lock___65 **, void **);
		struct {
			int (*setlease)(struct file___65 *, long int, struct file_lock___65 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___65 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___48 *, struct file___65 *);
};

struct file_lock_operations___65;

struct lock_manager_operations___65;

struct file_lock___65 {
	struct file_lock___65 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___65 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___65 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___65 *fl_ops;
	const struct lock_manager_operations___65 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___65 {
	void (*fl_copy_lock)(struct file_lock___65 *, struct file_lock___65 *);
	void (*fl_release_private)(struct file_lock___65 *);
};

struct lock_manager_operations___65 {
	int (*lm_compare_owner)(struct file_lock___65 *, struct file_lock___65 *);
	long unsigned int (*lm_owner_key)(struct file_lock___65 *);
	void (*lm_notify)(struct file_lock___65 *);
	int (*lm_grant)(struct file_lock___65 *, struct file_lock___65 *, int);
	void (*lm_break)(struct file_lock___65 *);
	int (*lm_change)(struct file_lock___65 **, int);
};

struct fasync_struct___65 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___65 *fa_next;
	struct file___65 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___65 {
	const char *name;
	int fs_flags;
	struct dentry___66 * (*mount)(struct file_system_type___65 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___66 *);
	struct module___40 *owner;
	struct file_system_type___65 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___65 {
	struct inode___66 * (*alloc_inode)(struct super_block___66 *);
	void (*destroy_inode)(struct inode___66 *);
	void (*dirty_inode)(struct inode___66 *, int);
	int (*write_inode)(struct inode___66 *, struct writeback_control *);
	int (*drop_inode)(struct inode___66 *);
	void (*evict_inode)(struct inode___66 *);
	void (*put_super)(struct super_block___66 *);
	int (*sync_fs)(struct super_block___66 *, int);
	int (*freeze_fs)(struct super_block___66 *);
	int (*unfreeze_fs)(struct super_block___66 *);
	int (*statfs)(struct dentry___66 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___66 *, int *, char *);
	void (*umount_begin)(struct super_block___66 *);
	int (*show_options)(struct seq_file___48 *, struct dentry___66 *);
	int (*show_devname)(struct seq_file___48 *, struct dentry___66 *);
	int (*show_path)(struct seq_file___48 *, struct dentry___66 *);
	int (*show_stats)(struct seq_file___48 *, struct dentry___66 *);
	ssize_t (*quota_read)(struct super_block___66 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___66 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___66 *);
	int (*bdev_try_to_free_page)(struct super_block___66 *, struct page___65 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___66 *);
	void (*free_cached_objects)(struct super_block___66 *, int);
};

struct xattr_handler___37 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___66 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___66 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___66 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___41)(struct file___65 *, wait_queue_head_t *, struct poll_table_struct___41 *);

struct poll_table_struct___41 {
	poll_queue_proc___41 _qproc;
	long unsigned int _key;
};

struct seq_operations___47;

struct seq_file___48 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___66 lock;
	const struct seq_operations___47 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___48 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___48 *);
	void (*irq_shutdown)(struct irq_data___48 *);
	void (*irq_enable)(struct irq_data___48 *);
	void (*irq_disable)(struct irq_data___48 *);
	void (*irq_ack)(struct irq_data___48 *);
	void (*irq_mask)(struct irq_data___48 *);
	void (*irq_mask_ack)(struct irq_data___48 *);
	void (*irq_unmask)(struct irq_data___48 *);
	void (*irq_eoi)(struct irq_data___48 *);
	int (*irq_set_affinity)(struct irq_data___48 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___48 *);
	int (*irq_set_type)(struct irq_data___48 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___48 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___48 *);
	void (*irq_bus_sync_unlock)(struct irq_data___48 *);
	void (*irq_cpu_online)(struct irq_data___48 *);
	void (*irq_cpu_offline)(struct irq_data___48 *);
	void (*irq_suspend)(struct irq_data___48 *);
	void (*irq_resume)(struct irq_data___48 *);
	void (*irq_pm_shutdown)(struct irq_data___48 *);
	void (*irq_print_chip)(struct irq_data___48 *, struct seq_file___48 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___48 *, void *);
	long unsigned int flags;
};

struct tlb_state___23 {
	struct mm_struct___69 *active_mm;
	int state;
};

struct kernel_cpustat {
	u64 cpustat[13];
};

struct netns_core___10 {
	struct ctl_table_header___10 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___10 {
	struct mutex___66 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___10 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___10 *ctl;
};

struct netns_ipv4___10 {
	struct ctl_table_header___10 *forw_hdr;
	struct ctl_table_header___10 *frags_hdr;
	struct ctl_table_header___10 *ipv4_hdr;
	struct ctl_table_header___10 *route_hdr;
	struct ctl_table_header___10 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___10 {
	struct ctl_table_header___10 *hdr;
	struct ctl_table_header___10 *route_hdr;
	struct ctl_table_header___10 *icmp_hdr;
	struct ctl_table_header___10 *frags_hdr;
	struct ctl_table_header___10 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___10 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___10 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___6 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___6 *);
	int (*local_out)(struct sk_buff___6 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___6 *, const void *);
	struct kmem_cache___56 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___10 {
	struct netns_sysctl_ipv6___10 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___10 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___10 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___10 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___10 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___10 *nf_log_dir_header;
};

struct nf_proto_net___10 {
	struct ctl_table_header___10 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___10 {
	struct nf_proto_net___10 pn;
	unsigned int timeout;
};

struct nf_tcp_net___10 {
	struct nf_proto_net___10 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___10 {
	struct nf_proto_net___10 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___10 {
	struct nf_proto_net___10 pn;
	unsigned int timeout;
};

struct nf_ip_net___10 {
	struct nf_generic_net___10 generic;
	struct nf_tcp_net___10 tcp;
	struct nf_udp_net___10 udp;
	struct nf_icmp_net___10 icmp;
	struct nf_icmp_net___10 icmpv6;
};

struct netns_ct___10 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___10 *sysctl_header;
	struct ctl_table_header___10 *acct_sysctl_header;
	struct ctl_table_header___10 *tstamp_sysctl_header;
	struct ctl_table_header___10 *event_sysctl_header;
	struct ctl_table_header___10 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___56 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___10 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___10 {
	struct netns_sysctl_ipv6___10 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___10 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___10 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___10 xfrm4_dst_ops;
	struct dst_ops___10 xfrm6_dst_ops;
};

struct net___11 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___10 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___10 core;
	struct netns_mib mib;
	struct netns_packet___10 packet;
	struct netns_unix___10 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___10 ipv4;
	struct netns_ipv6___10 ipv6;
	struct netns_sctp___10 sctp;
	struct netns_dccp___3 dccp;
	struct netns_nf___10 nf;
	struct netns_xt xt;
	struct netns_ct___10 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___10 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___10 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___66 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___66 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___28 {
	void * (*alloc)(struct device___54 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___54 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___54 *, struct vm_area_struct___69 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___54 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___54 *, struct page___65 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___54 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___54 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___54 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___54 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___54 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___54 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___54 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___54 *, dma_addr_t);
	int (*dma_supported)(struct device___54 *, u64);
	int (*set_dma_mask)(struct device___54 *, u64);
	int is_phys;
};

struct bus_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___54 *, char *);
	ssize_t (*store)(struct bus_type___54 *, const char *, size_t);
};

struct device_attribute___54;

struct driver_attribute___54;

struct bus_type___54 {
	const char *name;
	const char *dev_name;
	struct device___54 *dev_root;
	struct bus_attribute___54 *bus_attrs;
	struct device_attribute___54 *dev_attrs;
	struct driver_attribute___54 *drv_attrs;
	const struct attribute_group___48 **bus_groups;
	const struct attribute_group___48 **dev_groups;
	const struct attribute_group___48 **drv_groups;
	int (*match)(struct device___54 *, struct device_driver___54 *);
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	int (*probe)(struct device___54 *);
	int (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*online)(struct device___54 *);
	int (*offline)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct device___54 *, struct device_attribute___54 *, char *);
	ssize_t (*store)(struct device___54 *, struct device_attribute___54 *, const char *, size_t);
};

struct driver_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___54 *, char *);
	ssize_t (*store)(struct device_driver___54 *, const char *, size_t);
};

struct device_driver___54 {
	const char *name;
	struct bus_type___54 *bus;
	struct module___40 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___54 *);
	int (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	const struct attribute_group___48 **groups;
	const struct dev_pm_ops___54 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___54 {
	const char *name;
	const struct attribute_group___48 **groups;
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
};

struct class_attribute___54;

struct class___54 {
	const char *name;
	struct module___40 *owner;
	struct class_attribute___54 *class_attrs;
	struct device_attribute___54 *dev_attrs;
	const struct attribute_group___48 **dev_groups;
	struct bin_attribute___48 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *);
	void (*class_release)(struct class___54 *);
	void (*dev_release)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
	struct subsys_private *p;
};

struct class_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct class___54 *, struct class_attribute___54 *, char *);
	ssize_t (*store)(struct class___54 *, struct class_attribute___54 *, const char *, size_t);
	const void * (*namespace)(struct class___54 *, const struct class_attribute___54 *);
};

struct device_rh___54 {
	struct dev_pm_info_rh___54 power;
};

struct kmem_cache_cpu___56 {
	void **freelist;
	long unsigned int tid;
	struct page___65 *page;
	struct page___65 *partial;
};

struct memcg_cache_params___56 {
	bool is_root_cache;
	union {
		struct kmem_cache___56 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___56 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___37;

struct cgroup___37 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___37 *parent;
	struct dentry___66 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___37 *subsys[11];
	struct cgroupfs_root___37 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___66 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___37 {
	struct super_block___66 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___37 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___13 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___66 *, struct file___65 *);
	ssize_t (*read)(struct cgroup___37 *, struct cftype___13 *, struct file___65 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___37 *, struct cftype___13 *);
	s64 (*read_s64)(struct cgroup___37 *, struct cftype___13 *);
	int (*read_map)(struct cgroup___37 *, struct cftype___13 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___37 *, struct cftype___13 *, struct seq_file___48 *);
	ssize_t (*write)(struct cgroup___37 *, struct cftype___13 *, struct file___65 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___37 *, struct cftype___13 *, u64);
	int (*write_s64)(struct cgroup___37 *, struct cftype___13 *, s64);
	int (*write_string)(struct cgroup___37 *, struct cftype___13 *, const char *);
	int (*trigger)(struct cgroup___37 *, unsigned int);
	int (*release)(struct inode___66 *, struct file___65 *);
	int (*register_event)(struct cgroup___37 *, struct cftype___13 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___37 *, struct cftype___13 *, struct eventfd_ctx *);
};

struct cftype_set___12 {
	struct list_head node;
	struct cftype___13 *cfts;
};

struct task_and_cgroup___12 {
	struct task_struct___2 *task;
	struct cgroup___37 *cgrp;
	struct css_set___37 *cg;
};

struct cgroup_taskset___12 {
	struct task_and_cgroup___12 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___37 *cur_cgrp;
};

struct cgroup_subsys___12 {
	struct cgroup_subsys_state___37 * (*css_alloc)(struct cgroup___37 *);
	int (*css_online)(struct cgroup___37 *);
	void (*css_offline)(struct cgroup___37 *);
	void (*css_free)(struct cgroup___37 *);
	int (*can_attach)(struct cgroup___37 *, struct cgroup_taskset___12 *);
	void (*cancel_attach)(struct cgroup___37 *, struct cgroup_taskset___12 *);
	void (*attach)(struct cgroup___37 *, struct cgroup_taskset___12 *);
	void (*fork)(struct task_struct___2 *);
	void (*exit)(struct cgroup___37 *, struct cgroup___37 *, struct task_struct___2 *);
	void (*bind)(struct cgroup___37 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___37 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___13 *base_cftypes;
	struct cftype_set___12 base_cftset;
	struct module___40 *module;
};

struct perf_cpu_context___32;

struct pmu___32 {
	struct list_head entry;
	struct device___54 *dev;
	const struct attribute_group___48 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___32 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___32 *);
	void (*pmu_disable)(struct pmu___32 *);
	int (*event_init)(struct perf_event___32 *);
	int (*add)(struct perf_event___32 *, int);
	void (*del)(struct perf_event___32 *, int);
	void (*start)(struct perf_event___32 *, int);
	void (*stop)(struct perf_event___32 *, int);
	void (*read)(struct perf_event___32 *);
	void (*start_txn)(struct pmu___32 *);
	int (*commit_txn)(struct pmu___32 *);
	void (*cancel_txn)(struct pmu___32 *);
	int (*event_idx)(struct perf_event___32 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___40 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___32 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___32 *);
};

struct perf_cpu_context___32 {
	struct perf_event_context___32 ctx;
	struct perf_event_context___32 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___32 *unique_pmu;
	struct perf_cgroup___32 *cgrp;
};

struct perf_cgroup___32 {
	struct cgroup_subsys_state___37 css;
	struct perf_cgroup_info *info;
};

struct linux_binprm___10 {
	char buf[128];
	struct vm_area_struct___69 *vma;
	long unsigned int vma_pages;
	struct mm_struct___69 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___65 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct disk_part_tbl___7 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___7 *last_lookup;
	struct hd_struct___7 *part[0];
};

struct block_device_operations___7 {
	int (*open)(struct block_device___65 *, fmode_t);
	void (*release)(struct gendisk___7 *, fmode_t);
	int (*ioctl)(struct block_device___65 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___65 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___65 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___7 *, unsigned int);
	int (*media_changed)(struct gendisk___7 *);
	void (*unlock_native_capacity)(struct gendisk___7 *);
	int (*revalidate_disk)(struct gendisk___7 *);
	int (*getgeo)(struct block_device___65 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___65 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___40 *owner;
};

struct io_cq___7 {
	struct request_queue___7 *q;
	struct io_context___7 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___56 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___7(struct request___7 *, int);

struct request___7 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue___7 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___7 *bio;
	struct bio___7 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___7 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___7 *saved_end_io;
		} flush;
	};
	struct gendisk___7 *rq_disk;
	struct hd_struct___7 *part;
	long unsigned int start_time;
	struct request_list___7 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___7 *end_io;
	void *end_io_data;
	struct request___7 *next_rq;
};

typedef int elevator_merge_fn___7(struct request_queue___7 *, struct request___7 **, struct bio___7 *);

typedef void elevator_merge_req_fn___7(struct request_queue___7 *, struct request___7 *, struct request___7 *);

typedef void elevator_merged_fn___7(struct request_queue___7 *, struct request___7 *, int);

typedef int elevator_allow_merge_fn___7(struct request_queue___7 *, struct request___7 *, struct bio___7 *);

typedef void elevator_bio_merged_fn___7(struct request_queue___7 *, struct request___7 *, struct bio___7 *);

typedef int elevator_dispatch_fn___7(struct request_queue___7 *, int);

typedef void elevator_add_req_fn___7(struct request_queue___7 *, struct request___7 *);

typedef struct request___7 *elevator_request_list_fn___7(struct request_queue___7 *, struct request___7 *);

typedef void elevator_completed_req_fn___7(struct request_queue___7 *, struct request___7 *);

typedef int elevator_may_queue_fn___7(struct request_queue___7 *, int);

typedef void elevator_init_icq_fn___7(struct io_cq___7 *);

typedef void elevator_exit_icq_fn___7(struct io_cq___7 *);

typedef int elevator_set_req_fn___7(struct request_queue___7 *, struct request___7 *, struct bio___7 *, gfp_t);

typedef void elevator_put_req_fn___7(struct request___7 *);

typedef void elevator_activate_req_fn___7(struct request_queue___7 *, struct request___7 *);

typedef void elevator_deactivate_req_fn___7(struct request_queue___7 *, struct request___7 *);

struct elevator_type___7;

typedef int elevator_init_fn___7(struct request_queue___7 *, struct elevator_type___7 *);

typedef void elevator_exit_fn___7(struct elevator_queue___7 *);

struct elevator_ops___7 {
	elevator_merge_fn___7 *elevator_merge_fn;
	elevator_merged_fn___7 *elevator_merged_fn;
	elevator_merge_req_fn___7 *elevator_merge_req_fn;
	elevator_allow_merge_fn___7 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___7 *elevator_bio_merged_fn;
	elevator_dispatch_fn___7 *elevator_dispatch_fn;
	elevator_add_req_fn___7 *elevator_add_req_fn;
	elevator_activate_req_fn___7 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___7 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___7 *elevator_completed_req_fn;
	elevator_request_list_fn___7 *elevator_former_req_fn;
	elevator_request_list_fn___7 *elevator_latter_req_fn;
	elevator_init_icq_fn___7 *elevator_init_icq_fn;
	elevator_exit_icq_fn___7 *elevator_exit_icq_fn;
	elevator_set_req_fn___7 *elevator_set_req_fn;
	elevator_put_req_fn___7 *elevator_put_req_fn;
	elevator_may_queue_fn___7 *elevator_may_queue_fn;
	elevator_init_fn___7 *elevator_init_fn;
	elevator_exit_fn___7 *elevator_exit_fn;
};

struct elv_fs_entry___7;

struct elevator_type___7 {
	struct kmem_cache___56 *icq_cache;
	struct elevator_ops___7 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___7 *elevator_attrs;
	char elevator_name[16];
	struct module___40 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___7 {
	struct elevator_type___7 *type;
	void *elevator_data;
	struct kobject___3 kobj;
	struct mutex___66 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___7 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___7 *, char *);
	ssize_t (*store)(struct elevator_queue___7 *, const char *, size_t);
};

struct bvec_merge_data___7 {
	struct block_device___65 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___7 {
	struct request___7 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___47 {
	void * (*start)(struct seq_file___48 *, loff_t *);
	void (*stop)(struct seq_file___48 *, void *);
	void * (*next)(struct seq_file___48 *, void *, loff_t *);
	int (*show)(struct seq_file___48 *, void *);
};

struct trace_iterator___24 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___66 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___24)(struct trace_iterator___24 *, int, struct trace_event___24 *);

struct trace_event_functions___24 {
	trace_print_func___24 trace;
	trace_print_func___24 raw;
	trace_print_func___24 hex;
	trace_print_func___24 binary;
};

struct ftrace_event_class___24 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___24 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___24 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___24 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___24 *);
};

struct ftrace_event_file___12 {
	struct list_head list;
	struct ftrace_event_call___24 *event_call;
	struct dentry___66 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct syscall_metadata___11 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___24 *enter_event;
	struct ftrace_event_call___24 *exit_event;
};

struct kprobe_insn_cache___13 {
	struct mutex___66 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct nf_afinfo___10 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___6 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___6 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___11 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___6 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___6 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct coredump_params___9 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___65 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

typedef int (*cpu_stop_fn_t)(void *);

struct cpu_stop_done;

struct cpu_stop_work {
	struct list_head list;
	cpu_stop_fn_t fn;
	void *arg;
	struct cpu_stop_done *done;
};

struct cpupri_vec {
	atomic_t count;
	cpumask_var_t mask;
};

struct cpupri {
	struct cpupri_vec pri_to_cpu[102];
	int cpu_to_pri[5120];
};

typedef int (*tg_visitor)(struct task_group *, void *);

struct root_domain;

struct rq {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq cfs;
	struct rt_rq rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___2 *curr;
	struct task_struct___2 *idle;
	struct task_struct___2 *stop;
	long unsigned int next_balance;
	struct mm_struct___69 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct root_domain {
	atomic_t refcount;
	atomic_t rto_count;
	struct callback_head rcu;
	cpumask_var_t span;
	cpumask_var_t online;
	cpumask_var_t rto_mask;
	struct cpupri cpupri;
	bool overload;
};

enum {
	__SCHED_FEAT_GENTLE_FAIR_SLEEPERS = 0,
	__SCHED_FEAT_START_DEBIT = 1,
	__SCHED_FEAT_NEXT_BUDDY = 2,
	__SCHED_FEAT_LAST_BUDDY = 3,
	__SCHED_FEAT_CACHE_HOT_BUDDY = 4,
	__SCHED_FEAT_WAKEUP_PREEMPTION = 5,
	__SCHED_FEAT_ARCH_POWER = 6,
	__SCHED_FEAT_HRTICK = 7,
	__SCHED_FEAT_DOUBLE_TICK = 8,
	__SCHED_FEAT_LB_BIAS = 9,
	__SCHED_FEAT_NONTASK_POWER = 10,
	__SCHED_FEAT_TTWU_QUEUE = 11,
	__SCHED_FEAT_FORCE_SD_OVERLAP = 12,
	__SCHED_FEAT_RT_RUNTIME_SHARE = 13,
	__SCHED_FEAT_LB_MIN = 14,
	__SCHED_FEAT_NUMA = 15,
	__SCHED_FEAT_NUMA_FAVOUR_HIGHER = 16,
	__SCHED_FEAT_NUMA_RESIST_LOWER = 17,
	__SCHED_FEAT_NR = 18,
};

enum rq_nohz_flag_bits {
	NOHZ_TICK_STOPPED = 0,
	NOHZ_BALANCE_KICK = 1,
};

struct ftrace_raw_sched_kthread_stop {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct ftrace_raw_sched_kthread_stop_ret {
	struct trace_entry ent;
	int ret;
	char __data[0];
};

struct ftrace_raw_sched_wakeup_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int success;
	int target_cpu;
	char __data[0];
};

struct ftrace_raw_sched_switch {
	struct trace_entry ent;
	char prev_comm[16];
	pid_t prev_pid;
	int prev_prio;
	long int prev_state;
	char next_comm[16];
	pid_t next_pid;
	int next_prio;
	char __data[0];
};

struct ftrace_raw_sched_migrate_task {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int orig_cpu;
	int dest_cpu;
	char __data[0];
};

struct ftrace_raw_sched_process_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct ftrace_raw_sched_process_wait {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct ftrace_raw_sched_process_fork {
	struct trace_entry ent;
	char parent_comm[16];
	pid_t parent_pid;
	char child_comm[16];
	pid_t child_pid;
	char __data[0];
};

struct ftrace_raw_sched_process_exec {
	struct trace_entry ent;
	u32 __data_loc_filename;
	pid_t pid;
	pid_t old_pid;
	char __data[0];
};

struct ftrace_raw_sched_stat_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 delay;
	char __data[0];
};

struct ftrace_raw_sched_stat_runtime {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 runtime;
	u64 vruntime;
	char __data[0];
};

struct ftrace_raw_sched_pi_setprio {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int oldprio;
	int newprio;
	char __data[0];
};

struct ftrace_raw_sched_move_task_template {
	struct trace_entry ent;
	pid_t pid;
	pid_t tgid;
	pid_t ngid;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct ftrace_raw_sched_swap_numa {
	struct trace_entry ent;
	pid_t src_pid;
	pid_t src_tgid;
	pid_t src_ngid;
	int src_cpu;
	int src_nid;
	pid_t dst_pid;
	pid_t dst_tgid;
	pid_t dst_ngid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct ftrace_raw_sched_wake_idle_without_ipi {
	struct trace_entry ent;
	int cpu;
	char __data[0];
};

struct ftrace_data_offsets_sched_kthread_stop {};

struct ftrace_data_offsets_sched_kthread_stop_ret {};

struct ftrace_data_offsets_sched_wakeup_template {};

struct ftrace_data_offsets_sched_switch {};

struct ftrace_data_offsets_sched_migrate_task {};

struct ftrace_data_offsets_sched_process_template {};

struct ftrace_data_offsets_sched_process_wait {};

struct ftrace_data_offsets_sched_process_fork {};

struct ftrace_data_offsets_sched_process_exec {
	u32 filename;
};

struct ftrace_data_offsets_sched_stat_template {};

struct ftrace_data_offsets_sched_stat_runtime {};

struct ftrace_data_offsets_sched_pi_setprio {};

struct ftrace_data_offsets_sched_move_task_template {};

struct ftrace_data_offsets_sched_swap_numa {};

struct ftrace_data_offsets_sched_wake_idle_without_ipi {};

struct migration_swap_arg {
	struct task_struct___2 *src_task;
	struct task_struct___2 *dst_task;
	int src_cpu;
	int dst_cpu;
};

struct migration_arg {
	struct task_struct___2 *task;
	int dest_cpu;
};

struct s_data {
	struct sched_domain **sd;
	struct root_domain *rd;
};

enum s_alloc {
	sa_rootdomain = 0,
	sa_sd = 1,
	sa_sd_storage = 2,
	sa_none = 3,
};

struct rt_schedulable_data {
	struct task_group *tg;
	u64 rt_period;
	u64 rt_runtime;
};

struct cfs_schedulable_data {
	struct task_group *tg;
	u64 period;
	u64 quota;
};

enum {
	cpuset = 0,
	possible = 1,
	fail = 2,
};

struct sched_clock_data {
	u64 tick_raw;
	u64 tick_gtod;
	u64 clock;
};

struct page___66;

typedef struct page___66 *pgtable_t___66;

struct address_space___66;

struct kmem_cache___57;

struct page___66 {
	long unsigned int flags;
	struct address_space___66 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___66 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___66 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___57 *slab_cache;
		struct page___66 *first_page;
	};
	long: 64;
};

struct task_struct___66;

struct pv_cpu_ops___66 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___66 *);
	void (*end_context_switch)(struct task_struct___66 *);
};

struct cfs_rq___2;

struct sched_entity___2 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___2 *parent;
	struct cfs_rq___2 *cfs_rq;
	struct cfs_rq___2 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___2;

struct sched_rt_entity___2 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___2 *back;
	struct sched_rt_entity___2 *parent;
	struct rt_rq___2 *rt_rq;
	struct rt_rq___2 *my_q;
};

struct mutex___67 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___66 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___63 {
	struct page___66 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___2;

struct task_group___2;

struct mm_struct___70;

struct signal_struct___66;

struct css_set___38;

struct task_struct___66 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___66 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___2 *sched_class;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group___2 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___70 *mm;
	struct mm_struct___70 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___66 *real_parent;
	struct task_struct___66 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___66 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___66 = 0,
		VTIME_USER___66 = 1,
		VTIME_SYS___66 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___66 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___38 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___67 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___63 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___70 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___70 *, struct mm_struct___70 *);
	void (*dup_mmap)(struct mm_struct___70 *, struct mm_struct___70 *);
	void (*exit_mmap)(struct mm_struct___70 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___70 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___70 *);
	void (*pgd_free)(struct mm_struct___70 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___70 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___70 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___70 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___70 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___70 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___70 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___70 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___70 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___70 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___70 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___70 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___67 lock;
	void *vdso;
} mm_context_t___67;

struct xol_area___66;

struct uprobes_state___66 {
	struct xol_area___66 *xol_area;
};

struct vm_area_struct___70;

struct file___66;

struct core_state___66;

struct mm_struct___70 {
	struct vm_area_struct___70 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___70 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___70 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___67 context;
	long unsigned int flags;
	struct core_state___66 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___66 *owner;
	struct file___66 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___66 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___30 {
	struct task_struct___66 *task;
	struct exec_domain___18 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___66 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___66 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___57;

struct memcg_cache_params___57;

struct kmem_cache___57 {
	struct kmem_cache_cpu___57 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___57 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___67;

struct address_space_operations___66;

struct address_space___66 {
	struct inode___67 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___67 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___66 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___67;

struct path___66 {
	struct vfsmount *mnt;
	struct dentry___67 *dentry;
};

struct file_operations___66;

struct file___66 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___66 f_path;
	struct inode___67 *f_inode;
	const struct file_operations___66 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___66 *f_mapping;
	struct mutex___67 f_pos_lock;
};

struct vm_area_struct___70 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___70 *vm_next;
	struct vm_area_struct___70 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___70 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___66 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___66 {
	struct task_struct___66 *task;
	struct core_thread___66 *next;
};

struct core_state___66 {
	atomic_t nr_threads;
	struct core_thread___66 dumper;
	struct completion startup;
};

struct smp_ops___66 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___66 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___66;

struct lruvec___66 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___66 *zone;
};

struct pglist_data___66;

struct zone___66 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___66 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___66 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___66 {
	struct zone___66 *zone;
	int zone_idx;
};

struct zonelist___66 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___66 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___66 {
	struct zone___66 node_zones[4];
	struct zonelist___66 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___66 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct autogroup___2;

struct signal_struct___66 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___66 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___66 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___2 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___67 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___2 {
	struct kref kref;
	struct task_group___2 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___2;

struct cfs_rq___2 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___2 *curr;
	struct sched_entity___2 *next;
	struct sched_entity___2 *last;
	struct sched_entity___2 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___2 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___2 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___2 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___2 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___2 *tg;
};

struct sched_class___2 {
	const struct sched_class___2 *next;
	void (*enqueue_task)(struct rq___2 *, struct task_struct___66 *, int);
	void (*dequeue_task)(struct rq___2 *, struct task_struct___66 *, int);
	void (*yield_task)(struct rq___2 *);
	bool (*yield_to_task)(struct rq___2 *, struct task_struct___66 *, bool);
	void (*check_preempt_curr)(struct rq___2 *, struct task_struct___66 *, int);
	struct task_struct___66 * (*pick_next_task)(struct rq___2 *);
	void (*put_prev_task)(struct rq___2 *, struct task_struct___66 *);
	int (*select_task_rq)(struct task_struct___66 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___66 *, int);
	void (*pre_schedule)(struct rq___2 *, struct task_struct___66 *);
	void (*post_schedule)(struct rq___2 *);
	void (*task_waking)(struct task_struct___66 *);
	void (*task_woken)(struct rq___2 *, struct task_struct___66 *);
	void (*set_cpus_allowed)(struct task_struct___66 *, const struct cpumask *);
	void (*rq_online)(struct rq___2 *);
	void (*rq_offline)(struct rq___2 *);
	void (*set_curr_task)(struct rq___2 *);
	void (*task_tick)(struct rq___2 *, struct task_struct___66 *, int);
	void (*task_fork)(struct task_struct___66 *);
	void (*switched_from)(struct rq___2 *, struct task_struct___66 *);
	void (*switched_to)(struct rq___2 *, struct task_struct___66 *);
	void (*prio_changed)(struct rq___2 *, struct task_struct___66 *, int);
	unsigned int (*get_rr_interval)(struct rq___2 *, struct task_struct___66 *);
	void (*task_move_group)(struct task_struct___66 *, int);
	void (*update_curr)(struct rq___2 *);
};

struct cgroup___38;

struct cgroup_subsys_state___38 {
	struct cgroup___38 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_group___2 {
	struct cgroup_subsys_state___38 css;
	struct sched_entity___2 **se;
	struct cfs_rq___2 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___2 **rt_se;
	struct rt_rq___2 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___2 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___2 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___38 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___38 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___57 {
	void **freelist;
	long unsigned int tid;
	struct page___66 *page;
	struct page___66 *partial;
};

struct memcg_cache_params___57 {
	bool is_root_cache;
	union {
		struct kmem_cache___57 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___57 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___38 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___67 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___67 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___67 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___66;

struct super_block___67;

struct dentry___67 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___67 *d_parent;
	struct qstr d_name;
	struct inode___67 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___66 *d_op;
	struct super_block___67 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___66;

struct file_lock___66;

struct dquot___66;

struct block_device___66;

struct inode___67 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___66 *i_op;
	struct super_block___67 *i_sb;
	struct address_space___66 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___67 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___66 *i_fop;
	struct file_lock___66 *i_flock;
	struct address_space___66 i_data;
	struct dquot___66 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___66 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___66 {
	int (*d_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_hash)(const struct dentry___67 *, struct qstr *);
	int (*d_compare)(const struct dentry___67 *, const struct dentry___67 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___67 *);
	void (*d_release)(struct dentry___67 *);
	void (*d_prune)(struct dentry___67 *);
	void (*d_iput)(struct dentry___67 *, struct inode___67 *);
	char * (*d_dname)(struct dentry___67 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___66 *);
	int (*d_manage)(struct dentry___67 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___66;

struct mem_dqinfo___66 {
	struct quota_format_type___66 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___66;

struct quota_info___66 {
	unsigned int flags;
	struct mutex___67 dqio_mutex;
	struct mutex___67 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___67 *files[2];
	struct mem_dqinfo___66 info[2];
	const struct quota_format_ops___66 *ops[2];
};

struct file_system_type___66;

struct super_operations___66;

struct dquot_operations___66;

struct quotactl_ops___66;

struct super_block___67 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___66 *s_type;
	const struct super_operations___66 *s_op;
	const struct dquot_operations___66 *dq_op;
	const struct quotactl_ops___66 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___67 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___38 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___66 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___66 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___67 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___66 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___66 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___67 *bd_inode;
	struct super_block___67 *bd_super;
	struct mutex___67 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___66 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___67 bd_fsfreeze_mutex;
};

struct iattr___67 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___66 *ia_file;
};

struct dquot___66 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___67 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___67 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___66 {
	int qf_fmt_id;
	const struct quota_format_ops___66 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___66 *qf_next;
};

struct quota_format_ops___66 {
	int (*check_quota_file)(struct super_block___67 *, int);
	int (*read_file_info)(struct super_block___67 *, int);
	int (*write_file_info)(struct super_block___67 *, int);
	int (*free_file_info)(struct super_block___67 *, int);
	int (*read_dqblk)(struct dquot___66 *);
	int (*commit_dqblk)(struct dquot___66 *);
	int (*release_dqblk)(struct dquot___66 *);
};

struct dquot_operations___66 {
	int (*write_dquot)(struct dquot___66 *);
	struct dquot___66 * (*alloc_dquot)(struct super_block___67 *, int);
	void (*destroy_dquot)(struct dquot___66 *);
	int (*acquire_dquot)(struct dquot___66 *);
	int (*release_dquot)(struct dquot___66 *);
	int (*mark_dirty)(struct dquot___66 *);
	int (*write_info)(struct super_block___67 *, int);
	qsize_t * (*get_reserved_space)(struct inode___67 *);
};

struct quotactl_ops___66 {
	int (*quota_on)(struct super_block___67 *, int, int, struct path___66 *);
	int (*quota_on_meta)(struct super_block___67 *, int, int);
	int (*quota_off)(struct super_block___67 *, int);
	int (*quota_sync)(struct super_block___67 *, int);
	int (*get_info)(struct super_block___67 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___67 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___67 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___67 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___67 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___67 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___67 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___67 *, unsigned int);
};

struct address_space_operations___66 {
	int (*writepage)(struct page___66 *, struct writeback_control *);
	int (*readpage)(struct file___66 *, struct page___66 *);
	int (*writepages)(struct address_space___66 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___66 *);
	int (*readpages)(struct file___66 *, struct address_space___66 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___66 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___66 **, void **);
	int (*write_end)(struct file___66 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___66 *, void *);
	sector_t (*bmap)(struct address_space___66 *, sector_t);
	void (*invalidatepage)(struct page___66 *, long unsigned int);
	int (*releasepage)(struct page___66 *, gfp_t);
	void (*freepage)(struct page___66 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___66 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___66 *, struct page___66 *, struct page___66 *, enum migrate_mode);
	int (*launder_page)(struct page___66 *);
	int (*is_partially_uptodate)(struct page___66 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___66 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___66 *, struct page___66 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___66 *, sector_t *);
	void (*swap_deactivate)(struct file___66 *);
	void (*invalidatepage_range)(struct page___66 *, unsigned int, unsigned int);
};

struct inode_operations___66 {
	struct dentry___67 * (*lookup)(struct inode___67 *, struct dentry___67 *, unsigned int);
	void * (*follow_link)(struct dentry___67 *, struct nameidata *);
	int (*permission)(struct inode___67 *, int);
	struct posix_acl * (*get_acl)(struct inode___67 *, int);
	int (*readlink)(struct dentry___67 *, char *, int);
	void (*put_link)(struct dentry___67 *, struct nameidata *, void *);
	int (*create)(struct inode___67 *, struct dentry___67 *, umode_t, bool);
	int (*link)(struct dentry___67 *, struct inode___67 *, struct dentry___67 *);
	int (*unlink)(struct inode___67 *, struct dentry___67 *);
	int (*symlink)(struct inode___67 *, struct dentry___67 *, const char *);
	int (*mkdir)(struct inode___67 *, struct dentry___67 *, umode_t);
	int (*rmdir)(struct inode___67 *, struct dentry___67 *);
	int (*mknod)(struct inode___67 *, struct dentry___67 *, umode_t, dev_t);
	int (*rename)(struct inode___67 *, struct dentry___67 *, struct inode___67 *, struct dentry___67 *);
	int (*setattr)(struct dentry___67 *, struct iattr___67 *);
	int (*getattr)(struct vfsmount *, struct dentry___67 *, struct kstat *);
	int (*setxattr)(struct dentry___67 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___67 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___67 *, char *, size_t);
	int (*removexattr)(struct dentry___67 *, const char *);
	int (*fiemap)(struct inode___67 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___67 *, struct timespec *, int);
	int (*atomic_open)(struct inode___67 *, struct dentry___67 *, struct file___66 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___66 {
	struct module *owner;
	loff_t (*llseek)(struct file___66 *, loff_t, int);
	ssize_t (*read)(struct file___66 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___66 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___66 *, void *, filldir_t);
	unsigned int (*poll)(struct file___66 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___66 *, struct vm_area_struct___70 *);
	int (*open)(struct inode___67 *, struct file___66 *);
	int (*flush)(struct file___66 *, fl_owner_t);
	int (*release)(struct inode___67 *, struct file___66 *);
	int (*fsync)(struct file___66 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___66 *, int);
	int (*lock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*sendpage)(struct file___66 *, struct page___66 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___66 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___66 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___66 *, long int, struct file_lock___66 **, void **);
		struct {
			int (*setlease)(struct file___66 *, long int, struct file_lock___66 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___66 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___66 *);
};

struct fasync_struct___66;

struct file_lock_operations___66;

struct lock_manager_operations___66;

struct file_lock___66 {
	struct file_lock___66 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___66 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___66 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___66 *fl_ops;
	const struct lock_manager_operations___66 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___66 {
	void (*fl_copy_lock)(struct file_lock___66 *, struct file_lock___66 *);
	void (*fl_release_private)(struct file_lock___66 *);
};

struct lock_manager_operations___66 {
	int (*lm_compare_owner)(struct file_lock___66 *, struct file_lock___66 *);
	long unsigned int (*lm_owner_key)(struct file_lock___66 *);
	void (*lm_notify)(struct file_lock___66 *);
	int (*lm_grant)(struct file_lock___66 *, struct file_lock___66 *, int);
	void (*lm_break)(struct file_lock___66 *);
	int (*lm_change)(struct file_lock___66 **, int);
};

struct fasync_struct___66 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___66 *fa_next;
	struct file___66 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___66 {
	const char *name;
	int fs_flags;
	struct dentry___67 * (*mount)(struct file_system_type___66 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___67 *);
	struct module *owner;
	struct file_system_type___66 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___66 {
	struct inode___67 * (*alloc_inode)(struct super_block___67 *);
	void (*destroy_inode)(struct inode___67 *);
	void (*dirty_inode)(struct inode___67 *, int);
	int (*write_inode)(struct inode___67 *, struct writeback_control *);
	int (*drop_inode)(struct inode___67 *);
	void (*evict_inode)(struct inode___67 *);
	void (*put_super)(struct super_block___67 *);
	int (*sync_fs)(struct super_block___67 *, int);
	int (*freeze_fs)(struct super_block___67 *);
	int (*unfreeze_fs)(struct super_block___67 *);
	int (*statfs)(struct dentry___67 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___67 *, int *, char *);
	void (*umount_begin)(struct super_block___67 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___67 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___67 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___67 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___67 *);
	ssize_t (*quota_read)(struct super_block___67 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___67 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___67 *);
	int (*bdev_try_to_free_page)(struct super_block___67 *, struct page___66 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___67 *);
	void (*free_cached_objects)(struct super_block___67 *, int);
};

struct cgroupfs_root___38;

struct cgroup___38 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___38 *parent;
	struct dentry___67 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___38 *subsys[11];
	struct cgroupfs_root___38 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___67 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___38 {
	struct super_block___67 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___38 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct rq___2 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___2 cfs;
	struct rt_rq___2 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___66 *curr;
	struct task_struct___66 *idle;
	struct task_struct___66 *stop;
	long unsigned int next_balance;
	struct mm_struct___70 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data___2 hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct page___67;

typedef struct page___67 *pgtable_t___67;

struct address_space___67;

struct kmem_cache___58;

struct page___67 {
	long unsigned int flags;
	struct address_space___67 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___67 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___67 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___58 *slab_cache;
		struct page___67 *first_page;
	};
	long: 64;
};

struct task_struct___67;

struct pv_cpu_ops___67 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___67 *);
	void (*end_context_switch)(struct task_struct___67 *);
};

struct cfs_rq___3;

struct sched_entity___3 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___3 *parent;
	struct cfs_rq___3 *cfs_rq;
	struct cfs_rq___3 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___3;

struct sched_rt_entity___3 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___3 *back;
	struct sched_rt_entity___3 *parent;
	struct rt_rq___3 *rt_rq;
	struct rt_rq___3 *my_q;
};

struct mutex___68 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___67 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___64 {
	struct page___67 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___3;

struct task_group___3;

struct mm_struct___71;

struct signal_struct___67;

struct css_set___39;

struct numa_group___2;

struct task_struct___67 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___67 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___3 *sched_class;
	struct sched_entity___3 se;
	struct sched_rt_entity___3 rt;
	struct task_group___3 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___71 *mm;
	struct mm_struct___71 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___67 *real_parent;
	struct task_struct___67 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___67 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___67 = 0,
		VTIME_USER___67 = 1,
		VTIME_SYS___67 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___67 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___39 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___68 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group___2 *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___64 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___71 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___71 *, struct mm_struct___71 *);
	void (*dup_mmap)(struct mm_struct___71 *, struct mm_struct___71 *);
	void (*exit_mmap)(struct mm_struct___71 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___71 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___71 *);
	void (*pgd_free)(struct mm_struct___71 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___71 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___71 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___71 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___71 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___71 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___71 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___71 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___71 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___71 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___71 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___71 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___68 lock;
	void *vdso;
} mm_context_t___68;

struct xol_area___67;

struct uprobes_state___67 {
	struct xol_area___67 *xol_area;
};

struct vm_area_struct___71;

struct file___67;

struct linux_binfmt___10;

struct core_state___67;

struct mm_struct___71 {
	struct vm_area_struct___71 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___71 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___71 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___10 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___68 context;
	long unsigned int flags;
	struct core_state___67 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___67 *owner;
	struct file___67 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___67 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___31 {
	struct task_struct___67 *task;
	struct exec_domain___18 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___67 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___67 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___58;

struct memcg_cache_params___58;

struct kmem_cache___58 {
	struct kmem_cache_cpu___58 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___58 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___68;

struct address_space_operations___67;

struct address_space___67 {
	struct inode___68 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___68 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___67 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___68;

struct path___67 {
	struct vfsmount *mnt;
	struct dentry___68 *dentry;
};

struct file_operations___67;

struct file___67 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___67 f_path;
	struct inode___68 *f_inode;
	const struct file_operations___67 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___67 *f_mapping;
	struct mutex___68 f_pos_lock;
};

struct vm_operations_struct___60;

struct vm_area_struct___71 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___71 *vm_next;
	struct vm_area_struct___71 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___71 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___60 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___67 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___57;

struct vm_operations_struct___60 {
	void (*open)(struct vm_area_struct___71 *);
	void (*close)(struct vm_area_struct___71 *);
	int (*fault)(struct vm_area_struct___71 *, struct vm_fault___57 *);
	int (*page_mkwrite)(struct vm_area_struct___71 *, struct vm_fault___57 *);
	int (*access)(struct vm_area_struct___71 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___71 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___71 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___71 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___71 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___67 {
	struct task_struct___67 *task;
	struct core_thread___67 *next;
};

struct core_state___67 {
	atomic_t nr_threads;
	struct core_thread___67 dumper;
	struct completion startup;
};

struct linux_binprm___11;

struct coredump_params___10;

struct linux_binfmt___10 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___11 *);
	int (*load_shlib)(struct file___67 *);
	int (*core_dump)(struct coredump_params___10 *);
	long unsigned int min_coredump;
};

struct smp_ops___67 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___67 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___67;

struct lruvec___67 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___67 *zone;
};

struct pglist_data___67;

struct zone___67 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___67 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___67 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___67 {
	struct zone___67 *zone;
	int zone_idx;
};

struct zonelist___67 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___67 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___67 {
	struct zone___67 node_zones[4];
	struct zonelist___67 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___67 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct autogroup___3;

struct signal_struct___67 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___67 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___67 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___3 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___68 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___3 {
	struct kref kref;
	struct task_group___3 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___3;

struct cfs_rq___3 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___3 *curr;
	struct sched_entity___3 *next;
	struct sched_entity___3 *last;
	struct sched_entity___3 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___3 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___3 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___3 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___3 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___3 *tg;
};

struct sched_class___3 {
	const struct sched_class___3 *next;
	void (*enqueue_task)(struct rq___3 *, struct task_struct___67 *, int);
	void (*dequeue_task)(struct rq___3 *, struct task_struct___67 *, int);
	void (*yield_task)(struct rq___3 *);
	bool (*yield_to_task)(struct rq___3 *, struct task_struct___67 *, bool);
	void (*check_preempt_curr)(struct rq___3 *, struct task_struct___67 *, int);
	struct task_struct___67 * (*pick_next_task)(struct rq___3 *);
	void (*put_prev_task)(struct rq___3 *, struct task_struct___67 *);
	int (*select_task_rq)(struct task_struct___67 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___67 *, int);
	void (*pre_schedule)(struct rq___3 *, struct task_struct___67 *);
	void (*post_schedule)(struct rq___3 *);
	void (*task_waking)(struct task_struct___67 *);
	void (*task_woken)(struct rq___3 *, struct task_struct___67 *);
	void (*set_cpus_allowed)(struct task_struct___67 *, const struct cpumask *);
	void (*rq_online)(struct rq___3 *);
	void (*rq_offline)(struct rq___3 *);
	void (*set_curr_task)(struct rq___3 *);
	void (*task_tick)(struct rq___3 *, struct task_struct___67 *, int);
	void (*task_fork)(struct task_struct___67 *);
	void (*switched_from)(struct rq___3 *, struct task_struct___67 *);
	void (*switched_to)(struct rq___3 *, struct task_struct___67 *);
	void (*prio_changed)(struct rq___3 *, struct task_struct___67 *, int);
	unsigned int (*get_rr_interval)(struct rq___3 *, struct task_struct___67 *);
	void (*task_move_group)(struct task_struct___67 *, int);
	void (*update_curr)(struct rq___3 *);
};

struct cgroup___39;

struct cgroup_subsys_state___39 {
	struct cgroup___39 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_group___3 {
	struct cgroup_subsys_state___39 css;
	struct sched_entity___3 **se;
	struct cfs_rq___3 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___3 **rt_se;
	struct rt_rq___3 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___3 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___3 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___39 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___39 *subsys[11];
	struct callback_head callback_head;
};

struct numa_group___2 {
	atomic_t refcount;
	spinlock_t lock;
	int nr_tasks;
	pid_t gid;
	struct list_head task_list;
	struct callback_head rcu;
	nodemask_t active_nodes;
	long unsigned int total_faults;
	long unsigned int *faults_cpu;
	long unsigned int faults[0];
};

struct kmem_cache_cpu___58 {
	void **freelist;
	long unsigned int tid;
	struct page___67 *page;
	struct page___67 *partial;
};

struct memcg_cache_params___58 {
	bool is_root_cache;
	union {
		struct kmem_cache___58 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___58 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___57 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___67 *page;
};

struct dentry_operations___67;

struct super_block___68;

struct dentry___68 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___68 *d_parent;
	struct qstr d_name;
	struct inode___68 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___67 *d_op;
	struct super_block___68 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___67;

struct file_lock___67;

struct dquot___67;

struct block_device___67;

struct inode___68 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___67 *i_op;
	struct super_block___68 *i_sb;
	struct address_space___67 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___68 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___67 *i_fop;
	struct file_lock___67 *i_flock;
	struct address_space___67 i_data;
	struct dquot___67 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___67 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___67 {
	int (*d_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_hash)(const struct dentry___68 *, struct qstr *);
	int (*d_compare)(const struct dentry___68 *, const struct dentry___68 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___68 *);
	void (*d_release)(struct dentry___68 *);
	void (*d_prune)(struct dentry___68 *);
	void (*d_iput)(struct dentry___68 *, struct inode___68 *);
	char * (*d_dname)(struct dentry___68 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___67 *);
	int (*d_manage)(struct dentry___68 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___67;

struct mem_dqinfo___67 {
	struct quota_format_type___67 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___67;

struct quota_info___67 {
	unsigned int flags;
	struct mutex___68 dqio_mutex;
	struct mutex___68 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___68 *files[2];
	struct mem_dqinfo___67 info[2];
	const struct quota_format_ops___67 *ops[2];
};

struct file_system_type___67;

struct super_operations___67;

struct dquot_operations___67;

struct quotactl_ops___67;

struct xattr_handler___39;

struct super_block___68 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___67 *s_type;
	const struct super_operations___67 *s_op;
	const struct dquot_operations___67 *dq_op;
	const struct quotactl_ops___67 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___68 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___39 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___67 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___67 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___68 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___67 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___67 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___68 *bd_inode;
	struct super_block___68 *bd_super;
	struct mutex___68 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___67 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___68 bd_fsfreeze_mutex;
};

struct iattr___68 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___67 *ia_file;
};

struct dquot___67 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___68 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___68 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___67 {
	int qf_fmt_id;
	const struct quota_format_ops___67 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___67 *qf_next;
};

struct quota_format_ops___67 {
	int (*check_quota_file)(struct super_block___68 *, int);
	int (*read_file_info)(struct super_block___68 *, int);
	int (*write_file_info)(struct super_block___68 *, int);
	int (*free_file_info)(struct super_block___68 *, int);
	int (*read_dqblk)(struct dquot___67 *);
	int (*commit_dqblk)(struct dquot___67 *);
	int (*release_dqblk)(struct dquot___67 *);
};

struct dquot_operations___67 {
	int (*write_dquot)(struct dquot___67 *);
	struct dquot___67 * (*alloc_dquot)(struct super_block___68 *, int);
	void (*destroy_dquot)(struct dquot___67 *);
	int (*acquire_dquot)(struct dquot___67 *);
	int (*release_dquot)(struct dquot___67 *);
	int (*mark_dirty)(struct dquot___67 *);
	int (*write_info)(struct super_block___68 *, int);
	qsize_t * (*get_reserved_space)(struct inode___68 *);
};

struct quotactl_ops___67 {
	int (*quota_on)(struct super_block___68 *, int, int, struct path___67 *);
	int (*quota_on_meta)(struct super_block___68 *, int, int);
	int (*quota_off)(struct super_block___68 *, int);
	int (*quota_sync)(struct super_block___68 *, int);
	int (*get_info)(struct super_block___68 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___68 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___68 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___68 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___68 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___68 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___68 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___68 *, unsigned int);
};

struct address_space_operations___67 {
	int (*writepage)(struct page___67 *, struct writeback_control *);
	int (*readpage)(struct file___67 *, struct page___67 *);
	int (*writepages)(struct address_space___67 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___67 *);
	int (*readpages)(struct file___67 *, struct address_space___67 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___67 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___67 **, void **);
	int (*write_end)(struct file___67 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___67 *, void *);
	sector_t (*bmap)(struct address_space___67 *, sector_t);
	void (*invalidatepage)(struct page___67 *, long unsigned int);
	int (*releasepage)(struct page___67 *, gfp_t);
	void (*freepage)(struct page___67 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___67 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___67 *, struct page___67 *, struct page___67 *, enum migrate_mode);
	int (*launder_page)(struct page___67 *);
	int (*is_partially_uptodate)(struct page___67 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___67 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___67 *, struct page___67 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___67 *, sector_t *);
	void (*swap_deactivate)(struct file___67 *);
	void (*invalidatepage_range)(struct page___67 *, unsigned int, unsigned int);
};

struct inode_operations___67 {
	struct dentry___68 * (*lookup)(struct inode___68 *, struct dentry___68 *, unsigned int);
	void * (*follow_link)(struct dentry___68 *, struct nameidata *);
	int (*permission)(struct inode___68 *, int);
	struct posix_acl * (*get_acl)(struct inode___68 *, int);
	int (*readlink)(struct dentry___68 *, char *, int);
	void (*put_link)(struct dentry___68 *, struct nameidata *, void *);
	int (*create)(struct inode___68 *, struct dentry___68 *, umode_t, bool);
	int (*link)(struct dentry___68 *, struct inode___68 *, struct dentry___68 *);
	int (*unlink)(struct inode___68 *, struct dentry___68 *);
	int (*symlink)(struct inode___68 *, struct dentry___68 *, const char *);
	int (*mkdir)(struct inode___68 *, struct dentry___68 *, umode_t);
	int (*rmdir)(struct inode___68 *, struct dentry___68 *);
	int (*mknod)(struct inode___68 *, struct dentry___68 *, umode_t, dev_t);
	int (*rename)(struct inode___68 *, struct dentry___68 *, struct inode___68 *, struct dentry___68 *);
	int (*setattr)(struct dentry___68 *, struct iattr___68 *);
	int (*getattr)(struct vfsmount *, struct dentry___68 *, struct kstat *);
	int (*setxattr)(struct dentry___68 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___68 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___68 *, char *, size_t);
	int (*removexattr)(struct dentry___68 *, const char *);
	int (*fiemap)(struct inode___68 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___68 *, struct timespec *, int);
	int (*atomic_open)(struct inode___68 *, struct dentry___68 *, struct file___67 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___67 {
	struct module *owner;
	loff_t (*llseek)(struct file___67 *, loff_t, int);
	ssize_t (*read)(struct file___67 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___67 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___67 *, void *, filldir_t);
	unsigned int (*poll)(struct file___67 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___67 *, struct vm_area_struct___71 *);
	int (*open)(struct inode___68 *, struct file___67 *);
	int (*flush)(struct file___67 *, fl_owner_t);
	int (*release)(struct inode___68 *, struct file___67 *);
	int (*fsync)(struct file___67 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___67 *, int);
	int (*lock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*sendpage)(struct file___67 *, struct page___67 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___67 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___67 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___67 *, long int, struct file_lock___67 **, void **);
		struct {
			int (*setlease)(struct file___67 *, long int, struct file_lock___67 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___67 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___67 *);
};

struct fasync_struct___67;

struct file_lock_operations___67;

struct lock_manager_operations___67;

struct file_lock___67 {
	struct file_lock___67 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___67 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___67 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___67 *fl_ops;
	const struct lock_manager_operations___67 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___67 {
	void (*fl_copy_lock)(struct file_lock___67 *, struct file_lock___67 *);
	void (*fl_release_private)(struct file_lock___67 *);
};

struct lock_manager_operations___67 {
	int (*lm_compare_owner)(struct file_lock___67 *, struct file_lock___67 *);
	long unsigned int (*lm_owner_key)(struct file_lock___67 *);
	void (*lm_notify)(struct file_lock___67 *);
	int (*lm_grant)(struct file_lock___67 *, struct file_lock___67 *, int);
	void (*lm_break)(struct file_lock___67 *);
	int (*lm_change)(struct file_lock___67 **, int);
};

struct fasync_struct___67 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___67 *fa_next;
	struct file___67 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___67 {
	const char *name;
	int fs_flags;
	struct dentry___68 * (*mount)(struct file_system_type___67 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___68 *);
	struct module *owner;
	struct file_system_type___67 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___67 {
	struct inode___68 * (*alloc_inode)(struct super_block___68 *);
	void (*destroy_inode)(struct inode___68 *);
	void (*dirty_inode)(struct inode___68 *, int);
	int (*write_inode)(struct inode___68 *, struct writeback_control *);
	int (*drop_inode)(struct inode___68 *);
	void (*evict_inode)(struct inode___68 *);
	void (*put_super)(struct super_block___68 *);
	int (*sync_fs)(struct super_block___68 *, int);
	int (*freeze_fs)(struct super_block___68 *);
	int (*unfreeze_fs)(struct super_block___68 *);
	int (*statfs)(struct dentry___68 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___68 *, int *, char *);
	void (*umount_begin)(struct super_block___68 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___68 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___68 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___68 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___68 *);
	ssize_t (*quota_read)(struct super_block___68 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___68 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___68 *);
	int (*bdev_try_to_free_page)(struct super_block___68 *, struct page___67 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___68 *);
	void (*free_cached_objects)(struct super_block___68 *, int);
};

struct xattr_handler___39 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___68 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___68 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___68 *, const char *, const void *, size_t, int, int);
};

struct linux_binprm___11 {
	char buf[128];
	struct vm_area_struct___71 *vma;
	long unsigned int vma_pages;
	struct mm_struct___71 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___67 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___10 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___67 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct cgroupfs_root___39;

struct cgroup___39 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___39 *parent;
	struct dentry___68 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___39 *subsys[11];
	struct cgroupfs_root___39 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___68 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___39 {
	struct super_block___68 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___39 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

typedef int (*tg_visitor___2)(struct task_group___3 *, void *);

struct rq___3 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___3 cfs;
	struct rt_rq___3 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___67 *curr;
	struct task_struct___67 *idle;
	struct task_struct___67 *stop;
	long unsigned int next_balance;
	struct mm_struct___71 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data___2 hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct numa_stats {
	long unsigned int nr_running;
	long unsigned int load;
	long unsigned int power;
	long unsigned int capacity;
	int has_capacity;
};

struct task_numa_env {
	struct task_struct___67 *p;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	struct numa_stats src_stats;
	struct numa_stats dst_stats;
	int imbalance_pct;
	int idx;
	struct task_struct___67 *best_task;
	long int best_imp;
	int best_cpu;
};

enum fbq_type {
	regular = 0,
	remote = 1,
	all = 2,
};

struct lb_env {
	struct sched_domain *sd;
	struct rq___3 *src_rq;
	int src_cpu;
	int dst_cpu;
	struct rq___3 *dst_rq;
	struct cpumask *dst_grpmask;
	int new_dst_cpu;
	enum cpu_idle_type idle;
	long int imbalance;
	struct cpumask *cpus;
	unsigned int flags;
	unsigned int loop;
	unsigned int loop_break;
	unsigned int loop_max;
	enum fbq_type fbq_type;
};

struct sg_lb_stats {
	long unsigned int avg_load;
	long unsigned int group_load;
	long unsigned int sum_weighted_load;
	long unsigned int load_per_task;
	long unsigned int group_power;
	unsigned int sum_nr_running;
	unsigned int group_capacity;
	unsigned int idle_cpus;
	unsigned int group_weight;
	int group_imb;
	int group_has_capacity;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
};

struct sd_lb_stats {
	struct sched_group *busiest;
	struct sched_group *this;
	long unsigned int total_load;
	long unsigned int total_pwr;
	long unsigned int avg_load;
	struct sg_lb_stats busiest_stat;
	struct sg_lb_stats this_stat;
};

typedef struct task_group___2 *rt_rq_iter_t;

struct page___68;

typedef struct page___68 *pgtable_t___68;

struct address_space___68;

struct kmem_cache___59;

struct page___68 {
	long unsigned int flags;
	struct address_space___68 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___68 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___68 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___59 *slab_cache;
		struct page___68 *first_page;
	};
	long: 64;
};

struct task_struct___68;

struct pv_cpu_ops___68 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___68 *);
	void (*end_context_switch)(struct task_struct___68 *);
};

struct cfs_rq___4;

struct sched_entity___4 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___4 *parent;
	struct cfs_rq___4 *cfs_rq;
	struct cfs_rq___4 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___4;

struct sched_rt_entity___4 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___4 *back;
	struct sched_rt_entity___4 *parent;
	struct rt_rq___4 *rt_rq;
	struct rt_rq___4 *my_q;
};

struct mutex___69 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___68 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___65 {
	struct page___68 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___4;

struct task_group___4;

struct mm_struct___72;

struct signal_struct___68;

struct css_set___40;

struct task_struct___68 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___68 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___4 *sched_class;
	struct sched_entity___4 se;
	struct sched_rt_entity___4 rt;
	struct task_group___4 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___72 *mm;
	struct mm_struct___72 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___68 *real_parent;
	struct task_struct___68 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___68 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___68 = 0,
		VTIME_USER___68 = 1,
		VTIME_SYS___68 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___68 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___40 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___69 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___65 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___72 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___72 *, struct mm_struct___72 *);
	void (*dup_mmap)(struct mm_struct___72 *, struct mm_struct___72 *);
	void (*exit_mmap)(struct mm_struct___72 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___72 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___72 *);
	void (*pgd_free)(struct mm_struct___72 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___72 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___72 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___72 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___72 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___72 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___72 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___72 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___72 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___72 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___72 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___72 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___69 lock;
	void *vdso;
} mm_context_t___69;

struct xol_area___68;

struct uprobes_state___68 {
	struct xol_area___68 *xol_area;
};

struct vm_area_struct___72;

struct file___68;

struct core_state___68;

struct mm_struct___72 {
	struct vm_area_struct___72 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___72 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___72 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___69 context;
	long unsigned int flags;
	struct core_state___68 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___68 *owner;
	struct file___68 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___68 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___68 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___68 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___59;

struct memcg_cache_params___59;

struct kmem_cache___59 {
	struct kmem_cache_cpu___59 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___59 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___69;

struct address_space_operations___68;

struct address_space___68 {
	struct inode___69 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___69 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___68 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___69;

struct path___68 {
	struct vfsmount *mnt;
	struct dentry___69 *dentry;
};

struct file_operations___68;

struct file___68 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___68 f_path;
	struct inode___69 *f_inode;
	const struct file_operations___68 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___68 *f_mapping;
	struct mutex___69 f_pos_lock;
};

struct vm_area_struct___72 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___72 *vm_next;
	struct vm_area_struct___72 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___72 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___68 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___68 {
	struct task_struct___68 *task;
	struct core_thread___68 *next;
};

struct core_state___68 {
	atomic_t nr_threads;
	struct core_thread___68 dumper;
	struct completion startup;
};

struct smp_ops___68 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___68 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___68;

struct lruvec___68 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___68 *zone;
};

struct pglist_data___68;

struct zone___68 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___68 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___68 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___68 {
	struct zone___68 *zone;
	int zone_idx;
};

struct zonelist___68 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___68 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___68 {
	struct zone___68 node_zones[4];
	struct zonelist___68 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___68 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct autogroup___4;

struct signal_struct___68 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___68 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___68 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___4 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___69 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___4 {
	struct kref kref;
	struct task_group___4 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___4;

struct cfs_rq___4 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___4 *curr;
	struct sched_entity___4 *next;
	struct sched_entity___4 *last;
	struct sched_entity___4 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___4 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___4 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___4 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___4 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___4 *tg;
};

struct sched_class___4 {
	const struct sched_class___4 *next;
	void (*enqueue_task)(struct rq___4 *, struct task_struct___68 *, int);
	void (*dequeue_task)(struct rq___4 *, struct task_struct___68 *, int);
	void (*yield_task)(struct rq___4 *);
	bool (*yield_to_task)(struct rq___4 *, struct task_struct___68 *, bool);
	void (*check_preempt_curr)(struct rq___4 *, struct task_struct___68 *, int);
	struct task_struct___68 * (*pick_next_task)(struct rq___4 *);
	void (*put_prev_task)(struct rq___4 *, struct task_struct___68 *);
	int (*select_task_rq)(struct task_struct___68 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___68 *, int);
	void (*pre_schedule)(struct rq___4 *, struct task_struct___68 *);
	void (*post_schedule)(struct rq___4 *);
	void (*task_waking)(struct task_struct___68 *);
	void (*task_woken)(struct rq___4 *, struct task_struct___68 *);
	void (*set_cpus_allowed)(struct task_struct___68 *, const struct cpumask *);
	void (*rq_online)(struct rq___4 *);
	void (*rq_offline)(struct rq___4 *);
	void (*set_curr_task)(struct rq___4 *);
	void (*task_tick)(struct rq___4 *, struct task_struct___68 *, int);
	void (*task_fork)(struct task_struct___68 *);
	void (*switched_from)(struct rq___4 *, struct task_struct___68 *);
	void (*switched_to)(struct rq___4 *, struct task_struct___68 *);
	void (*prio_changed)(struct rq___4 *, struct task_struct___68 *, int);
	unsigned int (*get_rr_interval)(struct rq___4 *, struct task_struct___68 *);
	void (*task_move_group)(struct task_struct___68 *, int);
	void (*update_curr)(struct rq___4 *);
};

struct cgroup___40;

struct cgroup_subsys_state___40 {
	struct cgroup___40 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_group___4 {
	struct cgroup_subsys_state___40 css;
	struct sched_entity___4 **se;
	struct cfs_rq___4 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___4 **rt_se;
	struct rt_rq___4 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___4 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___4 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___40 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___40 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___59 {
	void **freelist;
	long unsigned int tid;
	struct page___68 *page;
	struct page___68 *partial;
};

struct memcg_cache_params___59 {
	bool is_root_cache;
	union {
		struct kmem_cache___59 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___59 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___40 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___69 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___69 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___69 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___68;

struct super_block___69;

struct dentry___69 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___69 *d_parent;
	struct qstr d_name;
	struct inode___69 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___68 *d_op;
	struct super_block___69 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___68;

struct file_lock___68;

struct dquot___68;

struct block_device___68;

struct inode___69 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___68 *i_op;
	struct super_block___69 *i_sb;
	struct address_space___68 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___69 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___68 *i_fop;
	struct file_lock___68 *i_flock;
	struct address_space___68 i_data;
	struct dquot___68 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___68 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___68 {
	int (*d_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_hash)(const struct dentry___69 *, struct qstr *);
	int (*d_compare)(const struct dentry___69 *, const struct dentry___69 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___69 *);
	void (*d_release)(struct dentry___69 *);
	void (*d_prune)(struct dentry___69 *);
	void (*d_iput)(struct dentry___69 *, struct inode___69 *);
	char * (*d_dname)(struct dentry___69 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___68 *);
	int (*d_manage)(struct dentry___69 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___68;

struct mem_dqinfo___68 {
	struct quota_format_type___68 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___68;

struct quota_info___68 {
	unsigned int flags;
	struct mutex___69 dqio_mutex;
	struct mutex___69 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___69 *files[2];
	struct mem_dqinfo___68 info[2];
	const struct quota_format_ops___68 *ops[2];
};

struct file_system_type___68;

struct super_operations___68;

struct dquot_operations___68;

struct quotactl_ops___68;

struct super_block___69 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___68 *s_type;
	const struct super_operations___68 *s_op;
	const struct dquot_operations___68 *dq_op;
	const struct quotactl_ops___68 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___69 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___40 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___68 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___68 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___69 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___68 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___68 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___69 *bd_inode;
	struct super_block___69 *bd_super;
	struct mutex___69 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___68 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___69 bd_fsfreeze_mutex;
};

struct iattr___69 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___68 *ia_file;
};

struct dquot___68 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___69 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___69 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___68 {
	int qf_fmt_id;
	const struct quota_format_ops___68 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___68 *qf_next;
};

struct quota_format_ops___68 {
	int (*check_quota_file)(struct super_block___69 *, int);
	int (*read_file_info)(struct super_block___69 *, int);
	int (*write_file_info)(struct super_block___69 *, int);
	int (*free_file_info)(struct super_block___69 *, int);
	int (*read_dqblk)(struct dquot___68 *);
	int (*commit_dqblk)(struct dquot___68 *);
	int (*release_dqblk)(struct dquot___68 *);
};

struct dquot_operations___68 {
	int (*write_dquot)(struct dquot___68 *);
	struct dquot___68 * (*alloc_dquot)(struct super_block___69 *, int);
	void (*destroy_dquot)(struct dquot___68 *);
	int (*acquire_dquot)(struct dquot___68 *);
	int (*release_dquot)(struct dquot___68 *);
	int (*mark_dirty)(struct dquot___68 *);
	int (*write_info)(struct super_block___69 *, int);
	qsize_t * (*get_reserved_space)(struct inode___69 *);
};

struct quotactl_ops___68 {
	int (*quota_on)(struct super_block___69 *, int, int, struct path___68 *);
	int (*quota_on_meta)(struct super_block___69 *, int, int);
	int (*quota_off)(struct super_block___69 *, int);
	int (*quota_sync)(struct super_block___69 *, int);
	int (*get_info)(struct super_block___69 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___69 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___69 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___69 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___69 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___69 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___69 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___69 *, unsigned int);
};

struct address_space_operations___68 {
	int (*writepage)(struct page___68 *, struct writeback_control *);
	int (*readpage)(struct file___68 *, struct page___68 *);
	int (*writepages)(struct address_space___68 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___68 *);
	int (*readpages)(struct file___68 *, struct address_space___68 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___68 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___68 **, void **);
	int (*write_end)(struct file___68 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___68 *, void *);
	sector_t (*bmap)(struct address_space___68 *, sector_t);
	void (*invalidatepage)(struct page___68 *, long unsigned int);
	int (*releasepage)(struct page___68 *, gfp_t);
	void (*freepage)(struct page___68 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___68 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___68 *, struct page___68 *, struct page___68 *, enum migrate_mode);
	int (*launder_page)(struct page___68 *);
	int (*is_partially_uptodate)(struct page___68 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___68 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___68 *, struct page___68 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___68 *, sector_t *);
	void (*swap_deactivate)(struct file___68 *);
	void (*invalidatepage_range)(struct page___68 *, unsigned int, unsigned int);
};

struct inode_operations___68 {
	struct dentry___69 * (*lookup)(struct inode___69 *, struct dentry___69 *, unsigned int);
	void * (*follow_link)(struct dentry___69 *, struct nameidata *);
	int (*permission)(struct inode___69 *, int);
	struct posix_acl * (*get_acl)(struct inode___69 *, int);
	int (*readlink)(struct dentry___69 *, char *, int);
	void (*put_link)(struct dentry___69 *, struct nameidata *, void *);
	int (*create)(struct inode___69 *, struct dentry___69 *, umode_t, bool);
	int (*link)(struct dentry___69 *, struct inode___69 *, struct dentry___69 *);
	int (*unlink)(struct inode___69 *, struct dentry___69 *);
	int (*symlink)(struct inode___69 *, struct dentry___69 *, const char *);
	int (*mkdir)(struct inode___69 *, struct dentry___69 *, umode_t);
	int (*rmdir)(struct inode___69 *, struct dentry___69 *);
	int (*mknod)(struct inode___69 *, struct dentry___69 *, umode_t, dev_t);
	int (*rename)(struct inode___69 *, struct dentry___69 *, struct inode___69 *, struct dentry___69 *);
	int (*setattr)(struct dentry___69 *, struct iattr___69 *);
	int (*getattr)(struct vfsmount *, struct dentry___69 *, struct kstat *);
	int (*setxattr)(struct dentry___69 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___69 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___69 *, char *, size_t);
	int (*removexattr)(struct dentry___69 *, const char *);
	int (*fiemap)(struct inode___69 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___69 *, struct timespec *, int);
	int (*atomic_open)(struct inode___69 *, struct dentry___69 *, struct file___68 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___49;

struct file_operations___68 {
	struct module *owner;
	loff_t (*llseek)(struct file___68 *, loff_t, int);
	ssize_t (*read)(struct file___68 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___68 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___68 *, void *, filldir_t);
	unsigned int (*poll)(struct file___68 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___68 *, struct vm_area_struct___72 *);
	int (*open)(struct inode___69 *, struct file___68 *);
	int (*flush)(struct file___68 *, fl_owner_t);
	int (*release)(struct inode___69 *, struct file___68 *);
	int (*fsync)(struct file___68 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___68 *, int);
	int (*lock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*sendpage)(struct file___68 *, struct page___68 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___68 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___68 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___68 *, long int, struct file_lock___68 **, void **);
		struct {
			int (*setlease)(struct file___68 *, long int, struct file_lock___68 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___68 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___49 *, struct file___68 *);
};

struct fasync_struct___68;

struct file_lock_operations___68;

struct lock_manager_operations___68;

struct file_lock___68 {
	struct file_lock___68 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___68 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___68 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___68 *fl_ops;
	const struct lock_manager_operations___68 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___68 {
	void (*fl_copy_lock)(struct file_lock___68 *, struct file_lock___68 *);
	void (*fl_release_private)(struct file_lock___68 *);
};

struct lock_manager_operations___68 {
	int (*lm_compare_owner)(struct file_lock___68 *, struct file_lock___68 *);
	long unsigned int (*lm_owner_key)(struct file_lock___68 *);
	void (*lm_notify)(struct file_lock___68 *);
	int (*lm_grant)(struct file_lock___68 *, struct file_lock___68 *, int);
	void (*lm_break)(struct file_lock___68 *);
	int (*lm_change)(struct file_lock___68 **, int);
};

struct fasync_struct___68 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___68 *fa_next;
	struct file___68 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___68 {
	const char *name;
	int fs_flags;
	struct dentry___69 * (*mount)(struct file_system_type___68 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___69 *);
	struct module *owner;
	struct file_system_type___68 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___68 {
	struct inode___69 * (*alloc_inode)(struct super_block___69 *);
	void (*destroy_inode)(struct inode___69 *);
	void (*dirty_inode)(struct inode___69 *, int);
	int (*write_inode)(struct inode___69 *, struct writeback_control *);
	int (*drop_inode)(struct inode___69 *);
	void (*evict_inode)(struct inode___69 *);
	void (*put_super)(struct super_block___69 *);
	int (*sync_fs)(struct super_block___69 *, int);
	int (*freeze_fs)(struct super_block___69 *);
	int (*unfreeze_fs)(struct super_block___69 *);
	int (*statfs)(struct dentry___69 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___69 *, int *, char *);
	void (*umount_begin)(struct super_block___69 *);
	int (*show_options)(struct seq_file___49 *, struct dentry___69 *);
	int (*show_devname)(struct seq_file___49 *, struct dentry___69 *);
	int (*show_path)(struct seq_file___49 *, struct dentry___69 *);
	int (*show_stats)(struct seq_file___49 *, struct dentry___69 *);
	ssize_t (*quota_read)(struct super_block___69 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___69 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___69 *);
	int (*bdev_try_to_free_page)(struct super_block___69 *, struct page___68 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___69 *);
	void (*free_cached_objects)(struct super_block___69 *, int);
};

struct seq_operations___48;

struct seq_file___49 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___69 lock;
	const struct seq_operations___48 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___40;

struct cgroup___40 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___40 *parent;
	struct dentry___69 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___40 *subsys[11];
	struct cgroupfs_root___40 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___69 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___40 {
	struct super_block___69 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___40 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct rq___4 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___4 cfs;
	struct rt_rq___4 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___68 *curr;
	struct task_struct___68 *idle;
	struct task_struct___68 *stop;
	long unsigned int next_balance;
	struct mm_struct___72 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data___2 hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct seq_operations___48 {
	void * (*start)(struct seq_file___49 *, loff_t *);
	void (*stop)(struct seq_file___49 *, void *);
	void * (*next)(struct seq_file___49 *, void *, loff_t *);
	int (*show)(struct seq_file___49 *, void *);
};

struct page___69;

typedef struct page___69 *pgtable_t___69;

struct address_space___69;

struct kmem_cache___60;

struct page___69 {
	long unsigned int flags;
	struct address_space___69 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___69 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___69 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___60 *slab_cache;
		struct page___69 *first_page;
	};
	long: 64;
};

struct task_struct___69;

struct pv_cpu_ops___69 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___69 *);
	void (*end_context_switch)(struct task_struct___69 *);
};

struct cfs_rq___5;

struct sched_entity___5 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___5 *parent;
	struct cfs_rq___5 *cfs_rq;
	struct cfs_rq___5 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___5;

struct sched_rt_entity___5 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___5 *back;
	struct sched_rt_entity___5 *parent;
	struct rt_rq___5 *rt_rq;
	struct rt_rq___5 *my_q;
};

struct mutex___70 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___69 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___66 {
	struct page___69 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___5;

struct task_group___5;

struct mm_struct___73;

struct signal_struct___69;

struct css_set___41;

struct task_struct___69 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___69 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___5 *sched_class;
	struct sched_entity___5 se;
	struct sched_rt_entity___5 rt;
	struct task_group___5 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___73 *mm;
	struct mm_struct___73 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___69 *real_parent;
	struct task_struct___69 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___69 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___69 = 0,
		VTIME_USER___69 = 1,
		VTIME_SYS___69 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___69 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___41 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___70 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___66 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___73 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___73 *, struct mm_struct___73 *);
	void (*dup_mmap)(struct mm_struct___73 *, struct mm_struct___73 *);
	void (*exit_mmap)(struct mm_struct___73 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___73 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___73 *);
	void (*pgd_free)(struct mm_struct___73 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___73 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___73 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___73 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___73 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___73 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___73 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___73 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___73 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___73 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___73 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___73 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___70 lock;
	void *vdso;
} mm_context_t___70;

struct xol_area___69;

struct uprobes_state___69 {
	struct xol_area___69 *xol_area;
};

struct vm_area_struct___73;

struct file___69;

struct core_state___69;

struct mm_struct___73 {
	struct vm_area_struct___73 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___73 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___73 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___70 context;
	long unsigned int flags;
	struct core_state___69 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___69 *owner;
	struct file___69 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___69 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___69;

struct lruvec___69 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___69 *zone;
};

struct pglist_data___69;

struct zone___69 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___69 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___69 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___69 {
	struct zone___69 *zone;
	int zone_idx;
};

struct zonelist___69 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___69 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___69 {
	struct zone___69 node_zones[4];
	struct zonelist___69 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___69 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___69 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___69 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dentry___70;

struct path___69 {
	struct vfsmount *mnt;
	struct dentry___70 *dentry;
};

struct inode___70;

struct file_operations___69;

struct file___69 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___69 f_path;
	struct inode___70 *f_inode;
	const struct file_operations___69 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___69 *f_mapping;
	struct mutex___70 f_pos_lock;
};

struct vm_area_struct___73 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___73 *vm_next;
	struct vm_area_struct___73 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___73 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___69 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___60 {
	void **freelist;
	long unsigned int tid;
	struct page___69 *page;
	struct page___69 *partial;
};

struct memcg_cache_params___60;

struct kmem_cache___60 {
	struct kmem_cache_cpu___60 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___60 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___60 {
	bool is_root_cache;
	union {
		struct kmem_cache___60 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___60 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___69;

struct super_block___70;

struct dentry___70 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___70 *d_parent;
	struct qstr d_name;
	struct inode___70 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___69 *d_op;
	struct super_block___70 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___69;

struct address_space___69 {
	struct inode___70 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___70 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___69 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___69;

struct file_lock___69;

struct dquot___69;

struct block_device___69;

struct inode___70 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___69 *i_op;
	struct super_block___70 *i_sb;
	struct address_space___69 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___70 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___69 *i_fop;
	struct file_lock___69 *i_flock;
	struct address_space___69 i_data;
	struct dquot___69 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___69 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___69 {
	int (*d_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_hash)(const struct dentry___70 *, struct qstr *);
	int (*d_compare)(const struct dentry___70 *, const struct dentry___70 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___70 *);
	void (*d_release)(struct dentry___70 *);
	void (*d_prune)(struct dentry___70 *);
	void (*d_iput)(struct dentry___70 *, struct inode___70 *);
	char * (*d_dname)(struct dentry___70 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___69 *);
	int (*d_manage)(struct dentry___70 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___69;

struct mem_dqinfo___69 {
	struct quota_format_type___69 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___69;

struct quota_info___69 {
	unsigned int flags;
	struct mutex___70 dqio_mutex;
	struct mutex___70 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___70 *files[2];
	struct mem_dqinfo___69 info[2];
	const struct quota_format_ops___69 *ops[2];
};

struct file_system_type___69;

struct super_operations___69;

struct dquot_operations___69;

struct quotactl_ops___69;

struct xattr_handler___41;

struct super_block___70 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___69 *s_type;
	const struct super_operations___69 *s_op;
	const struct dquot_operations___69 *dq_op;
	const struct quotactl_ops___69 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___70 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___41 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___69 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___69 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___70 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___69 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___69 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___70 *bd_inode;
	struct super_block___70 *bd_super;
	struct mutex___70 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___69 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___70 bd_fsfreeze_mutex;
};

struct cgroup___41;

struct cgroup_subsys_state___41 {
	struct cgroup___41 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___70 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___69 *ia_file;
};

struct dquot___69 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___70 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___70 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___69 {
	int qf_fmt_id;
	const struct quota_format_ops___69 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___69 *qf_next;
};

struct quota_format_ops___69 {
	int (*check_quota_file)(struct super_block___70 *, int);
	int (*read_file_info)(struct super_block___70 *, int);
	int (*write_file_info)(struct super_block___70 *, int);
	int (*free_file_info)(struct super_block___70 *, int);
	int (*read_dqblk)(struct dquot___69 *);
	int (*commit_dqblk)(struct dquot___69 *);
	int (*release_dqblk)(struct dquot___69 *);
};

struct dquot_operations___69 {
	int (*write_dquot)(struct dquot___69 *);
	struct dquot___69 * (*alloc_dquot)(struct super_block___70 *, int);
	void (*destroy_dquot)(struct dquot___69 *);
	int (*acquire_dquot)(struct dquot___69 *);
	int (*release_dquot)(struct dquot___69 *);
	int (*mark_dirty)(struct dquot___69 *);
	int (*write_info)(struct super_block___70 *, int);
	qsize_t * (*get_reserved_space)(struct inode___70 *);
};

struct quotactl_ops___69 {
	int (*quota_on)(struct super_block___70 *, int, int, struct path___69 *);
	int (*quota_on_meta)(struct super_block___70 *, int, int);
	int (*quota_off)(struct super_block___70 *, int);
	int (*quota_sync)(struct super_block___70 *, int);
	int (*get_info)(struct super_block___70 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___70 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___70 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___70 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___70 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___70 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___70 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___70 *, unsigned int);
};

struct address_space_operations___69 {
	int (*writepage)(struct page___69 *, struct writeback_control *);
	int (*readpage)(struct file___69 *, struct page___69 *);
	int (*writepages)(struct address_space___69 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___69 *);
	int (*readpages)(struct file___69 *, struct address_space___69 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___69 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___69 **, void **);
	int (*write_end)(struct file___69 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___69 *, void *);
	sector_t (*bmap)(struct address_space___69 *, sector_t);
	void (*invalidatepage)(struct page___69 *, long unsigned int);
	int (*releasepage)(struct page___69 *, gfp_t);
	void (*freepage)(struct page___69 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___69 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___69 *, struct page___69 *, struct page___69 *, enum migrate_mode);
	int (*launder_page)(struct page___69 *);
	int (*is_partially_uptodate)(struct page___69 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___69 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___69 *, struct page___69 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___69 *, sector_t *);
	void (*swap_deactivate)(struct file___69 *);
	void (*invalidatepage_range)(struct page___69 *, unsigned int, unsigned int);
};

struct inode_operations___69 {
	struct dentry___70 * (*lookup)(struct inode___70 *, struct dentry___70 *, unsigned int);
	void * (*follow_link)(struct dentry___70 *, struct nameidata *);
	int (*permission)(struct inode___70 *, int);
	struct posix_acl * (*get_acl)(struct inode___70 *, int);
	int (*readlink)(struct dentry___70 *, char *, int);
	void (*put_link)(struct dentry___70 *, struct nameidata *, void *);
	int (*create)(struct inode___70 *, struct dentry___70 *, umode_t, bool);
	int (*link)(struct dentry___70 *, struct inode___70 *, struct dentry___70 *);
	int (*unlink)(struct inode___70 *, struct dentry___70 *);
	int (*symlink)(struct inode___70 *, struct dentry___70 *, const char *);
	int (*mkdir)(struct inode___70 *, struct dentry___70 *, umode_t);
	int (*rmdir)(struct inode___70 *, struct dentry___70 *);
	int (*mknod)(struct inode___70 *, struct dentry___70 *, umode_t, dev_t);
	int (*rename)(struct inode___70 *, struct dentry___70 *, struct inode___70 *, struct dentry___70 *);
	int (*setattr)(struct dentry___70 *, struct iattr___70 *);
	int (*getattr)(struct vfsmount *, struct dentry___70 *, struct kstat *);
	int (*setxattr)(struct dentry___70 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___70 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___70 *, char *, size_t);
	int (*removexattr)(struct dentry___70 *, const char *);
	int (*fiemap)(struct inode___70 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___70 *, struct timespec *, int);
	int (*atomic_open)(struct inode___70 *, struct dentry___70 *, struct file___69 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___50;

struct file_operations___69 {
	struct module *owner;
	loff_t (*llseek)(struct file___69 *, loff_t, int);
	ssize_t (*read)(struct file___69 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___69 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___69 *, void *, filldir_t);
	unsigned int (*poll)(struct file___69 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___69 *, struct vm_area_struct___73 *);
	int (*open)(struct inode___70 *, struct file___69 *);
	int (*flush)(struct file___69 *, fl_owner_t);
	int (*release)(struct inode___70 *, struct file___69 *);
	int (*fsync)(struct file___69 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___69 *, int);
	int (*lock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*sendpage)(struct file___69 *, struct page___69 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___69 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___69 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___69 *, long int, struct file_lock___69 **, void **);
		struct {
			int (*setlease)(struct file___69 *, long int, struct file_lock___69 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___69 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___50 *, struct file___69 *);
};

struct fasync_struct___69;

struct file_lock_operations___69;

struct lock_manager_operations___69;

struct file_lock___69 {
	struct file_lock___69 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___69 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___69 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___69 *fl_ops;
	const struct lock_manager_operations___69 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___69 {
	void (*fl_copy_lock)(struct file_lock___69 *, struct file_lock___69 *);
	void (*fl_release_private)(struct file_lock___69 *);
};

struct lock_manager_operations___69 {
	int (*lm_compare_owner)(struct file_lock___69 *, struct file_lock___69 *);
	long unsigned int (*lm_owner_key)(struct file_lock___69 *);
	void (*lm_notify)(struct file_lock___69 *);
	int (*lm_grant)(struct file_lock___69 *, struct file_lock___69 *, int);
	void (*lm_break)(struct file_lock___69 *);
	int (*lm_change)(struct file_lock___69 **, int);
};

struct fasync_struct___69 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___69 *fa_next;
	struct file___69 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___69 {
	const char *name;
	int fs_flags;
	struct dentry___70 * (*mount)(struct file_system_type___69 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___70 *);
	struct module *owner;
	struct file_system_type___69 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___69 {
	struct inode___70 * (*alloc_inode)(struct super_block___70 *);
	void (*destroy_inode)(struct inode___70 *);
	void (*dirty_inode)(struct inode___70 *, int);
	int (*write_inode)(struct inode___70 *, struct writeback_control *);
	int (*drop_inode)(struct inode___70 *);
	void (*evict_inode)(struct inode___70 *);
	void (*put_super)(struct super_block___70 *);
	int (*sync_fs)(struct super_block___70 *, int);
	int (*freeze_fs)(struct super_block___70 *);
	int (*unfreeze_fs)(struct super_block___70 *);
	int (*statfs)(struct dentry___70 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___70 *, int *, char *);
	void (*umount_begin)(struct super_block___70 *);
	int (*show_options)(struct seq_file___50 *, struct dentry___70 *);
	int (*show_devname)(struct seq_file___50 *, struct dentry___70 *);
	int (*show_path)(struct seq_file___50 *, struct dentry___70 *);
	int (*show_stats)(struct seq_file___50 *, struct dentry___70 *);
	ssize_t (*quota_read)(struct super_block___70 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___70 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___70 *);
	int (*bdev_try_to_free_page)(struct super_block___70 *, struct page___69 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___70 *);
	void (*free_cached_objects)(struct super_block___70 *, int);
};

struct xattr_handler___41 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___70 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___70 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___70 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___49;

struct seq_file___50 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___70 lock;
	const struct seq_operations___49 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___49 {
	void * (*start)(struct seq_file___50 *, loff_t *);
	void (*stop)(struct seq_file___50 *, void *);
	void * (*next)(struct seq_file___50 *, void *, loff_t *);
	int (*show)(struct seq_file___50 *, void *);
};

struct xol_area___69 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___69 *page;
	long unsigned int vaddr;
};

struct core_thread___69 {
	struct task_struct___69 *task;
	struct core_thread___69 *next;
};

struct core_state___69 {
	atomic_t nr_threads;
	struct core_thread___69 dumper;
	struct completion startup;
};

struct autogroup___5;

struct signal_struct___69 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___69 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___69 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___5 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___70 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___5 {
	struct kref kref;
	struct task_group___5 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___5;

struct cfs_rq___5 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___5 *curr;
	struct sched_entity___5 *next;
	struct sched_entity___5 *last;
	struct sched_entity___5 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___5 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___5 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___5 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___5 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___5 *tg;
};

struct sched_class___5 {
	const struct sched_class___5 *next;
	void (*enqueue_task)(struct rq___5 *, struct task_struct___69 *, int);
	void (*dequeue_task)(struct rq___5 *, struct task_struct___69 *, int);
	void (*yield_task)(struct rq___5 *);
	bool (*yield_to_task)(struct rq___5 *, struct task_struct___69 *, bool);
	void (*check_preempt_curr)(struct rq___5 *, struct task_struct___69 *, int);
	struct task_struct___69 * (*pick_next_task)(struct rq___5 *);
	void (*put_prev_task)(struct rq___5 *, struct task_struct___69 *);
	int (*select_task_rq)(struct task_struct___69 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___69 *, int);
	void (*pre_schedule)(struct rq___5 *, struct task_struct___69 *);
	void (*post_schedule)(struct rq___5 *);
	void (*task_waking)(struct task_struct___69 *);
	void (*task_woken)(struct rq___5 *, struct task_struct___69 *);
	void (*set_cpus_allowed)(struct task_struct___69 *, const struct cpumask *);
	void (*rq_online)(struct rq___5 *);
	void (*rq_offline)(struct rq___5 *);
	void (*set_curr_task)(struct rq___5 *);
	void (*task_tick)(struct rq___5 *, struct task_struct___69 *, int);
	void (*task_fork)(struct task_struct___69 *);
	void (*switched_from)(struct rq___5 *, struct task_struct___69 *);
	void (*switched_to)(struct rq___5 *, struct task_struct___69 *);
	void (*prio_changed)(struct rq___5 *, struct task_struct___69 *, int);
	unsigned int (*get_rr_interval)(struct rq___5 *, struct task_struct___69 *);
	void (*task_move_group)(struct task_struct___69 *, int);
	void (*update_curr)(struct rq___5 *);
};

struct task_group___5 {
	struct cgroup_subsys_state___41 css;
	struct sched_entity___5 **se;
	struct cfs_rq___5 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___5 **rt_se;
	struct rt_rq___5 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___5 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___5 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___41 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___41 *subsys[11];
	struct callback_head callback_head;
};

struct cgroupfs_root___41;

struct cgroup___41 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___41 *parent;
	struct dentry___70 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___41 *subsys[11];
	struct cgroupfs_root___41 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___70 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___41 {
	struct super_block___70 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___41 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct rq___5 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___5 cfs;
	struct rt_rq___5 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___69 *curr;
	struct task_struct___69 *idle;
	struct task_struct___69 *stop;
	long unsigned int next_balance;
	struct mm_struct___73 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct page___70;

typedef struct page___70 *pgtable_t___70;

struct address_space___70;

struct kmem_cache___61;

struct page___70 {
	long unsigned int flags;
	struct address_space___70 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___70 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___70 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___61 *slab_cache;
		struct page___70 *first_page;
	};
	long: 64;
};

struct task_struct___70;

struct pv_cpu_ops___70 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___70 *);
	void (*end_context_switch)(struct task_struct___70 *);
};

struct cfs_rq___6;

struct sched_entity___6 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___6 *parent;
	struct cfs_rq___6 *cfs_rq;
	struct cfs_rq___6 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___6;

struct sched_rt_entity___6 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___6 *back;
	struct sched_rt_entity___6 *parent;
	struct rt_rq___6 *rt_rq;
	struct rt_rq___6 *my_q;
};

struct mutex___71 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___70 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___67 {
	struct page___70 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___6;

struct task_group___6;

struct mm_struct___74;

struct signal_struct___70;

struct css_set___42;

struct task_struct___70 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___70 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___6 *sched_class;
	struct sched_entity___6 se;
	struct sched_rt_entity___6 rt;
	struct task_group___6 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___74 *mm;
	struct mm_struct___74 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___70 *real_parent;
	struct task_struct___70 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___70 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___34 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___70 = 0,
		VTIME_USER___70 = 1,
		VTIME_SYS___70 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___70 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___42 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___71 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___67 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___74 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___74 *, struct mm_struct___74 *);
	void (*dup_mmap)(struct mm_struct___74 *, struct mm_struct___74 *);
	void (*exit_mmap)(struct mm_struct___74 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___74 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___74 *);
	void (*pgd_free)(struct mm_struct___74 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___74 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___74 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___74 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___74 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___74 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___74 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___74 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___74 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___74 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___74 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___74 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___71 lock;
	void *vdso;
} mm_context_t___71;

struct xol_area___70;

struct uprobes_state___70 {
	struct xol_area___70 *xol_area;
};

struct vm_area_struct___74;

struct file___70;

struct core_state___70;

struct mm_struct___74 {
	struct vm_area_struct___74 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___74 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___74 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___71 context;
	long unsigned int flags;
	struct core_state___70 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___70 *owner;
	struct file___70 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___70 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___32 {
	struct task_struct___70 *task;
	struct exec_domain___18 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___71;

struct dentry_operations___70;

struct super_block___71;

struct dentry___71 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___71 *d_parent;
	struct qstr d_name;
	struct inode___71 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___70 *d_op;
	struct super_block___71 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___70;

struct address_space___70 {
	struct inode___71 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___71 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___70 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___70;

struct file_operations___70;

struct file_lock___70;

struct dquot___70;

struct block_device___70;

struct inode___71 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___70 *i_op;
	struct super_block___71 *i_sb;
	struct address_space___70 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___71 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___70 *i_fop;
	struct file_lock___70 *i_flock;
	struct address_space___70 i_data;
	struct dquot___70 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___70 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___70;

struct dentry_operations___70 {
	int (*d_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_hash)(const struct dentry___71 *, struct qstr *);
	int (*d_compare)(const struct dentry___71 *, const struct dentry___71 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___71 *);
	void (*d_release)(struct dentry___71 *);
	void (*d_prune)(struct dentry___71 *);
	void (*d_iput)(struct dentry___71 *, struct inode___71 *);
	char * (*d_dname)(struct dentry___71 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___70 *);
	int (*d_manage)(struct dentry___71 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___70;

struct mem_dqinfo___70 {
	struct quota_format_type___70 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___70;

struct quota_info___70 {
	unsigned int flags;
	struct mutex___71 dqio_mutex;
	struct mutex___71 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___71 *files[2];
	struct mem_dqinfo___70 info[2];
	const struct quota_format_ops___70 *ops[2];
};

struct file_system_type___70;

struct super_operations___70;

struct dquot_operations___70;

struct quotactl_ops___70;

struct xattr_handler___42;

struct super_block___71 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___70 *s_type;
	const struct super_operations___70 *s_op;
	const struct dquot_operations___70 *dq_op;
	const struct quotactl_ops___70 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___71 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___42 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___70 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___70 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___71 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___70 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___70 {
	struct vfsmount *mnt;
	struct dentry___71 *dentry;
};

struct irq_data___49;

struct x86_io_apic_ops___49 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___49 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___49;

struct irq_data___49 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___49 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___70 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___70 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___70 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___71 *bd_inode;
	struct super_block___71 *bd_super;
	struct mutex___71 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___70 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___71 bd_fsfreeze_mutex;
};

struct cgroup___42;

struct cgroup_subsys_state___42 {
	struct cgroup___42 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___71 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___70 *ia_file;
};

struct file___70 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___70 f_path;
	struct inode___71 *f_inode;
	const struct file_operations___70 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___70 *f_mapping;
	struct mutex___71 f_pos_lock;
};

struct zone___70;

struct lruvec___70 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___70 *zone;
};

struct pglist_data___70;

struct zone___70 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___70 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___70 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___70 {
	struct zone___70 *zone;
	int zone_idx;
};

struct zonelist___70 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___70 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___70 {
	struct zone___70 node_zones[4];
	struct zonelist___70 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___70 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___70 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___71 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___71 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___70 {
	int qf_fmt_id;
	const struct quota_format_ops___70 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___70 *qf_next;
};

struct quota_format_ops___70 {
	int (*check_quota_file)(struct super_block___71 *, int);
	int (*read_file_info)(struct super_block___71 *, int);
	int (*write_file_info)(struct super_block___71 *, int);
	int (*free_file_info)(struct super_block___71 *, int);
	int (*read_dqblk)(struct dquot___70 *);
	int (*commit_dqblk)(struct dquot___70 *);
	int (*release_dqblk)(struct dquot___70 *);
};

struct dquot_operations___70 {
	int (*write_dquot)(struct dquot___70 *);
	struct dquot___70 * (*alloc_dquot)(struct super_block___71 *, int);
	void (*destroy_dquot)(struct dquot___70 *);
	int (*acquire_dquot)(struct dquot___70 *);
	int (*release_dquot)(struct dquot___70 *);
	int (*mark_dirty)(struct dquot___70 *);
	int (*write_info)(struct super_block___71 *, int);
	qsize_t * (*get_reserved_space)(struct inode___71 *);
};

struct quotactl_ops___70 {
	int (*quota_on)(struct super_block___71 *, int, int, struct path___70 *);
	int (*quota_on_meta)(struct super_block___71 *, int, int);
	int (*quota_off)(struct super_block___71 *, int);
	int (*quota_sync)(struct super_block___71 *, int);
	int (*get_info)(struct super_block___71 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___71 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___71 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___71 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___71 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___71 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___71 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___71 *, unsigned int);
};

struct address_space_operations___70 {
	int (*writepage)(struct page___70 *, struct writeback_control *);
	int (*readpage)(struct file___70 *, struct page___70 *);
	int (*writepages)(struct address_space___70 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___70 *);
	int (*readpages)(struct file___70 *, struct address_space___70 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___70 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___70 **, void **);
	int (*write_end)(struct file___70 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___70 *, void *);
	sector_t (*bmap)(struct address_space___70 *, sector_t);
	void (*invalidatepage)(struct page___70 *, long unsigned int);
	int (*releasepage)(struct page___70 *, gfp_t);
	void (*freepage)(struct page___70 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___70 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___70 *, struct page___70 *, struct page___70 *, enum migrate_mode);
	int (*launder_page)(struct page___70 *);
	int (*is_partially_uptodate)(struct page___70 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___70 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___70 *, struct page___70 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___70 *, sector_t *);
	void (*swap_deactivate)(struct file___70 *);
	void (*invalidatepage_range)(struct page___70 *, unsigned int, unsigned int);
};

struct inode_operations___70 {
	struct dentry___71 * (*lookup)(struct inode___71 *, struct dentry___71 *, unsigned int);
	void * (*follow_link)(struct dentry___71 *, struct nameidata *);
	int (*permission)(struct inode___71 *, int);
	struct posix_acl * (*get_acl)(struct inode___71 *, int);
	int (*readlink)(struct dentry___71 *, char *, int);
	void (*put_link)(struct dentry___71 *, struct nameidata *, void *);
	int (*create)(struct inode___71 *, struct dentry___71 *, umode_t, bool);
	int (*link)(struct dentry___71 *, struct inode___71 *, struct dentry___71 *);
	int (*unlink)(struct inode___71 *, struct dentry___71 *);
	int (*symlink)(struct inode___71 *, struct dentry___71 *, const char *);
	int (*mkdir)(struct inode___71 *, struct dentry___71 *, umode_t);
	int (*rmdir)(struct inode___71 *, struct dentry___71 *);
	int (*mknod)(struct inode___71 *, struct dentry___71 *, umode_t, dev_t);
	int (*rename)(struct inode___71 *, struct dentry___71 *, struct inode___71 *, struct dentry___71 *);
	int (*setattr)(struct dentry___71 *, struct iattr___71 *);
	int (*getattr)(struct vfsmount *, struct dentry___71 *, struct kstat *);
	int (*setxattr)(struct dentry___71 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___71 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___71 *, char *, size_t);
	int (*removexattr)(struct dentry___71 *, const char *);
	int (*fiemap)(struct inode___71 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___71 *, struct timespec *, int);
	int (*atomic_open)(struct inode___71 *, struct dentry___71 *, struct file___70 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___51;

struct file_operations___70 {
	struct module *owner;
	loff_t (*llseek)(struct file___70 *, loff_t, int);
	ssize_t (*read)(struct file___70 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___70 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___70 *, void *, filldir_t);
	unsigned int (*poll)(struct file___70 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___70 *, struct vm_area_struct___74 *);
	int (*open)(struct inode___71 *, struct file___70 *);
	int (*flush)(struct file___70 *, fl_owner_t);
	int (*release)(struct inode___71 *, struct file___70 *);
	int (*fsync)(struct file___70 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___70 *, int);
	int (*lock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*sendpage)(struct file___70 *, struct page___70 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___70 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___70 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___70 *, long int, struct file_lock___70 **, void **);
		struct {
			int (*setlease)(struct file___70 *, long int, struct file_lock___70 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___70 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___51 *, struct file___70 *);
};

struct fasync_struct___70;

struct file_lock_operations___70;

struct lock_manager_operations___70;

struct file_lock___70 {
	struct file_lock___70 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___34 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___70 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___70 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___70 *fl_ops;
	const struct lock_manager_operations___70 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___70 {
	void (*fl_copy_lock)(struct file_lock___70 *, struct file_lock___70 *);
	void (*fl_release_private)(struct file_lock___70 *);
};

struct lock_manager_operations___70 {
	int (*lm_compare_owner)(struct file_lock___70 *, struct file_lock___70 *);
	long unsigned int (*lm_owner_key)(struct file_lock___70 *);
	void (*lm_notify)(struct file_lock___70 *);
	int (*lm_grant)(struct file_lock___70 *, struct file_lock___70 *, int);
	void (*lm_break)(struct file_lock___70 *);
	int (*lm_change)(struct file_lock___70 **, int);
};

struct fasync_struct___70 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___70 *fa_next;
	struct file___70 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___70 {
	const char *name;
	int fs_flags;
	struct dentry___71 * (*mount)(struct file_system_type___70 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___71 *);
	struct module *owner;
	struct file_system_type___70 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___70 {
	struct inode___71 * (*alloc_inode)(struct super_block___71 *);
	void (*destroy_inode)(struct inode___71 *);
	void (*dirty_inode)(struct inode___71 *, int);
	int (*write_inode)(struct inode___71 *, struct writeback_control *);
	int (*drop_inode)(struct inode___71 *);
	void (*evict_inode)(struct inode___71 *);
	void (*put_super)(struct super_block___71 *);
	int (*sync_fs)(struct super_block___71 *, int);
	int (*freeze_fs)(struct super_block___71 *);
	int (*unfreeze_fs)(struct super_block___71 *);
	int (*statfs)(struct dentry___71 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___71 *, int *, char *);
	void (*umount_begin)(struct super_block___71 *);
	int (*show_options)(struct seq_file___51 *, struct dentry___71 *);
	int (*show_devname)(struct seq_file___51 *, struct dentry___71 *);
	int (*show_path)(struct seq_file___51 *, struct dentry___71 *);
	int (*show_stats)(struct seq_file___51 *, struct dentry___71 *);
	ssize_t (*quota_read)(struct super_block___71 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___71 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___71 *);
	int (*bdev_try_to_free_page)(struct super_block___71 *, struct page___70 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___71 *);
	void (*free_cached_objects)(struct super_block___71 *, int);
};

struct xattr_handler___42 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___71 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___71 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___71 *, const char *, const void *, size_t, int, int);
};

struct vm_operations_struct___61;

struct vm_area_struct___74 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___74 *vm_next;
	struct vm_area_struct___74 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___74 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___61 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___70 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___50;

struct seq_file___51 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___71 lock;
	const struct seq_operations___50 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___70 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___70 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___61;

struct memcg_cache_params___61;

struct kmem_cache___61 {
	struct kmem_cache_cpu___61 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___61 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___58;

struct vm_operations_struct___61 {
	void (*open)(struct vm_area_struct___74 *);
	void (*close)(struct vm_area_struct___74 *);
	int (*fault)(struct vm_area_struct___74 *, struct vm_fault___58 *);
	int (*page_mkwrite)(struct vm_area_struct___74 *, struct vm_fault___58 *);
	int (*access)(struct vm_area_struct___74 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___74 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___74 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___74 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___74 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___70 {
	struct task_struct___70 *task;
	struct core_thread___70 *next;
};

struct core_state___70 {
	atomic_t nr_threads;
	struct core_thread___70 dumper;
	struct completion startup;
};

struct autogroup___6;

struct signal_struct___70 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___70 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___70 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___34 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___6 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___71 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___6 {
	struct kref kref;
	struct task_group___6 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___6;

struct cfs_rq___6 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___6 *curr;
	struct sched_entity___6 *next;
	struct sched_entity___6 *last;
	struct sched_entity___6 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___6 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___6 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___6 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___6 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___6 *tg;
};

struct sched_class___6 {
	const struct sched_class___6 *next;
	void (*enqueue_task)(struct rq___6 *, struct task_struct___70 *, int);
	void (*dequeue_task)(struct rq___6 *, struct task_struct___70 *, int);
	void (*yield_task)(struct rq___6 *);
	bool (*yield_to_task)(struct rq___6 *, struct task_struct___70 *, bool);
	void (*check_preempt_curr)(struct rq___6 *, struct task_struct___70 *, int);
	struct task_struct___70 * (*pick_next_task)(struct rq___6 *);
	void (*put_prev_task)(struct rq___6 *, struct task_struct___70 *);
	int (*select_task_rq)(struct task_struct___70 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___70 *, int);
	void (*pre_schedule)(struct rq___6 *, struct task_struct___70 *);
	void (*post_schedule)(struct rq___6 *);
	void (*task_waking)(struct task_struct___70 *);
	void (*task_woken)(struct rq___6 *, struct task_struct___70 *);
	void (*set_cpus_allowed)(struct task_struct___70 *, const struct cpumask *);
	void (*rq_online)(struct rq___6 *);
	void (*rq_offline)(struct rq___6 *);
	void (*set_curr_task)(struct rq___6 *);
	void (*task_tick)(struct rq___6 *, struct task_struct___70 *, int);
	void (*task_fork)(struct task_struct___70 *);
	void (*switched_from)(struct rq___6 *, struct task_struct___70 *);
	void (*switched_to)(struct rq___6 *, struct task_struct___70 *);
	void (*prio_changed)(struct rq___6 *, struct task_struct___70 *, int);
	unsigned int (*get_rr_interval)(struct rq___6 *, struct task_struct___70 *);
	void (*task_move_group)(struct task_struct___70 *, int);
	void (*update_curr)(struct rq___6 *);
};

struct task_group___6 {
	struct cgroup_subsys_state___42 css;
	struct sched_entity___6 **se;
	struct cfs_rq___6 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___6 **rt_se;
	struct rt_rq___6 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___6 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___6 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___42 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___42 *subsys[11];
	struct callback_head callback_head;
};

struct seq_operations___50 {
	void * (*start)(struct seq_file___51 *, loff_t *);
	void (*stop)(struct seq_file___51 *, void *);
	void * (*next)(struct seq_file___51 *, void *, loff_t *);
	int (*show)(struct seq_file___51 *, void *);
};

struct kmem_cache_cpu___61 {
	void **freelist;
	long unsigned int tid;
	struct page___70 *page;
	struct page___70 *partial;
};

struct memcg_cache_params___61 {
	bool is_root_cache;
	union {
		struct kmem_cache___61 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___61 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___58 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___70 *page;
};

struct irq_chip___49 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___49 *);
	void (*irq_shutdown)(struct irq_data___49 *);
	void (*irq_enable)(struct irq_data___49 *);
	void (*irq_disable)(struct irq_data___49 *);
	void (*irq_ack)(struct irq_data___49 *);
	void (*irq_mask)(struct irq_data___49 *);
	void (*irq_mask_ack)(struct irq_data___49 *);
	void (*irq_unmask)(struct irq_data___49 *);
	void (*irq_eoi)(struct irq_data___49 *);
	int (*irq_set_affinity)(struct irq_data___49 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___49 *);
	int (*irq_set_type)(struct irq_data___49 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___49 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___49 *);
	void (*irq_bus_sync_unlock)(struct irq_data___49 *);
	void (*irq_cpu_online)(struct irq_data___49 *);
	void (*irq_cpu_offline)(struct irq_data___49 *);
	void (*irq_suspend)(struct irq_data___49 *);
	void (*irq_resume)(struct irq_data___49 *);
	void (*irq_pm_shutdown)(struct irq_data___49 *);
	void (*irq_print_chip)(struct irq_data___49 *, struct seq_file___51 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___49 *, void *);
	long unsigned int flags;
};

struct cgroupfs_root___42;

struct cgroup___42 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___42 *parent;
	struct dentry___71 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___42 *subsys[11];
	struct cgroupfs_root___42 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___71 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___42 {
	struct super_block___71 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___42 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct rq___6 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___6 cfs;
	struct rt_rq___6 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___70 *curr;
	struct task_struct___70 *idle;
	struct task_struct___70 *stop;
	long unsigned int next_balance;
	struct mm_struct___74 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

struct page___71;

typedef struct page___71 *pgtable_t___71;

struct address_space___71;

struct kmem_cache___62;

struct page___71 {
	long unsigned int flags;
	struct address_space___71 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___71 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___71 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___62 *slab_cache;
		struct page___71 *first_page;
	};
	long: 64;
};

struct task_struct___71;

struct pv_cpu_ops___71 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___32 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___32 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___71 *);
	void (*end_context_switch)(struct task_struct___71 *);
};

struct cfs_rq___7;

struct sched_entity___7 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___7 *parent;
	struct cfs_rq___7 *cfs_rq;
	struct cfs_rq___7 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___7;

struct sched_rt_entity___7 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___7 *back;
	struct sched_rt_entity___7 *parent;
	struct rt_rq___7 *rt_rq;
	struct rt_rq___7 *my_q;
};

struct pid___35;

struct pid_link___35 {
	struct hlist_node node;
	struct pid___35 *pid;
};

struct mutex___72 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___71 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___68 {
	struct page___71 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___7;

struct task_group___7;

struct mm_struct___75;

struct nsproxy___36;

struct signal_struct___71;

struct css_set___43;

struct cpuacct___2;

struct task_struct___71 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___71 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___7 *sched_class;
	struct sched_entity___7 se;
	struct sched_rt_entity___7 rt;
	struct task_group___7 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___75 *mm;
	struct mm_struct___75 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___71 *real_parent;
	struct task_struct___71 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___71 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___35 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___71 = 0,
		VTIME_USER___71 = 1,
		VTIME_SYS___71 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___32 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___36 *nsproxy;
	struct signal_struct___71 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___43 *cgroups;
	struct list_head cg_list;
	struct cpuacct___2 *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___72 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___68 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___75 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___75 *, struct mm_struct___75 *);
	void (*dup_mmap)(struct mm_struct___75 *, struct mm_struct___75 *);
	void (*exit_mmap)(struct mm_struct___75 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___75 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___75 *);
	void (*pgd_free)(struct mm_struct___75 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___75 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___75 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___75 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___75 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___75 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___75 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___75 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___75 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___75 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___75 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___75 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___72 lock;
	void *vdso;
} mm_context_t___72;

struct xol_area___71;

struct uprobes_state___71 {
	struct xol_area___71 *xol_area;
};

struct vm_area_struct___75;

struct file___71;

struct core_state___71;

struct mm_struct___75 {
	struct vm_area_struct___75 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___75 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___75 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___72 context;
	long unsigned int flags;
	struct core_state___71 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___71 *owner;
	struct file___71 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___71 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___33 {
	struct task_struct___71 *task;
	struct exec_domain___18 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___71 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___71 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___62;

struct memcg_cache_params___62;

struct kmem_cache___62 {
	struct kmem_cache_cpu___62 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___62 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___72;

struct address_space_operations___71;

struct address_space___71 {
	struct inode___72 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___72 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___71 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___72;

struct path___71 {
	struct vfsmount *mnt;
	struct dentry___72 *dentry;
};

struct fown_struct___35 {
	rwlock_t lock;
	struct pid___35 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___71;

struct file___71 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___71 f_path;
	struct inode___72 *f_inode;
	const struct file_operations___71 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___35 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___71 *f_mapping;
	struct mutex___72 f_pos_lock;
};

struct vm_operations_struct___62;

struct vm_area_struct___75 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___75 *vm_next;
	struct vm_area_struct___75 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___75 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___62 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___71 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___59;

struct vm_operations_struct___62 {
	void (*open)(struct vm_area_struct___75 *);
	void (*close)(struct vm_area_struct___75 *);
	int (*fault)(struct vm_area_struct___75 *, struct vm_fault___59 *);
	int (*page_mkwrite)(struct vm_area_struct___75 *, struct vm_fault___59 *);
	int (*access)(struct vm_area_struct___75 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___75 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___75 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___75 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___75 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___71 {
	struct task_struct___71 *task;
	struct core_thread___71 *next;
};

struct core_state___71 {
	atomic_t nr_threads;
	struct core_thread___71 dumper;
	struct completion startup;
};

struct irq_data___50;

struct x86_io_apic_ops___50 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___50 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___50;

struct irq_data___50 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___50 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___71 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___71 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___35;

struct upid___35 {
	int nr;
	struct pid_namespace___35 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___35 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___71 *child_reaper;
	struct kmem_cache___62 *pid_cachep;
	unsigned int level;
	struct pid_namespace___35 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___72 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___35 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___35 numbers[1];
};

struct zone___71;

struct lruvec___71 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___71 *zone;
};

struct pglist_data___71;

struct zone___71 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___71 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___71 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___71 {
	struct zone___71 *zone;
	int zone_idx;
};

struct zonelist___71 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___71 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___71 {
	struct zone___71 node_zones[4];
	struct zonelist___71 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___71 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___36 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___35 *pid_ns;
	struct net *net_ns;
};

struct autogroup___7;

struct signal_struct___71 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___71 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___71 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___35 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___35 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___7 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___72 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___7 {
	struct kref kref;
	struct task_group___7 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___7;

struct cfs_rq___7 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___7 *curr;
	struct sched_entity___7 *next;
	struct sched_entity___7 *last;
	struct sched_entity___7 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___7 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___7 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___7 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___7 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___7 *tg;
};

struct sched_class___7 {
	const struct sched_class___7 *next;
	void (*enqueue_task)(struct rq___7 *, struct task_struct___71 *, int);
	void (*dequeue_task)(struct rq___7 *, struct task_struct___71 *, int);
	void (*yield_task)(struct rq___7 *);
	bool (*yield_to_task)(struct rq___7 *, struct task_struct___71 *, bool);
	void (*check_preempt_curr)(struct rq___7 *, struct task_struct___71 *, int);
	struct task_struct___71 * (*pick_next_task)(struct rq___7 *);
	void (*put_prev_task)(struct rq___7 *, struct task_struct___71 *);
	int (*select_task_rq)(struct task_struct___71 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___71 *, int);
	void (*pre_schedule)(struct rq___7 *, struct task_struct___71 *);
	void (*post_schedule)(struct rq___7 *);
	void (*task_waking)(struct task_struct___71 *);
	void (*task_woken)(struct rq___7 *, struct task_struct___71 *);
	void (*set_cpus_allowed)(struct task_struct___71 *, const struct cpumask *);
	void (*rq_online)(struct rq___7 *);
	void (*rq_offline)(struct rq___7 *);
	void (*set_curr_task)(struct rq___7 *);
	void (*task_tick)(struct rq___7 *, struct task_struct___71 *, int);
	void (*task_fork)(struct task_struct___71 *);
	void (*switched_from)(struct rq___7 *, struct task_struct___71 *);
	void (*switched_to)(struct rq___7 *, struct task_struct___71 *);
	void (*prio_changed)(struct rq___7 *, struct task_struct___71 *, int);
	unsigned int (*get_rr_interval)(struct rq___7 *, struct task_struct___71 *);
	void (*task_move_group)(struct task_struct___71 *, int);
	void (*update_curr)(struct rq___7 *);
};

struct cgroup___43;

struct cgroup_subsys_state___43 {
	struct cgroup___43 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_group___7 {
	struct cgroup_subsys_state___43 css;
	struct sched_entity___7 **se;
	struct cfs_rq___7 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___7 **rt_se;
	struct rt_rq___7 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___7 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___7 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___43 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___43 *subsys[11];
	struct callback_head callback_head;
};

struct cpuacct___2 {
	struct cgroup_subsys_state___43 css;
	u64 *cpuusage;
	struct kernel_cpustat *cpustat;
	long unsigned int *nr_uninterruptible;
	long unsigned int *nr_running;
	long unsigned int avenrun[3];
	u64 *nr_switches;
};

struct kmem_cache_cpu___62 {
	void **freelist;
	long unsigned int tid;
	struct page___71 *page;
	struct page___71 *partial;
};

struct memcg_cache_params___62 {
	bool is_root_cache;
	union {
		struct kmem_cache___62 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___62 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___43 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___72 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___72 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___72 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___71;

struct super_block___72;

struct dentry___72 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___72 *d_parent;
	struct qstr d_name;
	struct inode___72 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___71 *d_op;
	struct super_block___72 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___71;

struct file_lock___71;

struct dquot___71;

struct block_device___71;

struct inode___72 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___71 *i_op;
	struct super_block___72 *i_sb;
	struct address_space___71 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___72 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___71 *i_fop;
	struct file_lock___71 *i_flock;
	struct address_space___71 i_data;
	struct dquot___71 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___71 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___71 {
	int (*d_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_hash)(const struct dentry___72 *, struct qstr *);
	int (*d_compare)(const struct dentry___72 *, const struct dentry___72 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___72 *);
	void (*d_release)(struct dentry___72 *);
	void (*d_prune)(struct dentry___72 *);
	void (*d_iput)(struct dentry___72 *, struct inode___72 *);
	char * (*d_dname)(struct dentry___72 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___71 *);
	int (*d_manage)(struct dentry___72 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___71;

struct mem_dqinfo___71 {
	struct quota_format_type___71 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___71;

struct quota_info___71 {
	unsigned int flags;
	struct mutex___72 dqio_mutex;
	struct mutex___72 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___72 *files[2];
	struct mem_dqinfo___71 info[2];
	const struct quota_format_ops___71 *ops[2];
};

struct file_system_type___71;

struct super_operations___71;

struct dquot_operations___71;

struct quotactl_ops___71;

struct super_block___72 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___71 *s_type;
	const struct super_operations___71 *s_op;
	const struct dquot_operations___71 *dq_op;
	const struct quotactl_ops___71 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___72 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___43 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___71 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___71 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___72 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___71 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___71 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___72 *bd_inode;
	struct super_block___72 *bd_super;
	struct mutex___72 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___71 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___72 bd_fsfreeze_mutex;
};

struct iattr___72 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___71 *ia_file;
};

struct dquot___71 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___72 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___72 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___71 {
	int qf_fmt_id;
	const struct quota_format_ops___71 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___71 *qf_next;
};

struct quota_format_ops___71 {
	int (*check_quota_file)(struct super_block___72 *, int);
	int (*read_file_info)(struct super_block___72 *, int);
	int (*write_file_info)(struct super_block___72 *, int);
	int (*free_file_info)(struct super_block___72 *, int);
	int (*read_dqblk)(struct dquot___71 *);
	int (*commit_dqblk)(struct dquot___71 *);
	int (*release_dqblk)(struct dquot___71 *);
};

struct dquot_operations___71 {
	int (*write_dquot)(struct dquot___71 *);
	struct dquot___71 * (*alloc_dquot)(struct super_block___72 *, int);
	void (*destroy_dquot)(struct dquot___71 *);
	int (*acquire_dquot)(struct dquot___71 *);
	int (*release_dquot)(struct dquot___71 *);
	int (*mark_dirty)(struct dquot___71 *);
	int (*write_info)(struct super_block___72 *, int);
	qsize_t * (*get_reserved_space)(struct inode___72 *);
};

struct quotactl_ops___71 {
	int (*quota_on)(struct super_block___72 *, int, int, struct path___71 *);
	int (*quota_on_meta)(struct super_block___72 *, int, int);
	int (*quota_off)(struct super_block___72 *, int);
	int (*quota_sync)(struct super_block___72 *, int);
	int (*get_info)(struct super_block___72 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___72 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___72 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___72 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___72 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___72 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___72 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___72 *, unsigned int);
};

struct address_space_operations___71 {
	int (*writepage)(struct page___71 *, struct writeback_control *);
	int (*readpage)(struct file___71 *, struct page___71 *);
	int (*writepages)(struct address_space___71 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___71 *);
	int (*readpages)(struct file___71 *, struct address_space___71 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___71 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___71 **, void **);
	int (*write_end)(struct file___71 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___71 *, void *);
	sector_t (*bmap)(struct address_space___71 *, sector_t);
	void (*invalidatepage)(struct page___71 *, long unsigned int);
	int (*releasepage)(struct page___71 *, gfp_t);
	void (*freepage)(struct page___71 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___71 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___71 *, struct page___71 *, struct page___71 *, enum migrate_mode);
	int (*launder_page)(struct page___71 *);
	int (*is_partially_uptodate)(struct page___71 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___71 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___71 *, struct page___71 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___71 *, sector_t *);
	void (*swap_deactivate)(struct file___71 *);
	void (*invalidatepage_range)(struct page___71 *, unsigned int, unsigned int);
};

struct inode_operations___71 {
	struct dentry___72 * (*lookup)(struct inode___72 *, struct dentry___72 *, unsigned int);
	void * (*follow_link)(struct dentry___72 *, struct nameidata *);
	int (*permission)(struct inode___72 *, int);
	struct posix_acl * (*get_acl)(struct inode___72 *, int);
	int (*readlink)(struct dentry___72 *, char *, int);
	void (*put_link)(struct dentry___72 *, struct nameidata *, void *);
	int (*create)(struct inode___72 *, struct dentry___72 *, umode_t, bool);
	int (*link)(struct dentry___72 *, struct inode___72 *, struct dentry___72 *);
	int (*unlink)(struct inode___72 *, struct dentry___72 *);
	int (*symlink)(struct inode___72 *, struct dentry___72 *, const char *);
	int (*mkdir)(struct inode___72 *, struct dentry___72 *, umode_t);
	int (*rmdir)(struct inode___72 *, struct dentry___72 *);
	int (*mknod)(struct inode___72 *, struct dentry___72 *, umode_t, dev_t);
	int (*rename)(struct inode___72 *, struct dentry___72 *, struct inode___72 *, struct dentry___72 *);
	int (*setattr)(struct dentry___72 *, struct iattr___72 *);
	int (*getattr)(struct vfsmount *, struct dentry___72 *, struct kstat *);
	int (*setxattr)(struct dentry___72 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___72 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___72 *, char *, size_t);
	int (*removexattr)(struct dentry___72 *, const char *);
	int (*fiemap)(struct inode___72 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___72 *, struct timespec *, int);
	int (*atomic_open)(struct inode___72 *, struct dentry___72 *, struct file___71 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___52;

struct file_operations___71 {
	struct module *owner;
	loff_t (*llseek)(struct file___71 *, loff_t, int);
	ssize_t (*read)(struct file___71 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___71 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___71 *, void *, filldir_t);
	unsigned int (*poll)(struct file___71 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___71 *, struct vm_area_struct___75 *);
	int (*open)(struct inode___72 *, struct file___71 *);
	int (*flush)(struct file___71 *, fl_owner_t);
	int (*release)(struct inode___72 *, struct file___71 *);
	int (*fsync)(struct file___71 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___71 *, int);
	int (*lock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*sendpage)(struct file___71 *, struct page___71 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___71 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___71 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___71 *, long int, struct file_lock___71 **, void **);
		struct {
			int (*setlease)(struct file___71 *, long int, struct file_lock___71 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___71 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___52 *, struct file___71 *);
};

struct fasync_struct___71;

struct file_lock_operations___71;

struct lock_manager_operations___71;

struct file_lock___71 {
	struct file_lock___71 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___35 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___71 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___71 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___71 *fl_ops;
	const struct lock_manager_operations___71 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___71 {
	void (*fl_copy_lock)(struct file_lock___71 *, struct file_lock___71 *);
	void (*fl_release_private)(struct file_lock___71 *);
};

struct lock_manager_operations___71 {
	int (*lm_compare_owner)(struct file_lock___71 *, struct file_lock___71 *);
	long unsigned int (*lm_owner_key)(struct file_lock___71 *);
	void (*lm_notify)(struct file_lock___71 *);
	int (*lm_grant)(struct file_lock___71 *, struct file_lock___71 *, int);
	void (*lm_break)(struct file_lock___71 *);
	int (*lm_change)(struct file_lock___71 **, int);
};

struct fasync_struct___71 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___71 *fa_next;
	struct file___71 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___71 {
	const char *name;
	int fs_flags;
	struct dentry___72 * (*mount)(struct file_system_type___71 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___72 *);
	struct module *owner;
	struct file_system_type___71 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___71 {
	struct inode___72 * (*alloc_inode)(struct super_block___72 *);
	void (*destroy_inode)(struct inode___72 *);
	void (*dirty_inode)(struct inode___72 *, int);
	int (*write_inode)(struct inode___72 *, struct writeback_control *);
	int (*drop_inode)(struct inode___72 *);
	void (*evict_inode)(struct inode___72 *);
	void (*put_super)(struct super_block___72 *);
	int (*sync_fs)(struct super_block___72 *, int);
	int (*freeze_fs)(struct super_block___72 *);
	int (*unfreeze_fs)(struct super_block___72 *);
	int (*statfs)(struct dentry___72 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___72 *, int *, char *);
	void (*umount_begin)(struct super_block___72 *);
	int (*show_options)(struct seq_file___52 *, struct dentry___72 *);
	int (*show_devname)(struct seq_file___52 *, struct dentry___72 *);
	int (*show_path)(struct seq_file___52 *, struct dentry___72 *);
	int (*show_stats)(struct seq_file___52 *, struct dentry___72 *);
	ssize_t (*quota_read)(struct super_block___72 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___72 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___72 *);
	int (*bdev_try_to_free_page)(struct super_block___72 *, struct page___71 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___72 *);
	void (*free_cached_objects)(struct super_block___72 *, int);
};

struct seq_operations___51;

struct seq_file___52 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___72 lock;
	const struct seq_operations___51 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___43;

struct cgroup___43 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___43 *parent;
	struct dentry___72 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___43 *subsys[11];
	struct cgroupfs_root___43 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___72 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

enum {
	CSS_ROOT = 1,
	CSS_ONLINE = 2,
};

struct cgroupfs_root___43 {
	struct super_block___72 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___43 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___14 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___72 *, struct file___71 *);
	ssize_t (*read)(struct cgroup___43 *, struct cftype___14 *, struct file___71 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___43 *, struct cftype___14 *);
	s64 (*read_s64)(struct cgroup___43 *, struct cftype___14 *);
	int (*read_map)(struct cgroup___43 *, struct cftype___14 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___43 *, struct cftype___14 *, struct seq_file___52 *);
	ssize_t (*write)(struct cgroup___43 *, struct cftype___14 *, struct file___71 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___43 *, struct cftype___14 *, u64);
	int (*write_s64)(struct cgroup___43 *, struct cftype___14 *, s64);
	int (*write_string)(struct cgroup___43 *, struct cftype___14 *, const char *);
	int (*trigger)(struct cgroup___43 *, unsigned int);
	int (*release)(struct inode___72 *, struct file___71 *);
	int (*register_event)(struct cgroup___43 *, struct cftype___14 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___43 *, struct cftype___14 *, struct eventfd_ctx *);
};

struct cftype_set___13 {
	struct list_head node;
	struct cftype___14 *cfts;
};

struct task_and_cgroup___13 {
	struct task_struct___71 *task;
	struct cgroup___43 *cgrp;
	struct css_set___43 *cg;
};

struct cgroup_taskset___13 {
	struct task_and_cgroup___13 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___43 *cur_cgrp;
};

struct cgroup_subsys___13 {
	struct cgroup_subsys_state___43 * (*css_alloc)(struct cgroup___43 *);
	int (*css_online)(struct cgroup___43 *);
	void (*css_offline)(struct cgroup___43 *);
	void (*css_free)(struct cgroup___43 *);
	int (*can_attach)(struct cgroup___43 *, struct cgroup_taskset___13 *);
	void (*cancel_attach)(struct cgroup___43 *, struct cgroup_taskset___13 *);
	void (*attach)(struct cgroup___43 *, struct cgroup_taskset___13 *);
	void (*fork)(struct task_struct___71 *);
	void (*exit)(struct cgroup___43 *, struct cgroup___43 *, struct task_struct___71 *);
	void (*bind)(struct cgroup___43 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___43 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___14 *base_cftypes;
	struct cftype_set___13 base_cftset;
	struct module *module;
};

struct seq_operations___51 {
	void * (*start)(struct seq_file___52 *, loff_t *);
	void (*stop)(struct seq_file___52 *, void *);
	void * (*next)(struct seq_file___52 *, void *, loff_t *);
	int (*show)(struct seq_file___52 *, void *);
};

struct irq_chip___50 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___50 *);
	void (*irq_shutdown)(struct irq_data___50 *);
	void (*irq_enable)(struct irq_data___50 *);
	void (*irq_disable)(struct irq_data___50 *);
	void (*irq_ack)(struct irq_data___50 *);
	void (*irq_mask)(struct irq_data___50 *);
	void (*irq_mask_ack)(struct irq_data___50 *);
	void (*irq_unmask)(struct irq_data___50 *);
	void (*irq_eoi)(struct irq_data___50 *);
	int (*irq_set_affinity)(struct irq_data___50 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___50 *);
	int (*irq_set_type)(struct irq_data___50 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___50 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___50 *);
	void (*irq_bus_sync_unlock)(struct irq_data___50 *);
	void (*irq_cpu_online)(struct irq_data___50 *);
	void (*irq_cpu_offline)(struct irq_data___50 *);
	void (*irq_suspend)(struct irq_data___50 *);
	void (*irq_resume)(struct irq_data___50 *);
	void (*irq_pm_shutdown)(struct irq_data___50 *);
	void (*irq_print_chip)(struct irq_data___50 *, struct seq_file___52 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___50 *, void *);
	long unsigned int flags;
};

struct vm_fault___59 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___71 *page;
};

struct rq___7 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___7 cfs;
	struct rt_rq___7 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___71 *curr;
	struct task_struct___71 *idle;
	struct task_struct___71 *stop;
	long unsigned int next_balance;
	struct mm_struct___75 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data___2 hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

enum cpuacct_stat_index {
	CPUACCT_STAT_USER = 0,
	CPUACCT_STAT_SYSTEM = 1,
	CPUACCT_STAT_NSTATS = 2,
};

struct device___55;

struct miscdevice___3 {
	int minor;
	const char *name;
	const struct file_operations___6 *fops;
	struct list_head list;
	struct device___55 *parent;
	struct device___55 *this_device;
	const char *nodename;
	umode_t mode;
};

struct dev_pm_qos___6;

struct dev_pm_info___6 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___6 *qos;
};

struct device_type___55;

struct bus_type___55;

struct device_driver___55;

struct dev_pm_domain___55;

struct class___55;

struct device_rh___55;

struct device___55 {
	struct device___55 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___55 *type;
	struct mutex___9 mutex;
	struct bus_type___55 *bus;
	struct device_driver___55 *driver;
	void *platform_data;
	struct dev_pm_info___6 power;
	struct dev_pm_domain___55 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___55 *class;
	const struct attribute_group___6 **groups;
	void (*release)(struct device___55 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___55 *device_rh;
};

struct dev_pm_ops___55 {
	int (*prepare)(struct device___55 *);
	void (*complete)(struct device___55 *);
	int (*suspend)(struct device___55 *);
	int (*resume)(struct device___55 *);
	int (*freeze)(struct device___55 *);
	int (*thaw)(struct device___55 *);
	int (*poweroff)(struct device___55 *);
	int (*restore)(struct device___55 *);
	int (*suspend_late)(struct device___55 *);
	int (*resume_early)(struct device___55 *);
	int (*freeze_late)(struct device___55 *);
	int (*thaw_early)(struct device___55 *);
	int (*poweroff_late)(struct device___55 *);
	int (*restore_early)(struct device___55 *);
	int (*suspend_noirq)(struct device___55 *);
	int (*resume_noirq)(struct device___55 *);
	int (*freeze_noirq)(struct device___55 *);
	int (*thaw_noirq)(struct device___55 *);
	int (*poweroff_noirq)(struct device___55 *);
	int (*restore_noirq)(struct device___55 *);
	int (*runtime_suspend)(struct device___55 *);
	int (*runtime_resume)(struct device___55 *);
	int (*runtime_idle)(struct device___55 *);
};

struct dev_pm_qos_request___6;

struct dev_pm_qos___6 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___6 *latency_req;
	struct dev_pm_qos_request___6 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___6 *latency_tolerance_req;
};

struct dev_pm_info_rh___55 {
	void (*set_latency_tolerance)(struct device___55 *, s32);
};

struct dev_pm_domain___55 {
	struct dev_pm_ops___55 ops;
};

struct bus_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___55 *, char *);
	ssize_t (*store)(struct bus_type___55 *, const char *, size_t);
};

struct device_attribute___55;

struct driver_attribute___55;

struct bus_type___55 {
	const char *name;
	const char *dev_name;
	struct device___55 *dev_root;
	struct bus_attribute___55 *bus_attrs;
	struct device_attribute___55 *dev_attrs;
	struct driver_attribute___55 *drv_attrs;
	const struct attribute_group___6 **bus_groups;
	const struct attribute_group___6 **dev_groups;
	const struct attribute_group___6 **drv_groups;
	int (*match)(struct device___55 *, struct device_driver___55 *);
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	int (*probe)(struct device___55 *);
	int (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*online)(struct device___55 *);
	int (*offline)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct device___55 *, struct device_attribute___55 *, char *);
	ssize_t (*store)(struct device___55 *, struct device_attribute___55 *, const char *, size_t);
};

struct driver_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___55 *, char *);
	ssize_t (*store)(struct device_driver___55 *, const char *, size_t);
};

struct device_driver___55 {
	const char *name;
	struct bus_type___55 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___55 *);
	int (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	const struct attribute_group___6 **groups;
	const struct dev_pm_ops___55 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___55 {
	const char *name;
	const struct attribute_group___6 **groups;
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
};

struct class_attribute___55;

struct class___55 {
	const char *name;
	struct module *owner;
	struct class_attribute___55 *class_attrs;
	struct device_attribute___55 *dev_attrs;
	const struct attribute_group___6 **dev_groups;
	struct bin_attribute___6 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *);
	void (*class_release)(struct class___55 *);
	void (*dev_release)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
	struct subsys_private *p;
};

struct class_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct class___55 *, struct class_attribute___55 *, char *);
	ssize_t (*store)(struct class___55 *, struct class_attribute___55 *, const char *, size_t);
	const void * (*namespace)(struct class___55 *, const struct class_attribute___55 *);
};

struct device_rh___55 {
	struct dev_pm_info_rh___55 power;
};

enum {
	PM_QOS_RESERVED = 0,
	PM_QOS_CPU_DMA_LATENCY = 1,
	PM_QOS_NETWORK_LATENCY = 2,
	PM_QOS_NETWORK_THROUGHPUT = 3,
	PM_QOS_NUM_CLASSES = 4,
};

struct dev_pm_qos_request___6 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___55 *dev;
};

enum pm_qos_req_action {
	PM_QOS_ADD_REQ = 0,
	PM_QOS_UPDATE_REQ = 1,
	PM_QOS_REMOVE_REQ = 2,
};

struct pm_qos_object {
	struct pm_qos_constraints *constraints;
	struct miscdevice___3 pm_qos_power_miscdev;
	char *name;
};

typedef int suspend_state_t;

struct pm_vt_switch {
	struct list_head head;
	struct device *dev;
	bool required;
};

struct page___72;

typedef struct page___72 *pgtable_t___72;

struct address_space___72;

struct kmem_cache___63;

struct page___72 {
	long unsigned int flags;
	struct address_space___72 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___72 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___72 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___63 *slab_cache;
		struct page___72 *first_page;
	};
	long: 64;
};

struct thread_struct___33;

struct task_struct___72;

struct pv_cpu_ops___72 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___33 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___33 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___72 *);
	void (*end_context_switch)(struct task_struct___72 *);
};

struct perf_event___33;

struct thread_struct___33 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___33 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___36;

struct pid_link___36 {
	struct hlist_node node;
	struct pid___36 *pid;
};

struct mutex___73 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___72 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___69 {
	struct page___72 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___76;

struct nsproxy___37;

struct signal_struct___72;

struct css_set___44;

struct perf_event_context___33;

struct task_struct___72 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___72 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___7 se;
	struct sched_rt_entity___7 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___76 *mm;
	struct mm_struct___76 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___72 *real_parent;
	struct task_struct___72 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___72 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___36 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___72 = 0,
		VTIME_USER___72 = 1,
		VTIME_SYS___72 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___33 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___37 *nsproxy;
	struct signal_struct___72 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___44 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___33 *perf_event_ctxp[2];
	struct mutex___73 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___69 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___76 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___76 *, struct mm_struct___76 *);
	void (*dup_mmap)(struct mm_struct___76 *, struct mm_struct___76 *);
	void (*exit_mmap)(struct mm_struct___76 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___76 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___76 *);
	void (*pgd_free)(struct mm_struct___76 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___76 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___76 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___76 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___76 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___76 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___76 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___76 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___76 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___76 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___76 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___76 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___73 lock;
	void *vdso;
} mm_context_t___73;

struct xol_area___72;

struct uprobes_state___72 {
	struct xol_area___72 *xol_area;
};

struct vm_area_struct___76;

struct file___72;

struct core_state___72;

struct mm_struct___76 {
	struct vm_area_struct___76 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___76 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___76 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___73 context;
	long unsigned int flags;
	struct core_state___72 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___72 *owner;
	struct file___72 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___72 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___41;

struct exec_domain___19 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___41 *module;
	struct exec_domain___19 *next;
};

struct module_kobject___40 {
	struct kobject___3 kobj;
	struct module___41 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___40;

struct ftrace_event_call___25;

struct module___41 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___40 mkobj;
	struct module_attribute___40 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___25 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___72 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___33 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___72 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___72 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___72 *target;
};

typedef void (*perf_overflow_handler_t___33)(struct perf_event___33 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___33;

typedef void (*ftrace_func_t___33)(long unsigned int, long unsigned int, struct ftrace_ops___33 *, struct pt_regs *);

struct ftrace_ops___33 {
	ftrace_func_t___33 func;
	struct ftrace_ops___33 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___73 regex_lock;
};

struct pmu___33;

struct fasync_struct___72;

struct pid_namespace___36;

struct perf_cgroup___33;

struct perf_event___33 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___33 *group_leader;
	struct pmu___33 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___33 hw;
	struct perf_event_context___33 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___73 child_mutex;
	struct list_head child_list;
	struct perf_event___33 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___72 *owner;
	struct mutex___73 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___72 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___33 *);
	struct callback_head callback_head;
	struct pid_namespace___36 *ns;
	u64 id;
	perf_overflow_handler_t___33 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___25 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___33 ftrace_ops;
	struct perf_cgroup___33 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___34 {
	struct task_struct___72 *task;
	struct exec_domain___19 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___51;

struct x86_io_apic_ops___51 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___51 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___51;

struct irq_data___51 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___51 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___56;

struct dev_pm_ops___56 {
	int (*prepare)(struct device___56 *);
	void (*complete)(struct device___56 *);
	int (*suspend)(struct device___56 *);
	int (*resume)(struct device___56 *);
	int (*freeze)(struct device___56 *);
	int (*thaw)(struct device___56 *);
	int (*poweroff)(struct device___56 *);
	int (*restore)(struct device___56 *);
	int (*suspend_late)(struct device___56 *);
	int (*resume_early)(struct device___56 *);
	int (*freeze_late)(struct device___56 *);
	int (*thaw_early)(struct device___56 *);
	int (*poweroff_late)(struct device___56 *);
	int (*restore_early)(struct device___56 *);
	int (*suspend_noirq)(struct device___56 *);
	int (*resume_noirq)(struct device___56 *);
	int (*freeze_noirq)(struct device___56 *);
	int (*thaw_noirq)(struct device___56 *);
	int (*poweroff_noirq)(struct device___56 *);
	int (*restore_noirq)(struct device___56 *);
	int (*runtime_suspend)(struct device___56 *);
	int (*runtime_resume)(struct device___56 *);
	int (*runtime_idle)(struct device___56 *);
};

struct device_type___56;

struct bus_type___56;

struct device_driver___56;

struct dev_pm_domain___56;

struct class___56;

struct attribute_group___49;

struct device_rh___56;

struct device___56 {
	struct device___56 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___56 *type;
	struct mutex___73 mutex;
	struct bus_type___56 *bus;
	struct device_driver___56 *driver;
	void *platform_data;
	struct dev_pm_info___6 power;
	struct dev_pm_domain___56 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___56 *class;
	const struct attribute_group___49 **groups;
	void (*release)(struct device___56 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___56 *device_rh;
};

struct dev_pm_info_rh___56 {
	void (*set_latency_tolerance)(struct device___56 *, s32);
};

struct dev_pm_domain___56 {
	struct dev_pm_ops___56 ops;
};

struct smp_ops___72 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___72 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___72;

struct lruvec___72 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___72 *zone;
};

struct pglist_data___72;

struct zone___72 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___72 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___72 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___72 {
	struct zone___72 *zone;
	int zone_idx;
};

struct zonelist___72 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___72 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___72 {
	struct zone___72 node_zones[4];
	struct zonelist___72 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___72 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___53;

struct irq_chip___51 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___51 *);
	void (*irq_shutdown)(struct irq_data___51 *);
	void (*irq_enable)(struct irq_data___51 *);
	void (*irq_disable)(struct irq_data___51 *);
	void (*irq_ack)(struct irq_data___51 *);
	void (*irq_mask)(struct irq_data___51 *);
	void (*irq_mask_ack)(struct irq_data___51 *);
	void (*irq_unmask)(struct irq_data___51 *);
	void (*irq_eoi)(struct irq_data___51 *);
	int (*irq_set_affinity)(struct irq_data___51 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___51 *);
	int (*irq_set_type)(struct irq_data___51 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___51 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___51 *);
	void (*irq_bus_sync_unlock)(struct irq_data___51 *);
	void (*irq_cpu_online)(struct irq_data___51 *);
	void (*irq_cpu_offline)(struct irq_data___51 *);
	void (*irq_suspend)(struct irq_data___51 *);
	void (*irq_resume)(struct irq_data___51 *);
	void (*irq_pm_shutdown)(struct irq_data___51 *);
	void (*irq_print_chip)(struct irq_data___51 *, struct seq_file___53 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___51 *, void *);
	long unsigned int flags;
};

struct seq_operations___52;

struct seq_file___53 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___73 lock;
	const struct seq_operations___52 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___72 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___72 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___63;

struct memcg_cache_params___63;

struct kmem_cache___63 {
	struct kmem_cache_cpu___63 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___63 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___73;

struct address_space_operations___72;

struct address_space___72 {
	struct inode___73 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___73 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___72 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___73;

struct path___72 {
	struct vfsmount *mnt;
	struct dentry___73 *dentry;
};

struct fown_struct___36 {
	rwlock_t lock;
	struct pid___36 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___72;

struct file___72 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___72 f_path;
	struct inode___73 *f_inode;
	const struct file_operations___72 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___36 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___72 *f_mapping;
	struct mutex___73 f_pos_lock;
};

struct vm_operations_struct___63;

struct vm_area_struct___76 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___76 *vm_next;
	struct vm_area_struct___76 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___76 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___63 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___72 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___60;

struct vm_operations_struct___63 {
	void (*open)(struct vm_area_struct___76 *);
	void (*close)(struct vm_area_struct___76 *);
	int (*fault)(struct vm_area_struct___76 *, struct vm_fault___60 *);
	int (*page_mkwrite)(struct vm_area_struct___76 *, struct vm_fault___60 *);
	int (*access)(struct vm_area_struct___76 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___76 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___76 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___76 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___76 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___72 {
	struct task_struct___72 *task;
	struct core_thread___72 *next;
};

struct core_state___72 {
	atomic_t nr_threads;
	struct core_thread___72 dumper;
	struct completion startup;
};

struct upid___36 {
	int nr;
	struct pid_namespace___36 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___36 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___72 *child_reaper;
	struct kmem_cache___63 *pid_cachep;
	unsigned int level;
	struct pid_namespace___36 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___73 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___36 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___36 numbers[1];
};

struct nsproxy___37 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___36 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___72 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___72 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___72 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___36 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___36 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___73 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___44;

struct css_set___44 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___44 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___33 {
	struct pmu___33 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___73 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___72 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___33 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___49;

struct attribute_group___49 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___49 **bin_attrs;
};

struct bin_attribute___49 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___72 *, struct kobject___3 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___72 *, struct kobject___3 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	int (*mmap)(struct file___72 *, struct kobject___3 *, struct bin_attribute___49 *, struct vm_area_struct___76 *);
};

struct kmem_cache_cpu___63 {
	void **freelist;
	long unsigned int tid;
	struct page___72 *page;
	struct page___72 *partial;
};

struct memcg_cache_params___63 {
	bool is_root_cache;
	union {
		struct kmem_cache___63 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___63 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___44 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___73 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___73 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___73 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___72;

struct super_block___73;

struct dentry___73 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___73 *d_parent;
	struct qstr d_name;
	struct inode___73 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___72 *d_op;
	struct super_block___73 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___72;

struct file_lock___72;

struct dquot___72;

struct block_device___72;

struct inode___73 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___72 *i_op;
	struct super_block___73 *i_sb;
	struct address_space___72 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___73 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___72 *i_fop;
	struct file_lock___72 *i_flock;
	struct address_space___72 i_data;
	struct dquot___72 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___72 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___72 {
	int (*d_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_hash)(const struct dentry___73 *, struct qstr *);
	int (*d_compare)(const struct dentry___73 *, const struct dentry___73 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___73 *);
	void (*d_release)(struct dentry___73 *);
	void (*d_prune)(struct dentry___73 *);
	void (*d_iput)(struct dentry___73 *, struct inode___73 *);
	char * (*d_dname)(struct dentry___73 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___72 *);
	int (*d_manage)(struct dentry___73 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___72;

struct mem_dqinfo___72 {
	struct quota_format_type___72 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___72;

struct quota_info___72 {
	unsigned int flags;
	struct mutex___73 dqio_mutex;
	struct mutex___73 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___73 *files[2];
	struct mem_dqinfo___72 info[2];
	const struct quota_format_ops___72 *ops[2];
};

struct file_system_type___72;

struct super_operations___72;

struct dquot_operations___72;

struct quotactl_ops___72;

struct super_block___73 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___72 *s_type;
	const struct super_operations___72 *s_op;
	const struct dquot_operations___72 *dq_op;
	const struct quotactl_ops___72 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___73 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___44 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___72 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___72 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___73 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___72 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___72 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___73 *bd_inode;
	struct super_block___73 *bd_super;
	struct mutex___73 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___72 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___73 bd_fsfreeze_mutex;
};

struct cgroup___44;

struct cgroup_subsys_state___44 {
	struct cgroup___44 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___73 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___72 *ia_file;
};

struct dquot___72 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___73 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___73 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___72 {
	int qf_fmt_id;
	const struct quota_format_ops___72 *qf_ops;
	struct module___41 *qf_owner;
	struct quota_format_type___72 *qf_next;
};

struct quota_format_ops___72 {
	int (*check_quota_file)(struct super_block___73 *, int);
	int (*read_file_info)(struct super_block___73 *, int);
	int (*write_file_info)(struct super_block___73 *, int);
	int (*free_file_info)(struct super_block___73 *, int);
	int (*read_dqblk)(struct dquot___72 *);
	int (*commit_dqblk)(struct dquot___72 *);
	int (*release_dqblk)(struct dquot___72 *);
};

struct dquot_operations___72 {
	int (*write_dquot)(struct dquot___72 *);
	struct dquot___72 * (*alloc_dquot)(struct super_block___73 *, int);
	void (*destroy_dquot)(struct dquot___72 *);
	int (*acquire_dquot)(struct dquot___72 *);
	int (*release_dquot)(struct dquot___72 *);
	int (*mark_dirty)(struct dquot___72 *);
	int (*write_info)(struct super_block___73 *, int);
	qsize_t * (*get_reserved_space)(struct inode___73 *);
};

struct quotactl_ops___72 {
	int (*quota_on)(struct super_block___73 *, int, int, struct path___72 *);
	int (*quota_on_meta)(struct super_block___73 *, int, int);
	int (*quota_off)(struct super_block___73 *, int);
	int (*quota_sync)(struct super_block___73 *, int);
	int (*get_info)(struct super_block___73 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___73 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___73 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___73 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___73 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___73 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___73 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___73 *, unsigned int);
};

struct swap_info_struct___12;

struct address_space_operations___72 {
	int (*writepage)(struct page___72 *, struct writeback_control *);
	int (*readpage)(struct file___72 *, struct page___72 *);
	int (*writepages)(struct address_space___72 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___72 *);
	int (*readpages)(struct file___72 *, struct address_space___72 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___72 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___72 **, void **);
	int (*write_end)(struct file___72 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___72 *, void *);
	sector_t (*bmap)(struct address_space___72 *, sector_t);
	void (*invalidatepage)(struct page___72 *, long unsigned int);
	int (*releasepage)(struct page___72 *, gfp_t);
	void (*freepage)(struct page___72 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___72 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___72 *, struct page___72 *, struct page___72 *, enum migrate_mode);
	int (*launder_page)(struct page___72 *);
	int (*is_partially_uptodate)(struct page___72 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___72 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___72 *, struct page___72 *);
	int (*swap_activate)(struct swap_info_struct___12 *, struct file___72 *, sector_t *);
	void (*swap_deactivate)(struct file___72 *);
	void (*invalidatepage_range)(struct page___72 *, unsigned int, unsigned int);
};

struct swap_info_struct___12 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___72 *bdev;
	struct file___72 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___72 {
	struct dentry___73 * (*lookup)(struct inode___73 *, struct dentry___73 *, unsigned int);
	void * (*follow_link)(struct dentry___73 *, struct nameidata *);
	int (*permission)(struct inode___73 *, int);
	struct posix_acl * (*get_acl)(struct inode___73 *, int);
	int (*readlink)(struct dentry___73 *, char *, int);
	void (*put_link)(struct dentry___73 *, struct nameidata *, void *);
	int (*create)(struct inode___73 *, struct dentry___73 *, umode_t, bool);
	int (*link)(struct dentry___73 *, struct inode___73 *, struct dentry___73 *);
	int (*unlink)(struct inode___73 *, struct dentry___73 *);
	int (*symlink)(struct inode___73 *, struct dentry___73 *, const char *);
	int (*mkdir)(struct inode___73 *, struct dentry___73 *, umode_t);
	int (*rmdir)(struct inode___73 *, struct dentry___73 *);
	int (*mknod)(struct inode___73 *, struct dentry___73 *, umode_t, dev_t);
	int (*rename)(struct inode___73 *, struct dentry___73 *, struct inode___73 *, struct dentry___73 *);
	int (*setattr)(struct dentry___73 *, struct iattr___73 *);
	int (*getattr)(struct vfsmount *, struct dentry___73 *, struct kstat *);
	int (*setxattr)(struct dentry___73 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___73 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___73 *, char *, size_t);
	int (*removexattr)(struct dentry___73 *, const char *);
	int (*fiemap)(struct inode___73 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___73 *, struct timespec *, int);
	int (*atomic_open)(struct inode___73 *, struct dentry___73 *, struct file___72 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___42;

struct file_operations___72 {
	struct module___41 *owner;
	loff_t (*llseek)(struct file___72 *, loff_t, int);
	ssize_t (*read)(struct file___72 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___72 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___72 *, void *, filldir_t);
	unsigned int (*poll)(struct file___72 *, struct poll_table_struct___42 *);
	long int (*unlocked_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___72 *, struct vm_area_struct___76 *);
	int (*open)(struct inode___73 *, struct file___72 *);
	int (*flush)(struct file___72 *, fl_owner_t);
	int (*release)(struct inode___73 *, struct file___72 *);
	int (*fsync)(struct file___72 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___72 *, int);
	int (*lock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*sendpage)(struct file___72 *, struct page___72 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___72 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___72 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___72 *, long int, struct file_lock___72 **, void **);
		struct {
			int (*setlease)(struct file___72 *, long int, struct file_lock___72 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___72 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___53 *, struct file___72 *);
};

struct file_lock_operations___72;

struct lock_manager_operations___72;

struct file_lock___72 {
	struct file_lock___72 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___36 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___72 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___72 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___72 *fl_ops;
	const struct lock_manager_operations___72 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___72 {
	void (*fl_copy_lock)(struct file_lock___72 *, struct file_lock___72 *);
	void (*fl_release_private)(struct file_lock___72 *);
};

struct lock_manager_operations___72 {
	int (*lm_compare_owner)(struct file_lock___72 *, struct file_lock___72 *);
	long unsigned int (*lm_owner_key)(struct file_lock___72 *);
	void (*lm_notify)(struct file_lock___72 *);
	int (*lm_grant)(struct file_lock___72 *, struct file_lock___72 *, int);
	void (*lm_break)(struct file_lock___72 *);
	int (*lm_change)(struct file_lock___72 **, int);
};

struct fasync_struct___72 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___72 *fa_next;
	struct file___72 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___72 {
	const char *name;
	int fs_flags;
	struct dentry___73 * (*mount)(struct file_system_type___72 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___73 *);
	struct module___41 *owner;
	struct file_system_type___72 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___72 {
	struct inode___73 * (*alloc_inode)(struct super_block___73 *);
	void (*destroy_inode)(struct inode___73 *);
	void (*dirty_inode)(struct inode___73 *, int);
	int (*write_inode)(struct inode___73 *, struct writeback_control *);
	int (*drop_inode)(struct inode___73 *);
	void (*evict_inode)(struct inode___73 *);
	void (*put_super)(struct super_block___73 *);
	int (*sync_fs)(struct super_block___73 *, int);
	int (*freeze_fs)(struct super_block___73 *);
	int (*unfreeze_fs)(struct super_block___73 *);
	int (*statfs)(struct dentry___73 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___73 *, int *, char *);
	void (*umount_begin)(struct super_block___73 *);
	int (*show_options)(struct seq_file___53 *, struct dentry___73 *);
	int (*show_devname)(struct seq_file___53 *, struct dentry___73 *);
	int (*show_path)(struct seq_file___53 *, struct dentry___73 *);
	int (*show_stats)(struct seq_file___53 *, struct dentry___73 *);
	ssize_t (*quota_read)(struct super_block___73 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___73 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___73 *);
	int (*bdev_try_to_free_page)(struct super_block___73 *, struct page___72 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___73 *);
	void (*free_cached_objects)(struct super_block___73 *, int);
};

typedef void (*poll_queue_proc___42)(struct file___72 *, wait_queue_head_t *, struct poll_table_struct___42 *);

struct poll_table_struct___42 {
	poll_queue_proc___42 _qproc;
	long unsigned int _key;
};

struct cgroupfs_root___44;

struct cgroup___44 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___44 *parent;
	struct dentry___73 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___44 *subsys[11];
	struct cgroupfs_root___44 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___73 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___44 {
	struct super_block___73 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___44 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___15 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___73 *, struct file___72 *);
	ssize_t (*read)(struct cgroup___44 *, struct cftype___15 *, struct file___72 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___44 *, struct cftype___15 *);
	s64 (*read_s64)(struct cgroup___44 *, struct cftype___15 *);
	int (*read_map)(struct cgroup___44 *, struct cftype___15 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___44 *, struct cftype___15 *, struct seq_file___53 *);
	ssize_t (*write)(struct cgroup___44 *, struct cftype___15 *, struct file___72 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___44 *, struct cftype___15 *, u64);
	int (*write_s64)(struct cgroup___44 *, struct cftype___15 *, s64);
	int (*write_string)(struct cgroup___44 *, struct cftype___15 *, const char *);
	int (*trigger)(struct cgroup___44 *, unsigned int);
	int (*release)(struct inode___73 *, struct file___72 *);
	int (*register_event)(struct cgroup___44 *, struct cftype___15 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___44 *, struct cftype___15 *, struct eventfd_ctx *);
};

struct cftype_set___14 {
	struct list_head node;
	struct cftype___15 *cfts;
};

struct task_and_cgroup___14 {
	struct task_struct___72 *task;
	struct cgroup___44 *cgrp;
	struct css_set___44 *cg;
};

struct cgroup_taskset___14 {
	struct task_and_cgroup___14 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___44 *cur_cgrp;
};

struct cgroup_subsys___14 {
	struct cgroup_subsys_state___44 * (*css_alloc)(struct cgroup___44 *);
	int (*css_online)(struct cgroup___44 *);
	void (*css_offline)(struct cgroup___44 *);
	void (*css_free)(struct cgroup___44 *);
	int (*can_attach)(struct cgroup___44 *, struct cgroup_taskset___14 *);
	void (*cancel_attach)(struct cgroup___44 *, struct cgroup_taskset___14 *);
	void (*attach)(struct cgroup___44 *, struct cgroup_taskset___14 *);
	void (*fork)(struct task_struct___72 *);
	void (*exit)(struct cgroup___44 *, struct cgroup___44 *, struct task_struct___72 *);
	void (*bind)(struct cgroup___44 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___44 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___15 *base_cftypes;
	struct cftype_set___14 base_cftset;
	struct module___41 *module;
};

struct bus_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___56 *, char *);
	ssize_t (*store)(struct bus_type___56 *, const char *, size_t);
};

struct device_attribute___56;

struct driver_attribute___56;

struct bus_type___56 {
	const char *name;
	const char *dev_name;
	struct device___56 *dev_root;
	struct bus_attribute___56 *bus_attrs;
	struct device_attribute___56 *dev_attrs;
	struct driver_attribute___56 *drv_attrs;
	const struct attribute_group___49 **bus_groups;
	const struct attribute_group___49 **dev_groups;
	const struct attribute_group___49 **drv_groups;
	int (*match)(struct device___56 *, struct device_driver___56 *);
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	int (*probe)(struct device___56 *);
	int (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*online)(struct device___56 *);
	int (*offline)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct device___56 *, struct device_attribute___56 *, char *);
	ssize_t (*store)(struct device___56 *, struct device_attribute___56 *, const char *, size_t);
};

struct driver_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___56 *, char *);
	ssize_t (*store)(struct device_driver___56 *, const char *, size_t);
};

struct device_driver___56 {
	const char *name;
	struct bus_type___56 *bus;
	struct module___41 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___56 *);
	int (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	const struct attribute_group___49 **groups;
	const struct dev_pm_ops___56 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___56 {
	const char *name;
	const struct attribute_group___49 **groups;
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
};

struct class_attribute___56;

struct class___56 {
	const char *name;
	struct module___41 *owner;
	struct class_attribute___56 *class_attrs;
	struct device_attribute___56 *dev_attrs;
	const struct attribute_group___49 **dev_groups;
	struct bin_attribute___49 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *);
	void (*class_release)(struct class___56 *);
	void (*dev_release)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
	struct subsys_private *p;
};

struct class_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct class___56 *, struct class_attribute___56 *, char *);
	ssize_t (*store)(struct class___56 *, struct class_attribute___56 *, const char *, size_t);
	const void * (*namespace)(struct class___56 *, const struct class_attribute___56 *);
};

struct device_rh___56 {
	struct dev_pm_info_rh___56 power;
};

struct vm_fault___60 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___72 *page;
};

struct module_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___40 *, struct module_kobject___40 *, char *);
	ssize_t (*store)(struct module_attribute___40 *, struct module_kobject___40 *, const char *, size_t);
	void (*setup)(struct module___41 *, const char *);
	int (*test)(struct module___41 *);
	void (*free)(struct module___41 *);
};

struct trace_event_functions___25;

struct trace_event___25 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___25 *funcs;
};

struct ftrace_event_class___25;

struct ftrace_event_call___25 {
	struct list_head list;
	struct ftrace_event_class___25 *class;
	char *name;
	struct trace_event___25 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct seq_operations___52 {
	void * (*start)(struct seq_file___53 *, loff_t *);
	void (*stop)(struct seq_file___53 *, void *);
	void * (*next)(struct seq_file___53 *, void *, loff_t *);
	int (*show)(struct seq_file___53 *, void *);
};

struct perf_cpu_context___33;

struct pmu___33 {
	struct list_head entry;
	struct device___56 *dev;
	const struct attribute_group___49 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___33 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___33 *);
	void (*pmu_disable)(struct pmu___33 *);
	int (*event_init)(struct perf_event___33 *);
	int (*add)(struct perf_event___33 *, int);
	void (*del)(struct perf_event___33 *, int);
	void (*start)(struct perf_event___33 *, int);
	void (*stop)(struct perf_event___33 *, int);
	void (*read)(struct perf_event___33 *);
	void (*start_txn)(struct pmu___33 *);
	int (*commit_txn)(struct pmu___33 *);
	void (*cancel_txn)(struct pmu___33 *);
	int (*event_idx)(struct perf_event___33 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___41 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___33 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___33 *);
};

struct perf_cpu_context___33 {
	struct perf_event_context___33 ctx;
	struct perf_event_context___33 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___33 *unique_pmu;
	struct perf_cgroup___33 *cgrp;
};

struct perf_cgroup___33 {
	struct cgroup_subsys_state___44 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___25 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___73 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___25)(struct trace_iterator___25 *, int, struct trace_event___25 *);

struct trace_event_functions___25 {
	trace_print_func___25 trace;
	trace_print_func___25 raw;
	trace_print_func___25 hex;
	trace_print_func___25 binary;
};

struct ftrace_event_class___25 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___25 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___25 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___25 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___25 *);
};

struct page___73;

typedef struct page___73 *pgtable_t___73;

struct address_space___73;

struct kmem_cache___64;

struct page___73 {
	long unsigned int flags;
	struct address_space___73 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___73 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___73 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___64 *slab_cache;
		struct page___73 *first_page;
	};
	long: 64;
};

struct thread_struct___34;

struct task_struct___73;

struct pv_cpu_ops___73 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___34 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___34 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___73 *);
	void (*end_context_switch)(struct task_struct___73 *);
};

struct perf_event___34;

struct thread_struct___34 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___34 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___37;

struct pid_link___37 {
	struct hlist_node node;
	struct pid___37 *pid;
};

struct mutex___74 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___73 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___70 {
	struct page___73 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___77;

struct nsproxy___38;

struct signal_struct___73;

struct css_set___45;

struct perf_event_context___34;

struct task_struct___73 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___73 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___7 se;
	struct sched_rt_entity___7 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___77 *mm;
	struct mm_struct___77 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___73 *real_parent;
	struct task_struct___73 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___73 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___37 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___73 = 0,
		VTIME_USER___73 = 1,
		VTIME_SYS___73 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___34 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___38 *nsproxy;
	struct signal_struct___73 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___45 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___34 *perf_event_ctxp[2];
	struct mutex___74 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___70 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___77 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___77 *, struct mm_struct___77 *);
	void (*dup_mmap)(struct mm_struct___77 *, struct mm_struct___77 *);
	void (*exit_mmap)(struct mm_struct___77 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___77 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___77 *);
	void (*pgd_free)(struct mm_struct___77 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___77 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___77 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___77 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___77 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___77 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___77 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___77 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___77 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___77 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___77 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___77 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___74 lock;
	void *vdso;
} mm_context_t___74;

struct xol_area___73;

struct uprobes_state___73 {
	struct xol_area___73 *xol_area;
};

struct vm_area_struct___77;

struct file___73;

struct core_state___73;

struct mm_struct___77 {
	struct vm_area_struct___77 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___77 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___77 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___74 context;
	long unsigned int flags;
	struct core_state___73 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___73 *owner;
	struct file___73 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___73 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___34 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___73 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___73 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___73 *target;
};

typedef void (*perf_overflow_handler_t___34)(struct perf_event___34 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___34;

typedef void (*ftrace_func_t___34)(long unsigned int, long unsigned int, struct ftrace_ops___34 *, struct pt_regs *);

struct ftrace_ops___34 {
	ftrace_func_t___34 func;
	struct ftrace_ops___34 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___74 regex_lock;
};

struct pmu___34;

struct fasync_struct___73;

struct pid_namespace___37;

struct ftrace_event_call___26;

struct perf_cgroup___34;

struct perf_event___34 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___34 *group_leader;
	struct pmu___34 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___34 hw;
	struct perf_event_context___34 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___74 child_mutex;
	struct list_head child_list;
	struct perf_event___34 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___73 *owner;
	struct mutex___74 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___73 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___34 *);
	struct callback_head callback_head;
	struct pid_namespace___37 *ns;
	u64 id;
	perf_overflow_handler_t___34 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___26 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___34 ftrace_ops;
	struct perf_cgroup___34 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct bin_attribute___50;

struct attribute_group___50 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___50 **bin_attrs;
};

struct bin_attribute___50 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___73 *, struct kobject___3 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___73 *, struct kobject___3 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	int (*mmap)(struct file___73 *, struct kobject___3 *, struct bin_attribute___50 *, struct vm_area_struct___77 *);
};

struct dentry___74;

struct path___73 {
	struct vfsmount *mnt;
	struct dentry___74 *dentry;
};

struct fown_struct___37 {
	rwlock_t lock;
	struct pid___37 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___74;

struct file_operations___73;

struct file___73 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___73 f_path;
	struct inode___74 *f_inode;
	const struct file_operations___73 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___37 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___73 *f_mapping;
	struct mutex___74 f_pos_lock;
};

struct vm_operations_struct___64;

struct vm_area_struct___77 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___77 *vm_next;
	struct vm_area_struct___77 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___77 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___64 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___73 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___57;

struct dev_pm_ops___57 {
	int (*prepare)(struct device___57 *);
	void (*complete)(struct device___57 *);
	int (*suspend)(struct device___57 *);
	int (*resume)(struct device___57 *);
	int (*freeze)(struct device___57 *);
	int (*thaw)(struct device___57 *);
	int (*poweroff)(struct device___57 *);
	int (*restore)(struct device___57 *);
	int (*suspend_late)(struct device___57 *);
	int (*resume_early)(struct device___57 *);
	int (*freeze_late)(struct device___57 *);
	int (*thaw_early)(struct device___57 *);
	int (*poweroff_late)(struct device___57 *);
	int (*restore_early)(struct device___57 *);
	int (*suspend_noirq)(struct device___57 *);
	int (*resume_noirq)(struct device___57 *);
	int (*freeze_noirq)(struct device___57 *);
	int (*thaw_noirq)(struct device___57 *);
	int (*poweroff_noirq)(struct device___57 *);
	int (*restore_noirq)(struct device___57 *);
	int (*runtime_suspend)(struct device___57 *);
	int (*runtime_resume)(struct device___57 *);
	int (*runtime_idle)(struct device___57 *);
};

struct dev_pm_qos___7;

struct dev_pm_info___7 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___7 *qos;
};

struct device_type___57;

struct bus_type___57;

struct device_driver___57;

struct dev_pm_domain___57;

struct class___57;

struct device_rh___57;

struct device___57 {
	struct device___57 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___57 *type;
	struct mutex___74 mutex;
	struct bus_type___57 *bus;
	struct device_driver___57 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___57 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___57 *class;
	const struct attribute_group___50 **groups;
	void (*release)(struct device___57 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___57 *device_rh;
};

struct dev_pm_qos_request___7;

struct dev_pm_qos___7 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___7 *latency_req;
	struct dev_pm_qos_request___7 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___7 *latency_tolerance_req;
};

struct dev_pm_info_rh___57 {
	void (*set_latency_tolerance)(struct device___57 *, s32);
};

struct dev_pm_domain___57 {
	struct dev_pm_ops___57 ops;
};

struct zone___73;

struct lruvec___73 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___73 *zone;
};

struct pglist_data___73;

struct zone___73 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___73 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___73 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___73 {
	struct zone___73 *zone;
	int zone_idx;
};

struct zonelist___73 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___73 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___73 {
	struct zone___73 node_zones[4];
	struct zonelist___73 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___73 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___52;

struct x86_io_apic_ops___52 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___52 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___52;

struct irq_data___52 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___52 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___73 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___73 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___57 *, char *);
	ssize_t (*store)(struct bus_type___57 *, const char *, size_t);
};

struct device_attribute___57;

struct driver_attribute___57;

struct bus_type___57 {
	const char *name;
	const char *dev_name;
	struct device___57 *dev_root;
	struct bus_attribute___57 *bus_attrs;
	struct device_attribute___57 *dev_attrs;
	struct driver_attribute___57 *drv_attrs;
	const struct attribute_group___50 **bus_groups;
	const struct attribute_group___50 **dev_groups;
	const struct attribute_group___50 **drv_groups;
	int (*match)(struct device___57 *, struct device_driver___57 *);
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	int (*probe)(struct device___57 *);
	int (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*online)(struct device___57 *);
	int (*offline)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct device___57 *, struct device_attribute___57 *, char *);
	ssize_t (*store)(struct device___57 *, struct device_attribute___57 *, const char *, size_t);
};

struct driver_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___57 *, char *);
	ssize_t (*store)(struct device_driver___57 *, const char *, size_t);
};

struct device_driver___57 {
	const char *name;
	struct bus_type___57 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___57 *);
	int (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	const struct attribute_group___50 **groups;
	const struct dev_pm_ops___57 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___57 {
	const char *name;
	const struct attribute_group___50 **groups;
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
};

struct class_attribute___57;

struct class___57 {
	const char *name;
	struct module *owner;
	struct class_attribute___57 *class_attrs;
	struct device_attribute___57 *dev_attrs;
	const struct attribute_group___50 **dev_groups;
	struct bin_attribute___50 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *);
	void (*class_release)(struct class___57 *);
	void (*dev_release)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
	struct subsys_private *p;
};

struct class_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct class___57 *, struct class_attribute___57 *, char *);
	ssize_t (*store)(struct class___57 *, struct class_attribute___57 *, const char *, size_t);
	const void * (*namespace)(struct class___57 *, const struct class_attribute___57 *);
};

struct device_rh___57 {
	struct dev_pm_info_rh___57 power;
};

struct super_block___74;

struct dquot___73 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___74 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___74 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___73;

struct mem_dqinfo___73 {
	struct quota_format_type___73 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___73;

struct quota_info___73 {
	unsigned int flags;
	struct mutex___74 dqio_mutex;
	struct mutex___74 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___74 *files[2];
	struct mem_dqinfo___73 info[2];
	const struct quota_format_ops___73 *ops[2];
};

struct file_system_type___73;

struct super_operations___73;

struct dquot_operations___73;

struct quotactl_ops___73;

struct xattr_handler___45;

struct block_device___73;

struct dentry_operations___73;

struct super_block___74 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___73 *s_type;
	const struct super_operations___73 *s_op;
	const struct dquot_operations___73 *dq_op;
	const struct quotactl_ops___73 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___74 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___45 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___73 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___73 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___74 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___73 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___73 {
	int qf_fmt_id;
	const struct quota_format_ops___73 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___73 *qf_next;
};

struct quota_format_ops___73 {
	int (*check_quota_file)(struct super_block___74 *, int);
	int (*read_file_info)(struct super_block___74 *, int);
	int (*write_file_info)(struct super_block___74 *, int);
	int (*free_file_info)(struct super_block___74 *, int);
	int (*read_dqblk)(struct dquot___73 *);
	int (*commit_dqblk)(struct dquot___73 *);
	int (*release_dqblk)(struct dquot___73 *);
};

struct dquot_operations___73 {
	int (*write_dquot)(struct dquot___73 *);
	struct dquot___73 * (*alloc_dquot)(struct super_block___74 *, int);
	void (*destroy_dquot)(struct dquot___73 *);
	int (*acquire_dquot)(struct dquot___73 *);
	int (*release_dquot)(struct dquot___73 *);
	int (*mark_dirty)(struct dquot___73 *);
	int (*write_info)(struct super_block___74 *, int);
	qsize_t * (*get_reserved_space)(struct inode___74 *);
};

struct address_space_operations___73;

struct address_space___73 {
	struct inode___74 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___74 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___73 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___73;

struct file_lock___73;

struct inode___74 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___73 *i_op;
	struct super_block___74 *i_sb;
	struct address_space___73 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___74 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___73 *i_fop;
	struct file_lock___73 *i_flock;
	struct address_space___73 i_data;
	struct dquot___73 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___73 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___73 {
	int (*quota_on)(struct super_block___74 *, int, int, struct path___73 *);
	int (*quota_on_meta)(struct super_block___74 *, int, int);
	int (*quota_off)(struct super_block___74 *, int);
	int (*quota_sync)(struct super_block___74 *, int);
	int (*get_info)(struct super_block___74 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___74 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___74 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___74 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___74 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___74 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___74 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___74 *, unsigned int);
};

struct nsproxy___38 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___37 *pid_ns;
	struct net *net_ns;
};

struct xol_area___73 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___73 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___64;

struct memcg_cache_params___64;

struct kmem_cache___64 {
	struct kmem_cache_cpu___64 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___64 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___61;

struct vm_operations_struct___64 {
	void (*open)(struct vm_area_struct___77 *);
	void (*close)(struct vm_area_struct___77 *);
	int (*fault)(struct vm_area_struct___77 *, struct vm_fault___61 *);
	int (*page_mkwrite)(struct vm_area_struct___77 *, struct vm_fault___61 *);
	int (*access)(struct vm_area_struct___77 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___77 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___77 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___77 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___77 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___73 {
	struct task_struct___73 *task;
	struct core_thread___73 *next;
};

struct core_state___73 {
	atomic_t nr_threads;
	struct core_thread___73 dumper;
	struct completion startup;
};

struct vm_fault___61 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___73 *page;
};

struct seq_operations___53;

struct seq_file___54 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___74 lock;
	const struct seq_operations___53 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___53 {
	void * (*start)(struct seq_file___54 *, loff_t *);
	void (*stop)(struct seq_file___54 *, void *);
	void * (*next)(struct seq_file___54 *, void *, loff_t *);
	int (*show)(struct seq_file___54 *, void *);
};

struct dentry___74 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___74 *d_parent;
	struct qstr d_name;
	struct inode___74 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___73 *d_op;
	struct super_block___74 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___73 {
	int (*d_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_hash)(const struct dentry___74 *, struct qstr *);
	int (*d_compare)(const struct dentry___74 *, const struct dentry___74 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___74 *);
	void (*d_release)(struct dentry___74 *);
	void (*d_prune)(struct dentry___74 *);
	void (*d_iput)(struct dentry___74 *, struct inode___74 *);
	char * (*d_dname)(struct dentry___74 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___73 *);
	int (*d_manage)(struct dentry___74 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___37 {
	int nr;
	struct pid_namespace___37 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___37 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___73 *child_reaper;
	struct kmem_cache___64 *pid_cachep;
	unsigned int level;
	struct pid_namespace___37 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___74 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___37 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___37 numbers[1];
};

struct block_device___73 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___74 *bd_inode;
	struct super_block___74 *bd_super;
	struct mutex___74 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___73 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___74 bd_fsfreeze_mutex;
};

struct cgroup___45;

struct cgroup_subsys_state___45 {
	struct cgroup___45 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___74 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___73 *ia_file;
};

struct swap_info_struct___13;

struct address_space_operations___73 {
	int (*writepage)(struct page___73 *, struct writeback_control *);
	int (*readpage)(struct file___73 *, struct page___73 *);
	int (*writepages)(struct address_space___73 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___73 *);
	int (*readpages)(struct file___73 *, struct address_space___73 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___73 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___73 **, void **);
	int (*write_end)(struct file___73 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___73 *, void *);
	sector_t (*bmap)(struct address_space___73 *, sector_t);
	void (*invalidatepage)(struct page___73 *, long unsigned int);
	int (*releasepage)(struct page___73 *, gfp_t);
	void (*freepage)(struct page___73 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___73 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___73 *, struct page___73 *, struct page___73 *, enum migrate_mode);
	int (*launder_page)(struct page___73 *);
	int (*is_partially_uptodate)(struct page___73 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___73 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___73 *, struct page___73 *);
	int (*swap_activate)(struct swap_info_struct___13 *, struct file___73 *, sector_t *);
	void (*swap_deactivate)(struct file___73 *);
	void (*invalidatepage_range)(struct page___73 *, unsigned int, unsigned int);
};

struct swap_info_struct___13 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___73 *bdev;
	struct file___73 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___73 {
	struct dentry___74 * (*lookup)(struct inode___74 *, struct dentry___74 *, unsigned int);
	void * (*follow_link)(struct dentry___74 *, struct nameidata *);
	int (*permission)(struct inode___74 *, int);
	struct posix_acl * (*get_acl)(struct inode___74 *, int);
	int (*readlink)(struct dentry___74 *, char *, int);
	void (*put_link)(struct dentry___74 *, struct nameidata *, void *);
	int (*create)(struct inode___74 *, struct dentry___74 *, umode_t, bool);
	int (*link)(struct dentry___74 *, struct inode___74 *, struct dentry___74 *);
	int (*unlink)(struct inode___74 *, struct dentry___74 *);
	int (*symlink)(struct inode___74 *, struct dentry___74 *, const char *);
	int (*mkdir)(struct inode___74 *, struct dentry___74 *, umode_t);
	int (*rmdir)(struct inode___74 *, struct dentry___74 *);
	int (*mknod)(struct inode___74 *, struct dentry___74 *, umode_t, dev_t);
	int (*rename)(struct inode___74 *, struct dentry___74 *, struct inode___74 *, struct dentry___74 *);
	int (*setattr)(struct dentry___74 *, struct iattr___74 *);
	int (*getattr)(struct vfsmount *, struct dentry___74 *, struct kstat *);
	int (*setxattr)(struct dentry___74 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___74 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___74 *, char *, size_t);
	int (*removexattr)(struct dentry___74 *, const char *);
	int (*fiemap)(struct inode___74 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___74 *, struct timespec *, int);
	int (*atomic_open)(struct inode___74 *, struct dentry___74 *, struct file___73 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___43;

struct file_operations___73 {
	struct module *owner;
	loff_t (*llseek)(struct file___73 *, loff_t, int);
	ssize_t (*read)(struct file___73 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___73 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___73 *, void *, filldir_t);
	unsigned int (*poll)(struct file___73 *, struct poll_table_struct___43 *);
	long int (*unlocked_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___73 *, struct vm_area_struct___77 *);
	int (*open)(struct inode___74 *, struct file___73 *);
	int (*flush)(struct file___73 *, fl_owner_t);
	int (*release)(struct inode___74 *, struct file___73 *);
	int (*fsync)(struct file___73 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___73 *, int);
	int (*lock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*sendpage)(struct file___73 *, struct page___73 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___73 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___73 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___73 *, long int, struct file_lock___73 **, void **);
		struct {
			int (*setlease)(struct file___73 *, long int, struct file_lock___73 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___73 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___54 *, struct file___73 *);
};

struct file_lock_operations___73;

struct lock_manager_operations___73;

struct file_lock___73 {
	struct file_lock___73 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___37 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___73 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___73 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___73 *fl_ops;
	const struct lock_manager_operations___73 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___73 {
	void (*fl_copy_lock)(struct file_lock___73 *, struct file_lock___73 *);
	void (*fl_release_private)(struct file_lock___73 *);
};

struct lock_manager_operations___73 {
	int (*lm_compare_owner)(struct file_lock___73 *, struct file_lock___73 *);
	long unsigned int (*lm_owner_key)(struct file_lock___73 *);
	void (*lm_notify)(struct file_lock___73 *);
	int (*lm_grant)(struct file_lock___73 *, struct file_lock___73 *, int);
	void (*lm_break)(struct file_lock___73 *);
	int (*lm_change)(struct file_lock___73 **, int);
};

struct fasync_struct___73 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___73 *fa_next;
	struct file___73 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___73 {
	const char *name;
	int fs_flags;
	struct dentry___74 * (*mount)(struct file_system_type___73 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___74 *);
	struct module *owner;
	struct file_system_type___73 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___73 {
	struct inode___74 * (*alloc_inode)(struct super_block___74 *);
	void (*destroy_inode)(struct inode___74 *);
	void (*dirty_inode)(struct inode___74 *, int);
	int (*write_inode)(struct inode___74 *, struct writeback_control *);
	int (*drop_inode)(struct inode___74 *);
	void (*evict_inode)(struct inode___74 *);
	void (*put_super)(struct super_block___74 *);
	int (*sync_fs)(struct super_block___74 *, int);
	int (*freeze_fs)(struct super_block___74 *);
	int (*unfreeze_fs)(struct super_block___74 *);
	int (*statfs)(struct dentry___74 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___74 *, int *, char *);
	void (*umount_begin)(struct super_block___74 *);
	int (*show_options)(struct seq_file___54 *, struct dentry___74 *);
	int (*show_devname)(struct seq_file___54 *, struct dentry___74 *);
	int (*show_path)(struct seq_file___54 *, struct dentry___74 *);
	int (*show_stats)(struct seq_file___54 *, struct dentry___74 *);
	ssize_t (*quota_read)(struct super_block___74 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___74 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___74 *);
	int (*bdev_try_to_free_page)(struct super_block___74 *, struct page___73 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___74 *);
	void (*free_cached_objects)(struct super_block___74 *, int);
};

struct xattr_handler___45 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___74 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___74 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___74 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___43)(struct file___73 *, wait_queue_head_t *, struct poll_table_struct___43 *);

struct poll_table_struct___43 {
	poll_queue_proc___43 _qproc;
	long unsigned int _key;
};

struct irq_chip___52 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___52 *);
	void (*irq_shutdown)(struct irq_data___52 *);
	void (*irq_enable)(struct irq_data___52 *);
	void (*irq_disable)(struct irq_data___52 *);
	void (*irq_ack)(struct irq_data___52 *);
	void (*irq_mask)(struct irq_data___52 *);
	void (*irq_mask_ack)(struct irq_data___52 *);
	void (*irq_unmask)(struct irq_data___52 *);
	void (*irq_eoi)(struct irq_data___52 *);
	int (*irq_set_affinity)(struct irq_data___52 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___52 *);
	int (*irq_set_type)(struct irq_data___52 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___52 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___52 *);
	void (*irq_bus_sync_unlock)(struct irq_data___52 *);
	void (*irq_cpu_online)(struct irq_data___52 *);
	void (*irq_cpu_offline)(struct irq_data___52 *);
	void (*irq_suspend)(struct irq_data___52 *);
	void (*irq_resume)(struct irq_data___52 *);
	void (*irq_pm_shutdown)(struct irq_data___52 *);
	void (*irq_print_chip)(struct irq_data___52 *, struct seq_file___54 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___52 *, void *);
	long unsigned int flags;
};

struct signal_struct___73 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___73 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___73 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___37 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___37 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___74 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___45 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___45 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___34 {
	struct pmu___34 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___74 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___73 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___34 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct kmem_cache_cpu___64 {
	void **freelist;
	long unsigned int tid;
	struct page___73 *page;
	struct page___73 *partial;
};

struct memcg_cache_params___64 {
	bool is_root_cache;
	union {
		struct kmem_cache___64 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___64 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___45;

struct cgroup___45 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___45 *parent;
	struct dentry___74 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___45 *subsys[11];
	struct cgroupfs_root___45 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___74 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___45 {
	struct super_block___74 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___45 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___16 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___74 *, struct file___73 *);
	ssize_t (*read)(struct cgroup___45 *, struct cftype___16 *, struct file___73 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___45 *, struct cftype___16 *);
	s64 (*read_s64)(struct cgroup___45 *, struct cftype___16 *);
	int (*read_map)(struct cgroup___45 *, struct cftype___16 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___45 *, struct cftype___16 *, struct seq_file___54 *);
	ssize_t (*write)(struct cgroup___45 *, struct cftype___16 *, struct file___73 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___45 *, struct cftype___16 *, u64);
	int (*write_s64)(struct cgroup___45 *, struct cftype___16 *, s64);
	int (*write_string)(struct cgroup___45 *, struct cftype___16 *, const char *);
	int (*trigger)(struct cgroup___45 *, unsigned int);
	int (*release)(struct inode___74 *, struct file___73 *);
	int (*register_event)(struct cgroup___45 *, struct cftype___16 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___45 *, struct cftype___16 *, struct eventfd_ctx *);
};

struct cftype_set___15 {
	struct list_head node;
	struct cftype___16 *cfts;
};

struct task_and_cgroup___15 {
	struct task_struct___73 *task;
	struct cgroup___45 *cgrp;
	struct css_set___45 *cg;
};

struct cgroup_taskset___15 {
	struct task_and_cgroup___15 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___45 *cur_cgrp;
};

struct cgroup_subsys___15 {
	struct cgroup_subsys_state___45 * (*css_alloc)(struct cgroup___45 *);
	int (*css_online)(struct cgroup___45 *);
	void (*css_offline)(struct cgroup___45 *);
	void (*css_free)(struct cgroup___45 *);
	int (*can_attach)(struct cgroup___45 *, struct cgroup_taskset___15 *);
	void (*cancel_attach)(struct cgroup___45 *, struct cgroup_taskset___15 *);
	void (*attach)(struct cgroup___45 *, struct cgroup_taskset___15 *);
	void (*fork)(struct task_struct___73 *);
	void (*exit)(struct cgroup___45 *, struct cgroup___45 *, struct task_struct___73 *);
	void (*bind)(struct cgroup___45 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___45 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___16 *base_cftypes;
	struct cftype_set___15 base_cftset;
	struct module *module;
};

struct perf_cpu_context___34;

struct pmu___34 {
	struct list_head entry;
	struct device___57 *dev;
	const struct attribute_group___50 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___34 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___34 *);
	void (*pmu_disable)(struct pmu___34 *);
	int (*event_init)(struct perf_event___34 *);
	int (*add)(struct perf_event___34 *, int);
	void (*del)(struct perf_event___34 *, int);
	void (*start)(struct perf_event___34 *, int);
	void (*stop)(struct perf_event___34 *, int);
	void (*read)(struct perf_event___34 *);
	void (*start_txn)(struct pmu___34 *);
	int (*commit_txn)(struct pmu___34 *);
	void (*cancel_txn)(struct pmu___34 *);
	int (*event_idx)(struct perf_event___34 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___34 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___34 *);
};

struct perf_cpu_context___34 {
	struct perf_event_context___34 ctx;
	struct perf_event_context___34 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___34 *unique_pmu;
	struct perf_cgroup___34 *cgrp;
};

struct trace_event_functions___26;

struct trace_event___26 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___26 *funcs;
};

struct ftrace_event_class___26;

struct ftrace_event_call___26 {
	struct list_head list;
	struct ftrace_event_class___26 *class;
	char *name;
	struct trace_event___26 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___34 {
	struct cgroup_subsys_state___45 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___26 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___74 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___26)(struct trace_iterator___26 *, int, struct trace_event___26 *);

struct trace_event_functions___26 {
	trace_print_func___26 trace;
	trace_print_func___26 raw;
	trace_print_func___26 hex;
	trace_print_func___26 binary;
};

struct ftrace_event_class___26 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___26 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___26 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___26 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___26 *);
};

struct platform_suspend_ops {
	int (*valid)(suspend_state_t);
	int (*begin)(suspend_state_t);
	int (*prepare)();
	int (*prepare_late)();
	int (*enter)(suspend_state_t);
	void (*wake)();
	void (*finish)();
	bool (*suspend_again)();
	void (*end)();
	void (*recover)();
};

struct dev_pm_qos_request___7 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___57 *dev;
};

enum {
	TEST_NONE = 0,
	TEST_CORE = 1,
	TEST_CPUS = 2,
	TEST_PLATFORM = 3,
	TEST_DEVICES = 4,
	TEST_FREEZER = 5,
	__TEST_AFTER_LAST = 6,
};

struct page___74;

typedef struct page___74 *pgtable_t___74;

struct address_space___74;

struct kmem_cache___65;

struct page___74 {
	long unsigned int flags;
	struct address_space___74 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___74 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___74 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___65 *slab_cache;
		struct page___74 *first_page;
	};
	long: 64;
};

struct thread_struct___35;

struct task_struct___74;

struct pv_cpu_ops___74 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___35 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___35 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___74 *);
	void (*end_context_switch)(struct task_struct___74 *);
};

struct perf_event___35;

struct thread_struct___35 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___35 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___38;

struct pid_link___38 {
	struct hlist_node node;
	struct pid___38 *pid;
};

struct mutex___75 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___74 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___71 {
	struct page___74 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___78;

struct nsproxy___39;

struct signal_struct___74;

struct css_set___46;

struct perf_event_context___35;

struct task_struct___74 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___74 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___7 se;
	struct sched_rt_entity___7 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___78 *mm;
	struct mm_struct___78 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___74 *real_parent;
	struct task_struct___74 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___74 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___38 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___74 = 0,
		VTIME_USER___74 = 1,
		VTIME_SYS___74 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___35 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___39 *nsproxy;
	struct signal_struct___74 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___46 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___35 *perf_event_ctxp[2];
	struct mutex___75 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___71 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___78 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___78 *, struct mm_struct___78 *);
	void (*dup_mmap)(struct mm_struct___78 *, struct mm_struct___78 *);
	void (*exit_mmap)(struct mm_struct___78 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___78 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___78 *);
	void (*pgd_free)(struct mm_struct___78 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___78 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___78 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___78 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___78 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___78 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___78 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___78 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___78 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___78 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___78 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___78 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___75 lock;
	void *vdso;
} mm_context_t___75;

struct xol_area___74;

struct uprobes_state___74 {
	struct xol_area___74 *xol_area;
};

struct vm_area_struct___78;

struct file___74;

struct core_state___74;

struct mm_struct___78 {
	struct vm_area_struct___78 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___78 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___78 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___75 context;
	long unsigned int flags;
	struct core_state___74 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___74 *owner;
	struct file___74 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___74 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___35 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___74 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___74 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___74 *target;
};

typedef void (*perf_overflow_handler_t___35)(struct perf_event___35 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___35;

typedef void (*ftrace_func_t___35)(long unsigned int, long unsigned int, struct ftrace_ops___35 *, struct pt_regs *);

struct ftrace_ops___35 {
	ftrace_func_t___35 func;
	struct ftrace_ops___35 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___75 regex_lock;
};

struct pmu___35;

struct fasync_struct___74;

struct pid_namespace___38;

struct ftrace_event_call___27;

struct perf_cgroup___35;

struct perf_event___35 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___35 *group_leader;
	struct pmu___35 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___35 hw;
	struct perf_event_context___35 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___75 child_mutex;
	struct list_head child_list;
	struct perf_event___35 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___74 *owner;
	struct mutex___75 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___74 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___35 *);
	struct callback_head callback_head;
	struct pid_namespace___38 *ns;
	u64 id;
	perf_overflow_handler_t___35 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___27 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___35 ftrace_ops;
	struct perf_cgroup___35 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___74;

struct lruvec___74 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___74 *zone;
};

struct pglist_data___74;

struct zone___74 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___74 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___74 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___74 {
	struct zone___74 *zone;
	int zone_idx;
};

struct zonelist___74 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___74 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___74 {
	struct zone___74 node_zones[4];
	struct zonelist___74 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___74 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___53;

struct x86_io_apic_ops___53 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___53 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___53;

struct irq_data___53 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___53 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___58;

struct dev_pm_ops___58 {
	int (*prepare)(struct device___58 *);
	void (*complete)(struct device___58 *);
	int (*suspend)(struct device___58 *);
	int (*resume)(struct device___58 *);
	int (*freeze)(struct device___58 *);
	int (*thaw)(struct device___58 *);
	int (*poweroff)(struct device___58 *);
	int (*restore)(struct device___58 *);
	int (*suspend_late)(struct device___58 *);
	int (*resume_early)(struct device___58 *);
	int (*freeze_late)(struct device___58 *);
	int (*thaw_early)(struct device___58 *);
	int (*poweroff_late)(struct device___58 *);
	int (*restore_early)(struct device___58 *);
	int (*suspend_noirq)(struct device___58 *);
	int (*resume_noirq)(struct device___58 *);
	int (*freeze_noirq)(struct device___58 *);
	int (*thaw_noirq)(struct device___58 *);
	int (*poweroff_noirq)(struct device___58 *);
	int (*restore_noirq)(struct device___58 *);
	int (*runtime_suspend)(struct device___58 *);
	int (*runtime_resume)(struct device___58 *);
	int (*runtime_idle)(struct device___58 *);
};

struct device_type___58;

struct bus_type___58;

struct device_driver___58;

struct dev_pm_domain___58;

struct class___58;

struct attribute_group___51;

struct device_rh___58;

struct device___58 {
	struct device___58 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___58 *type;
	struct mutex___75 mutex;
	struct bus_type___58 *bus;
	struct device_driver___58 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___58 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___58 *class;
	const struct attribute_group___51 **groups;
	void (*release)(struct device___58 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___58 *device_rh;
};

struct dev_pm_info_rh___58 {
	void (*set_latency_tolerance)(struct device___58 *, s32);
};

struct dev_pm_domain___58 {
	struct dev_pm_ops___58 ops;
};

struct smp_ops___74 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___74 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___74 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___74 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___65;

struct memcg_cache_params___65;

struct kmem_cache___65 {
	struct kmem_cache_cpu___65 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___65 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___75;

struct address_space_operations___74;

struct address_space___74 {
	struct inode___75 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___75 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___74 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___9;

struct dentry___75;

struct path___74 {
	struct vfsmount___9 *mnt;
	struct dentry___75 *dentry;
};

struct fown_struct___38 {
	rwlock_t lock;
	struct pid___38 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___74;

struct file___74 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___74 f_path;
	struct inode___75 *f_inode;
	const struct file_operations___74 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___74 *f_mapping;
	struct mutex___75 f_pos_lock;
};

struct vm_operations_struct___65;

struct vm_area_struct___78 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___78 *vm_next;
	struct vm_area_struct___78 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___78 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___65 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___74 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___62;

struct vm_operations_struct___65 {
	void (*open)(struct vm_area_struct___78 *);
	void (*close)(struct vm_area_struct___78 *);
	int (*fault)(struct vm_area_struct___78 *, struct vm_fault___62 *);
	int (*page_mkwrite)(struct vm_area_struct___78 *, struct vm_fault___62 *);
	int (*access)(struct vm_area_struct___78 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___78 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___78 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___78 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___78 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___74 {
	struct task_struct___74 *task;
	struct core_thread___74 *next;
};

struct core_state___74 {
	atomic_t nr_threads;
	struct core_thread___74 dumper;
	struct completion startup;
};

struct upid___38 {
	int nr;
	struct pid_namespace___38 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___38 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___74 *child_reaper;
	struct kmem_cache___65 *pid_cachep;
	unsigned int level;
	struct pid_namespace___38 *parent;
	struct vfsmount___9 *proc_mnt;
	struct dentry___75 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___38 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___38 numbers[1];
};

struct nsproxy___39 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___38 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___74 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___74 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___74 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___38 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___38 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___75 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___46;

struct css_set___46 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___46 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___35 {
	struct pmu___35 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___75 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___74 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___35 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___51;

struct attribute_group___51 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___51 **bin_attrs;
};

struct bin_attribute___51 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___74 *, struct kobject___3 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___74 *, struct kobject___3 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	int (*mmap)(struct file___74 *, struct kobject___3 *, struct bin_attribute___51 *, struct vm_area_struct___78 *);
};

struct kmem_cache_cpu___65 {
	void **freelist;
	long unsigned int tid;
	struct page___74 *page;
	struct page___74 *partial;
};

struct memcg_cache_params___65 {
	bool is_root_cache;
	union {
		struct kmem_cache___65 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___65 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___46 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___75 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___75 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___75 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___74;

struct super_block___75;

struct dentry___75 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___75 *d_parent;
	struct qstr d_name;
	struct inode___75 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___74 *d_op;
	struct super_block___75 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___74;

struct file_lock___74;

struct dquot___74;

struct block_device___74;

struct inode___75 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___74 *i_op;
	struct super_block___75 *i_sb;
	struct address_space___74 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___75 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___74 *i_fop;
	struct file_lock___74 *i_flock;
	struct address_space___74 i_data;
	struct dquot___74 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___74 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___74 {
	int (*d_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_hash)(const struct dentry___75 *, struct qstr *);
	int (*d_compare)(const struct dentry___75 *, const struct dentry___75 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___75 *);
	void (*d_release)(struct dentry___75 *);
	void (*d_prune)(struct dentry___75 *);
	void (*d_iput)(struct dentry___75 *, struct inode___75 *);
	char * (*d_dname)(struct dentry___75 *, char *, int);
	struct vfsmount___9 * (*d_automount)(struct path___74 *);
	int (*d_manage)(struct dentry___75 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___74;

struct mem_dqinfo___74 {
	struct quota_format_type___74 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___74;

struct quota_info___74 {
	unsigned int flags;
	struct mutex___75 dqio_mutex;
	struct mutex___75 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___75 *files[2];
	struct mem_dqinfo___74 info[2];
	const struct quota_format_ops___74 *ops[2];
};

struct file_system_type___74;

struct super_operations___74;

struct dquot_operations___74;

struct quotactl_ops___74;

struct super_block___75 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___74 *s_type;
	const struct super_operations___74 *s_op;
	const struct dquot_operations___74 *dq_op;
	const struct quotactl_ops___74 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___75 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___46 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___74 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___74 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___75 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___74 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___9 {
	struct dentry___75 *mnt_root;
	struct super_block___75 *mnt_sb;
	int mnt_flags;
};

struct hd_struct___8;

struct gendisk___8;

struct block_device___74 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___75 *bd_inode;
	struct super_block___75 *bd_super;
	struct mutex___75 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___74 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___8 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___8 *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___75 bd_fsfreeze_mutex;
};

struct cgroup___46;

struct cgroup_subsys_state___46 {
	struct cgroup___46 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___75 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___74 *ia_file;
};

struct dquot___74 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___75 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___75 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___74 {
	int qf_fmt_id;
	const struct quota_format_ops___74 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___74 *qf_next;
};

struct quota_format_ops___74 {
	int (*check_quota_file)(struct super_block___75 *, int);
	int (*read_file_info)(struct super_block___75 *, int);
	int (*write_file_info)(struct super_block___75 *, int);
	int (*free_file_info)(struct super_block___75 *, int);
	int (*read_dqblk)(struct dquot___74 *);
	int (*commit_dqblk)(struct dquot___74 *);
	int (*release_dqblk)(struct dquot___74 *);
};

struct dquot_operations___74 {
	int (*write_dquot)(struct dquot___74 *);
	struct dquot___74 * (*alloc_dquot)(struct super_block___75 *, int);
	void (*destroy_dquot)(struct dquot___74 *);
	int (*acquire_dquot)(struct dquot___74 *);
	int (*release_dquot)(struct dquot___74 *);
	int (*mark_dirty)(struct dquot___74 *);
	int (*write_info)(struct super_block___75 *, int);
	qsize_t * (*get_reserved_space)(struct inode___75 *);
};

struct quotactl_ops___74 {
	int (*quota_on)(struct super_block___75 *, int, int, struct path___74 *);
	int (*quota_on_meta)(struct super_block___75 *, int, int);
	int (*quota_off)(struct super_block___75 *, int);
	int (*quota_sync)(struct super_block___75 *, int);
	int (*get_info)(struct super_block___75 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___75 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___75 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___75 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___75 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___75 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___75 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___75 *, unsigned int);
};

struct swap_info_struct___14;

struct address_space_operations___74 {
	int (*writepage)(struct page___74 *, struct writeback_control *);
	int (*readpage)(struct file___74 *, struct page___74 *);
	int (*writepages)(struct address_space___74 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___74 *);
	int (*readpages)(struct file___74 *, struct address_space___74 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___74 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___74 **, void **);
	int (*write_end)(struct file___74 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___74 *, void *);
	sector_t (*bmap)(struct address_space___74 *, sector_t);
	void (*invalidatepage)(struct page___74 *, long unsigned int);
	int (*releasepage)(struct page___74 *, gfp_t);
	void (*freepage)(struct page___74 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___74 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___74 *, struct page___74 *, struct page___74 *, enum migrate_mode);
	int (*launder_page)(struct page___74 *);
	int (*is_partially_uptodate)(struct page___74 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___74 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___74 *, struct page___74 *);
	int (*swap_activate)(struct swap_info_struct___14 *, struct file___74 *, sector_t *);
	void (*swap_deactivate)(struct file___74 *);
	void (*invalidatepage_range)(struct page___74 *, unsigned int, unsigned int);
};

struct swap_info_struct___14 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___74 *bdev;
	struct file___74 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___8 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___58 __dev;
	struct kobject___3 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___8;

struct block_device_operations___8;

struct gendisk___8 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___8 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___8 *part_tbl;
	struct hd_struct___8 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct device___58 *driverfs_dev;
	struct kobject___3 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct inode_operations___74 {
	struct dentry___75 * (*lookup)(struct inode___75 *, struct dentry___75 *, unsigned int);
	void * (*follow_link)(struct dentry___75 *, struct nameidata *);
	int (*permission)(struct inode___75 *, int);
	struct posix_acl * (*get_acl)(struct inode___75 *, int);
	int (*readlink)(struct dentry___75 *, char *, int);
	void (*put_link)(struct dentry___75 *, struct nameidata *, void *);
	int (*create)(struct inode___75 *, struct dentry___75 *, umode_t, bool);
	int (*link)(struct dentry___75 *, struct inode___75 *, struct dentry___75 *);
	int (*unlink)(struct inode___75 *, struct dentry___75 *);
	int (*symlink)(struct inode___75 *, struct dentry___75 *, const char *);
	int (*mkdir)(struct inode___75 *, struct dentry___75 *, umode_t);
	int (*rmdir)(struct inode___75 *, struct dentry___75 *);
	int (*mknod)(struct inode___75 *, struct dentry___75 *, umode_t, dev_t);
	int (*rename)(struct inode___75 *, struct dentry___75 *, struct inode___75 *, struct dentry___75 *);
	int (*setattr)(struct dentry___75 *, struct iattr___75 *);
	int (*getattr)(struct vfsmount___9 *, struct dentry___75 *, struct kstat *);
	int (*setxattr)(struct dentry___75 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___75 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___75 *, char *, size_t);
	int (*removexattr)(struct dentry___75 *, const char *);
	int (*fiemap)(struct inode___75 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___75 *, struct timespec *, int);
	int (*atomic_open)(struct inode___75 *, struct dentry___75 *, struct file___74 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___44;

struct seq_file___55;

struct file_operations___74 {
	struct module *owner;
	loff_t (*llseek)(struct file___74 *, loff_t, int);
	ssize_t (*read)(struct file___74 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___74 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___74 *, void *, filldir_t);
	unsigned int (*poll)(struct file___74 *, struct poll_table_struct___44 *);
	long int (*unlocked_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___74 *, struct vm_area_struct___78 *);
	int (*open)(struct inode___75 *, struct file___74 *);
	int (*flush)(struct file___74 *, fl_owner_t);
	int (*release)(struct inode___75 *, struct file___74 *);
	int (*fsync)(struct file___74 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___74 *, int);
	int (*lock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*sendpage)(struct file___74 *, struct page___74 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___74 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___74 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___74 *, long int, struct file_lock___74 **, void **);
		struct {
			int (*setlease)(struct file___74 *, long int, struct file_lock___74 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___74 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___55 *, struct file___74 *);
};

struct file_lock_operations___74;

struct lock_manager_operations___74;

struct file_lock___74 {
	struct file_lock___74 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___38 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___74 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___74 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___74 *fl_ops;
	const struct lock_manager_operations___74 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___74 {
	void (*fl_copy_lock)(struct file_lock___74 *, struct file_lock___74 *);
	void (*fl_release_private)(struct file_lock___74 *);
};

struct lock_manager_operations___74 {
	int (*lm_compare_owner)(struct file_lock___74 *, struct file_lock___74 *);
	long unsigned int (*lm_owner_key)(struct file_lock___74 *);
	void (*lm_notify)(struct file_lock___74 *);
	int (*lm_grant)(struct file_lock___74 *, struct file_lock___74 *, int);
	void (*lm_break)(struct file_lock___74 *);
	int (*lm_change)(struct file_lock___74 **, int);
};

struct fasync_struct___74 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___74 *fa_next;
	struct file___74 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___74 {
	const char *name;
	int fs_flags;
	struct dentry___75 * (*mount)(struct file_system_type___74 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___75 *);
	struct module *owner;
	struct file_system_type___74 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___74 {
	struct inode___75 * (*alloc_inode)(struct super_block___75 *);
	void (*destroy_inode)(struct inode___75 *);
	void (*dirty_inode)(struct inode___75 *, int);
	int (*write_inode)(struct inode___75 *, struct writeback_control *);
	int (*drop_inode)(struct inode___75 *);
	void (*evict_inode)(struct inode___75 *);
	void (*put_super)(struct super_block___75 *);
	int (*sync_fs)(struct super_block___75 *, int);
	int (*freeze_fs)(struct super_block___75 *);
	int (*unfreeze_fs)(struct super_block___75 *);
	int (*statfs)(struct dentry___75 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___75 *, int *, char *);
	void (*umount_begin)(struct super_block___75 *);
	int (*show_options)(struct seq_file___55 *, struct dentry___75 *);
	int (*show_devname)(struct seq_file___55 *, struct dentry___75 *);
	int (*show_path)(struct seq_file___55 *, struct dentry___75 *);
	int (*show_stats)(struct seq_file___55 *, struct dentry___75 *);
	ssize_t (*quota_read)(struct super_block___75 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___75 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___75 *);
	int (*bdev_try_to_free_page)(struct super_block___75 *, struct page___74 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___75 *);
	void (*free_cached_objects)(struct super_block___75 *, int);
};

typedef void (*poll_queue_proc___44)(struct file___74 *, wait_queue_head_t *, struct poll_table_struct___44 *);

struct poll_table_struct___44 {
	poll_queue_proc___44 _qproc;
	long unsigned int _key;
};

struct seq_operations___54;

struct seq_file___55 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___75 lock;
	const struct seq_operations___54 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___46;

struct cgroup___46 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___46 *parent;
	struct dentry___75 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___46 *subsys[11];
	struct cgroupfs_root___46 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___75 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___46 {
	struct super_block___75 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___46 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___17 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___75 *, struct file___74 *);
	ssize_t (*read)(struct cgroup___46 *, struct cftype___17 *, struct file___74 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___46 *, struct cftype___17 *);
	s64 (*read_s64)(struct cgroup___46 *, struct cftype___17 *);
	int (*read_map)(struct cgroup___46 *, struct cftype___17 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___46 *, struct cftype___17 *, struct seq_file___55 *);
	ssize_t (*write)(struct cgroup___46 *, struct cftype___17 *, struct file___74 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___46 *, struct cftype___17 *, u64);
	int (*write_s64)(struct cgroup___46 *, struct cftype___17 *, s64);
	int (*write_string)(struct cgroup___46 *, struct cftype___17 *, const char *);
	int (*trigger)(struct cgroup___46 *, unsigned int);
	int (*release)(struct inode___75 *, struct file___74 *);
	int (*register_event)(struct cgroup___46 *, struct cftype___17 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___46 *, struct cftype___17 *, struct eventfd_ctx *);
};

struct cftype_set___16 {
	struct list_head node;
	struct cftype___17 *cfts;
};

struct task_and_cgroup___16 {
	struct task_struct___74 *task;
	struct cgroup___46 *cgrp;
	struct css_set___46 *cg;
};

struct cgroup_taskset___16 {
	struct task_and_cgroup___16 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___46 *cur_cgrp;
};

struct cgroup_subsys___16 {
	struct cgroup_subsys_state___46 * (*css_alloc)(struct cgroup___46 *);
	int (*css_online)(struct cgroup___46 *);
	void (*css_offline)(struct cgroup___46 *);
	void (*css_free)(struct cgroup___46 *);
	int (*can_attach)(struct cgroup___46 *, struct cgroup_taskset___16 *);
	void (*cancel_attach)(struct cgroup___46 *, struct cgroup_taskset___16 *);
	void (*attach)(struct cgroup___46 *, struct cgroup_taskset___16 *);
	void (*fork)(struct task_struct___74 *);
	void (*exit)(struct cgroup___46 *, struct cgroup___46 *, struct task_struct___74 *);
	void (*bind)(struct cgroup___46 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___46 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___17 *base_cftypes;
	struct cftype_set___16 base_cftset;
	struct module *module;
};

struct irq_chip___53 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___53 *);
	void (*irq_shutdown)(struct irq_data___53 *);
	void (*irq_enable)(struct irq_data___53 *);
	void (*irq_disable)(struct irq_data___53 *);
	void (*irq_ack)(struct irq_data___53 *);
	void (*irq_mask)(struct irq_data___53 *);
	void (*irq_mask_ack)(struct irq_data___53 *);
	void (*irq_unmask)(struct irq_data___53 *);
	void (*irq_eoi)(struct irq_data___53 *);
	int (*irq_set_affinity)(struct irq_data___53 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___53 *);
	int (*irq_set_type)(struct irq_data___53 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___53 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___53 *);
	void (*irq_bus_sync_unlock)(struct irq_data___53 *);
	void (*irq_cpu_online)(struct irq_data___53 *);
	void (*irq_cpu_offline)(struct irq_data___53 *);
	void (*irq_suspend)(struct irq_data___53 *);
	void (*irq_resume)(struct irq_data___53 *);
	void (*irq_pm_shutdown)(struct irq_data___53 *);
	void (*irq_print_chip)(struct irq_data___53 *, struct seq_file___55 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___53 *, void *);
	long unsigned int flags;
};

struct bus_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___58 *, char *);
	ssize_t (*store)(struct bus_type___58 *, const char *, size_t);
};

struct device_attribute___58;

struct driver_attribute___58;

struct bus_type___58 {
	const char *name;
	const char *dev_name;
	struct device___58 *dev_root;
	struct bus_attribute___58 *bus_attrs;
	struct device_attribute___58 *dev_attrs;
	struct driver_attribute___58 *drv_attrs;
	const struct attribute_group___51 **bus_groups;
	const struct attribute_group___51 **dev_groups;
	const struct attribute_group___51 **drv_groups;
	int (*match)(struct device___58 *, struct device_driver___58 *);
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	int (*probe)(struct device___58 *);
	int (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*online)(struct device___58 *);
	int (*offline)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct device___58 *, struct device_attribute___58 *, char *);
	ssize_t (*store)(struct device___58 *, struct device_attribute___58 *, const char *, size_t);
};

struct driver_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___58 *, char *);
	ssize_t (*store)(struct device_driver___58 *, const char *, size_t);
};

struct device_driver___58 {
	const char *name;
	struct bus_type___58 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___58 *);
	int (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	const struct attribute_group___51 **groups;
	const struct dev_pm_ops___58 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___58 {
	const char *name;
	const struct attribute_group___51 **groups;
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
};

struct class_attribute___58;

struct class___58 {
	const char *name;
	struct module *owner;
	struct class_attribute___58 *class_attrs;
	struct device_attribute___58 *dev_attrs;
	const struct attribute_group___51 **dev_groups;
	struct bin_attribute___51 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *);
	void (*class_release)(struct class___58 *);
	void (*dev_release)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
	struct subsys_private *p;
};

struct class_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct class___58 *, struct class_attribute___58 *, char *);
	ssize_t (*store)(struct class___58 *, struct class_attribute___58 *, const char *, size_t);
	const void * (*namespace)(struct class___58 *, const struct class_attribute___58 *);
};

struct device_rh___58 {
	struct dev_pm_info_rh___58 power;
};

struct vm_fault___62 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___74 *page;
};

struct platform_hibernation_ops {
	int (*begin)();
	void (*end)();
	int (*pre_snapshot)();
	void (*finish)();
	int (*prepare)();
	int (*enter)();
	void (*leave)();
	int (*pre_restore)();
	void (*restore_cleanup)();
	void (*recover)();
};

struct seq_operations___54 {
	void * (*start)(struct seq_file___55 *, loff_t *);
	void (*stop)(struct seq_file___55 *, void *);
	void * (*next)(struct seq_file___55 *, void *, loff_t *);
	int (*show)(struct seq_file___55 *, void *);
};

struct perf_cpu_context___35;

struct pmu___35 {
	struct list_head entry;
	struct device___58 *dev;
	const struct attribute_group___51 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___35 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___35 *);
	void (*pmu_disable)(struct pmu___35 *);
	int (*event_init)(struct perf_event___35 *);
	int (*add)(struct perf_event___35 *, int);
	void (*del)(struct perf_event___35 *, int);
	void (*start)(struct perf_event___35 *, int);
	void (*stop)(struct perf_event___35 *, int);
	void (*read)(struct perf_event___35 *);
	void (*start_txn)(struct pmu___35 *);
	int (*commit_txn)(struct pmu___35 *);
	void (*cancel_txn)(struct pmu___35 *);
	int (*event_idx)(struct perf_event___35 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___35 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___35 *);
};

struct perf_cpu_context___35 {
	struct perf_event_context___35 ctx;
	struct perf_event_context___35 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___35 *unique_pmu;
	struct perf_cgroup___35 *cgrp;
};

struct trace_event_functions___27;

struct trace_event___27 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___27 *funcs;
};

struct ftrace_event_class___27;

struct ftrace_event_call___27 {
	struct list_head list;
	struct ftrace_event_class___27 *class;
	char *name;
	struct trace_event___27 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___35 {
	struct cgroup_subsys_state___46 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___27 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___75 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___27)(struct trace_iterator___27 *, int, struct trace_event___27 *);

struct trace_event_functions___27 {
	trace_print_func___27 trace;
	trace_print_func___27 raw;
	trace_print_func___27 hex;
	trace_print_func___27 binary;
};

struct ftrace_event_class___27 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___27 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___27 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___27 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___27 *);
};

struct disk_part_tbl___8 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___8 *last_lookup;
	struct hd_struct___8 *part[0];
};

struct block_device___75;

struct gendisk___9;

struct module___42;

struct block_device_operations___8 {
	int (*open)(struct block_device___75 *, fmode_t);
	void (*release)(struct gendisk___9 *, fmode_t);
	int (*ioctl)(struct block_device___75 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___75 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___75 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___9 *, unsigned int);
	int (*media_changed)(struct gendisk___9 *);
	void (*unlock_native_capacity)(struct gendisk___9 *);
	int (*revalidate_disk)(struct gendisk___9 *);
	int (*getgeo)(struct block_device___75 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___75 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___42 *owner;
};

enum {
	HIBERNATION_INVALID = 0,
	HIBERNATION_PLATFORM = 1,
	HIBERNATION_SHUTDOWN = 2,
	HIBERNATION_REBOOT = 3,
	HIBERNATION_SUSPEND = 4,
	__HIBERNATION_AFTER_LAST = 5,
};

struct pbe {
	void *address;
	void *orig_address;
	struct pbe *next;
};

struct swsusp_info {
	struct new_utsname uts;
	u32 version_code;
	long unsigned int num_physpages;
	int cpus;
	long unsigned int image_pages;
	long unsigned int pages;
	long unsigned int size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct snapshot_handle {
	unsigned int cur;
	void *buffer;
	int sync_read;
};

struct linked_page {
	struct linked_page *next;
	char data[4088];
};

struct chain_allocator {
	struct linked_page *chain;
	unsigned int used_space;
	gfp_t gfp_mask;
	int safe_needed;
};

struct bm_block {
	struct list_head hook;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	long unsigned int *data;
};

struct bm_position {
	struct bm_block *block;
	int bit;
};

struct memory_bitmap {
	struct list_head blocks;
	struct linked_page *p_list;
	struct bm_position cur;
};

struct mem_extent {
	struct list_head hook;
	long unsigned int start;
	long unsigned int end;
};

struct nosave_region {
	struct list_head list;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
};

struct page___75;

typedef struct page___75 *pgtable_t___75;

struct address_space___75;

struct kmem_cache___66;

struct page___75 {
	long unsigned int flags;
	struct address_space___75 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___75 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___75 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___66 *slab_cache;
		struct page___75 *first_page;
	};
	long: 64;
};

struct task_struct___75;

struct pv_cpu_ops___75 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___35 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___35 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___75 *);
	void (*end_context_switch)(struct task_struct___75 *);
};

struct mutex___76 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___75 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___72 {
	struct page___75 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___79;

struct signal_struct___75;

struct bio_list___8;

struct backing_dev_info___9;

struct io_context___8;

struct css_set___47;

struct task_struct___75 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___75 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___7 se;
	struct sched_rt_entity___7 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___79 *mm;
	struct mm_struct___79 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___75 *real_parent;
	struct task_struct___75 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___75 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___38 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___75 = 0,
		VTIME_USER___75 = 1,
		VTIME_SYS___75 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___35 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___39 *nsproxy;
	struct signal_struct___75 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___8 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___9 *backing_dev_info;
	struct io_context___8 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___47 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___76 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___72 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___79 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___79 *, struct mm_struct___79 *);
	void (*dup_mmap)(struct mm_struct___79 *, struct mm_struct___79 *);
	void (*exit_mmap)(struct mm_struct___79 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___79 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___79 *);
	void (*pgd_free)(struct mm_struct___79 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___79 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___79 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___79 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___79 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___79 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___79 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___79 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___79 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___79 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___79 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___79 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___76 lock;
	void *vdso;
} mm_context_t___76;

struct xol_area___75;

struct uprobes_state___75 {
	struct xol_area___75 *xol_area;
};

struct vm_area_struct___79;

struct file___75;

struct core_state___75;

struct mm_struct___79 {
	struct vm_area_struct___79 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___79 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___79 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___76 context;
	long unsigned int flags;
	struct core_state___75 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___75 *owner;
	struct file___75 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___75 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module_kobject___41 {
	struct kobject___3 kobj;
	struct module___42 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___41;

struct module___42 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___41 mkobj;
	struct module_attribute___41 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___75 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___75;

struct lruvec___75 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___75 *zone;
};

struct pglist_data___75;

struct zone___75 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___75 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___75 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___75 {
	struct zone___75 *zone;
	int zone_idx;
};

struct zonelist___75 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___75 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___75 {
	struct zone___75 node_zones[4];
	struct zonelist___75 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___75 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___59;

struct dev_pm_ops___59 {
	int (*prepare)(struct device___59 *);
	void (*complete)(struct device___59 *);
	int (*suspend)(struct device___59 *);
	int (*resume)(struct device___59 *);
	int (*freeze)(struct device___59 *);
	int (*thaw)(struct device___59 *);
	int (*poweroff)(struct device___59 *);
	int (*restore)(struct device___59 *);
	int (*suspend_late)(struct device___59 *);
	int (*resume_early)(struct device___59 *);
	int (*freeze_late)(struct device___59 *);
	int (*thaw_early)(struct device___59 *);
	int (*poweroff_late)(struct device___59 *);
	int (*restore_early)(struct device___59 *);
	int (*suspend_noirq)(struct device___59 *);
	int (*resume_noirq)(struct device___59 *);
	int (*freeze_noirq)(struct device___59 *);
	int (*thaw_noirq)(struct device___59 *);
	int (*poweroff_noirq)(struct device___59 *);
	int (*restore_noirq)(struct device___59 *);
	int (*runtime_suspend)(struct device___59 *);
	int (*runtime_resume)(struct device___59 *);
	int (*runtime_idle)(struct device___59 *);
};

struct device_type___59;

struct bus_type___59;

struct device_driver___59;

struct dev_pm_domain___59;

struct class___59;

struct attribute_group___52;

struct device_rh___59;

struct device___59 {
	struct device___59 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___59 *type;
	struct mutex___76 mutex;
	struct bus_type___59 *bus;
	struct device_driver___59 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___59 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___59 *class;
	const struct attribute_group___52 **groups;
	void (*release)(struct device___59 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___59 *device_rh;
};

struct dev_pm_info_rh___59 {
	void (*set_latency_tolerance)(struct device___59 *, s32);
};

struct dev_pm_domain___59 {
	struct dev_pm_ops___59 ops;
};

struct smp_ops___75 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___75 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___52;

struct attribute_group___52 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___52 **bin_attrs;
};

struct bin_attribute___52 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___75 *, struct kobject___3 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___75 *, struct kobject___3 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	int (*mmap)(struct file___75 *, struct kobject___3 *, struct bin_attribute___52 *, struct vm_area_struct___79 *);
};

struct dentry___76;

struct path___75 {
	struct vfsmount *mnt;
	struct dentry___76 *dentry;
};

struct inode___76;

struct file_operations___75;

struct file___75 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___75 f_path;
	struct inode___76 *f_inode;
	const struct file_operations___75 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___75 *f_mapping;
	struct mutex___76 f_pos_lock;
};

struct vm_operations_struct___66;

struct vm_area_struct___79 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___79 *vm_next;
	struct vm_area_struct___79 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___79 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___66 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___75 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___41 *, struct module_kobject___41 *, char *);
	ssize_t (*store)(struct module_attribute___41 *, struct module_kobject___41 *, const char *, size_t);
	void (*setup)(struct module___42 *, const char *);
	int (*test)(struct module___42 *);
	void (*free)(struct module___42 *);
};

struct kmem_cache_cpu___66 {
	void **freelist;
	long unsigned int tid;
	struct page___75 *page;
	struct page___75 *partial;
};

struct memcg_cache_params___66;

struct kmem_cache___66 {
	struct kmem_cache_cpu___66 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___66 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___66 {
	bool is_root_cache;
	union {
		struct kmem_cache___66 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___66 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___59 *, char *);
	ssize_t (*store)(struct bus_type___59 *, const char *, size_t);
};

struct device_attribute___59;

struct driver_attribute___59;

struct bus_type___59 {
	const char *name;
	const char *dev_name;
	struct device___59 *dev_root;
	struct bus_attribute___59 *bus_attrs;
	struct device_attribute___59 *dev_attrs;
	struct driver_attribute___59 *drv_attrs;
	const struct attribute_group___52 **bus_groups;
	const struct attribute_group___52 **dev_groups;
	const struct attribute_group___52 **drv_groups;
	int (*match)(struct device___59 *, struct device_driver___59 *);
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	int (*probe)(struct device___59 *);
	int (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*online)(struct device___59 *);
	int (*offline)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct device___59 *, struct device_attribute___59 *, char *);
	ssize_t (*store)(struct device___59 *, struct device_attribute___59 *, const char *, size_t);
};

struct driver_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___59 *, char *);
	ssize_t (*store)(struct device_driver___59 *, const char *, size_t);
};

struct device_driver___59 {
	const char *name;
	struct bus_type___59 *bus;
	struct module___42 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___59 *);
	int (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	const struct attribute_group___52 **groups;
	const struct dev_pm_ops___59 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___59 {
	const char *name;
	const struct attribute_group___52 **groups;
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
};

struct class_attribute___59;

struct class___59 {
	const char *name;
	struct module___42 *owner;
	struct class_attribute___59 *class_attrs;
	struct device_attribute___59 *dev_attrs;
	const struct attribute_group___52 **dev_groups;
	struct bin_attribute___52 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *);
	void (*class_release)(struct class___59 *);
	void (*dev_release)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
	struct subsys_private *p;
};

struct class_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct class___59 *, struct class_attribute___59 *, char *);
	ssize_t (*store)(struct class___59 *, struct class_attribute___59 *, const char *, size_t);
	const void * (*namespace)(struct class___59 *, const struct class_attribute___59 *);
};

struct device_rh___59 {
	struct dev_pm_info_rh___59 power;
};

struct dentry_operations___75;

struct super_block___76;

struct dentry___76 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___76 *d_parent;
	struct qstr d_name;
	struct inode___76 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___75 *d_op;
	struct super_block___76 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___75;

struct address_space___75 {
	struct inode___76 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___76 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___75 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___9 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___75;

struct file_lock___75;

struct dquot___75;

struct inode___76 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___75 *i_op;
	struct super_block___76 *i_sb;
	struct address_space___75 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___76 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___75 *i_fop;
	struct file_lock___75 *i_flock;
	struct address_space___75 i_data;
	struct dquot___75 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___75 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___75 {
	int (*d_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_hash)(const struct dentry___76 *, struct qstr *);
	int (*d_compare)(const struct dentry___76 *, const struct dentry___76 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___76 *);
	void (*d_release)(struct dentry___76 *);
	void (*d_prune)(struct dentry___76 *);
	void (*d_iput)(struct dentry___76 *, struct inode___76 *);
	char * (*d_dname)(struct dentry___76 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___75 *);
	int (*d_manage)(struct dentry___76 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___75;

struct mem_dqinfo___75 {
	struct quota_format_type___75 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___75;

struct quota_info___75 {
	unsigned int flags;
	struct mutex___76 dqio_mutex;
	struct mutex___76 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___76 *files[2];
	struct mem_dqinfo___75 info[2];
	const struct quota_format_ops___75 *ops[2];
};

struct file_system_type___75;

struct super_operations___75;

struct dquot_operations___75;

struct quotactl_ops___75;

struct xattr_handler___47;

struct super_block___76 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___75 *s_type;
	const struct super_operations___75 *s_op;
	const struct dquot_operations___75 *dq_op;
	const struct quotactl_ops___75 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___76 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___47 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___75 *s_bdev;
	struct backing_dev_info___9 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___75 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___76 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___75 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___8;

typedef void bio_end_io_t___8(struct bio___8 *, int);

struct bio_vec___8 {
	struct page___75 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___47;

struct bio_integrity_payload___8;

struct bio_set___8;

struct bio___8 {
	sector_t bi_sector;
	struct bio___8 *bi_next;
	struct block_device___75 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___8 *bi_end_io;
	void *bi_private;
	struct io_context___8 *bi_ioc;
	struct cgroup_subsys_state___47 *bi_css;
	struct bio_integrity_payload___8 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___8 *bi_io_vec;
	struct bio_set___8 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	struct bio_vec___8 bi_inline_vecs[0];
};

struct hd_struct___9;

struct request_queue___8;

struct block_device___75 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___76 *bd_inode;
	struct super_block___76 *bd_super;
	struct mutex___76 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___75 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___9 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___9 *bd_disk;
	struct request_queue___8 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___76 bd_fsfreeze_mutex;
};

struct io_cq___8;

struct io_context___8 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___8 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___47;

struct cgroup_subsys_state___47 {
	struct cgroup___47 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___8 {
	struct bio___8 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___8 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___8 *bip_vec;
	struct bio_vec___8 bip_inline_vecs[0];
};

struct bio_list___8 {
	struct bio___8 *head;
	struct bio___8 *tail;
};

struct bio_set___8 {
	struct kmem_cache___66 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___8 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___76 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___75 *ia_file;
};

struct dquot___75 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___76 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___76 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___75 {
	int qf_fmt_id;
	const struct quota_format_ops___75 *qf_ops;
	struct module___42 *qf_owner;
	struct quota_format_type___75 *qf_next;
};

struct quota_format_ops___75 {
	int (*check_quota_file)(struct super_block___76 *, int);
	int (*read_file_info)(struct super_block___76 *, int);
	int (*write_file_info)(struct super_block___76 *, int);
	int (*free_file_info)(struct super_block___76 *, int);
	int (*read_dqblk)(struct dquot___75 *);
	int (*commit_dqblk)(struct dquot___75 *);
	int (*release_dqblk)(struct dquot___75 *);
};

struct dquot_operations___75 {
	int (*write_dquot)(struct dquot___75 *);
	struct dquot___75 * (*alloc_dquot)(struct super_block___76 *, int);
	void (*destroy_dquot)(struct dquot___75 *);
	int (*acquire_dquot)(struct dquot___75 *);
	int (*release_dquot)(struct dquot___75 *);
	int (*mark_dirty)(struct dquot___75 *);
	int (*write_info)(struct super_block___76 *, int);
	qsize_t * (*get_reserved_space)(struct inode___76 *);
};

struct quotactl_ops___75 {
	int (*quota_on)(struct super_block___76 *, int, int, struct path___75 *);
	int (*quota_on_meta)(struct super_block___76 *, int, int);
	int (*quota_off)(struct super_block___76 *, int);
	int (*quota_sync)(struct super_block___76 *, int);
	int (*get_info)(struct super_block___76 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___76 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___76 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___76 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___76 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___76 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___76 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___76 *, unsigned int);
};

struct swap_info_struct___15;

struct address_space_operations___75 {
	int (*writepage)(struct page___75 *, struct writeback_control *);
	int (*readpage)(struct file___75 *, struct page___75 *);
	int (*writepages)(struct address_space___75 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___75 *);
	int (*readpages)(struct file___75 *, struct address_space___75 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___75 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___75 **, void **);
	int (*write_end)(struct file___75 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___75 *, void *);
	sector_t (*bmap)(struct address_space___75 *, sector_t);
	void (*invalidatepage)(struct page___75 *, long unsigned int);
	int (*releasepage)(struct page___75 *, gfp_t);
	void (*freepage)(struct page___75 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___75 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___75 *, struct page___75 *, struct page___75 *, enum migrate_mode);
	int (*launder_page)(struct page___75 *);
	int (*is_partially_uptodate)(struct page___75 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___75 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___75 *, struct page___75 *);
	int (*swap_activate)(struct swap_info_struct___15 *, struct file___75 *, sector_t *);
	void (*swap_deactivate)(struct file___75 *);
	void (*invalidatepage_range)(struct page___75 *, unsigned int, unsigned int);
};

struct swap_info_struct___15 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___75 *bdev;
	struct file___75 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___9 {
	struct backing_dev_info___9 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___9 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___9 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___59 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___76 *debug_dir;
	struct dentry___76 *debug_stats;
};

struct hd_struct___9 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___59 __dev;
	struct kobject___3 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___9;

struct gendisk___9 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___9 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___9 *part_tbl;
	struct hd_struct___9 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue___8 *queue;
	void *private_data;
	int flags;
	struct device___59 *driverfs_dev;
	struct kobject___3 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___8 {
	struct request_queue___8 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___8(struct request_queue___8 *);

typedef void make_request_fn___8(struct request_queue___8 *, struct bio___8 *);

struct request___8;

typedef int prep_rq_fn___8(struct request_queue___8 *, struct request___8 *);

struct bvec_merge_data___8;

typedef int merge_bvec_fn___8(struct request_queue___8 *, struct bvec_merge_data___8 *, struct bio_vec___8 *);

typedef void softirq_done_fn___8(struct request___8 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___8(struct request___8 *);

typedef int dma_drain_needed_fn___8(struct request___8 *);

typedef int lld_busy_fn___8(struct request_queue___8 *);

struct bsg_class_device___8 {
	struct device___59 *class_dev;
	struct device___59 *parent;
	int minor;
	struct request_queue___8 *queue;
	struct kref ref;
	void (*release)(struct device___59 *);
};

typedef void unprep_rq_fn___8(struct request_queue___8 *, struct request___8 *);

struct elevator_queue___8;

struct blk_queue_tag___8;

struct request_queue___8 {
	struct list_head queue_head;
	struct request___8 *last_merge;
	struct elevator_queue___8 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___8 root_rl;
	request_fn_proc___8 *request_fn;
	make_request_fn___8 *make_request_fn;
	prep_rq_fn___8 *prep_rq_fn;
	merge_bvec_fn___8 *merge_bvec_fn;
	softirq_done_fn___8 *softirq_done_fn;
	rq_timed_out_fn___8 *rq_timed_out_fn;
	dma_drain_needed_fn___8 *dma_drain_needed;
	lld_busy_fn___8 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___8 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___9 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___3 kobj;
	struct kobject___3 mq_kobj;
	struct device___59 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___8 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___8 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___76 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___8 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___8 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___8 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___75 {
	struct dentry___76 * (*lookup)(struct inode___76 *, struct dentry___76 *, unsigned int);
	void * (*follow_link)(struct dentry___76 *, struct nameidata *);
	int (*permission)(struct inode___76 *, int);
	struct posix_acl * (*get_acl)(struct inode___76 *, int);
	int (*readlink)(struct dentry___76 *, char *, int);
	void (*put_link)(struct dentry___76 *, struct nameidata *, void *);
	int (*create)(struct inode___76 *, struct dentry___76 *, umode_t, bool);
	int (*link)(struct dentry___76 *, struct inode___76 *, struct dentry___76 *);
	int (*unlink)(struct inode___76 *, struct dentry___76 *);
	int (*symlink)(struct inode___76 *, struct dentry___76 *, const char *);
	int (*mkdir)(struct inode___76 *, struct dentry___76 *, umode_t);
	int (*rmdir)(struct inode___76 *, struct dentry___76 *);
	int (*mknod)(struct inode___76 *, struct dentry___76 *, umode_t, dev_t);
	int (*rename)(struct inode___76 *, struct dentry___76 *, struct inode___76 *, struct dentry___76 *);
	int (*setattr)(struct dentry___76 *, struct iattr___76 *);
	int (*getattr)(struct vfsmount *, struct dentry___76 *, struct kstat *);
	int (*setxattr)(struct dentry___76 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___76 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___76 *, char *, size_t);
	int (*removexattr)(struct dentry___76 *, const char *);
	int (*fiemap)(struct inode___76 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___76 *, struct timespec *, int);
	int (*atomic_open)(struct inode___76 *, struct dentry___76 *, struct file___75 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___75 {
	struct module___42 *owner;
	loff_t (*llseek)(struct file___75 *, loff_t, int);
	ssize_t (*read)(struct file___75 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___75 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___75 *, void *, filldir_t);
	unsigned int (*poll)(struct file___75 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___75 *, struct vm_area_struct___79 *);
	int (*open)(struct inode___76 *, struct file___75 *);
	int (*flush)(struct file___75 *, fl_owner_t);
	int (*release)(struct inode___76 *, struct file___75 *);
	int (*fsync)(struct file___75 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___75 *, int);
	int (*lock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*sendpage)(struct file___75 *, struct page___75 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___75 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___75 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___75 *, long int, struct file_lock___75 **, void **);
		struct {
			int (*setlease)(struct file___75 *, long int, struct file_lock___75 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___75 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___75 *);
};

struct fasync_struct___75;

struct file_lock_operations___75;

struct lock_manager_operations___75;

struct file_lock___75 {
	struct file_lock___75 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___38 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___75 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___75 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___75 *fl_ops;
	const struct lock_manager_operations___75 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___75 {
	void (*fl_copy_lock)(struct file_lock___75 *, struct file_lock___75 *);
	void (*fl_release_private)(struct file_lock___75 *);
};

struct lock_manager_operations___75 {
	int (*lm_compare_owner)(struct file_lock___75 *, struct file_lock___75 *);
	long unsigned int (*lm_owner_key)(struct file_lock___75 *);
	void (*lm_notify)(struct file_lock___75 *);
	int (*lm_grant)(struct file_lock___75 *, struct file_lock___75 *, int);
	void (*lm_break)(struct file_lock___75 *);
	int (*lm_change)(struct file_lock___75 **, int);
};

struct fasync_struct___75 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___75 *fa_next;
	struct file___75 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___75 {
	const char *name;
	int fs_flags;
	struct dentry___76 * (*mount)(struct file_system_type___75 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___76 *);
	struct module___42 *owner;
	struct file_system_type___75 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___75 {
	struct inode___76 * (*alloc_inode)(struct super_block___76 *);
	void (*destroy_inode)(struct inode___76 *);
	void (*dirty_inode)(struct inode___76 *, int);
	int (*write_inode)(struct inode___76 *, struct writeback_control *);
	int (*drop_inode)(struct inode___76 *);
	void (*evict_inode)(struct inode___76 *);
	void (*put_super)(struct super_block___76 *);
	int (*sync_fs)(struct super_block___76 *, int);
	int (*freeze_fs)(struct super_block___76 *);
	int (*unfreeze_fs)(struct super_block___76 *);
	int (*statfs)(struct dentry___76 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___76 *, int *, char *);
	void (*umount_begin)(struct super_block___76 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___76 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___76 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___76 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___76 *);
	ssize_t (*quota_read)(struct super_block___76 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___76 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___76 *);
	int (*bdev_try_to_free_page)(struct super_block___76 *, struct page___75 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___76 *);
	void (*free_cached_objects)(struct super_block___76 *, int);
};

struct xattr_handler___47 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___76 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___76 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___76 *, const char *, const void *, size_t, int, int);
};

struct disk_part_tbl___9 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___9 *last_lookup;
	struct hd_struct___9 *part[0];
};

struct xol_area___75 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___75 *page;
	long unsigned int vaddr;
};

struct vm_fault___63;

struct vm_operations_struct___66 {
	void (*open)(struct vm_area_struct___79 *);
	void (*close)(struct vm_area_struct___79 *);
	int (*fault)(struct vm_area_struct___79 *, struct vm_fault___63 *);
	int (*page_mkwrite)(struct vm_area_struct___79 *, struct vm_fault___63 *);
	int (*access)(struct vm_area_struct___79 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___79 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___79 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___79 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___79 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___75 {
	struct task_struct___75 *task;
	struct core_thread___75 *next;
};

struct core_state___75 {
	atomic_t nr_threads;
	struct core_thread___75 dumper;
	struct completion startup;
};

struct vm_fault___63 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___75 *page;
};

struct signal_struct___75 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___75 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___75 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___38 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___38 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___76 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___47 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___47 *subsys[11];
	struct callback_head callback_head;
};

struct io_cq___8 {
	struct request_queue___8 *q;
	struct io_context___8 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___66 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___8(struct request___8 *, int);

struct request___8 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___8 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___8 *bio;
	struct bio___8 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___8 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___8 *saved_end_io;
		} flush;
	};
	struct gendisk___9 *rq_disk;
	struct hd_struct___9 *part;
	long unsigned int start_time;
	struct request_list___8 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___8 *end_io;
	void *end_io_data;
	struct request___8 *next_rq;
};

typedef int elevator_merge_fn___8(struct request_queue___8 *, struct request___8 **, struct bio___8 *);

typedef void elevator_merge_req_fn___8(struct request_queue___8 *, struct request___8 *, struct request___8 *);

typedef void elevator_merged_fn___8(struct request_queue___8 *, struct request___8 *, int);

typedef int elevator_allow_merge_fn___8(struct request_queue___8 *, struct request___8 *, struct bio___8 *);

typedef void elevator_bio_merged_fn___8(struct request_queue___8 *, struct request___8 *, struct bio___8 *);

typedef int elevator_dispatch_fn___8(struct request_queue___8 *, int);

typedef void elevator_add_req_fn___8(struct request_queue___8 *, struct request___8 *);

typedef struct request___8 *elevator_request_list_fn___8(struct request_queue___8 *, struct request___8 *);

typedef void elevator_completed_req_fn___8(struct request_queue___8 *, struct request___8 *);

typedef int elevator_may_queue_fn___8(struct request_queue___8 *, int);

typedef void elevator_init_icq_fn___8(struct io_cq___8 *);

typedef void elevator_exit_icq_fn___8(struct io_cq___8 *);

typedef int elevator_set_req_fn___8(struct request_queue___8 *, struct request___8 *, struct bio___8 *, gfp_t);

typedef void elevator_put_req_fn___8(struct request___8 *);

typedef void elevator_activate_req_fn___8(struct request_queue___8 *, struct request___8 *);

typedef void elevator_deactivate_req_fn___8(struct request_queue___8 *, struct request___8 *);

struct elevator_type___8;

typedef int elevator_init_fn___8(struct request_queue___8 *, struct elevator_type___8 *);

typedef void elevator_exit_fn___8(struct elevator_queue___8 *);

struct elevator_ops___8 {
	elevator_merge_fn___8 *elevator_merge_fn;
	elevator_merged_fn___8 *elevator_merged_fn;
	elevator_merge_req_fn___8 *elevator_merge_req_fn;
	elevator_allow_merge_fn___8 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___8 *elevator_bio_merged_fn;
	elevator_dispatch_fn___8 *elevator_dispatch_fn;
	elevator_add_req_fn___8 *elevator_add_req_fn;
	elevator_activate_req_fn___8 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___8 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___8 *elevator_completed_req_fn;
	elevator_request_list_fn___8 *elevator_former_req_fn;
	elevator_request_list_fn___8 *elevator_latter_req_fn;
	elevator_init_icq_fn___8 *elevator_init_icq_fn;
	elevator_exit_icq_fn___8 *elevator_exit_icq_fn;
	elevator_set_req_fn___8 *elevator_set_req_fn;
	elevator_put_req_fn___8 *elevator_put_req_fn;
	elevator_may_queue_fn___8 *elevator_may_queue_fn;
	elevator_init_fn___8 *elevator_init_fn;
	elevator_exit_fn___8 *elevator_exit_fn;
};

struct elv_fs_entry___8;

struct elevator_type___8 {
	struct kmem_cache___66 *icq_cache;
	struct elevator_ops___8 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___8 *elevator_attrs;
	char elevator_name[16];
	struct module___42 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___8 {
	struct elevator_type___8 *type;
	void *elevator_data;
	struct kobject___3 kobj;
	struct mutex___76 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___8 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___8 *, char *);
	ssize_t (*store)(struct elevator_queue___8 *, const char *, size_t);
};

struct bvec_merge_data___8 {
	struct block_device___75 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___8 {
	struct request___8 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct cgroupfs_root___47;

struct cgroup___47 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___47 *parent;
	struct dentry___76 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___47 *subsys[11];
	struct cgroupfs_root___47 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___76 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___47 {
	struct super_block___76 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___47 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___18 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___76 *, struct file___75 *);
	ssize_t (*read)(struct cgroup___47 *, struct cftype___18 *, struct file___75 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___47 *, struct cftype___18 *);
	s64 (*read_s64)(struct cgroup___47 *, struct cftype___18 *);
	int (*read_map)(struct cgroup___47 *, struct cftype___18 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___47 *, struct cftype___18 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___47 *, struct cftype___18 *, struct file___75 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___47 *, struct cftype___18 *, u64);
	int (*write_s64)(struct cgroup___47 *, struct cftype___18 *, s64);
	int (*write_string)(struct cgroup___47 *, struct cftype___18 *, const char *);
	int (*trigger)(struct cgroup___47 *, unsigned int);
	int (*release)(struct inode___76 *, struct file___75 *);
	int (*register_event)(struct cgroup___47 *, struct cftype___18 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___47 *, struct cftype___18 *, struct eventfd_ctx *);
};

struct cftype_set___17 {
	struct list_head node;
	struct cftype___18 *cfts;
};

struct task_and_cgroup___17 {
	struct task_struct___75 *task;
	struct cgroup___47 *cgrp;
	struct css_set___47 *cg;
};

struct cgroup_taskset___17 {
	struct task_and_cgroup___17 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___47 *cur_cgrp;
};

struct cgroup_subsys___17 {
	struct cgroup_subsys_state___47 * (*css_alloc)(struct cgroup___47 *);
	int (*css_online)(struct cgroup___47 *);
	void (*css_offline)(struct cgroup___47 *);
	void (*css_free)(struct cgroup___47 *);
	int (*can_attach)(struct cgroup___47 *, struct cgroup_taskset___17 *);
	void (*cancel_attach)(struct cgroup___47 *, struct cgroup_taskset___17 *);
	void (*attach)(struct cgroup___47 *, struct cgroup_taskset___17 *);
	void (*fork)(struct task_struct___75 *);
	void (*exit)(struct cgroup___47 *, struct cgroup___47 *, struct task_struct___75 *);
	void (*bind)(struct cgroup___47 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___47 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___18 *base_cftypes;
	struct cftype_set___17 base_cftset;
	struct module___42 *module;
};

typedef struct {
	long unsigned int val;
} swp_entry_t;

struct swap_map_page {
	sector_t entries[511];
	sector_t next_swap;
};

struct swap_map_page_list {
	struct swap_map_page *map;
	struct swap_map_page_list *next;
};

struct swap_map_handle {
	struct swap_map_page *cur;
	struct swap_map_page_list *maps;
	sector_t cur_swap;
	sector_t first_sector;
	unsigned int k;
	long unsigned int reqd_free_pages;
	u32 crc32;
};

struct swsusp_header {
	char reserved[4060];
	u32 crc32;
	sector_t image;
	unsigned int flags;
	char orig_sig[10];
	char sig[10];
};

struct swsusp_extent {
	struct rb_node node;
	long unsigned int start;
	long unsigned int end;
};

struct crc_data {
	struct task_struct___75 *thr;
	atomic_t ready;
	atomic_t stop;
	unsigned int run_threads;
	wait_queue_head_t go;
	wait_queue_head_t done;
	u32 *crc32;
	size_t *unc_len[3];
	unsigned char *unc[3];
};

struct cmp_data {
	struct task_struct___75 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[131072];
	unsigned char cmp[143360];
	unsigned char wrk[16384];
};

struct dec_data {
	struct task_struct___75 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[131072];
	unsigned char cmp[143360];
};

struct thread_info___35 {
	struct task_struct___74 *task;
	struct exec_domain___19 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

typedef s64 compat_loff_t;

struct miscdevice___4 {
	int minor;
	const char *name;
	const struct file_operations___74 *fops;
	struct list_head list;
	struct device___58 *parent;
	struct device___58 *this_device;
	const char *nodename;
	umode_t mode;
};

struct resume_swap_area {
	__kernel_loff_t offset;
	__u32 dev;
} __attribute__((packed));

struct snapshot_data {
	struct snapshot_handle handle;
	int swap;
	int mode;
	char frozen;
	char ready;
	char platform_support;
};

struct compat_resume_swap_area {
	compat_loff_t offset;
	u32 dev;
} __attribute__((packed));

enum rq_flag_bits {
	__REQ_WRITE = 0,
	__REQ_FAILFAST_DEV = 1,
	__REQ_FAILFAST_TRANSPORT = 2,
	__REQ_FAILFAST_DRIVER = 3,
	__REQ_SYNC = 4,
	__REQ_META = 5,
	__REQ_PRIO = 6,
	__REQ_DISCARD = 7,
	__REQ_SECURE = 8,
	__REQ_WRITE_SAME = 9,
	__REQ_NOIDLE = 10,
	__REQ_FUA = 11,
	__REQ_FLUSH = 12,
	__REQ_RAHEAD = 13,
	__REQ_THROTTLED = 14,
	__REQ_ALI_PRIV = 15,
	__REQ_SORTED = 16,
	__REQ_SOFTBARRIER = 17,
	__REQ_NOMERGE = 18,
	__REQ_STARTED = 19,
	__REQ_DONTPREP = 20,
	__REQ_QUEUED = 21,
	__REQ_ELVPRIV = 22,
	__REQ_FAILED = 23,
	__REQ_QUIET = 24,
	__REQ_PREEMPT = 25,
	__REQ_ALLOCED = 26,
	__REQ_COPY_USER = 27,
	__REQ_FLUSH_SEQ = 28,
	__REQ_IO_STAT = 29,
	__REQ_MIXED_MERGE = 30,
	__REQ_KERNEL = 31,
	__REQ_PM = 32,
	__REQ_END = 33,
	__REQ_HASHED = 34,
	__REQ_MQ_INFLIGHT = 35,
	__REQ_NO_TIMEOUT = 36,
	__REQ_NR_BITS = 37,
};

struct sysrq_key_op {
	void (*handler)(int);
	char *help_msg;
	char *action_msg;
	int enable_mask;
};

struct page___76;

typedef struct page___76 *pgtable_t___76;

struct address_space___76;

struct kmem_cache___67;

struct page___76 {
	long unsigned int flags;
	struct address_space___76 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___76 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___76 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___67 *slab_cache;
		struct page___76 *first_page;
	};
	long: 64;
};

struct task_struct___76;

struct pv_cpu_ops___76 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___35 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___35 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___76 *);
	void (*end_context_switch)(struct task_struct___76 *);
};

struct cfs_rq___8;

struct sched_entity___8 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	struct sched_entity___8 *parent;
	struct cfs_rq___8 *cfs_rq;
	struct cfs_rq___8 *my_q;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_rq___8;

struct sched_rt_entity___8 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	struct sched_rt_entity___8 *back;
	struct sched_rt_entity___8 *parent;
	struct rt_rq___8 *rt_rq;
	struct rt_rq___8 *my_q;
};

struct mutex___77 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___76 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___73 {
	struct page___76 *page;
	__u32 offset;
	__u32 size;
};

struct sched_class___8;

struct task_group___8;

struct mm_struct___80;

struct signal_struct___76;

struct css_set___48;

struct task_struct___76 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___76 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___8 *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group___8 *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___80 *mm;
	struct mm_struct___80 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___76 *real_parent;
	struct task_struct___76 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___76 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___38 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___76 = 0,
		VTIME_USER___76 = 1,
		VTIME_SYS___76 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___35 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___76 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___48 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___77 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___73 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___80 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___80 *, struct mm_struct___80 *);
	void (*dup_mmap)(struct mm_struct___80 *, struct mm_struct___80 *);
	void (*exit_mmap)(struct mm_struct___80 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___80 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___80 *);
	void (*pgd_free)(struct mm_struct___80 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___80 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___80 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___80 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___80 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___80 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___80 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___80 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___80 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___80 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___80 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___80 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___77 lock;
	void *vdso;
} mm_context_t___77;

struct xol_area___76;

struct uprobes_state___76 {
	struct xol_area___76 *xol_area;
};

struct vm_area_struct___80;

struct file___76;

struct core_state___76;

struct mm_struct___80 {
	struct vm_area_struct___80 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___80 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___80 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___77 context;
	long unsigned int flags;
	struct core_state___76 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___76 *owner;
	struct file___76 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___76 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___36 {
	struct task_struct___76 *task;
	struct exec_domain___19 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___76 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___76 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___67;

struct memcg_cache_params___67;

struct kmem_cache___67 {
	struct kmem_cache_cpu___67 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___67 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___77;

struct address_space_operations___76;

struct address_space___76 {
	struct inode___77 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___77 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___76 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___77;

struct path___76 {
	struct vfsmount *mnt;
	struct dentry___77 *dentry;
};

struct file_operations___76;

struct file___76 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___76 f_path;
	struct inode___77 *f_inode;
	const struct file_operations___76 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___76 *f_mapping;
	struct mutex___77 f_pos_lock;
};

struct vm_operations_struct___67;

struct vm_area_struct___80 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___80 *vm_next;
	struct vm_area_struct___80 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___80 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___67 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___76 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___64;

struct vm_operations_struct___67 {
	void (*open)(struct vm_area_struct___80 *);
	void (*close)(struct vm_area_struct___80 *);
	int (*fault)(struct vm_area_struct___80 *, struct vm_fault___64 *);
	int (*page_mkwrite)(struct vm_area_struct___80 *, struct vm_fault___64 *);
	int (*access)(struct vm_area_struct___80 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___80 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___80 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___80 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___80 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___76 {
	struct task_struct___76 *task;
	struct core_thread___76 *next;
};

struct core_state___76 {
	atomic_t nr_threads;
	struct core_thread___76 dumper;
	struct completion startup;
};

struct smp_ops___76 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___76 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___76;

struct lruvec___76 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___76 *zone;
};

struct pglist_data___76;

struct zone___76 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___76 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___76 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___76 {
	struct zone___76 *zone;
	int zone_idx;
};

struct zonelist___76 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___76 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___76 {
	struct zone___76 node_zones[4];
	struct zonelist___76 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___76 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct autogroup___8;

struct signal_struct___76 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___76 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___76 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___38 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___38 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___8 *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___77 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct autogroup___8 {
	struct kref kref;
	struct task_group___8 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct rq___8;

struct cfs_rq___8 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root tasks_timeline;
	struct rb_node *rb_leftmost;
	struct sched_entity___8 *curr;
	struct sched_entity___8 *next;
	struct sched_entity___8 *last;
	struct sched_entity___8 *skip;
	unsigned int nr_spread_over;
	u64 runnable_load_avg;
	u64 blocked_load_avg;
	atomic64_t decay_counter;
	atomic64_t removed_load;
	u64 last_decay;
	u32 tg_runnable_contrib;
	u64 tg_load_contrib;
	long unsigned int h_load;
	struct rq___8 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___8 *tg;
	int runtime_enabled;
	u64 runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
};

struct rt_rq___8 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___8 *rq;
	struct list_head leaf_rt_rq_list;
	struct task_group___8 *tg;
};

struct sched_class___8 {
	const struct sched_class___8 *next;
	void (*enqueue_task)(struct rq___8 *, struct task_struct___76 *, int);
	void (*dequeue_task)(struct rq___8 *, struct task_struct___76 *, int);
	void (*yield_task)(struct rq___8 *);
	bool (*yield_to_task)(struct rq___8 *, struct task_struct___76 *, bool);
	void (*check_preempt_curr)(struct rq___8 *, struct task_struct___76 *, int);
	struct task_struct___76 * (*pick_next_task)(struct rq___8 *);
	void (*put_prev_task)(struct rq___8 *, struct task_struct___76 *);
	int (*select_task_rq)(struct task_struct___76 *, int, int, int);
	void (*migrate_task_rq)(struct task_struct___76 *, int);
	void (*pre_schedule)(struct rq___8 *, struct task_struct___76 *);
	void (*post_schedule)(struct rq___8 *);
	void (*task_waking)(struct task_struct___76 *);
	void (*task_woken)(struct rq___8 *, struct task_struct___76 *);
	void (*set_cpus_allowed)(struct task_struct___76 *, const struct cpumask *);
	void (*rq_online)(struct rq___8 *);
	void (*rq_offline)(struct rq___8 *);
	void (*set_curr_task)(struct rq___8 *);
	void (*task_tick)(struct rq___8 *, struct task_struct___76 *, int);
	void (*task_fork)(struct task_struct___76 *);
	void (*switched_from)(struct rq___8 *, struct task_struct___76 *);
	void (*switched_to)(struct rq___8 *, struct task_struct___76 *);
	void (*prio_changed)(struct rq___8 *, struct task_struct___76 *, int);
	unsigned int (*get_rr_interval)(struct rq___8 *, struct task_struct___76 *);
	void (*task_move_group)(struct task_struct___76 *, int);
	void (*update_curr)(struct rq___8 *);
};

struct cgroup___48;

struct cgroup_subsys_state___48 {
	struct cgroup___48 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_group___8 {
	struct cgroup_subsys_state___48 css;
	struct sched_entity___8 **se;
	struct cfs_rq___8 **cfs_rq;
	long unsigned int shares;
	atomic_t load_weight;
	atomic64_t load_avg;
	atomic_t runnable_avg;
	struct sched_rt_entity___8 **rt_se;
	struct rt_rq___8 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___8 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___8 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
};

struct css_set___48 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___48 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___64 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___76 *page;
};

struct kmem_cache_cpu___67 {
	void **freelist;
	long unsigned int tid;
	struct page___76 *page;
	struct page___76 *partial;
};

struct memcg_cache_params___67 {
	bool is_root_cache;
	union {
		struct kmem_cache___67 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___67 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___48 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___77 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___77 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___77 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___76;

struct super_block___77;

struct dentry___77 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___77 *d_parent;
	struct qstr d_name;
	struct inode___77 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___76 *d_op;
	struct super_block___77 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___76;

struct file_lock___76;

struct dquot___76;

struct block_device___76;

struct inode___77 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___76 *i_op;
	struct super_block___77 *i_sb;
	struct address_space___76 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___77 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___76 *i_fop;
	struct file_lock___76 *i_flock;
	struct address_space___76 i_data;
	struct dquot___76 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___76 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___76 {
	int (*d_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_hash)(const struct dentry___77 *, struct qstr *);
	int (*d_compare)(const struct dentry___77 *, const struct dentry___77 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___77 *);
	void (*d_release)(struct dentry___77 *);
	void (*d_prune)(struct dentry___77 *);
	void (*d_iput)(struct dentry___77 *, struct inode___77 *);
	char * (*d_dname)(struct dentry___77 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___76 *);
	int (*d_manage)(struct dentry___77 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___76;

struct mem_dqinfo___76 {
	struct quota_format_type___76 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___76;

struct quota_info___76 {
	unsigned int flags;
	struct mutex___77 dqio_mutex;
	struct mutex___77 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___77 *files[2];
	struct mem_dqinfo___76 info[2];
	const struct quota_format_ops___76 *ops[2];
};

struct file_system_type___76;

struct super_operations___76;

struct dquot_operations___76;

struct quotactl_ops___76;

struct super_block___77 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___76 *s_type;
	const struct super_operations___76 *s_op;
	const struct dquot_operations___76 *dq_op;
	const struct quotactl_ops___76 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___77 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___48 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___76 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___76 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___77 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___76 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___76 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___77 *bd_inode;
	struct super_block___77 *bd_super;
	struct mutex___77 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___76 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___77 bd_fsfreeze_mutex;
};

struct iattr___77 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___76 *ia_file;
};

struct dquot___76 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___77 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___77 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___76 {
	int qf_fmt_id;
	const struct quota_format_ops___76 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___76 *qf_next;
};

struct quota_format_ops___76 {
	int (*check_quota_file)(struct super_block___77 *, int);
	int (*read_file_info)(struct super_block___77 *, int);
	int (*write_file_info)(struct super_block___77 *, int);
	int (*free_file_info)(struct super_block___77 *, int);
	int (*read_dqblk)(struct dquot___76 *);
	int (*commit_dqblk)(struct dquot___76 *);
	int (*release_dqblk)(struct dquot___76 *);
};

struct dquot_operations___76 {
	int (*write_dquot)(struct dquot___76 *);
	struct dquot___76 * (*alloc_dquot)(struct super_block___77 *, int);
	void (*destroy_dquot)(struct dquot___76 *);
	int (*acquire_dquot)(struct dquot___76 *);
	int (*release_dquot)(struct dquot___76 *);
	int (*mark_dirty)(struct dquot___76 *);
	int (*write_info)(struct super_block___77 *, int);
	qsize_t * (*get_reserved_space)(struct inode___77 *);
};

struct quotactl_ops___76 {
	int (*quota_on)(struct super_block___77 *, int, int, struct path___76 *);
	int (*quota_on_meta)(struct super_block___77 *, int, int);
	int (*quota_off)(struct super_block___77 *, int);
	int (*quota_sync)(struct super_block___77 *, int);
	int (*get_info)(struct super_block___77 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___77 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___77 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___77 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___77 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___77 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___77 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___77 *, unsigned int);
};

struct swap_info_struct___16;

struct address_space_operations___76 {
	int (*writepage)(struct page___76 *, struct writeback_control *);
	int (*readpage)(struct file___76 *, struct page___76 *);
	int (*writepages)(struct address_space___76 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___76 *);
	int (*readpages)(struct file___76 *, struct address_space___76 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___76 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___76 **, void **);
	int (*write_end)(struct file___76 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___76 *, void *);
	sector_t (*bmap)(struct address_space___76 *, sector_t);
	void (*invalidatepage)(struct page___76 *, long unsigned int);
	int (*releasepage)(struct page___76 *, gfp_t);
	void (*freepage)(struct page___76 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___76 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___76 *, struct page___76 *, struct page___76 *, enum migrate_mode);
	int (*launder_page)(struct page___76 *);
	int (*is_partially_uptodate)(struct page___76 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___76 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___76 *, struct page___76 *);
	int (*swap_activate)(struct swap_info_struct___16 *, struct file___76 *, sector_t *);
	void (*swap_deactivate)(struct file___76 *);
	void (*invalidatepage_range)(struct page___76 *, unsigned int, unsigned int);
};

struct swap_info_struct___16 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___76 *bdev;
	struct file___76 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___76 {
	struct dentry___77 * (*lookup)(struct inode___77 *, struct dentry___77 *, unsigned int);
	void * (*follow_link)(struct dentry___77 *, struct nameidata *);
	int (*permission)(struct inode___77 *, int);
	struct posix_acl * (*get_acl)(struct inode___77 *, int);
	int (*readlink)(struct dentry___77 *, char *, int);
	void (*put_link)(struct dentry___77 *, struct nameidata *, void *);
	int (*create)(struct inode___77 *, struct dentry___77 *, umode_t, bool);
	int (*link)(struct dentry___77 *, struct inode___77 *, struct dentry___77 *);
	int (*unlink)(struct inode___77 *, struct dentry___77 *);
	int (*symlink)(struct inode___77 *, struct dentry___77 *, const char *);
	int (*mkdir)(struct inode___77 *, struct dentry___77 *, umode_t);
	int (*rmdir)(struct inode___77 *, struct dentry___77 *);
	int (*mknod)(struct inode___77 *, struct dentry___77 *, umode_t, dev_t);
	int (*rename)(struct inode___77 *, struct dentry___77 *, struct inode___77 *, struct dentry___77 *);
	int (*setattr)(struct dentry___77 *, struct iattr___77 *);
	int (*getattr)(struct vfsmount *, struct dentry___77 *, struct kstat *);
	int (*setxattr)(struct dentry___77 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___77 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___77 *, char *, size_t);
	int (*removexattr)(struct dentry___77 *, const char *);
	int (*fiemap)(struct inode___77 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___77 *, struct timespec *, int);
	int (*atomic_open)(struct inode___77 *, struct dentry___77 *, struct file___76 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___76 {
	struct module *owner;
	loff_t (*llseek)(struct file___76 *, loff_t, int);
	ssize_t (*read)(struct file___76 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___76 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___76 *, void *, filldir_t);
	unsigned int (*poll)(struct file___76 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___76 *, struct vm_area_struct___80 *);
	int (*open)(struct inode___77 *, struct file___76 *);
	int (*flush)(struct file___76 *, fl_owner_t);
	int (*release)(struct inode___77 *, struct file___76 *);
	int (*fsync)(struct file___76 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___76 *, int);
	int (*lock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*sendpage)(struct file___76 *, struct page___76 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___76 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___76 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___76 *, long int, struct file_lock___76 **, void **);
		struct {
			int (*setlease)(struct file___76 *, long int, struct file_lock___76 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___76 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___76 *);
};

struct fasync_struct___76;

struct file_lock_operations___76;

struct lock_manager_operations___76;

struct file_lock___76 {
	struct file_lock___76 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___38 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___76 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___76 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___76 *fl_ops;
	const struct lock_manager_operations___76 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___76 {
	void (*fl_copy_lock)(struct file_lock___76 *, struct file_lock___76 *);
	void (*fl_release_private)(struct file_lock___76 *);
};

struct lock_manager_operations___76 {
	int (*lm_compare_owner)(struct file_lock___76 *, struct file_lock___76 *);
	long unsigned int (*lm_owner_key)(struct file_lock___76 *);
	void (*lm_notify)(struct file_lock___76 *);
	int (*lm_grant)(struct file_lock___76 *, struct file_lock___76 *, int);
	void (*lm_break)(struct file_lock___76 *);
	int (*lm_change)(struct file_lock___76 **, int);
};

struct fasync_struct___76 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___76 *fa_next;
	struct file___76 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___76 {
	const char *name;
	int fs_flags;
	struct dentry___77 * (*mount)(struct file_system_type___76 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___77 *);
	struct module *owner;
	struct file_system_type___76 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___76 {
	struct inode___77 * (*alloc_inode)(struct super_block___77 *);
	void (*destroy_inode)(struct inode___77 *);
	void (*dirty_inode)(struct inode___77 *, int);
	int (*write_inode)(struct inode___77 *, struct writeback_control *);
	int (*drop_inode)(struct inode___77 *);
	void (*evict_inode)(struct inode___77 *);
	void (*put_super)(struct super_block___77 *);
	int (*sync_fs)(struct super_block___77 *, int);
	int (*freeze_fs)(struct super_block___77 *);
	int (*unfreeze_fs)(struct super_block___77 *);
	int (*statfs)(struct dentry___77 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___77 *, int *, char *);
	void (*umount_begin)(struct super_block___77 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___77 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___77 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___77 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___77 *);
	ssize_t (*quota_read)(struct super_block___77 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___77 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___77 *);
	int (*bdev_try_to_free_page)(struct super_block___77 *, struct page___76 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___77 *);
	void (*free_cached_objects)(struct super_block___77 *, int);
};

struct cgroupfs_root___48;

struct cgroup___48 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___48 *parent;
	struct dentry___77 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___48 *subsys[11];
	struct cgroupfs_root___48 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___77 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___48 {
	struct super_block___77 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___48 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___19 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___77 *, struct file___76 *);
	ssize_t (*read)(struct cgroup___48 *, struct cftype___19 *, struct file___76 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___48 *, struct cftype___19 *);
	s64 (*read_s64)(struct cgroup___48 *, struct cftype___19 *);
	int (*read_map)(struct cgroup___48 *, struct cftype___19 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___48 *, struct cftype___19 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___48 *, struct cftype___19 *, struct file___76 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___48 *, struct cftype___19 *, u64);
	int (*write_s64)(struct cgroup___48 *, struct cftype___19 *, s64);
	int (*write_string)(struct cgroup___48 *, struct cftype___19 *, const char *);
	int (*trigger)(struct cgroup___48 *, unsigned int);
	int (*release)(struct inode___77 *, struct file___76 *);
	int (*register_event)(struct cgroup___48 *, struct cftype___19 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___48 *, struct cftype___19 *, struct eventfd_ctx *);
};

struct cftype_set___18 {
	struct list_head node;
	struct cftype___19 *cfts;
};

struct task_and_cgroup___18 {
	struct task_struct___76 *task;
	struct cgroup___48 *cgrp;
	struct css_set___48 *cg;
};

struct cgroup_taskset___18 {
	struct task_and_cgroup___18 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___48 *cur_cgrp;
};

struct cgroup_subsys___18 {
	struct cgroup_subsys_state___48 * (*css_alloc)(struct cgroup___48 *);
	int (*css_online)(struct cgroup___48 *);
	void (*css_offline)(struct cgroup___48 *);
	void (*css_free)(struct cgroup___48 *);
	int (*can_attach)(struct cgroup___48 *, struct cgroup_taskset___18 *);
	void (*cancel_attach)(struct cgroup___48 *, struct cgroup_taskset___18 *);
	void (*attach)(struct cgroup___48 *, struct cgroup_taskset___18 *);
	void (*fork)(struct task_struct___76 *);
	void (*exit)(struct cgroup___48 *, struct cgroup___48 *, struct task_struct___76 *);
	void (*bind)(struct cgroup___48 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___48 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___19 *base_cftypes;
	struct cftype_set___18 base_cftset;
	struct module *module;
};

struct tlb_state___24 {
	struct mm_struct___80 *active_mm;
	int state;
};

struct rq___8 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	u64 nohz_stamp;
	long unsigned int nohz_flags;
	long unsigned int last_sched_tick;
	int skip_clock_update;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	struct cfs_rq___8 cfs;
	struct rt_rq___8 rt;
	struct list_head leaf_cfs_rq_list;
	long unsigned int h_load_throttle;
	struct list_head leaf_rt_rq_list;
	long unsigned int nr_uninterruptible;
	struct task_struct___76 *curr;
	struct task_struct___76 *idle;
	struct task_struct___76 *stop;
	long unsigned int next_balance;
	struct mm_struct___80 *prev_mm;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_power;
	unsigned char idle_balance;
	int post_schedule;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rt_avg;
	u64 age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	struct call_single_data___2 hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct sched_avg avg;
};

enum profile_type {
	PROFILE_TASK_EXIT = 0,
	PROFILE_MUNMAP = 1,
};

struct profile_hit {
	u32 pc;
	u32 hits;
};

struct page___77;

typedef struct page___77 *pgtable_t___77;

struct address_space___77;

struct page___77 {
	long unsigned int flags;
	struct address_space___77 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___77 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___77 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___77 *first_page;
	};
	long: 64;
};

struct mm_struct___81;

struct pv_mmu_ops___81 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___81 *, struct mm_struct___81 *);
	void (*dup_mmap)(struct mm_struct___81 *, struct mm_struct___81 *);
	void (*exit_mmap)(struct mm_struct___81 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___81 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___81 *);
	void (*pgd_free)(struct mm_struct___81 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___81 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___81 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___81 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___81 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___81 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___81 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___81 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___81 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___81 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___81 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___81 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct xol_area___77;

struct uprobes_state___77 {
	struct xol_area___77 *xol_area;
};

struct vm_area_struct___81;

struct file___77;

struct mm_struct___81 {
	struct vm_area_struct___81 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___81 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___81 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___73 context;
	long unsigned int flags;
	struct core_state___76 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file___77 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___77 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef __s64 time64_t;

struct xol_area___77 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___77 *page;
	long unsigned int vaddr;
};

struct inode___78;

struct address_space_operations___77;

struct address_space___77 {
	struct inode___78 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___73 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___77 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___78;

struct path___77 {
	struct vfsmount *mnt;
	struct dentry___78 *dentry;
};

struct file_operations___77;

struct file___77 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___77 f_path;
	struct inode___78 *f_inode;
	const struct file_operations___77 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___77 *f_mapping;
	struct mutex___73 f_pos_lock;
};

struct vm_operations_struct___68;

struct vm_area_struct___81 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___81 *vm_next;
	struct vm_area_struct___81 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___81 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___68 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___77 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___65;

struct vm_operations_struct___68 {
	void (*open)(struct vm_area_struct___81 *);
	void (*close)(struct vm_area_struct___81 *);
	int (*fault)(struct vm_area_struct___81 *, struct vm_fault___65 *);
	int (*page_mkwrite)(struct vm_area_struct___81 *, struct vm_fault___65 *);
	int (*access)(struct vm_area_struct___81 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___81 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___81 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___81 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___81 *, long unsigned int, long unsigned int, long unsigned int);
};

struct vm_fault___65 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___77 *page;
};

struct cdev___26 {
	struct kobject___3 kobj;
	struct module___42 *owner;
	const struct file_operations___77 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___45;

struct file_lock___77;

struct file_operations___77 {
	struct module___42 *owner;
	loff_t (*llseek)(struct file___77 *, loff_t, int);
	ssize_t (*read)(struct file___77 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___77 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___77 *, void *, filldir_t);
	unsigned int (*poll)(struct file___77 *, struct poll_table_struct___45 *);
	long int (*unlocked_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___77 *, struct vm_area_struct___81 *);
	int (*open)(struct inode___78 *, struct file___77 *);
	int (*flush)(struct file___77 *, fl_owner_t);
	int (*release)(struct inode___78 *, struct file___77 *);
	int (*fsync)(struct file___77 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___77 *, int);
	int (*lock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*sendpage)(struct file___77 *, struct page___77 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___77 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___77 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___77 *, long int, struct file_lock___77 **, void **);
		struct {
			int (*setlease)(struct file___77 *, long int, struct file_lock___77 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___77 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___53 *, struct file___77 *);
};

struct dentry_operations___77;

struct super_block___78;

struct dentry___78 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___78 *d_parent;
	struct qstr d_name;
	struct inode___78 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___77 *d_op;
	struct super_block___78 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___77;

struct dquot___77;

struct block_device___77;

struct inode___78 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___77 *i_op;
	struct super_block___78 *i_sb;
	struct address_space___77 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___73 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___77 *i_fop;
	struct file_lock___77 *i_flock;
	struct address_space___77 i_data;
	struct dquot___77 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___77 *i_bdev;
		struct cdev___26 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___77 {
	int (*d_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_hash)(const struct dentry___78 *, struct qstr *);
	int (*d_compare)(const struct dentry___78 *, const struct dentry___78 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___78 *);
	void (*d_release)(struct dentry___78 *);
	void (*d_prune)(struct dentry___78 *);
	void (*d_iput)(struct dentry___78 *, struct inode___78 *);
	char * (*d_dname)(struct dentry___78 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___77 *);
	int (*d_manage)(struct dentry___78 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___77;

struct mem_dqinfo___77 {
	struct quota_format_type___77 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___77;

struct quota_info___77 {
	unsigned int flags;
	struct mutex___73 dqio_mutex;
	struct mutex___73 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___78 *files[2];
	struct mem_dqinfo___77 info[2];
	const struct quota_format_ops___77 *ops[2];
};

struct file_system_type___77;

struct super_operations___77;

struct dquot_operations___77;

struct quotactl_ops___77;

struct super_block___78 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___77 *s_type;
	const struct super_operations___77 *s_op;
	const struct dquot_operations___77 *dq_op;
	const struct quotactl_ops___77 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___78 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___77 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___77 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___73 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___77 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___77 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___78 *bd_inode;
	struct super_block___78 *bd_super;
	struct mutex___73 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___77 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___73 bd_fsfreeze_mutex;
};

struct iattr___78 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___77 *ia_file;
};

struct dquot___77 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___73 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___78 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___77 {
	int qf_fmt_id;
	const struct quota_format_ops___77 *qf_ops;
	struct module___42 *qf_owner;
	struct quota_format_type___77 *qf_next;
};

struct quota_format_ops___77 {
	int (*check_quota_file)(struct super_block___78 *, int);
	int (*read_file_info)(struct super_block___78 *, int);
	int (*write_file_info)(struct super_block___78 *, int);
	int (*free_file_info)(struct super_block___78 *, int);
	int (*read_dqblk)(struct dquot___77 *);
	int (*commit_dqblk)(struct dquot___77 *);
	int (*release_dqblk)(struct dquot___77 *);
};

struct dquot_operations___77 {
	int (*write_dquot)(struct dquot___77 *);
	struct dquot___77 * (*alloc_dquot)(struct super_block___78 *, int);
	void (*destroy_dquot)(struct dquot___77 *);
	int (*acquire_dquot)(struct dquot___77 *);
	int (*release_dquot)(struct dquot___77 *);
	int (*mark_dirty)(struct dquot___77 *);
	int (*write_info)(struct super_block___78 *, int);
	qsize_t * (*get_reserved_space)(struct inode___78 *);
};

struct quotactl_ops___77 {
	int (*quota_on)(struct super_block___78 *, int, int, struct path___77 *);
	int (*quota_on_meta)(struct super_block___78 *, int, int);
	int (*quota_off)(struct super_block___78 *, int);
	int (*quota_sync)(struct super_block___78 *, int);
	int (*get_info)(struct super_block___78 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___78 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___78 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___78 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___78 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___78 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___78 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___78 *, unsigned int);
};

struct address_space_operations___77 {
	int (*writepage)(struct page___77 *, struct writeback_control *);
	int (*readpage)(struct file___77 *, struct page___77 *);
	int (*writepages)(struct address_space___77 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___77 *);
	int (*readpages)(struct file___77 *, struct address_space___77 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___77 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___77 **, void **);
	int (*write_end)(struct file___77 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___77 *, void *);
	sector_t (*bmap)(struct address_space___77 *, sector_t);
	void (*invalidatepage)(struct page___77 *, long unsigned int);
	int (*releasepage)(struct page___77 *, gfp_t);
	void (*freepage)(struct page___77 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___77 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___77 *, struct page___77 *, struct page___77 *, enum migrate_mode);
	int (*launder_page)(struct page___77 *);
	int (*is_partially_uptodate)(struct page___77 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___77 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___77 *, struct page___77 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___77 *, sector_t *);
	void (*swap_deactivate)(struct file___77 *);
	void (*invalidatepage_range)(struct page___77 *, unsigned int, unsigned int);
};

struct inode_operations___77 {
	struct dentry___78 * (*lookup)(struct inode___78 *, struct dentry___78 *, unsigned int);
	void * (*follow_link)(struct dentry___78 *, struct nameidata *);
	int (*permission)(struct inode___78 *, int);
	struct posix_acl * (*get_acl)(struct inode___78 *, int);
	int (*readlink)(struct dentry___78 *, char *, int);
	void (*put_link)(struct dentry___78 *, struct nameidata *, void *);
	int (*create)(struct inode___78 *, struct dentry___78 *, umode_t, bool);
	int (*link)(struct dentry___78 *, struct inode___78 *, struct dentry___78 *);
	int (*unlink)(struct inode___78 *, struct dentry___78 *);
	int (*symlink)(struct inode___78 *, struct dentry___78 *, const char *);
	int (*mkdir)(struct inode___78 *, struct dentry___78 *, umode_t);
	int (*rmdir)(struct inode___78 *, struct dentry___78 *);
	int (*mknod)(struct inode___78 *, struct dentry___78 *, umode_t, dev_t);
	int (*rename)(struct inode___78 *, struct dentry___78 *, struct inode___78 *, struct dentry___78 *);
	int (*setattr)(struct dentry___78 *, struct iattr___78 *);
	int (*getattr)(struct vfsmount *, struct dentry___78 *, struct kstat *);
	int (*setxattr)(struct dentry___78 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___78 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___78 *, char *, size_t);
	int (*removexattr)(struct dentry___78 *, const char *);
	int (*fiemap)(struct inode___78 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___78 *, struct timespec *, int);
	int (*atomic_open)(struct inode___78 *, struct dentry___78 *, struct file___77 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___77;

struct file_lock_operations___77;

struct lock_manager_operations___77;

struct file_lock___77 {
	struct file_lock___77 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___38 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___77 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___77 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___77 *fl_ops;
	const struct lock_manager_operations___77 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___77 {
	void (*fl_copy_lock)(struct file_lock___77 *, struct file_lock___77 *);
	void (*fl_release_private)(struct file_lock___77 *);
};

struct lock_manager_operations___77 {
	int (*lm_compare_owner)(struct file_lock___77 *, struct file_lock___77 *);
	long unsigned int (*lm_owner_key)(struct file_lock___77 *);
	void (*lm_notify)(struct file_lock___77 *);
	int (*lm_grant)(struct file_lock___77 *, struct file_lock___77 *, int);
	void (*lm_break)(struct file_lock___77 *);
	int (*lm_change)(struct file_lock___77 **, int);
};

struct fasync_struct___77 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___77 *fa_next;
	struct file___77 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___77 {
	const char *name;
	int fs_flags;
	struct dentry___78 * (*mount)(struct file_system_type___77 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___78 *);
	struct module___42 *owner;
	struct file_system_type___77 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___77 {
	struct inode___78 * (*alloc_inode)(struct super_block___78 *);
	void (*destroy_inode)(struct inode___78 *);
	void (*dirty_inode)(struct inode___78 *, int);
	int (*write_inode)(struct inode___78 *, struct writeback_control *);
	int (*drop_inode)(struct inode___78 *);
	void (*evict_inode)(struct inode___78 *);
	void (*put_super)(struct super_block___78 *);
	int (*sync_fs)(struct super_block___78 *, int);
	int (*freeze_fs)(struct super_block___78 *);
	int (*unfreeze_fs)(struct super_block___78 *);
	int (*statfs)(struct dentry___78 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___78 *, int *, char *);
	void (*umount_begin)(struct super_block___78 *);
	int (*show_options)(struct seq_file___53 *, struct dentry___78 *);
	int (*show_devname)(struct seq_file___53 *, struct dentry___78 *);
	int (*show_path)(struct seq_file___53 *, struct dentry___78 *);
	int (*show_stats)(struct seq_file___53 *, struct dentry___78 *);
	ssize_t (*quota_read)(struct super_block___78 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___78 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___78 *);
	int (*bdev_try_to_free_page)(struct super_block___78 *, struct page___77 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___78 *);
	void (*free_cached_objects)(struct super_block___78 *, int);
};

typedef void (*poll_queue_proc___45)(struct file___77 *, wait_queue_head_t *, struct poll_table_struct___45 *);

struct poll_table_struct___45 {
	poll_queue_proc___45 _qproc;
	long unsigned int _key;
};

struct timer_list_iter {
	int cpu;
	bool second_pass;
	u64 now;
};

struct tm {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	long int tm_year;
	int tm_wday;
	int tm_yday;
};

struct cyclecounter {
	cycle_t (*read)(const struct cyclecounter *);
	cycle_t mask;
	u32 mult;
	u32 shift;
};

struct timecounter {
	const struct cyclecounter *cc;
	cycle_t cycle_last;
	u64 nsec;
	u64 mask;
	u64 frac;
};

typedef unsigned int uint;

struct page___78;

typedef struct page___78 *pgtable_t___78;

struct address_space___78;

struct kmem_cache___68;

struct page___78 {
	long unsigned int flags;
	struct address_space___78 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___78 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___78 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___68 *slab_cache;
		struct page___78 *first_page;
	};
	long: 64;
};

struct thread_struct___36;

struct task_struct___77;

struct pv_cpu_ops___77 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___36 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___36 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___77 *);
	void (*end_context_switch)(struct task_struct___77 *);
};

struct perf_event___36;

struct thread_struct___36 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___36 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___39;

struct pid_link___39 {
	struct hlist_node node;
	struct pid___39 *pid;
};

struct mutex___78 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___77 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___74 {
	struct page___78 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___82;

struct nsproxy___40;

struct signal_struct___77;

struct css_set___49;

struct perf_event_context___36;

struct task_struct___77 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___77 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___82 *mm;
	struct mm_struct___82 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___77 *real_parent;
	struct task_struct___77 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___77 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___39 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___77 = 0,
		VTIME_USER___77 = 1,
		VTIME_SYS___77 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___36 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___40 *nsproxy;
	struct signal_struct___77 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___49 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___36 *perf_event_ctxp[2];
	struct mutex___78 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___74 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___82 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___82 *, struct mm_struct___82 *);
	void (*dup_mmap)(struct mm_struct___82 *, struct mm_struct___82 *);
	void (*exit_mmap)(struct mm_struct___82 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___82 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___82 *);
	void (*pgd_free)(struct mm_struct___82 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___82 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___82 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___82 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___82 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___82 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___82 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___82 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___82 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___82 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___82 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___82 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___78 lock;
	void *vdso;
} mm_context_t___78;

struct xol_area___78;

struct uprobes_state___78 {
	struct xol_area___78 *xol_area;
};

struct vm_area_struct___82;

struct file___78;

struct core_state___77;

struct mm_struct___82 {
	struct vm_area_struct___82 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___82 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___82 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___78 context;
	long unsigned int flags;
	struct core_state___77 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___77 *owner;
	struct file___78 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___78 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___36 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___77 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___77 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___77 *target;
};

typedef void (*perf_overflow_handler_t___36)(struct perf_event___36 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___36;

typedef void (*ftrace_func_t___36)(long unsigned int, long unsigned int, struct ftrace_ops___36 *, struct pt_regs *);

struct ftrace_ops___36 {
	ftrace_func_t___36 func;
	struct ftrace_ops___36 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___78 regex_lock;
};

struct pmu___36;

struct fasync_struct___78;

struct pid_namespace___39;

struct ftrace_event_call___28;

struct perf_cgroup___36;

struct perf_event___36 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___36 *group_leader;
	struct pmu___36 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___36 hw;
	struct perf_event_context___36 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___78 child_mutex;
	struct list_head child_list;
	struct perf_event___36 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___77 *owner;
	struct mutex___78 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___78 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___36 *);
	struct callback_head callback_head;
	struct pid_namespace___39 *ns;
	u64 id;
	perf_overflow_handler_t___36 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___28 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___36 ftrace_ops;
	struct perf_cgroup___36 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct bin_attribute___53;

struct attribute_group___53 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___53 **bin_attrs;
};

struct bin_attribute___53 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___78 *, struct kobject___3 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___78 *, struct kobject___3 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	int (*mmap)(struct file___78 *, struct kobject___3 *, struct bin_attribute___53 *, struct vm_area_struct___82 *);
};

struct dentry___79;

struct path___78 {
	struct vfsmount *mnt;
	struct dentry___79 *dentry;
};

struct fown_struct___39 {
	rwlock_t lock;
	struct pid___39 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___79;

struct file_operations___78;

struct file___78 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___78 f_path;
	struct inode___79 *f_inode;
	const struct file_operations___78 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___39 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___78 *f_mapping;
	struct mutex___78 f_pos_lock;
};

struct vm_operations_struct___69;

struct vm_area_struct___82 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___82 *vm_next;
	struct vm_area_struct___82 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___82 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___69 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___78 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___60;

struct dev_pm_ops___60 {
	int (*prepare)(struct device___60 *);
	void (*complete)(struct device___60 *);
	int (*suspend)(struct device___60 *);
	int (*resume)(struct device___60 *);
	int (*freeze)(struct device___60 *);
	int (*thaw)(struct device___60 *);
	int (*poweroff)(struct device___60 *);
	int (*restore)(struct device___60 *);
	int (*suspend_late)(struct device___60 *);
	int (*resume_early)(struct device___60 *);
	int (*freeze_late)(struct device___60 *);
	int (*thaw_early)(struct device___60 *);
	int (*poweroff_late)(struct device___60 *);
	int (*restore_early)(struct device___60 *);
	int (*suspend_noirq)(struct device___60 *);
	int (*resume_noirq)(struct device___60 *);
	int (*freeze_noirq)(struct device___60 *);
	int (*thaw_noirq)(struct device___60 *);
	int (*poweroff_noirq)(struct device___60 *);
	int (*restore_noirq)(struct device___60 *);
	int (*runtime_suspend)(struct device___60 *);
	int (*runtime_resume)(struct device___60 *);
	int (*runtime_idle)(struct device___60 *);
};

struct device_type___60;

struct bus_type___60;

struct device_driver___60;

struct dev_pm_domain___60;

struct class___60;

struct device_rh___60;

struct device___60 {
	struct device___60 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___60 *type;
	struct mutex___78 mutex;
	struct bus_type___60 *bus;
	struct device_driver___60 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___60 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___60 *class;
	const struct attribute_group___53 **groups;
	void (*release)(struct device___60 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___60 *device_rh;
};

struct dev_pm_info_rh___60 {
	void (*set_latency_tolerance)(struct device___60 *, s32);
};

struct dev_pm_domain___60 {
	struct dev_pm_ops___60 ops;
};

struct zone___77;

struct lruvec___77 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___77 *zone;
};

struct pglist_data___77;

struct zone___77 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___77 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___77 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___77 {
	struct zone___77 *zone;
	int zone_idx;
};

struct zonelist___77 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___77 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___77 {
	struct zone___77 node_zones[4];
	struct zonelist___77 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___77 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___54;

struct x86_io_apic_ops___54 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___54 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___54;

struct irq_data___54 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___54 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___77 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___77 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___60 *, char *);
	ssize_t (*store)(struct bus_type___60 *, const char *, size_t);
};

struct device_attribute___60;

struct driver_attribute___60;

struct bus_type___60 {
	const char *name;
	const char *dev_name;
	struct device___60 *dev_root;
	struct bus_attribute___60 *bus_attrs;
	struct device_attribute___60 *dev_attrs;
	struct driver_attribute___60 *drv_attrs;
	const struct attribute_group___53 **bus_groups;
	const struct attribute_group___53 **dev_groups;
	const struct attribute_group___53 **drv_groups;
	int (*match)(struct device___60 *, struct device_driver___60 *);
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	int (*probe)(struct device___60 *);
	int (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*online)(struct device___60 *);
	int (*offline)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct device___60 *, struct device_attribute___60 *, char *);
	ssize_t (*store)(struct device___60 *, struct device_attribute___60 *, const char *, size_t);
};

struct driver_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___60 *, char *);
	ssize_t (*store)(struct device_driver___60 *, const char *, size_t);
};

struct device_driver___60 {
	const char *name;
	struct bus_type___60 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___60 *);
	int (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	const struct attribute_group___53 **groups;
	const struct dev_pm_ops___60 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___60 {
	const char *name;
	const struct attribute_group___53 **groups;
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
};

struct class_attribute___60;

struct class___60 {
	const char *name;
	struct module *owner;
	struct class_attribute___60 *class_attrs;
	struct device_attribute___60 *dev_attrs;
	const struct attribute_group___53 **dev_groups;
	struct bin_attribute___53 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *);
	void (*class_release)(struct class___60 *);
	void (*dev_release)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
	struct subsys_private *p;
};

struct class_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct class___60 *, struct class_attribute___60 *, char *);
	ssize_t (*store)(struct class___60 *, struct class_attribute___60 *, const char *, size_t);
	const void * (*namespace)(struct class___60 *, const struct class_attribute___60 *);
};

struct device_rh___60 {
	struct dev_pm_info_rh___60 power;
};

struct cdev___27 {
	struct kobject___3 kobj;
	struct module *owner;
	const struct file_operations___78 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___46;

struct file_lock___78;

struct seq_file___56;

struct file_operations___78 {
	struct module *owner;
	loff_t (*llseek)(struct file___78 *, loff_t, int);
	ssize_t (*read)(struct file___78 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___78 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___78 *, void *, filldir_t);
	unsigned int (*poll)(struct file___78 *, struct poll_table_struct___46 *);
	long int (*unlocked_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___78 *, struct vm_area_struct___82 *);
	int (*open)(struct inode___79 *, struct file___78 *);
	int (*flush)(struct file___78 *, fl_owner_t);
	int (*release)(struct inode___79 *, struct file___78 *);
	int (*fsync)(struct file___78 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___78 *, int);
	int (*lock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*sendpage)(struct file___78 *, struct page___78 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___78 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___78 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___78 *, long int, struct file_lock___78 **, void **);
		struct {
			int (*setlease)(struct file___78 *, long int, struct file_lock___78 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___78 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___56 *, struct file___78 *);
};

struct dentry_operations___78;

struct super_block___79;

struct dentry___79 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___79 *d_parent;
	struct qstr d_name;
	struct inode___79 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___78 *d_op;
	struct super_block___79 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___78;

struct address_space___78 {
	struct inode___79 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___78 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___78 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___78;

struct dquot___78;

struct block_device___78;

struct inode___79 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___78 *i_op;
	struct super_block___79 *i_sb;
	struct address_space___78 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___78 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___78 *i_fop;
	struct file_lock___78 *i_flock;
	struct address_space___78 i_data;
	struct dquot___78 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___78 *i_bdev;
		struct cdev___27 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___78 {
	int (*d_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_hash)(const struct dentry___79 *, struct qstr *);
	int (*d_compare)(const struct dentry___79 *, const struct dentry___79 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___79 *);
	void (*d_release)(struct dentry___79 *);
	void (*d_prune)(struct dentry___79 *);
	void (*d_iput)(struct dentry___79 *, struct inode___79 *);
	char * (*d_dname)(struct dentry___79 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___78 *);
	int (*d_manage)(struct dentry___79 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___78;

struct mem_dqinfo___78 {
	struct quota_format_type___78 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___78;

struct quota_info___78 {
	unsigned int flags;
	struct mutex___78 dqio_mutex;
	struct mutex___78 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___79 *files[2];
	struct mem_dqinfo___78 info[2];
	const struct quota_format_ops___78 *ops[2];
};

struct file_system_type___78;

struct super_operations___78;

struct dquot_operations___78;

struct quotactl_ops___78;

struct xattr_handler___49;

struct super_block___79 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___78 *s_type;
	const struct super_operations___78 *s_op;
	const struct dquot_operations___78 *dq_op;
	const struct quotactl_ops___78 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___79 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___49 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___78 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___78 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___78 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___78 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___39 {
	int nr;
	struct pid_namespace___39 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___39 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___77 *child_reaper;
	struct kmem_cache___68 *pid_cachep;
	unsigned int level;
	struct pid_namespace___39 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___79 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___39 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___39 numbers[1];
};

struct block_device___78 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___79 *bd_inode;
	struct super_block___79 *bd_super;
	struct mutex___78 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___78 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___78 bd_fsfreeze_mutex;
};

struct cgroup___49;

struct cgroup_subsys_state___49 {
	struct cgroup___49 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___79 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___78 *ia_file;
};

struct dquot___78 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___78 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___79 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___78 {
	int qf_fmt_id;
	const struct quota_format_ops___78 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___78 *qf_next;
};

struct quota_format_ops___78 {
	int (*check_quota_file)(struct super_block___79 *, int);
	int (*read_file_info)(struct super_block___79 *, int);
	int (*write_file_info)(struct super_block___79 *, int);
	int (*free_file_info)(struct super_block___79 *, int);
	int (*read_dqblk)(struct dquot___78 *);
	int (*commit_dqblk)(struct dquot___78 *);
	int (*release_dqblk)(struct dquot___78 *);
};

struct dquot_operations___78 {
	int (*write_dquot)(struct dquot___78 *);
	struct dquot___78 * (*alloc_dquot)(struct super_block___79 *, int);
	void (*destroy_dquot)(struct dquot___78 *);
	int (*acquire_dquot)(struct dquot___78 *);
	int (*release_dquot)(struct dquot___78 *);
	int (*mark_dirty)(struct dquot___78 *);
	int (*write_info)(struct super_block___79 *, int);
	qsize_t * (*get_reserved_space)(struct inode___79 *);
};

struct quotactl_ops___78 {
	int (*quota_on)(struct super_block___79 *, int, int, struct path___78 *);
	int (*quota_on_meta)(struct super_block___79 *, int, int);
	int (*quota_off)(struct super_block___79 *, int);
	int (*quota_sync)(struct super_block___79 *, int);
	int (*get_info)(struct super_block___79 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___79 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___79 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___79 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___79 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___79 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___79 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___79 *, unsigned int);
};

struct address_space_operations___78 {
	int (*writepage)(struct page___78 *, struct writeback_control *);
	int (*readpage)(struct file___78 *, struct page___78 *);
	int (*writepages)(struct address_space___78 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___78 *);
	int (*readpages)(struct file___78 *, struct address_space___78 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___78 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___78 **, void **);
	int (*write_end)(struct file___78 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___78 *, void *);
	sector_t (*bmap)(struct address_space___78 *, sector_t);
	void (*invalidatepage)(struct page___78 *, long unsigned int);
	int (*releasepage)(struct page___78 *, gfp_t);
	void (*freepage)(struct page___78 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___78 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___78 *, struct page___78 *, struct page___78 *, enum migrate_mode);
	int (*launder_page)(struct page___78 *);
	int (*is_partially_uptodate)(struct page___78 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___78 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___78 *, struct page___78 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___78 *, sector_t *);
	void (*swap_deactivate)(struct file___78 *);
	void (*invalidatepage_range)(struct page___78 *, unsigned int, unsigned int);
};

struct inode_operations___78 {
	struct dentry___79 * (*lookup)(struct inode___79 *, struct dentry___79 *, unsigned int);
	void * (*follow_link)(struct dentry___79 *, struct nameidata *);
	int (*permission)(struct inode___79 *, int);
	struct posix_acl * (*get_acl)(struct inode___79 *, int);
	int (*readlink)(struct dentry___79 *, char *, int);
	void (*put_link)(struct dentry___79 *, struct nameidata *, void *);
	int (*create)(struct inode___79 *, struct dentry___79 *, umode_t, bool);
	int (*link)(struct dentry___79 *, struct inode___79 *, struct dentry___79 *);
	int (*unlink)(struct inode___79 *, struct dentry___79 *);
	int (*symlink)(struct inode___79 *, struct dentry___79 *, const char *);
	int (*mkdir)(struct inode___79 *, struct dentry___79 *, umode_t);
	int (*rmdir)(struct inode___79 *, struct dentry___79 *);
	int (*mknod)(struct inode___79 *, struct dentry___79 *, umode_t, dev_t);
	int (*rename)(struct inode___79 *, struct dentry___79 *, struct inode___79 *, struct dentry___79 *);
	int (*setattr)(struct dentry___79 *, struct iattr___79 *);
	int (*getattr)(struct vfsmount *, struct dentry___79 *, struct kstat *);
	int (*setxattr)(struct dentry___79 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___79 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___79 *, char *, size_t);
	int (*removexattr)(struct dentry___79 *, const char *);
	int (*fiemap)(struct inode___79 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___79 *, struct timespec *, int);
	int (*atomic_open)(struct inode___79 *, struct dentry___79 *, struct file___78 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___78;

struct lock_manager_operations___78;

struct file_lock___78 {
	struct file_lock___78 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___39 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___78 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___78 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___78 *fl_ops;
	const struct lock_manager_operations___78 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___78 {
	void (*fl_copy_lock)(struct file_lock___78 *, struct file_lock___78 *);
	void (*fl_release_private)(struct file_lock___78 *);
};

struct lock_manager_operations___78 {
	int (*lm_compare_owner)(struct file_lock___78 *, struct file_lock___78 *);
	long unsigned int (*lm_owner_key)(struct file_lock___78 *);
	void (*lm_notify)(struct file_lock___78 *);
	int (*lm_grant)(struct file_lock___78 *, struct file_lock___78 *, int);
	void (*lm_break)(struct file_lock___78 *);
	int (*lm_change)(struct file_lock___78 **, int);
};

struct fasync_struct___78 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___78 *fa_next;
	struct file___78 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___78 {
	const char *name;
	int fs_flags;
	struct dentry___79 * (*mount)(struct file_system_type___78 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___79 *);
	struct module *owner;
	struct file_system_type___78 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___78 {
	struct inode___79 * (*alloc_inode)(struct super_block___79 *);
	void (*destroy_inode)(struct inode___79 *);
	void (*dirty_inode)(struct inode___79 *, int);
	int (*write_inode)(struct inode___79 *, struct writeback_control *);
	int (*drop_inode)(struct inode___79 *);
	void (*evict_inode)(struct inode___79 *);
	void (*put_super)(struct super_block___79 *);
	int (*sync_fs)(struct super_block___79 *, int);
	int (*freeze_fs)(struct super_block___79 *);
	int (*unfreeze_fs)(struct super_block___79 *);
	int (*statfs)(struct dentry___79 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___79 *, int *, char *);
	void (*umount_begin)(struct super_block___79 *);
	int (*show_options)(struct seq_file___56 *, struct dentry___79 *);
	int (*show_devname)(struct seq_file___56 *, struct dentry___79 *);
	int (*show_path)(struct seq_file___56 *, struct dentry___79 *);
	int (*show_stats)(struct seq_file___56 *, struct dentry___79 *);
	ssize_t (*quota_read)(struct super_block___79 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___79 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___79 *);
	int (*bdev_try_to_free_page)(struct super_block___79 *, struct page___78 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___79 *);
	void (*free_cached_objects)(struct super_block___79 *, int);
};

struct xattr_handler___49 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___79 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___79 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___79 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___46)(struct file___78 *, wait_queue_head_t *, struct poll_table_struct___46 *);

struct poll_table_struct___46 {
	poll_queue_proc___46 _qproc;
	long unsigned int _key;
};

struct seq_operations___55;

struct seq_file___56 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___78 lock;
	const struct seq_operations___55 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nsproxy___40 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___39 *pid_ns;
	struct net *net_ns;
};

typedef struct poll_table_struct___46 poll_table___3;

struct xol_area___78 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___78 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___68;

struct memcg_cache_params___68;

struct kmem_cache___68 {
	struct kmem_cache_cpu___68 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___68 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___66;

struct vm_operations_struct___69 {
	void (*open)(struct vm_area_struct___82 *);
	void (*close)(struct vm_area_struct___82 *);
	int (*fault)(struct vm_area_struct___82 *, struct vm_fault___66 *);
	int (*page_mkwrite)(struct vm_area_struct___82 *, struct vm_fault___66 *);
	int (*access)(struct vm_area_struct___82 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___82 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___82 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___82 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___82 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___77 {
	struct task_struct___77 *task;
	struct core_thread___77 *next;
};

struct core_state___77 {
	atomic_t nr_threads;
	struct core_thread___77 dumper;
	struct completion startup;
};

struct signal_struct___77 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___77 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___77 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___39 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___39 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___78 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___49 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___49 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___36 {
	struct pmu___36 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___78 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___77 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___36 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct irq_chip___54 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___54 *);
	void (*irq_shutdown)(struct irq_data___54 *);
	void (*irq_enable)(struct irq_data___54 *);
	void (*irq_disable)(struct irq_data___54 *);
	void (*irq_ack)(struct irq_data___54 *);
	void (*irq_mask)(struct irq_data___54 *);
	void (*irq_mask_ack)(struct irq_data___54 *);
	void (*irq_unmask)(struct irq_data___54 *);
	void (*irq_eoi)(struct irq_data___54 *);
	int (*irq_set_affinity)(struct irq_data___54 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___54 *);
	int (*irq_set_type)(struct irq_data___54 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___54 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___54 *);
	void (*irq_bus_sync_unlock)(struct irq_data___54 *);
	void (*irq_cpu_online)(struct irq_data___54 *);
	void (*irq_cpu_offline)(struct irq_data___54 *);
	void (*irq_suspend)(struct irq_data___54 *);
	void (*irq_resume)(struct irq_data___54 *);
	void (*irq_pm_shutdown)(struct irq_data___54 *);
	void (*irq_print_chip)(struct irq_data___54 *, struct seq_file___56 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___54 *, void *);
	long unsigned int flags;
};

struct seq_operations___55 {
	void * (*start)(struct seq_file___56 *, loff_t *);
	void (*stop)(struct seq_file___56 *, void *);
	void * (*next)(struct seq_file___56 *, void *, loff_t *);
	int (*show)(struct seq_file___56 *, void *);
};

struct cpu_timer_list___3 {
	struct list_head entry;
	union cpu_time_count expires;
	union cpu_time_count incr;
	struct task_struct___77 *task;
	int firing;
};

struct k_itimer___3 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	clockid_t it_clock;
	timer_t it_id;
	int it_overrun;
	int it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	struct signal_struct___77 *it_signal;
	union {
		struct pid___39 *it_pid;
		struct task_struct___77 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
			ktime_t interval;
		} real;
		struct cpu_timer_list___3 cpu;
		struct {
			unsigned int clock;
			unsigned int node;
			long unsigned int incr;
			long unsigned int expires;
		} mmtimer;
		struct {
			struct alarm alarmtimer;
			ktime_t interval;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___3 {
	int (*clock_getres)(const clockid_t, struct timespec *);
	int (*clock_set)(const clockid_t, const struct timespec *);
	int (*clock_get)(const clockid_t, struct timespec *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___3 *);
	int (*nsleep)(const clockid_t, int, struct timespec *, struct timespec *);
	long int (*nsleep_restart)(struct restart_block *);
	int (*timer_set)(struct k_itimer___3 *, int, struct itimerspec *, struct itimerspec *);
	int (*timer_del)(struct k_itimer___3 *);
	void (*timer_get)(struct k_itimer___3 *, struct itimerspec *);
};

struct posix_clock;

struct posix_clock_operations {
	struct module *owner;
	int (*clock_adjtime)(struct posix_clock *, struct timex *);
	int (*clock_gettime)(struct posix_clock *, struct timespec *);
	int (*clock_getres)(struct posix_clock *, struct timespec *);
	int (*clock_settime)(struct posix_clock *, const struct timespec *);
	int (*timer_create)(struct posix_clock *, struct k_itimer___3 *);
	int (*timer_delete)(struct posix_clock *, struct k_itimer___3 *);
	void (*timer_gettime)(struct posix_clock *, struct k_itimer___3 *, struct itimerspec *);
	int (*timer_settime)(struct posix_clock *, struct k_itimer___3 *, int, struct itimerspec *, struct itimerspec *);
	int (*fasync)(struct posix_clock *, int, struct file___78 *, int);
	long int (*ioctl)(struct posix_clock *, unsigned int, long unsigned int);
	int (*mmap)(struct posix_clock *, struct vm_area_struct___82 *);
	int (*open)(struct posix_clock *, fmode_t);
	uint (*poll)(struct posix_clock *, struct file___78 *, poll_table___3 *);
	int (*release)(struct posix_clock *);
	ssize_t (*read)(struct posix_clock *, uint, char *, size_t);
};

struct posix_clock {
	struct posix_clock_operations ops;
	struct cdev___27 cdev;
	struct kref kref;
	struct rw_semaphore rwsem;
	bool zombie;
	void (*release)(struct posix_clock *);
};

struct kmem_cache_cpu___68 {
	void **freelist;
	long unsigned int tid;
	struct page___78 *page;
	struct page___78 *partial;
};

struct memcg_cache_params___68 {
	bool is_root_cache;
	union {
		struct kmem_cache___68 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___68 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___66 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___78 *page;
};

struct cgroupfs_root___49;

struct cgroup___49 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___49 *parent;
	struct dentry___79 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___49 *subsys[11];
	struct cgroupfs_root___49 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___78 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___49 {
	struct super_block___79 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___49 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___36;

struct pmu___36 {
	struct list_head entry;
	struct device___60 *dev;
	const struct attribute_group___53 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___36 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___36 *);
	void (*pmu_disable)(struct pmu___36 *);
	int (*event_init)(struct perf_event___36 *);
	int (*add)(struct perf_event___36 *, int);
	void (*del)(struct perf_event___36 *, int);
	void (*start)(struct perf_event___36 *, int);
	void (*stop)(struct perf_event___36 *, int);
	void (*read)(struct perf_event___36 *);
	void (*start_txn)(struct pmu___36 *);
	int (*commit_txn)(struct pmu___36 *);
	void (*cancel_txn)(struct pmu___36 *);
	int (*event_idx)(struct perf_event___36 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___36 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___36 *);
};

struct perf_cpu_context___36 {
	struct perf_event_context___36 ctx;
	struct perf_event_context___36 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___36 *unique_pmu;
	struct perf_cgroup___36 *cgrp;
};

struct trace_event_functions___28;

struct trace_event___28 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___28 *funcs;
};

struct ftrace_event_class___28;

struct ftrace_event_call___28 {
	struct list_head list;
	struct ftrace_event_class___28 *class;
	char *name;
	struct trace_event___28 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___36 {
	struct cgroup_subsys_state___49 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___28 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___78 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___28)(struct trace_iterator___28 *, int, struct trace_event___28 *);

struct trace_event_functions___28 {
	trace_print_func___28 trace;
	trace_print_func___28 raw;
	trace_print_func___28 hex;
	trace_print_func___28 binary;
};

struct ftrace_event_class___28 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___28 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___28 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___28 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___28 *);
};

struct posix_clock_desc {
	struct file___78 *fp;
	struct posix_clock *clk;
};

struct page___79;

typedef struct page___79 *pgtable_t___79;

struct address_space___79;

struct page___79 {
	long unsigned int flags;
	struct address_space___79 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___79 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___79 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___79 *first_page;
	};
	long: 64;
};

struct task_struct___78;

struct pv_cpu_ops___78 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___36 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___36 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___78 *);
	void (*end_context_switch)(struct task_struct___78 *);
};

struct mutex___79 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___78 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___75 {
	struct page___79 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___83;

struct signal_struct___78;

struct task_struct___78 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___78 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___83 *mm;
	struct mm_struct___83 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___78 *real_parent;
	struct task_struct___78 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___78 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___39 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___78 = 0,
		VTIME_USER___78 = 1,
		VTIME_SYS___78 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___36 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___78 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___79 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___75 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___83 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___83 *, struct mm_struct___83 *);
	void (*dup_mmap)(struct mm_struct___83 *, struct mm_struct___83 *);
	void (*exit_mmap)(struct mm_struct___83 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___83 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___83 *);
	void (*pgd_free)(struct mm_struct___83 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___83 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___83 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___83 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___83 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___83 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___83 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___83 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___83 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___83 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___83 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___83 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___79 lock;
	void *vdso;
} mm_context_t___79;

struct xol_area___79;

struct uprobes_state___79 {
	struct xol_area___79 *xol_area;
};

struct vm_area_struct___83;

struct file___79;

struct core_state___78;

struct mm_struct___83 {
	struct vm_area_struct___83 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___83 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___83 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___79 context;
	long unsigned int flags;
	struct core_state___78 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___78 *owner;
	struct file___79 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___79 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___37 {
	struct task_struct___78 *task;
	struct exec_domain___19 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___55;

struct x86_io_apic_ops___55 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___55 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___55;

struct irq_data___55 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___55 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___61;

struct dev_pm_ops___61 {
	int (*prepare)(struct device___61 *);
	void (*complete)(struct device___61 *);
	int (*suspend)(struct device___61 *);
	int (*resume)(struct device___61 *);
	int (*freeze)(struct device___61 *);
	int (*thaw)(struct device___61 *);
	int (*poweroff)(struct device___61 *);
	int (*restore)(struct device___61 *);
	int (*suspend_late)(struct device___61 *);
	int (*resume_early)(struct device___61 *);
	int (*freeze_late)(struct device___61 *);
	int (*thaw_early)(struct device___61 *);
	int (*poweroff_late)(struct device___61 *);
	int (*restore_early)(struct device___61 *);
	int (*suspend_noirq)(struct device___61 *);
	int (*resume_noirq)(struct device___61 *);
	int (*freeze_noirq)(struct device___61 *);
	int (*thaw_noirq)(struct device___61 *);
	int (*poweroff_noirq)(struct device___61 *);
	int (*restore_noirq)(struct device___61 *);
	int (*runtime_suspend)(struct device___61 *);
	int (*runtime_resume)(struct device___61 *);
	int (*runtime_idle)(struct device___61 *);
};

struct device_type___61;

struct bus_type___61;

struct device_driver___61;

struct dev_pm_domain___61;

struct class___61;

struct attribute_group___54;

struct device_rh___61;

struct device___61 {
	struct device___61 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___61 *type;
	struct mutex___79 mutex;
	struct bus_type___61 *bus;
	struct device_driver___61 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___61 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___61 *class;
	const struct attribute_group___54 **groups;
	void (*release)(struct device___61 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___61 *device_rh;
};

struct dev_pm_info_rh___61 {
	void (*set_latency_tolerance)(struct device___61 *, s32);
};

struct dev_pm_domain___61 {
	struct dev_pm_ops___61 ops;
};

struct smp_ops___78 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___78 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___78;

struct lruvec___78 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___78 *zone;
};

struct pglist_data___78;

struct zone___78 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___78 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___78 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___78 {
	struct zone___78 *zone;
	int zone_idx;
};

struct zonelist___78 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___78 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___78 {
	struct zone___78 node_zones[4];
	struct zonelist___78 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___78 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___57;

struct irq_chip___55 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___55 *);
	void (*irq_shutdown)(struct irq_data___55 *);
	void (*irq_enable)(struct irq_data___55 *);
	void (*irq_disable)(struct irq_data___55 *);
	void (*irq_ack)(struct irq_data___55 *);
	void (*irq_mask)(struct irq_data___55 *);
	void (*irq_mask_ack)(struct irq_data___55 *);
	void (*irq_unmask)(struct irq_data___55 *);
	void (*irq_eoi)(struct irq_data___55 *);
	int (*irq_set_affinity)(struct irq_data___55 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___55 *);
	int (*irq_set_type)(struct irq_data___55 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___55 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___55 *);
	void (*irq_bus_sync_unlock)(struct irq_data___55 *);
	void (*irq_cpu_online)(struct irq_data___55 *);
	void (*irq_cpu_offline)(struct irq_data___55 *);
	void (*irq_suspend)(struct irq_data___55 *);
	void (*irq_resume)(struct irq_data___55 *);
	void (*irq_pm_shutdown)(struct irq_data___55 *);
	void (*irq_print_chip)(struct irq_data___55 *, struct seq_file___57 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___55 *, void *);
	long unsigned int flags;
};

struct seq_operations___56;

struct seq_file___57 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___79 lock;
	const struct seq_operations___56 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct rtc_wkalrm {
	unsigned char enabled;
	unsigned char pending;
	struct rtc_time time;
};

struct bin_attribute___54;

struct attribute_group___54 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___54 **bin_attrs;
};

struct bin_attribute___54 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___79 *, struct kobject___3 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___79 *, struct kobject___3 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	int (*mmap)(struct file___79 *, struct kobject___3 *, struct bin_attribute___54 *, struct vm_area_struct___83 *);
};

struct dentry___80;

struct path___79 {
	struct vfsmount *mnt;
	struct dentry___80 *dentry;
};

struct inode___80;

struct file_operations___79;

struct file___79 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___79 f_path;
	struct inode___80 *f_inode;
	const struct file_operations___79 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___39 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___79 *f_mapping;
	struct mutex___79 f_pos_lock;
};

struct vm_area_struct___83 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___83 *vm_next;
	struct vm_area_struct___83 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___83 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___79 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___61 *, char *);
	ssize_t (*store)(struct bus_type___61 *, const char *, size_t);
};

struct device_attribute___61;

struct driver_attribute___61;

struct bus_type___61 {
	const char *name;
	const char *dev_name;
	struct device___61 *dev_root;
	struct bus_attribute___61 *bus_attrs;
	struct device_attribute___61 *dev_attrs;
	struct driver_attribute___61 *drv_attrs;
	const struct attribute_group___54 **bus_groups;
	const struct attribute_group___54 **dev_groups;
	const struct attribute_group___54 **drv_groups;
	int (*match)(struct device___61 *, struct device_driver___61 *);
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	int (*probe)(struct device___61 *);
	int (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*online)(struct device___61 *);
	int (*offline)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct device___61 *, struct device_attribute___61 *, char *);
	ssize_t (*store)(struct device___61 *, struct device_attribute___61 *, const char *, size_t);
};

struct driver_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___61 *, char *);
	ssize_t (*store)(struct device_driver___61 *, const char *, size_t);
};

struct device_driver___61 {
	const char *name;
	struct bus_type___61 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___61 *);
	int (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	const struct attribute_group___54 **groups;
	const struct dev_pm_ops___61 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___61 {
	const char *name;
	const struct attribute_group___54 **groups;
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
};

struct class_attribute___61;

struct class___61 {
	const char *name;
	struct module *owner;
	struct class_attribute___61 *class_attrs;
	struct device_attribute___61 *dev_attrs;
	const struct attribute_group___54 **dev_groups;
	struct bin_attribute___54 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *);
	void (*class_release)(struct class___61 *);
	void (*dev_release)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
	struct subsys_private *p;
};

struct class_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct class___61 *, struct class_attribute___61 *, char *);
	ssize_t (*store)(struct class___61 *, struct class_attribute___61 *, const char *, size_t);
	const void * (*namespace)(struct class___61 *, const struct class_attribute___61 *);
};

struct class_interface {
	struct list_head node;
	struct class___61 *class;
	int (*add_dev)(struct device___61 *, struct class_interface *);
	void (*remove_dev)(struct device___61 *, struct class_interface *);
};

struct device_rh___61 {
	struct dev_pm_info_rh___61 power;
};

struct seq_operations___56 {
	void * (*start)(struct seq_file___57 *, loff_t *);
	void (*stop)(struct seq_file___57 *, void *);
	void * (*next)(struct seq_file___57 *, void *, loff_t *);
	int (*show)(struct seq_file___57 *, void *);
};

struct cdev___28 {
	struct kobject___3 kobj;
	struct module *owner;
	const struct file_operations___79 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___47;

struct file_lock___79;

struct file_operations___79 {
	struct module *owner;
	loff_t (*llseek)(struct file___79 *, loff_t, int);
	ssize_t (*read)(struct file___79 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___79 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___79 *, void *, filldir_t);
	unsigned int (*poll)(struct file___79 *, struct poll_table_struct___47 *);
	long int (*unlocked_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___79 *, struct vm_area_struct___83 *);
	int (*open)(struct inode___80 *, struct file___79 *);
	int (*flush)(struct file___79 *, fl_owner_t);
	int (*release)(struct inode___80 *, struct file___79 *);
	int (*fsync)(struct file___79 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___79 *, int);
	int (*lock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*sendpage)(struct file___79 *, struct page___79 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___79 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___79 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___79 *, long int, struct file_lock___79 **, void **);
		struct {
			int (*setlease)(struct file___79 *, long int, struct file_lock___79 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___79 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___57 *, struct file___79 *);
};

struct dentry_operations___79;

struct super_block___80;

struct dentry___80 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___80 *d_parent;
	struct qstr d_name;
	struct inode___80 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___79 *d_op;
	struct super_block___80 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___79;

struct address_space___79 {
	struct inode___80 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___79 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___79 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___79;

struct dquot___79;

struct block_device___79;

struct inode___80 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___79 *i_op;
	struct super_block___80 *i_sb;
	struct address_space___79 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___79 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___79 *i_fop;
	struct file_lock___79 *i_flock;
	struct address_space___79 i_data;
	struct dquot___79 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___79 *i_bdev;
		struct cdev___28 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___79 {
	int (*d_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_hash)(const struct dentry___80 *, struct qstr *);
	int (*d_compare)(const struct dentry___80 *, const struct dentry___80 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___80 *);
	void (*d_release)(struct dentry___80 *);
	void (*d_prune)(struct dentry___80 *);
	void (*d_iput)(struct dentry___80 *, struct inode___80 *);
	char * (*d_dname)(struct dentry___80 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___79 *);
	int (*d_manage)(struct dentry___80 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___79;

struct mem_dqinfo___79 {
	struct quota_format_type___79 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___79;

struct quota_info___79 {
	unsigned int flags;
	struct mutex___79 dqio_mutex;
	struct mutex___79 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___80 *files[2];
	struct mem_dqinfo___79 info[2];
	const struct quota_format_ops___79 *ops[2];
};

struct file_system_type___79;

struct super_operations___79;

struct dquot_operations___79;

struct quotactl_ops___79;

struct super_block___80 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___79 *s_type;
	const struct super_operations___79 *s_op;
	const struct dquot_operations___79 *dq_op;
	const struct quotactl_ops___79 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___80 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___79 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___79 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___79 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___79 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___79 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___80 *bd_inode;
	struct super_block___80 *bd_super;
	struct mutex___79 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___79 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___79 bd_fsfreeze_mutex;
};

struct iattr___80 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___79 *ia_file;
};

struct dquot___79 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___79 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___80 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___79 {
	int qf_fmt_id;
	const struct quota_format_ops___79 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___79 *qf_next;
};

struct quota_format_ops___79 {
	int (*check_quota_file)(struct super_block___80 *, int);
	int (*read_file_info)(struct super_block___80 *, int);
	int (*write_file_info)(struct super_block___80 *, int);
	int (*free_file_info)(struct super_block___80 *, int);
	int (*read_dqblk)(struct dquot___79 *);
	int (*commit_dqblk)(struct dquot___79 *);
	int (*release_dqblk)(struct dquot___79 *);
};

struct dquot_operations___79 {
	int (*write_dquot)(struct dquot___79 *);
	struct dquot___79 * (*alloc_dquot)(struct super_block___80 *, int);
	void (*destroy_dquot)(struct dquot___79 *);
	int (*acquire_dquot)(struct dquot___79 *);
	int (*release_dquot)(struct dquot___79 *);
	int (*mark_dirty)(struct dquot___79 *);
	int (*write_info)(struct super_block___80 *, int);
	qsize_t * (*get_reserved_space)(struct inode___80 *);
};

struct quotactl_ops___79 {
	int (*quota_on)(struct super_block___80 *, int, int, struct path___79 *);
	int (*quota_on_meta)(struct super_block___80 *, int, int);
	int (*quota_off)(struct super_block___80 *, int);
	int (*quota_sync)(struct super_block___80 *, int);
	int (*get_info)(struct super_block___80 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___80 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___80 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___80 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___80 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___80 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___80 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___80 *, unsigned int);
};

struct address_space_operations___79 {
	int (*writepage)(struct page___79 *, struct writeback_control *);
	int (*readpage)(struct file___79 *, struct page___79 *);
	int (*writepages)(struct address_space___79 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___79 *);
	int (*readpages)(struct file___79 *, struct address_space___79 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___79 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___79 **, void **);
	int (*write_end)(struct file___79 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___79 *, void *);
	sector_t (*bmap)(struct address_space___79 *, sector_t);
	void (*invalidatepage)(struct page___79 *, long unsigned int);
	int (*releasepage)(struct page___79 *, gfp_t);
	void (*freepage)(struct page___79 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___79 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___79 *, struct page___79 *, struct page___79 *, enum migrate_mode);
	int (*launder_page)(struct page___79 *);
	int (*is_partially_uptodate)(struct page___79 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___79 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___79 *, struct page___79 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___79 *, sector_t *);
	void (*swap_deactivate)(struct file___79 *);
	void (*invalidatepage_range)(struct page___79 *, unsigned int, unsigned int);
};

struct inode_operations___79 {
	struct dentry___80 * (*lookup)(struct inode___80 *, struct dentry___80 *, unsigned int);
	void * (*follow_link)(struct dentry___80 *, struct nameidata *);
	int (*permission)(struct inode___80 *, int);
	struct posix_acl * (*get_acl)(struct inode___80 *, int);
	int (*readlink)(struct dentry___80 *, char *, int);
	void (*put_link)(struct dentry___80 *, struct nameidata *, void *);
	int (*create)(struct inode___80 *, struct dentry___80 *, umode_t, bool);
	int (*link)(struct dentry___80 *, struct inode___80 *, struct dentry___80 *);
	int (*unlink)(struct inode___80 *, struct dentry___80 *);
	int (*symlink)(struct inode___80 *, struct dentry___80 *, const char *);
	int (*mkdir)(struct inode___80 *, struct dentry___80 *, umode_t);
	int (*rmdir)(struct inode___80 *, struct dentry___80 *);
	int (*mknod)(struct inode___80 *, struct dentry___80 *, umode_t, dev_t);
	int (*rename)(struct inode___80 *, struct dentry___80 *, struct inode___80 *, struct dentry___80 *);
	int (*setattr)(struct dentry___80 *, struct iattr___80 *);
	int (*getattr)(struct vfsmount *, struct dentry___80 *, struct kstat *);
	int (*setxattr)(struct dentry___80 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___80 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___80 *, char *, size_t);
	int (*removexattr)(struct dentry___80 *, const char *);
	int (*fiemap)(struct inode___80 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___80 *, struct timespec *, int);
	int (*atomic_open)(struct inode___80 *, struct dentry___80 *, struct file___79 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___79;

struct file_lock_operations___79;

struct lock_manager_operations___79;

struct file_lock___79 {
	struct file_lock___79 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___39 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___79 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___79 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___79 *fl_ops;
	const struct lock_manager_operations___79 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___79 {
	void (*fl_copy_lock)(struct file_lock___79 *, struct file_lock___79 *);
	void (*fl_release_private)(struct file_lock___79 *);
};

struct lock_manager_operations___79 {
	int (*lm_compare_owner)(struct file_lock___79 *, struct file_lock___79 *);
	long unsigned int (*lm_owner_key)(struct file_lock___79 *);
	void (*lm_notify)(struct file_lock___79 *);
	int (*lm_grant)(struct file_lock___79 *, struct file_lock___79 *, int);
	void (*lm_break)(struct file_lock___79 *);
	int (*lm_change)(struct file_lock___79 **, int);
};

struct fasync_struct___79 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___79 *fa_next;
	struct file___79 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___79 {
	const char *name;
	int fs_flags;
	struct dentry___80 * (*mount)(struct file_system_type___79 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___80 *);
	struct module *owner;
	struct file_system_type___79 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___79 {
	struct inode___80 * (*alloc_inode)(struct super_block___80 *);
	void (*destroy_inode)(struct inode___80 *);
	void (*dirty_inode)(struct inode___80 *, int);
	int (*write_inode)(struct inode___80 *, struct writeback_control *);
	int (*drop_inode)(struct inode___80 *);
	void (*evict_inode)(struct inode___80 *);
	void (*put_super)(struct super_block___80 *);
	int (*sync_fs)(struct super_block___80 *, int);
	int (*freeze_fs)(struct super_block___80 *);
	int (*unfreeze_fs)(struct super_block___80 *);
	int (*statfs)(struct dentry___80 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___80 *, int *, char *);
	void (*umount_begin)(struct super_block___80 *);
	int (*show_options)(struct seq_file___57 *, struct dentry___80 *);
	int (*show_devname)(struct seq_file___57 *, struct dentry___80 *);
	int (*show_path)(struct seq_file___57 *, struct dentry___80 *);
	int (*show_stats)(struct seq_file___57 *, struct dentry___80 *);
	ssize_t (*quota_read)(struct super_block___80 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___80 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___80 *);
	int (*bdev_try_to_free_page)(struct super_block___80 *, struct page___79 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___80 *);
	void (*free_cached_objects)(struct super_block___80 *, int);
};

typedef void (*poll_queue_proc___47)(struct file___79 *, wait_queue_head_t *, struct poll_table_struct___47 *);

struct poll_table_struct___47 {
	poll_queue_proc___47 _qproc;
	long unsigned int _key;
};

struct rtc_class_ops {
	int (*open)(struct device___61 *);
	void (*release)(struct device___61 *);
	int (*ioctl)(struct device___61 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___61 *, struct rtc_time *);
	int (*set_time)(struct device___61 *, struct rtc_time *);
	int (*read_alarm)(struct device___61 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___61 *, struct rtc_wkalrm *);
	int (*proc)(struct device___61 *, struct seq_file___57 *);
	int (*set_mmss)(struct device___61 *, long unsigned int);
	int (*read_callback)(struct device___61 *, int);
	int (*alarm_irq_enable)(struct device___61 *, unsigned int);
};

struct rtc_task {
	void (*func)(void *);
	void *private_data;
};

struct rtc_timer {
	struct rtc_task task;
	struct timerqueue_node node;
	ktime_t period;
	int enabled;
};

struct rtc_device {
	struct device___61 dev;
	struct module *owner;
	int id;
	char name[20];
	const struct rtc_class_ops *ops;
	struct mutex___79 ops_lock;
	struct cdev___28 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___79 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
};

struct platform_device___3 {
	const char *name;
	int id;
	bool id_auto;
	struct device___61 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___3 {
	struct device___61 *parent;
	struct acpi_dev_node___4 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct platform_driver {
	int (*probe)(struct platform_device___3 *);
	int (*remove)(struct platform_device___3 *);
	void (*shutdown)(struct platform_device___3 *);
	int (*suspend)(struct platform_device___3 *, pm_message_t);
	int (*resume)(struct platform_device___3 *);
	struct device_driver___61 driver;
	const struct platform_device_id *id_table;
};

struct xol_area___79 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___79 *page;
	long unsigned int vaddr;
};

struct core_thread___78 {
	struct task_struct___78 *task;
	struct core_thread___78 *next;
};

struct core_state___78 {
	atomic_t nr_threads;
	struct core_thread___78 dumper;
	struct completion startup;
};

struct signal_struct___78 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___78 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___78 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___39 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___39 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___79 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cpu_timer_list___4 {
	struct list_head entry;
	union cpu_time_count expires;
	union cpu_time_count incr;
	struct task_struct___78 *task;
	int firing;
};

struct k_itimer___4 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	clockid_t it_clock;
	timer_t it_id;
	int it_overrun;
	int it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	struct signal_struct___78 *it_signal;
	union {
		struct pid___39 *it_pid;
		struct task_struct___78 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
			ktime_t interval;
		} real;
		struct cpu_timer_list___4 cpu;
		struct {
			unsigned int clock;
			unsigned int node;
			long unsigned int incr;
			long unsigned int expires;
		} mmtimer;
		struct {
			struct alarm alarmtimer;
			ktime_t interval;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___4 {
	int (*clock_getres)(const clockid_t, struct timespec *);
	int (*clock_set)(const clockid_t, const struct timespec *);
	int (*clock_get)(const clockid_t, struct timespec *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___4 *);
	int (*nsleep)(const clockid_t, int, struct timespec *, struct timespec *);
	long int (*nsleep_restart)(struct restart_block *);
	int (*timer_set)(struct k_itimer___4 *, int, struct itimerspec *, struct itimerspec *);
	int (*timer_del)(struct k_itimer___4 *);
	void (*timer_get)(struct k_itimer___4 *, struct itimerspec *);
};

struct alarm_base {
	spinlock_t lock;
	struct timerqueue_head timerqueue;
	ktime_t (*gettime)();
	clockid_t base_clockid;
};

typedef __s64 int64_t;

struct clock_event_device___3 {
	void (*event_handler)(struct clock_event_device___3 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___3 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___3 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_mode mode;
	unsigned int features;
	long unsigned int retries;
	void (*broadcast)(const struct cpumask *);
	void (*set_mode)(enum clock_event_mode, struct clock_event_device___3 *);
	void (*suspend)(struct clock_event_device___3 *);
	void (*resume)(struct clock_event_device___3 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___4 *owner;
	long: 64;
	long: 64;
};

struct tick_device___2 {
	struct clock_event_device___3 *evtdev;
	enum tick_device_mode mode;
};

struct page___80;

typedef struct page___80 *pgtable_t___80;

struct address_space___80;

struct kmem_cache___69;

struct page___80 {
	long unsigned int flags;
	struct address_space___80 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___80 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___80 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___69 *slab_cache;
		struct page___80 *first_page;
	};
	long: 64;
};

struct thread_struct___37;

struct task_struct___79;

struct pv_cpu_ops___79 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___37 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___37 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___79 *);
	void (*end_context_switch)(struct task_struct___79 *);
};

struct perf_event___37;

struct thread_struct___37 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___37 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___40;

struct pid_link___40 {
	struct hlist_node node;
	struct pid___40 *pid;
};

struct mutex___80 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___79 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___76 {
	struct page___80 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___84;

struct nsproxy___41;

struct signal_struct___79;

struct css_set___50;

struct perf_event_context___37;

struct task_struct___79 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___79 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___84 *mm;
	struct mm_struct___84 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___79 *real_parent;
	struct task_struct___79 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___79 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___40 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___79 = 0,
		VTIME_USER___79 = 1,
		VTIME_SYS___79 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___37 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___41 *nsproxy;
	struct signal_struct___79 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___50 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___37 *perf_event_ctxp[2];
	struct mutex___80 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___76 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___84 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___84 *, struct mm_struct___84 *);
	void (*dup_mmap)(struct mm_struct___84 *, struct mm_struct___84 *);
	void (*exit_mmap)(struct mm_struct___84 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___84 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___84 *);
	void (*pgd_free)(struct mm_struct___84 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___84 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___84 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___84 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___84 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___84 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___84 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___84 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___84 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___84 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___84 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___84 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___80 lock;
	void *vdso;
} mm_context_t___80;

struct xol_area___80;

struct uprobes_state___80 {
	struct xol_area___80 *xol_area;
};

struct vm_area_struct___84;

struct file___80;

struct core_state___79;

struct mm_struct___84 {
	struct vm_area_struct___84 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___84 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___84 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___80 context;
	long unsigned int flags;
	struct core_state___79 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___79 *owner;
	struct file___80 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___80 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___43;

struct exec_domain___20 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___43 *module;
	struct exec_domain___20 *next;
};

struct module_kobject___42 {
	struct kobject___3 kobj;
	struct module___43 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___42;

struct module___43 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___42 mkobj;
	struct module_attribute___42 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___79 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___37 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___79 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___79 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___79 *target;
};

typedef void (*perf_overflow_handler_t___37)(struct perf_event___37 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___37;

typedef void (*ftrace_func_t___37)(long unsigned int, long unsigned int, struct ftrace_ops___37 *, struct pt_regs *);

struct ftrace_ops___37 {
	ftrace_func_t___37 func;
	struct ftrace_ops___37 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___80 regex_lock;
};

struct pmu___37;

struct fasync_struct___80;

struct pid_namespace___40;

struct perf_cgroup___37;

struct perf_event___37 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___37 *group_leader;
	struct pmu___37 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___37 hw;
	struct perf_event_context___37 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___80 child_mutex;
	struct list_head child_list;
	struct perf_event___37 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___79 *owner;
	struct mutex___80 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___80 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___37 *);
	struct callback_head callback_head;
	struct pid_namespace___40 *ns;
	u64 id;
	perf_overflow_handler_t___37 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___37 ftrace_ops;
	struct perf_cgroup___37 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___38 {
	struct task_struct___79 *task;
	struct exec_domain___20 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___55;

struct attribute_group___55 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___55 **bin_attrs;
};

struct bin_attribute___55 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___80 *, struct kobject___3 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___80 *, struct kobject___3 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	int (*mmap)(struct file___80 *, struct kobject___3 *, struct bin_attribute___55 *, struct vm_area_struct___84 *);
};

struct dentry___81;

struct path___80 {
	struct vfsmount *mnt;
	struct dentry___81 *dentry;
};

struct fown_struct___40 {
	rwlock_t lock;
	struct pid___40 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___81;

struct file_operations___80;

struct file___80 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___80 f_path;
	struct inode___81 *f_inode;
	const struct file_operations___80 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___40 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___80 *f_mapping;
	struct mutex___80 f_pos_lock;
};

struct vm_operations_struct___70;

struct vm_area_struct___84 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___84 *vm_next;
	struct vm_area_struct___84 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___84 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___70 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___80 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___62;

struct dev_pm_ops___62 {
	int (*prepare)(struct device___62 *);
	void (*complete)(struct device___62 *);
	int (*suspend)(struct device___62 *);
	int (*resume)(struct device___62 *);
	int (*freeze)(struct device___62 *);
	int (*thaw)(struct device___62 *);
	int (*poweroff)(struct device___62 *);
	int (*restore)(struct device___62 *);
	int (*suspend_late)(struct device___62 *);
	int (*resume_early)(struct device___62 *);
	int (*freeze_late)(struct device___62 *);
	int (*thaw_early)(struct device___62 *);
	int (*poweroff_late)(struct device___62 *);
	int (*restore_early)(struct device___62 *);
	int (*suspend_noirq)(struct device___62 *);
	int (*resume_noirq)(struct device___62 *);
	int (*freeze_noirq)(struct device___62 *);
	int (*thaw_noirq)(struct device___62 *);
	int (*poweroff_noirq)(struct device___62 *);
	int (*restore_noirq)(struct device___62 *);
	int (*runtime_suspend)(struct device___62 *);
	int (*runtime_resume)(struct device___62 *);
	int (*runtime_idle)(struct device___62 *);
};

struct device_type___62;

struct bus_type___62;

struct device_driver___62;

struct dev_pm_domain___62;

struct class___62;

struct device_rh___62;

struct device___62 {
	struct device___62 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___62 *type;
	struct mutex___80 mutex;
	struct bus_type___62 *bus;
	struct device_driver___62 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___62 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___62 *class;
	const struct attribute_group___55 **groups;
	void (*release)(struct device___62 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___62 *device_rh;
};

struct dev_pm_info_rh___62 {
	void (*set_latency_tolerance)(struct device___62 *, s32);
};

struct dev_pm_domain___62 {
	struct dev_pm_ops___62 ops;
};

struct zone___79;

struct lruvec___79 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___79 *zone;
};

struct pglist_data___79;

struct zone___79 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___79 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___79 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___79 {
	struct zone___79 *zone;
	int zone_idx;
};

struct zonelist___79 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___79 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___79 {
	struct zone___79 node_zones[4];
	struct zonelist___79 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___79 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___56;

struct x86_io_apic_ops___56 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___56 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___56;

struct irq_data___56 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___56 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___79 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___79 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___62 *, char *);
	ssize_t (*store)(struct bus_type___62 *, const char *, size_t);
};

struct device_attribute___62;

struct driver_attribute___62;

struct bus_type___62 {
	const char *name;
	const char *dev_name;
	struct device___62 *dev_root;
	struct bus_attribute___62 *bus_attrs;
	struct device_attribute___62 *dev_attrs;
	struct driver_attribute___62 *drv_attrs;
	const struct attribute_group___55 **bus_groups;
	const struct attribute_group___55 **dev_groups;
	const struct attribute_group___55 **drv_groups;
	int (*match)(struct device___62 *, struct device_driver___62 *);
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	int (*probe)(struct device___62 *);
	int (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*online)(struct device___62 *);
	int (*offline)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct device___62 *, struct device_attribute___62 *, char *);
	ssize_t (*store)(struct device___62 *, struct device_attribute___62 *, const char *, size_t);
};

struct driver_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___62 *, char *);
	ssize_t (*store)(struct device_driver___62 *, const char *, size_t);
};

struct device_driver___62 {
	const char *name;
	struct bus_type___62 *bus;
	struct module___43 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___62 *);
	int (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	const struct attribute_group___55 **groups;
	const struct dev_pm_ops___62 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___62 {
	const char *name;
	const struct attribute_group___55 **groups;
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
};

struct class_attribute___62;

struct class___62 {
	const char *name;
	struct module___43 *owner;
	struct class_attribute___62 *class_attrs;
	struct device_attribute___62 *dev_attrs;
	const struct attribute_group___55 **dev_groups;
	struct bin_attribute___55 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *);
	void (*class_release)(struct class___62 *);
	void (*dev_release)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
	struct subsys_private *p;
};

struct class_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct class___62 *, struct class_attribute___62 *, char *);
	ssize_t (*store)(struct class___62 *, struct class_attribute___62 *, const char *, size_t);
	const void * (*namespace)(struct class___62 *, const struct class_attribute___62 *);
};

struct device_rh___62 {
	struct dev_pm_info_rh___62 power;
};

struct seq_file___58;

struct irq_chip___56 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___56 *);
	void (*irq_shutdown)(struct irq_data___56 *);
	void (*irq_enable)(struct irq_data___56 *);
	void (*irq_disable)(struct irq_data___56 *);
	void (*irq_ack)(struct irq_data___56 *);
	void (*irq_mask)(struct irq_data___56 *);
	void (*irq_mask_ack)(struct irq_data___56 *);
	void (*irq_unmask)(struct irq_data___56 *);
	void (*irq_eoi)(struct irq_data___56 *);
	int (*irq_set_affinity)(struct irq_data___56 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___56 *);
	int (*irq_set_type)(struct irq_data___56 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___56 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___56 *);
	void (*irq_bus_sync_unlock)(struct irq_data___56 *);
	void (*irq_cpu_online)(struct irq_data___56 *);
	void (*irq_cpu_offline)(struct irq_data___56 *);
	void (*irq_suspend)(struct irq_data___56 *);
	void (*irq_resume)(struct irq_data___56 *);
	void (*irq_pm_shutdown)(struct irq_data___56 *);
	void (*irq_print_chip)(struct irq_data___56 *, struct seq_file___58 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___56 *, void *);
	long unsigned int flags;
};

struct seq_operations___57;

struct seq_file___58 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___80 lock;
	const struct seq_operations___57 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___80 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___80 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___69;

struct memcg_cache_params___69;

struct kmem_cache___69 {
	struct kmem_cache_cpu___69 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___69 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___80;

struct address_space___80 {
	struct inode___81 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___80 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___80 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___67;

struct vm_operations_struct___70 {
	void (*open)(struct vm_area_struct___84 *);
	void (*close)(struct vm_area_struct___84 *);
	int (*fault)(struct vm_area_struct___84 *, struct vm_fault___67 *);
	int (*page_mkwrite)(struct vm_area_struct___84 *, struct vm_fault___67 *);
	int (*access)(struct vm_area_struct___84 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___84 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___84 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___84 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___84 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___79 {
	struct task_struct___79 *task;
	struct core_thread___79 *next;
};

struct core_state___79 {
	atomic_t nr_threads;
	struct core_thread___79 dumper;
	struct completion startup;
};

struct upid___40 {
	int nr;
	struct pid_namespace___40 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___40 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___79 *child_reaper;
	struct kmem_cache___69 *pid_cachep;
	unsigned int level;
	struct pid_namespace___40 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___81 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___40 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___40 numbers[1];
};

struct nsproxy___41 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___40 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___79 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___79 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___79 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___40 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___40 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___80 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___50;

struct css_set___50 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___50 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___37 {
	struct pmu___37 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___80 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___79 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___37 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct module_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___42 *, struct module_kobject___42 *, char *);
	ssize_t (*store)(struct module_attribute___42 *, struct module_kobject___42 *, const char *, size_t);
	void (*setup)(struct module___43 *, const char *);
	int (*test)(struct module___43 *);
	void (*free)(struct module___43 *);
};

struct seq_operations___57 {
	void * (*start)(struct seq_file___58 *, loff_t *);
	void (*stop)(struct seq_file___58 *, void *);
	void * (*next)(struct seq_file___58 *, void *, loff_t *);
	int (*show)(struct seq_file___58 *, void *);
};

struct cdev___29 {
	struct kobject___3 kobj;
	struct module___43 *owner;
	const struct file_operations___80 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___48;

struct file_lock___80;

struct file_operations___80 {
	struct module___43 *owner;
	loff_t (*llseek)(struct file___80 *, loff_t, int);
	ssize_t (*read)(struct file___80 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___80 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___80 *, void *, filldir_t);
	unsigned int (*poll)(struct file___80 *, struct poll_table_struct___48 *);
	long int (*unlocked_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___80 *, struct vm_area_struct___84 *);
	int (*open)(struct inode___81 *, struct file___80 *);
	int (*flush)(struct file___80 *, fl_owner_t);
	int (*release)(struct inode___81 *, struct file___80 *);
	int (*fsync)(struct file___80 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___80 *, int);
	int (*lock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*sendpage)(struct file___80 *, struct page___80 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___80 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___80 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___80 *, long int, struct file_lock___80 **, void **);
		struct {
			int (*setlease)(struct file___80 *, long int, struct file_lock___80 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___80 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___58 *, struct file___80 *);
};

struct dentry_operations___80;

struct super_block___81;

struct dentry___81 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___81 *d_parent;
	struct qstr d_name;
	struct inode___81 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___80 *d_op;
	struct super_block___81 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___80;

struct dquot___80;

struct block_device___80;

struct inode___81 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___80 *i_op;
	struct super_block___81 *i_sb;
	struct address_space___80 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___80 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___80 *i_fop;
	struct file_lock___80 *i_flock;
	struct address_space___80 i_data;
	struct dquot___80 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___80 *i_bdev;
		struct cdev___29 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___80 {
	int (*d_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_hash)(const struct dentry___81 *, struct qstr *);
	int (*d_compare)(const struct dentry___81 *, const struct dentry___81 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___81 *);
	void (*d_release)(struct dentry___81 *);
	void (*d_prune)(struct dentry___81 *);
	void (*d_iput)(struct dentry___81 *, struct inode___81 *);
	char * (*d_dname)(struct dentry___81 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___80 *);
	int (*d_manage)(struct dentry___81 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___80;

struct mem_dqinfo___80 {
	struct quota_format_type___80 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___80;

struct quota_info___80 {
	unsigned int flags;
	struct mutex___80 dqio_mutex;
	struct mutex___80 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___81 *files[2];
	struct mem_dqinfo___80 info[2];
	const struct quota_format_ops___80 *ops[2];
};

struct file_system_type___80;

struct super_operations___80;

struct dquot_operations___80;

struct quotactl_ops___80;

struct xattr_handler___50;

struct super_block___81 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___80 *s_type;
	const struct super_operations___80 *s_op;
	const struct dquot_operations___80 *dq_op;
	const struct quotactl_ops___80 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___81 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___50 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___80 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___80 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___80 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___80 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___80 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___81 *bd_inode;
	struct super_block___81 *bd_super;
	struct mutex___80 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___80 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___80 bd_fsfreeze_mutex;
};

struct cgroup___50;

struct cgroup_subsys_state___50 {
	struct cgroup___50 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___81 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___80 *ia_file;
};

struct dquot___80 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___80 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___81 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___80 {
	int qf_fmt_id;
	const struct quota_format_ops___80 *qf_ops;
	struct module___43 *qf_owner;
	struct quota_format_type___80 *qf_next;
};

struct quota_format_ops___80 {
	int (*check_quota_file)(struct super_block___81 *, int);
	int (*read_file_info)(struct super_block___81 *, int);
	int (*write_file_info)(struct super_block___81 *, int);
	int (*free_file_info)(struct super_block___81 *, int);
	int (*read_dqblk)(struct dquot___80 *);
	int (*commit_dqblk)(struct dquot___80 *);
	int (*release_dqblk)(struct dquot___80 *);
};

struct dquot_operations___80 {
	int (*write_dquot)(struct dquot___80 *);
	struct dquot___80 * (*alloc_dquot)(struct super_block___81 *, int);
	void (*destroy_dquot)(struct dquot___80 *);
	int (*acquire_dquot)(struct dquot___80 *);
	int (*release_dquot)(struct dquot___80 *);
	int (*mark_dirty)(struct dquot___80 *);
	int (*write_info)(struct super_block___81 *, int);
	qsize_t * (*get_reserved_space)(struct inode___81 *);
};

struct quotactl_ops___80 {
	int (*quota_on)(struct super_block___81 *, int, int, struct path___80 *);
	int (*quota_on_meta)(struct super_block___81 *, int, int);
	int (*quota_off)(struct super_block___81 *, int);
	int (*quota_sync)(struct super_block___81 *, int);
	int (*get_info)(struct super_block___81 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___81 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___81 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___81 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___81 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___81 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___81 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___81 *, unsigned int);
};

struct address_space_operations___80 {
	int (*writepage)(struct page___80 *, struct writeback_control *);
	int (*readpage)(struct file___80 *, struct page___80 *);
	int (*writepages)(struct address_space___80 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___80 *);
	int (*readpages)(struct file___80 *, struct address_space___80 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___80 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___80 **, void **);
	int (*write_end)(struct file___80 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___80 *, void *);
	sector_t (*bmap)(struct address_space___80 *, sector_t);
	void (*invalidatepage)(struct page___80 *, long unsigned int);
	int (*releasepage)(struct page___80 *, gfp_t);
	void (*freepage)(struct page___80 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___80 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___80 *, struct page___80 *, struct page___80 *, enum migrate_mode);
	int (*launder_page)(struct page___80 *);
	int (*is_partially_uptodate)(struct page___80 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___80 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___80 *, struct page___80 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___80 *, sector_t *);
	void (*swap_deactivate)(struct file___80 *);
	void (*invalidatepage_range)(struct page___80 *, unsigned int, unsigned int);
};

struct inode_operations___80 {
	struct dentry___81 * (*lookup)(struct inode___81 *, struct dentry___81 *, unsigned int);
	void * (*follow_link)(struct dentry___81 *, struct nameidata *);
	int (*permission)(struct inode___81 *, int);
	struct posix_acl * (*get_acl)(struct inode___81 *, int);
	int (*readlink)(struct dentry___81 *, char *, int);
	void (*put_link)(struct dentry___81 *, struct nameidata *, void *);
	int (*create)(struct inode___81 *, struct dentry___81 *, umode_t, bool);
	int (*link)(struct dentry___81 *, struct inode___81 *, struct dentry___81 *);
	int (*unlink)(struct inode___81 *, struct dentry___81 *);
	int (*symlink)(struct inode___81 *, struct dentry___81 *, const char *);
	int (*mkdir)(struct inode___81 *, struct dentry___81 *, umode_t);
	int (*rmdir)(struct inode___81 *, struct dentry___81 *);
	int (*mknod)(struct inode___81 *, struct dentry___81 *, umode_t, dev_t);
	int (*rename)(struct inode___81 *, struct dentry___81 *, struct inode___81 *, struct dentry___81 *);
	int (*setattr)(struct dentry___81 *, struct iattr___81 *);
	int (*getattr)(struct vfsmount *, struct dentry___81 *, struct kstat *);
	int (*setxattr)(struct dentry___81 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___81 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___81 *, char *, size_t);
	int (*removexattr)(struct dentry___81 *, const char *);
	int (*fiemap)(struct inode___81 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___81 *, struct timespec *, int);
	int (*atomic_open)(struct inode___81 *, struct dentry___81 *, struct file___80 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___80;

struct lock_manager_operations___80;

struct file_lock___80 {
	struct file_lock___80 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___40 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___80 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___80 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___80 *fl_ops;
	const struct lock_manager_operations___80 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___80 {
	void (*fl_copy_lock)(struct file_lock___80 *, struct file_lock___80 *);
	void (*fl_release_private)(struct file_lock___80 *);
};

struct lock_manager_operations___80 {
	int (*lm_compare_owner)(struct file_lock___80 *, struct file_lock___80 *);
	long unsigned int (*lm_owner_key)(struct file_lock___80 *);
	void (*lm_notify)(struct file_lock___80 *);
	int (*lm_grant)(struct file_lock___80 *, struct file_lock___80 *, int);
	void (*lm_break)(struct file_lock___80 *);
	int (*lm_change)(struct file_lock___80 **, int);
};

struct fasync_struct___80 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___80 *fa_next;
	struct file___80 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___80 {
	const char *name;
	int fs_flags;
	struct dentry___81 * (*mount)(struct file_system_type___80 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___81 *);
	struct module___43 *owner;
	struct file_system_type___80 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___80 {
	struct inode___81 * (*alloc_inode)(struct super_block___81 *);
	void (*destroy_inode)(struct inode___81 *);
	void (*dirty_inode)(struct inode___81 *, int);
	int (*write_inode)(struct inode___81 *, struct writeback_control *);
	int (*drop_inode)(struct inode___81 *);
	void (*evict_inode)(struct inode___81 *);
	void (*put_super)(struct super_block___81 *);
	int (*sync_fs)(struct super_block___81 *, int);
	int (*freeze_fs)(struct super_block___81 *);
	int (*unfreeze_fs)(struct super_block___81 *);
	int (*statfs)(struct dentry___81 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___81 *, int *, char *);
	void (*umount_begin)(struct super_block___81 *);
	int (*show_options)(struct seq_file___58 *, struct dentry___81 *);
	int (*show_devname)(struct seq_file___58 *, struct dentry___81 *);
	int (*show_path)(struct seq_file___58 *, struct dentry___81 *);
	int (*show_stats)(struct seq_file___58 *, struct dentry___81 *);
	ssize_t (*quota_read)(struct super_block___81 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___81 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___81 *);
	int (*bdev_try_to_free_page)(struct super_block___81 *, struct page___80 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___81 *);
	void (*free_cached_objects)(struct super_block___81 *, int);
};

struct xattr_handler___50 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___81 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___81 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___81 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___48)(struct file___80 *, wait_queue_head_t *, struct poll_table_struct___48 *);

struct poll_table_struct___48 {
	poll_queue_proc___48 _qproc;
	long unsigned int _key;
};

struct vm_fault___67 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___80 *page;
};

struct kmem_cache_cpu___69 {
	void **freelist;
	long unsigned int tid;
	struct page___80 *page;
	struct page___80 *partial;
};

struct memcg_cache_params___69 {
	bool is_root_cache;
	union {
		struct kmem_cache___69 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___69 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___50;

struct cgroup___50 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___50 *parent;
	struct dentry___81 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___50 *subsys[11];
	struct cgroupfs_root___50 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___80 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___50 {
	struct super_block___81 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___50 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___37;

struct pmu___37 {
	struct list_head entry;
	struct device___62 *dev;
	const struct attribute_group___55 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___37 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___37 *);
	void (*pmu_disable)(struct pmu___37 *);
	int (*event_init)(struct perf_event___37 *);
	int (*add)(struct perf_event___37 *, int);
	void (*del)(struct perf_event___37 *, int);
	void (*start)(struct perf_event___37 *, int);
	void (*stop)(struct perf_event___37 *, int);
	void (*read)(struct perf_event___37 *);
	void (*start_txn)(struct pmu___37 *);
	int (*commit_txn)(struct pmu___37 *);
	void (*cancel_txn)(struct pmu___37 *);
	int (*event_idx)(struct perf_event___37 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___43 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___37 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___37 *);
};

struct perf_cpu_context___37 {
	struct perf_event_context___37 ctx;
	struct perf_event_context___37 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___37 *unique_pmu;
	struct perf_cgroup___37 *cgrp;
};

struct perf_cgroup___37 {
	struct cgroup_subsys_state___50 css;
	struct perf_cgroup_info *info;
};

struct clock_event_device___4 {
	void (*event_handler)(struct clock_event_device___4 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___4 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___4 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_mode mode;
	unsigned int features;
	long unsigned int retries;
	void (*broadcast)(const struct cpumask *);
	void (*set_mode)(enum clock_event_mode, struct clock_event_device___4 *);
	void (*suspend)(struct clock_event_device___4 *);
	void (*resume)(struct clock_event_device___4 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___43 *owner;
	long: 64;
	long: 64;
};

struct tick_device___3 {
	struct clock_event_device___4 *evtdev;
	enum tick_device_mode mode;
};

struct entry {
	struct entry *next;
	void *timer;
	void *start_func;
	void *expire_func;
	pid_t pid;
	long unsigned int count;
	unsigned int timer_flag;
	char comm[17];
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page___81;

typedef struct page___81 *pgtable_t___81;

struct address_space___81;

struct kmem_cache___70;

struct page___81 {
	long unsigned int flags;
	struct address_space___81 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___81 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___81 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___70 *slab_cache;
		struct page___81 *first_page;
	};
	long: 64;
};

struct thread_struct___38;

struct task_struct___80;

struct pv_cpu_ops___80 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___80 *);
	void (*end_context_switch)(struct task_struct___80 *);
};

struct perf_event___38;

struct thread_struct___38 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___38 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___41;

struct pid_link___41 {
	struct hlist_node node;
	struct pid___41 *pid;
};

struct mutex___81 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___80 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___77 {
	struct page___81 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___85;

struct nsproxy___42;

struct signal_struct___80;

struct css_set___51;

struct perf_event_context___38;

struct task_struct___80 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___80 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___85 *mm;
	struct mm_struct___85 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___80 *real_parent;
	struct task_struct___80 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___80 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___41 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___80 = 0,
		VTIME_USER___80 = 1,
		VTIME_SYS___80 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___42 *nsproxy;
	struct signal_struct___80 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___51 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___38 *perf_event_ctxp[2];
	struct mutex___81 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___77 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___85 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___85 *, struct mm_struct___85 *);
	void (*dup_mmap)(struct mm_struct___85 *, struct mm_struct___85 *);
	void (*exit_mmap)(struct mm_struct___85 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___85 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___85 *);
	void (*pgd_free)(struct mm_struct___85 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___85 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___85 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___85 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___85 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___85 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___85 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___85 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___85 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___85 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___85 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___85 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___81 lock;
	void *vdso;
} mm_context_t___81;

struct xol_area___81;

struct uprobes_state___81 {
	struct xol_area___81 *xol_area;
};

struct vm_area_struct___85;

struct file___81;

struct core_state___80;

struct mm_struct___85 {
	struct vm_area_struct___85 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___85 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___85 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___81 context;
	long unsigned int flags;
	struct core_state___80 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___80 *owner;
	struct file___81 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___81 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___38 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___80 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___80 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___80 *target;
};

typedef void (*perf_overflow_handler_t___38)(struct perf_event___38 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___38;

typedef void (*ftrace_func_t___38)(long unsigned int, long unsigned int, struct ftrace_ops___38 *, struct pt_regs *);

struct ftrace_ops___38 {
	ftrace_func_t___38 func;
	struct ftrace_ops___38 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___81 regex_lock;
};

struct pmu___38;

struct fasync_struct___81;

struct pid_namespace___41;

struct ftrace_event_call___29;

struct perf_cgroup___38;

struct perf_event___38 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___38 *group_leader;
	struct pmu___38 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___38 hw;
	struct perf_event_context___38 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___81 child_mutex;
	struct list_head child_list;
	struct perf_event___38 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___80 *owner;
	struct mutex___81 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___81 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___38 *);
	struct callback_head callback_head;
	struct pid_namespace___41 *ns;
	u64 id;
	perf_overflow_handler_t___38 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___29 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___38 ftrace_ops;
	struct perf_cgroup___38 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___39 {
	struct task_struct___80 *task;
	struct exec_domain___20 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___80;

struct lruvec___80 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___80 *zone;
};

struct pglist_data___80;

struct zone___80 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___80 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___80 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___80 {
	struct zone___80 *zone;
	int zone_idx;
};

struct zonelist___80 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___80 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___80 {
	struct zone___80 node_zones[4];
	struct zonelist___80 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___80 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___57;

struct x86_io_apic_ops___57 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___57 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___57;

struct irq_data___57 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___57 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___63;

struct dev_pm_ops___63 {
	int (*prepare)(struct device___63 *);
	void (*complete)(struct device___63 *);
	int (*suspend)(struct device___63 *);
	int (*resume)(struct device___63 *);
	int (*freeze)(struct device___63 *);
	int (*thaw)(struct device___63 *);
	int (*poweroff)(struct device___63 *);
	int (*restore)(struct device___63 *);
	int (*suspend_late)(struct device___63 *);
	int (*resume_early)(struct device___63 *);
	int (*freeze_late)(struct device___63 *);
	int (*thaw_early)(struct device___63 *);
	int (*poweroff_late)(struct device___63 *);
	int (*restore_early)(struct device___63 *);
	int (*suspend_noirq)(struct device___63 *);
	int (*resume_noirq)(struct device___63 *);
	int (*freeze_noirq)(struct device___63 *);
	int (*thaw_noirq)(struct device___63 *);
	int (*poweroff_noirq)(struct device___63 *);
	int (*restore_noirq)(struct device___63 *);
	int (*runtime_suspend)(struct device___63 *);
	int (*runtime_resume)(struct device___63 *);
	int (*runtime_idle)(struct device___63 *);
};

struct device_type___63;

struct bus_type___63;

struct device_driver___63;

struct dev_pm_domain___63;

struct class___63;

struct attribute_group___56;

struct device_rh___63;

struct device___63 {
	struct device___63 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___63 *type;
	struct mutex___81 mutex;
	struct bus_type___63 *bus;
	struct device_driver___63 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___63 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___28 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___63 *class;
	const struct attribute_group___56 **groups;
	void (*release)(struct device___63 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___63 *device_rh;
};

struct dev_pm_info_rh___63 {
	void (*set_latency_tolerance)(struct device___63 *, s32);
};

struct dev_pm_domain___63 {
	struct dev_pm_ops___63 ops;
};

struct smp_ops___80 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___80 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___56;

struct attribute_group___56 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___56 **bin_attrs;
};

struct bin_attribute___56 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___81 *, struct kobject___3 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___81 *, struct kobject___3 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	int (*mmap)(struct file___81 *, struct kobject___3 *, struct bin_attribute___56 *, struct vm_area_struct___85 *);
};

struct vfsmount___10;

struct dentry___82;

struct path___81 {
	struct vfsmount___10 *mnt;
	struct dentry___82 *dentry;
};

struct fown_struct___41 {
	rwlock_t lock;
	struct pid___41 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___82;

struct file_operations___81;

struct file___81 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___81 f_path;
	struct inode___82 *f_inode;
	const struct file_operations___81 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___41 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___81 *f_mapping;
	struct mutex___81 f_pos_lock;
};

struct vm_operations_struct___71;

struct vm_area_struct___85 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___85 *vm_next;
	struct vm_area_struct___85 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___85 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___71 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___81 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___70 {
	void **freelist;
	long unsigned int tid;
	struct page___81 *page;
	struct page___81 *partial;
};

struct memcg_cache_params___70;

struct kmem_cache___70 {
	struct kmem_cache_cpu___70 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___70 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___70 {
	bool is_root_cache;
	union {
		struct kmem_cache___70 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___70 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___81;

struct super_block___82;

struct dentry___82 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___82 *d_parent;
	struct qstr d_name;
	struct inode___82 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___81 *d_op;
	struct super_block___82 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___81;

struct address_space___81 {
	struct inode___82 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___81 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___81 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___81;

struct file_lock___81;

struct dquot___81;

struct block_device___81;

struct inode___82 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___81 *i_op;
	struct super_block___82 *i_sb;
	struct address_space___81 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___81 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___81 *i_fop;
	struct file_lock___81 *i_flock;
	struct address_space___81 i_data;
	struct dquot___81 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___81 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___81 {
	int (*d_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_hash)(const struct dentry___82 *, struct qstr *);
	int (*d_compare)(const struct dentry___82 *, const struct dentry___82 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___82 *);
	void (*d_release)(struct dentry___82 *);
	void (*d_prune)(struct dentry___82 *);
	void (*d_iput)(struct dentry___82 *, struct inode___82 *);
	char * (*d_dname)(struct dentry___82 *, char *, int);
	struct vfsmount___10 * (*d_automount)(struct path___81 *);
	int (*d_manage)(struct dentry___82 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___81;

struct mem_dqinfo___81 {
	struct quota_format_type___81 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___81;

struct quota_info___81 {
	unsigned int flags;
	struct mutex___81 dqio_mutex;
	struct mutex___81 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___82 *files[2];
	struct mem_dqinfo___81 info[2];
	const struct quota_format_ops___81 *ops[2];
};

struct file_system_type___81;

struct super_operations___81;

struct dquot_operations___81;

struct quotactl_ops___81;

struct xattr_handler___51;

struct super_block___82 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___81 *s_type;
	const struct super_operations___81 *s_op;
	const struct dquot_operations___81 *dq_op;
	const struct quotactl_ops___81 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___82 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___51 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___81 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___81 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___81 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___81 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___10 {
	struct dentry___82 *mnt_root;
	struct super_block___82 *mnt_sb;
	int mnt_flags;
};

struct upid___41 {
	int nr;
	struct pid_namespace___41 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___41 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___80 *child_reaper;
	struct kmem_cache___70 *pid_cachep;
	unsigned int level;
	struct pid_namespace___41 *parent;
	struct vfsmount___10 *proc_mnt;
	struct dentry___82 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___41 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___41 numbers[1];
};

struct block_device___81 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___82 *bd_inode;
	struct super_block___82 *bd_super;
	struct mutex___81 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___81 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___81 bd_fsfreeze_mutex;
};

struct cgroup___51;

struct cgroup_subsys_state___51 {
	struct cgroup___51 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___82 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___81 *ia_file;
};

struct dquot___81 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___81 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___82 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___81 {
	int qf_fmt_id;
	const struct quota_format_ops___81 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___81 *qf_next;
};

struct quota_format_ops___81 {
	int (*check_quota_file)(struct super_block___82 *, int);
	int (*read_file_info)(struct super_block___82 *, int);
	int (*write_file_info)(struct super_block___82 *, int);
	int (*free_file_info)(struct super_block___82 *, int);
	int (*read_dqblk)(struct dquot___81 *);
	int (*commit_dqblk)(struct dquot___81 *);
	int (*release_dqblk)(struct dquot___81 *);
};

struct dquot_operations___81 {
	int (*write_dquot)(struct dquot___81 *);
	struct dquot___81 * (*alloc_dquot)(struct super_block___82 *, int);
	void (*destroy_dquot)(struct dquot___81 *);
	int (*acquire_dquot)(struct dquot___81 *);
	int (*release_dquot)(struct dquot___81 *);
	int (*mark_dirty)(struct dquot___81 *);
	int (*write_info)(struct super_block___82 *, int);
	qsize_t * (*get_reserved_space)(struct inode___82 *);
};

struct quotactl_ops___81 {
	int (*quota_on)(struct super_block___82 *, int, int, struct path___81 *);
	int (*quota_on_meta)(struct super_block___82 *, int, int);
	int (*quota_off)(struct super_block___82 *, int);
	int (*quota_sync)(struct super_block___82 *, int);
	int (*get_info)(struct super_block___82 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___82 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___82 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___82 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___82 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___82 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___82 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___82 *, unsigned int);
};

struct address_space_operations___81 {
	int (*writepage)(struct page___81 *, struct writeback_control *);
	int (*readpage)(struct file___81 *, struct page___81 *);
	int (*writepages)(struct address_space___81 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___81 *);
	int (*readpages)(struct file___81 *, struct address_space___81 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___81 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___81 **, void **);
	int (*write_end)(struct file___81 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___81 *, void *);
	sector_t (*bmap)(struct address_space___81 *, sector_t);
	void (*invalidatepage)(struct page___81 *, long unsigned int);
	int (*releasepage)(struct page___81 *, gfp_t);
	void (*freepage)(struct page___81 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___81 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___81 *, struct page___81 *, struct page___81 *, enum migrate_mode);
	int (*launder_page)(struct page___81 *);
	int (*is_partially_uptodate)(struct page___81 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___81 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___81 *, struct page___81 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___81 *, sector_t *);
	void (*swap_deactivate)(struct file___81 *);
	void (*invalidatepage_range)(struct page___81 *, unsigned int, unsigned int);
};

struct inode_operations___81 {
	struct dentry___82 * (*lookup)(struct inode___82 *, struct dentry___82 *, unsigned int);
	void * (*follow_link)(struct dentry___82 *, struct nameidata *);
	int (*permission)(struct inode___82 *, int);
	struct posix_acl * (*get_acl)(struct inode___82 *, int);
	int (*readlink)(struct dentry___82 *, char *, int);
	void (*put_link)(struct dentry___82 *, struct nameidata *, void *);
	int (*create)(struct inode___82 *, struct dentry___82 *, umode_t, bool);
	int (*link)(struct dentry___82 *, struct inode___82 *, struct dentry___82 *);
	int (*unlink)(struct inode___82 *, struct dentry___82 *);
	int (*symlink)(struct inode___82 *, struct dentry___82 *, const char *);
	int (*mkdir)(struct inode___82 *, struct dentry___82 *, umode_t);
	int (*rmdir)(struct inode___82 *, struct dentry___82 *);
	int (*mknod)(struct inode___82 *, struct dentry___82 *, umode_t, dev_t);
	int (*rename)(struct inode___82 *, struct dentry___82 *, struct inode___82 *, struct dentry___82 *);
	int (*setattr)(struct dentry___82 *, struct iattr___82 *);
	int (*getattr)(struct vfsmount___10 *, struct dentry___82 *, struct kstat *);
	int (*setxattr)(struct dentry___82 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___82 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___82 *, char *, size_t);
	int (*removexattr)(struct dentry___82 *, const char *);
	int (*fiemap)(struct inode___82 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___82 *, struct timespec *, int);
	int (*atomic_open)(struct inode___82 *, struct dentry___82 *, struct file___81 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___49;

struct seq_file___59;

struct file_operations___81 {
	struct module *owner;
	loff_t (*llseek)(struct file___81 *, loff_t, int);
	ssize_t (*read)(struct file___81 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___81 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___81 *, void *, filldir_t);
	unsigned int (*poll)(struct file___81 *, struct poll_table_struct___49 *);
	long int (*unlocked_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___81 *, struct vm_area_struct___85 *);
	int (*open)(struct inode___82 *, struct file___81 *);
	int (*flush)(struct file___81 *, fl_owner_t);
	int (*release)(struct inode___82 *, struct file___81 *);
	int (*fsync)(struct file___81 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___81 *, int);
	int (*lock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*sendpage)(struct file___81 *, struct page___81 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___81 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___81 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___81 *, long int, struct file_lock___81 **, void **);
		struct {
			int (*setlease)(struct file___81 *, long int, struct file_lock___81 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___81 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___59 *, struct file___81 *);
};

struct file_lock_operations___81;

struct lock_manager_operations___81;

struct file_lock___81 {
	struct file_lock___81 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___41 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___81 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___81 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___81 *fl_ops;
	const struct lock_manager_operations___81 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___81 {
	void (*fl_copy_lock)(struct file_lock___81 *, struct file_lock___81 *);
	void (*fl_release_private)(struct file_lock___81 *);
};

struct lock_manager_operations___81 {
	int (*lm_compare_owner)(struct file_lock___81 *, struct file_lock___81 *);
	long unsigned int (*lm_owner_key)(struct file_lock___81 *);
	void (*lm_notify)(struct file_lock___81 *);
	int (*lm_grant)(struct file_lock___81 *, struct file_lock___81 *, int);
	void (*lm_break)(struct file_lock___81 *);
	int (*lm_change)(struct file_lock___81 **, int);
};

struct fasync_struct___81 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___81 *fa_next;
	struct file___81 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___81 {
	const char *name;
	int fs_flags;
	struct dentry___82 * (*mount)(struct file_system_type___81 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___82 *);
	struct module *owner;
	struct file_system_type___81 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___81 {
	struct inode___82 * (*alloc_inode)(struct super_block___82 *);
	void (*destroy_inode)(struct inode___82 *);
	void (*dirty_inode)(struct inode___82 *, int);
	int (*write_inode)(struct inode___82 *, struct writeback_control *);
	int (*drop_inode)(struct inode___82 *);
	void (*evict_inode)(struct inode___82 *);
	void (*put_super)(struct super_block___82 *);
	int (*sync_fs)(struct super_block___82 *, int);
	int (*freeze_fs)(struct super_block___82 *);
	int (*unfreeze_fs)(struct super_block___82 *);
	int (*statfs)(struct dentry___82 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___82 *, int *, char *);
	void (*umount_begin)(struct super_block___82 *);
	int (*show_options)(struct seq_file___59 *, struct dentry___82 *);
	int (*show_devname)(struct seq_file___59 *, struct dentry___82 *);
	int (*show_path)(struct seq_file___59 *, struct dentry___82 *);
	int (*show_stats)(struct seq_file___59 *, struct dentry___82 *);
	ssize_t (*quota_read)(struct super_block___82 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___82 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___82 *);
	int (*bdev_try_to_free_page)(struct super_block___82 *, struct page___81 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___82 *);
	void (*free_cached_objects)(struct super_block___82 *, int);
};

struct xattr_handler___51 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___82 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___82 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___82 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___49)(struct file___81 *, wait_queue_head_t *, struct poll_table_struct___49 *);

struct poll_table_struct___49 {
	poll_queue_proc___49 _qproc;
	long unsigned int _key;
};

struct seq_operations___58;

struct seq_file___59 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___81 lock;
	const struct seq_operations___58 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nsproxy___42 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___41 *pid_ns;
	struct net *net_ns;
};

union futex_key {
	struct {
		long unsigned int pgoff;
		struct inode___82 *inode;
		int offset;
	} shared;
	struct {
		long unsigned int address;
		struct mm_struct___85 *mm;
		int offset;
	} private;
	struct {
		long unsigned int word;
		void *ptr;
		int offset;
	} both;
};

struct xol_area___81 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___81 *page;
	long unsigned int vaddr;
};

struct vm_fault___68;

struct vm_operations_struct___71 {
	void (*open)(struct vm_area_struct___85 *);
	void (*close)(struct vm_area_struct___85 *);
	int (*fault)(struct vm_area_struct___85 *, struct vm_fault___68 *);
	int (*page_mkwrite)(struct vm_area_struct___85 *, struct vm_fault___68 *);
	int (*access)(struct vm_area_struct___85 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___85 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___85 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___85 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___85 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___80 {
	struct task_struct___80 *task;
	struct core_thread___80 *next;
};

struct core_state___80 {
	atomic_t nr_threads;
	struct core_thread___80 dumper;
	struct completion startup;
};

struct vm_fault___68 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___81 *page;
};

struct irq_chip___57 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___57 *);
	void (*irq_shutdown)(struct irq_data___57 *);
	void (*irq_enable)(struct irq_data___57 *);
	void (*irq_disable)(struct irq_data___57 *);
	void (*irq_ack)(struct irq_data___57 *);
	void (*irq_mask)(struct irq_data___57 *);
	void (*irq_mask_ack)(struct irq_data___57 *);
	void (*irq_unmask)(struct irq_data___57 *);
	void (*irq_eoi)(struct irq_data___57 *);
	int (*irq_set_affinity)(struct irq_data___57 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___57 *);
	int (*irq_set_type)(struct irq_data___57 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___57 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___57 *);
	void (*irq_bus_sync_unlock)(struct irq_data___57 *);
	void (*irq_cpu_online)(struct irq_data___57 *);
	void (*irq_cpu_offline)(struct irq_data___57 *);
	void (*irq_suspend)(struct irq_data___57 *);
	void (*irq_resume)(struct irq_data___57 *);
	void (*irq_pm_shutdown)(struct irq_data___57 *);
	void (*irq_print_chip)(struct irq_data___57 *, struct seq_file___59 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___57 *, void *);
	long unsigned int flags;
};

struct seq_operations___58 {
	void * (*start)(struct seq_file___59 *, loff_t *);
	void (*stop)(struct seq_file___59 *, void *);
	void * (*next)(struct seq_file___59 *, void *, loff_t *);
	int (*show)(struct seq_file___59 *, void *);
};

struct rt_mutex {
	raw_spinlock_t wait_lock;
	struct plist_head wait_list;
	struct task_struct___80 *owner;
};

struct hrtimer_sleeper___2 {
	struct hrtimer timer;
	struct task_struct___80 *task;
};

struct signal_struct___80 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___80 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___80 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___41 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___81 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_mutex_waiter {
	struct plist_node list_entry;
	struct plist_node pi_list_entry;
	struct task_struct___80 *task;
	struct rt_mutex *lock;
};

struct css_set___51 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___51 *subsys[11];
	struct callback_head callback_head;
};

struct futex_pi_state {
	struct list_head list;
	struct rt_mutex pi_mutex;
	struct task_struct___80 *owner;
	atomic_t refcount;
	union futex_key key;
};

struct perf_event_context___38 {
	struct pmu___38 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___81 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___80 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___38 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bus_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___63 *, char *);
	ssize_t (*store)(struct bus_type___63 *, const char *, size_t);
};

struct device_attribute___63;

struct driver_attribute___63;

struct bus_type___63 {
	const char *name;
	const char *dev_name;
	struct device___63 *dev_root;
	struct bus_attribute___63 *bus_attrs;
	struct device_attribute___63 *dev_attrs;
	struct driver_attribute___63 *drv_attrs;
	const struct attribute_group___56 **bus_groups;
	const struct attribute_group___56 **dev_groups;
	const struct attribute_group___56 **drv_groups;
	int (*match)(struct device___63 *, struct device_driver___63 *);
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	int (*probe)(struct device___63 *);
	int (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*online)(struct device___63 *);
	int (*offline)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct device___63 *, struct device_attribute___63 *, char *);
	ssize_t (*store)(struct device___63 *, struct device_attribute___63 *, const char *, size_t);
};

struct driver_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___63 *, char *);
	ssize_t (*store)(struct device_driver___63 *, const char *, size_t);
};

struct device_driver___63 {
	const char *name;
	struct bus_type___63 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___63 *);
	int (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	const struct attribute_group___56 **groups;
	const struct dev_pm_ops___63 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___63 {
	const char *name;
	const struct attribute_group___56 **groups;
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
};

struct class_attribute___63;

struct class___63 {
	const char *name;
	struct module *owner;
	struct class_attribute___63 *class_attrs;
	struct device_attribute___63 *dev_attrs;
	const struct attribute_group___56 **dev_groups;
	struct bin_attribute___56 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *);
	void (*class_release)(struct class___63 *);
	void (*dev_release)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
	struct subsys_private *p;
};

struct class_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct class___63 *, struct class_attribute___63 *, char *);
	ssize_t (*store)(struct class___63 *, struct class_attribute___63 *, const char *, size_t);
	const void * (*namespace)(struct class___63 *, const struct class_attribute___63 *);
};

struct device_rh___63 {
	struct dev_pm_info_rh___63 power;
};

struct cgroupfs_root___51;

struct cgroup___51 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___51 *parent;
	struct dentry___82 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___51 *subsys[11];
	struct cgroupfs_root___51 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___81 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___51 {
	struct super_block___82 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___51 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___20 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___82 *, struct file___81 *);
	ssize_t (*read)(struct cgroup___51 *, struct cftype___20 *, struct file___81 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___51 *, struct cftype___20 *);
	s64 (*read_s64)(struct cgroup___51 *, struct cftype___20 *);
	int (*read_map)(struct cgroup___51 *, struct cftype___20 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___51 *, struct cftype___20 *, struct seq_file___59 *);
	ssize_t (*write)(struct cgroup___51 *, struct cftype___20 *, struct file___81 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___51 *, struct cftype___20 *, u64);
	int (*write_s64)(struct cgroup___51 *, struct cftype___20 *, s64);
	int (*write_string)(struct cgroup___51 *, struct cftype___20 *, const char *);
	int (*trigger)(struct cgroup___51 *, unsigned int);
	int (*release)(struct inode___82 *, struct file___81 *);
	int (*register_event)(struct cgroup___51 *, struct cftype___20 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___51 *, struct cftype___20 *, struct eventfd_ctx *);
};

struct perf_cpu_context___38;

struct pmu___38 {
	struct list_head entry;
	struct device___63 *dev;
	const struct attribute_group___56 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___38 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___38 *);
	void (*pmu_disable)(struct pmu___38 *);
	int (*event_init)(struct perf_event___38 *);
	int (*add)(struct perf_event___38 *, int);
	void (*del)(struct perf_event___38 *, int);
	void (*start)(struct perf_event___38 *, int);
	void (*stop)(struct perf_event___38 *, int);
	void (*read)(struct perf_event___38 *);
	void (*start_txn)(struct pmu___38 *);
	int (*commit_txn)(struct pmu___38 *);
	void (*cancel_txn)(struct pmu___38 *);
	int (*event_idx)(struct perf_event___38 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___38 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___38 *);
};

struct perf_cpu_context___38 {
	struct perf_event_context___38 ctx;
	struct perf_event_context___38 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___38 *unique_pmu;
	struct perf_cgroup___38 *cgrp;
};

struct trace_event_functions___29;

struct trace_event___29 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___29 *funcs;
};

struct ftrace_event_class___29;

struct ftrace_event_call___29 {
	struct list_head list;
	struct ftrace_event_class___29 *class;
	char *name;
	struct trace_event___29 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___38 {
	struct cgroup_subsys_state___51 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___29 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___81 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___29)(struct trace_iterator___29 *, int, struct trace_event___29 *);

struct trace_event_functions___29 {
	trace_print_func___29 trace;
	trace_print_func___29 raw;
	trace_print_func___29 hex;
	trace_print_func___29 binary;
};

struct ftrace_event_class___29 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___29 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___29 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___29 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___29 *);
};

struct syscall_metadata___12 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___29 *enter_event;
	struct ftrace_event_call___29 *exit_event;
};

struct tlb_state___25 {
	struct mm_struct___85 *active_mm;
	int state;
};

struct hstate___5 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___20 cgroup_files[5];
	char name[32];
};

struct futex_q {
	struct plist_node list;
	struct task_struct___80 *task;
	spinlock_t *lock_ptr;
	union futex_key key;
	struct futex_pi_state *pi_state;
	struct rt_mutex_waiter *rt_waiter;
	union futex_key *requeue_pi_key;
	u32 bitset;
};

struct futex_hash_bucket {
	atomic_t waiters;
	spinlock_t lock;
	struct plist_head chain;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct task_struct___81;

struct pv_cpu_ops___81 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___81 *);
	void (*end_context_switch)(struct task_struct___81 *);
};

struct mutex___82 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___81 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___86;

struct signal_struct___81;

struct rt_mutex_waiter___2;

struct task_struct___81 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___81 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___86 *mm;
	struct mm_struct___86 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___81 *real_parent;
	struct task_struct___81 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___81 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___41 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___81 = 0,
		VTIME_USER___81 = 1,
		VTIME_SYS___81 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___81 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter___2 *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___82 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___77 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___86 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___86 *, struct mm_struct___86 *);
	void (*dup_mmap)(struct mm_struct___86 *, struct mm_struct___86 *);
	void (*exit_mmap)(struct mm_struct___86 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___86 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___86 *);
	void (*pgd_free)(struct mm_struct___86 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___86 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___86 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___86 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___86 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___86 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___86 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___86 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___86 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___86 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___86 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___86 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___82 lock;
	void *vdso;
} mm_context_t___82;

struct vm_area_struct___86;

struct core_state___81;

struct mm_struct___86 {
	struct vm_area_struct___86 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___86 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___86 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___82 context;
	long unsigned int flags;
	struct core_state___81 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___81 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___81 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___40 {
	struct task_struct___81 *task;
	struct exec_domain___20 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct vm_area_struct___86 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___86 *vm_next;
	struct vm_area_struct___86 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___86 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___81 {
	struct task_struct___81 *task;
	struct core_thread___81 *next;
};

struct core_state___81 {
	atomic_t nr_threads;
	struct core_thread___81 dumper;
	struct completion startup;
};

struct smp_ops___81 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___81 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___81;

struct lruvec___81 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___81 *zone;
};

struct pglist_data___81;

struct zone___81 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___81 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___81 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___81 {
	struct zone___81 *zone;
	int zone_idx;
};

struct zonelist___81 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___81 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___81 {
	struct zone___81 node_zones[4];
	struct zonelist___81 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___81 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rt_mutex___2 {
	raw_spinlock_t wait_lock;
	struct plist_head wait_list;
	struct task_struct___81 *owner;
};

struct hrtimer_sleeper___3 {
	struct hrtimer timer;
	struct task_struct___81 *task;
};

struct signal_struct___81 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___81 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___81 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___41 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___82 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_mutex_waiter___2 {
	struct plist_node list_entry;
	struct plist_node pi_list_entry;
	struct task_struct___81 *task;
	struct rt_mutex___2 *lock;
};

struct dma_chan {
	int lock;
	const char *device_id;
};

struct call_single_data___3 {
	union {
		struct llist_node llist;
		struct {
			struct list_head list;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
	smp_call_func_t func;
	void *info;
	u16 flags;
};

enum {
	CSD_FLAG_LOCK = 1,
	CSD_FLAG_WAIT = 2,
};

struct call_function_data {
	struct call_single_data___3 *csd;
	cpumask_var_t cpumask;
};

struct key_construction;

typedef int (*request_key_actor_t)(struct key_construction *, const char *, void *);

struct key_preparsed_payload;

struct key_type {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key *, struct key_preparsed_payload *);
	int (*update)(struct key *, struct key_preparsed_payload *);
	int (*match)(const struct key *, const void *);
	void (*revoke)(struct key *);
	void (*destroy)(struct key *);
	void (*describe)(const struct key *, struct seq_file___5 *);
	long int (*read)(const struct key *, char *, size_t);
	request_key_actor_t request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct __key_reference_with_attributes;

typedef struct __key_reference_with_attributes *key_ref_t;

struct key_construction {
	struct key *key;
	struct key *authkey;
};

struct key_preparsed_payload {
	char *description;
	void *type_data[2];
	void *payload;
	const void *data;
	size_t datalen;
	size_t quotalen;
	bool trusted;
};

struct modversion_info {
	long unsigned int crc;
	char name[56];
};

struct module_use {
	struct list_head source_list;
	struct list_head target_list;
	struct module___33 *source;
	struct module___33 *target;
};

struct module_sect_attr {
	struct module_attribute___32 mattr;
	char *name;
	long unsigned int address;
};

struct module_sect_attrs {
	struct attribute_group___34 grp;
	unsigned int nsections;
	struct module_sect_attr attrs[0];
};

struct module_notes_attrs {
	struct kobject *dir;
	unsigned int notes;
	struct bin_attribute___34 attrs[0];
};

struct symsearch {
	const struct kernel_symbol *start;
	const struct kernel_symbol *stop;
	const long unsigned int *crcs;
	enum {
		NOT_GPL_ONLY = 0,
		GPL_ONLY = 1,
		WILL_BE_GPL_ONLY = 2,
	} licence;
	bool unused;
};

struct ftrace_raw_module_load {
	struct trace_entry ent;
	unsigned int taints;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_module_free {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_module_refcnt {
	struct trace_entry ent;
	long unsigned int ip;
	int refcnt;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_module_request {
	struct trace_entry ent;
	long unsigned int ip;
	bool wait;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_data_offsets_module_load {
	u32 name;
};

struct ftrace_data_offsets_module_free {
	u32 name;
};

struct ftrace_data_offsets_module_refcnt {
	u32 name;
};

struct ftrace_data_offsets_module_request {
	u32 name;
};

struct module_ext {
	struct list_head next;
	struct module___33 *module;
	char *rhelversion;
};

struct load_info {
	Elf64_Ehdr *hdr;
	long unsigned int len;
	Elf64_Shdr *sechdrs;
	char *secstrings;
	char *strtab;
	long unsigned int symoffs;
	long unsigned int stroffs;
	struct _ddebug *debug;
	unsigned int num_debug;
	bool sig_ok;
	struct {
		unsigned int sym;
		unsigned int str;
		unsigned int mod;
		unsigned int vers;
		unsigned int info;
		unsigned int pcpu;
	} index;
};

struct find_symbol_arg {
	const char *name;
	bool gplok;
	bool warn;
	struct module___33 *owner;
	const long unsigned int *crc;
	const struct kernel_symbol *sym;
};

struct stopref {
	struct module___33 *mod;
	int flags;
	int *forced;
};

typedef long unsigned int mpi_limb_t;

struct gcry_mpi {
	int alloced;
	int nlimbs;
	int nbits;
	int sign;
	unsigned int flags;
	mpi_limb_t *d;
};

typedef struct gcry_mpi *MPI;

enum hash_algo {
	HASH_ALGO_MD4 = 0,
	HASH_ALGO_MD5 = 1,
	HASH_ALGO_SHA1 = 2,
	HASH_ALGO_RIPE_MD_160 = 3,
	HASH_ALGO_SHA256 = 4,
	HASH_ALGO_SHA384 = 5,
	HASH_ALGO_SHA512 = 6,
	HASH_ALGO_SHA224 = 7,
	HASH_ALGO_RIPE_MD_128 = 8,
	HASH_ALGO_RIPE_MD_256 = 9,
	HASH_ALGO_RIPE_MD_320 = 10,
	HASH_ALGO_WP_256 = 11,
	HASH_ALGO_WP_384 = 12,
	HASH_ALGO_WP_512 = 13,
	HASH_ALGO_TGR_128 = 14,
	HASH_ALGO_TGR_160 = 15,
	HASH_ALGO_TGR_192 = 16,
	HASH_ALGO__LAST = 17,
};

enum pkey_algo {
	PKEY_ALGO_DSA = 0,
	PKEY_ALGO_RSA = 1,
	PKEY_ALGO__LAST = 2,
};

enum pkey_id_type {
	PKEY_ID_PGP = 0,
	PKEY_ID_X509 = 1,
	PKEY_ID_TYPE__LAST = 2,
};

struct public_key_signature {
	u8 *digest;
	u8 digest_size;
	u8 nr_mpi;
	enum pkey_algo pkey_algo: 8;
	enum hash_algo pkey_hash_algo: 8;
	union {
		MPI mpi[2];
		struct {
			MPI s;
		} rsa;
		struct {
			MPI r;
			MPI s;
		} dsa;
	};
};

struct crypto_shash;

struct shash_desc {
	struct crypto_shash *tfm;
	u32 flags;
	void *__ctx[0];
};

struct crypto_shash {
	unsigned int descsize;
	struct crypto_tfm base;
};

struct shash_alg {
	int (*init)(struct shash_desc *);
	int (*update)(struct shash_desc *, const u8 *, unsigned int);
	int (*final)(struct shash_desc *, u8 *);
	int (*finup)(struct shash_desc *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc *, void *);
	int (*import)(struct shash_desc *, const void *);
	int (*setkey)(struct crypto_shash *, const u8 *, unsigned int);
	unsigned int descsize;
	int: 32;
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg base;
};

struct module_signature {
	u8 algo;
	u8 hash;
	u8 id_type;
	u8 signer_len;
	u8 key_id_len;
	u8 __pad[3];
	__be32 sig_len;
};

struct page___82;

typedef struct page___82 *pgtable_t___82;

struct address_space___82;

struct kmem_cache___71;

struct page___82 {
	long unsigned int flags;
	struct address_space___82 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___82 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___82 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___71 *slab_cache;
		struct page___82 *first_page;
	};
	long: 64;
};

struct task_struct___82;

struct pv_cpu_ops___82 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___82 *);
	void (*end_context_switch)(struct task_struct___82 *);
};

struct mutex___83 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___82 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___78 {
	struct page___82 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___87;

struct cred___2;

struct signal_struct___82;

struct task_struct___82 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___82 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___87 *mm;
	struct mm_struct___87 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___82 *real_parent;
	struct task_struct___82 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___82 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___41 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___82 = 0,
		VTIME_USER___82 = 1,
		VTIME_SYS___82 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___82 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___83 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___78 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___87 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___87 *, struct mm_struct___87 *);
	void (*dup_mmap)(struct mm_struct___87 *, struct mm_struct___87 *);
	void (*exit_mmap)(struct mm_struct___87 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___87 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___87 *);
	void (*pgd_free)(struct mm_struct___87 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___87 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___87 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___87 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___87 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___87 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___87 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___87 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___87 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___87 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___87 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___87 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___83 lock;
	void *vdso;
} mm_context_t___83;

struct xol_area___82;

struct uprobes_state___82 {
	struct xol_area___82 *xol_area;
};

struct vm_area_struct___87;

struct file___82;

struct core_state___82;

struct mm_struct___87 {
	struct vm_area_struct___87 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___87 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___87 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___83 context;
	long unsigned int flags;
	struct core_state___82 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___82 *owner;
	struct file___82 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___82 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___82 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___82 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___71;

struct memcg_cache_params___71;

struct kmem_cache___71 {
	struct kmem_cache_cpu___71 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___71 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___83;

struct address_space_operations___82;

struct address_space___82 {
	struct inode___83 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___83 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___82 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___83;

struct path___82 {
	struct vfsmount *mnt;
	struct dentry___83 *dentry;
};

struct file_operations___82;

struct file___82 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___82 f_path;
	struct inode___83 *f_inode;
	const struct file_operations___82 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___41 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___82 *f_mapping;
	struct mutex___83 f_pos_lock;
};

struct vm_area_struct___87 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___87 *vm_next;
	struct vm_area_struct___87 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___87 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___82 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___82 {
	struct task_struct___82 *task;
	struct core_thread___82 *next;
};

struct core_state___82 {
	atomic_t nr_threads;
	struct core_thread___82 dumper;
	struct completion startup;
};

struct irq_data___58;

struct x86_io_apic_ops___58 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___58 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___58;

struct irq_data___58 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___58 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___82 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___82 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___2;

struct user_struct___2 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___2 *uid_keyring;
	struct key___2 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct zone___82;

struct lruvec___82 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___82 *zone;
};

struct pglist_data___82;

struct zone___82 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___82 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___82 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___82 {
	struct zone___82 *zone;
	int zone_idx;
};

struct zonelist___82 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___82 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___82 {
	struct zone___82 node_zones[4];
	struct zonelist___82 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___82 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_type___2;

struct keyring_index_key___2 {
	struct key_type___2 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___2;

typedef int (*request_key_actor_t___2)(struct key_construction___2 *, const char *, void *);

struct seq_file___60;

struct key_type___2 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___2 *, struct key_preparsed_payload *);
	int (*update)(struct key___2 *, struct key_preparsed_payload *);
	int (*match)(const struct key___2 *, const void *);
	void (*revoke)(struct key___2 *);
	void (*destroy)(struct key___2 *);
	void (*describe)(const struct key___2 *, struct seq_file___60 *);
	long int (*read)(const struct key___2 *, char *, size_t);
	request_key_actor_t___2 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key___2 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___2 index_key;
		struct {
			struct key_type___2 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct cred___2 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___2 *session_keyring;
	struct key___2 *process_keyring;
	struct key___2 *thread_keyring;
	struct key___2 *request_key_auth;
	void *security;
	struct user_struct___2 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___82 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___82 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___82 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___41 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___83 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___82;

struct super_block___83;

struct dentry___83 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___83 *d_parent;
	struct qstr d_name;
	struct inode___83 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___82 *d_op;
	struct super_block___83 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___82;

struct file_lock___82;

struct dquot___82;

struct block_device___82;

struct cdev___30;

struct inode___83 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___82 *i_op;
	struct super_block___83 *i_sb;
	struct address_space___82 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___83 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___82 *i_fop;
	struct file_lock___82 *i_flock;
	struct address_space___82 i_data;
	struct dquot___82 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___82 *i_bdev;
		struct cdev___30 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___82 {
	int (*d_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_hash)(const struct dentry___83 *, struct qstr *);
	int (*d_compare)(const struct dentry___83 *, const struct dentry___83 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___83 *);
	void (*d_release)(struct dentry___83 *);
	void (*d_prune)(struct dentry___83 *);
	void (*d_iput)(struct dentry___83 *, struct inode___83 *);
	char * (*d_dname)(struct dentry___83 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___82 *);
	int (*d_manage)(struct dentry___83 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___82;

struct mem_dqinfo___82 {
	struct quota_format_type___82 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___82;

struct quota_info___82 {
	unsigned int flags;
	struct mutex___83 dqio_mutex;
	struct mutex___83 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___83 *files[2];
	struct mem_dqinfo___82 info[2];
	const struct quota_format_ops___82 *ops[2];
};

struct file_system_type___82;

struct super_operations___82;

struct dquot_operations___82;

struct quotactl_ops___82;

struct super_block___83 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___82 *s_type;
	const struct super_operations___82 *s_op;
	const struct dquot_operations___82 *dq_op;
	const struct quotactl_ops___82 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___83 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___82 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___82 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___83 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___82 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___82 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___83 *bd_inode;
	struct super_block___83 *bd_super;
	struct mutex___83 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___82 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___83 bd_fsfreeze_mutex;
};

struct iattr___83 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___82 *ia_file;
};

struct dquot___82 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___83 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___83 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___82 {
	int qf_fmt_id;
	const struct quota_format_ops___82 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___82 *qf_next;
};

struct quota_format_ops___82 {
	int (*check_quota_file)(struct super_block___83 *, int);
	int (*read_file_info)(struct super_block___83 *, int);
	int (*write_file_info)(struct super_block___83 *, int);
	int (*free_file_info)(struct super_block___83 *, int);
	int (*read_dqblk)(struct dquot___82 *);
	int (*commit_dqblk)(struct dquot___82 *);
	int (*release_dqblk)(struct dquot___82 *);
};

struct dquot_operations___82 {
	int (*write_dquot)(struct dquot___82 *);
	struct dquot___82 * (*alloc_dquot)(struct super_block___83 *, int);
	void (*destroy_dquot)(struct dquot___82 *);
	int (*acquire_dquot)(struct dquot___82 *);
	int (*release_dquot)(struct dquot___82 *);
	int (*mark_dirty)(struct dquot___82 *);
	int (*write_info)(struct super_block___83 *, int);
	qsize_t * (*get_reserved_space)(struct inode___83 *);
};

struct quotactl_ops___82 {
	int (*quota_on)(struct super_block___83 *, int, int, struct path___82 *);
	int (*quota_on_meta)(struct super_block___83 *, int, int);
	int (*quota_off)(struct super_block___83 *, int);
	int (*quota_sync)(struct super_block___83 *, int);
	int (*get_info)(struct super_block___83 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___83 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___83 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___83 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___83 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___83 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___83 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___83 *, unsigned int);
};

struct address_space_operations___82 {
	int (*writepage)(struct page___82 *, struct writeback_control *);
	int (*readpage)(struct file___82 *, struct page___82 *);
	int (*writepages)(struct address_space___82 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___82 *);
	int (*readpages)(struct file___82 *, struct address_space___82 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___82 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___82 **, void **);
	int (*write_end)(struct file___82 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___82 *, void *);
	sector_t (*bmap)(struct address_space___82 *, sector_t);
	void (*invalidatepage)(struct page___82 *, long unsigned int);
	int (*releasepage)(struct page___82 *, gfp_t);
	void (*freepage)(struct page___82 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___82 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___82 *, struct page___82 *, struct page___82 *, enum migrate_mode);
	int (*launder_page)(struct page___82 *);
	int (*is_partially_uptodate)(struct page___82 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___82 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___82 *, struct page___82 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___82 *, sector_t *);
	void (*swap_deactivate)(struct file___82 *);
	void (*invalidatepage_range)(struct page___82 *, unsigned int, unsigned int);
};

struct cdev___30 {
	struct kobject___3 kobj;
	struct module *owner;
	const struct file_operations___82 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___82 {
	struct dentry___83 * (*lookup)(struct inode___83 *, struct dentry___83 *, unsigned int);
	void * (*follow_link)(struct dentry___83 *, struct nameidata *);
	int (*permission)(struct inode___83 *, int);
	struct posix_acl * (*get_acl)(struct inode___83 *, int);
	int (*readlink)(struct dentry___83 *, char *, int);
	void (*put_link)(struct dentry___83 *, struct nameidata *, void *);
	int (*create)(struct inode___83 *, struct dentry___83 *, umode_t, bool);
	int (*link)(struct dentry___83 *, struct inode___83 *, struct dentry___83 *);
	int (*unlink)(struct inode___83 *, struct dentry___83 *);
	int (*symlink)(struct inode___83 *, struct dentry___83 *, const char *);
	int (*mkdir)(struct inode___83 *, struct dentry___83 *, umode_t);
	int (*rmdir)(struct inode___83 *, struct dentry___83 *);
	int (*mknod)(struct inode___83 *, struct dentry___83 *, umode_t, dev_t);
	int (*rename)(struct inode___83 *, struct dentry___83 *, struct inode___83 *, struct dentry___83 *);
	int (*setattr)(struct dentry___83 *, struct iattr___83 *);
	int (*getattr)(struct vfsmount *, struct dentry___83 *, struct kstat *);
	int (*setxattr)(struct dentry___83 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___83 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___83 *, char *, size_t);
	int (*removexattr)(struct dentry___83 *, const char *);
	int (*fiemap)(struct inode___83 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___83 *, struct timespec *, int);
	int (*atomic_open)(struct inode___83 *, struct dentry___83 *, struct file___82 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___50;

struct file_operations___82 {
	struct module *owner;
	loff_t (*llseek)(struct file___82 *, loff_t, int);
	ssize_t (*read)(struct file___82 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___82 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___82 *, void *, filldir_t);
	unsigned int (*poll)(struct file___82 *, struct poll_table_struct___50 *);
	long int (*unlocked_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___82 *, struct vm_area_struct___87 *);
	int (*open)(struct inode___83 *, struct file___82 *);
	int (*flush)(struct file___82 *, fl_owner_t);
	int (*release)(struct inode___83 *, struct file___82 *);
	int (*fsync)(struct file___82 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___82 *, int);
	int (*lock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*sendpage)(struct file___82 *, struct page___82 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___82 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___82 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___82 *, long int, struct file_lock___82 **, void **);
		struct {
			int (*setlease)(struct file___82 *, long int, struct file_lock___82 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___82 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___60 *, struct file___82 *);
};

struct fasync_struct___82;

struct file_lock_operations___82;

struct lock_manager_operations___82;

struct file_lock___82 {
	struct file_lock___82 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___41 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___82 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___82 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___82 *fl_ops;
	const struct lock_manager_operations___82 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___82 {
	void (*fl_copy_lock)(struct file_lock___82 *, struct file_lock___82 *);
	void (*fl_release_private)(struct file_lock___82 *);
};

struct lock_manager_operations___82 {
	int (*lm_compare_owner)(struct file_lock___82 *, struct file_lock___82 *);
	long unsigned int (*lm_owner_key)(struct file_lock___82 *);
	void (*lm_notify)(struct file_lock___82 *);
	int (*lm_grant)(struct file_lock___82 *, struct file_lock___82 *, int);
	void (*lm_break)(struct file_lock___82 *);
	int (*lm_change)(struct file_lock___82 **, int);
};

struct fasync_struct___82 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___82 *fa_next;
	struct file___82 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___82 {
	const char *name;
	int fs_flags;
	struct dentry___83 * (*mount)(struct file_system_type___82 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___83 *);
	struct module *owner;
	struct file_system_type___82 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___82 {
	struct inode___83 * (*alloc_inode)(struct super_block___83 *);
	void (*destroy_inode)(struct inode___83 *);
	void (*dirty_inode)(struct inode___83 *, int);
	int (*write_inode)(struct inode___83 *, struct writeback_control *);
	int (*drop_inode)(struct inode___83 *);
	void (*evict_inode)(struct inode___83 *);
	void (*put_super)(struct super_block___83 *);
	int (*sync_fs)(struct super_block___83 *, int);
	int (*freeze_fs)(struct super_block___83 *);
	int (*unfreeze_fs)(struct super_block___83 *);
	int (*statfs)(struct dentry___83 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___83 *, int *, char *);
	void (*umount_begin)(struct super_block___83 *);
	int (*show_options)(struct seq_file___60 *, struct dentry___83 *);
	int (*show_devname)(struct seq_file___60 *, struct dentry___83 *);
	int (*show_path)(struct seq_file___60 *, struct dentry___83 *);
	int (*show_stats)(struct seq_file___60 *, struct dentry___83 *);
	ssize_t (*quota_read)(struct super_block___83 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___83 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___83 *);
	int (*bdev_try_to_free_page)(struct super_block___83 *, struct page___82 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___83 *);
	void (*free_cached_objects)(struct super_block___83 *, int);
};

typedef void (*poll_queue_proc___50)(struct file___82 *, wait_queue_head_t *, struct poll_table_struct___50 *);

struct poll_table_struct___50 {
	poll_queue_proc___50 _qproc;
	long unsigned int _key;
};

struct seq_operations___59;

struct seq_file___60 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___83 lock;
	const struct seq_operations___59 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___58 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___58 *);
	void (*irq_shutdown)(struct irq_data___58 *);
	void (*irq_enable)(struct irq_data___58 *);
	void (*irq_disable)(struct irq_data___58 *);
	void (*irq_ack)(struct irq_data___58 *);
	void (*irq_mask)(struct irq_data___58 *);
	void (*irq_mask_ack)(struct irq_data___58 *);
	void (*irq_unmask)(struct irq_data___58 *);
	void (*irq_eoi)(struct irq_data___58 *);
	int (*irq_set_affinity)(struct irq_data___58 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___58 *);
	int (*irq_set_type)(struct irq_data___58 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___58 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___58 *);
	void (*irq_bus_sync_unlock)(struct irq_data___58 *);
	void (*irq_cpu_online)(struct irq_data___58 *);
	void (*irq_cpu_offline)(struct irq_data___58 *);
	void (*irq_suspend)(struct irq_data___58 *);
	void (*irq_resume)(struct irq_data___58 *);
	void (*irq_pm_shutdown)(struct irq_data___58 *);
	void (*irq_print_chip)(struct irq_data___58 *, struct seq_file___60 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___58 *, void *);
	long unsigned int flags;
};

struct seq_operations___59 {
	void * (*start)(struct seq_file___60 *, loff_t *);
	void (*stop)(struct seq_file___60 *, void *);
	void * (*next)(struct seq_file___60 *, void *, loff_t *);
	int (*show)(struct seq_file___60 *, void *);
};

struct kmem_cache_cpu___71 {
	void **freelist;
	long unsigned int tid;
	struct page___82 *page;
	struct page___82 *partial;
};

struct memcg_cache_params___71 {
	bool is_root_cache;
	union {
		struct kmem_cache___71 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___71 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct key_construction___2 {
	struct key___2 *key;
	struct key___2 *authkey;
};

struct kallsym_iter {
	loff_t pos;
	long unsigned int value;
	unsigned int nameoff;
	char type;
	char name[128];
	char module_name[56];
	int exported;
};

typedef __u16 comp_t;

struct acct_v3 {
	char ac_flag;
	char ac_version;
	__u16 ac_tty;
	__u32 ac_exitcode;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u32 ac_etime;
	comp_t ac_utime;
	comp_t ac_stime;
	comp_t ac_mem;
	comp_t ac_io;
	comp_t ac_rw;
	comp_t ac_minflt;
	comp_t ac_majflt;
	comp_t ac_swaps;
	char ac_comm[16];
};

typedef struct acct_v3 acct_t;

struct bsd_acct_struct {
	int active;
	long unsigned int needcheck;
	struct file___50 *file;
	struct pid_namespace___20 *ns;
	struct list_head list;
};

struct fd___2 {
	struct file___50 *file;
	unsigned int flags;
};

typedef long unsigned int elf_greg_t;

typedef elf_greg_t elf_gregset_t[27];

struct elf64_note {
	Elf64_Word n_namesz;
	Elf64_Word n_descsz;
	Elf64_Word n_type;
};

struct elf_siginfo {
	int si_signo;
	int si_code;
	int si_errno;
};

struct elf_prstatus {
	struct elf_siginfo pr_info;
	short int pr_cursig;
	long unsigned int pr_sigpend;
	long unsigned int pr_sighold;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	struct timeval pr_utime;
	struct timeval pr_stime;
	struct timeval pr_cutime;
	struct timeval pr_cstime;
	elf_gregset_t pr_reg;
	int pr_fpvalid;
};

struct compat_kexec_segment {
	compat_uptr_t buf;
	compat_size_t bufsz;
	compat_ulong_t mem;
	compat_size_t memsz;
};

struct kexec_sha_region {
	long unsigned int start;
	long unsigned int len;
};

struct kexec_file_ops___5;

struct kimage___5 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int destination;
	long unsigned int start;
	struct page___50 *control_code_page;
	struct page___50 *swap_page;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	struct kexec_file_ops___5 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef void *kexec_load_t___5(struct kimage___5 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___5 {
	kexec_probe_t *probe;
	kexec_load_t___5 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kexec_buf {
	struct kimage___5 *image;
	char *buffer;
	long unsigned int bufsz;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

struct crypto_async_request___2;

typedef void (*crypto_completion_t___2)(struct crypto_async_request___2 *, int);

struct crypto_tfm___3;

struct crypto_async_request___2 {
	struct list_head list;
	crypto_completion_t___2 complete;
	void *data;
	struct crypto_tfm___3 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___2;

struct ablkcipher_request___2;

struct ablkcipher_tfm___2 {
	int (*setkey)(struct crypto_ablkcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___2 *);
	int (*decrypt)(struct ablkcipher_request___2 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___2 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___2;

struct aead_request___2;

struct aead_tfm___2 {
	int (*setkey)(struct crypto_aead___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___2 *);
	int (*decrypt)(struct aead_request___2 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___2 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___2;

struct blkcipher_tfm___2 {
	void *iv;
	int (*setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___2 {
	int (*cit_setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___3 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___3 *, u8 *, const u8 *);
};

struct hash_desc___2;

struct crypto_hash___2;

struct hash_tfm___2 {
	int (*init)(struct hash_desc___2 *);
	int (*update)(struct hash_desc___2 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___2 *, u8 *);
	int (*digest)(struct hash_desc___2 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___2 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___2 {
	int (*cot_compress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___2;

struct rng_tfm___2 {
	int (*rng_gen_random)(struct crypto_rng___2 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___2 *, u8 *, unsigned int);
};

struct crypto_alg___3;

struct crypto_tfm___3 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___2 ablkcipher;
		struct aead_tfm___2 aead;
		struct blkcipher_tfm___2 blkcipher;
		struct cipher_tfm___2 cipher;
		struct hash_tfm___2 hash;
		struct compress_tfm___2 compress;
		struct rng_tfm___2 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___3 *);
	struct crypto_alg___3 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___2 {
	struct crypto_async_request___2 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___2 {
	struct crypto_async_request___2 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___2;

struct blkcipher_desc___2 {
	struct crypto_blkcipher___2 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___2 {
	struct crypto_tfm___3 base;
};

struct hash_desc___2 {
	struct crypto_hash___2 *tfm;
	u32 flags;
};

struct crypto_hash___2 {
	struct crypto_tfm___3 base;
};

struct ablkcipher_alg___2 {
	int (*setkey)(struct crypto_ablkcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___2 *);
	int (*decrypt)(struct ablkcipher_request___2 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___2 {
	struct crypto_tfm___3 base;
};

struct aead_alg___2 {
	int (*setkey)(struct crypto_aead___2 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___2 *, unsigned int);
	int (*encrypt)(struct aead_request___2 *);
	int (*decrypt)(struct aead_request___2 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___2 {
	struct crypto_tfm___3 base;
};

struct blkcipher_alg___2 {
	int (*setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___2 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
};

struct compress_alg___2 {
	int (*coa_compress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___2 {
	int (*rng_make_random)(struct crypto_rng___2 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___2 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___2 {
	struct crypto_tfm___3 base;
};

struct crypto_alg___3 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___2 ablkcipher;
		struct aead_alg___2 aead;
		struct blkcipher_alg___2 blkcipher;
		struct cipher_alg___2 cipher;
		struct compress_alg___2 compress;
		struct rng_alg___2 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___3 *);
	void (*cra_exit)(struct crypto_tfm___3 *);
	void (*cra_destroy)(struct crypto_alg___3 *);
	struct module___33 *cra_module;
};

struct crypto_shash___2;

struct shash_desc___2 {
	struct crypto_shash___2 *tfm;
	u32 flags;
	void *__ctx[0];
};

struct crypto_shash___2 {
	unsigned int descsize;
	struct crypto_tfm___3 base;
};

struct shash_alg___2 {
	int (*init)(struct shash_desc___2 *);
	int (*update)(struct shash_desc___2 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___2 *, u8 *);
	int (*finup)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___2 *, void *);
	int (*import)(struct shash_desc___2 *, const void *);
	int (*setkey)(struct crypto_shash___2 *, const u8 *, unsigned int);
	unsigned int descsize;
	int: 32;
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg___3 base;
};

struct compat_itimerspec {
	struct compat_timespec it_interval;
	struct compat_timespec it_value;
};

struct compat_itimerval {
	struct compat_timeval it_interval;
	struct compat_timeval it_value;
};

struct compat_tms {
	compat_clock_t tms_utime;
	compat_clock_t tms_stime;
	compat_clock_t tms_cutime;
	compat_clock_t tms_cstime;
};

struct compat_timex {
	compat_uint_t modes;
	compat_long_t offset;
	compat_long_t freq;
	compat_long_t maxerror;
	compat_long_t esterror;
	compat_int_t status;
	compat_long_t constant;
	compat_long_t precision;
	compat_long_t tolerance;
	struct compat_timeval time;
	compat_long_t tick;
	compat_long_t ppsfreq;
	compat_long_t jitter;
	compat_int_t shift;
	compat_long_t stabil;
	compat_long_t jitcnt;
	compat_long_t calcnt;
	compat_long_t errcnt;
	compat_long_t stbcnt;
	compat_int_t tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct compat_rlimit {
	compat_ulong_t rlim_cur;
	compat_ulong_t rlim_max;
};

struct compat_sigevent {
	compat_sigval_t sigev_value;
	compat_int_t sigev_signo;
	compat_int_t sigev_notify;
	union {
		compat_int_t _pad[13];
		compat_int_t _tid;
		struct {
			compat_uptr_t _function;
			compat_uptr_t _attribute;
		} _sigev_thread;
	} _sigev_un;
};

struct page___83;

typedef struct page___83 *pgtable_t___83;

struct address_space___83;

struct kmem_cache___72;

struct page___83 {
	long unsigned int flags;
	struct address_space___83 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___83 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___83 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___72 *slab_cache;
		struct page___83 *first_page;
	};
	long: 64;
};

struct task_struct___83;

struct pv_cpu_ops___83 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___83 *);
	void (*end_context_switch)(struct task_struct___83 *);
};

struct pid___42;

struct pid_link___42 {
	struct hlist_node node;
	struct pid___42 *pid;
};

struct mutex___84 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___83 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___79 {
	struct page___83 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___88;

struct nsproxy___43;

struct signal_struct___83;

struct backing_dev_info___10;

struct css_set___52;

struct task_struct___83 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___83 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___88 *mm;
	struct mm_struct___88 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___83 *real_parent;
	struct task_struct___83 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___83 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___42 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___83 = 0,
		VTIME_USER___83 = 1,
		VTIME_SYS___83 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___43 *nsproxy;
	struct signal_struct___83 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___10 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___52 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___84 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___79 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___88 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___88 *, struct mm_struct___88 *);
	void (*dup_mmap)(struct mm_struct___88 *, struct mm_struct___88 *);
	void (*exit_mmap)(struct mm_struct___88 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___88 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___88 *);
	void (*pgd_free)(struct mm_struct___88 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___88 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___88 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___88 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___88 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___88 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___88 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___88 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___88 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___88 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___88 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___88 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___84 lock;
	void *vdso;
} mm_context_t___84;

struct xol_area___83;

struct uprobes_state___83 {
	struct xol_area___83 *xol_area;
};

struct vm_area_struct___88;

struct file___83;

struct core_state___83;

struct mm_struct___88 {
	struct vm_area_struct___88 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___88 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___88 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___84 context;
	long unsigned int flags;
	struct core_state___83 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___83 *owner;
	struct file___83 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___83 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___44;

struct module_kobject___43 {
	struct kobject___3 kobj;
	struct module___44 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___43;

struct module___44 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___43 mkobj;
	struct module_attribute___43 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___83 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___83 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___83 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___72;

struct memcg_cache_params___72;

struct kmem_cache___72 {
	struct kmem_cache_cpu___72 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___72 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___84;

struct address_space_operations___83;

struct address_space___83 {
	struct inode___84 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___84 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___83 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___10 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___11;

struct dentry___84;

struct path___83 {
	struct vfsmount___11 *mnt;
	struct dentry___84 *dentry;
};

struct fown_struct___42 {
	rwlock_t lock;
	struct pid___42 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___83;

struct file___83 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___83 f_path;
	struct inode___84 *f_inode;
	const struct file_operations___83 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___42 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___83 *f_mapping;
	struct mutex___84 f_pos_lock;
};

struct vm_operations_struct___72;

struct vm_area_struct___88 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___88 *vm_next;
	struct vm_area_struct___88 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___88 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___72 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___83 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___69;

struct vm_operations_struct___72 {
	void (*open)(struct vm_area_struct___88 *);
	void (*close)(struct vm_area_struct___88 *);
	int (*fault)(struct vm_area_struct___88 *, struct vm_fault___69 *);
	int (*page_mkwrite)(struct vm_area_struct___88 *, struct vm_fault___69 *);
	int (*access)(struct vm_area_struct___88 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___88 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___88 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___88 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___88 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___83 {
	struct task_struct___83 *task;
	struct core_thread___83 *next;
};

struct core_state___83 {
	atomic_t nr_threads;
	struct core_thread___83 dumper;
	struct completion startup;
};

struct irq_data___59;

struct x86_io_apic_ops___59 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___59 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___59;

struct irq_data___59 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___59 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___64;

struct dev_pm_ops___64 {
	int (*prepare)(struct device___64 *);
	void (*complete)(struct device___64 *);
	int (*suspend)(struct device___64 *);
	int (*resume)(struct device___64 *);
	int (*freeze)(struct device___64 *);
	int (*thaw)(struct device___64 *);
	int (*poweroff)(struct device___64 *);
	int (*restore)(struct device___64 *);
	int (*suspend_late)(struct device___64 *);
	int (*resume_early)(struct device___64 *);
	int (*freeze_late)(struct device___64 *);
	int (*thaw_early)(struct device___64 *);
	int (*poweroff_late)(struct device___64 *);
	int (*restore_early)(struct device___64 *);
	int (*suspend_noirq)(struct device___64 *);
	int (*resume_noirq)(struct device___64 *);
	int (*freeze_noirq)(struct device___64 *);
	int (*thaw_noirq)(struct device___64 *);
	int (*poweroff_noirq)(struct device___64 *);
	int (*restore_noirq)(struct device___64 *);
	int (*runtime_suspend)(struct device___64 *);
	int (*runtime_resume)(struct device___64 *);
	int (*runtime_idle)(struct device___64 *);
};

struct dma_map_ops___29;

struct dev_archdata___29 {
	struct dma_map_ops___29 *dma_ops;
	void *iommu;
};

struct device_type___64;

struct bus_type___64;

struct device_driver___64;

struct dev_pm_domain___64;

struct class___64;

struct attribute_group___57;

struct device_rh___64;

struct device___64 {
	struct device___64 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___64 *type;
	struct mutex___84 mutex;
	struct bus_type___64 *bus;
	struct device_driver___64 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___64 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___29 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___64 *class;
	const struct attribute_group___57 **groups;
	void (*release)(struct device___64 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___64 *device_rh;
};

struct dev_pm_info_rh___64 {
	void (*set_latency_tolerance)(struct device___64 *, s32);
};

struct dev_pm_domain___64 {
	struct dev_pm_ops___64 ops;
};

struct smp_ops___83 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___83 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___42;

struct upid___42 {
	int nr;
	struct pid_namespace___42 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___42 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___83 *child_reaper;
	struct kmem_cache___72 *pid_cachep;
	unsigned int level;
	struct pid_namespace___42 *parent;
	struct vfsmount___11 *proc_mnt;
	struct dentry___84 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___42 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___42 numbers[1];
};

struct zone___83;

struct lruvec___83 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___83 *zone;
};

struct pglist_data___83;

struct zone___83 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___83 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___83 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___83 {
	struct zone___83 *zone;
	int zone_idx;
};

struct zonelist___83 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___83 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___83 {
	struct zone___83 node_zones[4];
	struct zonelist___83 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___83 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___11;

struct ctl_node___11 {
	struct rb_node node;
	struct ctl_table_header___11 *header;
};

struct ctl_table_root___11;

struct ctl_table_set___11;

struct ctl_dir___11;

struct ctl_table_header___11 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___11 *root;
	struct ctl_table_set___11 *set;
	struct ctl_dir___11 *parent;
	struct ctl_node___11 *node;
};

struct ctl_dir___11 {
	struct ctl_table_header___11 header;
	struct rb_root root;
};

struct ctl_table_set___11 {
	int (*is_seen)(struct ctl_table_set___11 *);
	struct ctl_dir___11 dir;
};

struct ctl_table_root___11 {
	struct ctl_table_set___11 default_set;
	struct ctl_table_set___11 * (*lookup)(struct ctl_table_root___11 *, struct nsproxy___43 *);
	int (*permissions)(struct ctl_table_header___11 *, struct ctl_table *);
};

struct net___12;

struct nsproxy___43 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___42 *pid_ns;
	struct net___12 *net_ns;
};

struct signal_struct___83 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___83 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___83 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___42 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___42 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___84 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback___10 {
	struct backing_dev_info___10 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___10 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___10 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___64 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___84 *debug_dir;
	struct dentry___84 *debug_stats;
};

struct cgroup_subsys_state___52;

struct css_set___52 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___52 *subsys[11];
	struct callback_head callback_head;
};

struct cgroupstats {
	__u64 nr_sleeping;
	__u64 nr_running;
	__u64 nr_stopped;
	__u64 nr_uninterruptible;
	__u64 nr_io_wait;
};

struct ptr_heap {
	void **ptrs;
	int max;
	int size;
	int (*gt)(void *, void *);
};

struct bin_attribute___57;

struct attribute_group___57 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___57 **bin_attrs;
};

struct bin_attribute___57 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___83 *, struct kobject___3 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___83 *, struct kobject___3 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	int (*mmap)(struct file___83 *, struct kobject___3 *, struct bin_attribute___57 *, struct vm_area_struct___88 *);
};

struct kmem_cache_cpu___72 {
	void **freelist;
	long unsigned int tid;
	struct page___83 *page;
	struct page___83 *partial;
};

struct memcg_cache_params___72 {
	bool is_root_cache;
	union {
		struct kmem_cache___72 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___72 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___52 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___84 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___84 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___84 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___83;

struct super_block___84;

struct dentry___84 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___84 *d_parent;
	struct qstr d_name;
	struct inode___84 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___83 *d_op;
	struct super_block___84 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct simple_xattr {
	struct list_head list;
	char *name;
	size_t size;
	char value[0];
};

struct inode_operations___83;

struct file_lock___83;

struct dquot___83;

struct block_device___83;

struct inode___84 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___83 *i_op;
	struct super_block___84 *i_sb;
	struct address_space___83 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___84 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___83 *i_fop;
	struct file_lock___83 *i_flock;
	struct address_space___83 i_data;
	struct dquot___83 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___83 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___83 {
	int (*d_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_hash)(const struct dentry___84 *, struct qstr *);
	int (*d_compare)(const struct dentry___84 *, const struct dentry___84 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___84 *);
	void (*d_release)(struct dentry___84 *);
	void (*d_prune)(struct dentry___84 *);
	void (*d_iput)(struct dentry___84 *, struct inode___84 *);
	char * (*d_dname)(struct dentry___84 *, char *, int);
	struct vfsmount___11 * (*d_automount)(struct path___83 *);
	int (*d_manage)(struct dentry___84 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___83;

struct mem_dqinfo___83 {
	struct quota_format_type___83 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___83;

struct quota_info___83 {
	unsigned int flags;
	struct mutex___84 dqio_mutex;
	struct mutex___84 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___84 *files[2];
	struct mem_dqinfo___83 info[2];
	const struct quota_format_ops___83 *ops[2];
};

struct file_system_type___83;

struct super_operations___83;

struct dquot_operations___83;

struct quotactl_ops___83;

struct super_block___84 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___83 *s_type;
	const struct super_operations___83 *s_op;
	const struct dquot_operations___83 *dq_op;
	const struct quotactl_ops___83 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___84 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___52 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___83 *s_bdev;
	struct backing_dev_info___10 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___83 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___84 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___83 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___11 {
	struct dentry___84 *mnt_root;
	struct super_block___84 *mnt_sb;
	int mnt_flags;
};

struct block_device___83 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___84 *bd_inode;
	struct super_block___84 *bd_super;
	struct mutex___84 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___83 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___84 bd_fsfreeze_mutex;
};

struct cgroup___52;

struct cgroup_subsys_state___52 {
	struct cgroup___52 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___84 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___83 *ia_file;
};

struct dquot___83 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___84 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___84 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___83 {
	int qf_fmt_id;
	const struct quota_format_ops___83 *qf_ops;
	struct module___44 *qf_owner;
	struct quota_format_type___83 *qf_next;
};

struct quota_format_ops___83 {
	int (*check_quota_file)(struct super_block___84 *, int);
	int (*read_file_info)(struct super_block___84 *, int);
	int (*write_file_info)(struct super_block___84 *, int);
	int (*free_file_info)(struct super_block___84 *, int);
	int (*read_dqblk)(struct dquot___83 *);
	int (*commit_dqblk)(struct dquot___83 *);
	int (*release_dqblk)(struct dquot___83 *);
};

struct dquot_operations___83 {
	int (*write_dquot)(struct dquot___83 *);
	struct dquot___83 * (*alloc_dquot)(struct super_block___84 *, int);
	void (*destroy_dquot)(struct dquot___83 *);
	int (*acquire_dquot)(struct dquot___83 *);
	int (*release_dquot)(struct dquot___83 *);
	int (*mark_dirty)(struct dquot___83 *);
	int (*write_info)(struct super_block___84 *, int);
	qsize_t * (*get_reserved_space)(struct inode___84 *);
};

struct quotactl_ops___83 {
	int (*quota_on)(struct super_block___84 *, int, int, struct path___83 *);
	int (*quota_on_meta)(struct super_block___84 *, int, int);
	int (*quota_off)(struct super_block___84 *, int);
	int (*quota_sync)(struct super_block___84 *, int);
	int (*get_info)(struct super_block___84 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___84 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___84 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___84 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___84 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___84 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___84 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___84 *, unsigned int);
};

struct address_space_operations___83 {
	int (*writepage)(struct page___83 *, struct writeback_control *);
	int (*readpage)(struct file___83 *, struct page___83 *);
	int (*writepages)(struct address_space___83 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___83 *);
	int (*readpages)(struct file___83 *, struct address_space___83 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___83 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___83 **, void **);
	int (*write_end)(struct file___83 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___83 *, void *);
	sector_t (*bmap)(struct address_space___83 *, sector_t);
	void (*invalidatepage)(struct page___83 *, long unsigned int);
	int (*releasepage)(struct page___83 *, gfp_t);
	void (*freepage)(struct page___83 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___83 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___83 *, struct page___83 *, struct page___83 *, enum migrate_mode);
	int (*launder_page)(struct page___83 *);
	int (*is_partially_uptodate)(struct page___83 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___83 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___83 *, struct page___83 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___83 *, sector_t *);
	void (*swap_deactivate)(struct file___83 *);
	void (*invalidatepage_range)(struct page___83 *, unsigned int, unsigned int);
};

struct inode_operations___83 {
	struct dentry___84 * (*lookup)(struct inode___84 *, struct dentry___84 *, unsigned int);
	void * (*follow_link)(struct dentry___84 *, struct nameidata *);
	int (*permission)(struct inode___84 *, int);
	struct posix_acl * (*get_acl)(struct inode___84 *, int);
	int (*readlink)(struct dentry___84 *, char *, int);
	void (*put_link)(struct dentry___84 *, struct nameidata *, void *);
	int (*create)(struct inode___84 *, struct dentry___84 *, umode_t, bool);
	int (*link)(struct dentry___84 *, struct inode___84 *, struct dentry___84 *);
	int (*unlink)(struct inode___84 *, struct dentry___84 *);
	int (*symlink)(struct inode___84 *, struct dentry___84 *, const char *);
	int (*mkdir)(struct inode___84 *, struct dentry___84 *, umode_t);
	int (*rmdir)(struct inode___84 *, struct dentry___84 *);
	int (*mknod)(struct inode___84 *, struct dentry___84 *, umode_t, dev_t);
	int (*rename)(struct inode___84 *, struct dentry___84 *, struct inode___84 *, struct dentry___84 *);
	int (*setattr)(struct dentry___84 *, struct iattr___84 *);
	int (*getattr)(struct vfsmount___11 *, struct dentry___84 *, struct kstat *);
	int (*setxattr)(struct dentry___84 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___84 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___84 *, char *, size_t);
	int (*removexattr)(struct dentry___84 *, const char *);
	int (*fiemap)(struct inode___84 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___84 *, struct timespec *, int);
	int (*atomic_open)(struct inode___84 *, struct dentry___84 *, struct file___83 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___51;

struct seq_file___61;

struct file_operations___83 {
	struct module___44 *owner;
	loff_t (*llseek)(struct file___83 *, loff_t, int);
	ssize_t (*read)(struct file___83 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___83 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___83 *, void *, filldir_t);
	unsigned int (*poll)(struct file___83 *, struct poll_table_struct___51 *);
	long int (*unlocked_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___83 *, struct vm_area_struct___88 *);
	int (*open)(struct inode___84 *, struct file___83 *);
	int (*flush)(struct file___83 *, fl_owner_t);
	int (*release)(struct inode___84 *, struct file___83 *);
	int (*fsync)(struct file___83 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___83 *, int);
	int (*lock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*sendpage)(struct file___83 *, struct page___83 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___83 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___83 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___83 *, long int, struct file_lock___83 **, void **);
		struct {
			int (*setlease)(struct file___83 *, long int, struct file_lock___83 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___83 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___61 *, struct file___83 *);
};

struct fasync_struct___83;

struct file_lock_operations___83;

struct lock_manager_operations___83;

struct file_lock___83 {
	struct file_lock___83 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___42 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___83 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___83 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___83 *fl_ops;
	const struct lock_manager_operations___83 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___83 {
	void (*fl_copy_lock)(struct file_lock___83 *, struct file_lock___83 *);
	void (*fl_release_private)(struct file_lock___83 *);
};

struct lock_manager_operations___83 {
	int (*lm_compare_owner)(struct file_lock___83 *, struct file_lock___83 *);
	long unsigned int (*lm_owner_key)(struct file_lock___83 *);
	void (*lm_notify)(struct file_lock___83 *);
	int (*lm_grant)(struct file_lock___83 *, struct file_lock___83 *, int);
	void (*lm_break)(struct file_lock___83 *);
	int (*lm_change)(struct file_lock___83 **, int);
};

struct fasync_struct___83 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___83 *fa_next;
	struct file___83 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___83 {
	const char *name;
	int fs_flags;
	struct dentry___84 * (*mount)(struct file_system_type___83 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___84 *);
	struct module___44 *owner;
	struct file_system_type___83 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___83 {
	struct inode___84 * (*alloc_inode)(struct super_block___84 *);
	void (*destroy_inode)(struct inode___84 *);
	void (*dirty_inode)(struct inode___84 *, int);
	int (*write_inode)(struct inode___84 *, struct writeback_control *);
	int (*drop_inode)(struct inode___84 *);
	void (*evict_inode)(struct inode___84 *);
	void (*put_super)(struct super_block___84 *);
	int (*sync_fs)(struct super_block___84 *, int);
	int (*freeze_fs)(struct super_block___84 *);
	int (*unfreeze_fs)(struct super_block___84 *);
	int (*statfs)(struct dentry___84 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___84 *, int *, char *);
	void (*umount_begin)(struct super_block___84 *);
	int (*show_options)(struct seq_file___61 *, struct dentry___84 *);
	int (*show_devname)(struct seq_file___61 *, struct dentry___84 *);
	int (*show_path)(struct seq_file___61 *, struct dentry___84 *);
	int (*show_stats)(struct seq_file___61 *, struct dentry___84 *);
	ssize_t (*quota_read)(struct super_block___84 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___84 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___84 *);
	int (*bdev_try_to_free_page)(struct super_block___84 *, struct page___83 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___84 *);
	void (*free_cached_objects)(struct super_block___84 *, int);
};

typedef void (*poll_queue_proc___51)(struct file___83 *, wait_queue_head_t *, struct poll_table_struct___51 *);

struct poll_table_struct___51 {
	poll_queue_proc___51 _qproc;
	long unsigned int _key;
};

struct seq_operations___60;

struct seq_file___61 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___84 lock;
	const struct seq_operations___60 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata {
	struct path___83 path;
	struct qstr last;
	struct path___83 root;
	struct inode___84 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct cgroupfs_root___52;

struct cgroup___52 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___52 *parent;
	struct dentry___84 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___52 *subsys[11];
	struct cgroupfs_root___52 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___84 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct css_id {
	struct cgroup_subsys_state___52 *css;
	short unsigned int id;
	short unsigned int depth;
	struct callback_head callback_head;
	short unsigned int stack[0];
};

enum {
	CGRP_REMOVED = 0,
	CGRP_RELEASABLE = 1,
	CGRP_NOTIFY_ON_RELEASE = 2,
	CGRP_CPUSET_CLONE_CHILDREN = 3,
	CGRP_SANE_BEHAVIOR = 4,
};

struct cgroupfs_root___52 {
	struct super_block___84 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___52 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

enum {
	CGRP_ROOT_SANE_BEHAVIOR = 1,
	CGRP_ROOT_NOPREFIX = 2,
	CGRP_ROOT_XATTR = 4,
};

struct cftype___21 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___84 *, struct file___83 *);
	ssize_t (*read)(struct cgroup___52 *, struct cftype___21 *, struct file___83 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___52 *, struct cftype___21 *);
	s64 (*read_s64)(struct cgroup___52 *, struct cftype___21 *);
	int (*read_map)(struct cgroup___52 *, struct cftype___21 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___52 *, struct cftype___21 *, struct seq_file___61 *);
	ssize_t (*write)(struct cgroup___52 *, struct cftype___21 *, struct file___83 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___52 *, struct cftype___21 *, u64);
	int (*write_s64)(struct cgroup___52 *, struct cftype___21 *, s64);
	int (*write_string)(struct cgroup___52 *, struct cftype___21 *, const char *);
	int (*trigger)(struct cgroup___52 *, unsigned int);
	int (*release)(struct inode___84 *, struct file___83 *);
	int (*register_event)(struct cgroup___52 *, struct cftype___21 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___52 *, struct cftype___21 *, struct eventfd_ctx *);
};

struct cftype_set___19 {
	struct list_head node;
	struct cftype___21 *cfts;
};

struct cgroup_scanner {
	struct cgroup___52 *cg;
	int (*test_task)(struct task_struct___83 *, struct cgroup_scanner *);
	void (*process_task)(struct task_struct___83 *, struct cgroup_scanner *);
	struct ptr_heap *heap;
	void *data;
};

struct task_and_cgroup___19 {
	struct task_struct___83 *task;
	struct cgroup___52 *cgrp;
	struct css_set___52 *cg;
};

struct cgroup_taskset___19 {
	struct task_and_cgroup___19 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___52 *cur_cgrp;
};

struct reciprocal_value {
	u32 m;
	u8 sh1;
	u8 sh2;
};

struct flex_array_part;

struct flex_array {
	union {
		struct {
			int element_size;
			int total_nr_elements;
			int elems_per_part;
			struct reciprocal_value reciprocal_elems;
			struct flex_array_part *parts[0];
		};
		char padding[4096];
	};
};

struct cgroup_subsys___19 {
	struct cgroup_subsys_state___52 * (*css_alloc)(struct cgroup___52 *);
	int (*css_online)(struct cgroup___52 *);
	void (*css_offline)(struct cgroup___52 *);
	void (*css_free)(struct cgroup___52 *);
	int (*can_attach)(struct cgroup___52 *, struct cgroup_taskset___19 *);
	void (*cancel_attach)(struct cgroup___52 *, struct cgroup_taskset___19 *);
	void (*attach)(struct cgroup___52 *, struct cgroup_taskset___19 *);
	void (*fork)(struct task_struct___83 *);
	void (*exit)(struct cgroup___52 *, struct cgroup___52 *, struct task_struct___83 *);
	void (*bind)(struct cgroup___52 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___52 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___21 *base_cftypes;
	struct cftype_set___19 base_cftset;
	struct module___44 *module;
};

struct cgroup_iter {
	struct list_head *cg_link;
	struct list_head *task;
};

struct netns_core___11 {
	struct ctl_table_header___11 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___11 {
	struct mutex___84 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___11 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___11 *ctl;
};

struct netns_ipv4___11 {
	struct ctl_table_header___11 *forw_hdr;
	struct ctl_table_header___11 *frags_hdr;
	struct ctl_table_header___11 *ipv4_hdr;
	struct ctl_table_header___11 *route_hdr;
	struct ctl_table_header___11 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___11 {
	struct ctl_table_header___11 *hdr;
	struct ctl_table_header___11 *route_hdr;
	struct ctl_table_header___11 *icmp_hdr;
	struct ctl_table_header___11 *frags_hdr;
	struct ctl_table_header___11 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___11 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___11 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___5 *);
	int (*local_out)(struct sk_buff___5 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___5 *, const void *);
	struct kmem_cache___72 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___11 {
	struct netns_sysctl_ipv6___11 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___11 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___11 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___11 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___11 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___11 *nf_log_dir_header;
};

struct nf_proto_net___11 {
	struct ctl_table_header___11 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___11 {
	struct nf_proto_net___11 pn;
	unsigned int timeout;
};

struct nf_tcp_net___11 {
	struct nf_proto_net___11 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___11 {
	struct nf_proto_net___11 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___11 {
	struct nf_proto_net___11 pn;
	unsigned int timeout;
};

struct nf_ip_net___11 {
	struct nf_generic_net___11 generic;
	struct nf_tcp_net___11 tcp;
	struct nf_udp_net___11 udp;
	struct nf_icmp_net___11 icmp;
	struct nf_icmp_net___11 icmpv6;
};

struct netns_ct___11 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___11 *sysctl_header;
	struct ctl_table_header___11 *acct_sysctl_header;
	struct ctl_table_header___11 *tstamp_sysctl_header;
	struct ctl_table_header___11 *event_sysctl_header;
	struct ctl_table_header___11 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___72 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___11 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___11 {
	struct netns_sysctl_ipv6___11 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___11 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___11 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___11 xfrm4_dst_ops;
	struct dst_ops___11 xfrm6_dst_ops;
};

struct net___12 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___11 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___11 core;
	struct netns_mib mib;
	struct netns_packet___11 packet;
	struct netns_unix___11 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___11 ipv4;
	struct netns_ipv6___11 ipv6;
	struct netns_sctp___11 sctp;
	struct netns_dccp___3 dccp;
	struct netns_nf___11 nf;
	struct netns_xt xt;
	struct netns_ct___11 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___11 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___11 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___84 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___84 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___69 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___83 *page;
};

struct dma_map_ops___29 {
	void * (*alloc)(struct device___64 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___64 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___64 *, struct vm_area_struct___88 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___64 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___64 *, struct page___83 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___64 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___64 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___64 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___64 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___64 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___64 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___64 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___64 *, dma_addr_t);
	int (*dma_supported)(struct device___64 *, u64);
	int (*set_dma_mask)(struct device___64 *, u64);
	int is_phys;
};

struct bus_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___64 *, char *);
	ssize_t (*store)(struct bus_type___64 *, const char *, size_t);
};

struct device_attribute___64;

struct driver_attribute___64;

struct bus_type___64 {
	const char *name;
	const char *dev_name;
	struct device___64 *dev_root;
	struct bus_attribute___64 *bus_attrs;
	struct device_attribute___64 *dev_attrs;
	struct driver_attribute___64 *drv_attrs;
	const struct attribute_group___57 **bus_groups;
	const struct attribute_group___57 **dev_groups;
	const struct attribute_group___57 **drv_groups;
	int (*match)(struct device___64 *, struct device_driver___64 *);
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	int (*probe)(struct device___64 *);
	int (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*online)(struct device___64 *);
	int (*offline)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct device___64 *, struct device_attribute___64 *, char *);
	ssize_t (*store)(struct device___64 *, struct device_attribute___64 *, const char *, size_t);
};

struct driver_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___64 *, char *);
	ssize_t (*store)(struct device_driver___64 *, const char *, size_t);
};

struct device_driver___64 {
	const char *name;
	struct bus_type___64 *bus;
	struct module___44 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___64 *);
	int (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	const struct attribute_group___57 **groups;
	const struct dev_pm_ops___64 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___64 {
	const char *name;
	const struct attribute_group___57 **groups;
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
};

struct class_attribute___64;

struct class___64 {
	const char *name;
	struct module___44 *owner;
	struct class_attribute___64 *class_attrs;
	struct device_attribute___64 *dev_attrs;
	const struct attribute_group___57 **dev_groups;
	struct bin_attribute___57 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *);
	void (*class_release)(struct class___64 *);
	void (*dev_release)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
	struct subsys_private *p;
};

struct class_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct class___64 *, struct class_attribute___64 *, char *);
	ssize_t (*store)(struct class___64 *, struct class_attribute___64 *, const char *, size_t);
	const void * (*namespace)(struct class___64 *, const struct class_attribute___64 *);
};

struct device_rh___64 {
	struct dev_pm_info_rh___64 power;
};

struct nf_afinfo___11 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___5 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___5 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___12 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___5 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___5 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___59 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___59 *);
	void (*irq_shutdown)(struct irq_data___59 *);
	void (*irq_enable)(struct irq_data___59 *);
	void (*irq_disable)(struct irq_data___59 *);
	void (*irq_ack)(struct irq_data___59 *);
	void (*irq_mask)(struct irq_data___59 *);
	void (*irq_mask_ack)(struct irq_data___59 *);
	void (*irq_unmask)(struct irq_data___59 *);
	void (*irq_eoi)(struct irq_data___59 *);
	int (*irq_set_affinity)(struct irq_data___59 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___59 *);
	int (*irq_set_type)(struct irq_data___59 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___59 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___59 *);
	void (*irq_bus_sync_unlock)(struct irq_data___59 *);
	void (*irq_cpu_online)(struct irq_data___59 *);
	void (*irq_cpu_offline)(struct irq_data___59 *);
	void (*irq_suspend)(struct irq_data___59 *);
	void (*irq_resume)(struct irq_data___59 *);
	void (*irq_pm_shutdown)(struct irq_data___59 *);
	void (*irq_print_chip)(struct irq_data___59 *, struct seq_file___61 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___59 *, void *);
	long unsigned int flags;
};

struct seq_operations___60 {
	void * (*start)(struct seq_file___61 *, loff_t *);
	void (*stop)(struct seq_file___61 *, void *);
	void * (*next)(struct seq_file___61 *, void *, loff_t *);
	int (*show)(struct seq_file___61 *, void *);
};

struct module_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___43 *, struct module_kobject___43 *, char *);
	ssize_t (*store)(struct module_attribute___43 *, struct module_kobject___43 *, const char *, size_t);
	void (*setup)(struct module___44 *, const char *);
	int (*test)(struct module___44 *);
	void (*free)(struct module___44 *);
};

typedef struct poll_table_struct___51 poll_table___4;

struct cfent {
	struct list_head node;
	struct dentry___84 *dentry;
	struct cftype___21 *type;
	struct simple_xattrs xattrs;
};

struct cgroup_event {
	struct cgroup___52 *cgrp;
	struct cftype___21 *cft;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	poll_table___4 pt;
	wait_queue_head_t *wqh;
	wait_queue_t wait;
	struct work_struct remove;
};

struct cg_cgroup_link {
	struct list_head cgrp_link_list;
	struct cgroup___52 *cgrp;
	struct list_head cg_link_list;
	struct css_set___52 *cg;
};

struct cgroup_sb_opts {
	long unsigned int subsys_mask;
	long unsigned int flags;
	char *release_agent;
	bool cpuset_clone_children;
	char *name;
	bool none;
	struct cgroupfs_root___52 *new_root;
};

struct cgroup_seqfile_state {
	struct cftype___21 *cft;
	struct cgroup___52 *cgroup;
};

enum cgroup_filetype {
	CGROUP_FILE_PROCS = 0,
	CGROUP_FILE_TASKS = 1,
};

struct cgroup_pidlist {
	struct {
		enum cgroup_filetype type;
		struct pid_namespace___42 *ns;
	} key;
	pid_t *list;
	int length;
	int use_count;
	struct list_head links;
	struct cgroup___52 *owner;
	struct rw_semaphore mutex;
};

enum freezer_state_flags {
	CGROUP_FREEZER_ONLINE = 1,
	CGROUP_FREEZING_SELF = 2,
	CGROUP_FREEZING_PARENT = 4,
	CGROUP_FROZEN = 8,
	CGROUP_FREEZING = 6,
};

struct freezer {
	struct cgroup_subsys_state___37 css;
	unsigned int state;
	spinlock_t lock;
};

struct page___84;

typedef struct page___84 *pgtable_t___84;

struct address_space___84;

struct kmem_cache___73;

struct page___84 {
	long unsigned int flags;
	struct address_space___84 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___84 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___84 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___73 *slab_cache;
		struct page___84 *first_page;
	};
	long: 64;
};

struct task_struct___84;

struct pv_cpu_ops___84 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___84 *);
	void (*end_context_switch)(struct task_struct___84 *);
};

struct mutex___85 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___84 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___80 {
	struct page___84 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___89;

struct signal_struct___84;

struct backing_dev_info___11;

struct css_set___53;

struct task_struct___84 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___84 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___89 *mm;
	struct mm_struct___89 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___84 *real_parent;
	struct task_struct___84 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___84 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___42 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___84 = 0,
		VTIME_USER___84 = 1,
		VTIME_SYS___84 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___84 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___11 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___53 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___85 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___80 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___89 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___89 *, struct mm_struct___89 *);
	void (*dup_mmap)(struct mm_struct___89 *, struct mm_struct___89 *);
	void (*exit_mmap)(struct mm_struct___89 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___89 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___89 *);
	void (*pgd_free)(struct mm_struct___89 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___89 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___89 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___89 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___89 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___89 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___89 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___89 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___89 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___89 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___89 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___89 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___85 lock;
	void *vdso;
} mm_context_t___85;

struct xol_area___84;

struct uprobes_state___84 {
	struct xol_area___84 *xol_area;
};

struct vm_area_struct___89;

struct file___84;

struct core_state___84;

struct mm_struct___89 {
	struct vm_area_struct___89 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___89 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___89 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___85 context;
	long unsigned int flags;
	struct core_state___84 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___84 *owner;
	struct file___84 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___84 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___41 {
	struct task_struct___84 *task;
	struct exec_domain___20 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___58;

struct attribute_group___58 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___58 **bin_attrs;
};

struct bin_attribute___58 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___84 *, struct kobject___3 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___84 *, struct kobject___3 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	int (*mmap)(struct file___84 *, struct kobject___3 *, struct bin_attribute___58 *, struct vm_area_struct___89 *);
};

struct vfsmount___12;

struct dentry___85;

struct path___84 {
	struct vfsmount___12 *mnt;
	struct dentry___85 *dentry;
};

struct inode___85;

struct file_operations___84;

struct file___84 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___84 f_path;
	struct inode___85 *f_inode;
	const struct file_operations___84 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___42 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___84 *f_mapping;
	struct mutex___85 f_pos_lock;
};

struct vm_operations_struct___73;

struct vm_area_struct___89 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___89 *vm_next;
	struct vm_area_struct___89 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___89 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___73 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___84 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___65;

struct dev_pm_ops___65 {
	int (*prepare)(struct device___65 *);
	void (*complete)(struct device___65 *);
	int (*suspend)(struct device___65 *);
	int (*resume)(struct device___65 *);
	int (*freeze)(struct device___65 *);
	int (*thaw)(struct device___65 *);
	int (*poweroff)(struct device___65 *);
	int (*restore)(struct device___65 *);
	int (*suspend_late)(struct device___65 *);
	int (*resume_early)(struct device___65 *);
	int (*freeze_late)(struct device___65 *);
	int (*thaw_early)(struct device___65 *);
	int (*poweroff_late)(struct device___65 *);
	int (*restore_early)(struct device___65 *);
	int (*suspend_noirq)(struct device___65 *);
	int (*resume_noirq)(struct device___65 *);
	int (*freeze_noirq)(struct device___65 *);
	int (*thaw_noirq)(struct device___65 *);
	int (*poweroff_noirq)(struct device___65 *);
	int (*restore_noirq)(struct device___65 *);
	int (*runtime_suspend)(struct device___65 *);
	int (*runtime_resume)(struct device___65 *);
	int (*runtime_idle)(struct device___65 *);
};

struct device_type___65;

struct bus_type___65;

struct device_driver___65;

struct dev_pm_domain___65;

struct class___65;

struct device_rh___65;

struct device___65 {
	struct device___65 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___65 *type;
	struct mutex___85 mutex;
	struct bus_type___65 *bus;
	struct device_driver___65 *driver;
	void *platform_data;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___65 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___29 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___65 *class;
	const struct attribute_group___58 **groups;
	void (*release)(struct device___65 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___65 *device_rh;
};

struct dev_pm_info_rh___65 {
	void (*set_latency_tolerance)(struct device___65 *, s32);
};

struct dev_pm_domain___65 {
	struct dev_pm_ops___65 ops;
};

struct zone___84;

struct lruvec___84 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___84 *zone;
};

struct pglist_data___84;

struct zone___84 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___84 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___84 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___84 {
	struct zone___84 *zone;
	int zone_idx;
};

struct zonelist___84 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___84 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___84 {
	struct zone___84 node_zones[4];
	struct zonelist___84 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___84 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___60;

struct x86_io_apic_ops___60 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___60 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___60;

struct irq_data___60 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___60 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___84 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___84 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___65 *, char *);
	ssize_t (*store)(struct bus_type___65 *, const char *, size_t);
};

struct device_attribute___65;

struct driver_attribute___65;

struct bus_type___65 {
	const char *name;
	const char *dev_name;
	struct device___65 *dev_root;
	struct bus_attribute___65 *bus_attrs;
	struct device_attribute___65 *dev_attrs;
	struct driver_attribute___65 *drv_attrs;
	const struct attribute_group___58 **bus_groups;
	const struct attribute_group___58 **dev_groups;
	const struct attribute_group___58 **drv_groups;
	int (*match)(struct device___65 *, struct device_driver___65 *);
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	int (*probe)(struct device___65 *);
	int (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*online)(struct device___65 *);
	int (*offline)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct device___65 *, struct device_attribute___65 *, char *);
	ssize_t (*store)(struct device___65 *, struct device_attribute___65 *, const char *, size_t);
};

struct driver_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___65 *, char *);
	ssize_t (*store)(struct device_driver___65 *, const char *, size_t);
};

struct device_driver___65 {
	const char *name;
	struct bus_type___65 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___65 *);
	int (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	const struct attribute_group___58 **groups;
	const struct dev_pm_ops___65 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___65 {
	const char *name;
	const struct attribute_group___58 **groups;
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
};

struct class_attribute___65;

struct class___65 {
	const char *name;
	struct module *owner;
	struct class_attribute___65 *class_attrs;
	struct device_attribute___65 *dev_attrs;
	const struct attribute_group___58 **dev_groups;
	struct bin_attribute___58 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *);
	void (*class_release)(struct class___65 *);
	void (*dev_release)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
	struct subsys_private *p;
};

struct class_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct class___65 *, struct class_attribute___65 *, char *);
	ssize_t (*store)(struct class___65 *, struct class_attribute___65 *, const char *, size_t);
	const void * (*namespace)(struct class___65 *, const struct class_attribute___65 *);
};

struct device_rh___65 {
	struct dev_pm_info_rh___65 power;
};

struct xol_area___84 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___84 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___73;

struct memcg_cache_params___73;

struct kmem_cache___73 {
	struct kmem_cache_cpu___73 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___73 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___84;

struct address_space___84 {
	struct inode___85 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___85 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___84 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___11 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___70;

struct vm_operations_struct___73 {
	void (*open)(struct vm_area_struct___89 *);
	void (*close)(struct vm_area_struct___89 *);
	int (*fault)(struct vm_area_struct___89 *, struct vm_fault___70 *);
	int (*page_mkwrite)(struct vm_area_struct___89 *, struct vm_fault___70 *);
	int (*access)(struct vm_area_struct___89 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___89 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___89 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___89 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___89 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___84 {
	struct task_struct___84 *task;
	struct core_thread___84 *next;
};

struct core_state___84 {
	atomic_t nr_threads;
	struct core_thread___84 dumper;
	struct completion startup;
};

struct signal_struct___84 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___84 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___84 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___42 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___42 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___85 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback___11 {
	struct backing_dev_info___11 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___11 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___11 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___65 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___85 *debug_dir;
	struct dentry___85 *debug_stats;
};

struct cgroup_subsys_state___53;

struct css_set___53 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___53 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___70 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___84 *page;
};

struct kmem_cache_cpu___73 {
	void **freelist;
	long unsigned int tid;
	struct page___84 *page;
	struct page___84 *partial;
};

struct memcg_cache_params___73 {
	bool is_root_cache;
	union {
		struct kmem_cache___73 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___73 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___53 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___85 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___85 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___85 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___84;

struct super_block___85;

struct dentry___85 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___85 *d_parent;
	struct qstr d_name;
	struct inode___85 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___84 *d_op;
	struct super_block___85 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___84;

struct file_lock___84;

struct dquot___84;

struct block_device___84;

struct inode___85 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___84 *i_op;
	struct super_block___85 *i_sb;
	struct address_space___84 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___85 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___84 *i_fop;
	struct file_lock___84 *i_flock;
	struct address_space___84 i_data;
	struct dquot___84 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___84 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___84 {
	int (*d_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_hash)(const struct dentry___85 *, struct qstr *);
	int (*d_compare)(const struct dentry___85 *, const struct dentry___85 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___85 *);
	void (*d_release)(struct dentry___85 *);
	void (*d_prune)(struct dentry___85 *);
	void (*d_iput)(struct dentry___85 *, struct inode___85 *);
	char * (*d_dname)(struct dentry___85 *, char *, int);
	struct vfsmount___12 * (*d_automount)(struct path___84 *);
	int (*d_manage)(struct dentry___85 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___84;

struct mem_dqinfo___84 {
	struct quota_format_type___84 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___84;

struct quota_info___84 {
	unsigned int flags;
	struct mutex___85 dqio_mutex;
	struct mutex___85 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___85 *files[2];
	struct mem_dqinfo___84 info[2];
	const struct quota_format_ops___84 *ops[2];
};

struct file_system_type___84;

struct super_operations___84;

struct dquot_operations___84;

struct quotactl_ops___84;

struct super_block___85 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___84 *s_type;
	const struct super_operations___84 *s_op;
	const struct dquot_operations___84 *dq_op;
	const struct quotactl_ops___84 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___85 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___53 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___84 *s_bdev;
	struct backing_dev_info___11 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___84 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___85 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___84 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___12 {
	struct dentry___85 *mnt_root;
	struct super_block___85 *mnt_sb;
	int mnt_flags;
};

struct block_device___84 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___85 *bd_inode;
	struct super_block___85 *bd_super;
	struct mutex___85 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___84 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___85 bd_fsfreeze_mutex;
};

struct cgroup___53;

struct cgroup_subsys_state___53 {
	struct cgroup___53 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___85 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___84 *ia_file;
};

struct dquot___84 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___85 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___85 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___84 {
	int qf_fmt_id;
	const struct quota_format_ops___84 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___84 *qf_next;
};

struct quota_format_ops___84 {
	int (*check_quota_file)(struct super_block___85 *, int);
	int (*read_file_info)(struct super_block___85 *, int);
	int (*write_file_info)(struct super_block___85 *, int);
	int (*free_file_info)(struct super_block___85 *, int);
	int (*read_dqblk)(struct dquot___84 *);
	int (*commit_dqblk)(struct dquot___84 *);
	int (*release_dqblk)(struct dquot___84 *);
};

struct dquot_operations___84 {
	int (*write_dquot)(struct dquot___84 *);
	struct dquot___84 * (*alloc_dquot)(struct super_block___85 *, int);
	void (*destroy_dquot)(struct dquot___84 *);
	int (*acquire_dquot)(struct dquot___84 *);
	int (*release_dquot)(struct dquot___84 *);
	int (*mark_dirty)(struct dquot___84 *);
	int (*write_info)(struct super_block___85 *, int);
	qsize_t * (*get_reserved_space)(struct inode___85 *);
};

struct quotactl_ops___84 {
	int (*quota_on)(struct super_block___85 *, int, int, struct path___84 *);
	int (*quota_on_meta)(struct super_block___85 *, int, int);
	int (*quota_off)(struct super_block___85 *, int);
	int (*quota_sync)(struct super_block___85 *, int);
	int (*get_info)(struct super_block___85 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___85 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___85 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___85 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___85 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___85 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___85 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___85 *, unsigned int);
};

struct address_space_operations___84 {
	int (*writepage)(struct page___84 *, struct writeback_control *);
	int (*readpage)(struct file___84 *, struct page___84 *);
	int (*writepages)(struct address_space___84 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___84 *);
	int (*readpages)(struct file___84 *, struct address_space___84 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___84 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___84 **, void **);
	int (*write_end)(struct file___84 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___84 *, void *);
	sector_t (*bmap)(struct address_space___84 *, sector_t);
	void (*invalidatepage)(struct page___84 *, long unsigned int);
	int (*releasepage)(struct page___84 *, gfp_t);
	void (*freepage)(struct page___84 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___84 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___84 *, struct page___84 *, struct page___84 *, enum migrate_mode);
	int (*launder_page)(struct page___84 *);
	int (*is_partially_uptodate)(struct page___84 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___84 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___84 *, struct page___84 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___84 *, sector_t *);
	void (*swap_deactivate)(struct file___84 *);
	void (*invalidatepage_range)(struct page___84 *, unsigned int, unsigned int);
};

struct nameidata___3;

struct inode_operations___84 {
	struct dentry___85 * (*lookup)(struct inode___85 *, struct dentry___85 *, unsigned int);
	void * (*follow_link)(struct dentry___85 *, struct nameidata___3 *);
	int (*permission)(struct inode___85 *, int);
	struct posix_acl * (*get_acl)(struct inode___85 *, int);
	int (*readlink)(struct dentry___85 *, char *, int);
	void (*put_link)(struct dentry___85 *, struct nameidata___3 *, void *);
	int (*create)(struct inode___85 *, struct dentry___85 *, umode_t, bool);
	int (*link)(struct dentry___85 *, struct inode___85 *, struct dentry___85 *);
	int (*unlink)(struct inode___85 *, struct dentry___85 *);
	int (*symlink)(struct inode___85 *, struct dentry___85 *, const char *);
	int (*mkdir)(struct inode___85 *, struct dentry___85 *, umode_t);
	int (*rmdir)(struct inode___85 *, struct dentry___85 *);
	int (*mknod)(struct inode___85 *, struct dentry___85 *, umode_t, dev_t);
	int (*rename)(struct inode___85 *, struct dentry___85 *, struct inode___85 *, struct dentry___85 *);
	int (*setattr)(struct dentry___85 *, struct iattr___85 *);
	int (*getattr)(struct vfsmount___12 *, struct dentry___85 *, struct kstat *);
	int (*setxattr)(struct dentry___85 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___85 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___85 *, char *, size_t);
	int (*removexattr)(struct dentry___85 *, const char *);
	int (*fiemap)(struct inode___85 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___85 *, struct timespec *, int);
	int (*atomic_open)(struct inode___85 *, struct dentry___85 *, struct file___84 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___62;

struct file_operations___84 {
	struct module *owner;
	loff_t (*llseek)(struct file___84 *, loff_t, int);
	ssize_t (*read)(struct file___84 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___84 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___84 *, void *, filldir_t);
	unsigned int (*poll)(struct file___84 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___84 *, struct vm_area_struct___89 *);
	int (*open)(struct inode___85 *, struct file___84 *);
	int (*flush)(struct file___84 *, fl_owner_t);
	int (*release)(struct inode___85 *, struct file___84 *);
	int (*fsync)(struct file___84 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___84 *, int);
	int (*lock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*sendpage)(struct file___84 *, struct page___84 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___84 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___84 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___84 *, long int, struct file_lock___84 **, void **);
		struct {
			int (*setlease)(struct file___84 *, long int, struct file_lock___84 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___84 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___62 *, struct file___84 *);
};

struct fasync_struct___84;

struct file_lock_operations___84;

struct lock_manager_operations___84;

struct file_lock___84 {
	struct file_lock___84 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___42 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___84 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___84 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___84 *fl_ops;
	const struct lock_manager_operations___84 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___84 {
	void (*fl_copy_lock)(struct file_lock___84 *, struct file_lock___84 *);
	void (*fl_release_private)(struct file_lock___84 *);
};

struct lock_manager_operations___84 {
	int (*lm_compare_owner)(struct file_lock___84 *, struct file_lock___84 *);
	long unsigned int (*lm_owner_key)(struct file_lock___84 *);
	void (*lm_notify)(struct file_lock___84 *);
	int (*lm_grant)(struct file_lock___84 *, struct file_lock___84 *, int);
	void (*lm_break)(struct file_lock___84 *);
	int (*lm_change)(struct file_lock___84 **, int);
};

struct fasync_struct___84 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___84 *fa_next;
	struct file___84 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___84 {
	const char *name;
	int fs_flags;
	struct dentry___85 * (*mount)(struct file_system_type___84 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___85 *);
	struct module *owner;
	struct file_system_type___84 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___84 {
	struct inode___85 * (*alloc_inode)(struct super_block___85 *);
	void (*destroy_inode)(struct inode___85 *);
	void (*dirty_inode)(struct inode___85 *, int);
	int (*write_inode)(struct inode___85 *, struct writeback_control *);
	int (*drop_inode)(struct inode___85 *);
	void (*evict_inode)(struct inode___85 *);
	void (*put_super)(struct super_block___85 *);
	int (*sync_fs)(struct super_block___85 *, int);
	int (*freeze_fs)(struct super_block___85 *);
	int (*unfreeze_fs)(struct super_block___85 *);
	int (*statfs)(struct dentry___85 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___85 *, int *, char *);
	void (*umount_begin)(struct super_block___85 *);
	int (*show_options)(struct seq_file___62 *, struct dentry___85 *);
	int (*show_devname)(struct seq_file___62 *, struct dentry___85 *);
	int (*show_path)(struct seq_file___62 *, struct dentry___85 *);
	int (*show_stats)(struct seq_file___62 *, struct dentry___85 *);
	ssize_t (*quota_read)(struct super_block___85 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___85 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___85 *);
	int (*bdev_try_to_free_page)(struct super_block___85 *, struct page___84 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___85 *);
	void (*free_cached_objects)(struct super_block___85 *, int);
};

struct seq_operations___61;

struct seq_file___62 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___85 lock;
	const struct seq_operations___61 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___3 {
	struct path___84 path;
	struct qstr last;
	struct path___84 root;
	struct inode___85 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct cgroupfs_root___53;

struct cgroup___53 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___53 *parent;
	struct dentry___85 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___53 *subsys[11];
	struct cgroupfs_root___53 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___85 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___53 {
	struct super_block___85 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___53 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___22 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___85 *, struct file___84 *);
	ssize_t (*read)(struct cgroup___53 *, struct cftype___22 *, struct file___84 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___53 *, struct cftype___22 *);
	s64 (*read_s64)(struct cgroup___53 *, struct cftype___22 *);
	int (*read_map)(struct cgroup___53 *, struct cftype___22 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___53 *, struct cftype___22 *, struct seq_file___62 *);
	ssize_t (*write)(struct cgroup___53 *, struct cftype___22 *, struct file___84 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___53 *, struct cftype___22 *, u64);
	int (*write_s64)(struct cgroup___53 *, struct cftype___22 *, s64);
	int (*write_string)(struct cgroup___53 *, struct cftype___22 *, const char *);
	int (*trigger)(struct cgroup___53 *, unsigned int);
	int (*release)(struct inode___85 *, struct file___84 *);
	int (*register_event)(struct cgroup___53 *, struct cftype___22 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___53 *, struct cftype___22 *, struct eventfd_ctx *);
};

struct cftype_set___20 {
	struct list_head node;
	struct cftype___22 *cfts;
};

struct cgroup_scanner___2 {
	struct cgroup___53 *cg;
	int (*test_task)(struct task_struct___84 *, struct cgroup_scanner___2 *);
	void (*process_task)(struct task_struct___84 *, struct cgroup_scanner___2 *);
	struct ptr_heap *heap;
	void *data;
};

struct task_and_cgroup___20 {
	struct task_struct___84 *task;
	struct cgroup___53 *cgrp;
	struct css_set___53 *cg;
};

struct cgroup_taskset___20 {
	struct task_and_cgroup___20 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___53 *cur_cgrp;
};

struct cgroup_subsys___20 {
	struct cgroup_subsys_state___53 * (*css_alloc)(struct cgroup___53 *);
	int (*css_online)(struct cgroup___53 *);
	void (*css_offline)(struct cgroup___53 *);
	void (*css_free)(struct cgroup___53 *);
	int (*can_attach)(struct cgroup___53 *, struct cgroup_taskset___20 *);
	void (*cancel_attach)(struct cgroup___53 *, struct cgroup_taskset___20 *);
	void (*attach)(struct cgroup___53 *, struct cgroup_taskset___20 *);
	void (*fork)(struct task_struct___84 *);
	void (*exit)(struct cgroup___53 *, struct cgroup___53 *, struct task_struct___84 *);
	void (*bind)(struct cgroup___53 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___53 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___22 *base_cftypes;
	struct cftype_set___20 base_cftset;
	struct module *module;
};

struct irq_chip___60 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___60 *);
	void (*irq_shutdown)(struct irq_data___60 *);
	void (*irq_enable)(struct irq_data___60 *);
	void (*irq_disable)(struct irq_data___60 *);
	void (*irq_ack)(struct irq_data___60 *);
	void (*irq_mask)(struct irq_data___60 *);
	void (*irq_mask_ack)(struct irq_data___60 *);
	void (*irq_unmask)(struct irq_data___60 *);
	void (*irq_eoi)(struct irq_data___60 *);
	int (*irq_set_affinity)(struct irq_data___60 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___60 *);
	int (*irq_set_type)(struct irq_data___60 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___60 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___60 *);
	void (*irq_bus_sync_unlock)(struct irq_data___60 *);
	void (*irq_cpu_online)(struct irq_data___60 *);
	void (*irq_cpu_offline)(struct irq_data___60 *);
	void (*irq_suspend)(struct irq_data___60 *);
	void (*irq_resume)(struct irq_data___60 *);
	void (*irq_pm_shutdown)(struct irq_data___60 *);
	void (*irq_print_chip)(struct irq_data___60 *, struct seq_file___62 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___60 *, void *);
	long unsigned int flags;
};

enum mpol_rebind_step {
	MPOL_REBIND_ONCE = 0,
	MPOL_REBIND_STEP1 = 1,
	MPOL_REBIND_STEP2 = 2,
	MPOL_REBIND_NSTEP = 3,
};

struct seq_operations___61 {
	void * (*start)(struct seq_file___62 *, loff_t *);
	void (*stop)(struct seq_file___62 *, void *);
	void * (*next)(struct seq_file___62 *, void *, loff_t *);
	int (*show)(struct seq_file___62 *, void *);
};

struct fmeter {
	int cnt;
	int val;
	time_t time;
	spinlock_t lock;
};

struct cpuset {
	struct cgroup_subsys_state___53 css;
	long unsigned int flags;
	cpumask_var_t cpus_allowed;
	nodemask_t mems_allowed;
	struct fmeter fmeter;
	int attach_in_progress;
	int pn;
	int relax_domain_level;
	struct work_struct hotplug_work;
};

typedef enum {
	CS_ONLINE = 0,
	CS_CPU_EXCLUSIVE = 1,
	CS_MEM_EXCLUSIVE = 2,
	CS_MEM_HARDWALL = 3,
	CS_MEMORY_MIGRATE = 4,
	CS_SCHED_LOAD_BALANCE = 5,
	CS_SPREAD_PAGE = 6,
	CS_SPREAD_SLAB = 7,
} cpuset_flagbits_t;

typedef enum {
	FILE_MEMORY_MIGRATE = 0,
	FILE_CPULIST = 1,
	FILE_MEMLIST = 2,
	FILE_CPU_EXCLUSIVE = 3,
	FILE_MEM_EXCLUSIVE = 4,
	FILE_MEM_HARDWALL = 5,
	FILE_SCHED_LOAD_BALANCE = 6,
	FILE_SCHED_RELAX_DOMAIN_LEVEL = 7,
	FILE_MEMORY_PRESSURE_ENABLED = 8,
	FILE_MEMORY_PRESSURE = 9,
	FILE_SPREAD_PAGE = 10,
	FILE_SPREAD_SLAB = 11,
} cpuset_filetype_t;

struct proc_ns_operations___2 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___83 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___43 *, void *);
	unsigned int (*inum)(void *);
};

struct page___85;

typedef struct page___85 *pgtable_t___85;

struct address_space___85;

struct kmem_cache___74;

struct page___85 {
	long unsigned int flags;
	struct address_space___85 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___85 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___85 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___74 *slab_cache;
		struct page___85 *first_page;
	};
	long: 64;
};

struct task_struct___85;

struct pv_cpu_ops___85 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___38 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___38 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___85 *);
	void (*end_context_switch)(struct task_struct___85 *);
};

struct mutex___86 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___85 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___81 {
	struct page___85 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___90;

struct cred___3;

struct fs_struct___6;

struct signal_struct___85;

struct task_struct___85 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___85 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___90 *mm;
	struct mm_struct___90 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___85 *real_parent;
	struct task_struct___85 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___85 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___42 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___85 = 0,
		VTIME_USER___85 = 1,
		VTIME_SYS___85 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___38 thread;
	struct fs_struct___6 *fs;
	struct files_struct *files;
	struct nsproxy___43 *nsproxy;
	struct signal_struct___85 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___86 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___81 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___90 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___90 *, struct mm_struct___90 *);
	void (*dup_mmap)(struct mm_struct___90 *, struct mm_struct___90 *);
	void (*exit_mmap)(struct mm_struct___90 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___90 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___90 *);
	void (*pgd_free)(struct mm_struct___90 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___90 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___90 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___90 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___90 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___90 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___90 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___90 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___90 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___90 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___90 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___90 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___86 lock;
	void *vdso;
} mm_context_t___86;

struct xol_area___85;

struct uprobes_state___85 {
	struct xol_area___85 *xol_area;
};

struct vm_area_struct___90;

struct file___85;

struct core_state___85;

struct mm_struct___90 {
	struct vm_area_struct___90 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___90 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___90 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___86 context;
	long unsigned int flags;
	struct core_state___85 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___85 *owner;
	struct file___85 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___85 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___85 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___85 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___74;

struct memcg_cache_params___74;

struct kmem_cache___74 {
	struct kmem_cache_cpu___74 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___3 kobj;
	struct memcg_cache_params___74 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___86;

struct address_space_operations___85;

struct address_space___85 {
	struct inode___86 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___86 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___85 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___86;

struct path___85 {
	struct vfsmount *mnt;
	struct dentry___86 *dentry;
};

struct file_operations___85;

struct file___85 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___85 f_path;
	struct inode___86 *f_inode;
	const struct file_operations___85 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___42 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___85 *f_mapping;
	struct mutex___86 f_pos_lock;
};

struct vm_area_struct___90 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___90 *vm_next;
	struct vm_area_struct___90 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___90 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___85 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___85 {
	struct task_struct___85 *task;
	struct core_thread___85 *next;
};

struct core_state___85 {
	atomic_t nr_threads;
	struct core_thread___85 dumper;
	struct completion startup;
};

struct smp_ops___85 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___85 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___3;

struct user_struct___3 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___3 *uid_keyring;
	struct key___3 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct zone___85;

struct lruvec___85 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___85 *zone;
};

struct pglist_data___85;

struct zone___85 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___85 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___85 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___85 {
	struct zone___85 *zone;
	int zone_idx;
};

struct zonelist___85 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___85 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___85 {
	struct zone___85 node_zones[4];
	struct zonelist___85 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___85 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_type___3;

struct keyring_index_key___3 {
	struct key_type___3 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___3;

typedef int (*request_key_actor_t___3)(struct key_construction___3 *, const char *, void *);

struct seq_file___63;

struct key_type___3 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___3 *, struct key_preparsed_payload *);
	int (*update)(struct key___3 *, struct key_preparsed_payload *);
	int (*match)(const struct key___3 *, const void *);
	void (*revoke)(struct key___3 *);
	void (*destroy)(struct key___3 *);
	void (*describe)(const struct key___3 *, struct seq_file___63 *);
	long int (*read)(const struct key___3 *, char *, size_t);
	request_key_actor_t___3 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key___3 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___3 index_key;
		struct {
			struct key_type___3 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct user_namespace___2;

struct cred___3 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct___3 *user;
	struct user_namespace___2 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct user_namespace___2 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___2 *parent;
	kuid_t owner;
	kgid_t group;
	unsigned int proc_inum;
	bool may_mount_sysfs;
	bool may_mount_proc;
	struct key___3 *persistent_keyring_register;
	struct rw_semaphore persistent_keyring_register_sem;
	int level;
	long unsigned int flags;
};

struct signal_struct___85 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___85 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___85 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___42 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___42 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___86 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___6 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___85 root;
	struct path___85 pwd;
};

struct kmem_cache_cpu___74 {
	void **freelist;
	long unsigned int tid;
	struct page___85 *page;
	struct page___85 *partial;
};

struct memcg_cache_params___74 {
	bool is_root_cache;
	union {
		struct kmem_cache___74 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___74 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct proc_ns_operations___3 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___85 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___43 *, void *);
	unsigned int (*inum)(void *);
};

struct key_construction___3 {
	struct key___3 *key;
	struct key___3 *authkey;
};

struct seq_operations___62;

struct seq_file___63 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___86 lock;
	const struct seq_operations___62 *op;
	int poll_event;
	struct user_namespace___2 *user_ns;
	void *private;
};

struct seq_operations___62 {
	void * (*start)(struct seq_file___63 *, loff_t *);
	void (*stop)(struct seq_file___63 *, void *);
	void * (*next)(struct seq_file___63 *, void *, loff_t *);
	int (*show)(struct seq_file___63 *, void *);
};

struct dentry_operations___85;

struct super_block___86;

struct dentry___86 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___86 *d_parent;
	struct qstr d_name;
	struct inode___86 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___85 *d_op;
	struct super_block___86 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___85;

struct file_lock___85;

struct dquot___85;

struct block_device___85;

struct inode___86 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___85 *i_op;
	struct super_block___86 *i_sb;
	struct address_space___85 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___86 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___85 *i_fop;
	struct file_lock___85 *i_flock;
	struct address_space___85 i_data;
	struct dquot___85 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___85 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___85 {
	int (*d_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_hash)(const struct dentry___86 *, struct qstr *);
	int (*d_compare)(const struct dentry___86 *, const struct dentry___86 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___86 *);
	void (*d_release)(struct dentry___86 *);
	void (*d_prune)(struct dentry___86 *);
	void (*d_iput)(struct dentry___86 *, struct inode___86 *);
	char * (*d_dname)(struct dentry___86 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___85 *);
	int (*d_manage)(struct dentry___86 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___85;

struct mem_dqinfo___85 {
	struct quota_format_type___85 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___85;

struct quota_info___85 {
	unsigned int flags;
	struct mutex___86 dqio_mutex;
	struct mutex___86 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___86 *files[2];
	struct mem_dqinfo___85 info[2];
	const struct quota_format_ops___85 *ops[2];
};

struct file_system_type___85;

struct super_operations___85;

struct dquot_operations___85;

struct quotactl_ops___85;

struct super_block___86 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___85 *s_type;
	const struct super_operations___85 *s_op;
	const struct dquot_operations___85 *dq_op;
	const struct quotactl_ops___85 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___86 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___85 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___85 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___86 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___85 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___85 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___86 *bd_inode;
	struct super_block___86 *bd_super;
	struct mutex___86 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___85 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___86 bd_fsfreeze_mutex;
};

struct iattr___86 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___85 *ia_file;
};

struct dquot___85 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___86 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___86 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___85 {
	int qf_fmt_id;
	const struct quota_format_ops___85 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___85 *qf_next;
};

struct quota_format_ops___85 {
	int (*check_quota_file)(struct super_block___86 *, int);
	int (*read_file_info)(struct super_block___86 *, int);
	int (*write_file_info)(struct super_block___86 *, int);
	int (*free_file_info)(struct super_block___86 *, int);
	int (*read_dqblk)(struct dquot___85 *);
	int (*commit_dqblk)(struct dquot___85 *);
	int (*release_dqblk)(struct dquot___85 *);
};

struct dquot_operations___85 {
	int (*write_dquot)(struct dquot___85 *);
	struct dquot___85 * (*alloc_dquot)(struct super_block___86 *, int);
	void (*destroy_dquot)(struct dquot___85 *);
	int (*acquire_dquot)(struct dquot___85 *);
	int (*release_dquot)(struct dquot___85 *);
	int (*mark_dirty)(struct dquot___85 *);
	int (*write_info)(struct super_block___86 *, int);
	qsize_t * (*get_reserved_space)(struct inode___86 *);
};

struct quotactl_ops___85 {
	int (*quota_on)(struct super_block___86 *, int, int, struct path___85 *);
	int (*quota_on_meta)(struct super_block___86 *, int, int);
	int (*quota_off)(struct super_block___86 *, int);
	int (*quota_sync)(struct super_block___86 *, int);
	int (*get_info)(struct super_block___86 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___86 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___86 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___86 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___86 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___86 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___86 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___86 *, unsigned int);
};

struct address_space_operations___85 {
	int (*writepage)(struct page___85 *, struct writeback_control *);
	int (*readpage)(struct file___85 *, struct page___85 *);
	int (*writepages)(struct address_space___85 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___85 *);
	int (*readpages)(struct file___85 *, struct address_space___85 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___85 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___85 **, void **);
	int (*write_end)(struct file___85 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___85 *, void *);
	sector_t (*bmap)(struct address_space___85 *, sector_t);
	void (*invalidatepage)(struct page___85 *, long unsigned int);
	int (*releasepage)(struct page___85 *, gfp_t);
	void (*freepage)(struct page___85 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___85 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___85 *, struct page___85 *, struct page___85 *, enum migrate_mode);
	int (*launder_page)(struct page___85 *);
	int (*is_partially_uptodate)(struct page___85 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___85 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___85 *, struct page___85 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___85 *, sector_t *);
	void (*swap_deactivate)(struct file___85 *);
	void (*invalidatepage_range)(struct page___85 *, unsigned int, unsigned int);
};

struct inode_operations___85 {
	struct dentry___86 * (*lookup)(struct inode___86 *, struct dentry___86 *, unsigned int);
	void * (*follow_link)(struct dentry___86 *, struct nameidata *);
	int (*permission)(struct inode___86 *, int);
	struct posix_acl * (*get_acl)(struct inode___86 *, int);
	int (*readlink)(struct dentry___86 *, char *, int);
	void (*put_link)(struct dentry___86 *, struct nameidata *, void *);
	int (*create)(struct inode___86 *, struct dentry___86 *, umode_t, bool);
	int (*link)(struct dentry___86 *, struct inode___86 *, struct dentry___86 *);
	int (*unlink)(struct inode___86 *, struct dentry___86 *);
	int (*symlink)(struct inode___86 *, struct dentry___86 *, const char *);
	int (*mkdir)(struct inode___86 *, struct dentry___86 *, umode_t);
	int (*rmdir)(struct inode___86 *, struct dentry___86 *);
	int (*mknod)(struct inode___86 *, struct dentry___86 *, umode_t, dev_t);
	int (*rename)(struct inode___86 *, struct dentry___86 *, struct inode___86 *, struct dentry___86 *);
	int (*setattr)(struct dentry___86 *, struct iattr___86 *);
	int (*getattr)(struct vfsmount *, struct dentry___86 *, struct kstat *);
	int (*setxattr)(struct dentry___86 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___86 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___86 *, char *, size_t);
	int (*removexattr)(struct dentry___86 *, const char *);
	int (*fiemap)(struct inode___86 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___86 *, struct timespec *, int);
	int (*atomic_open)(struct inode___86 *, struct dentry___86 *, struct file___85 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___85 {
	struct module *owner;
	loff_t (*llseek)(struct file___85 *, loff_t, int);
	ssize_t (*read)(struct file___85 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___85 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___85 *, void *, filldir_t);
	unsigned int (*poll)(struct file___85 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___85 *, struct vm_area_struct___90 *);
	int (*open)(struct inode___86 *, struct file___85 *);
	int (*flush)(struct file___85 *, fl_owner_t);
	int (*release)(struct inode___86 *, struct file___85 *);
	int (*fsync)(struct file___85 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___85 *, int);
	int (*lock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*sendpage)(struct file___85 *, struct page___85 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___85 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___85 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___85 *, long int, struct file_lock___85 **, void **);
		struct {
			int (*setlease)(struct file___85 *, long int, struct file_lock___85 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___85 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___63 *, struct file___85 *);
};

struct fasync_struct___85;

struct file_lock_operations___85;

struct lock_manager_operations___85;

struct file_lock___85 {
	struct file_lock___85 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___42 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___85 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___85 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___85 *fl_ops;
	const struct lock_manager_operations___85 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___85 {
	void (*fl_copy_lock)(struct file_lock___85 *, struct file_lock___85 *);
	void (*fl_release_private)(struct file_lock___85 *);
};

struct lock_manager_operations___85 {
	int (*lm_compare_owner)(struct file_lock___85 *, struct file_lock___85 *);
	long unsigned int (*lm_owner_key)(struct file_lock___85 *);
	void (*lm_notify)(struct file_lock___85 *);
	int (*lm_grant)(struct file_lock___85 *, struct file_lock___85 *, int);
	void (*lm_break)(struct file_lock___85 *);
	int (*lm_change)(struct file_lock___85 **, int);
};

struct fasync_struct___85 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___85 *fa_next;
	struct file___85 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___85 {
	const char *name;
	int fs_flags;
	struct dentry___86 * (*mount)(struct file_system_type___85 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___86 *);
	struct module *owner;
	struct file_system_type___85 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___85 {
	struct inode___86 * (*alloc_inode)(struct super_block___86 *);
	void (*destroy_inode)(struct inode___86 *);
	void (*dirty_inode)(struct inode___86 *, int);
	int (*write_inode)(struct inode___86 *, struct writeback_control *);
	int (*drop_inode)(struct inode___86 *);
	void (*evict_inode)(struct inode___86 *);
	void (*put_super)(struct super_block___86 *);
	int (*sync_fs)(struct super_block___86 *, int);
	int (*freeze_fs)(struct super_block___86 *);
	int (*unfreeze_fs)(struct super_block___86 *);
	int (*statfs)(struct dentry___86 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___86 *, int *, char *);
	void (*umount_begin)(struct super_block___86 *);
	int (*show_options)(struct seq_file___63 *, struct dentry___86 *);
	int (*show_devname)(struct seq_file___63 *, struct dentry___86 *);
	int (*show_path)(struct seq_file___63 *, struct dentry___86 *);
	int (*show_stats)(struct seq_file___63 *, struct dentry___86 *);
	ssize_t (*quota_read)(struct super_block___86 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___86 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___86 *);
	int (*bdev_try_to_free_page)(struct super_block___86 *, struct page___85 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___86 *);
	void (*free_cached_objects)(struct super_block___86 *, int);
};

struct proc_ns_operations___4 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___74 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___39 *, void *);
	unsigned int (*inum)(void *);
};

struct pid_cache {
	int nr_ids;
	char name[16];
	struct kmem_cache___65 *cachep;
	struct list_head list;
};

enum {
	RES_USAGE = 0,
	RES_MAX_USAGE = 1,
	RES_LIMIT = 2,
	RES_FAILCNT = 3,
	RES_SOFT_LIMIT = 4,
};

struct cpu_stop_done {
	atomic_t nr_todo;
	bool executed;
	int ret;
	struct completion completion;
};

struct cpu_stopper {
	spinlock_t lock;
	bool enabled;
	struct list_head works;
};

enum multi_stop_state {
	MULTI_STOP_NONE = 0,
	MULTI_STOP_PREPARE = 1,
	MULTI_STOP_DISABLE_IRQ = 2,
	MULTI_STOP_RUN = 3,
	MULTI_STOP_EXIT = 4,
};

struct multi_stop_data {
	int (*fn)(void *);
	void *data;
	unsigned int num_threads;
	const struct cpumask *active_cpus;
	enum multi_stop_state state;
	atomic_t thread_ack;
};

struct page___86;

typedef struct page___86 *pgtable_t___86;

struct address_space___86;

struct kmem_cache___75;

struct page___86 {
	long unsigned int flags;
	struct address_space___86 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___86 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___86 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___75 *slab_cache;
		struct page___86 *first_page;
	};
	long: 64;
};

struct thread_struct___39;

struct task_struct___86;

struct pv_cpu_ops___86 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___86 *);
	void (*end_context_switch)(struct task_struct___86 *);
};

struct perf_event___39;

struct thread_struct___39 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___39 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___43;

struct pid_link___43 {
	struct hlist_node node;
	struct pid___43 *pid;
};

struct mutex___87 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___86 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___82 {
	struct page___86 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___91;

struct nsproxy___44;

struct signal_struct___86;

struct audit_context___3;

struct css_set___54;

struct perf_event_context___39;

struct task_struct___86 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___86 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___91 *mm;
	struct mm_struct___91 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___86 *real_parent;
	struct task_struct___86 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___86 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___86 = 0,
		VTIME_USER___86 = 1,
		VTIME_SYS___86 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___44 *nsproxy;
	struct signal_struct___86 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context___3 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___54 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___39 *perf_event_ctxp[2];
	struct mutex___87 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___82 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___91 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___91 *, struct mm_struct___91 *);
	void (*dup_mmap)(struct mm_struct___91 *, struct mm_struct___91 *);
	void (*exit_mmap)(struct mm_struct___91 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___91 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___91 *);
	void (*pgd_free)(struct mm_struct___91 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___91 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___91 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___91 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___91 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___91 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___91 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___91 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___91 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___91 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___91 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___91 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___87 lock;
	void *vdso;
} mm_context_t___87;

struct xol_area___86;

struct uprobes_state___86 {
	struct xol_area___86 *xol_area;
};

struct vm_area_struct___91;

struct file___86;

struct core_state___86;

struct mm_struct___91 {
	struct vm_area_struct___91 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___91 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___91 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___87 context;
	long unsigned int flags;
	struct core_state___86 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___86 *owner;
	struct file___86 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___86 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___39 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___86 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___86 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___86 *target;
};

typedef void (*perf_overflow_handler_t___39)(struct perf_event___39 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___39;

typedef void (*ftrace_func_t___39)(long unsigned int, long unsigned int, struct ftrace_ops___39 *, struct pt_regs *);

struct ftrace_ops___39 {
	ftrace_func_t___39 func;
	struct ftrace_ops___39 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___87 regex_lock;
};

struct pmu___39;

struct fasync_struct___86;

struct pid_namespace___43;

struct ftrace_event_call___30;

struct perf_cgroup___39;

struct perf_event___39 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___39 *group_leader;
	struct pmu___39 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___39 hw;
	struct perf_event_context___39 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___87 child_mutex;
	struct list_head child_list;
	struct perf_event___39 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___86 *owner;
	struct mutex___87 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___86 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___39 *);
	struct callback_head callback_head;
	struct pid_namespace___43 *ns;
	u64 id;
	perf_overflow_handler_t___39 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___30 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___39 ftrace_ops;
	struct perf_cgroup___39 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___86;

struct lruvec___86 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___86 *zone;
};

struct pglist_data___86;

struct zone___86 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___86 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___86 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___86 {
	struct zone___86 *zone;
	int zone_idx;
};

struct zonelist___86 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___86 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___86 {
	struct zone___86 node_zones[4];
	struct zonelist___86 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___86 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___61;

struct x86_io_apic_ops___61 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___61 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___61;

struct irq_data___61 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___61 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___66;

struct dev_pm_ops___66 {
	int (*prepare)(struct device___66 *);
	void (*complete)(struct device___66 *);
	int (*suspend)(struct device___66 *);
	int (*resume)(struct device___66 *);
	int (*freeze)(struct device___66 *);
	int (*thaw)(struct device___66 *);
	int (*poweroff)(struct device___66 *);
	int (*restore)(struct device___66 *);
	int (*suspend_late)(struct device___66 *);
	int (*resume_early)(struct device___66 *);
	int (*freeze_late)(struct device___66 *);
	int (*thaw_early)(struct device___66 *);
	int (*poweroff_late)(struct device___66 *);
	int (*restore_early)(struct device___66 *);
	int (*suspend_noirq)(struct device___66 *);
	int (*resume_noirq)(struct device___66 *);
	int (*freeze_noirq)(struct device___66 *);
	int (*thaw_noirq)(struct device___66 *);
	int (*poweroff_noirq)(struct device___66 *);
	int (*restore_noirq)(struct device___66 *);
	int (*runtime_suspend)(struct device___66 *);
	int (*runtime_resume)(struct device___66 *);
	int (*runtime_idle)(struct device___66 *);
};

struct kset___4;

struct kobj_type___4;

struct kobject___4 {
	const char *name;
	struct list_head entry;
	struct kobject___4 *parent;
	struct kset___4 *kset;
	struct kobj_type___4 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___8;

struct dev_pm_info___8 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___8 *qos;
};

struct dma_map_ops___30;

struct dev_archdata___30 {
	struct dma_map_ops___30 *dma_ops;
	void *iommu;
};

struct device_type___66;

struct bus_type___66;

struct device_driver___66;

struct dev_pm_domain___66;

struct class___66;

struct attribute_group___59;

struct device_rh___66;

struct device___66 {
	struct device___66 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___66 *type;
	struct mutex___87 mutex;
	struct bus_type___66 *bus;
	struct device_driver___66 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___66 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___30 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___66 *class;
	const struct attribute_group___59 **groups;
	void (*release)(struct device___66 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___66 *device_rh;
};

struct dev_pm_qos_request___8;

struct dev_pm_qos___8 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___8 *latency_req;
	struct dev_pm_qos_request___8 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___8 *latency_tolerance_req;
};

struct dev_pm_info_rh___66 {
	void (*set_latency_tolerance)(struct device___66 *, s32);
};

struct dev_pm_domain___66 {
	struct dev_pm_ops___66 ops;
};

struct smp_ops___86 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___86 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___86 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___86 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___75;

struct memcg_cache_params___75;

struct kmem_cache___75 {
	struct kmem_cache_cpu___75 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___75 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___87;

struct address_space_operations___86;

struct address_space___86 {
	struct inode___87 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___87 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___86 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___87;

struct path___86 {
	struct vfsmount *mnt;
	struct dentry___87 *dentry;
};

struct fown_struct___43 {
	rwlock_t lock;
	struct pid___43 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___86;

struct file___86 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___86 f_path;
	struct inode___87 *f_inode;
	const struct file_operations___86 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___86 *f_mapping;
	struct mutex___87 f_pos_lock;
};

struct vm_operations_struct___74;

struct vm_area_struct___91 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___91 *vm_next;
	struct vm_area_struct___91 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___91 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___74 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___86 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___71;

struct vm_operations_struct___74 {
	void (*open)(struct vm_area_struct___91 *);
	void (*close)(struct vm_area_struct___91 *);
	int (*fault)(struct vm_area_struct___91 *, struct vm_fault___71 *);
	int (*page_mkwrite)(struct vm_area_struct___91 *, struct vm_fault___71 *);
	int (*access)(struct vm_area_struct___91 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___91 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___91 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___91 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___91 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___86 {
	struct task_struct___86 *task;
	struct core_thread___86 *next;
};

struct core_state___86 {
	atomic_t nr_threads;
	struct core_thread___86 dumper;
	struct completion startup;
};

struct vm_fault___71 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___86 *page;
};

struct sock___5;

struct kobj_ns_type_operations___4 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___5 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___4;

struct net___13;

struct sock_common___4 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___4 *skc_prot;
	struct net___13 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___8;

struct sk_buff_head___6 {
	struct sk_buff___8 *next;
	struct sk_buff___8 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___5;

struct socket_wq___4;

struct dst_entry___4;

struct socket___4;

struct cg_proto___4;

struct sock___5 {
	struct sock_common___4 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___6 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___8 *head;
		struct sk_buff___8 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___5 *sk_filter;
	struct socket_wq___4 *sk_wq;
	struct sk_buff_head___6 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___4 *sk_rx_dst;
	struct dst_entry___4 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___6 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___6 sk_error_queue;
	struct proto___4 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___43 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___4 *sk_socket;
	void *sk_user_data;
	struct page_frag___82 sk_frag;
	struct sk_buff___8 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___4 *sk_cgrp;
	void (*sk_state_change)(struct sock___5 *);
	void (*sk_data_ready)(struct sock___5 *, int);
	void (*sk_write_space)(struct sock___5 *);
	void (*sk_error_report)(struct sock___5 *);
	int (*sk_backlog_rcv)(struct sock___5 *, struct sk_buff___8 *);
	void (*sk_destruct)(struct sock___5 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___59;

struct attribute_group___59 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___59 **bin_attrs;
};

struct bin_attribute___59 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___86 *, struct kobject___4 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___86 *, struct kobject___4 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	int (*mmap)(struct file___86 *, struct kobject___4 *, struct bin_attribute___59 *, struct vm_area_struct___91 *);
};

struct sysfs_ops___4 {
	ssize_t (*show)(struct kobject___4 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___4 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___4 *, const struct attribute *);
};

struct kset_uevent_ops___4;

struct kset___4 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___4 kobj;
	const struct kset_uevent_ops___4 *uevent_ops;
};

struct kobj_type___4 {
	void (*release)(struct kobject___4 *);
	const struct sysfs_ops___4 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___4 *);
	const void * (*namespace)(struct kobject___4 *);
};

struct kset_uevent_ops___4 {
	int (* const filter)(struct kset___4 *, struct kobject___4 *);
	const char * (* const name)(struct kset___4 *, struct kobject___4 *);
	int (* const uevent)(struct kset___4 *, struct kobject___4 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___75 {
	void **freelist;
	long unsigned int tid;
	struct page___86 *page;
	struct page___86 *partial;
};

struct memcg_cache_params___75 {
	bool is_root_cache;
	union {
		struct kmem_cache___75 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___75 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cpu_vfs_cap_data {
	__u32 magic_etc;
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
};

struct upid___43 {
	int nr;
	struct pid_namespace___43 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___43 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___86 *child_reaper;
	struct kmem_cache___75 *pid_cachep;
	unsigned int level;
	struct pid_namespace___43 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___87 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___43 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___43 numbers[1];
};

struct ctl_table_header___12;

struct ctl_node___12 {
	struct rb_node node;
	struct ctl_table_header___12 *header;
};

struct ctl_table_root___12;

struct ctl_table_set___12;

struct ctl_dir___12;

struct ctl_table_header___12 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___12 *root;
	struct ctl_table_set___12 *set;
	struct ctl_dir___12 *parent;
	struct ctl_node___12 *node;
};

struct ctl_dir___12 {
	struct ctl_table_header___12 header;
	struct rb_root root;
};

struct ctl_table_set___12 {
	int (*is_seen)(struct ctl_table_set___12 *);
	struct ctl_dir___12 dir;
};

struct ctl_table_root___12 {
	struct ctl_table_set___12 default_set;
	struct ctl_table_set___12 * (*lookup)(struct ctl_table_root___12 *, struct nsproxy___44 *);
	int (*permissions)(struct ctl_table_header___12 *, struct ctl_table *);
};

struct nsproxy___44 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___43 *pid_ns;
	struct net___13 *net_ns;
};

struct tty_struct___7;

struct signal_struct___86 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___86 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___86 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct___7 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___87 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___7;

struct tty_operations___7;

struct tty_ldisc___7;

struct tty_port___7;

struct tty_struct___7 {
	int magic;
	struct kref kref;
	struct device___66 *dev;
	struct tty_driver___7 *driver;
	const struct tty_operations___7 *ops;
	int index;
	struct mutex___87 ldisc_mutex;
	struct tty_ldisc___7 *ldisc;
	struct mutex___87 atomic_write_lock;
	struct mutex___87 legacy_mutex;
	struct mutex___87 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___43 *pgrp;
	struct pid___43 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___7 *link;
	struct fasync_struct___86 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___7 *port;
	struct ld_semaphore ldisc_sem;
};

struct audit_context___3 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___86 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
	};
	int fds[2];
};

struct cgroup_subsys_state___54;

struct css_set___54 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___54 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___39 {
	struct pmu___39 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___87 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___86 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___39 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct super_block___87;

struct dquot___86 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___87 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___87 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___86;

struct mem_dqinfo___86 {
	struct quota_format_type___86 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___86;

struct quota_info___86 {
	unsigned int flags;
	struct mutex___87 dqio_mutex;
	struct mutex___87 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___87 *files[2];
	struct mem_dqinfo___86 info[2];
	const struct quota_format_ops___86 *ops[2];
};

struct file_system_type___86;

struct super_operations___86;

struct dquot_operations___86;

struct quotactl_ops___86;

struct xattr_handler___54;

struct block_device___86;

struct dentry_operations___86;

struct super_block___87 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___86 *s_type;
	const struct super_operations___86 *s_op;
	const struct dquot_operations___86 *dq_op;
	const struct quotactl_ops___86 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___87 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___54 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___86 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___86 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___87 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___86 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___86 {
	int qf_fmt_id;
	const struct quota_format_ops___86 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___86 *qf_next;
};

struct quota_format_ops___86 {
	int (*check_quota_file)(struct super_block___87 *, int);
	int (*read_file_info)(struct super_block___87 *, int);
	int (*write_file_info)(struct super_block___87 *, int);
	int (*free_file_info)(struct super_block___87 *, int);
	int (*read_dqblk)(struct dquot___86 *);
	int (*commit_dqblk)(struct dquot___86 *);
	int (*release_dqblk)(struct dquot___86 *);
};

struct dquot_operations___86 {
	int (*write_dquot)(struct dquot___86 *);
	struct dquot___86 * (*alloc_dquot)(struct super_block___87 *, int);
	void (*destroy_dquot)(struct dquot___86 *);
	int (*acquire_dquot)(struct dquot___86 *);
	int (*release_dquot)(struct dquot___86 *);
	int (*mark_dirty)(struct dquot___86 *);
	int (*write_info)(struct super_block___87 *, int);
	qsize_t * (*get_reserved_space)(struct inode___87 *);
};

struct inode_operations___86;

struct file_lock___86;

struct cdev___31;

struct inode___87 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___86 *i_op;
	struct super_block___87 *i_sb;
	struct address_space___86 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___87 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___86 *i_fop;
	struct file_lock___86 *i_flock;
	struct address_space___86 i_data;
	struct dquot___86 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___86 *i_bdev;
		struct cdev___31 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___86 {
	int (*quota_on)(struct super_block___87 *, int, int, struct path___86 *);
	int (*quota_on_meta)(struct super_block___87 *, int, int);
	int (*quota_off)(struct super_block___87 *, int);
	int (*quota_sync)(struct super_block___87 *, int);
	int (*get_info)(struct super_block___87 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___87 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___87 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___87 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___87 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___87 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___87 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___87 *, unsigned int);
};

struct seq_operations___63;

struct seq_file___64 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___87 lock;
	const struct seq_operations___63 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___63 {
	void * (*start)(struct seq_file___64 *, loff_t *);
	void (*stop)(struct seq_file___64 *, void *);
	void * (*next)(struct seq_file___64 *, void *, loff_t *);
	int (*show)(struct seq_file___64 *, void *);
};

struct dentry___87 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___87 *d_parent;
	struct qstr d_name;
	struct inode___87 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___86 *d_op;
	struct super_block___87 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___86 {
	int (*d_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_hash)(const struct dentry___87 *, struct qstr *);
	int (*d_compare)(const struct dentry___87 *, const struct dentry___87 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___87 *);
	void (*d_release)(struct dentry___87 *);
	void (*d_prune)(struct dentry___87 *);
	void (*d_iput)(struct dentry___87 *, struct inode___87 *);
	char * (*d_dname)(struct dentry___87 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___86 *);
	int (*d_manage)(struct dentry___87 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___86 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___87 *bd_inode;
	struct super_block___87 *bd_super;
	struct mutex___87 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___86 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___87 bd_fsfreeze_mutex;
};

struct cgroup___54;

struct cgroup_subsys_state___54 {
	struct cgroup___54 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___5;

typedef int kiocb_cancel_fn___5(struct kiocb___5 *, struct io_event *);

struct kiocb___5 {
	atomic_t ki_users;
	struct file___86 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___5 *ki_cancel;
	void (*ki_dtor)(struct kiocb___5 *);
	union {
		void *user;
		struct task_struct___86 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___87 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___86 *ia_file;
};

struct address_space_operations___86 {
	int (*writepage)(struct page___86 *, struct writeback_control *);
	int (*readpage)(struct file___86 *, struct page___86 *);
	int (*writepages)(struct address_space___86 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___86 *);
	int (*readpages)(struct file___86 *, struct address_space___86 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___86 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___86 **, void **);
	int (*write_end)(struct file___86 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___86 *, void *);
	sector_t (*bmap)(struct address_space___86 *, sector_t);
	void (*invalidatepage)(struct page___86 *, long unsigned int);
	int (*releasepage)(struct page___86 *, gfp_t);
	void (*freepage)(struct page___86 *);
	ssize_t (*direct_IO)(int, struct kiocb___5 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___86 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___86 *, struct page___86 *, struct page___86 *, enum migrate_mode);
	int (*launder_page)(struct page___86 *);
	int (*is_partially_uptodate)(struct page___86 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___86 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___86 *, struct page___86 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___86 *, sector_t *);
	void (*swap_deactivate)(struct file___86 *);
	void (*invalidatepage_range)(struct page___86 *, unsigned int, unsigned int);
};

struct cdev___31 {
	struct kobject___4 kobj;
	struct module *owner;
	const struct file_operations___86 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___86 {
	struct dentry___87 * (*lookup)(struct inode___87 *, struct dentry___87 *, unsigned int);
	void * (*follow_link)(struct dentry___87 *, struct nameidata *);
	int (*permission)(struct inode___87 *, int);
	struct posix_acl * (*get_acl)(struct inode___87 *, int);
	int (*readlink)(struct dentry___87 *, char *, int);
	void (*put_link)(struct dentry___87 *, struct nameidata *, void *);
	int (*create)(struct inode___87 *, struct dentry___87 *, umode_t, bool);
	int (*link)(struct dentry___87 *, struct inode___87 *, struct dentry___87 *);
	int (*unlink)(struct inode___87 *, struct dentry___87 *);
	int (*symlink)(struct inode___87 *, struct dentry___87 *, const char *);
	int (*mkdir)(struct inode___87 *, struct dentry___87 *, umode_t);
	int (*rmdir)(struct inode___87 *, struct dentry___87 *);
	int (*mknod)(struct inode___87 *, struct dentry___87 *, umode_t, dev_t);
	int (*rename)(struct inode___87 *, struct dentry___87 *, struct inode___87 *, struct dentry___87 *);
	int (*setattr)(struct dentry___87 *, struct iattr___87 *);
	int (*getattr)(struct vfsmount *, struct dentry___87 *, struct kstat *);
	int (*setxattr)(struct dentry___87 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___87 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___87 *, char *, size_t);
	int (*removexattr)(struct dentry___87 *, const char *);
	int (*fiemap)(struct inode___87 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___87 *, struct timespec *, int);
	int (*atomic_open)(struct inode___87 *, struct dentry___87 *, struct file___86 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___52;

struct file_operations___86 {
	struct module *owner;
	loff_t (*llseek)(struct file___86 *, loff_t, int);
	ssize_t (*read)(struct file___86 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___86 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___5 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___5 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___86 *, void *, filldir_t);
	unsigned int (*poll)(struct file___86 *, struct poll_table_struct___52 *);
	long int (*unlocked_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___86 *, struct vm_area_struct___91 *);
	int (*open)(struct inode___87 *, struct file___86 *);
	int (*flush)(struct file___86 *, fl_owner_t);
	int (*release)(struct inode___87 *, struct file___86 *);
	int (*fsync)(struct file___86 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___5 *, int);
	int (*fasync)(int, struct file___86 *, int);
	int (*lock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*sendpage)(struct file___86 *, struct page___86 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___86 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___86 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___86 *, long int, struct file_lock___86 **, void **);
		struct {
			int (*setlease)(struct file___86 *, long int, struct file_lock___86 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___86 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___64 *, struct file___86 *);
};

struct file_lock_operations___86;

struct lock_manager_operations___86;

struct file_lock___86 {
	struct file_lock___86 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___86 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___86 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___86 *fl_ops;
	const struct lock_manager_operations___86 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___86 {
	void (*fl_copy_lock)(struct file_lock___86 *, struct file_lock___86 *);
	void (*fl_release_private)(struct file_lock___86 *);
};

struct lock_manager_operations___86 {
	int (*lm_compare_owner)(struct file_lock___86 *, struct file_lock___86 *);
	long unsigned int (*lm_owner_key)(struct file_lock___86 *);
	void (*lm_notify)(struct file_lock___86 *);
	int (*lm_grant)(struct file_lock___86 *, struct file_lock___86 *, int);
	void (*lm_break)(struct file_lock___86 *);
	int (*lm_change)(struct file_lock___86 **, int);
};

struct fasync_struct___86 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___86 *fa_next;
	struct file___86 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___86 {
	const char *name;
	int fs_flags;
	struct dentry___87 * (*mount)(struct file_system_type___86 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___87 *);
	struct module *owner;
	struct file_system_type___86 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___86 {
	struct inode___87 * (*alloc_inode)(struct super_block___87 *);
	void (*destroy_inode)(struct inode___87 *);
	void (*dirty_inode)(struct inode___87 *, int);
	int (*write_inode)(struct inode___87 *, struct writeback_control *);
	int (*drop_inode)(struct inode___87 *);
	void (*evict_inode)(struct inode___87 *);
	void (*put_super)(struct super_block___87 *);
	int (*sync_fs)(struct super_block___87 *, int);
	int (*freeze_fs)(struct super_block___87 *);
	int (*unfreeze_fs)(struct super_block___87 *);
	int (*statfs)(struct dentry___87 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___87 *, int *, char *);
	void (*umount_begin)(struct super_block___87 *);
	int (*show_options)(struct seq_file___64 *, struct dentry___87 *);
	int (*show_devname)(struct seq_file___64 *, struct dentry___87 *);
	int (*show_path)(struct seq_file___64 *, struct dentry___87 *);
	int (*show_stats)(struct seq_file___64 *, struct dentry___87 *);
	ssize_t (*quota_read)(struct super_block___87 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___87 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___87 *);
	int (*bdev_try_to_free_page)(struct super_block___87 *, struct page___86 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___87 *);
	void (*free_cached_objects)(struct super_block___87 *, int);
};

struct xattr_handler___54 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___87 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___87 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___87 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___52)(struct file___86 *, wait_queue_head_t *, struct poll_table_struct___52 *);

struct poll_table_struct___52 {
	poll_queue_proc___52 _qproc;
	long unsigned int _key;
};

struct irq_chip___61 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___61 *);
	void (*irq_shutdown)(struct irq_data___61 *);
	void (*irq_enable)(struct irq_data___61 *);
	void (*irq_disable)(struct irq_data___61 *);
	void (*irq_ack)(struct irq_data___61 *);
	void (*irq_mask)(struct irq_data___61 *);
	void (*irq_mask_ack)(struct irq_data___61 *);
	void (*irq_unmask)(struct irq_data___61 *);
	void (*irq_eoi)(struct irq_data___61 *);
	int (*irq_set_affinity)(struct irq_data___61 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___61 *);
	int (*irq_set_type)(struct irq_data___61 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___61 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___61 *);
	void (*irq_bus_sync_unlock)(struct irq_data___61 *);
	void (*irq_cpu_online)(struct irq_data___61 *);
	void (*irq_cpu_offline)(struct irq_data___61 *);
	void (*irq_suspend)(struct irq_data___61 *);
	void (*irq_resume)(struct irq_data___61 *);
	void (*irq_pm_shutdown)(struct irq_data___61 *);
	void (*irq_print_chip)(struct irq_data___61 *, struct seq_file___64 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___61 *, void *);
	long unsigned int flags;
};

struct netns_core___12 {
	struct ctl_table_header___12 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___12 {
	struct mutex___87 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___12 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___12 *ctl;
};

struct netns_ipv4___12 {
	struct ctl_table_header___12 *forw_hdr;
	struct ctl_table_header___12 *frags_hdr;
	struct ctl_table_header___12 *ipv4_hdr;
	struct ctl_table_header___12 *route_hdr;
	struct ctl_table_header___12 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___5 *fibnl;
	struct sock___5 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___12 {
	struct ctl_table_header___12 *hdr;
	struct ctl_table_header___12 *route_hdr;
	struct ctl_table_header___12 *icmp_hdr;
	struct ctl_table_header___12 *frags_hdr;
	struct ctl_table_header___12 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___7;

struct neighbour___4;

struct dst_ops___12 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___12 *);
	struct dst_entry___4 * (*check)(struct dst_entry___4 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___4 *);
	unsigned int (*mtu)(const struct dst_entry___4 *);
	u32 * (*cow_metrics)(struct dst_entry___4 *, long unsigned int);
	void (*destroy)(struct dst_entry___4 *);
	void (*ifdown)(struct dst_entry___4 *, struct net_device___7 *, int);
	struct dst_entry___4 * (*negative_advice)(struct dst_entry___4 *);
	void (*link_failure)(struct sk_buff___8 *);
	void (*update_pmtu)(struct dst_entry___4 *, struct sock___5 *, struct sk_buff___8 *, u32);
	void (*redirect)(struct dst_entry___4 *, struct sock___5 *, struct sk_buff___8 *);
	int (*local_out)(struct sk_buff___8 *);
	struct neighbour___4 * (*neigh_lookup)(const struct dst_entry___4 *, struct sk_buff___8 *, const void *);
	struct kmem_cache___75 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___12 {
	struct netns_sysctl_ipv6___12 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___12 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___5 **icmp_sk;
	struct sock___5 *ndisc_sk;
	struct sock___5 *tcp_sk;
	struct sock___5 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___12 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___12 *sysctl_header;
	struct sock___5 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___4 {
	struct sock___5 *v4_ctl_sk;
	struct sock___5 *v6_ctl_sk;
};

struct netns_nf___12 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___12 *nf_log_dir_header;
};

struct nf_proto_net___12 {
	struct ctl_table_header___12 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___12 {
	struct nf_proto_net___12 pn;
	unsigned int timeout;
};

struct nf_tcp_net___12 {
	struct nf_proto_net___12 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___12 {
	struct nf_proto_net___12 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___12 {
	struct nf_proto_net___12 pn;
	unsigned int timeout;
};

struct nf_ip_net___12 {
	struct nf_generic_net___12 generic;
	struct nf_tcp_net___12 tcp;
	struct nf_udp_net___12 udp;
	struct nf_icmp_net___12 icmp;
	struct nf_icmp_net___12 icmpv6;
};

struct netns_ct___12 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___12 *sysctl_header;
	struct ctl_table_header___12 *acct_sysctl_header;
	struct ctl_table_header___12 *tstamp_sysctl_header;
	struct ctl_table_header___12 *event_sysctl_header;
	struct ctl_table_header___12 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___75 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___12 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___12 {
	struct netns_sysctl_ipv6___12 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___12 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___5 *nlsk;
	struct sock___5 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___12 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___12 xfrm4_dst_ops;
	struct dst_ops___12 xfrm6_dst_ops;
};

struct net___13 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___12 sysctls;
	struct sock___5 *rtnl;
	struct sock___5 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___7 *loopback_dev;
	struct netns_core___12 core;
	struct netns_mib mib;
	struct netns_packet___12 packet;
	struct netns_unix___12 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___12 ipv4;
	struct netns_ipv6___12 ipv6;
	struct netns_sctp___12 sctp;
	struct netns_dccp___4 dccp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct___12 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___12 nf_frag;
	struct sock___5 *nfnl;
	struct sock___5 *nfnl_stash;
	struct sk_buff_head___6 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___12 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___5 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___5 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___87 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___87 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___30 {
	void * (*alloc)(struct device___66 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___66 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___66 *, struct vm_area_struct___91 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___66 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___66 *, struct page___86 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___66 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___66 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___66 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___66 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___66 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___66 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___66 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___66 *, dma_addr_t);
	int (*dma_supported)(struct device___66 *, u64);
	int (*set_dma_mask)(struct device___66 *, u64);
	int is_phys;
};

struct bus_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___66 *, char *);
	ssize_t (*store)(struct bus_type___66 *, const char *, size_t);
};

struct device_attribute___66;

struct driver_attribute___66;

struct bus_type___66 {
	const char *name;
	const char *dev_name;
	struct device___66 *dev_root;
	struct bus_attribute___66 *bus_attrs;
	struct device_attribute___66 *dev_attrs;
	struct driver_attribute___66 *drv_attrs;
	const struct attribute_group___59 **bus_groups;
	const struct attribute_group___59 **dev_groups;
	const struct attribute_group___59 **drv_groups;
	int (*match)(struct device___66 *, struct device_driver___66 *);
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	int (*probe)(struct device___66 *);
	int (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*online)(struct device___66 *);
	int (*offline)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct device___66 *, struct device_attribute___66 *, char *);
	ssize_t (*store)(struct device___66 *, struct device_attribute___66 *, const char *, size_t);
};

struct driver_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___66 *, char *);
	ssize_t (*store)(struct device_driver___66 *, const char *, size_t);
};

struct device_driver___66 {
	const char *name;
	struct bus_type___66 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___66 *);
	int (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	const struct attribute_group___59 **groups;
	const struct dev_pm_ops___66 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___66 {
	const char *name;
	const struct attribute_group___59 **groups;
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
};

struct class_attribute___66;

struct class___66 {
	const char *name;
	struct module *owner;
	struct class_attribute___66 *class_attrs;
	struct device_attribute___66 *dev_attrs;
	const struct attribute_group___59 **dev_groups;
	struct bin_attribute___59 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *);
	void (*class_release)(struct class___66 *);
	void (*dev_release)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
	struct subsys_private *p;
};

struct class_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct class___66 *, struct class_attribute___66 *, char *);
	ssize_t (*store)(struct class___66 *, struct class_attribute___66 *, const char *, size_t);
	const void * (*namespace)(struct class___66 *, const struct class_attribute___66 *);
};

struct device_rh___66 {
	struct dev_pm_info_rh___66 power;
};

struct cgroupfs_root___54;

struct cgroup___54 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___54 *parent;
	struct dentry___87 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___54 *subsys[11];
	struct cgroupfs_root___54 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___87 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___54 {
	struct super_block___87 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___54 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___23 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___87 *, struct file___86 *);
	ssize_t (*read)(struct cgroup___54 *, struct cftype___23 *, struct file___86 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___54 *, struct cftype___23 *);
	s64 (*read_s64)(struct cgroup___54 *, struct cftype___23 *);
	int (*read_map)(struct cgroup___54 *, struct cftype___23 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___54 *, struct cftype___23 *, struct seq_file___64 *);
	ssize_t (*write)(struct cgroup___54 *, struct cftype___23 *, struct file___86 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___54 *, struct cftype___23 *, u64);
	int (*write_s64)(struct cgroup___54 *, struct cftype___23 *, s64);
	int (*write_string)(struct cgroup___54 *, struct cftype___23 *, const char *);
	int (*trigger)(struct cgroup___54 *, unsigned int);
	int (*release)(struct inode___87 *, struct file___86 *);
	int (*register_event)(struct cgroup___54 *, struct cftype___23 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___54 *, struct cftype___23 *, struct eventfd_ctx *);
};

struct cftype_set___21 {
	struct list_head node;
	struct cftype___23 *cfts;
};

struct task_and_cgroup___21 {
	struct task_struct___86 *task;
	struct cgroup___54 *cgrp;
	struct css_set___54 *cg;
};

struct cgroup_taskset___21 {
	struct task_and_cgroup___21 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___54 *cur_cgrp;
};

struct cgroup_subsys___21 {
	struct cgroup_subsys_state___54 * (*css_alloc)(struct cgroup___54 *);
	int (*css_online)(struct cgroup___54 *);
	void (*css_offline)(struct cgroup___54 *);
	void (*css_free)(struct cgroup___54 *);
	int (*can_attach)(struct cgroup___54 *, struct cgroup_taskset___21 *);
	void (*cancel_attach)(struct cgroup___54 *, struct cgroup_taskset___21 *);
	void (*attach)(struct cgroup___54 *, struct cgroup_taskset___21 *);
	void (*fork)(struct task_struct___86 *);
	void (*exit)(struct cgroup___54 *, struct cgroup___54 *, struct task_struct___86 *);
	void (*bind)(struct cgroup___54 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___54 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___23 *base_cftypes;
	struct cftype_set___21 base_cftset;
	struct module *module;
};

struct perf_cpu_context___39;

struct pmu___39 {
	struct list_head entry;
	struct device___66 *dev;
	const struct attribute_group___59 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___39 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___39 *);
	void (*pmu_disable)(struct pmu___39 *);
	int (*event_init)(struct perf_event___39 *);
	int (*add)(struct perf_event___39 *, int);
	void (*del)(struct perf_event___39 *, int);
	void (*start)(struct perf_event___39 *, int);
	void (*stop)(struct perf_event___39 *, int);
	void (*read)(struct perf_event___39 *);
	void (*start_txn)(struct pmu___39 *);
	int (*commit_txn)(struct pmu___39 *);
	void (*cancel_txn)(struct pmu___39 *);
	int (*event_idx)(struct perf_event___39 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___39 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___39 *);
};

struct perf_cpu_context___39 {
	struct perf_event_context___39 ctx;
	struct perf_event_context___39 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___39 *unique_pmu;
	struct perf_cgroup___39 *cgrp;
};

struct trace_event_functions___30;

struct trace_event___30 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___30 *funcs;
};

struct ftrace_event_class___30;

struct ftrace_event_call___30 {
	struct list_head list;
	struct ftrace_event_class___30 *class;
	char *name;
	struct trace_event___30 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___39 {
	struct cgroup_subsys_state___54 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___30 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___87 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___30)(struct trace_iterator___30 *, int, struct trace_event___30 *);

struct trace_event_functions___30 {
	trace_print_func___30 trace;
	trace_print_func___30 raw;
	trace_print_func___30 hex;
	trace_print_func___30 binary;
};

struct ftrace_event_class___30 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___30 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___30 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___30 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___30 *);
};

struct audit_status {
	__u32 mask;
	__u32 enabled;
	__u32 failure;
	__u32 pid;
	__u32 rate_limit;
	__u32 backlog_limit;
	__u32 lost;
	__u32 backlog;
	union {
		__u32 version;
		__u32 feature_bitmap;
	};
};

struct audit_features {
	__u32 vers;
	__u32 mask;
	__u32 features;
	__u32 lock;
};

struct audit_tty_status {
	__u32 enabled;
	__u32 log_passwd;
};

struct audit_sig_info {
	uid_t uid;
	pid_t pid;
	char ctx[0];
};

struct dev_pm_qos_request___8 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___66 *dev;
};

struct socket_wq___4 {
	wait_queue_head_t wait;
	struct fasync_struct___86 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___4;

struct socket___4 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___4 *wq;
	struct file___86 *file;
	struct sock___5 *sk;
	const struct proto_ops___4 *ops;
};

struct proto_ops___4 {
	int family;
	struct module *owner;
	int (*release)(struct socket___4 *);
	int (*bind)(struct socket___4 *, struct sockaddr *, int);
	int (*connect)(struct socket___4 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___4 *, struct socket___4 *);
	int (*accept)(struct socket___4 *, struct socket___4 *, int);
	int (*getname)(struct socket___4 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___86 *, struct socket___4 *, struct poll_table_struct___52 *);
	int (*ioctl)(struct socket___4 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___4 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___4 *, int);
	int (*shutdown)(struct socket___4 *, int);
	int (*setsockopt)(struct socket___4 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___4 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___4 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___4 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___5 *, struct socket___4 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___5 *, struct socket___4 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___86 *, struct socket___4 *, struct vm_area_struct___91 *);
	ssize_t (*sendpage)(struct socket___4 *, struct page___86 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___4 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___5 *, int);
		struct {
			void (*set_peek_off)(struct sock___5 *, int);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
};

struct nf_bridge_info___5 {
	atomic_t use;
	unsigned int mask;
	struct net_device___7 *physindev;
	struct net_device___7 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___5(struct sk_buff___8 **);

struct net_device_ops___5;

struct ethtool_ops___5;

struct header_ops___5;

struct netdev_rx_queue___5;

struct netdev_queue___5;

struct rtnl_link_ops___4;

struct dcbnl_rtnl_ops___5;

struct net_device___7 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___5 *netdev_ops;
	const struct ethtool_ops___5 *ethtool_ops;
	const struct header_ops___5 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___4 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___5 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___5 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___5 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___5 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___5 = 0,
		NETREG_REGISTERED___5 = 1,
		NETREG_UNREGISTERING___5 = 2,
		NETREG_UNREGISTERED___5 = 3,
		NETREG_RELEASED___5 = 4,
		NETREG_DUMMY___5 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___5 = 0,
		RTNL_LINK_INITIALIZING___5 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___7 *);
	struct netpoll_info *npinfo;
	struct net___13 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide22;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___66 dev;
	const struct attribute_group___59 *sysfs_groups[4];
	const struct rtnl_link_ops___4 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___5 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___8 {
	struct sk_buff___8 *next;
	struct sk_buff___8 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___5 *sk;
	struct net_device___7 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___8 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___5 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___5 {
	int (*get_settings)(struct net_device___7 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___7 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___7 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___7 *);
	void (*get_regs)(struct net_device___7 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___7 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___7 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___7 *);
	void (*set_msglevel)(struct net_device___7 *, u32);
	int (*nway_reset)(struct net_device___7 *);
	u32 (*get_link)(struct net_device___7 *);
	int (*get_eeprom_len)(struct net_device___7 *);
	int (*get_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___7 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___7 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___7 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___7 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___7 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___7 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___7 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___7 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___7 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___7 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___7 *);
	void (*complete)(struct net_device___7 *);
	u32 (*get_priv_flags)(struct net_device___7 *);
	int (*set_priv_flags)(struct net_device___7 *, u32);
	int (*get_sset_count)(struct net_device___7 *, int);
	int (*get_rxnfc)(struct net_device___7 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___7 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___7 *, struct ethtool_flash *);
	int (*reset)(struct net_device___7 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___7 *);
	int (*get_rxfh_indir)(struct net_device___7 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___7 *, const u32 *);
	void (*get_channels)(struct net_device___7 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___7 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___7 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___7 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___7 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___7 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___7 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___7 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___7 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___7 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___7 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___7 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___4 {
	struct callback_head callback_head;
	struct dst_entry___4 *child;
	struct net_device___7 *dev;
	struct dst_ops___12 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___4 *path;
	struct dst_entry___4 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___8 *);
	union {
		int (*output)(struct sock___5 *, struct sk_buff___8 *);
		struct {
			int (*output)(struct sk_buff___8 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___4 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___4;

struct neigh_parms___4;

struct neigh_ops___4;

struct neighbour___4 {
	struct neighbour___4 *next;
	struct neigh_table___4 *tbl;
	struct neigh_parms___4 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___6 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___4 *, struct sk_buff___8 *);
	const struct neigh_ops___4 *ops;
	struct callback_head rcu;
	struct net_device___7 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___12 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___8 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___8 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___13 *, struct dst_entry___4 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___8 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___8 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___5 {
	int (*ieee_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___7 *);
	u8 (*setstate)(struct net_device___7 *, u8);
	void (*getpermhwaddr)(struct net_device___7 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___7 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___7 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___7 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___7 *, int, u8 *);
	void (*setpfccfg)(struct net_device___7 *, int, u8);
	void (*getpfccfg)(struct net_device___7 *, int, u8 *);
	u8 (*setall)(struct net_device___7 *);
	u8 (*getcap)(struct net_device___7 *, int, u8 *);
	int (*getnumtcs)(struct net_device___7 *, int, u8 *);
	int (*setnumtcs)(struct net_device___7 *, int, u8);
	u8 (*getpfcstate)(struct net_device___7 *);
	void (*setpfcstate)(struct net_device___7 *, u8);
	void (*getbcncfg)(struct net_device___7 *, int, u32 *);
	void (*setbcncfg)(struct net_device___7 *, int, u32);
	void (*getbcnrp)(struct net_device___7 *, int, u8 *);
	void (*setbcnrp)(struct net_device___7 *, int, u8);
	u8 (*setapp)(struct net_device___7 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___7 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___7 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___7 *, int, u8);
	u8 (*getdcbx)(struct net_device___7 *);
	u8 (*setdcbx)(struct net_device___7 *, u8);
	int (*peer_getappinfo)(struct net_device___7 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___7 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___7 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___7 *, struct cee_pfc *);
};

struct scm_creds {
	u32 pid;
	kuid_t uid;
	kgid_t gid;
};

struct netlink_skb_parms {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___5 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___8 *);
	struct mutex___87 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___13 *, struct sock___5 *);
};

struct netlink_callback___5 {
	struct sk_buff___8 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___8 *, struct netlink_callback___5 *);
	int (*done)(struct netlink_callback___5 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___5 {
	int (*create)(struct sk_buff___8 *, struct net_device___7 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___8 *, unsigned char *);
	int (*rebuild)(struct sk_buff___8 *);
	int (*cache)(const struct neighbour___4 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___7 *, const unsigned char *);
};

struct napi_struct___5 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___5 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___7 *dev;
	struct sk_buff___8 *gro_list;
	struct sk_buff___8 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___5 {
	struct net_device___7 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___4 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___5 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___4 kobj;
	struct net_device___7 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___5 {
	int (*ndo_init)(struct net_device___7 *);
	void (*ndo_uninit)(struct net_device___7 *);
	int (*ndo_open)(struct net_device___7 *);
	int (*ndo_stop)(struct net_device___7 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___8 *, struct net_device___7 *);
	u16 (*ndo_select_queue)(struct net_device___7 *, struct sk_buff___8 *);
	void (*ndo_change_rx_flags)(struct net_device___7 *, int);
	void (*ndo_set_rx_mode)(struct net_device___7 *);
	int (*ndo_set_mac_address)(struct net_device___7 *, void *);
	int (*ndo_validate_addr)(struct net_device___7 *);
	int (*ndo_do_ioctl)(struct net_device___7 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___7 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___7 *, int);
	int (*ndo_neigh_setup)(struct net_device___7 *, struct neigh_parms___4 *);
	void (*ndo_tx_timeout)(struct net_device___7 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___7 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___7 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___7 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___7 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___7 *);
	int (*ndo_netpoll_setup)(struct net_device___7 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___7 *);
	int (*ndo_busy_poll)(struct napi_struct___5 *);
	int (*ndo_set_vf_mac)(struct net_device___7 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___7 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___7 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___7 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___7 *, int, struct ifla_vf_info___2 *);
	int (*ndo_set_vf_link_state)(struct net_device___7 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___7 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___7 *, int, struct sk_buff___8 *);
	int (*ndo_setup_tc)(struct net_device___7 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___7 *);
	int (*ndo_fcoe_disable)(struct net_device___7 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___7 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___7 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___7 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___7 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___7 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___7 *, const struct sk_buff___8 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___7 *, struct net_device___7 *);
	int (*ndo_del_slave)(struct net_device___7 *, struct net_device___7 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___4 *);
	void (*ndo_neigh_destroy)(struct neighbour___4 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___8 *, struct netlink_callback___5 *, struct net_device___7 *, int);
	int (*ndo_bridge_setlink)(struct net_device___7 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___8 *, u32, u32, struct net_device___7 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___7 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___7 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___7 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___7 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___7 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___7 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___8 *, struct net_device___7 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___7 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___7 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___7 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___4 {
	struct net___13 *net;
	struct net_device___7 *dev;
	struct neigh_parms___4 *next;
	int (*neigh_setup)(struct neighbour___4 *);
	void (*neigh_cleanup)(struct neighbour___4 *);
	struct neigh_table___4 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___4 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___7 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___13 *, struct net_device___7 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___7 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___7 *, struct list_head *);
	size_t (*get_size)(const struct net_device___7 *);
	int (*fill_info)(struct sk_buff___8 *, const struct net_device___7 *);
	size_t (*get_xstats_size)(const struct net_device___7 *);
	int (*fill_xstats)(struct sk_buff___8 *, const struct net_device___7 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___13 * (*get_link_net)(const struct net_device___7 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___7 *, struct net_device___7 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___7 *, const struct net_device___7 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___8 *, const struct net_device___7 *, const struct net_device___7 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___5 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___8 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___4;

struct neigh_hash_table___4;

struct neigh_table___4 {
	struct neigh_table___4 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___7 *, __u32 *);
	int (*constructor)(struct neighbour___4 *);
	int (*pconstructor)(struct pneigh_entry___4 *);
	void (*pdestructor)(struct pneigh_entry___4 *);
	void (*proxy_redo)(struct sk_buff___8 *);
	char *id;
	struct neigh_parms___4 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___6 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___4 *nht;
	struct pneigh_entry___4 **phash_buckets;
};

struct neigh_ops___4 {
	int family;
	void (*solicit)(struct neighbour___4 *, struct sk_buff___8 *);
	void (*error_report)(struct neighbour___4 *, struct sk_buff___8 *);
	int (*output)(struct neighbour___4 *, struct sk_buff___8 *);
	int (*connected_output)(struct neighbour___4 *, struct sk_buff___8 *);
};

struct pneigh_entry___4 {
	struct pneigh_entry___4 *next;
	struct net___13 *net;
	struct net_device___7 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___4 {
	struct neighbour___4 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct request_sock_ops___4;

struct timewait_sock_ops___4;

struct proto___4 {
	void (*close)(struct sock___5 *, long int);
	int (*connect)(struct sock___5 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___5 *, int);
	struct sock___5 * (*accept)(struct sock___5 *, int, int *);
	int (*ioctl)(struct sock___5 *, int, long unsigned int);
	int (*init)(struct sock___5 *);
	void (*destroy)(struct sock___5 *);
	void (*shutdown)(struct sock___5 *, int);
	int (*setsockopt)(struct sock___5 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___5 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___5 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___5 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___5 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___5 *, struct sock___5 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___5 *, struct sock___5 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___5 *, struct page___86 *, int, size_t, int);
	int (*bind)(struct sock___5 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___5 *, struct sk_buff___8 *);
	void (*release_cb)(struct sock___5 *);
	void (*mtu_reduced)(struct sock___5 *);
	void (*hash)(struct sock___5 *);
	void (*unhash)(struct sock___5 *);
	void (*rehash)(struct sock___5 *);
	int (*get_port)(struct sock___5 *, short unsigned int);
	void (*clear_sk)(struct sock___5 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___5 *);
	void (*enter_memory_pressure)(struct sock___5 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___75 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___21 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___4 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___4 {
	void (*enter_memory_pressure)(struct sock___5 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct tty_operations___7 {
	struct tty_struct___7 * (*lookup)(struct tty_driver___7 *, struct inode___87 *, int);
	int (*install)(struct tty_driver___7 *, struct tty_struct___7 *);
	void (*remove)(struct tty_driver___7 *, struct tty_struct___7 *);
	int (*open)(struct tty_struct___7 *, struct file___86 *);
	void (*close)(struct tty_struct___7 *, struct file___86 *);
	void (*shutdown)(struct tty_struct___7 *);
	void (*cleanup)(struct tty_struct___7 *);
	int (*write)(struct tty_struct___7 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___7 *, unsigned char);
	void (*flush_chars)(struct tty_struct___7 *);
	int (*write_room)(struct tty_struct___7 *);
	int (*chars_in_buffer)(struct tty_struct___7 *);
	int (*ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	void (*throttle)(struct tty_struct___7 *);
	void (*unthrottle)(struct tty_struct___7 *);
	void (*stop)(struct tty_struct___7 *);
	void (*start)(struct tty_struct___7 *);
	void (*hangup)(struct tty_struct___7 *);
	int (*break_ctl)(struct tty_struct___7 *, int);
	void (*flush_buffer)(struct tty_struct___7 *);
	void (*set_ldisc)(struct tty_struct___7 *);
	void (*wait_until_sent)(struct tty_struct___7 *, int);
	void (*send_xchar)(struct tty_struct___7 *, char);
	int (*tiocmget)(struct tty_struct___7 *);
	int (*tiocmset)(struct tty_struct___7 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___7 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___7 *, struct termiox *);
	int (*get_icount)(struct tty_struct___7 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___7 *, int, char *);
	int (*poll_get_char)(struct tty_driver___7 *, int);
	void (*poll_put_char)(struct tty_driver___7 *, int, char);
	const struct file_operations___86 *proc_fops;
};

struct tty_driver___7 {
	int magic;
	struct kref kref;
	struct cdev___31 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___7 *other;
	struct tty_struct___7 **ttys;
	struct tty_port___7 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___7 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___7;

struct tty_port___7 {
	struct tty_bufhead buf;
	struct tty_struct___7 *tty;
	struct tty_struct___7 *itty;
	const struct tty_port_operations___7 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___87 mutex;
	struct mutex___87 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___7 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___7 *);
	void (*close)(struct tty_struct___7 *);
	void (*flush_buffer)(struct tty_struct___7 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___7 *);
	ssize_t (*read)(struct tty_struct___7 *, struct file___86 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___7 *, struct file___86 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___7 *, struct file___86 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, struct file___86 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___7 *, struct file___86 *, struct poll_table_struct___52 *);
	int (*hangup)(struct tty_struct___7 *);
	void (*receive_buf)(struct tty_struct___7 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___7 *);
	void (*dcd_change)(struct tty_struct___7 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___7 *, int);
};

struct tty_ldisc___7 {
	struct tty_ldisc_ops___7 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___7 *tty;
};

struct tty_port_operations___7 {
	int (*carrier_raised)(struct tty_port___7 *);
	void (*dtr_rts)(struct tty_port___7 *, int);
	void (*shutdown)(struct tty_port___7 *);
	void (*drop)(struct tty_port___7 *);
	int (*activate)(struct tty_port___7 *, struct tty_struct___7 *);
	void (*destruct)(struct tty_port___7 *);
};

struct audit_netlink_list {
	int pid;
	struct sk_buff_head___6 q;
};

struct audit_buffer {
	struct list_head list;
	struct sk_buff___8 *skb;
	struct audit_context___3 *ctx;
	gfp_t gfp_mask;
};

struct audit_reply {
	int pid;
	struct sk_buff___8 *skb;
};

struct audit_context {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___33 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
	};
	int fds[2];
};

enum {
	Audit_equal = 0,
	Audit_not_equal = 1,
	Audit_bitmask = 2,
	Audit_bittest = 3,
	Audit_lt = 4,
	Audit_gt = 5,
	Audit_le = 6,
	Audit_ge = 7,
	Audit_bad = 8,
};

struct audit_rule_data {
	__u32 flags;
	__u32 action;
	__u32 field_count;
	__u32 mask[64];
	__u32 fields[64];
	__u32 values[64];
	__u32 fieldflags[64];
	__u32 buflen;
	char buf[0];
};

struct audit_rule {
	__u32 flags;
	__u32 action;
	__u32 field_count;
	__u32 mask[64];
	__u32 fields[64];
	__u32 values[64];
};

struct audit_field;

struct audit_watch;

struct audit_tree;

struct audit_krule {
	int vers_ops;
	u32 pflags;
	u32 flags;
	u32 listnr;
	u32 action;
	u32 mask[64];
	u32 buflen;
	u32 field_count;
	char *filterkey;
	struct audit_field *fields;
	struct audit_field *arch_f;
	struct audit_field *inode_f;
	struct audit_watch *watch;
	struct audit_tree *tree;
	struct list_head rlist;
	struct list_head list;
	u64 prio;
};

struct audit_field {
	u32 type;
	u32 val;
	kuid_t uid;
	kgid_t gid;
	u32 op;
	char *lsm_str;
	void *lsm_rule;
};

struct audit_entry {
	struct list_head list;
	struct callback_head rcu;
	struct audit_krule rule;
};

struct audit_netlink_list___2 {
	int pid;
	struct sk_buff_head q;
};

struct audit_buffer___2;

typedef int __kernel_key_t;

typedef __kernel_key_t key_t;

struct page___87;

typedef struct page___87 *pgtable_t___87;

struct address_space___87;

struct kmem_cache___76;

struct page___87 {
	long unsigned int flags;
	struct address_space___87 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___87 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___87 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___76 *slab_cache;
		struct page___87 *first_page;
	};
	long: 64;
};

struct thread_struct___40;

struct task_struct___87;

struct pv_cpu_ops___87 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___40 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___40 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___87 *);
	void (*end_context_switch)(struct task_struct___87 *);
};

struct perf_event___40;

struct thread_struct___40 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___40 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___44;

struct pid_link___44 {
	struct hlist_node node;
	struct pid___44 *pid;
};

struct mutex___88 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___87 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___83 {
	struct page___87 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___92;

struct fs_struct___7;

struct nsproxy___45;

struct signal_struct___87;

struct audit_context___4;

struct css_set___55;

struct perf_event_context___40;

struct task_struct___87 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___87 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___92 *mm;
	struct mm_struct___92 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___87 *real_parent;
	struct task_struct___87 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___87 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___44 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___87 = 0,
		VTIME_USER___87 = 1,
		VTIME_SYS___87 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___40 thread;
	struct fs_struct___7 *fs;
	struct files_struct *files;
	struct nsproxy___45 *nsproxy;
	struct signal_struct___87 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context___4 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___55 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___40 *perf_event_ctxp[2];
	struct mutex___88 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___83 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___92 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___92 *, struct mm_struct___92 *);
	void (*dup_mmap)(struct mm_struct___92 *, struct mm_struct___92 *);
	void (*exit_mmap)(struct mm_struct___92 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___92 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___92 *);
	void (*pgd_free)(struct mm_struct___92 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___92 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___92 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___92 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___92 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___92 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___92 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___92 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___92 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___92 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___92 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___92 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___88 lock;
	void *vdso;
} mm_context_t___88;

struct xol_area___87;

struct uprobes_state___87 {
	struct xol_area___87 *xol_area;
};

struct vm_area_struct___92;

struct file___87;

struct linux_binfmt___11;

struct core_state___87;

struct mm_struct___92 {
	struct vm_area_struct___92 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___92 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___92 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___11 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___88 context;
	long unsigned int flags;
	struct core_state___87 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___87 *owner;
	struct file___87 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___87 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___40 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___87 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___87 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___87 *target;
};

typedef void (*perf_overflow_handler_t___40)(struct perf_event___40 *, struct perf_sample_data___6 *, struct pt_regs *);

struct ftrace_ops___40;

typedef void (*ftrace_func_t___40)(long unsigned int, long unsigned int, struct ftrace_ops___40 *, struct pt_regs *);

struct ftrace_ops___40 {
	ftrace_func_t___40 func;
	struct ftrace_ops___40 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___88 regex_lock;
};

struct pmu___40;

struct fasync_struct___87;

struct pid_namespace___44;

struct ftrace_event_call___31;

struct perf_cgroup___40;

struct perf_event___40 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___40 *group_leader;
	struct pmu___40 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___40 hw;
	struct perf_event_context___40 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___88 child_mutex;
	struct list_head child_list;
	struct perf_event___40 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___87 *owner;
	struct mutex___88 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___87 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___40 *);
	struct callback_head callback_head;
	struct pid_namespace___44 *ns;
	u64 id;
	perf_overflow_handler_t___40 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___31 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___40 ftrace_ops;
	struct perf_cgroup___40 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___42 {
	struct task_struct___87 *task;
	struct exec_domain___8 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___88;

struct dentry_operations___87;

struct super_block___88;

struct dentry___88 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___88 *d_parent;
	struct qstr d_name;
	struct inode___88 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___87 *d_op;
	struct super_block___88 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___87;

struct address_space___87 {
	struct inode___88 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___88 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___87 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___87;

struct file_operations___87;

struct file_lock___87;

struct dquot___87;

struct block_device___87;

struct cdev___32;

struct inode___88 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___87 *i_op;
	struct super_block___88 *i_sb;
	struct address_space___87 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___88 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___87 *i_fop;
	struct file_lock___87 *i_flock;
	struct address_space___87 i_data;
	struct dquot___87 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___87 *i_bdev;
		struct cdev___32 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___13;

struct path___87;

struct dentry_operations___87 {
	int (*d_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_hash)(const struct dentry___88 *, struct qstr *);
	int (*d_compare)(const struct dentry___88 *, const struct dentry___88 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___88 *);
	void (*d_release)(struct dentry___88 *);
	void (*d_prune)(struct dentry___88 *);
	void (*d_iput)(struct dentry___88 *, struct inode___88 *);
	char * (*d_dname)(struct dentry___88 *, char *, int);
	struct vfsmount___13 * (*d_automount)(struct path___87 *);
	int (*d_manage)(struct dentry___88 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___87;

struct mem_dqinfo___87 {
	struct quota_format_type___87 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___87;

struct quota_info___87 {
	unsigned int flags;
	struct mutex___88 dqio_mutex;
	struct mutex___88 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___88 *files[2];
	struct mem_dqinfo___87 info[2];
	const struct quota_format_ops___87 *ops[2];
};

struct file_system_type___87;

struct super_operations___87;

struct dquot_operations___87;

struct quotactl_ops___87;

struct xattr_handler___55;

struct super_block___88 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___87 *s_type;
	const struct super_operations___87 *s_op;
	const struct dquot_operations___87 *dq_op;
	const struct quotactl_ops___87 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___88 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___55 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___87 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___87 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___88 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___87 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___13 {
	struct dentry___88 *mnt_root;
	struct super_block___88 *mnt_sb;
	int mnt_flags;
};

struct path___87 {
	struct vfsmount___13 *mnt;
	struct dentry___88 *dentry;
};

struct upid___44 {
	int nr;
	struct pid_namespace___44 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___44 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___87 *child_reaper;
	struct kmem_cache___76 *pid_cachep;
	unsigned int level;
	struct pid_namespace___44 *parent;
	struct vfsmount___13 *proc_mnt;
	struct dentry___88 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___44 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___44 numbers[1];
};

struct irq_data___62;

struct x86_io_apic_ops___62 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___62 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___62;

struct irq_data___62 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___62 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___67;

struct dev_pm_ops___67 {
	int (*prepare)(struct device___67 *);
	void (*complete)(struct device___67 *);
	int (*suspend)(struct device___67 *);
	int (*resume)(struct device___67 *);
	int (*freeze)(struct device___67 *);
	int (*thaw)(struct device___67 *);
	int (*poweroff)(struct device___67 *);
	int (*restore)(struct device___67 *);
	int (*suspend_late)(struct device___67 *);
	int (*resume_early)(struct device___67 *);
	int (*freeze_late)(struct device___67 *);
	int (*thaw_early)(struct device___67 *);
	int (*poweroff_late)(struct device___67 *);
	int (*restore_early)(struct device___67 *);
	int (*suspend_noirq)(struct device___67 *);
	int (*resume_noirq)(struct device___67 *);
	int (*freeze_noirq)(struct device___67 *);
	int (*thaw_noirq)(struct device___67 *);
	int (*poweroff_noirq)(struct device___67 *);
	int (*restore_noirq)(struct device___67 *);
	int (*runtime_suspend)(struct device___67 *);
	int (*runtime_resume)(struct device___67 *);
	int (*runtime_idle)(struct device___67 *);
};

struct dma_map_ops___31;

struct dev_archdata___31 {
	struct dma_map_ops___31 *dma_ops;
	void *iommu;
};

struct device_type___67;

struct bus_type___67;

struct device_driver___67;

struct dev_pm_domain___67;

struct class___67;

struct attribute_group___60;

struct device_rh___67;

struct device___67 {
	struct device___67 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___67 *type;
	struct mutex___88 mutex;
	struct bus_type___67 *bus;
	struct device_driver___67 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___67 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___67 *class;
	const struct attribute_group___60 **groups;
	void (*release)(struct device___67 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___67 *device_rh;
};

struct dev_pm_info_rh___67 {
	void (*set_latency_tolerance)(struct device___67 *, s32);
};

struct dev_pm_domain___67 {
	struct dev_pm_ops___67 ops;
};

struct smp_ops___87 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___87 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___87 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___88 *bd_inode;
	struct super_block___88 *bd_super;
	struct mutex___88 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___87 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___88 bd_fsfreeze_mutex;
};

struct cgroup___55;

struct cgroup_subsys_state___55 {
	struct cgroup___55 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___88 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___87 *ia_file;
};

struct fown_struct___44 {
	rwlock_t lock;
	struct pid___44 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___87 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___87 f_path;
	struct inode___88 *f_inode;
	const struct file_operations___87 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___44 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___87 *f_mapping;
	struct mutex___88 f_pos_lock;
};

struct zone___87;

struct lruvec___87 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___87 *zone;
};

struct pglist_data___87;

struct zone___87 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___87 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___87 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___87 {
	struct zone___87 *zone;
	int zone_idx;
};

struct zonelist___87 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___87 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___87 {
	struct zone___87 node_zones[4];
	struct zonelist___87 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___87 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___87 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___88 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___88 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___87 {
	int qf_fmt_id;
	const struct quota_format_ops___87 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___87 *qf_next;
};

struct quota_format_ops___87 {
	int (*check_quota_file)(struct super_block___88 *, int);
	int (*read_file_info)(struct super_block___88 *, int);
	int (*write_file_info)(struct super_block___88 *, int);
	int (*free_file_info)(struct super_block___88 *, int);
	int (*read_dqblk)(struct dquot___87 *);
	int (*commit_dqblk)(struct dquot___87 *);
	int (*release_dqblk)(struct dquot___87 *);
};

struct dquot_operations___87 {
	int (*write_dquot)(struct dquot___87 *);
	struct dquot___87 * (*alloc_dquot)(struct super_block___88 *, int);
	void (*destroy_dquot)(struct dquot___87 *);
	int (*acquire_dquot)(struct dquot___87 *);
	int (*release_dquot)(struct dquot___87 *);
	int (*mark_dirty)(struct dquot___87 *);
	int (*write_info)(struct super_block___88 *, int);
	qsize_t * (*get_reserved_space)(struct inode___88 *);
};

struct quotactl_ops___87 {
	int (*quota_on)(struct super_block___88 *, int, int, struct path___87 *);
	int (*quota_on_meta)(struct super_block___88 *, int, int);
	int (*quota_off)(struct super_block___88 *, int);
	int (*quota_sync)(struct super_block___88 *, int);
	int (*get_info)(struct super_block___88 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___88 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___88 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___88 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___88 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___88 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___88 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___88 *, unsigned int);
};

struct address_space_operations___87 {
	int (*writepage)(struct page___87 *, struct writeback_control *);
	int (*readpage)(struct file___87 *, struct page___87 *);
	int (*writepages)(struct address_space___87 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___87 *);
	int (*readpages)(struct file___87 *, struct address_space___87 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___87 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___87 **, void **);
	int (*write_end)(struct file___87 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___87 *, void *);
	sector_t (*bmap)(struct address_space___87 *, sector_t);
	void (*invalidatepage)(struct page___87 *, long unsigned int);
	int (*releasepage)(struct page___87 *, gfp_t);
	void (*freepage)(struct page___87 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___87 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___87 *, struct page___87 *, struct page___87 *, enum migrate_mode);
	int (*launder_page)(struct page___87 *);
	int (*is_partially_uptodate)(struct page___87 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___87 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___87 *, struct page___87 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___87 *, sector_t *);
	void (*swap_deactivate)(struct file___87 *);
	void (*invalidatepage_range)(struct page___87 *, unsigned int, unsigned int);
};

struct cdev___32 {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations___87 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct nameidata___4;

struct inode_operations___87 {
	struct dentry___88 * (*lookup)(struct inode___88 *, struct dentry___88 *, unsigned int);
	void * (*follow_link)(struct dentry___88 *, struct nameidata___4 *);
	int (*permission)(struct inode___88 *, int);
	struct posix_acl * (*get_acl)(struct inode___88 *, int);
	int (*readlink)(struct dentry___88 *, char *, int);
	void (*put_link)(struct dentry___88 *, struct nameidata___4 *, void *);
	int (*create)(struct inode___88 *, struct dentry___88 *, umode_t, bool);
	int (*link)(struct dentry___88 *, struct inode___88 *, struct dentry___88 *);
	int (*unlink)(struct inode___88 *, struct dentry___88 *);
	int (*symlink)(struct inode___88 *, struct dentry___88 *, const char *);
	int (*mkdir)(struct inode___88 *, struct dentry___88 *, umode_t);
	int (*rmdir)(struct inode___88 *, struct dentry___88 *);
	int (*mknod)(struct inode___88 *, struct dentry___88 *, umode_t, dev_t);
	int (*rename)(struct inode___88 *, struct dentry___88 *, struct inode___88 *, struct dentry___88 *);
	int (*setattr)(struct dentry___88 *, struct iattr___88 *);
	int (*getattr)(struct vfsmount___13 *, struct dentry___88 *, struct kstat *);
	int (*setxattr)(struct dentry___88 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___88 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___88 *, char *, size_t);
	int (*removexattr)(struct dentry___88 *, const char *);
	int (*fiemap)(struct inode___88 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___88 *, struct timespec *, int);
	int (*atomic_open)(struct inode___88 *, struct dentry___88 *, struct file___87 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___53;

struct seq_file___65;

struct file_operations___87 {
	struct module *owner;
	loff_t (*llseek)(struct file___87 *, loff_t, int);
	ssize_t (*read)(struct file___87 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___87 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___87 *, void *, filldir_t);
	unsigned int (*poll)(struct file___87 *, struct poll_table_struct___53 *);
	long int (*unlocked_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___87 *, struct vm_area_struct___92 *);
	int (*open)(struct inode___88 *, struct file___87 *);
	int (*flush)(struct file___87 *, fl_owner_t);
	int (*release)(struct inode___88 *, struct file___87 *);
	int (*fsync)(struct file___87 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___87 *, int);
	int (*lock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*sendpage)(struct file___87 *, struct page___87 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___87 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___87 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___87 *, long int, struct file_lock___87 **, void **);
		struct {
			int (*setlease)(struct file___87 *, long int, struct file_lock___87 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___87 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___65 *, struct file___87 *);
};

struct file_lock_operations___87;

struct lock_manager_operations___87;

struct file_lock___87 {
	struct file_lock___87 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___44 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___87 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___87 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___87 *fl_ops;
	const struct lock_manager_operations___87 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___87 {
	void (*fl_copy_lock)(struct file_lock___87 *, struct file_lock___87 *);
	void (*fl_release_private)(struct file_lock___87 *);
};

struct lock_manager_operations___87 {
	int (*lm_compare_owner)(struct file_lock___87 *, struct file_lock___87 *);
	long unsigned int (*lm_owner_key)(struct file_lock___87 *);
	void (*lm_notify)(struct file_lock___87 *);
	int (*lm_grant)(struct file_lock___87 *, struct file_lock___87 *, int);
	void (*lm_break)(struct file_lock___87 *);
	int (*lm_change)(struct file_lock___87 **, int);
};

struct fasync_struct___87 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___87 *fa_next;
	struct file___87 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___87 {
	const char *name;
	int fs_flags;
	struct dentry___88 * (*mount)(struct file_system_type___87 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___88 *);
	struct module *owner;
	struct file_system_type___87 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___87 {
	struct inode___88 * (*alloc_inode)(struct super_block___88 *);
	void (*destroy_inode)(struct inode___88 *);
	void (*dirty_inode)(struct inode___88 *, int);
	int (*write_inode)(struct inode___88 *, struct writeback_control *);
	int (*drop_inode)(struct inode___88 *);
	void (*evict_inode)(struct inode___88 *);
	void (*put_super)(struct super_block___88 *);
	int (*sync_fs)(struct super_block___88 *, int);
	int (*freeze_fs)(struct super_block___88 *);
	int (*unfreeze_fs)(struct super_block___88 *);
	int (*statfs)(struct dentry___88 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___88 *, int *, char *);
	void (*umount_begin)(struct super_block___88 *);
	int (*show_options)(struct seq_file___65 *, struct dentry___88 *);
	int (*show_devname)(struct seq_file___65 *, struct dentry___88 *);
	int (*show_path)(struct seq_file___65 *, struct dentry___88 *);
	int (*show_stats)(struct seq_file___65 *, struct dentry___88 *);
	ssize_t (*quota_read)(struct super_block___88 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___88 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___88 *);
	int (*bdev_try_to_free_page)(struct super_block___88 *, struct page___87 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___88 *);
	void (*free_cached_objects)(struct super_block___88 *, int);
};

struct xattr_handler___55 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___88 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___88 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___88 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___53)(struct file___87 *, wait_queue_head_t *, struct poll_table_struct___53 *);

struct poll_table_struct___53 {
	poll_queue_proc___53 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___75;

struct vm_area_struct___92 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___92 *vm_next;
	struct vm_area_struct___92 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___92 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___75 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___87 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___64;

struct seq_file___65 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___88 lock;
	const struct seq_operations___64 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___4 {
	struct path___87 path;
	struct qstr last;
	struct path___87 root;
	struct inode___88 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___87 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___87 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___76;

struct memcg_cache_params___76;

struct kmem_cache___76 {
	struct kmem_cache_cpu___76 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___76 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___72;

struct vm_operations_struct___75 {
	void (*open)(struct vm_area_struct___92 *);
	void (*close)(struct vm_area_struct___92 *);
	int (*fault)(struct vm_area_struct___92 *, struct vm_fault___72 *);
	int (*page_mkwrite)(struct vm_area_struct___92 *, struct vm_fault___72 *);
	int (*access)(struct vm_area_struct___92 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___92 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___92 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___92 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___92 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___87 {
	struct task_struct___87 *task;
	struct core_thread___87 *next;
};

struct core_state___87 {
	atomic_t nr_threads;
	struct core_thread___87 dumper;
	struct completion startup;
};

struct linux_binprm___12;

struct coredump_params___11;

struct linux_binfmt___11 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___12 *);
	int (*load_shlib)(struct file___87 *);
	int (*core_dump)(struct coredump_params___11 *);
	long unsigned int min_coredump;
};

struct vm_fault___72 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___87 *page;
};

struct bin_attribute___60;

struct attribute_group___60 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___60 **bin_attrs;
};

struct bin_attribute___60 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___87 *, struct kobject *, struct bin_attribute___60 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___87 *, struct kobject *, struct bin_attribute___60 *, char *, loff_t, size_t);
	int (*mmap)(struct file___87 *, struct kobject *, struct bin_attribute___60 *, struct vm_area_struct___92 *);
};

struct kmem_cache_cpu___76 {
	void **freelist;
	long unsigned int tid;
	struct page___87 *page;
	struct page___87 *partial;
};

struct memcg_cache_params___76 {
	bool is_root_cache;
	union {
		struct kmem_cache___76 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___76 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct kern_ipc_perm {
	spinlock_t lock;
	bool deleted;
	int id;
	key_t key;
	kuid_t uid;
	kgid_t gid;
	kuid_t cuid;
	kgid_t cgid;
	umode_t mode;
	long unsigned int seq;
	void *security;
};

struct nsproxy___45 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___44 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___8;

struct signal_struct___87 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___87 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___87 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___44 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___44 *tty_old_pgrp;
	int leader;
	struct tty_struct___8 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___88 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___8;

struct tty_operations___8;

struct tty_ldisc___8;

struct tty_port___8;

struct tty_struct___8 {
	int magic;
	struct kref kref;
	struct device___67 *dev;
	struct tty_driver___8 *driver;
	const struct tty_operations___8 *ops;
	int index;
	struct mutex___88 ldisc_mutex;
	struct tty_ldisc___8 *ldisc;
	struct mutex___88 atomic_write_lock;
	struct mutex___88 legacy_mutex;
	struct mutex___88 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___44 *pgrp;
	struct pid___44 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___8 *link;
	struct fasync_struct___87 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___8 *port;
	struct ld_semaphore ldisc_sem;
};

struct fs_struct___7 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___87 root;
	struct path___87 pwd;
};

struct audit_context___4 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___87 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
	};
	int fds[2];
};

struct css_set___55 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___55 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___40 {
	struct pmu___40 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___88 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___87 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___40 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dma_map_ops___31 {
	void * (*alloc)(struct device___67 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___67 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___67 *, struct vm_area_struct___92 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___67 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___67 *, struct page___87 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___67 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___67 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___67 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___67 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___67 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___67 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___67 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___67 *, dma_addr_t);
	int (*dma_supported)(struct device___67 *, u64);
	int (*set_dma_mask)(struct device___67 *, u64);
	int is_phys;
};

struct bus_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___67 *, char *);
	ssize_t (*store)(struct bus_type___67 *, const char *, size_t);
};

struct device_attribute___67;

struct driver_attribute___67;

struct bus_type___67 {
	const char *name;
	const char *dev_name;
	struct device___67 *dev_root;
	struct bus_attribute___67 *bus_attrs;
	struct device_attribute___67 *dev_attrs;
	struct driver_attribute___67 *drv_attrs;
	const struct attribute_group___60 **bus_groups;
	const struct attribute_group___60 **dev_groups;
	const struct attribute_group___60 **drv_groups;
	int (*match)(struct device___67 *, struct device_driver___67 *);
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	int (*probe)(struct device___67 *);
	int (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*online)(struct device___67 *);
	int (*offline)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct device___67 *, struct device_attribute___67 *, char *);
	ssize_t (*store)(struct device___67 *, struct device_attribute___67 *, const char *, size_t);
};

struct driver_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___67 *, char *);
	ssize_t (*store)(struct device_driver___67 *, const char *, size_t);
};

struct device_driver___67 {
	const char *name;
	struct bus_type___67 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___67 *);
	int (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	const struct attribute_group___60 **groups;
	const struct dev_pm_ops___67 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___67 {
	const char *name;
	const struct attribute_group___60 **groups;
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
};

struct class_attribute___67;

struct class___67 {
	const char *name;
	struct module *owner;
	struct class_attribute___67 *class_attrs;
	struct device_attribute___67 *dev_attrs;
	const struct attribute_group___60 **dev_groups;
	struct bin_attribute___60 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *);
	void (*class_release)(struct class___67 *);
	void (*dev_release)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
	struct subsys_private *p;
};

struct class_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct class___67 *, struct class_attribute___67 *, char *);
	ssize_t (*store)(struct class___67 *, struct class_attribute___67 *, const char *, size_t);
	const void * (*namespace)(struct class___67 *, const struct class_attribute___67 *);
};

struct device_rh___67 {
	struct dev_pm_info_rh___67 power;
};

struct linux_binprm___12 {
	char buf[128];
	struct vm_area_struct___92 *vma;
	long unsigned int vma_pages;
	struct mm_struct___92 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___87 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct tty_operations___8 {
	struct tty_struct___8 * (*lookup)(struct tty_driver___8 *, struct inode___88 *, int);
	int (*install)(struct tty_driver___8 *, struct tty_struct___8 *);
	void (*remove)(struct tty_driver___8 *, struct tty_struct___8 *);
	int (*open)(struct tty_struct___8 *, struct file___87 *);
	void (*close)(struct tty_struct___8 *, struct file___87 *);
	void (*shutdown)(struct tty_struct___8 *);
	void (*cleanup)(struct tty_struct___8 *);
	int (*write)(struct tty_struct___8 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___8 *, unsigned char);
	void (*flush_chars)(struct tty_struct___8 *);
	int (*write_room)(struct tty_struct___8 *);
	int (*chars_in_buffer)(struct tty_struct___8 *);
	int (*ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	void (*throttle)(struct tty_struct___8 *);
	void (*unthrottle)(struct tty_struct___8 *);
	void (*stop)(struct tty_struct___8 *);
	void (*start)(struct tty_struct___8 *);
	void (*hangup)(struct tty_struct___8 *);
	int (*break_ctl)(struct tty_struct___8 *, int);
	void (*flush_buffer)(struct tty_struct___8 *);
	void (*set_ldisc)(struct tty_struct___8 *);
	void (*wait_until_sent)(struct tty_struct___8 *, int);
	void (*send_xchar)(struct tty_struct___8 *, char);
	int (*tiocmget)(struct tty_struct___8 *);
	int (*tiocmset)(struct tty_struct___8 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___8 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___8 *, struct termiox *);
	int (*get_icount)(struct tty_struct___8 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___8 *, int, char *);
	int (*poll_get_char)(struct tty_driver___8 *, int);
	void (*poll_put_char)(struct tty_driver___8 *, int, char);
	const struct file_operations___87 *proc_fops;
};

struct tty_driver___8 {
	int magic;
	struct kref kref;
	struct cdev___32 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___8 *other;
	struct tty_struct___8 **ttys;
	struct tty_port___8 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___8 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___8;

struct tty_port___8 {
	struct tty_bufhead buf;
	struct tty_struct___8 *tty;
	struct tty_struct___8 *itty;
	const struct tty_port_operations___8 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___88 mutex;
	struct mutex___88 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___8 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___8 *);
	void (*close)(struct tty_struct___8 *);
	void (*flush_buffer)(struct tty_struct___8 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___8 *);
	ssize_t (*read)(struct tty_struct___8 *, struct file___87 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___8 *, struct file___87 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___8 *, struct file___87 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, struct file___87 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___8 *, struct file___87 *, struct poll_table_struct___53 *);
	int (*hangup)(struct tty_struct___8 *);
	void (*receive_buf)(struct tty_struct___8 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___8 *);
	void (*dcd_change)(struct tty_struct___8 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___8 *, int);
};

struct tty_ldisc___8 {
	struct tty_ldisc_ops___8 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___8 *tty;
};

struct tty_port_operations___8 {
	int (*carrier_raised)(struct tty_port___8 *);
	void (*dtr_rts)(struct tty_port___8 *, int);
	void (*shutdown)(struct tty_port___8 *);
	void (*drop)(struct tty_port___8 *);
	int (*activate)(struct tty_port___8 *, struct tty_struct___8 *);
	void (*destruct)(struct tty_port___8 *);
};

struct coredump_params___11 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___87 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct irq_chip___62 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___62 *);
	void (*irq_shutdown)(struct irq_data___62 *);
	void (*irq_enable)(struct irq_data___62 *);
	void (*irq_disable)(struct irq_data___62 *);
	void (*irq_ack)(struct irq_data___62 *);
	void (*irq_mask)(struct irq_data___62 *);
	void (*irq_mask_ack)(struct irq_data___62 *);
	void (*irq_unmask)(struct irq_data___62 *);
	void (*irq_eoi)(struct irq_data___62 *);
	int (*irq_set_affinity)(struct irq_data___62 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___62 *);
	int (*irq_set_type)(struct irq_data___62 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___62 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___62 *);
	void (*irq_bus_sync_unlock)(struct irq_data___62 *);
	void (*irq_cpu_online)(struct irq_data___62 *);
	void (*irq_cpu_offline)(struct irq_data___62 *);
	void (*irq_suspend)(struct irq_data___62 *);
	void (*irq_resume)(struct irq_data___62 *);
	void (*irq_pm_shutdown)(struct irq_data___62 *);
	void (*irq_print_chip)(struct irq_data___62 *, struct seq_file___65 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___62 *, void *);
	long unsigned int flags;
};

struct seq_operations___64 {
	void * (*start)(struct seq_file___65 *, loff_t *);
	void (*stop)(struct seq_file___65 *, void *);
	void * (*next)(struct seq_file___65 *, void *, loff_t *);
	int (*show)(struct seq_file___65 *, void *);
};

struct cgroupfs_root___55;

struct cgroup___55 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___55 *parent;
	struct dentry___88 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___55 *subsys[11];
	struct cgroupfs_root___55 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___88 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___55 {
	struct super_block___88 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___55 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___40;

struct pmu___40 {
	struct list_head entry;
	struct device___67 *dev;
	const struct attribute_group___60 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___40 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___40 *);
	void (*pmu_disable)(struct pmu___40 *);
	int (*event_init)(struct perf_event___40 *);
	int (*add)(struct perf_event___40 *, int);
	void (*del)(struct perf_event___40 *, int);
	void (*start)(struct perf_event___40 *, int);
	void (*stop)(struct perf_event___40 *, int);
	void (*read)(struct perf_event___40 *);
	void (*start_txn)(struct pmu___40 *);
	int (*commit_txn)(struct pmu___40 *);
	void (*cancel_txn)(struct pmu___40 *);
	int (*event_idx)(struct perf_event___40 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___40 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___40 *);
};

struct perf_cpu_context___40 {
	struct perf_event_context___40 ctx;
	struct perf_event_context___40 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___40 *unique_pmu;
	struct perf_cgroup___40 *cgrp;
};

struct trace_event_functions___31;

struct trace_event___31 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___31 *funcs;
};

struct ftrace_event_class___31;

struct ftrace_event_call___31 {
	struct list_head list;
	struct ftrace_event_class___31 *class;
	char *name;
	struct trace_event___31 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___40 {
	struct cgroup_subsys_state___55 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___31 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___88 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___31)(struct trace_iterator___31 *, int, struct trace_event___31 *);

struct trace_event_functions___31 {
	trace_print_func___31 trace;
	trace_print_func___31 raw;
	trace_print_func___31 hex;
	trace_print_func___31 binary;
};

struct ftrace_event_class___31 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___31 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___31 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___31 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___31 *);
};

struct audit_aux_data {
	struct audit_aux_data *next;
	int type;
};

struct audit_chunk;

struct audit_tree_refs {
	struct audit_tree_refs *next;
	struct audit_chunk *c[31];
};

struct audit_aux_data_pids {
	struct audit_aux_data d;
	pid_t target_pid[16];
	kuid_t target_auid[16];
	kuid_t target_uid[16];
	unsigned int target_sessionid[16];
	u32 target_sid[16];
	char target_comm[256];
	int pid_count;
};

struct audit_aux_data_bprm_fcaps {
	struct audit_aux_data d;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	struct audit_cap_data old_pcap;
	struct audit_cap_data new_pcap;
};

struct audit_parent;

struct audit_watch {
	atomic_t count;
	dev_t dev;
	char *path;
	long unsigned int ino;
	struct audit_parent *parent;
	struct list_head wlist;
	struct list_head rules;
};

struct fsnotify_group;

struct fsnotify_mark;

struct fsnotify_event;

struct fsnotify_event_private_data;

struct fsnotify_ops {
	bool (*should_send_event)(struct fsnotify_group *, struct inode___34 *, struct fsnotify_mark *, struct fsnotify_mark *, __u32, void *, int);
	int (*handle_event)(struct fsnotify_group *, struct fsnotify_mark *, struct fsnotify_mark *, struct fsnotify_event *);
	void (*free_group_priv)(struct fsnotify_group *);
	void (*freeing_mark)(struct fsnotify_mark *, struct fsnotify_group *);
	void (*free_event_priv)(struct fsnotify_event_private_data *);
};

struct inotify_group_private_data {
	spinlock_t idr_lock;
	struct idr idr;
	struct user_struct *user;
};

struct fanotify_group_private_data {
	struct mutex___34 access_mutex;
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	atomic_t bypass_perm;
	int f_flags;
	unsigned int max_marks;
	struct user_struct *user;
};

struct fsnotify_group {
	atomic_t refcnt;
	const struct fsnotify_ops *ops;
	struct mutex___34 notification_mutex;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	struct mutex___34 mark_mutex;
	atomic_t num_marks;
	struct list_head marks_list;
	struct fasync_struct___33 *fsn_fa;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_inode_mark {
	struct inode___34 *inode;
	struct hlist_node i_list;
	struct list_head free_i_list;
};

struct fsnotify_vfsmount_mark {
	struct vfsmount *mnt;
	struct hlist_node m_list;
	struct list_head free_m_list;
};

struct fsnotify_mark {
	__u32 mask;
	atomic_t refcnt;
	struct fsnotify_group *group;
	struct list_head g_list;
	spinlock_t lock;
	union {
		struct fsnotify_inode_mark i;
		struct fsnotify_vfsmount_mark m;
	};
	__u32 ignored_mask;
	unsigned int flags;
	struct list_head destroy_list;
	void (*free_mark)(struct fsnotify_mark *);
};

struct fsnotify_event_holder {
	struct fsnotify_event *event;
	struct list_head event_list;
};

struct fsnotify_event {
	struct fsnotify_event_holder holder;
	spinlock_t lock;
	struct inode___34 *to_tell;
	union {
		struct path___33 path;
		struct inode___34 *inode;
	};
	int data_type;
	atomic_t refcnt;
	__u32 mask;
	u32 sync_cookie;
	const unsigned char *file_name;
	size_t name_len;
	struct pid___16 *tgid;
	__u32 response;
	struct list_head private_data_list;
};

struct fsnotify_event_private_data {
	struct fsnotify_group *group;
	struct list_head event_list;
};

struct audit_parent {
	struct list_head watches;
	struct fsnotify_mark mark;
};

struct audit_chunk___2;

struct audit_tree {
	atomic_t count;
	int goner;
	struct audit_chunk___2 *root;
	struct list_head chunks;
	struct list_head rules;
	struct list_head list;
	struct list_head same_root;
	struct callback_head head;
	char pathname[0];
};

struct fsnotify_group___2;

struct fsnotify_mark___2;

struct fsnotify_event___2;

struct fsnotify_event_private_data___2;

struct fsnotify_ops___2 {
	bool (*should_send_event)(struct fsnotify_group___2 *, struct inode___88 *, struct fsnotify_mark___2 *, struct fsnotify_mark___2 *, __u32, void *, int);
	int (*handle_event)(struct fsnotify_group___2 *, struct fsnotify_mark___2 *, struct fsnotify_mark___2 *, struct fsnotify_event___2 *);
	void (*free_group_priv)(struct fsnotify_group___2 *);
	void (*freeing_mark)(struct fsnotify_mark___2 *, struct fsnotify_group___2 *);
	void (*free_event_priv)(struct fsnotify_event_private_data___2 *);
};

struct fanotify_group_private_data___2 {
	struct mutex___88 access_mutex;
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	atomic_t bypass_perm;
	int f_flags;
	unsigned int max_marks;
	struct user_struct *user;
};

struct fsnotify_group___2 {
	atomic_t refcnt;
	const struct fsnotify_ops___2 *ops;
	struct mutex___88 notification_mutex;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	struct mutex___88 mark_mutex;
	atomic_t num_marks;
	struct list_head marks_list;
	struct fasync_struct___87 *fsn_fa;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data___2 fanotify_data;
	};
};

struct fsnotify_inode_mark___2 {
	struct inode___88 *inode;
	struct hlist_node i_list;
	struct list_head free_i_list;
};

struct fsnotify_vfsmount_mark___2 {
	struct vfsmount___13 *mnt;
	struct hlist_node m_list;
	struct list_head free_m_list;
};

struct fsnotify_mark___2 {
	__u32 mask;
	atomic_t refcnt;
	struct fsnotify_group___2 *group;
	struct list_head g_list;
	spinlock_t lock;
	union {
		struct fsnotify_inode_mark___2 i;
		struct fsnotify_vfsmount_mark___2 m;
	};
	__u32 ignored_mask;
	unsigned int flags;
	struct list_head destroy_list;
	void (*free_mark)(struct fsnotify_mark___2 *);
};

struct fsnotify_event_holder___2 {
	struct fsnotify_event___2 *event;
	struct list_head event_list;
};

struct fsnotify_event___2 {
	struct fsnotify_event_holder___2 holder;
	spinlock_t lock;
	struct inode___88 *to_tell;
	union {
		struct path___87 path;
		struct inode___88 *inode;
	};
	int data_type;
	atomic_t refcnt;
	__u32 mask;
	u32 sync_cookie;
	const unsigned char *file_name;
	size_t name_len;
	struct pid___44 *tgid;
	__u32 response;
	struct list_head private_data_list;
};

struct fsnotify_event_private_data___2 {
	struct fsnotify_group___2 *group;
	struct list_head event_list;
};

struct node {
	struct list_head list;
	struct audit_tree *owner;
	unsigned int index;
};

struct audit_chunk___2 {
	struct list_head hash;
	struct fsnotify_mark___2 mark;
	struct list_head trees;
	int dead;
	int count;
	atomic_long_t refs;
	struct callback_head head;
	struct node owners[0];
};

enum {
	HASH_SIZE = 128,
};

enum {
	FTRACE_OPS_FL_ENABLED = 1,
	FTRACE_OPS_FL_GLOBAL = 2,
	FTRACE_OPS_FL_DYNAMIC = 4,
	FTRACE_OPS_FL_CONTROL = 8,
	FTRACE_OPS_FL_SAVE_REGS = 16,
	FTRACE_OPS_FL_SAVE_REGS_IF_SUPPORTED = 32,
	FTRACE_OPS_FL_RECURSION_SAFE = 64,
	FTRACE_OPS_FL_STUB = 128,
	FTRACE_OPS_FL_INITIALIZED = 256,
};

struct kprobe_blackpoint {
	const char *name;
	long unsigned int start_addr;
	long unsigned int range;
};

struct kprobe_insn_page {
	struct list_head list;
	kprobe_opcode_t *insns;
	struct kprobe_insn_cache___3 *cache;
	int nused;
	int ngarbage;
	char slot_used[0];
};

enum kprobe_slot_state {
	SLOT_CLEAN = 0,
	SLOT_DIRTY = 1,
	SLOT_USED = 2,
};

struct page___88;

typedef struct page___88 *pgtable_t___88;

struct address_space___88;

struct page___88 {
	long unsigned int flags;
	struct address_space___88 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___88 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___88 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___88 *first_page;
	};
	long: 64;
};

struct task_struct___88;

struct pv_cpu_ops___88 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___40 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___40 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___88 *);
	void (*end_context_switch)(struct task_struct___88 *);
};

struct pid___45;

struct pid_link___45 {
	struct hlist_node node;
	struct pid___45 *pid;
};

struct mutex___89 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___88 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___84 {
	struct page___88 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___93;

struct nsproxy___46;

struct signal_struct___88;

struct task_struct___88 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___88 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___93 *mm;
	struct mm_struct___93 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___88 *real_parent;
	struct task_struct___88 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___88 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___45 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___88 = 0,
		VTIME_USER___88 = 1,
		VTIME_SYS___88 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___40 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___46 *nsproxy;
	struct signal_struct___88 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___89 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___84 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___93 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___93 *, struct mm_struct___93 *);
	void (*dup_mmap)(struct mm_struct___93 *, struct mm_struct___93 *);
	void (*exit_mmap)(struct mm_struct___93 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___93 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___93 *);
	void (*pgd_free)(struct mm_struct___93 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___93 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___93 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___93 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___93 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___93 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___93 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___93 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___93 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___93 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___93 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___93 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___89 lock;
	void *vdso;
} mm_context_t___89;

struct xol_area___88;

struct uprobes_state___88 {
	struct xol_area___88 *xol_area;
};

struct vm_area_struct___93;

struct file___88;

struct core_state___88;

struct mm_struct___93 {
	struct vm_area_struct___93 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___93 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___93 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___89 context;
	long unsigned int flags;
	struct core_state___88 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___88 *owner;
	struct file___88 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___88 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___45;

struct exec_domain___21 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___45 *module;
	struct exec_domain___21 *next;
};

struct module_kobject___44 {
	struct kobject kobj;
	struct module___45 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___44;

struct module___45 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___44 mkobj;
	struct module_attribute___44 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___88 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___43 {
	struct task_struct___88 *task;
	struct exec_domain___21 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___88 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___88 *page;
	long unsigned int vaddr;
};

struct inode___89;

struct address_space_operations___88;

struct address_space___88 {
	struct inode___89 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___89 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___88 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___89;

struct path___88 {
	struct vfsmount *mnt;
	struct dentry___89 *dentry;
};

struct fown_struct___45 {
	rwlock_t lock;
	struct pid___45 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___88;

struct file___88 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___88 f_path;
	struct inode___89 *f_inode;
	const struct file_operations___88 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___45 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___88 *f_mapping;
	struct mutex___89 f_pos_lock;
};

struct vm_operations_struct___76;

struct vm_area_struct___93 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___93 *vm_next;
	struct vm_area_struct___93 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___93 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___76 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___88 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___73;

struct vm_operations_struct___76 {
	void (*open)(struct vm_area_struct___93 *);
	void (*close)(struct vm_area_struct___93 *);
	int (*fault)(struct vm_area_struct___93 *, struct vm_fault___73 *);
	int (*page_mkwrite)(struct vm_area_struct___93 *, struct vm_fault___73 *);
	int (*access)(struct vm_area_struct___93 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___93 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___93 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___93 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___93 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___88 {
	struct task_struct___88 *task;
	struct core_thread___88 *next;
};

struct core_state___88 {
	atomic_t nr_threads;
	struct core_thread___88 dumper;
	struct completion startup;
};

struct smp_ops___88 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___88 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___45;

struct upid___45 {
	int nr;
	struct pid_namespace___45 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___45 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___88 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___45 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___89 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___45 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___45 numbers[1];
};

struct zone___88;

struct lruvec___88 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___88 *zone;
};

struct pglist_data___88;

struct zone___88 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___88 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___88 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___88 {
	struct zone___88 *zone;
	int zone_idx;
};

struct zonelist___88 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___88 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___88 {
	struct zone___88 node_zones[4];
	struct zonelist___88 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___88 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___46 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___45 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___9;

struct signal_struct___88 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___88 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___88 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___45 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___45 *tty_old_pgrp;
	int leader;
	struct tty_struct___9 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___89 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___9;

struct tty_operations___9;

struct tty_ldisc___9;

struct fasync_struct___88;

struct tty_port___9;

struct tty_struct___9 {
	int magic;
	struct kref kref;
	struct device___31 *dev;
	struct tty_driver___9 *driver;
	const struct tty_operations___9 *ops;
	int index;
	struct mutex___89 ldisc_mutex;
	struct tty_ldisc___9 *ldisc;
	struct mutex___89 atomic_write_lock;
	struct mutex___89 legacy_mutex;
	struct mutex___89 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___45 *pgrp;
	struct pid___45 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___9 *link;
	struct fasync_struct___88 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___9 *port;
	struct ld_semaphore ldisc_sem;
};

struct vm_fault___73 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___88 *page;
};

struct dentry_operations___88;

struct super_block___89;

struct dentry___89 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___89 *d_parent;
	struct qstr d_name;
	struct inode___89 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___88 *d_op;
	struct super_block___89 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___88;

struct file_lock___88;

struct dquot___88;

struct block_device___88;

struct cdev___33;

struct inode___89 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___88 *i_op;
	struct super_block___89 *i_sb;
	struct address_space___88 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___89 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___88 *i_fop;
	struct file_lock___88 *i_flock;
	struct address_space___88 i_data;
	struct dquot___88 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___88 *i_bdev;
		struct cdev___33 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___88 {
	int (*d_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_hash)(const struct dentry___89 *, struct qstr *);
	int (*d_compare)(const struct dentry___89 *, const struct dentry___89 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___89 *);
	void (*d_release)(struct dentry___89 *);
	void (*d_prune)(struct dentry___89 *);
	void (*d_iput)(struct dentry___89 *, struct inode___89 *);
	char * (*d_dname)(struct dentry___89 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___88 *);
	int (*d_manage)(struct dentry___89 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___88;

struct mem_dqinfo___88 {
	struct quota_format_type___88 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___88;

struct quota_info___88 {
	unsigned int flags;
	struct mutex___89 dqio_mutex;
	struct mutex___89 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___89 *files[2];
	struct mem_dqinfo___88 info[2];
	const struct quota_format_ops___88 *ops[2];
};

struct file_system_type___88;

struct super_operations___88;

struct dquot_operations___88;

struct quotactl_ops___88;

struct super_block___89 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___88 *s_type;
	const struct super_operations___88 *s_op;
	const struct dquot_operations___88 *dq_op;
	const struct quotactl_ops___88 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___89 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___88 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___88 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___89 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___88 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___88 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___89 *bd_inode;
	struct super_block___89 *bd_super;
	struct mutex___89 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___88 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___89 bd_fsfreeze_mutex;
};

struct iattr___89 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___88 *ia_file;
};

struct dquot___88 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___89 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___89 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___88 {
	int qf_fmt_id;
	const struct quota_format_ops___88 *qf_ops;
	struct module___45 *qf_owner;
	struct quota_format_type___88 *qf_next;
};

struct quota_format_ops___88 {
	int (*check_quota_file)(struct super_block___89 *, int);
	int (*read_file_info)(struct super_block___89 *, int);
	int (*write_file_info)(struct super_block___89 *, int);
	int (*free_file_info)(struct super_block___89 *, int);
	int (*read_dqblk)(struct dquot___88 *);
	int (*commit_dqblk)(struct dquot___88 *);
	int (*release_dqblk)(struct dquot___88 *);
};

struct dquot_operations___88 {
	int (*write_dquot)(struct dquot___88 *);
	struct dquot___88 * (*alloc_dquot)(struct super_block___89 *, int);
	void (*destroy_dquot)(struct dquot___88 *);
	int (*acquire_dquot)(struct dquot___88 *);
	int (*release_dquot)(struct dquot___88 *);
	int (*mark_dirty)(struct dquot___88 *);
	int (*write_info)(struct super_block___89 *, int);
	qsize_t * (*get_reserved_space)(struct inode___89 *);
};

struct quotactl_ops___88 {
	int (*quota_on)(struct super_block___89 *, int, int, struct path___88 *);
	int (*quota_on_meta)(struct super_block___89 *, int, int);
	int (*quota_off)(struct super_block___89 *, int);
	int (*quota_sync)(struct super_block___89 *, int);
	int (*get_info)(struct super_block___89 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___89 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___89 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___89 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___89 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___89 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___89 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___89 *, unsigned int);
};

struct address_space_operations___88 {
	int (*writepage)(struct page___88 *, struct writeback_control *);
	int (*readpage)(struct file___88 *, struct page___88 *);
	int (*writepages)(struct address_space___88 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___88 *);
	int (*readpages)(struct file___88 *, struct address_space___88 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___88 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___88 **, void **);
	int (*write_end)(struct file___88 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___88 *, void *);
	sector_t (*bmap)(struct address_space___88 *, sector_t);
	void (*invalidatepage)(struct page___88 *, long unsigned int);
	int (*releasepage)(struct page___88 *, gfp_t);
	void (*freepage)(struct page___88 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___88 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___88 *, struct page___88 *, struct page___88 *, enum migrate_mode);
	int (*launder_page)(struct page___88 *);
	int (*is_partially_uptodate)(struct page___88 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___88 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___88 *, struct page___88 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___88 *, sector_t *);
	void (*swap_deactivate)(struct file___88 *);
	void (*invalidatepage_range)(struct page___88 *, unsigned int, unsigned int);
};

struct cdev___33 {
	struct kobject kobj;
	struct module___45 *owner;
	const struct file_operations___88 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___88 {
	struct dentry___89 * (*lookup)(struct inode___89 *, struct dentry___89 *, unsigned int);
	void * (*follow_link)(struct dentry___89 *, struct nameidata *);
	int (*permission)(struct inode___89 *, int);
	struct posix_acl * (*get_acl)(struct inode___89 *, int);
	int (*readlink)(struct dentry___89 *, char *, int);
	void (*put_link)(struct dentry___89 *, struct nameidata *, void *);
	int (*create)(struct inode___89 *, struct dentry___89 *, umode_t, bool);
	int (*link)(struct dentry___89 *, struct inode___89 *, struct dentry___89 *);
	int (*unlink)(struct inode___89 *, struct dentry___89 *);
	int (*symlink)(struct inode___89 *, struct dentry___89 *, const char *);
	int (*mkdir)(struct inode___89 *, struct dentry___89 *, umode_t);
	int (*rmdir)(struct inode___89 *, struct dentry___89 *);
	int (*mknod)(struct inode___89 *, struct dentry___89 *, umode_t, dev_t);
	int (*rename)(struct inode___89 *, struct dentry___89 *, struct inode___89 *, struct dentry___89 *);
	int (*setattr)(struct dentry___89 *, struct iattr___89 *);
	int (*getattr)(struct vfsmount *, struct dentry___89 *, struct kstat *);
	int (*setxattr)(struct dentry___89 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___89 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___89 *, char *, size_t);
	int (*removexattr)(struct dentry___89 *, const char *);
	int (*fiemap)(struct inode___89 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___89 *, struct timespec *, int);
	int (*atomic_open)(struct inode___89 *, struct dentry___89 *, struct file___88 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___88 {
	struct module___45 *owner;
	loff_t (*llseek)(struct file___88 *, loff_t, int);
	ssize_t (*read)(struct file___88 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___88 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___88 *, void *, filldir_t);
	unsigned int (*poll)(struct file___88 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___88 *, struct vm_area_struct___93 *);
	int (*open)(struct inode___89 *, struct file___88 *);
	int (*flush)(struct file___88 *, fl_owner_t);
	int (*release)(struct inode___89 *, struct file___88 *);
	int (*fsync)(struct file___88 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___88 *, int);
	int (*lock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*sendpage)(struct file___88 *, struct page___88 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___88 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___88 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___88 *, long int, struct file_lock___88 **, void **);
		struct {
			int (*setlease)(struct file___88 *, long int, struct file_lock___88 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___88 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___88 *);
};

struct file_lock_operations___88;

struct lock_manager_operations___88;

struct file_lock___88 {
	struct file_lock___88 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___45 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___88 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___88 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___88 *fl_ops;
	const struct lock_manager_operations___88 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___88 {
	void (*fl_copy_lock)(struct file_lock___88 *, struct file_lock___88 *);
	void (*fl_release_private)(struct file_lock___88 *);
};

struct lock_manager_operations___88 {
	int (*lm_compare_owner)(struct file_lock___88 *, struct file_lock___88 *);
	long unsigned int (*lm_owner_key)(struct file_lock___88 *);
	void (*lm_notify)(struct file_lock___88 *);
	int (*lm_grant)(struct file_lock___88 *, struct file_lock___88 *, int);
	void (*lm_break)(struct file_lock___88 *);
	int (*lm_change)(struct file_lock___88 **, int);
};

struct fasync_struct___88 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___88 *fa_next;
	struct file___88 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___88 {
	const char *name;
	int fs_flags;
	struct dentry___89 * (*mount)(struct file_system_type___88 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___89 *);
	struct module___45 *owner;
	struct file_system_type___88 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___88 {
	struct inode___89 * (*alloc_inode)(struct super_block___89 *);
	void (*destroy_inode)(struct inode___89 *);
	void (*dirty_inode)(struct inode___89 *, int);
	int (*write_inode)(struct inode___89 *, struct writeback_control *);
	int (*drop_inode)(struct inode___89 *);
	void (*evict_inode)(struct inode___89 *);
	void (*put_super)(struct super_block___89 *);
	int (*sync_fs)(struct super_block___89 *, int);
	int (*freeze_fs)(struct super_block___89 *);
	int (*unfreeze_fs)(struct super_block___89 *);
	int (*statfs)(struct dentry___89 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___89 *, int *, char *);
	void (*umount_begin)(struct super_block___89 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___89 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___89 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___89 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___89 *);
	ssize_t (*quota_read)(struct super_block___89 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___89 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___89 *);
	int (*bdev_try_to_free_page)(struct super_block___89 *, struct page___88 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___89 *);
	void (*free_cached_objects)(struct super_block___89 *, int);
};

struct tty_operations___9 {
	struct tty_struct___9 * (*lookup)(struct tty_driver___9 *, struct inode___89 *, int);
	int (*install)(struct tty_driver___9 *, struct tty_struct___9 *);
	void (*remove)(struct tty_driver___9 *, struct tty_struct___9 *);
	int (*open)(struct tty_struct___9 *, struct file___88 *);
	void (*close)(struct tty_struct___9 *, struct file___88 *);
	void (*shutdown)(struct tty_struct___9 *);
	void (*cleanup)(struct tty_struct___9 *);
	int (*write)(struct tty_struct___9 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___9 *, unsigned char);
	void (*flush_chars)(struct tty_struct___9 *);
	int (*write_room)(struct tty_struct___9 *);
	int (*chars_in_buffer)(struct tty_struct___9 *);
	int (*ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	void (*throttle)(struct tty_struct___9 *);
	void (*unthrottle)(struct tty_struct___9 *);
	void (*stop)(struct tty_struct___9 *);
	void (*start)(struct tty_struct___9 *);
	void (*hangup)(struct tty_struct___9 *);
	int (*break_ctl)(struct tty_struct___9 *, int);
	void (*flush_buffer)(struct tty_struct___9 *);
	void (*set_ldisc)(struct tty_struct___9 *);
	void (*wait_until_sent)(struct tty_struct___9 *, int);
	void (*send_xchar)(struct tty_struct___9 *, char);
	int (*tiocmget)(struct tty_struct___9 *);
	int (*tiocmset)(struct tty_struct___9 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___9 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___9 *, struct termiox *);
	int (*get_icount)(struct tty_struct___9 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___9 *, int, char *);
	int (*poll_get_char)(struct tty_driver___9 *, int);
	void (*poll_put_char)(struct tty_driver___9 *, int, char);
	const struct file_operations___88 *proc_fops;
};

struct tty_driver___9 {
	int magic;
	struct kref kref;
	struct cdev___33 *cdevs;
	struct module___45 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___9 *other;
	struct tty_struct___9 **ttys;
	struct tty_port___9 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___9 *ops;
	struct list_head tty_drivers;
};

struct serial_icounter_struct {
	int cts;
	int dsr;
	int rng;
	int dcd;
	int rx;
	int tx;
	int frame;
	int overrun;
	int parity;
	int brk;
	int buf_overrun;
	int reserved[9];
};

struct tty_port_operations___9;

struct tty_port___9 {
	struct tty_bufhead buf;
	struct tty_struct___9 *tty;
	struct tty_struct___9 *itty;
	const struct tty_port_operations___9 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___89 mutex;
	struct mutex___89 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___9 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___9 *);
	void (*close)(struct tty_struct___9 *);
	void (*flush_buffer)(struct tty_struct___9 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___9 *);
	ssize_t (*read)(struct tty_struct___9 *, struct file___88 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___9 *, struct file___88 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___9 *, struct file___88 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___9 *, struct file___88 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___9 *, struct file___88 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___9 *);
	void (*receive_buf)(struct tty_struct___9 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___9 *);
	void (*dcd_change)(struct tty_struct___9 *, unsigned int);
	struct module___45 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___9 *, int);
};

struct tty_ldisc___9 {
	struct tty_ldisc_ops___9 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___9 *tty;
};

struct tty_port_operations___9 {
	int (*carrier_raised)(struct tty_port___9 *);
	void (*dtr_rts)(struct tty_port___9 *, int);
	void (*shutdown)(struct tty_port___9 *);
	void (*drop)(struct tty_port___9 *);
	int (*activate)(struct tty_port___9 *, struct tty_struct___9 *);
	void (*destruct)(struct tty_port___9 *);
};

struct console___2 {
	char name[16];
	void (*write)(struct console___2 *, const char *, unsigned int);
	int (*read)(struct console___2 *, char *, unsigned int);
	struct tty_driver___9 * (*device)(struct console___2 *, int *);
	void (*unblank)();
	int (*setup)(struct console___2 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___2 *next;
};

struct module_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___44 *, struct module_kobject___44 *, char *);
	ssize_t (*store)(struct module_attribute___44 *, struct module_kobject___44 *, const char *, size_t);
	void (*setup)(struct module___45 *, const char *);
	int (*test)(struct module___45 *);
	void (*free)(struct module___45 *);
};

struct kgdb_io {
	const char *name;
	int (*read_char)();
	void (*write_char)(u8);
	void (*flush)();
	int (*init)();
	void (*pre_exception)();
	void (*post_exception)();
	int is_console;
};

enum {
	KDB_NOT_INITIALIZED = 0,
	KDB_INIT_EARLY = 1,
	KDB_INIT_FULL = 2,
};

struct kgdb_state {
	int ex_vector;
	int signo;
	int err_code;
	int cpu;
	int pass_exception;
	long unsigned int thr_query;
	long unsigned int threadid;
	long int kgdb_usethreadid;
	struct pt_regs *linux_regs;
	atomic_t *send_ready;
};

struct debuggerinfo_struct {
	void *debuggerinfo;
	struct task_struct___88 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

typedef int (*get_char_func)();

struct module_use___2 {
	struct list_head source_list;
	struct list_head target_list;
	struct module___8 *source;
	struct module___8 *target;
};

typedef enum {
	KDB_REPEAT_NONE = 0,
	KDB_REPEAT_NO_ARGS = 1,
	KDB_REPEAT_WITH_ARGS = 2,
} kdb_repeat_t;

typedef int (*kdb_func_t)(int, const char **);

typedef enum {
	KDB_REASON_ENTER = 1,
	KDB_REASON_ENTER_SLAVE = 2,
	KDB_REASON_BREAK = 3,
	KDB_REASON_DEBUG = 4,
	KDB_REASON_OOPS = 5,
	KDB_REASON_SWITCH = 6,
	KDB_REASON_KEYBOARD = 7,
	KDB_REASON_NMI = 8,
	KDB_REASON_RECURSE = 9,
	KDB_REASON_SSTEP = 10,
	KDB_REASON_SYSTEM_NMI = 11,
} kdb_reason_t;

struct debuggerinfo_struct___2 {
	void *debuggerinfo;
	struct task_struct___16 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct __ksymtab {
	long unsigned int value;
	const char *mod_name;
	long unsigned int mod_start;
	long unsigned int mod_end;
	const char *sec_name;
	long unsigned int sec_start;
	long unsigned int sec_end;
	const char *sym_name;
	long unsigned int sym_start;
	long unsigned int sym_end;
};

typedef struct __ksymtab kdb_symtab_t;

struct _kdbtab {
	char *cmd_name;
	kdb_func_t cmd_func;
	char *cmd_usage;
	char *cmd_help;
	short int cmd_flags;
	short int cmd_minlen;
	kdb_repeat_t cmd_repeat;
};

typedef struct _kdbtab kdbtab_t;

typedef enum {
	KDB_DB_BPT = 0,
	KDB_DB_SS = 1,
	KDB_DB_SSBPT = 2,
	KDB_DB_NOBPT = 3,
} kdb_dbtrap_t;

struct _kdbmsg {
	int km_diag;
	char *km_msg;
};

typedef struct _kdbmsg kdbmsg_t;

struct defcmd_set {
	int count;
	int usable;
	char *name;
	char *usage;
	char *help;
	char **command;
};

struct kdb_tm {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
};

struct debuggerinfo_struct___3 {
	void *debuggerinfo;
	struct task_struct___34 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct debug_alloc_header {
	u32 next;
	u32 size;
	void *caller;
};

struct _kdb_bp {
	long unsigned int bp_addr;
	unsigned int bp_free: 1;
	unsigned int bp_enabled: 1;
	unsigned int bp_type: 4;
	unsigned int bp_installed: 1;
	unsigned int bp_delay: 1;
	unsigned int bp_delayed: 1;
	unsigned int bph_length;
};

typedef struct _kdb_bp kdb_bp_t;

typedef short unsigned int u_short;

struct page___89;

typedef struct page___89 *pgtable_t___89;

struct address_space___89;

struct kmem_cache___77;

struct page___89 {
	long unsigned int flags;
	struct address_space___89 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___89 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___89 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___77 *slab_cache;
		struct page___89 *first_page;
	};
	long: 64;
};

struct thread_struct___41;

struct task_struct___89;

struct pv_cpu_ops___89 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___41 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___41 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___89 *);
	void (*end_context_switch)(struct task_struct___89 *);
};

struct perf_event___41;

struct thread_struct___41 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___41 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___46;

struct pid_link___46 {
	struct hlist_node node;
	struct pid___46 *pid;
};

struct mutex___90 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___89 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___85 {
	struct page___89 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___94;

struct nsproxy___47;

struct signal_struct___89;

struct css_set___56;

struct perf_event_context___41;

struct task_struct___89 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___89 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___94 *mm;
	struct mm_struct___94 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___89 *real_parent;
	struct task_struct___89 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___89 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___46 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___89 = 0,
		VTIME_USER___89 = 1,
		VTIME_SYS___89 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___41 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___47 *nsproxy;
	struct signal_struct___89 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___56 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___41 *perf_event_ctxp[2];
	struct mutex___90 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___85 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___94 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___94 *, struct mm_struct___94 *);
	void (*dup_mmap)(struct mm_struct___94 *, struct mm_struct___94 *);
	void (*exit_mmap)(struct mm_struct___94 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___94 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___94 *);
	void (*pgd_free)(struct mm_struct___94 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___94 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___94 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___94 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___94 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___94 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___94 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___94 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___94 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___94 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___94 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___94 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___90 lock;
	void *vdso;
} mm_context_t___90;

struct xol_area___89;

struct uprobes_state___89 {
	struct xol_area___89 *xol_area;
};

struct vm_area_struct___94;

struct file___89;

struct core_state___89;

struct mm_struct___94 {
	struct vm_area_struct___94 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___94 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___94 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___90 context;
	long unsigned int flags;
	struct core_state___89 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___89 *owner;
	struct file___89 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___89 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___46;

struct module_kobject___45 {
	struct kobject kobj;
	struct module___46 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___45;

struct module___46 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___45 mkobj;
	struct module_attribute___45 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___89 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___41 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___89 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___89 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___89 *target;
};

typedef void (*perf_overflow_handler_t___41)(struct perf_event___41 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___41;

typedef void (*ftrace_func_t___41)(long unsigned int, long unsigned int, struct ftrace_ops___41 *, struct pt_regs *);

struct ftrace_ops___41 {
	ftrace_func_t___41 func;
	struct ftrace_ops___41 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___90 regex_lock;
};

struct pmu___41;

struct fasync_struct___89;

struct pid_namespace___46;

struct perf_cgroup___41;

struct perf_event___41 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___41 *group_leader;
	struct pmu___41 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___41 hw;
	struct perf_event_context___41 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___90 child_mutex;
	struct list_head child_list;
	struct perf_event___41 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___89 *owner;
	struct mutex___90 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___89 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___41 *);
	struct callback_head callback_head;
	struct pid_namespace___46 *ns;
	u64 id;
	perf_overflow_handler_t___41 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___41 ftrace_ops;
	struct perf_cgroup___41 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___89;

struct lruvec___89 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___89 *zone;
};

struct pglist_data___89;

struct zone___89 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___89 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___89 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___89 {
	struct zone___89 *zone;
	int zone_idx;
};

struct zonelist___89 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___89 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___89 {
	struct zone___89 node_zones[4];
	struct zonelist___89 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___89 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___68;

struct dev_pm_ops___68 {
	int (*prepare)(struct device___68 *);
	void (*complete)(struct device___68 *);
	int (*suspend)(struct device___68 *);
	int (*resume)(struct device___68 *);
	int (*freeze)(struct device___68 *);
	int (*thaw)(struct device___68 *);
	int (*poweroff)(struct device___68 *);
	int (*restore)(struct device___68 *);
	int (*suspend_late)(struct device___68 *);
	int (*resume_early)(struct device___68 *);
	int (*freeze_late)(struct device___68 *);
	int (*thaw_early)(struct device___68 *);
	int (*poweroff_late)(struct device___68 *);
	int (*restore_early)(struct device___68 *);
	int (*suspend_noirq)(struct device___68 *);
	int (*resume_noirq)(struct device___68 *);
	int (*freeze_noirq)(struct device___68 *);
	int (*thaw_noirq)(struct device___68 *);
	int (*poweroff_noirq)(struct device___68 *);
	int (*restore_noirq)(struct device___68 *);
	int (*runtime_suspend)(struct device___68 *);
	int (*runtime_resume)(struct device___68 *);
	int (*runtime_idle)(struct device___68 *);
};

struct device_type___68;

struct bus_type___68;

struct device_driver___68;

struct dev_pm_domain___68;

struct class___68;

struct attribute_group___61;

struct device_rh___68;

struct device___68 {
	struct device___68 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___68 *type;
	struct mutex___90 mutex;
	struct bus_type___68 *bus;
	struct device_driver___68 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___68 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___10 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___68 *class;
	const struct attribute_group___61 **groups;
	void (*release)(struct device___68 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___68 *device_rh;
};

struct dev_pm_info_rh___68 {
	void (*set_latency_tolerance)(struct device___68 *, s32);
};

struct dev_pm_domain___68 {
	struct dev_pm_ops___68 ops;
};

struct smp_ops___89 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___89 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___89 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___89 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___77;

struct memcg_cache_params___77;

struct kmem_cache___77 {
	struct kmem_cache_cpu___77 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___77 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___90;

struct address_space_operations___89;

struct address_space___89 {
	struct inode___90 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___90 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___89 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___90;

struct path___89 {
	struct vfsmount *mnt;
	struct dentry___90 *dentry;
};

struct fown_struct___46 {
	rwlock_t lock;
	struct pid___46 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___89;

struct file___89 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___89 f_path;
	struct inode___90 *f_inode;
	const struct file_operations___89 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___46 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___89 *f_mapping;
	struct mutex___90 f_pos_lock;
};

struct vm_operations_struct___77;

struct vm_area_struct___94 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___94 *vm_next;
	struct vm_area_struct___94 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___94 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___77 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___89 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___74;

struct vm_operations_struct___77 {
	void (*open)(struct vm_area_struct___94 *);
	void (*close)(struct vm_area_struct___94 *);
	int (*fault)(struct vm_area_struct___94 *, struct vm_fault___74 *);
	int (*page_mkwrite)(struct vm_area_struct___94 *, struct vm_fault___74 *);
	int (*access)(struct vm_area_struct___94 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___94 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___94 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___94 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___94 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___89 {
	struct task_struct___89 *task;
	struct core_thread___89 *next;
};

struct core_state___89 {
	atomic_t nr_threads;
	struct core_thread___89 dumper;
	struct completion startup;
};

struct vm_fault___74 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___89 *page;
};

struct bin_attribute___61;

struct attribute_group___61 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___61 **bin_attrs;
};

struct bin_attribute___61 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___89 *, struct kobject *, struct bin_attribute___61 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___89 *, struct kobject *, struct bin_attribute___61 *, char *, loff_t, size_t);
	int (*mmap)(struct file___89 *, struct kobject *, struct bin_attribute___61 *, struct vm_area_struct___94 *);
};

struct bus_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___68 *, char *);
	ssize_t (*store)(struct bus_type___68 *, const char *, size_t);
};

struct device_attribute___68;

struct driver_attribute___68;

struct bus_type___68 {
	const char *name;
	const char *dev_name;
	struct device___68 *dev_root;
	struct bus_attribute___68 *bus_attrs;
	struct device_attribute___68 *dev_attrs;
	struct driver_attribute___68 *drv_attrs;
	const struct attribute_group___61 **bus_groups;
	const struct attribute_group___61 **dev_groups;
	const struct attribute_group___61 **drv_groups;
	int (*match)(struct device___68 *, struct device_driver___68 *);
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	int (*probe)(struct device___68 *);
	int (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*online)(struct device___68 *);
	int (*offline)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct device___68 *, struct device_attribute___68 *, char *);
	ssize_t (*store)(struct device___68 *, struct device_attribute___68 *, const char *, size_t);
};

struct driver_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___68 *, char *);
	ssize_t (*store)(struct device_driver___68 *, const char *, size_t);
};

struct device_driver___68 {
	const char *name;
	struct bus_type___68 *bus;
	struct module___46 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___68 *);
	int (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	const struct attribute_group___61 **groups;
	const struct dev_pm_ops___68 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___68 {
	const char *name;
	const struct attribute_group___61 **groups;
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
};

struct class_attribute___68;

struct class___68 {
	const char *name;
	struct module___46 *owner;
	struct class_attribute___68 *class_attrs;
	struct device_attribute___68 *dev_attrs;
	const struct attribute_group___61 **dev_groups;
	struct bin_attribute___61 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *);
	void (*class_release)(struct class___68 *);
	void (*dev_release)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
	struct subsys_private *p;
};

struct class_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct class___68 *, struct class_attribute___68 *, char *);
	ssize_t (*store)(struct class___68 *, struct class_attribute___68 *, const char *, size_t);
	const void * (*namespace)(struct class___68 *, const struct class_attribute___68 *);
};

struct device_rh___68 {
	struct dev_pm_info_rh___68 power;
};

struct upid___46 {
	int nr;
	struct pid_namespace___46 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___46 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___89 *child_reaper;
	struct kmem_cache___77 *pid_cachep;
	unsigned int level;
	struct pid_namespace___46 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___90 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___46 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___46 numbers[1];
};

struct nsproxy___47 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___46 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___89 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___89 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___89 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___46 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___46 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___90 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___56;

struct css_set___56 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___56 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___41 {
	struct pmu___41 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___90 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___89 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___41 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct module_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___45 *, struct module_kobject___45 *, char *);
	ssize_t (*store)(struct module_attribute___45 *, struct module_kobject___45 *, const char *, size_t);
	void (*setup)(struct module___46 *, const char *);
	int (*test)(struct module___46 *);
	void (*free)(struct module___46 *);
};

struct smp_hotplug_thread___3 {
	struct task_struct___89 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	void (*pre_unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct dentry_operations___89;

struct super_block___90;

struct dentry___90 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___90 *d_parent;
	struct qstr d_name;
	struct inode___90 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___89 *d_op;
	struct super_block___90 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___89;

struct file_lock___89;

struct dquot___89;

struct block_device___89;

struct inode___90 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___89 *i_op;
	struct super_block___90 *i_sb;
	struct address_space___89 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___90 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___89 *i_fop;
	struct file_lock___89 *i_flock;
	struct address_space___89 i_data;
	struct dquot___89 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___89 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___89 {
	int (*d_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_hash)(const struct dentry___90 *, struct qstr *);
	int (*d_compare)(const struct dentry___90 *, const struct dentry___90 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___90 *);
	void (*d_release)(struct dentry___90 *);
	void (*d_prune)(struct dentry___90 *);
	void (*d_iput)(struct dentry___90 *, struct inode___90 *);
	char * (*d_dname)(struct dentry___90 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___89 *);
	int (*d_manage)(struct dentry___90 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___89;

struct mem_dqinfo___89 {
	struct quota_format_type___89 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___89;

struct quota_info___89 {
	unsigned int flags;
	struct mutex___90 dqio_mutex;
	struct mutex___90 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___90 *files[2];
	struct mem_dqinfo___89 info[2];
	const struct quota_format_ops___89 *ops[2];
};

struct file_system_type___89;

struct super_operations___89;

struct dquot_operations___89;

struct quotactl_ops___89;

struct xattr_handler___56;

struct super_block___90 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___89 *s_type;
	const struct super_operations___89 *s_op;
	const struct dquot_operations___89 *dq_op;
	const struct quotactl_ops___89 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___90 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___56 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___89 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___89 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___90 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___89 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___89 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___90 *bd_inode;
	struct super_block___90 *bd_super;
	struct mutex___90 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___89 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___90 bd_fsfreeze_mutex;
};

struct cgroup___56;

struct cgroup_subsys_state___56 {
	struct cgroup___56 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___90 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___89 *ia_file;
};

struct dquot___89 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___90 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___90 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___89 {
	int qf_fmt_id;
	const struct quota_format_ops___89 *qf_ops;
	struct module___46 *qf_owner;
	struct quota_format_type___89 *qf_next;
};

struct quota_format_ops___89 {
	int (*check_quota_file)(struct super_block___90 *, int);
	int (*read_file_info)(struct super_block___90 *, int);
	int (*write_file_info)(struct super_block___90 *, int);
	int (*free_file_info)(struct super_block___90 *, int);
	int (*read_dqblk)(struct dquot___89 *);
	int (*commit_dqblk)(struct dquot___89 *);
	int (*release_dqblk)(struct dquot___89 *);
};

struct dquot_operations___89 {
	int (*write_dquot)(struct dquot___89 *);
	struct dquot___89 * (*alloc_dquot)(struct super_block___90 *, int);
	void (*destroy_dquot)(struct dquot___89 *);
	int (*acquire_dquot)(struct dquot___89 *);
	int (*release_dquot)(struct dquot___89 *);
	int (*mark_dirty)(struct dquot___89 *);
	int (*write_info)(struct super_block___90 *, int);
	qsize_t * (*get_reserved_space)(struct inode___90 *);
};

struct quotactl_ops___89 {
	int (*quota_on)(struct super_block___90 *, int, int, struct path___89 *);
	int (*quota_on_meta)(struct super_block___90 *, int, int);
	int (*quota_off)(struct super_block___90 *, int);
	int (*quota_sync)(struct super_block___90 *, int);
	int (*get_info)(struct super_block___90 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___90 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___90 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___90 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___90 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___90 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___90 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___90 *, unsigned int);
};

struct address_space_operations___89 {
	int (*writepage)(struct page___89 *, struct writeback_control *);
	int (*readpage)(struct file___89 *, struct page___89 *);
	int (*writepages)(struct address_space___89 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___89 *);
	int (*readpages)(struct file___89 *, struct address_space___89 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___89 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___89 **, void **);
	int (*write_end)(struct file___89 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___89 *, void *);
	sector_t (*bmap)(struct address_space___89 *, sector_t);
	void (*invalidatepage)(struct page___89 *, long unsigned int);
	int (*releasepage)(struct page___89 *, gfp_t);
	void (*freepage)(struct page___89 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___89 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___89 *, struct page___89 *, struct page___89 *, enum migrate_mode);
	int (*launder_page)(struct page___89 *);
	int (*is_partially_uptodate)(struct page___89 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___89 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___89 *, struct page___89 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___89 *, sector_t *);
	void (*swap_deactivate)(struct file___89 *);
	void (*invalidatepage_range)(struct page___89 *, unsigned int, unsigned int);
};

struct inode_operations___89 {
	struct dentry___90 * (*lookup)(struct inode___90 *, struct dentry___90 *, unsigned int);
	void * (*follow_link)(struct dentry___90 *, struct nameidata *);
	int (*permission)(struct inode___90 *, int);
	struct posix_acl * (*get_acl)(struct inode___90 *, int);
	int (*readlink)(struct dentry___90 *, char *, int);
	void (*put_link)(struct dentry___90 *, struct nameidata *, void *);
	int (*create)(struct inode___90 *, struct dentry___90 *, umode_t, bool);
	int (*link)(struct dentry___90 *, struct inode___90 *, struct dentry___90 *);
	int (*unlink)(struct inode___90 *, struct dentry___90 *);
	int (*symlink)(struct inode___90 *, struct dentry___90 *, const char *);
	int (*mkdir)(struct inode___90 *, struct dentry___90 *, umode_t);
	int (*rmdir)(struct inode___90 *, struct dentry___90 *);
	int (*mknod)(struct inode___90 *, struct dentry___90 *, umode_t, dev_t);
	int (*rename)(struct inode___90 *, struct dentry___90 *, struct inode___90 *, struct dentry___90 *);
	int (*setattr)(struct dentry___90 *, struct iattr___90 *);
	int (*getattr)(struct vfsmount *, struct dentry___90 *, struct kstat *);
	int (*setxattr)(struct dentry___90 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___90 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___90 *, char *, size_t);
	int (*removexattr)(struct dentry___90 *, const char *);
	int (*fiemap)(struct inode___90 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___90 *, struct timespec *, int);
	int (*atomic_open)(struct inode___90 *, struct dentry___90 *, struct file___89 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___89 {
	struct module___46 *owner;
	loff_t (*llseek)(struct file___89 *, loff_t, int);
	ssize_t (*read)(struct file___89 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___89 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___89 *, void *, filldir_t);
	unsigned int (*poll)(struct file___89 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___89 *, struct vm_area_struct___94 *);
	int (*open)(struct inode___90 *, struct file___89 *);
	int (*flush)(struct file___89 *, fl_owner_t);
	int (*release)(struct inode___90 *, struct file___89 *);
	int (*fsync)(struct file___89 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___89 *, int);
	int (*lock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*sendpage)(struct file___89 *, struct page___89 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___89 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___89 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___89 *, long int, struct file_lock___89 **, void **);
		struct {
			int (*setlease)(struct file___89 *, long int, struct file_lock___89 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___89 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___89 *);
};

struct file_lock_operations___89;

struct lock_manager_operations___89;

struct file_lock___89 {
	struct file_lock___89 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___46 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___89 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___89 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___89 *fl_ops;
	const struct lock_manager_operations___89 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___89 {
	void (*fl_copy_lock)(struct file_lock___89 *, struct file_lock___89 *);
	void (*fl_release_private)(struct file_lock___89 *);
};

struct lock_manager_operations___89 {
	int (*lm_compare_owner)(struct file_lock___89 *, struct file_lock___89 *);
	long unsigned int (*lm_owner_key)(struct file_lock___89 *);
	void (*lm_notify)(struct file_lock___89 *);
	int (*lm_grant)(struct file_lock___89 *, struct file_lock___89 *, int);
	void (*lm_break)(struct file_lock___89 *);
	int (*lm_change)(struct file_lock___89 **, int);
};

struct fasync_struct___89 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___89 *fa_next;
	struct file___89 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___89 {
	const char *name;
	int fs_flags;
	struct dentry___90 * (*mount)(struct file_system_type___89 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___90 *);
	struct module___46 *owner;
	struct file_system_type___89 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___89 {
	struct inode___90 * (*alloc_inode)(struct super_block___90 *);
	void (*destroy_inode)(struct inode___90 *);
	void (*dirty_inode)(struct inode___90 *, int);
	int (*write_inode)(struct inode___90 *, struct writeback_control *);
	int (*drop_inode)(struct inode___90 *);
	void (*evict_inode)(struct inode___90 *);
	void (*put_super)(struct super_block___90 *);
	int (*sync_fs)(struct super_block___90 *, int);
	int (*freeze_fs)(struct super_block___90 *);
	int (*unfreeze_fs)(struct super_block___90 *);
	int (*statfs)(struct dentry___90 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___90 *, int *, char *);
	void (*umount_begin)(struct super_block___90 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___90 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___90 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___90 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___90 *);
	ssize_t (*quota_read)(struct super_block___90 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___90 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___90 *);
	int (*bdev_try_to_free_page)(struct super_block___90 *, struct page___89 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___90 *);
	void (*free_cached_objects)(struct super_block___90 *, int);
};

struct xattr_handler___56 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___90 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___90 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___90 *, const char *, const void *, size_t, int, int);
};

struct kmem_cache_cpu___77 {
	void **freelist;
	long unsigned int tid;
	struct page___89 *page;
	struct page___89 *partial;
};

struct memcg_cache_params___77 {
	bool is_root_cache;
	union {
		struct kmem_cache___77 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___77 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___56;

struct cgroup___56 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___56 *parent;
	struct dentry___90 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___56 *subsys[11];
	struct cgroupfs_root___56 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___90 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___56 {
	struct super_block___90 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___56 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___41;

struct pmu___41 {
	struct list_head entry;
	struct device___68 *dev;
	const struct attribute_group___61 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___41 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___41 *);
	void (*pmu_disable)(struct pmu___41 *);
	int (*event_init)(struct perf_event___41 *);
	int (*add)(struct perf_event___41 *, int);
	void (*del)(struct perf_event___41 *, int);
	void (*start)(struct perf_event___41 *, int);
	void (*stop)(struct perf_event___41 *, int);
	void (*read)(struct perf_event___41 *);
	void (*start_txn)(struct pmu___41 *);
	int (*commit_txn)(struct pmu___41 *);
	void (*cancel_txn)(struct pmu___41 *);
	int (*event_idx)(struct perf_event___41 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___46 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___41 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___41 *);
};

struct perf_cpu_context___41 {
	struct perf_event_context___41 ctx;
	struct perf_event_context___41 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___41 *unique_pmu;
	struct perf_cgroup___41 *cgrp;
};

struct perf_cgroup___41 {
	struct cgroup_subsys_state___56 css;
	struct perf_cgroup_info *info;
};

typedef bool pto_T_____7;

enum {
	_IRQ_DEFAULT_INIT_FLAGS = 0,
	_IRQ_PER_CPU = 512,
	_IRQ_LEVEL = 256,
	_IRQ_NOPROBE = 1024,
	_IRQ_NOREQUEST = 2048,
	_IRQ_NOTHREAD = 65536,
	_IRQ_NOAUTOEN = 4096,
	_IRQ_MOVE_PCNTXT = 16384,
	_IRQ_NO_BALANCING = 8192,
	_IRQ_NESTED_THREAD = 32768,
	_IRQ_PER_CPU_DEVID = 131072,
	_IRQF_MODIFY_MASK = 261903,
};

enum {
	IRQTF_RUNTHREAD = 0,
	IRQTF_WARNED = 1,
	IRQTF_AFFINITY = 2,
	IRQTF_FORCED_THREAD = 3,
};

enum {
	IRQS_AUTODETECT = 1,
	IRQS_SPURIOUS_DISABLED = 2,
	IRQS_POLL_INPROGRESS = 8,
	IRQS_ONESHOT = 32,
	IRQS_REPLAY = 64,
	IRQS_WAITING = 128,
	IRQS_PENDING = 512,
	IRQS_SUSPENDED = 2048,
};

enum {
	IRQCHIP_SET_TYPE_MASKED = 1,
	IRQCHIP_EOI_IF_HANDLED = 2,
	IRQCHIP_MASK_ON_SUSPEND = 4,
	IRQCHIP_ONOFFLINE_ENABLED = 8,
	IRQCHIP_SKIP_SET_WAKE = 16,
	IRQCHIP_ONESHOT_SAFE = 32,
};

enum {
	IRQC_IS_HARDIRQ = 0,
	IRQC_IS_NESTED = 1,
};

typedef void (*dr_release_t___2)(struct device___25 *, void *);

typedef int (*dr_match_t___2)(struct device___25 *, void *, void *);

struct irq_devres {
	unsigned int irq;
	void *dev_id;
};

struct irq_data___63;

struct x86_io_apic_ops___63 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___63 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___63;

struct irq_domain___2;

struct irq_data___63 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___63 *chip;
	struct irq_domain___2 *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct property___5;

struct device_node___5 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___5 *properties;
	struct property___5 *deadprops;
	struct device_node___5 *parent;
	struct device_node___5 *child;
	struct device_node___5 *sibling;
	struct device_node___5 *next;
	struct device_node___5 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct irq_domain_ops___2 {
	int (*match)(struct irq_domain___2 *, struct device_node___5 *);
	int (*map)(struct irq_domain___2 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___2 *, unsigned int);
	int (*xlate)(struct irq_domain___2 *, struct device_node___5 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
};

struct irq_desc___7;

typedef void (*irq_flow_handler_t___7)(unsigned int, struct irq_desc___7 *);

struct irq_desc___7 {
	struct irq_data___63 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___7 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module___46 *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct irq_chip___63 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___63 *);
	void (*irq_shutdown)(struct irq_data___63 *);
	void (*irq_enable)(struct irq_data___63 *);
	void (*irq_disable)(struct irq_data___63 *);
	void (*irq_ack)(struct irq_data___63 *);
	void (*irq_mask)(struct irq_data___63 *);
	void (*irq_mask_ack)(struct irq_data___63 *);
	void (*irq_unmask)(struct irq_data___63 *);
	void (*irq_eoi)(struct irq_data___63 *);
	int (*irq_set_affinity)(struct irq_data___63 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___63 *);
	int (*irq_set_type)(struct irq_data___63 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___63 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___63 *);
	void (*irq_bus_sync_unlock)(struct irq_data___63 *);
	void (*irq_cpu_online)(struct irq_data___63 *);
	void (*irq_cpu_offline)(struct irq_data___63 *);
	void (*irq_suspend)(struct irq_data___63 *);
	void (*irq_resume)(struct irq_data___63 *);
	void (*irq_pm_shutdown)(struct irq_data___63 *);
	void (*irq_print_chip)(struct irq_data___63 *, struct seq_file___65 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___63 *, void *);
	long unsigned int flags;
};

struct irq_domain___2 {
	struct list_head link;
	unsigned int revmap_type;
	union {
		struct {
			unsigned int size;
			unsigned int first_irq;
			irq_hw_number_t first_hwirq;
		} legacy;
		struct {
			unsigned int size;
			unsigned int *revmap;
		} linear;
		struct {
			unsigned int max_irq;
		} nomap;
		struct radix_tree_root tree;
	} revmap_data;
	const struct irq_domain_ops___2 *ops;
	void *host_data;
	irq_hw_number_t inval_irq;
	struct device_node___5 *of_node;
};

struct property___5 {
	char *name;
	int length;
	void *value;
	struct property___5 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___60 attr;
};

struct irq_desc___8;

typedef void (*irq_flow_handler_t___8)(unsigned int, struct irq_desc___8 *);

struct irqaction___8;

struct irq_desc___8 {
	struct irq_data___25 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___8 handle_irq;
	struct irqaction___8 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct irqaction___8 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___8 *next;
	irq_handler_t thread_fn;
	struct task_struct___35 *thread;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seccomp_filter {
	atomic_t usage;
	struct seccomp_filter *prev;
	short unsigned int len;
	struct sock_filter insns[0];
};

struct sock_fprog {
	short unsigned int len;
	struct sock_filter *filter;
};

struct compat_sock_fprog {
	u16 len;
	compat_uptr_t filter;
};

struct sk_buff___9;

struct rcu_dynticks {
	long long int dynticks_nesting;
	int dynticks_nmi_nesting;
	atomic_t dynticks;
};

struct rcu_node {
	raw_spinlock_t lock;
	long unsigned int gpnum;
	long unsigned int completed;
	long unsigned int qsmask;
	long unsigned int expmask;
	long unsigned int qsmaskinit;
	long unsigned int grpmask;
	int grplo;
	int grphi;
	u8 grpnum;
	u8 level;
	struct rcu_node *parent;
	struct list_head blkd_tasks;
	struct list_head *gp_tasks;
	struct list_head *exp_tasks;
	wait_queue_head_t nocb_gp_wq[2];
	int need_future_gp[2];
	long: 64;
	long: 64;
	long: 64;
	raw_spinlock_t fqslock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rcu_state;

struct rcu_data {
	long unsigned int completed;
	long unsigned int gpnum;
	bool passed_quiesce;
	bool qs_pending;
	bool beenonline;
	bool preemptible;
	struct rcu_node *mynode;
	long unsigned int grpmask;
	struct callback_head *nxtlist;
	struct callback_head **nxttail[4];
	long unsigned int nxtcompleted[4];
	long int qlen_lazy;
	long int qlen;
	long int qlen_last_fqs_check;
	long unsigned int n_cbs_invoked;
	long unsigned int n_nocbs_invoked;
	long unsigned int n_cbs_orphaned;
	long unsigned int n_cbs_adopted;
	long unsigned int n_force_qs_snap;
	long int blimit;
	struct rcu_dynticks *dynticks;
	int dynticks_snap;
	long unsigned int dynticks_fqs;
	long unsigned int offline_fqs;
	long unsigned int n_rcu_pending;
	long unsigned int n_rp_qs_pending;
	long unsigned int n_rp_report_qs;
	long unsigned int n_rp_cb_ready;
	long unsigned int n_rp_cpu_needs_gp;
	long unsigned int n_rp_gp_completed;
	long unsigned int n_rp_gp_started;
	long unsigned int n_rp_need_nothing;
	struct callback_head barrier_head;
	struct callback_head *nocb_head;
	struct callback_head **nocb_tail;
	atomic_long_t nocb_q_count;
	atomic_long_t nocb_q_count_lazy;
	int nocb_p_count;
	int nocb_p_count_lazy;
	wait_queue_head_t nocb_wq;
	struct task_struct___37 *nocb_kthread;
	int cpu;
	struct rcu_state *rsp;
};

struct rcu_state {
	struct rcu_node node[326];
	struct rcu_node *level[3];
	u32 levelcnt[5];
	u8 levelspread[3];
	struct rcu_data *rda;
	void (*call)(struct callback_head *, void (*)(struct callback_head *));
	u8 fqs_state;
	u8 boost;
	long unsigned int gpnum;
	long unsigned int completed;
	struct task_struct___37 *gp_kthread;
	wait_queue_head_t gp_wq;
	int gp_flags;
	int: 32;
	raw_spinlock_t orphan_lock;
	struct callback_head *orphan_nxtlist;
	struct callback_head **orphan_nxttail;
	struct callback_head *orphan_donelist;
	struct callback_head **orphan_donetail;
	long int qlen_lazy;
	long int qlen;
	struct mutex___37 onoff_mutex;
	struct mutex___37 barrier_mutex;
	atomic_t barrier_cpu_count;
	struct completion barrier_completion;
	long unsigned int n_barrier_done;
	atomic_long_t expedited_start;
	atomic_long_t expedited_done;
	atomic_long_t expedited_wrap;
	atomic_long_t expedited_tryfail;
	atomic_long_t expedited_workdone1;
	atomic_long_t expedited_workdone2;
	atomic_long_t expedited_normal;
	atomic_long_t expedited_stoppedcpus;
	atomic_long_t expedited_done_tries;
	atomic_long_t expedited_done_lost;
	atomic_long_t expedited_done_exit;
	long unsigned int jiffies_force_qs;
	long unsigned int n_force_qs;
	long unsigned int n_force_qs_lh;
	long unsigned int n_force_qs_ngp;
	long unsigned int gp_start;
	long unsigned int jiffies_stall;
	long unsigned int gp_max;
	char *name;
	char abbr;
	struct list_head flavors;
	struct irq_work wakeup_work;
};

typedef void (*poll_queue_proc___54)(struct file___24 *, wait_queue_head_t *, struct poll_table_struct___2 *);

typedef struct poll_table_struct___2 poll_table___5;

struct rchan;

struct rchan_buf {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___25 *dentry;
	struct kref kref;
	struct page___24 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks;

struct rchan {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___25 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks {
	int (*subbuf_start)(struct rchan_buf *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf *, struct file___24 *);
	void (*buf_unmapped)(struct rchan_buf *, struct file___24 *);
	struct dentry___25 * (*create_buf_file)(const char *, struct dentry___25 *, umode_t, struct rchan_buf *, int *);
	int (*remove_buf_file)(struct dentry___25 *);
};

struct partial_page {
	unsigned int offset;
	unsigned int len;
	long unsigned int private;
};

struct splice_pipe_desc {
	struct page___24 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___2 *ops;
	void (*spd_release)(struct splice_pipe_desc *, unsigned int);
};

struct rchan_percpu_buf_dispatcher {
	struct rchan_buf *buf;
	struct dentry___25 *dentry;
};

typedef int (*subbuf_actor_t)(size_t, struct rchan_buf *, size_t, read_descriptor_t *);

enum {
	TASKSTATS_TYPE_UNSPEC = 0,
	TASKSTATS_TYPE_PID = 1,
	TASKSTATS_TYPE_TGID = 2,
	TASKSTATS_TYPE_STATS = 3,
	TASKSTATS_TYPE_AGGR_PID = 4,
	TASKSTATS_TYPE_AGGR_TGID = 5,
	TASKSTATS_TYPE_NULL = 6,
	__TASKSTATS_TYPE_MAX = 7,
};

enum {
	TASKSTATS_CMD_ATTR_UNSPEC = 0,
	TASKSTATS_CMD_ATTR_PID = 1,
	TASKSTATS_CMD_ATTR_TGID = 2,
	TASKSTATS_CMD_ATTR_REGISTER_CPUMASK = 3,
	TASKSTATS_CMD_ATTR_DEREGISTER_CPUMASK = 4,
	__TASKSTATS_CMD_ATTR_MAX = 5,
};

enum {
	CGROUPSTATS_CMD_UNSPEC = 3,
	CGROUPSTATS_CMD_GET = 4,
	CGROUPSTATS_CMD_NEW = 5,
	__CGROUPSTATS_CMD_MAX = 6,
};

enum {
	CGROUPSTATS_TYPE_UNSPEC = 0,
	CGROUPSTATS_TYPE_CGROUP_STATS = 1,
	__CGROUPSTATS_TYPE_MAX = 2,
};

enum {
	CGROUPSTATS_CMD_ATTR_UNSPEC = 0,
	CGROUPSTATS_CMD_ATTR_FD = 1,
	__CGROUPSTATS_CMD_ATTR_MAX = 2,
};

struct fd___3 {
	struct file___83 *file;
	unsigned int flags;
};

struct genlmsghdr {
	__u8 cmd;
	__u8 version;
	__u16 reserved;
};

enum {
	NLA_UNSPEC = 0,
	NLA_U8 = 1,
	NLA_U16 = 2,
	NLA_U32 = 3,
	NLA_U64 = 4,
	NLA_STRING = 5,
	NLA_FLAG = 6,
	NLA_MSECS = 7,
	NLA_NESTED = 8,
	NLA_NESTED_COMPAT = 9,
	NLA_NUL_STRING = 10,
	NLA_BINARY = 11,
	NLA_S8 = 12,
	NLA_S16 = 13,
	NLA_S32 = 14,
	NLA_S64 = 15,
	__NLA_TYPE_MAX = 16,
};

struct genl_multicast_group {
	char name[16];
};

struct genl_ops;

struct genl_info;

struct genl_family {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops *, struct sk_buff___5 *, struct genl_info *);
	void (*post_doit)(const struct genl_ops *, struct sk_buff___5 *, struct genl_info *);
	struct nlattr **attrbuf;
	const struct genl_ops *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___5 *, struct genl_info *);
	int (*dumpit)(struct sk_buff___5 *, struct netlink_callback *);
	int (*done)(struct netlink_callback *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___12 *_net;
	void *user_ptr[2];
	struct sock *dst_sk;
};

struct listener {
	struct list_head list;
	pid_t pid;
	char valid;
};

struct listener_list {
	struct rw_semaphore sem;
	struct list_head list;
};

enum actions {
	REGISTER = 0,
	DEREGISTER = 1,
	CPU_DONT_CARE = 2,
};

struct tp_module {
	struct list_head list;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
};

struct tracepoint_iter {
	struct tp_module *module;
	struct tracepoint * const *tracepoint;
};

struct tracepoint_entry {
	struct hlist_node hlist;
	struct tracepoint_func *funcs;
	int refcount;
	char name[0];
};

struct tp_probes {
	union {
		struct callback_head rcu;
		struct list_head list;
	} u;
	struct tracepoint_func probes[0];
};

struct page___90;

typedef struct page___90 *pgtable_t___90;

struct address_space___90;

struct kmem_cache___78;

struct page___90 {
	long unsigned int flags;
	struct address_space___90 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___90 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___90 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___78 *slab_cache;
		struct page___90 *first_page;
	};
	long: 64;
};

struct thread_struct___42;

struct task_struct___90;

struct pv_cpu_ops___90 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___42 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___42 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___90 *);
	void (*end_context_switch)(struct task_struct___90 *);
};

struct perf_event___42;

struct thread_struct___42 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___42 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___47;

struct pid_link___47 {
	struct hlist_node node;
	struct pid___47 *pid;
};

struct mutex___91 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___90 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___86 {
	struct page___90 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___95;

struct nsproxy___48;

struct signal_struct___90;

struct css_set___57;

struct perf_event_context___42;

struct task_struct___90 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___90 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___95 *mm;
	struct mm_struct___95 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___90 *real_parent;
	struct task_struct___90 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___90 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___47 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___90 = 0,
		VTIME_USER___90 = 1,
		VTIME_SYS___90 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___42 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___48 *nsproxy;
	struct signal_struct___90 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___57 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___42 *perf_event_ctxp[2];
	struct mutex___91 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___86 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___95 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___95 *, struct mm_struct___95 *);
	void (*dup_mmap)(struct mm_struct___95 *, struct mm_struct___95 *);
	void (*exit_mmap)(struct mm_struct___95 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___95 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___95 *);
	void (*pgd_free)(struct mm_struct___95 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___95 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___95 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___95 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___95 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___95 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___95 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___95 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___95 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___95 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___95 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___95 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___91 lock;
	void *vdso;
} mm_context_t___91;

struct xol_area___90;

struct uprobes_state___90 {
	struct xol_area___90 *xol_area;
};

struct vm_area_struct___95;

struct file___90;

struct linux_binfmt___12;

struct core_state___90;

struct mm_struct___95 {
	struct vm_area_struct___95 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___95 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___95 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___12 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___91 context;
	long unsigned int flags;
	struct core_state___90 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___90 *owner;
	struct file___90 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___90 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___47;

struct exec_domain___22 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___47 *module;
	struct exec_domain___22 *next;
};

struct module_kobject___46 {
	struct kobject kobj;
	struct module___47 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___46;

struct ftrace_event_call___32;

struct module___47 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___46 mkobj;
	struct module_attribute___46 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___32 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___90 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___42 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___90 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___90 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___90 *target;
};

typedef void (*perf_overflow_handler_t___42)(struct perf_event___42 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___42;

typedef void (*ftrace_func_t___42)(long unsigned int, long unsigned int, struct ftrace_ops___42 *, struct pt_regs *);

struct ftrace_ops___42 {
	ftrace_func_t___42 func;
	struct ftrace_ops___42 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___91 regex_lock;
};

struct pmu___42;

struct fasync_struct___90;

struct pid_namespace___47;

struct perf_cgroup___42;

struct perf_event___42 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___42 *group_leader;
	struct pmu___42 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___42 hw;
	struct perf_event_context___42 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___91 child_mutex;
	struct list_head child_list;
	struct perf_event___42 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___90 *owner;
	struct mutex___91 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___90 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___42 *);
	struct callback_head callback_head;
	struct pid_namespace___47 *ns;
	u64 id;
	perf_overflow_handler_t___42 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___32 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___42 ftrace_ops;
	struct perf_cgroup___42 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___44 {
	struct task_struct___90 *task;
	struct exec_domain___22 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___62;

struct attribute_group___62 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___62 **bin_attrs;
};

struct bin_attribute___62 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___90 *, struct kobject *, struct bin_attribute___62 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___90 *, struct kobject *, struct bin_attribute___62 *, char *, loff_t, size_t);
	int (*mmap)(struct file___90 *, struct kobject *, struct bin_attribute___62 *, struct vm_area_struct___95 *);
};

struct dentry___91;

struct path___90 {
	struct vfsmount *mnt;
	struct dentry___91 *dentry;
};

struct fown_struct___47 {
	rwlock_t lock;
	struct pid___47 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___91;

struct file_operations___90;

struct file___90 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___90 f_path;
	struct inode___91 *f_inode;
	const struct file_operations___90 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___47 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___90 *f_mapping;
	struct mutex___91 f_pos_lock;
};

struct vm_operations_struct___78;

struct vm_area_struct___95 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___95 *vm_next;
	struct vm_area_struct___95 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___95 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___78 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___90 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___69;

struct dev_pm_ops___69 {
	int (*prepare)(struct device___69 *);
	void (*complete)(struct device___69 *);
	int (*suspend)(struct device___69 *);
	int (*resume)(struct device___69 *);
	int (*freeze)(struct device___69 *);
	int (*thaw)(struct device___69 *);
	int (*poweroff)(struct device___69 *);
	int (*restore)(struct device___69 *);
	int (*suspend_late)(struct device___69 *);
	int (*resume_early)(struct device___69 *);
	int (*freeze_late)(struct device___69 *);
	int (*thaw_early)(struct device___69 *);
	int (*poweroff_late)(struct device___69 *);
	int (*restore_early)(struct device___69 *);
	int (*suspend_noirq)(struct device___69 *);
	int (*resume_noirq)(struct device___69 *);
	int (*freeze_noirq)(struct device___69 *);
	int (*thaw_noirq)(struct device___69 *);
	int (*poweroff_noirq)(struct device___69 *);
	int (*restore_noirq)(struct device___69 *);
	int (*runtime_suspend)(struct device___69 *);
	int (*runtime_resume)(struct device___69 *);
	int (*runtime_idle)(struct device___69 *);
};

struct device_type___69;

struct bus_type___69;

struct device_driver___69;

struct dev_pm_domain___69;

struct class___69;

struct device_rh___69;

struct device___69 {
	struct device___69 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___69 *type;
	struct mutex___91 mutex;
	struct bus_type___69 *bus;
	struct device_driver___69 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___69 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___9 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___69 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___69 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___69 *device_rh;
};

struct dev_pm_info_rh___69 {
	void (*set_latency_tolerance)(struct device___69 *, s32);
};

struct dev_pm_domain___69 {
	struct dev_pm_ops___69 ops;
};

struct zone___90;

struct lruvec___90 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___90 *zone;
};

struct pglist_data___90;

struct zone___90 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___90 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___90 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___90 {
	struct zone___90 *zone;
	int zone_idx;
};

struct zonelist___90 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___90 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___90 {
	struct zone___90 node_zones[4];
	struct zonelist___90 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___90 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___64;

struct x86_io_apic_ops___64 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___64 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___64;

struct irq_data___64 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___64 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___90 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___90 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___69 *, char *);
	ssize_t (*store)(struct bus_type___69 *, const char *, size_t);
};

struct device_attribute___69;

struct driver_attribute___69;

struct bus_type___69 {
	const char *name;
	const char *dev_name;
	struct device___69 *dev_root;
	struct bus_attribute___69 *bus_attrs;
	struct device_attribute___69 *dev_attrs;
	struct driver_attribute___69 *drv_attrs;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___69 *, struct device_driver___69 *);
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	int (*probe)(struct device___69 *);
	int (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*online)(struct device___69 *);
	int (*offline)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct device___69 *, struct device_attribute___69 *, char *);
	ssize_t (*store)(struct device___69 *, struct device_attribute___69 *, const char *, size_t);
};

struct driver_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___69 *, char *);
	ssize_t (*store)(struct device_driver___69 *, const char *, size_t);
};

struct device_driver___69 {
	const char *name;
	struct bus_type___69 *bus;
	struct module___47 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___69 *);
	int (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___69 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___69 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
};

struct class_attribute___69;

struct class___69 {
	const char *name;
	struct module___47 *owner;
	struct class_attribute___69 *class_attrs;
	struct device_attribute___69 *dev_attrs;
	const struct attribute_group___62 **dev_groups;
	struct bin_attribute___62 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *);
	void (*class_release)(struct class___69 *);
	void (*dev_release)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
	struct subsys_private *p;
};

struct class_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct class___69 *, struct class_attribute___69 *, char *);
	ssize_t (*store)(struct class___69 *, struct class_attribute___69 *, const char *, size_t);
	const void * (*namespace)(struct class___69 *, const struct class_attribute___69 *);
};

struct device_rh___69 {
	struct dev_pm_info_rh___69 power;
};

struct seq_operations___65;

struct seq_file___66 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___91 lock;
	const struct seq_operations___65 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___65 {
	void * (*start)(struct seq_file___66 *, loff_t *);
	void (*stop)(struct seq_file___66 *, void *);
	void * (*next)(struct seq_file___66 *, void *, loff_t *);
	int (*show)(struct seq_file___66 *, void *);
};

struct xol_area___90 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___90 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___78;

struct memcg_cache_params___78;

struct kmem_cache___78 {
	struct kmem_cache_cpu___78 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___78 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___90;

struct address_space___90 {
	struct inode___91 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___91 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___90 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___75;

struct vm_operations_struct___78 {
	void (*open)(struct vm_area_struct___95 *);
	void (*close)(struct vm_area_struct___95 *);
	int (*fault)(struct vm_area_struct___95 *, struct vm_fault___75 *);
	int (*page_mkwrite)(struct vm_area_struct___95 *, struct vm_fault___75 *);
	int (*access)(struct vm_area_struct___95 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___95 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___95 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___95 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___95 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___90 {
	struct task_struct___90 *task;
	struct core_thread___90 *next;
};

struct core_state___90 {
	atomic_t nr_threads;
	struct core_thread___90 dumper;
	struct completion startup;
};

struct linux_binprm___13;

struct coredump_params___12;

struct linux_binfmt___12 {
	struct list_head lh;
	struct module___47 *module;
	int (*load_binary)(struct linux_binprm___13 *);
	int (*load_shlib)(struct file___90 *);
	int (*core_dump)(struct coredump_params___12 *);
	long unsigned int min_coredump;
};

struct upid___47 {
	int nr;
	struct pid_namespace___47 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___47 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___90 *child_reaper;
	struct kmem_cache___78 *pid_cachep;
	unsigned int level;
	struct pid_namespace___47 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___91 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___47 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___47 numbers[1];
};

struct nsproxy___48 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___47 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___90 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___90 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___90 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___47 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___47 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___91 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___57;

struct css_set___57 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___57 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___42 {
	struct pmu___42 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___91 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___90 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___42 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct kmem_cache_cpu___78 {
	void **freelist;
	long unsigned int tid;
	struct page___90 *page;
	struct page___90 *partial;
};

struct memcg_cache_params___78 {
	bool is_root_cache;
	union {
		struct kmem_cache___78 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___78 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___57 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___91 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___91 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___91 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___90;

struct super_block___91;

struct dentry___91 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___91 *d_parent;
	struct qstr d_name;
	struct inode___91 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___90 *d_op;
	struct super_block___91 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___90;

struct file_lock___90;

struct dquot___90;

struct block_device___90;

struct inode___91 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___90 *i_op;
	struct super_block___91 *i_sb;
	struct address_space___90 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___91 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___90 *i_fop;
	struct file_lock___90 *i_flock;
	struct address_space___90 i_data;
	struct dquot___90 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___90 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___90 {
	int (*d_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_hash)(const struct dentry___91 *, struct qstr *);
	int (*d_compare)(const struct dentry___91 *, const struct dentry___91 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___91 *);
	void (*d_release)(struct dentry___91 *);
	void (*d_prune)(struct dentry___91 *);
	void (*d_iput)(struct dentry___91 *, struct inode___91 *);
	char * (*d_dname)(struct dentry___91 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___90 *);
	int (*d_manage)(struct dentry___91 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___90;

struct mem_dqinfo___90 {
	struct quota_format_type___90 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___90;

struct quota_info___90 {
	unsigned int flags;
	struct mutex___91 dqio_mutex;
	struct mutex___91 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___91 *files[2];
	struct mem_dqinfo___90 info[2];
	const struct quota_format_ops___90 *ops[2];
};

struct file_system_type___90;

struct super_operations___90;

struct dquot_operations___90;

struct quotactl_ops___90;

struct super_block___91 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___90 *s_type;
	const struct super_operations___90 *s_op;
	const struct dquot_operations___90 *dq_op;
	const struct quotactl_ops___90 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___91 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___57 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___90 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___90 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___91 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___90 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___90 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___91 *bd_inode;
	struct super_block___91 *bd_super;
	struct mutex___91 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___90 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___91 bd_fsfreeze_mutex;
};

struct cgroup___57;

struct cgroup_subsys_state___57 {
	struct cgroup___57 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___91 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___90 *ia_file;
};

struct dquot___90 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___91 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___91 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___90 {
	int qf_fmt_id;
	const struct quota_format_ops___90 *qf_ops;
	struct module___47 *qf_owner;
	struct quota_format_type___90 *qf_next;
};

struct quota_format_ops___90 {
	int (*check_quota_file)(struct super_block___91 *, int);
	int (*read_file_info)(struct super_block___91 *, int);
	int (*write_file_info)(struct super_block___91 *, int);
	int (*free_file_info)(struct super_block___91 *, int);
	int (*read_dqblk)(struct dquot___90 *);
	int (*commit_dqblk)(struct dquot___90 *);
	int (*release_dqblk)(struct dquot___90 *);
};

struct dquot_operations___90 {
	int (*write_dquot)(struct dquot___90 *);
	struct dquot___90 * (*alloc_dquot)(struct super_block___91 *, int);
	void (*destroy_dquot)(struct dquot___90 *);
	int (*acquire_dquot)(struct dquot___90 *);
	int (*release_dquot)(struct dquot___90 *);
	int (*mark_dirty)(struct dquot___90 *);
	int (*write_info)(struct super_block___91 *, int);
	qsize_t * (*get_reserved_space)(struct inode___91 *);
};

struct quotactl_ops___90 {
	int (*quota_on)(struct super_block___91 *, int, int, struct path___90 *);
	int (*quota_on_meta)(struct super_block___91 *, int, int);
	int (*quota_off)(struct super_block___91 *, int);
	int (*quota_sync)(struct super_block___91 *, int);
	int (*get_info)(struct super_block___91 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___91 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___91 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___91 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___91 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___91 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___91 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___91 *, unsigned int);
};

struct swap_info_struct___17;

struct address_space_operations___90 {
	int (*writepage)(struct page___90 *, struct writeback_control *);
	int (*readpage)(struct file___90 *, struct page___90 *);
	int (*writepages)(struct address_space___90 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___90 *);
	int (*readpages)(struct file___90 *, struct address_space___90 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___90 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___90 **, void **);
	int (*write_end)(struct file___90 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___90 *, void *);
	sector_t (*bmap)(struct address_space___90 *, sector_t);
	void (*invalidatepage)(struct page___90 *, long unsigned int);
	int (*releasepage)(struct page___90 *, gfp_t);
	void (*freepage)(struct page___90 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___90 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___90 *, struct page___90 *, struct page___90 *, enum migrate_mode);
	int (*launder_page)(struct page___90 *);
	int (*is_partially_uptodate)(struct page___90 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___90 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___90 *, struct page___90 *);
	int (*swap_activate)(struct swap_info_struct___17 *, struct file___90 *, sector_t *);
	void (*swap_deactivate)(struct file___90 *);
	void (*invalidatepage_range)(struct page___90 *, unsigned int, unsigned int);
};

struct swap_info_struct___17 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___90 *bdev;
	struct file___90 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___90 {
	struct dentry___91 * (*lookup)(struct inode___91 *, struct dentry___91 *, unsigned int);
	void * (*follow_link)(struct dentry___91 *, struct nameidata *);
	int (*permission)(struct inode___91 *, int);
	struct posix_acl * (*get_acl)(struct inode___91 *, int);
	int (*readlink)(struct dentry___91 *, char *, int);
	void (*put_link)(struct dentry___91 *, struct nameidata *, void *);
	int (*create)(struct inode___91 *, struct dentry___91 *, umode_t, bool);
	int (*link)(struct dentry___91 *, struct inode___91 *, struct dentry___91 *);
	int (*unlink)(struct inode___91 *, struct dentry___91 *);
	int (*symlink)(struct inode___91 *, struct dentry___91 *, const char *);
	int (*mkdir)(struct inode___91 *, struct dentry___91 *, umode_t);
	int (*rmdir)(struct inode___91 *, struct dentry___91 *);
	int (*mknod)(struct inode___91 *, struct dentry___91 *, umode_t, dev_t);
	int (*rename)(struct inode___91 *, struct dentry___91 *, struct inode___91 *, struct dentry___91 *);
	int (*setattr)(struct dentry___91 *, struct iattr___91 *);
	int (*getattr)(struct vfsmount *, struct dentry___91 *, struct kstat *);
	int (*setxattr)(struct dentry___91 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___91 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___91 *, char *, size_t);
	int (*removexattr)(struct dentry___91 *, const char *);
	int (*fiemap)(struct inode___91 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___91 *, struct timespec *, int);
	int (*atomic_open)(struct inode___91 *, struct dentry___91 *, struct file___90 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___54;

struct file_operations___90 {
	struct module___47 *owner;
	loff_t (*llseek)(struct file___90 *, loff_t, int);
	ssize_t (*read)(struct file___90 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___90 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___90 *, void *, filldir_t);
	unsigned int (*poll)(struct file___90 *, struct poll_table_struct___54 *);
	long int (*unlocked_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___90 *, struct vm_area_struct___95 *);
	int (*open)(struct inode___91 *, struct file___90 *);
	int (*flush)(struct file___90 *, fl_owner_t);
	int (*release)(struct inode___91 *, struct file___90 *);
	int (*fsync)(struct file___90 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___90 *, int);
	int (*lock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*sendpage)(struct file___90 *, struct page___90 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___90 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___90 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___90 *, long int, struct file_lock___90 **, void **);
		struct {
			int (*setlease)(struct file___90 *, long int, struct file_lock___90 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___90 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___66 *, struct file___90 *);
};

struct file_lock_operations___90;

struct lock_manager_operations___90;

struct file_lock___90 {
	struct file_lock___90 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___47 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___90 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___90 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___90 *fl_ops;
	const struct lock_manager_operations___90 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___90 {
	void (*fl_copy_lock)(struct file_lock___90 *, struct file_lock___90 *);
	void (*fl_release_private)(struct file_lock___90 *);
};

struct lock_manager_operations___90 {
	int (*lm_compare_owner)(struct file_lock___90 *, struct file_lock___90 *);
	long unsigned int (*lm_owner_key)(struct file_lock___90 *);
	void (*lm_notify)(struct file_lock___90 *);
	int (*lm_grant)(struct file_lock___90 *, struct file_lock___90 *, int);
	void (*lm_break)(struct file_lock___90 *);
	int (*lm_change)(struct file_lock___90 **, int);
};

struct fasync_struct___90 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___90 *fa_next;
	struct file___90 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___90 {
	const char *name;
	int fs_flags;
	struct dentry___91 * (*mount)(struct file_system_type___90 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___91 *);
	struct module___47 *owner;
	struct file_system_type___90 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___90 {
	struct inode___91 * (*alloc_inode)(struct super_block___91 *);
	void (*destroy_inode)(struct inode___91 *);
	void (*dirty_inode)(struct inode___91 *, int);
	int (*write_inode)(struct inode___91 *, struct writeback_control *);
	int (*drop_inode)(struct inode___91 *);
	void (*evict_inode)(struct inode___91 *);
	void (*put_super)(struct super_block___91 *);
	int (*sync_fs)(struct super_block___91 *, int);
	int (*freeze_fs)(struct super_block___91 *);
	int (*unfreeze_fs)(struct super_block___91 *);
	int (*statfs)(struct dentry___91 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___91 *, int *, char *);
	void (*umount_begin)(struct super_block___91 *);
	int (*show_options)(struct seq_file___66 *, struct dentry___91 *);
	int (*show_devname)(struct seq_file___66 *, struct dentry___91 *);
	int (*show_path)(struct seq_file___66 *, struct dentry___91 *);
	int (*show_stats)(struct seq_file___66 *, struct dentry___91 *);
	ssize_t (*quota_read)(struct super_block___91 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___91 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___91 *);
	int (*bdev_try_to_free_page)(struct super_block___91 *, struct page___90 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___91 *);
	void (*free_cached_objects)(struct super_block___91 *, int);
};

typedef void (*poll_queue_proc___55)(struct file___90 *, wait_queue_head_t *, struct poll_table_struct___54 *);

struct poll_table_struct___54 {
	poll_queue_proc___55 _qproc;
	long unsigned int _key;
};

struct cgroupfs_root___57;

struct cgroup___57 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___57 *parent;
	struct dentry___91 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___57 *subsys[11];
	struct cgroupfs_root___57 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___91 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___57 {
	struct super_block___91 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___57 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___24 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___91 *, struct file___90 *);
	ssize_t (*read)(struct cgroup___57 *, struct cftype___24 *, struct file___90 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___57 *, struct cftype___24 *);
	s64 (*read_s64)(struct cgroup___57 *, struct cftype___24 *);
	int (*read_map)(struct cgroup___57 *, struct cftype___24 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___57 *, struct cftype___24 *, struct seq_file___66 *);
	ssize_t (*write)(struct cgroup___57 *, struct cftype___24 *, struct file___90 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___57 *, struct cftype___24 *, u64);
	int (*write_s64)(struct cgroup___57 *, struct cftype___24 *, s64);
	int (*write_string)(struct cgroup___57 *, struct cftype___24 *, const char *);
	int (*trigger)(struct cgroup___57 *, unsigned int);
	int (*release)(struct inode___91 *, struct file___90 *);
	int (*register_event)(struct cgroup___57 *, struct cftype___24 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___57 *, struct cftype___24 *, struct eventfd_ctx *);
};

struct cftype_set___22 {
	struct list_head node;
	struct cftype___24 *cfts;
};

struct task_and_cgroup___22 {
	struct task_struct___90 *task;
	struct cgroup___57 *cgrp;
	struct css_set___57 *cg;
};

struct cgroup_taskset___22 {
	struct task_and_cgroup___22 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___57 *cur_cgrp;
};

struct cgroup_subsys___22 {
	struct cgroup_subsys_state___57 * (*css_alloc)(struct cgroup___57 *);
	int (*css_online)(struct cgroup___57 *);
	void (*css_offline)(struct cgroup___57 *);
	void (*css_free)(struct cgroup___57 *);
	int (*can_attach)(struct cgroup___57 *, struct cgroup_taskset___22 *);
	void (*cancel_attach)(struct cgroup___57 *, struct cgroup_taskset___22 *);
	void (*attach)(struct cgroup___57 *, struct cgroup_taskset___22 *);
	void (*fork)(struct task_struct___90 *);
	void (*exit)(struct cgroup___57 *, struct cgroup___57 *, struct task_struct___90 *);
	void (*bind)(struct cgroup___57 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___57 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___24 *base_cftypes;
	struct cftype_set___22 base_cftset;
	struct module___47 *module;
};

struct irq_chip___64 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___64 *);
	void (*irq_shutdown)(struct irq_data___64 *);
	void (*irq_enable)(struct irq_data___64 *);
	void (*irq_disable)(struct irq_data___64 *);
	void (*irq_ack)(struct irq_data___64 *);
	void (*irq_mask)(struct irq_data___64 *);
	void (*irq_mask_ack)(struct irq_data___64 *);
	void (*irq_unmask)(struct irq_data___64 *);
	void (*irq_eoi)(struct irq_data___64 *);
	int (*irq_set_affinity)(struct irq_data___64 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___64 *);
	int (*irq_set_type)(struct irq_data___64 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___64 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___64 *);
	void (*irq_bus_sync_unlock)(struct irq_data___64 *);
	void (*irq_cpu_online)(struct irq_data___64 *);
	void (*irq_cpu_offline)(struct irq_data___64 *);
	void (*irq_suspend)(struct irq_data___64 *);
	void (*irq_resume)(struct irq_data___64 *);
	void (*irq_pm_shutdown)(struct irq_data___64 *);
	void (*irq_print_chip)(struct irq_data___64 *, struct seq_file___66 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___64 *, void *);
	long unsigned int flags;
};

struct vm_fault___75 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___90 *page;
};

struct module_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___46 *, struct module_kobject___46 *, char *);
	ssize_t (*store)(struct module_attribute___46 *, struct module_kobject___46 *, const char *, size_t);
	void (*setup)(struct module___47 *, const char *);
	int (*test)(struct module___47 *);
	void (*free)(struct module___47 *);
};

struct trace_event_functions___32;

struct trace_event___32 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___32 *funcs;
};

struct ftrace_event_class___32;

struct ftrace_event_call___32 {
	struct list_head list;
	struct ftrace_event_class___32 *class;
	char *name;
	struct trace_event___32 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct ftrace_hash {
	long unsigned int size_bits;
	struct hlist_head *buckets;
	long unsigned int count;
	struct callback_head rcu;
};

struct ftrace_func_command {
	struct list_head list;
	char *name;
	int (*func)(struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops {
	void (*func)(long unsigned int, long unsigned int, void **);
	int (*init)(struct ftrace_probe_ops *, long unsigned int, void **);
	void (*free)(struct ftrace_probe_ops *, long unsigned int, void **);
	int (*print)(struct seq_file___66 *, long unsigned int, struct ftrace_probe_ops *, void *);
};

enum {
	FTRACE_UPDATE_CALLS = 1,
	FTRACE_DISABLE_CALLS = 2,
	FTRACE_UPDATE_TRACE_FUNC = 4,
	FTRACE_START_FUNC_RET = 8,
	FTRACE_STOP_FUNC_RET = 16,
};

enum {
	FTRACE_ITER_FILTER = 1,
	FTRACE_ITER_NOTRACE = 2,
	FTRACE_ITER_PRINTALL = 4,
	FTRACE_ITER_DO_HASH = 8,
	FTRACE_ITER_HASH = 16,
	FTRACE_ITER_ENABLED = 32,
};

struct ftrace_graph_ret {
	long unsigned int func;
	long long unsigned int calltime;
	long long unsigned int rettime;
	long unsigned int overrun;
	int depth;
};

typedef void (*trace_func_graph_ret_t)(struct ftrace_graph_ret *);

enum {
	TSK_TRACE_FL_TRACE = 1,
	TSK_TRACE_FL_GRAPH = 2,
};

struct linux_binprm___13 {
	char buf[128];
	struct vm_area_struct___95 *vma;
	long unsigned int vma_pages;
	struct mm_struct___95 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___90 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___12 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___90 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct perf_cpu_context___42;

struct pmu___42 {
	struct list_head entry;
	struct device___69 *dev;
	const struct attribute_group___62 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___42 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___42 *);
	void (*pmu_disable)(struct pmu___42 *);
	int (*event_init)(struct perf_event___42 *);
	int (*add)(struct perf_event___42 *, int);
	void (*del)(struct perf_event___42 *, int);
	void (*start)(struct perf_event___42 *, int);
	void (*stop)(struct perf_event___42 *, int);
	void (*read)(struct perf_event___42 *);
	void (*start_txn)(struct pmu___42 *);
	int (*commit_txn)(struct pmu___42 *);
	void (*cancel_txn)(struct pmu___42 *);
	int (*event_idx)(struct perf_event___42 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___47 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___42 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___42 *);
};

struct perf_cpu_context___42 {
	struct perf_event_context___42 ctx;
	struct perf_event_context___42 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___42 *unique_pmu;
	struct perf_cgroup___42 *cgrp;
};

struct filter_pred;

struct event_filter {
	int n_preds;
	int a_preds;
	struct filter_pred *preds;
	struct filter_pred *root;
	char *filter_string;
};

struct perf_cgroup___42 {
	struct cgroup_subsys_state___57 css;
	struct perf_cgroup_info *info;
};

struct trace_array___2;

struct tracer___2;

struct trace_buffer___2;

struct trace_iterator___32 {
	struct trace_array___2 *tr;
	struct tracer___2 *trace;
	struct trace_buffer___2 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___91 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu;

struct trace_buffer___2 {
	struct trace_array___2 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu {
	struct trace_array___2 *tr;
	struct dentry___91 *dir;
	int cpu;
};

struct trace_array___2 {
	struct list_head list;
	char *name;
	struct trace_buffer___2 trace_buffer;
	struct trace_buffer___2 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___2 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___91 *dir;
	struct dentry___91 *options;
	struct dentry___91 *percpu_dir;
	struct dentry___91 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___90 *waiter;
	int ref;
};

struct tracer_flags;

struct tracer___2 {
	const char *name;
	int (*init)(struct trace_array___2 *);
	void (*reset)(struct trace_array___2 *);
	void (*start)(struct trace_array___2 *);
	void (*stop)(struct trace_array___2 *);
	void (*open)(struct trace_iterator___32 *);
	void (*pipe_open)(struct trace_iterator___32 *);
	int (*wait_pipe)(struct trace_iterator___32 *);
	void (*close)(struct trace_iterator___32 *);
	void (*pipe_close)(struct trace_iterator___32 *);
	ssize_t (*read)(struct trace_iterator___32 *, struct file___90 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___32 *, struct file___90 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___66 *);
	enum print_line_t (*print_line)(struct trace_iterator___32 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___2 *, u32, int);
	struct tracer___2 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___32)(struct trace_iterator___32 *, int, struct trace_event___32 *);

struct trace_event_functions___32 {
	trace_print_func___32 trace;
	trace_print_func___32 raw;
	trace_print_func___32 hex;
	trace_print_func___32 binary;
};

struct ftrace_event_class___32 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___32 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___32 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___32 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___32 *);
};

struct trace_array_cpu {
	struct trace_cpu trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

struct tracer_opt {
	const char *name;
	u32 bit;
};

struct tracer_flags {
	u32 val;
	struct tracer_opt *opts;
};

enum {
	TRACE_BUFFER_BIT = 0,
	TRACE_BUFFER_NMI_BIT = 1,
	TRACE_BUFFER_IRQ_BIT = 2,
	TRACE_BUFFER_SIRQ_BIT = 3,
	TRACE_FTRACE_BIT = 4,
	TRACE_FTRACE_NMI_BIT = 5,
	TRACE_FTRACE_IRQ_BIT = 6,
	TRACE_FTRACE_SIRQ_BIT = 7,
	TRACE_GLOBAL_BIT = 8,
	TRACE_GLOBAL_NMI_BIT = 9,
	TRACE_GLOBAL_IRQ_BIT = 10,
	TRACE_GLOBAL_SIRQ_BIT = 11,
	TRACE_INTERNAL_BIT = 12,
	TRACE_INTERNAL_NMI_BIT = 13,
	TRACE_INTERNAL_IRQ_BIT = 14,
	TRACE_INTERNAL_SIRQ_BIT = 15,
	TRACE_CONTROL_BIT = 16,
	TRACE_IRQ_BIT = 17,
};

struct trace_parser {
	bool cont;
	char *buffer;
	unsigned int idx;
	unsigned int size;
};

enum trace_iterator_flags {
	TRACE_ITER_PRINT_PARENT = 1,
	TRACE_ITER_SYM_OFFSET = 2,
	TRACE_ITER_SYM_ADDR = 4,
	TRACE_ITER_VERBOSE = 8,
	TRACE_ITER_RAW = 16,
	TRACE_ITER_HEX = 32,
	TRACE_ITER_BIN = 64,
	TRACE_ITER_BLOCK = 128,
	TRACE_ITER_STACKTRACE = 256,
	TRACE_ITER_PRINTK = 512,
	TRACE_ITER_PREEMPTONLY = 1024,
	TRACE_ITER_BRANCH = 2048,
	TRACE_ITER_ANNOTATE = 4096,
	TRACE_ITER_USERSTACKTRACE = 8192,
	TRACE_ITER_SYM_USEROBJ = 16384,
	TRACE_ITER_PRINTK_MSGONLY = 32768,
	TRACE_ITER_CONTEXT_INFO = 65536,
	TRACE_ITER_LATENCY_FMT = 131072,
	TRACE_ITER_SLEEP_TIME = 262144,
	TRACE_ITER_GRAPH_TIME = 524288,
	TRACE_ITER_RECORD_CMD = 1048576,
	TRACE_ITER_OVERWRITE = 2097152,
	TRACE_ITER_STOP_ON_FREE = 4194304,
	TRACE_ITER_IRQ_INFO = 8388608,
	TRACE_ITER_MARKERS = 16777216,
	TRACE_ITER_FUNCTION = 33554432,
};

struct ftrace_event_field {
	struct list_head link;
	const char *name;
	const char *type;
	int filter_type;
	int offset;
	int size;
	int is_signed;
};

typedef int (*filter_pred_fn_t)(struct filter_pred *, void *);

struct regex;

typedef int (*regex_match_func)(char *, struct regex *, int);

struct regex {
	char pattern[256];
	int len;
	int field_len;
	regex_match_func match;
};

struct filter_pred {
	filter_pred_fn_t fn;
	u64 val;
	struct regex regex;
	short unsigned int *ops;
	struct ftrace_event_field *field;
	int offset;
	int not;
	int op;
	short unsigned int index;
	short unsigned int parent;
	short unsigned int left;
	short unsigned int right;
};

enum regex_type {
	MATCH_FULL = 0,
	MATCH_FRONT_ONLY = 1,
	MATCH_MIDDLE_ONLY = 2,
	MATCH_END_ONLY = 3,
};

struct tracer_stat {
	const char *name;
	void * (*stat_start)(struct tracer_stat *);
	void * (*stat_next)(void *, int);
	int (*stat_cmp)(void *, void *);
	int (*stat_show)(struct seq_file___66 *, void *);
	void (*stat_release)(void *);
	int (*stat_headers)(struct seq_file___66 *);
};

struct ftrace_pid {
	struct list_head list;
	struct pid___47 *pid;
};

struct ftrace_profile {
	struct hlist_node node;
	long unsigned int ip;
	long unsigned int counter;
	long long unsigned int time;
	long long unsigned int time_squared;
};

struct ftrace_profile_page {
	struct ftrace_profile_page *next;
	long unsigned int index;
	struct ftrace_profile records[0];
};

struct ftrace_profile_stat {
	atomic_t disabled;
	struct hlist_head *hash;
	struct ftrace_profile_page *pages;
	struct ftrace_profile_page *start;
	struct tracer_stat stat;
};

struct ftrace_func_probe {
	struct hlist_node node;
	struct ftrace_probe_ops *ops;
	long unsigned int flags;
	long unsigned int ip;
	void *data;
	struct list_head free_list;
};

struct ftrace_func_entry {
	struct hlist_node hlist;
	long unsigned int ip;
};

struct ftrace_page {
	struct ftrace_page *next;
	struct dyn_ftrace *records;
	int index;
	int size;
};

struct ftrace_rec_iter___2 {
	struct ftrace_page *pg;
	int index;
};

struct ftrace_iterator {
	loff_t pos;
	loff_t func_pos;
	struct ftrace_page *pg;
	struct dyn_ftrace *func;
	struct ftrace_func_probe *probe;
	struct trace_parser parser;
	struct ftrace_hash *hash;
	struct ftrace_ops___42 *ops;
	int hidx;
	int idx;
	unsigned int flags;
};

enum {
	PROBE_TEST_FUNC = 1,
	PROBE_TEST_DATA = 2,
};

struct page___91;

typedef struct page___91 *pgtable_t___91;

struct address_space___91;

struct kmem_cache___79;

struct page___91 {
	long unsigned int flags;
	struct address_space___91 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___91 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___91 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___79 *slab_cache;
		struct page___91 *first_page;
	};
	long: 64;
};

struct thread_struct___43;

struct task_struct___91;

struct pv_cpu_ops___91 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___43 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___43 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___91 *);
	void (*end_context_switch)(struct task_struct___91 *);
};

struct perf_event___43;

struct thread_struct___43 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___43 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___48;

struct pid_link___48 {
	struct hlist_node node;
	struct pid___48 *pid;
};

struct mutex___92 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___91 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___87 {
	struct page___91 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___96;

struct nsproxy___49;

struct signal_struct___91;

struct css_set___58;

struct perf_event_context___43;

struct task_struct___91 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___91 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___96 *mm;
	struct mm_struct___96 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___91 *real_parent;
	struct task_struct___91 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___91 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___48 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___91 = 0,
		VTIME_USER___91 = 1,
		VTIME_SYS___91 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___43 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___49 *nsproxy;
	struct signal_struct___91 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___58 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___43 *perf_event_ctxp[2];
	struct mutex___92 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___87 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___96 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___96 *, struct mm_struct___96 *);
	void (*dup_mmap)(struct mm_struct___96 *, struct mm_struct___96 *);
	void (*exit_mmap)(struct mm_struct___96 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___96 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___96 *);
	void (*pgd_free)(struct mm_struct___96 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___96 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___96 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___96 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___96 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___96 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___96 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___96 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___96 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___96 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___96 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___96 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___92 lock;
	void *vdso;
} mm_context_t___92;

struct xol_area___91;

struct uprobes_state___91 {
	struct xol_area___91 *xol_area;
};

struct vm_area_struct___96;

struct file___91;

struct core_state___91;

struct mm_struct___96 {
	struct vm_area_struct___96 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___96 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___96 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___92 context;
	long unsigned int flags;
	struct core_state___91 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___91 *owner;
	struct file___91 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___91 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___48;

struct exec_domain___23 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___48 *module;
	struct exec_domain___23 *next;
};

struct module_kobject___47 {
	struct kobject kobj;
	struct module___48 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___47;

struct ftrace_event_call___33;

struct module___48 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___47 mkobj;
	struct module_attribute___47 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___33 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___91 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___43 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___91 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___91 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___91 *target;
};

typedef void (*perf_overflow_handler_t___43)(struct perf_event___43 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___43;

typedef void (*ftrace_func_t___43)(long unsigned int, long unsigned int, struct ftrace_ops___43 *, struct pt_regs *);

struct ftrace_ops___43 {
	ftrace_func_t___43 func;
	struct ftrace_ops___43 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___92 regex_lock;
};

struct pmu___43;

struct ring_buffer___2;

struct fasync_struct___91;

struct pid_namespace___48;

struct perf_cgroup___43;

struct perf_event___43 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___43 *group_leader;
	struct pmu___43 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___43 hw;
	struct perf_event_context___43 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___92 child_mutex;
	struct list_head child_list;
	struct perf_event___43 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___91 *owner;
	struct mutex___92 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer___2 *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___91 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___43 *);
	struct callback_head callback_head;
	struct pid_namespace___48 *ns;
	u64 id;
	perf_overflow_handler_t___43 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___33 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___43 ftrace_ops;
	struct perf_cgroup___43 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___45 {
	struct task_struct___91 *task;
	struct exec_domain___23 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___91 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___91 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___79;

struct memcg_cache_params___79;

struct kmem_cache___79 {
	struct kmem_cache_cpu___79 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___79 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___92;

struct address_space_operations___91;

struct address_space___91 {
	struct inode___92 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___92 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___91 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___92;

struct path___91 {
	struct vfsmount *mnt;
	struct dentry___92 *dentry;
};

struct fown_struct___48 {
	rwlock_t lock;
	struct pid___48 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___91;

struct file___91 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___91 f_path;
	struct inode___92 *f_inode;
	const struct file_operations___91 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___48 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___91 *f_mapping;
	struct mutex___92 f_pos_lock;
};

struct vm_operations_struct___79;

struct vm_area_struct___96 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___96 *vm_next;
	struct vm_area_struct___96 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___96 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___79 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___91 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___76;

struct vm_operations_struct___79 {
	void (*open)(struct vm_area_struct___96 *);
	void (*close)(struct vm_area_struct___96 *);
	int (*fault)(struct vm_area_struct___96 *, struct vm_fault___76 *);
	int (*page_mkwrite)(struct vm_area_struct___96 *, struct vm_fault___76 *);
	int (*access)(struct vm_area_struct___96 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___96 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___96 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___96 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___96 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___91 {
	struct task_struct___91 *task;
	struct core_thread___91 *next;
};

struct core_state___91 {
	atomic_t nr_threads;
	struct core_thread___91 dumper;
	struct completion startup;
};

struct zone___91;

struct lruvec___91 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___91 *zone;
};

struct pglist_data___91;

struct zone___91 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___91 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___91 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___91 {
	struct zone___91 *zone;
	int zone_idx;
};

struct zonelist___91 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___91 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___91 {
	struct zone___91 node_zones[4];
	struct zonelist___91 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___91 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___65;

struct x86_io_apic_ops___65 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___65 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___65;

struct irq_data___65 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___65 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___70;

struct dev_pm_ops___70 {
	int (*prepare)(struct device___70 *);
	void (*complete)(struct device___70 *);
	int (*suspend)(struct device___70 *);
	int (*resume)(struct device___70 *);
	int (*freeze)(struct device___70 *);
	int (*thaw)(struct device___70 *);
	int (*poweroff)(struct device___70 *);
	int (*restore)(struct device___70 *);
	int (*suspend_late)(struct device___70 *);
	int (*resume_early)(struct device___70 *);
	int (*freeze_late)(struct device___70 *);
	int (*thaw_early)(struct device___70 *);
	int (*poweroff_late)(struct device___70 *);
	int (*restore_early)(struct device___70 *);
	int (*suspend_noirq)(struct device___70 *);
	int (*resume_noirq)(struct device___70 *);
	int (*freeze_noirq)(struct device___70 *);
	int (*thaw_noirq)(struct device___70 *);
	int (*poweroff_noirq)(struct device___70 *);
	int (*restore_noirq)(struct device___70 *);
	int (*runtime_suspend)(struct device___70 *);
	int (*runtime_resume)(struct device___70 *);
	int (*runtime_idle)(struct device___70 *);
};

struct device_type___70;

struct bus_type___70;

struct device_driver___70;

struct dev_pm_domain___70;

struct class___70;

struct attribute_group___63;

struct device_rh___70;

struct device___70 {
	struct device___70 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___70 *type;
	struct mutex___92 mutex;
	struct bus_type___70 *bus;
	struct device_driver___70 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___70 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___70 *class;
	const struct attribute_group___63 **groups;
	void (*release)(struct device___70 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___70 *device_rh;
};

struct dev_pm_info_rh___70 {
	void (*set_latency_tolerance)(struct device___70 *, s32);
};

struct dev_pm_domain___70 {
	struct dev_pm_ops___70 ops;
};

struct smp_ops___91 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___91 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vm_fault___76 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___91 *page;
};

struct seq_operations___66;

struct seq_file___67 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___92 lock;
	const struct seq_operations___66 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___66 {
	void * (*start)(struct seq_file___67 *, loff_t *);
	void (*stop)(struct seq_file___67 *, void *);
	void * (*next)(struct seq_file___67 *, void *, loff_t *);
	int (*show)(struct seq_file___67 *, void *);
};

struct dentry_operations___91;

struct super_block___92;

struct dentry___92 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___92 *d_parent;
	struct qstr d_name;
	struct inode___92 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___91 *d_op;
	struct super_block___92 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___91;

struct file_lock___91;

struct dquot___91;

struct block_device___91;

struct inode___92 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___91 *i_op;
	struct super_block___92 *i_sb;
	struct address_space___91 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___92 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___91 *i_fop;
	struct file_lock___91 *i_flock;
	struct address_space___91 i_data;
	struct dquot___91 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___91 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___91 {
	int (*d_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_hash)(const struct dentry___92 *, struct qstr *);
	int (*d_compare)(const struct dentry___92 *, const struct dentry___92 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___92 *);
	void (*d_release)(struct dentry___92 *);
	void (*d_prune)(struct dentry___92 *);
	void (*d_iput)(struct dentry___92 *, struct inode___92 *);
	char * (*d_dname)(struct dentry___92 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___91 *);
	int (*d_manage)(struct dentry___92 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___91;

struct mem_dqinfo___91 {
	struct quota_format_type___91 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___91;

struct quota_info___91 {
	unsigned int flags;
	struct mutex___92 dqio_mutex;
	struct mutex___92 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___92 *files[2];
	struct mem_dqinfo___91 info[2];
	const struct quota_format_ops___91 *ops[2];
};

struct file_system_type___91;

struct super_operations___91;

struct dquot_operations___91;

struct quotactl_ops___91;

struct xattr_handler___58;

struct super_block___92 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___91 *s_type;
	const struct super_operations___91 *s_op;
	const struct dquot_operations___91 *dq_op;
	const struct quotactl_ops___91 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___92 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___58 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___91 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___91 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___92 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___91 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___48 {
	int nr;
	struct pid_namespace___48 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___48 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___91 *child_reaper;
	struct kmem_cache___79 *pid_cachep;
	unsigned int level;
	struct pid_namespace___48 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___92 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___48 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___48 numbers[1];
};

struct block_device___91 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___92 *bd_inode;
	struct super_block___92 *bd_super;
	struct mutex___92 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___91 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___92 bd_fsfreeze_mutex;
};

struct cgroup___58;

struct cgroup_subsys_state___58 {
	struct cgroup___58 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___92 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___91 *ia_file;
};

struct dquot___91 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___92 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___92 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___91 {
	int qf_fmt_id;
	const struct quota_format_ops___91 *qf_ops;
	struct module___48 *qf_owner;
	struct quota_format_type___91 *qf_next;
};

struct quota_format_ops___91 {
	int (*check_quota_file)(struct super_block___92 *, int);
	int (*read_file_info)(struct super_block___92 *, int);
	int (*write_file_info)(struct super_block___92 *, int);
	int (*free_file_info)(struct super_block___92 *, int);
	int (*read_dqblk)(struct dquot___91 *);
	int (*commit_dqblk)(struct dquot___91 *);
	int (*release_dqblk)(struct dquot___91 *);
};

struct dquot_operations___91 {
	int (*write_dquot)(struct dquot___91 *);
	struct dquot___91 * (*alloc_dquot)(struct super_block___92 *, int);
	void (*destroy_dquot)(struct dquot___91 *);
	int (*acquire_dquot)(struct dquot___91 *);
	int (*release_dquot)(struct dquot___91 *);
	int (*mark_dirty)(struct dquot___91 *);
	int (*write_info)(struct super_block___92 *, int);
	qsize_t * (*get_reserved_space)(struct inode___92 *);
};

struct quotactl_ops___91 {
	int (*quota_on)(struct super_block___92 *, int, int, struct path___91 *);
	int (*quota_on_meta)(struct super_block___92 *, int, int);
	int (*quota_off)(struct super_block___92 *, int);
	int (*quota_sync)(struct super_block___92 *, int);
	int (*get_info)(struct super_block___92 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___92 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___92 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___92 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___92 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___92 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___92 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___92 *, unsigned int);
};

struct address_space_operations___91 {
	int (*writepage)(struct page___91 *, struct writeback_control *);
	int (*readpage)(struct file___91 *, struct page___91 *);
	int (*writepages)(struct address_space___91 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___91 *);
	int (*readpages)(struct file___91 *, struct address_space___91 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___91 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___91 **, void **);
	int (*write_end)(struct file___91 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___91 *, void *);
	sector_t (*bmap)(struct address_space___91 *, sector_t);
	void (*invalidatepage)(struct page___91 *, long unsigned int);
	int (*releasepage)(struct page___91 *, gfp_t);
	void (*freepage)(struct page___91 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___91 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___91 *, struct page___91 *, struct page___91 *, enum migrate_mode);
	int (*launder_page)(struct page___91 *);
	int (*is_partially_uptodate)(struct page___91 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___91 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___91 *, struct page___91 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___91 *, sector_t *);
	void (*swap_deactivate)(struct file___91 *);
	void (*invalidatepage_range)(struct page___91 *, unsigned int, unsigned int);
};

struct inode_operations___91 {
	struct dentry___92 * (*lookup)(struct inode___92 *, struct dentry___92 *, unsigned int);
	void * (*follow_link)(struct dentry___92 *, struct nameidata *);
	int (*permission)(struct inode___92 *, int);
	struct posix_acl * (*get_acl)(struct inode___92 *, int);
	int (*readlink)(struct dentry___92 *, char *, int);
	void (*put_link)(struct dentry___92 *, struct nameidata *, void *);
	int (*create)(struct inode___92 *, struct dentry___92 *, umode_t, bool);
	int (*link)(struct dentry___92 *, struct inode___92 *, struct dentry___92 *);
	int (*unlink)(struct inode___92 *, struct dentry___92 *);
	int (*symlink)(struct inode___92 *, struct dentry___92 *, const char *);
	int (*mkdir)(struct inode___92 *, struct dentry___92 *, umode_t);
	int (*rmdir)(struct inode___92 *, struct dentry___92 *);
	int (*mknod)(struct inode___92 *, struct dentry___92 *, umode_t, dev_t);
	int (*rename)(struct inode___92 *, struct dentry___92 *, struct inode___92 *, struct dentry___92 *);
	int (*setattr)(struct dentry___92 *, struct iattr___92 *);
	int (*getattr)(struct vfsmount *, struct dentry___92 *, struct kstat *);
	int (*setxattr)(struct dentry___92 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___92 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___92 *, char *, size_t);
	int (*removexattr)(struct dentry___92 *, const char *);
	int (*fiemap)(struct inode___92 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___92 *, struct timespec *, int);
	int (*atomic_open)(struct inode___92 *, struct dentry___92 *, struct file___91 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___55;

struct file_operations___91 {
	struct module___48 *owner;
	loff_t (*llseek)(struct file___91 *, loff_t, int);
	ssize_t (*read)(struct file___91 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___91 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___91 *, void *, filldir_t);
	unsigned int (*poll)(struct file___91 *, struct poll_table_struct___55 *);
	long int (*unlocked_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___91 *, struct vm_area_struct___96 *);
	int (*open)(struct inode___92 *, struct file___91 *);
	int (*flush)(struct file___91 *, fl_owner_t);
	int (*release)(struct inode___92 *, struct file___91 *);
	int (*fsync)(struct file___91 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___91 *, int);
	int (*lock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*sendpage)(struct file___91 *, struct page___91 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___91 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___91 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___91 *, long int, struct file_lock___91 **, void **);
		struct {
			int (*setlease)(struct file___91 *, long int, struct file_lock___91 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___91 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___67 *, struct file___91 *);
};

struct file_lock_operations___91;

struct lock_manager_operations___91;

struct file_lock___91 {
	struct file_lock___91 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___48 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___91 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___91 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___91 *fl_ops;
	const struct lock_manager_operations___91 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___91 {
	void (*fl_copy_lock)(struct file_lock___91 *, struct file_lock___91 *);
	void (*fl_release_private)(struct file_lock___91 *);
};

struct lock_manager_operations___91 {
	int (*lm_compare_owner)(struct file_lock___91 *, struct file_lock___91 *);
	long unsigned int (*lm_owner_key)(struct file_lock___91 *);
	void (*lm_notify)(struct file_lock___91 *);
	int (*lm_grant)(struct file_lock___91 *, struct file_lock___91 *, int);
	void (*lm_break)(struct file_lock___91 *);
	int (*lm_change)(struct file_lock___91 **, int);
};

struct fasync_struct___91 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___91 *fa_next;
	struct file___91 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___91 {
	const char *name;
	int fs_flags;
	struct dentry___92 * (*mount)(struct file_system_type___91 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___92 *);
	struct module___48 *owner;
	struct file_system_type___91 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___91 {
	struct inode___92 * (*alloc_inode)(struct super_block___92 *);
	void (*destroy_inode)(struct inode___92 *);
	void (*dirty_inode)(struct inode___92 *, int);
	int (*write_inode)(struct inode___92 *, struct writeback_control *);
	int (*drop_inode)(struct inode___92 *);
	void (*evict_inode)(struct inode___92 *);
	void (*put_super)(struct super_block___92 *);
	int (*sync_fs)(struct super_block___92 *, int);
	int (*freeze_fs)(struct super_block___92 *);
	int (*unfreeze_fs)(struct super_block___92 *);
	int (*statfs)(struct dentry___92 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___92 *, int *, char *);
	void (*umount_begin)(struct super_block___92 *);
	int (*show_options)(struct seq_file___67 *, struct dentry___92 *);
	int (*show_devname)(struct seq_file___67 *, struct dentry___92 *);
	int (*show_path)(struct seq_file___67 *, struct dentry___92 *);
	int (*show_stats)(struct seq_file___67 *, struct dentry___92 *);
	ssize_t (*quota_read)(struct super_block___92 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___92 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___92 *);
	int (*bdev_try_to_free_page)(struct super_block___92 *, struct page___91 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___92 *);
	void (*free_cached_objects)(struct super_block___92 *, int);
};

struct xattr_handler___58 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___92 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___92 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___92 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___56)(struct file___91 *, wait_queue_head_t *, struct poll_table_struct___55 *);

struct poll_table_struct___55 {
	poll_queue_proc___56 _qproc;
	long unsigned int _key;
};

struct nsproxy___49 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___48 *pid_ns;
	struct net *net_ns;
};

typedef struct poll_table_struct___55 poll_table___6;

enum ring_buffer_type {
	RINGBUF_TYPE_DATA_TYPE_LEN_MAX = 28,
	RINGBUF_TYPE_PADDING = 29,
	RINGBUF_TYPE_TIME_EXTEND = 30,
	RINGBUF_TYPE_TIME_STAMP = 31,
};

enum ring_buffer_flags {
	RB_FL_OVERWRITE = 1,
};

struct irq_chip___65 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___65 *);
	void (*irq_shutdown)(struct irq_data___65 *);
	void (*irq_enable)(struct irq_data___65 *);
	void (*irq_disable)(struct irq_data___65 *);
	void (*irq_ack)(struct irq_data___65 *);
	void (*irq_mask)(struct irq_data___65 *);
	void (*irq_mask_ack)(struct irq_data___65 *);
	void (*irq_unmask)(struct irq_data___65 *);
	void (*irq_eoi)(struct irq_data___65 *);
	int (*irq_set_affinity)(struct irq_data___65 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___65 *);
	int (*irq_set_type)(struct irq_data___65 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___65 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___65 *);
	void (*irq_bus_sync_unlock)(struct irq_data___65 *);
	void (*irq_cpu_online)(struct irq_data___65 *);
	void (*irq_cpu_offline)(struct irq_data___65 *);
	void (*irq_suspend)(struct irq_data___65 *);
	void (*irq_resume)(struct irq_data___65 *);
	void (*irq_pm_shutdown)(struct irq_data___65 *);
	void (*irq_print_chip)(struct irq_data___65 *, struct seq_file___67 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___65 *, void *);
	long unsigned int flags;
};

struct signal_struct___91 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___91 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___91 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___48 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___48 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___92 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___58 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___58 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___43 {
	struct pmu___43 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___92 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___91 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___43 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___63;

struct attribute_group___63 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___63 **bin_attrs;
};

struct bin_attribute___63 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___91 *, struct kobject *, struct bin_attribute___63 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___91 *, struct kobject *, struct bin_attribute___63 *, char *, loff_t, size_t);
	int (*mmap)(struct file___91 *, struct kobject *, struct bin_attribute___63 *, struct vm_area_struct___96 *);
};

struct bus_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___70 *, char *);
	ssize_t (*store)(struct bus_type___70 *, const char *, size_t);
};

struct device_attribute___70;

struct driver_attribute___70;

struct bus_type___70 {
	const char *name;
	const char *dev_name;
	struct device___70 *dev_root;
	struct bus_attribute___70 *bus_attrs;
	struct device_attribute___70 *dev_attrs;
	struct driver_attribute___70 *drv_attrs;
	const struct attribute_group___63 **bus_groups;
	const struct attribute_group___63 **dev_groups;
	const struct attribute_group___63 **drv_groups;
	int (*match)(struct device___70 *, struct device_driver___70 *);
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	int (*probe)(struct device___70 *);
	int (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*online)(struct device___70 *);
	int (*offline)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct device___70 *, struct device_attribute___70 *, char *);
	ssize_t (*store)(struct device___70 *, struct device_attribute___70 *, const char *, size_t);
};

struct driver_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___70 *, char *);
	ssize_t (*store)(struct device_driver___70 *, const char *, size_t);
};

struct device_driver___70 {
	const char *name;
	struct bus_type___70 *bus;
	struct module___48 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___70 *);
	int (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	const struct attribute_group___63 **groups;
	const struct dev_pm_ops___70 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___70 {
	const char *name;
	const struct attribute_group___63 **groups;
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
};

struct class_attribute___70;

struct class___70 {
	const char *name;
	struct module___48 *owner;
	struct class_attribute___70 *class_attrs;
	struct device_attribute___70 *dev_attrs;
	const struct attribute_group___63 **dev_groups;
	struct bin_attribute___63 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *);
	void (*class_release)(struct class___70 *);
	void (*dev_release)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
	struct subsys_private *p;
};

struct class_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct class___70 *, struct class_attribute___70 *, char *);
	ssize_t (*store)(struct class___70 *, struct class_attribute___70 *, const char *, size_t);
	const void * (*namespace)(struct class___70 *, const struct class_attribute___70 *);
};

struct device_rh___70 {
	struct dev_pm_info_rh___70 power;
};

struct kmem_cache_cpu___79 {
	void **freelist;
	long unsigned int tid;
	struct page___91 *page;
	struct page___91 *partial;
};

struct memcg_cache_params___79 {
	bool is_root_cache;
	union {
		struct kmem_cache___79 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___79 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___58;

struct cgroup___58 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___58 *parent;
	struct dentry___92 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___58 *subsys[11];
	struct cgroupfs_root___58 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___92 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___58 {
	struct super_block___92 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___58 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___43;

struct pmu___43 {
	struct list_head entry;
	struct device___70 *dev;
	const struct attribute_group___63 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___43 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___43 *);
	void (*pmu_disable)(struct pmu___43 *);
	int (*event_init)(struct perf_event___43 *);
	int (*add)(struct perf_event___43 *, int);
	void (*del)(struct perf_event___43 *, int);
	void (*start)(struct perf_event___43 *, int);
	void (*stop)(struct perf_event___43 *, int);
	void (*read)(struct perf_event___43 *);
	void (*start_txn)(struct pmu___43 *);
	int (*commit_txn)(struct pmu___43 *);
	void (*cancel_txn)(struct pmu___43 *);
	int (*event_idx)(struct perf_event___43 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___48 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___43 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___43 *);
};

struct perf_cpu_context___43 {
	struct perf_event_context___43 ctx;
	struct perf_event_context___43 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___43 *unique_pmu;
	struct perf_cgroup___43 *cgrp;
};

struct rb_irq_work {
	struct irq_work work;
	wait_queue_head_t waiters;
	bool waiters_pending;
};

struct ring_buffer_per_cpu;

struct ring_buffer___2 {
	unsigned int flags;
	int cpus;
	atomic_t record_disabled;
	atomic_t resize_disabled;
	cpumask_var_t cpumask;
	struct lock_class_key *reader_lock_key;
	struct mutex___92 mutex;
	struct ring_buffer_per_cpu **buffers;
	struct notifier_block cpu_notify;
	u64 (*clock)();
	struct rb_irq_work irq_work;
};

struct trace_event_functions___33;

struct trace_event___33 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___33 *funcs;
};

struct ftrace_event_class___33;

struct ftrace_event_call___33 {
	struct list_head list;
	struct ftrace_event_class___33 *class;
	char *name;
	struct trace_event___33 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___43 {
	struct cgroup_subsys_state___58 css;
	struct perf_cgroup_info *info;
};

struct ring_buffer_iter___2;

struct trace_iterator___33 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___92 mutex;
	struct ring_buffer_iter___2 **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct buffer_page;

struct ring_buffer_iter___2 {
	struct ring_buffer_per_cpu *cpu_buffer;
	long unsigned int head;
	struct buffer_page *head_page;
	struct buffer_page *cache_reader_page;
	long unsigned int cache_read;
	u64 read_stamp;
};

typedef enum print_line_t (*trace_print_func___33)(struct trace_iterator___33 *, int, struct trace_event___33 *);

struct trace_event_functions___33 {
	trace_print_func___33 trace;
	trace_print_func___33 raw;
	trace_print_func___33 hex;
	trace_print_func___33 binary;
};

struct ftrace_event_class___33 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___33 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___33 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___33 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___33 *);
};

struct module_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___47 *, struct module_kobject___47 *, char *);
	ssize_t (*store)(struct module_attribute___47 *, struct module_kobject___47 *, const char *, size_t);
	void (*setup)(struct module___48 *, const char *);
	int (*test)(struct module___48 *);
	void (*free)(struct module___48 *);
};

enum {
	RB_BUFFERS_ON_BIT = 0,
	RB_BUFFERS_DISABLED_BIT = 1,
};

enum {
	RB_BUFFERS_ON = 1,
	RB_BUFFERS_DISABLED = 2,
};

enum {
	RB_LEN_TIME_EXTEND = 8,
	RB_LEN_TIME_STAMP = 16,
};

struct buffer_data_page {
	u64 time_stamp;
	local_t commit;
	unsigned char data[0];
};

struct buffer_page {
	struct list_head list;
	local_t write;
	unsigned int read;
	local_t entries;
	long unsigned int real_end;
	struct buffer_data_page *page;
};

struct ring_buffer_per_cpu {
	int cpu;
	atomic_t record_disabled;
	struct ring_buffer___2 *buffer;
	raw_spinlock_t reader_lock;
	arch_spinlock_t lock;
	struct lock_class_key lock_key;
	unsigned int nr_pages;
	struct list_head *pages;
	struct buffer_page *head_page;
	struct buffer_page *tail_page;
	struct buffer_page *commit_page;
	struct buffer_page *reader_page;
	long unsigned int lost_events;
	long unsigned int last_overrun;
	local_t entries_bytes;
	local_t entries;
	local_t overrun;
	local_t commit_overrun;
	local_t dropped_events;
	local_t committing;
	local_t commits;
	long unsigned int read;
	long unsigned int read_bytes;
	u64 write_stamp;
	u64 read_stamp;
	int nr_pages_to_update;
	struct list_head new_pages;
	struct work_struct update_pages_work;
	struct completion update_done;
	struct rb_irq_work irq_work;
};

struct page___92;

typedef struct page___92 *pgtable_t___92;

struct address_space___92;

struct kmem_cache___80;

struct page___92 {
	long unsigned int flags;
	struct address_space___92 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___92 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___92 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___80 *slab_cache;
		struct page___92 *first_page;
	};
	long: 64;
};

struct thread_struct___44;

struct task_struct___92;

struct pv_cpu_ops___92 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___44 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___44 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___92 *);
	void (*end_context_switch)(struct task_struct___92 *);
};

struct perf_event___44;

struct thread_struct___44 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___44 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___49;

struct pid_link___49 {
	struct hlist_node node;
	struct pid___49 *pid;
};

struct mutex___93 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___92 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___88 {
	struct page___92 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___97;

struct nsproxy___50;

struct signal_struct___92;

struct css_set___59;

struct perf_event_context___44;

struct pipe_inode_info___3;

struct task_struct___92 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___92 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___97 *mm;
	struct mm_struct___97 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___92 *real_parent;
	struct task_struct___92 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___92 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___49 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___92 = 0,
		VTIME_USER___92 = 1,
		VTIME_SYS___92 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___44 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___50 *nsproxy;
	struct signal_struct___92 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___59 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___44 *perf_event_ctxp[2];
	struct mutex___93 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___3 *splice_pipe;
	struct page_frag___88 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___97 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___97 *, struct mm_struct___97 *);
	void (*dup_mmap)(struct mm_struct___97 *, struct mm_struct___97 *);
	void (*exit_mmap)(struct mm_struct___97 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___97 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___97 *);
	void (*pgd_free)(struct mm_struct___97 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___97 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___97 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___97 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___97 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___97 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___97 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___97 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___97 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___97 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___97 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___97 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___93 lock;
	void *vdso;
} mm_context_t___93;

struct xol_area___92;

struct uprobes_state___92 {
	struct xol_area___92 *xol_area;
};

struct vm_area_struct___97;

struct file___92;

struct core_state___92;

struct mm_struct___97 {
	struct vm_area_struct___97 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___97 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___97 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___93 context;
	long unsigned int flags;
	struct core_state___92 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___92 *owner;
	struct file___92 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___92 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___49;

struct exec_domain___24 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___49 *module;
	struct exec_domain___24 *next;
};

struct module_kobject___48 {
	struct kobject kobj;
	struct module___49 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___48;

struct ftrace_event_call___34;

struct module___49 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___48 mkobj;
	struct module_attribute___48 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___34 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___92 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___44 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___92 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___92 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___92 *target;
};

typedef void (*perf_overflow_handler_t___44)(struct perf_event___44 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___44;

typedef void (*ftrace_func_t___44)(long unsigned int, long unsigned int, struct ftrace_ops___44 *, struct pt_regs *);

struct ftrace_ops___44 {
	ftrace_func_t___44 func;
	struct ftrace_ops___44 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___93 regex_lock;
};

struct pmu___44;

struct fasync_struct___92;

struct pid_namespace___49;

struct perf_cgroup___44;

struct perf_event___44 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___44 *group_leader;
	struct pmu___44 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___44 hw;
	struct perf_event_context___44 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___93 child_mutex;
	struct list_head child_list;
	struct perf_event___44 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___92 *owner;
	struct mutex___93 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___92 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___44 *);
	struct callback_head callback_head;
	struct pid_namespace___49 *ns;
	u64 id;
	perf_overflow_handler_t___44 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___34 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___44 ftrace_ops;
	struct perf_cgroup___44 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___46 {
	struct task_struct___92 *task;
	struct exec_domain___24 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___92 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___92 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___80;

struct memcg_cache_params___80;

struct kmem_cache___80 {
	struct kmem_cache_cpu___80 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___80 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___93;

struct address_space_operations___92;

struct address_space___92 {
	struct inode___93 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___93 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___92 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___93;

struct path___92 {
	struct vfsmount *mnt;
	struct dentry___93 *dentry;
};

struct fown_struct___49 {
	rwlock_t lock;
	struct pid___49 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___92;

struct file___92 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___92 f_path;
	struct inode___93 *f_inode;
	const struct file_operations___92 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___49 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___92 *f_mapping;
	struct mutex___93 f_pos_lock;
};

struct vm_operations_struct___80;

struct vm_area_struct___97 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___97 *vm_next;
	struct vm_area_struct___97 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___97 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___80 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___92 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___77;

struct vm_operations_struct___80 {
	void (*open)(struct vm_area_struct___97 *);
	void (*close)(struct vm_area_struct___97 *);
	int (*fault)(struct vm_area_struct___97 *, struct vm_fault___77 *);
	int (*page_mkwrite)(struct vm_area_struct___97 *, struct vm_fault___77 *);
	int (*access)(struct vm_area_struct___97 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___97 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___97 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___97 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___97 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___92 {
	struct task_struct___92 *task;
	struct core_thread___92 *next;
};

struct core_state___92 {
	atomic_t nr_threads;
	struct core_thread___92 dumper;
	struct completion startup;
};

struct zone___92;

struct lruvec___92 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___92 *zone;
};

struct pglist_data___92;

struct zone___92 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___92 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___92 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___92 {
	struct zone___92 *zone;
	int zone_idx;
};

struct zonelist___92 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___92 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___92 {
	struct zone___92 node_zones[4];
	struct zonelist___92 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___92 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___66;

struct x86_io_apic_ops___66 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___66 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___66;

struct irq_data___66 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___66 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___71;

struct dev_pm_ops___71 {
	int (*prepare)(struct device___71 *);
	void (*complete)(struct device___71 *);
	int (*suspend)(struct device___71 *);
	int (*resume)(struct device___71 *);
	int (*freeze)(struct device___71 *);
	int (*thaw)(struct device___71 *);
	int (*poweroff)(struct device___71 *);
	int (*restore)(struct device___71 *);
	int (*suspend_late)(struct device___71 *);
	int (*resume_early)(struct device___71 *);
	int (*freeze_late)(struct device___71 *);
	int (*thaw_early)(struct device___71 *);
	int (*poweroff_late)(struct device___71 *);
	int (*restore_early)(struct device___71 *);
	int (*suspend_noirq)(struct device___71 *);
	int (*resume_noirq)(struct device___71 *);
	int (*freeze_noirq)(struct device___71 *);
	int (*thaw_noirq)(struct device___71 *);
	int (*poweroff_noirq)(struct device___71 *);
	int (*restore_noirq)(struct device___71 *);
	int (*runtime_suspend)(struct device___71 *);
	int (*runtime_resume)(struct device___71 *);
	int (*runtime_idle)(struct device___71 *);
};

struct device_type___71;

struct bus_type___71;

struct device_driver___71;

struct dev_pm_domain___71;

struct class___71;

struct attribute_group___64;

struct device_rh___71;

struct device___71 {
	struct device___71 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___71 *type;
	struct mutex___93 mutex;
	struct bus_type___71 *bus;
	struct device_driver___71 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___71 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___71 *class;
	const struct attribute_group___64 **groups;
	void (*release)(struct device___71 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___71 *device_rh;
};

struct dev_pm_info_rh___71 {
	void (*set_latency_tolerance)(struct device___71 *, s32);
};

struct dev_pm_domain___71 {
	struct dev_pm_ops___71 ops;
};

struct smp_ops___92 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___92 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vm_fault___77 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___92 *page;
};

struct seq_operations___67;

struct seq_file___68 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___93 lock;
	const struct seq_operations___67 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___67 {
	void * (*start)(struct seq_file___68 *, loff_t *);
	void (*stop)(struct seq_file___68 *, void *);
	void * (*next)(struct seq_file___68 *, void *, loff_t *);
	int (*show)(struct seq_file___68 *, void *);
};

struct dentry_operations___92;

struct super_block___93;

struct dentry___93 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___93 *d_parent;
	struct qstr d_name;
	struct inode___93 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___92 *d_op;
	struct super_block___93 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___92;

struct file_lock___92;

struct dquot___92;

struct block_device___92;

struct inode___93 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___92 *i_op;
	struct super_block___93 *i_sb;
	struct address_space___92 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___93 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___92 *i_fop;
	struct file_lock___92 *i_flock;
	struct address_space___92 i_data;
	struct dquot___92 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___3 *i_pipe;
		struct block_device___92 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___92 {
	int (*d_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_hash)(const struct dentry___93 *, struct qstr *);
	int (*d_compare)(const struct dentry___93 *, const struct dentry___93 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___93 *);
	void (*d_release)(struct dentry___93 *);
	void (*d_prune)(struct dentry___93 *);
	void (*d_iput)(struct dentry___93 *, struct inode___93 *);
	char * (*d_dname)(struct dentry___93 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___92 *);
	int (*d_manage)(struct dentry___93 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___92;

struct mem_dqinfo___92 {
	struct quota_format_type___92 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___92;

struct quota_info___92 {
	unsigned int flags;
	struct mutex___93 dqio_mutex;
	struct mutex___93 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___93 *files[2];
	struct mem_dqinfo___92 info[2];
	const struct quota_format_ops___92 *ops[2];
};

struct file_system_type___92;

struct super_operations___92;

struct dquot_operations___92;

struct quotactl_ops___92;

struct xattr_handler___59;

struct super_block___93 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___92 *s_type;
	const struct super_operations___92 *s_op;
	const struct dquot_operations___92 *dq_op;
	const struct quotactl_ops___92 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___93 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___59 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___92 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___92 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___93 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___92 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___49 {
	int nr;
	struct pid_namespace___49 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___49 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___92 *child_reaper;
	struct kmem_cache___80 *pid_cachep;
	unsigned int level;
	struct pid_namespace___49 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___93 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___49 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___49 numbers[1];
};

struct block_device___92 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___93 *bd_inode;
	struct super_block___93 *bd_super;
	struct mutex___93 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___92 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___93 bd_fsfreeze_mutex;
};

struct cgroup___59;

struct cgroup_subsys_state___59 {
	struct cgroup___59 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___93 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___92 *ia_file;
};

struct dquot___92 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___93 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___93 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___92 {
	int qf_fmt_id;
	const struct quota_format_ops___92 *qf_ops;
	struct module___49 *qf_owner;
	struct quota_format_type___92 *qf_next;
};

struct quota_format_ops___92 {
	int (*check_quota_file)(struct super_block___93 *, int);
	int (*read_file_info)(struct super_block___93 *, int);
	int (*write_file_info)(struct super_block___93 *, int);
	int (*free_file_info)(struct super_block___93 *, int);
	int (*read_dqblk)(struct dquot___92 *);
	int (*commit_dqblk)(struct dquot___92 *);
	int (*release_dqblk)(struct dquot___92 *);
};

struct dquot_operations___92 {
	int (*write_dquot)(struct dquot___92 *);
	struct dquot___92 * (*alloc_dquot)(struct super_block___93 *, int);
	void (*destroy_dquot)(struct dquot___92 *);
	int (*acquire_dquot)(struct dquot___92 *);
	int (*release_dquot)(struct dquot___92 *);
	int (*mark_dirty)(struct dquot___92 *);
	int (*write_info)(struct super_block___93 *, int);
	qsize_t * (*get_reserved_space)(struct inode___93 *);
};

struct quotactl_ops___92 {
	int (*quota_on)(struct super_block___93 *, int, int, struct path___92 *);
	int (*quota_on_meta)(struct super_block___93 *, int, int);
	int (*quota_off)(struct super_block___93 *, int);
	int (*quota_sync)(struct super_block___93 *, int);
	int (*get_info)(struct super_block___93 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___93 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___93 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___93 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___93 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___93 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___93 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___93 *, unsigned int);
};

struct address_space_operations___92 {
	int (*writepage)(struct page___92 *, struct writeback_control *);
	int (*readpage)(struct file___92 *, struct page___92 *);
	int (*writepages)(struct address_space___92 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___92 *);
	int (*readpages)(struct file___92 *, struct address_space___92 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___92 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___92 **, void **);
	int (*write_end)(struct file___92 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___92 *, void *);
	sector_t (*bmap)(struct address_space___92 *, sector_t);
	void (*invalidatepage)(struct page___92 *, long unsigned int);
	int (*releasepage)(struct page___92 *, gfp_t);
	void (*freepage)(struct page___92 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___92 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___92 *, struct page___92 *, struct page___92 *, enum migrate_mode);
	int (*launder_page)(struct page___92 *);
	int (*is_partially_uptodate)(struct page___92 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___92 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___92 *, struct page___92 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___92 *, sector_t *);
	void (*swap_deactivate)(struct file___92 *);
	void (*invalidatepage_range)(struct page___92 *, unsigned int, unsigned int);
};

struct pipe_buffer___3;

struct pipe_inode_info___3 {
	struct mutex___93 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___92 *tmp_page;
	struct fasync_struct___92 *fasync_readers;
	struct fasync_struct___92 *fasync_writers;
	struct pipe_buffer___3 *bufs;
};

struct inode_operations___92 {
	struct dentry___93 * (*lookup)(struct inode___93 *, struct dentry___93 *, unsigned int);
	void * (*follow_link)(struct dentry___93 *, struct nameidata *);
	int (*permission)(struct inode___93 *, int);
	struct posix_acl * (*get_acl)(struct inode___93 *, int);
	int (*readlink)(struct dentry___93 *, char *, int);
	void (*put_link)(struct dentry___93 *, struct nameidata *, void *);
	int (*create)(struct inode___93 *, struct dentry___93 *, umode_t, bool);
	int (*link)(struct dentry___93 *, struct inode___93 *, struct dentry___93 *);
	int (*unlink)(struct inode___93 *, struct dentry___93 *);
	int (*symlink)(struct inode___93 *, struct dentry___93 *, const char *);
	int (*mkdir)(struct inode___93 *, struct dentry___93 *, umode_t);
	int (*rmdir)(struct inode___93 *, struct dentry___93 *);
	int (*mknod)(struct inode___93 *, struct dentry___93 *, umode_t, dev_t);
	int (*rename)(struct inode___93 *, struct dentry___93 *, struct inode___93 *, struct dentry___93 *);
	int (*setattr)(struct dentry___93 *, struct iattr___93 *);
	int (*getattr)(struct vfsmount *, struct dentry___93 *, struct kstat *);
	int (*setxattr)(struct dentry___93 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___93 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___93 *, char *, size_t);
	int (*removexattr)(struct dentry___93 *, const char *);
	int (*fiemap)(struct inode___93 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___93 *, struct timespec *, int);
	int (*atomic_open)(struct inode___93 *, struct dentry___93 *, struct file___92 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___56;

struct file_operations___92 {
	struct module___49 *owner;
	loff_t (*llseek)(struct file___92 *, loff_t, int);
	ssize_t (*read)(struct file___92 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___92 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___92 *, void *, filldir_t);
	unsigned int (*poll)(struct file___92 *, struct poll_table_struct___56 *);
	long int (*unlocked_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___92 *, struct vm_area_struct___97 *);
	int (*open)(struct inode___93 *, struct file___92 *);
	int (*flush)(struct file___92 *, fl_owner_t);
	int (*release)(struct inode___93 *, struct file___92 *);
	int (*fsync)(struct file___92 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___92 *, int);
	int (*lock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*sendpage)(struct file___92 *, struct page___92 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*splice_write)(struct pipe_inode_info___3 *, struct file___92 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___92 *, loff_t *, struct pipe_inode_info___3 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___92 *, long int, struct file_lock___92 **, void **);
		struct {
			int (*setlease)(struct file___92 *, long int, struct file_lock___92 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___92 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___68 *, struct file___92 *);
};

struct file_lock_operations___92;

struct lock_manager_operations___92;

struct file_lock___92 {
	struct file_lock___92 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___49 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___92 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___92 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___92 *fl_ops;
	const struct lock_manager_operations___92 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___92 {
	void (*fl_copy_lock)(struct file_lock___92 *, struct file_lock___92 *);
	void (*fl_release_private)(struct file_lock___92 *);
};

struct lock_manager_operations___92 {
	int (*lm_compare_owner)(struct file_lock___92 *, struct file_lock___92 *);
	long unsigned int (*lm_owner_key)(struct file_lock___92 *);
	void (*lm_notify)(struct file_lock___92 *);
	int (*lm_grant)(struct file_lock___92 *, struct file_lock___92 *, int);
	void (*lm_break)(struct file_lock___92 *);
	int (*lm_change)(struct file_lock___92 **, int);
};

struct fasync_struct___92 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___92 *fa_next;
	struct file___92 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___92 {
	const char *name;
	int fs_flags;
	struct dentry___93 * (*mount)(struct file_system_type___92 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___93 *);
	struct module___49 *owner;
	struct file_system_type___92 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___92 {
	struct inode___93 * (*alloc_inode)(struct super_block___93 *);
	void (*destroy_inode)(struct inode___93 *);
	void (*dirty_inode)(struct inode___93 *, int);
	int (*write_inode)(struct inode___93 *, struct writeback_control *);
	int (*drop_inode)(struct inode___93 *);
	void (*evict_inode)(struct inode___93 *);
	void (*put_super)(struct super_block___93 *);
	int (*sync_fs)(struct super_block___93 *, int);
	int (*freeze_fs)(struct super_block___93 *);
	int (*unfreeze_fs)(struct super_block___93 *);
	int (*statfs)(struct dentry___93 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___93 *, int *, char *);
	void (*umount_begin)(struct super_block___93 *);
	int (*show_options)(struct seq_file___68 *, struct dentry___93 *);
	int (*show_devname)(struct seq_file___68 *, struct dentry___93 *);
	int (*show_path)(struct seq_file___68 *, struct dentry___93 *);
	int (*show_stats)(struct seq_file___68 *, struct dentry___93 *);
	ssize_t (*quota_read)(struct super_block___93 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___93 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___93 *);
	int (*bdev_try_to_free_page)(struct super_block___93 *, struct page___92 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___93 *);
	void (*free_cached_objects)(struct super_block___93 *, int);
};

struct xattr_handler___59 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___93 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___93 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___93 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___57)(struct file___92 *, wait_queue_head_t *, struct poll_table_struct___56 *);

struct poll_table_struct___56 {
	poll_queue_proc___57 _qproc;
	long unsigned int _key;
};

struct nsproxy___50 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___49 *pid_ns;
	struct net *net_ns;
};

typedef struct poll_table_struct___56 poll_table___7;

struct signal_struct___92 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___92 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___92 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___49 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___49 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___93 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___59 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___59 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___44 {
	struct pmu___44 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___93 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___92 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___44 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct irq_chip___66 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___66 *);
	void (*irq_shutdown)(struct irq_data___66 *);
	void (*irq_enable)(struct irq_data___66 *);
	void (*irq_disable)(struct irq_data___66 *);
	void (*irq_ack)(struct irq_data___66 *);
	void (*irq_mask)(struct irq_data___66 *);
	void (*irq_mask_ack)(struct irq_data___66 *);
	void (*irq_unmask)(struct irq_data___66 *);
	void (*irq_eoi)(struct irq_data___66 *);
	int (*irq_set_affinity)(struct irq_data___66 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___66 *);
	int (*irq_set_type)(struct irq_data___66 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___66 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___66 *);
	void (*irq_bus_sync_unlock)(struct irq_data___66 *);
	void (*irq_cpu_online)(struct irq_data___66 *);
	void (*irq_cpu_offline)(struct irq_data___66 *);
	void (*irq_suspend)(struct irq_data___66 *);
	void (*irq_resume)(struct irq_data___66 *);
	void (*irq_pm_shutdown)(struct irq_data___66 *);
	void (*irq_print_chip)(struct irq_data___66 *, struct seq_file___68 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___66 *, void *);
	long unsigned int flags;
};

struct ftrace_probe_ops___2 {
	void (*func)(long unsigned int, long unsigned int, void **);
	int (*init)(struct ftrace_probe_ops___2 *, long unsigned int, void **);
	void (*free)(struct ftrace_probe_ops___2 *, long unsigned int, void **);
	int (*print)(struct seq_file___68 *, long unsigned int, struct ftrace_probe_ops___2 *, void *);
};

struct kprobe_insn_cache___14 {
	struct mutex___93 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct bin_attribute___64;

struct attribute_group___64 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___64 **bin_attrs;
};

struct bin_attribute___64 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___92 *, struct kobject *, struct bin_attribute___64 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___92 *, struct kobject *, struct bin_attribute___64 *, char *, loff_t, size_t);
	int (*mmap)(struct file___92 *, struct kobject *, struct bin_attribute___64 *, struct vm_area_struct___97 *);
};

struct module_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___48 *, struct module_kobject___48 *, char *);
	ssize_t (*store)(struct module_attribute___48 *, struct module_kobject___48 *, const char *, size_t);
	void (*setup)(struct module___49 *, const char *);
	int (*test)(struct module___49 *);
	void (*free)(struct module___49 *);
};

struct trace_event_functions___34;

struct trace_event___34 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___34 *funcs;
};

struct ftrace_event_class___34;

struct ftrace_event_call___34 {
	struct list_head list;
	struct ftrace_event_class___34 *class;
	char *name;
	struct trace_event___34 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct pipe_buf_operations___3;

struct pipe_buffer___3 {
	struct page___92 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___3 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___3 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *, int);
	void (*unmap)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *, void *);
	int (*confirm)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	void (*release)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	int (*steal)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	void (*get)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
};

struct splice_pipe_desc___2 {
	struct page___92 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___3 *ops;
	void (*spd_release)(struct splice_pipe_desc___2 *, unsigned int);
};

struct kmem_cache_cpu___80 {
	void **freelist;
	long unsigned int tid;
	struct page___92 *page;
	struct page___92 *partial;
};

struct memcg_cache_params___80 {
	bool is_root_cache;
	union {
		struct kmem_cache___80 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___80 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___71 *, char *);
	ssize_t (*store)(struct bus_type___71 *, const char *, size_t);
};

struct device_attribute___71;

struct driver_attribute___71;

struct bus_type___71 {
	const char *name;
	const char *dev_name;
	struct device___71 *dev_root;
	struct bus_attribute___71 *bus_attrs;
	struct device_attribute___71 *dev_attrs;
	struct driver_attribute___71 *drv_attrs;
	const struct attribute_group___64 **bus_groups;
	const struct attribute_group___64 **dev_groups;
	const struct attribute_group___64 **drv_groups;
	int (*match)(struct device___71 *, struct device_driver___71 *);
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	int (*probe)(struct device___71 *);
	int (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*online)(struct device___71 *);
	int (*offline)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct device___71 *, struct device_attribute___71 *, char *);
	ssize_t (*store)(struct device___71 *, struct device_attribute___71 *, const char *, size_t);
};

struct driver_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___71 *, char *);
	ssize_t (*store)(struct device_driver___71 *, const char *, size_t);
};

struct device_driver___71 {
	const char *name;
	struct bus_type___71 *bus;
	struct module___49 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___71 *);
	int (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	const struct attribute_group___64 **groups;
	const struct dev_pm_ops___71 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___71 {
	const char *name;
	const struct attribute_group___64 **groups;
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
};

struct class_attribute___71;

struct class___71 {
	const char *name;
	struct module___49 *owner;
	struct class_attribute___71 *class_attrs;
	struct device_attribute___71 *dev_attrs;
	const struct attribute_group___64 **dev_groups;
	struct bin_attribute___64 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *);
	void (*class_release)(struct class___71 *);
	void (*dev_release)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
	struct subsys_private *p;
};

struct class_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct class___71 *, struct class_attribute___71 *, char *);
	ssize_t (*store)(struct class___71 *, struct class_attribute___71 *, const char *, size_t);
	const void * (*namespace)(struct class___71 *, const struct class_attribute___71 *);
};

struct device_rh___71 {
	struct dev_pm_info_rh___71 power;
};

struct cgroupfs_root___59;

struct cgroup___59 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___59 *parent;
	struct dentry___93 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___59 *subsys[11];
	struct cgroupfs_root___59 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___93 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___59 {
	struct super_block___93 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___59 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___44;

struct pmu___44 {
	struct list_head entry;
	struct device___71 *dev;
	const struct attribute_group___64 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___44 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___44 *);
	void (*pmu_disable)(struct pmu___44 *);
	int (*event_init)(struct perf_event___44 *);
	int (*add)(struct perf_event___44 *, int);
	void (*del)(struct perf_event___44 *, int);
	void (*start)(struct perf_event___44 *, int);
	void (*stop)(struct perf_event___44 *, int);
	void (*read)(struct perf_event___44 *);
	void (*start_txn)(struct pmu___44 *);
	int (*commit_txn)(struct pmu___44 *);
	void (*cancel_txn)(struct pmu___44 *);
	int (*event_idx)(struct perf_event___44 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___49 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___44 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___44 *);
};

struct perf_cpu_context___44 {
	struct perf_event_context___44 ctx;
	struct perf_event_context___44 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___44 *unique_pmu;
	struct perf_cgroup___44 *cgrp;
};

struct perf_cgroup___44 {
	struct cgroup_subsys_state___59 css;
	struct perf_cgroup_info *info;
};

struct trace_array___3;

struct tracer___3;

struct trace_buffer___3;

struct trace_iterator___34 {
	struct trace_array___3 *tr;
	struct tracer___3 *trace;
	struct trace_buffer___3 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___93 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___2;

struct trace_buffer___3 {
	struct trace_array___3 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___2 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___2 {
	struct trace_array___3 *tr;
	struct dentry___93 *dir;
	int cpu;
};

struct trace_array___3 {
	struct list_head list;
	char *name;
	struct trace_buffer___3 trace_buffer;
	struct trace_buffer___3 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___2 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___3 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___93 *dir;
	struct dentry___93 *options;
	struct dentry___93 *percpu_dir;
	struct dentry___93 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___92 *waiter;
	int ref;
};

struct tracer___3 {
	const char *name;
	int (*init)(struct trace_array___3 *);
	void (*reset)(struct trace_array___3 *);
	void (*start)(struct trace_array___3 *);
	void (*stop)(struct trace_array___3 *);
	void (*open)(struct trace_iterator___34 *);
	void (*pipe_open)(struct trace_iterator___34 *);
	int (*wait_pipe)(struct trace_iterator___34 *);
	void (*close)(struct trace_iterator___34 *);
	void (*pipe_close)(struct trace_iterator___34 *);
	ssize_t (*read)(struct trace_iterator___34 *, struct file___92 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___34 *, struct file___92 *, loff_t *, struct pipe_inode_info___3 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___68 *);
	enum print_line_t (*print_line)(struct trace_iterator___34 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___3 *, u32, int);
	struct tracer___3 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

enum trace_iter_flags {
	TRACE_FILE_LAT_FMT = 1,
	TRACE_FILE_ANNOTATE = 2,
	TRACE_FILE_TIME_IN_NS = 4,
};

typedef enum print_line_t (*trace_print_func___34)(struct trace_iterator___34 *, int, struct trace_event___34 *);

struct trace_event_functions___34 {
	trace_print_func___34 trace;
	trace_print_func___34 raw;
	trace_print_func___34 hex;
	trace_print_func___34 binary;
};

struct ftrace_event_class___34 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___34 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___34 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___34 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___34 *);
};

struct ftrace_subsystem_dir___2;

struct ftrace_event_file___13 {
	struct list_head list;
	struct ftrace_event_call___34 *event_call;
	struct dentry___93 *dir;
	struct trace_array___3 *tr;
	struct ftrace_subsystem_dir___2 *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct event_subsystem;

struct ftrace_subsystem_dir___2 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___3 *tr;
	struct dentry___93 *entry;
	int ref_count;
	int nr_events;
};

enum trace_type {
	__TRACE_FIRST_TYPE = 0,
	TRACE_FN = 1,
	TRACE_CTX = 2,
	TRACE_WAKE = 3,
	TRACE_STACK = 4,
	TRACE_PRINT = 5,
	TRACE_BPRINT = 6,
	TRACE_MMIO_RW = 7,
	TRACE_MMIO_MAP = 8,
	TRACE_BRANCH = 9,
	TRACE_GRAPH_RET = 10,
	TRACE_GRAPH_ENT = 11,
	TRACE_USER_STACK = 12,
	TRACE_BLK = 13,
	TRACE_BPUTS = 14,
	__TRACE_LAST_TYPE = 15,
};

struct ftrace_entry {
	struct trace_entry ent;
	long unsigned int ip;
	long unsigned int parent_ip;
};

struct stack_entry {
	struct trace_entry ent;
	int size;
	long unsigned int caller[0];
};

struct userstack_entry {
	struct trace_entry ent;
	unsigned int tgid;
	long unsigned int caller[8];
};

struct bprint_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *fmt;
	u32 buf[0];
};

struct print_entry {
	struct trace_entry ent;
	long unsigned int ip;
	char buf[0];
};

struct bputs_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *str;
};

enum trace_flag_type {
	TRACE_FLAG_IRQS_OFF = 1,
	TRACE_FLAG_IRQS_NOSUPPORT = 2,
	TRACE_FLAG_NEED_RESCHED = 4,
	TRACE_FLAG_HARDIRQ = 8,
	TRACE_FLAG_SOFTIRQ = 16,
};

struct trace_array_cpu___2 {
	struct trace_cpu___2 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

enum {
	TRACE_ARRAY_FL_GLOBAL = 1,
};

struct event_subsystem {
	struct list_head list;
	const char *name;
	struct event_filter *filter;
	int ref_count;
};

struct ftrace_stack {
	long unsigned int calls[512];
};

struct trace_buffer_struct {
	char buffer[1024];
};

struct ftrace_buffer_info {
	struct trace_iterator___34 iter;
	void *spare;
	unsigned int read;
};

struct buffer_ref {
	struct ring_buffer *buffer;
	void *page;
	int ref;
};

struct trace_option_dentry {
	struct tracer_opt *opt;
	struct tracer_flags *flags;
	struct trace_array___3 *tr;
	struct dentry___93 *entry;
};

typedef int pao_T_____2;

struct trace_array_cpu___3;

struct trace_buffer {
	struct trace_array *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___3 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___3 {
	struct trace_array *tr;
	struct dentry___59 *dir;
	int cpu;
};

struct trace_array {
	struct list_head list;
	char *name;
	struct trace_buffer trace_buffer;
	struct trace_buffer max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___3 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___59 *dir;
	struct dentry___59 *options;
	struct dentry___59 *percpu_dir;
	struct dentry___59 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___59 *waiter;
	int ref;
};

struct tracer {
	const char *name;
	int (*init)(struct trace_array *);
	void (*reset)(struct trace_array *);
	void (*start)(struct trace_array *);
	void (*stop)(struct trace_array *);
	void (*open)(struct trace_iterator___19 *);
	void (*pipe_open)(struct trace_iterator___19 *);
	int (*wait_pipe)(struct trace_iterator___19 *);
	void (*close)(struct trace_iterator___19 *);
	void (*pipe_close)(struct trace_iterator___19 *);
	ssize_t (*read)(struct trace_iterator___19 *, struct file___58 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___19 *, struct file___58 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___42 *);
	enum print_line_t (*print_line)(struct trace_iterator___19 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer *, u32, int);
	struct tracer *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

struct ctx_switch_entry {
	struct trace_entry ent;
	unsigned int prev_pid;
	unsigned int next_pid;
	unsigned int next_cpu;
	unsigned char prev_prio;
	unsigned char prev_state;
	unsigned char next_prio;
	unsigned char next_state;
};

struct trace_array_cpu___3 {
	struct trace_cpu___3 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

struct page___93;

typedef struct page___93 *pgtable_t___93;

struct address_space___93;

struct kmem_cache___81;

struct page___93 {
	long unsigned int flags;
	struct address_space___93 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___93 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___93 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___81 *slab_cache;
		struct page___93 *first_page;
	};
	long: 64;
};

struct thread_struct___45;

struct task_struct___93;

struct pv_cpu_ops___93 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___45 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___45 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___93 *);
	void (*end_context_switch)(struct task_struct___93 *);
};

struct perf_event___45;

struct thread_struct___45 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___45 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___50;

struct pid_link___50 {
	struct hlist_node node;
	struct pid___50 *pid;
};

struct mutex___94 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___93 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___89 {
	struct page___93 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___98;

struct nsproxy___51;

struct signal_struct___93;

struct css_set___60;

struct perf_event_context___45;

struct task_struct___93 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___93 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___98 *mm;
	struct mm_struct___98 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___93 *real_parent;
	struct task_struct___93 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___93 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___50 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___93 = 0,
		VTIME_USER___93 = 1,
		VTIME_SYS___93 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___45 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___51 *nsproxy;
	struct signal_struct___93 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___60 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___45 *perf_event_ctxp[2];
	struct mutex___94 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___89 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___98 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___98 *, struct mm_struct___98 *);
	void (*dup_mmap)(struct mm_struct___98 *, struct mm_struct___98 *);
	void (*exit_mmap)(struct mm_struct___98 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___98 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___98 *);
	void (*pgd_free)(struct mm_struct___98 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___98 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___98 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___98 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___98 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___98 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___98 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___98 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___98 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___98 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___98 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___98 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___94 lock;
	void *vdso;
} mm_context_t___94;

struct xol_area___93;

struct uprobes_state___93 {
	struct xol_area___93 *xol_area;
};

struct vm_area_struct___98;

struct file___93;

struct core_state___93;

struct mm_struct___98 {
	struct vm_area_struct___98 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___98 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___98 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___94 context;
	long unsigned int flags;
	struct core_state___93 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___93 *owner;
	struct file___93 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___93 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___45 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___93 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___93 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___93 *target;
};

typedef void (*perf_overflow_handler_t___45)(struct perf_event___45 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___45;

typedef void (*ftrace_func_t___45)(long unsigned int, long unsigned int, struct ftrace_ops___45 *, struct pt_regs *);

struct ftrace_ops___45 {
	ftrace_func_t___45 func;
	struct ftrace_ops___45 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___94 regex_lock;
};

struct pmu___45;

struct fasync_struct___93;

struct pid_namespace___50;

struct ftrace_event_call___35;

struct perf_cgroup___45;

struct perf_event___45 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___45 *group_leader;
	struct pmu___45 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___45 hw;
	struct perf_event_context___45 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___94 child_mutex;
	struct list_head child_list;
	struct perf_event___45 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___93 *owner;
	struct mutex___94 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___93 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___45 *);
	struct callback_head callback_head;
	struct pid_namespace___50 *ns;
	u64 id;
	perf_overflow_handler_t___45 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___35 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___45 ftrace_ops;
	struct perf_cgroup___45 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___93;

struct lruvec___93 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___93 *zone;
};

struct pglist_data___93;

struct zone___93 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___93 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___93 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___93 {
	struct zone___93 *zone;
	int zone_idx;
};

struct zonelist___93 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___93 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___93 {
	struct zone___93 node_zones[4];
	struct zonelist___93 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___93 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___67;

struct x86_io_apic_ops___67 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___67 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___67;

struct irq_data___67 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___67 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___72;

struct dev_pm_ops___72 {
	int (*prepare)(struct device___72 *);
	void (*complete)(struct device___72 *);
	int (*suspend)(struct device___72 *);
	int (*resume)(struct device___72 *);
	int (*freeze)(struct device___72 *);
	int (*thaw)(struct device___72 *);
	int (*poweroff)(struct device___72 *);
	int (*restore)(struct device___72 *);
	int (*suspend_late)(struct device___72 *);
	int (*resume_early)(struct device___72 *);
	int (*freeze_late)(struct device___72 *);
	int (*thaw_early)(struct device___72 *);
	int (*poweroff_late)(struct device___72 *);
	int (*restore_early)(struct device___72 *);
	int (*suspend_noirq)(struct device___72 *);
	int (*resume_noirq)(struct device___72 *);
	int (*freeze_noirq)(struct device___72 *);
	int (*thaw_noirq)(struct device___72 *);
	int (*poweroff_noirq)(struct device___72 *);
	int (*restore_noirq)(struct device___72 *);
	int (*runtime_suspend)(struct device___72 *);
	int (*runtime_resume)(struct device___72 *);
	int (*runtime_idle)(struct device___72 *);
};

struct device_type___72;

struct bus_type___72;

struct device_driver___72;

struct dev_pm_domain___72;

struct class___72;

struct attribute_group___65;

struct device_rh___72;

struct device___72 {
	struct device___72 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___72 *type;
	struct mutex___94 mutex;
	struct bus_type___72 *bus;
	struct device_driver___72 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___72 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___72 *class;
	const struct attribute_group___65 **groups;
	void (*release)(struct device___72 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___72 *device_rh;
};

struct dev_pm_info_rh___72 {
	void (*set_latency_tolerance)(struct device___72 *, s32);
};

struct dev_pm_domain___72 {
	struct dev_pm_ops___72 ops;
};

struct smp_ops___93 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___93 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___65;

struct attribute_group___65 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___65 **bin_attrs;
};

struct bin_attribute___65 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___93 *, struct kobject *, struct bin_attribute___65 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___93 *, struct kobject *, struct bin_attribute___65 *, char *, loff_t, size_t);
	int (*mmap)(struct file___93 *, struct kobject *, struct bin_attribute___65 *, struct vm_area_struct___98 *);
};

struct dentry___94;

struct path___93 {
	struct vfsmount *mnt;
	struct dentry___94 *dentry;
};

struct fown_struct___50 {
	rwlock_t lock;
	struct pid___50 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___94;

struct file_operations___93;

struct file___93 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___93 f_path;
	struct inode___94 *f_inode;
	const struct file_operations___93 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___50 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___93 *f_mapping;
	struct mutex___94 f_pos_lock;
};

struct vm_operations_struct___81;

struct vm_area_struct___98 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___98 *vm_next;
	struct vm_area_struct___98 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___98 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___81 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___93 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___81 {
	void **freelist;
	long unsigned int tid;
	struct page___93 *page;
	struct page___93 *partial;
};

struct memcg_cache_params___81;

struct kmem_cache___81 {
	struct kmem_cache_cpu___81 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___81 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___81 {
	bool is_root_cache;
	union {
		struct kmem_cache___81 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___81 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___93;

struct super_block___94;

struct dentry___94 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___94 *d_parent;
	struct qstr d_name;
	struct inode___94 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___93 *d_op;
	struct super_block___94 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___93;

struct address_space___93 {
	struct inode___94 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___94 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___93 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___93;

struct file_lock___93;

struct dquot___93;

struct block_device___93;

struct inode___94 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___93 *i_op;
	struct super_block___94 *i_sb;
	struct address_space___93 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___94 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___93 *i_fop;
	struct file_lock___93 *i_flock;
	struct address_space___93 i_data;
	struct dquot___93 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___93 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___93 {
	int (*d_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_hash)(const struct dentry___94 *, struct qstr *);
	int (*d_compare)(const struct dentry___94 *, const struct dentry___94 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___94 *);
	void (*d_release)(struct dentry___94 *);
	void (*d_prune)(struct dentry___94 *);
	void (*d_iput)(struct dentry___94 *, struct inode___94 *);
	char * (*d_dname)(struct dentry___94 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___93 *);
	int (*d_manage)(struct dentry___94 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___93;

struct mem_dqinfo___93 {
	struct quota_format_type___93 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___93;

struct quota_info___93 {
	unsigned int flags;
	struct mutex___94 dqio_mutex;
	struct mutex___94 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___94 *files[2];
	struct mem_dqinfo___93 info[2];
	const struct quota_format_ops___93 *ops[2];
};

struct file_system_type___93;

struct super_operations___93;

struct dquot_operations___93;

struct quotactl_ops___93;

struct xattr_handler___60;

struct super_block___94 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___93 *s_type;
	const struct super_operations___93 *s_op;
	const struct dquot_operations___93 *dq_op;
	const struct quotactl_ops___93 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___94 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___60 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___93 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___93 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___94 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___93 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___50 {
	int nr;
	struct pid_namespace___50 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___50 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___93 *child_reaper;
	struct kmem_cache___81 *pid_cachep;
	unsigned int level;
	struct pid_namespace___50 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___94 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___50 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___50 numbers[1];
};

struct block_device___93 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___94 *bd_inode;
	struct super_block___94 *bd_super;
	struct mutex___94 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___93 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___94 bd_fsfreeze_mutex;
};

struct cgroup___60;

struct cgroup_subsys_state___60 {
	struct cgroup___60 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___94 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___93 *ia_file;
};

struct dquot___93 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___94 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___94 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___93 {
	int qf_fmt_id;
	const struct quota_format_ops___93 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___93 *qf_next;
};

struct quota_format_ops___93 {
	int (*check_quota_file)(struct super_block___94 *, int);
	int (*read_file_info)(struct super_block___94 *, int);
	int (*write_file_info)(struct super_block___94 *, int);
	int (*free_file_info)(struct super_block___94 *, int);
	int (*read_dqblk)(struct dquot___93 *);
	int (*commit_dqblk)(struct dquot___93 *);
	int (*release_dqblk)(struct dquot___93 *);
};

struct dquot_operations___93 {
	int (*write_dquot)(struct dquot___93 *);
	struct dquot___93 * (*alloc_dquot)(struct super_block___94 *, int);
	void (*destroy_dquot)(struct dquot___93 *);
	int (*acquire_dquot)(struct dquot___93 *);
	int (*release_dquot)(struct dquot___93 *);
	int (*mark_dirty)(struct dquot___93 *);
	int (*write_info)(struct super_block___94 *, int);
	qsize_t * (*get_reserved_space)(struct inode___94 *);
};

struct quotactl_ops___93 {
	int (*quota_on)(struct super_block___94 *, int, int, struct path___93 *);
	int (*quota_on_meta)(struct super_block___94 *, int, int);
	int (*quota_off)(struct super_block___94 *, int);
	int (*quota_sync)(struct super_block___94 *, int);
	int (*get_info)(struct super_block___94 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___94 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___94 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___94 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___94 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___94 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___94 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___94 *, unsigned int);
};

struct address_space_operations___93 {
	int (*writepage)(struct page___93 *, struct writeback_control *);
	int (*readpage)(struct file___93 *, struct page___93 *);
	int (*writepages)(struct address_space___93 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___93 *);
	int (*readpages)(struct file___93 *, struct address_space___93 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___93 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___93 **, void **);
	int (*write_end)(struct file___93 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___93 *, void *);
	sector_t (*bmap)(struct address_space___93 *, sector_t);
	void (*invalidatepage)(struct page___93 *, long unsigned int);
	int (*releasepage)(struct page___93 *, gfp_t);
	void (*freepage)(struct page___93 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___93 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___93 *, struct page___93 *, struct page___93 *, enum migrate_mode);
	int (*launder_page)(struct page___93 *);
	int (*is_partially_uptodate)(struct page___93 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___93 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___93 *, struct page___93 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___93 *, sector_t *);
	void (*swap_deactivate)(struct file___93 *);
	void (*invalidatepage_range)(struct page___93 *, unsigned int, unsigned int);
};

struct inode_operations___93 {
	struct dentry___94 * (*lookup)(struct inode___94 *, struct dentry___94 *, unsigned int);
	void * (*follow_link)(struct dentry___94 *, struct nameidata *);
	int (*permission)(struct inode___94 *, int);
	struct posix_acl * (*get_acl)(struct inode___94 *, int);
	int (*readlink)(struct dentry___94 *, char *, int);
	void (*put_link)(struct dentry___94 *, struct nameidata *, void *);
	int (*create)(struct inode___94 *, struct dentry___94 *, umode_t, bool);
	int (*link)(struct dentry___94 *, struct inode___94 *, struct dentry___94 *);
	int (*unlink)(struct inode___94 *, struct dentry___94 *);
	int (*symlink)(struct inode___94 *, struct dentry___94 *, const char *);
	int (*mkdir)(struct inode___94 *, struct dentry___94 *, umode_t);
	int (*rmdir)(struct inode___94 *, struct dentry___94 *);
	int (*mknod)(struct inode___94 *, struct dentry___94 *, umode_t, dev_t);
	int (*rename)(struct inode___94 *, struct dentry___94 *, struct inode___94 *, struct dentry___94 *);
	int (*setattr)(struct dentry___94 *, struct iattr___94 *);
	int (*getattr)(struct vfsmount *, struct dentry___94 *, struct kstat *);
	int (*setxattr)(struct dentry___94 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___94 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___94 *, char *, size_t);
	int (*removexattr)(struct dentry___94 *, const char *);
	int (*fiemap)(struct inode___94 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___94 *, struct timespec *, int);
	int (*atomic_open)(struct inode___94 *, struct dentry___94 *, struct file___93 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___57;

struct seq_file___69;

struct file_operations___93 {
	struct module *owner;
	loff_t (*llseek)(struct file___93 *, loff_t, int);
	ssize_t (*read)(struct file___93 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___93 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___93 *, void *, filldir_t);
	unsigned int (*poll)(struct file___93 *, struct poll_table_struct___57 *);
	long int (*unlocked_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___93 *, struct vm_area_struct___98 *);
	int (*open)(struct inode___94 *, struct file___93 *);
	int (*flush)(struct file___93 *, fl_owner_t);
	int (*release)(struct inode___94 *, struct file___93 *);
	int (*fsync)(struct file___93 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___93 *, int);
	int (*lock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*sendpage)(struct file___93 *, struct page___93 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___93 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___93 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___93 *, long int, struct file_lock___93 **, void **);
		struct {
			int (*setlease)(struct file___93 *, long int, struct file_lock___93 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___93 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___69 *, struct file___93 *);
};

struct file_lock_operations___93;

struct lock_manager_operations___93;

struct file_lock___93 {
	struct file_lock___93 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___50 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___93 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___93 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___93 *fl_ops;
	const struct lock_manager_operations___93 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___93 {
	void (*fl_copy_lock)(struct file_lock___93 *, struct file_lock___93 *);
	void (*fl_release_private)(struct file_lock___93 *);
};

struct lock_manager_operations___93 {
	int (*lm_compare_owner)(struct file_lock___93 *, struct file_lock___93 *);
	long unsigned int (*lm_owner_key)(struct file_lock___93 *);
	void (*lm_notify)(struct file_lock___93 *);
	int (*lm_grant)(struct file_lock___93 *, struct file_lock___93 *, int);
	void (*lm_break)(struct file_lock___93 *);
	int (*lm_change)(struct file_lock___93 **, int);
};

struct fasync_struct___93 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___93 *fa_next;
	struct file___93 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___93 {
	const char *name;
	int fs_flags;
	struct dentry___94 * (*mount)(struct file_system_type___93 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___94 *);
	struct module *owner;
	struct file_system_type___93 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___93 {
	struct inode___94 * (*alloc_inode)(struct super_block___94 *);
	void (*destroy_inode)(struct inode___94 *);
	void (*dirty_inode)(struct inode___94 *, int);
	int (*write_inode)(struct inode___94 *, struct writeback_control *);
	int (*drop_inode)(struct inode___94 *);
	void (*evict_inode)(struct inode___94 *);
	void (*put_super)(struct super_block___94 *);
	int (*sync_fs)(struct super_block___94 *, int);
	int (*freeze_fs)(struct super_block___94 *);
	int (*unfreeze_fs)(struct super_block___94 *);
	int (*statfs)(struct dentry___94 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___94 *, int *, char *);
	void (*umount_begin)(struct super_block___94 *);
	int (*show_options)(struct seq_file___69 *, struct dentry___94 *);
	int (*show_devname)(struct seq_file___69 *, struct dentry___94 *);
	int (*show_path)(struct seq_file___69 *, struct dentry___94 *);
	int (*show_stats)(struct seq_file___69 *, struct dentry___94 *);
	ssize_t (*quota_read)(struct super_block___94 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___94 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___94 *);
	int (*bdev_try_to_free_page)(struct super_block___94 *, struct page___93 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___94 *);
	void (*free_cached_objects)(struct super_block___94 *, int);
};

struct xattr_handler___60 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___94 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___94 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___94 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___58)(struct file___93 *, wait_queue_head_t *, struct poll_table_struct___57 *);

struct poll_table_struct___57 {
	poll_queue_proc___58 _qproc;
	long unsigned int _key;
};

struct seq_operations___68;

struct seq_file___69 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___94 lock;
	const struct seq_operations___68 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___68 {
	void * (*start)(struct seq_file___69 *, loff_t *);
	void (*stop)(struct seq_file___69 *, void *);
	void * (*next)(struct seq_file___69 *, void *, loff_t *);
	int (*show)(struct seq_file___69 *, void *);
};

struct tracer_stat___2 {
	const char *name;
	void * (*stat_start)(struct tracer_stat___2 *);
	void * (*stat_next)(void *, int);
	int (*stat_cmp)(void *, void *);
	int (*stat_show)(struct seq_file___69 *, void *);
	void (*stat_release)(void *);
	int (*stat_headers)(struct seq_file___69 *);
};

struct xol_area___93 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___93 *page;
	long unsigned int vaddr;
};

struct vm_fault___78;

struct vm_operations_struct___81 {
	void (*open)(struct vm_area_struct___98 *);
	void (*close)(struct vm_area_struct___98 *);
	int (*fault)(struct vm_area_struct___98 *, struct vm_fault___78 *);
	int (*page_mkwrite)(struct vm_area_struct___98 *, struct vm_fault___78 *);
	int (*access)(struct vm_area_struct___98 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___98 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___98 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___98 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___98 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___93 {
	struct task_struct___93 *task;
	struct core_thread___93 *next;
};

struct core_state___93 {
	atomic_t nr_threads;
	struct core_thread___93 dumper;
	struct completion startup;
};

struct nsproxy___51 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___50 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___93 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___93 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___93 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___50 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___50 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___94 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___60 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___60 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___45 {
	struct pmu___45 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___94 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___93 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___45 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___78 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___93 *page;
};

struct bus_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___72 *, char *);
	ssize_t (*store)(struct bus_type___72 *, const char *, size_t);
};

struct device_attribute___72;

struct driver_attribute___72;

struct bus_type___72 {
	const char *name;
	const char *dev_name;
	struct device___72 *dev_root;
	struct bus_attribute___72 *bus_attrs;
	struct device_attribute___72 *dev_attrs;
	struct driver_attribute___72 *drv_attrs;
	const struct attribute_group___65 **bus_groups;
	const struct attribute_group___65 **dev_groups;
	const struct attribute_group___65 **drv_groups;
	int (*match)(struct device___72 *, struct device_driver___72 *);
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	int (*probe)(struct device___72 *);
	int (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*online)(struct device___72 *);
	int (*offline)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct device___72 *, struct device_attribute___72 *, char *);
	ssize_t (*store)(struct device___72 *, struct device_attribute___72 *, const char *, size_t);
};

struct driver_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___72 *, char *);
	ssize_t (*store)(struct device_driver___72 *, const char *, size_t);
};

struct device_driver___72 {
	const char *name;
	struct bus_type___72 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___72 *);
	int (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	const struct attribute_group___65 **groups;
	const struct dev_pm_ops___72 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___72 {
	const char *name;
	const struct attribute_group___65 **groups;
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
};

struct class_attribute___72;

struct class___72 {
	const char *name;
	struct module *owner;
	struct class_attribute___72 *class_attrs;
	struct device_attribute___72 *dev_attrs;
	const struct attribute_group___65 **dev_groups;
	struct bin_attribute___65 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *);
	void (*class_release)(struct class___72 *);
	void (*dev_release)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
	struct subsys_private *p;
};

struct class_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct class___72 *, struct class_attribute___72 *, char *);
	ssize_t (*store)(struct class___72 *, struct class_attribute___72 *, const char *, size_t);
	const void * (*namespace)(struct class___72 *, const struct class_attribute___72 *);
};

struct device_rh___72 {
	struct dev_pm_info_rh___72 power;
};

struct cgroupfs_root___60;

struct cgroup___60 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___60 *parent;
	struct dentry___94 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___60 *subsys[11];
	struct cgroupfs_root___60 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___94 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___60 {
	struct super_block___94 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___60 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___45;

struct pmu___45 {
	struct list_head entry;
	struct device___72 *dev;
	const struct attribute_group___65 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___45 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___45 *);
	void (*pmu_disable)(struct pmu___45 *);
	int (*event_init)(struct perf_event___45 *);
	int (*add)(struct perf_event___45 *, int);
	void (*del)(struct perf_event___45 *, int);
	void (*start)(struct perf_event___45 *, int);
	void (*stop)(struct perf_event___45 *, int);
	void (*read)(struct perf_event___45 *);
	void (*start_txn)(struct pmu___45 *);
	int (*commit_txn)(struct pmu___45 *);
	void (*cancel_txn)(struct pmu___45 *);
	int (*event_idx)(struct perf_event___45 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___45 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___45 *);
};

struct perf_cpu_context___45 {
	struct perf_event_context___45 ctx;
	struct perf_event_context___45 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___45 *unique_pmu;
	struct perf_cgroup___45 *cgrp;
};

struct trace_event_functions___35;

struct trace_event___35 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___35 *funcs;
};

struct ftrace_event_class___35;

struct ftrace_event_call___35 {
	struct list_head list;
	struct ftrace_event_class___35 *class;
	char *name;
	struct trace_event___35 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___45 {
	struct cgroup_subsys_state___60 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___67 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___67 *);
	void (*irq_shutdown)(struct irq_data___67 *);
	void (*irq_enable)(struct irq_data___67 *);
	void (*irq_disable)(struct irq_data___67 *);
	void (*irq_ack)(struct irq_data___67 *);
	void (*irq_mask)(struct irq_data___67 *);
	void (*irq_mask_ack)(struct irq_data___67 *);
	void (*irq_unmask)(struct irq_data___67 *);
	void (*irq_eoi)(struct irq_data___67 *);
	int (*irq_set_affinity)(struct irq_data___67 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___67 *);
	int (*irq_set_type)(struct irq_data___67 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___67 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___67 *);
	void (*irq_bus_sync_unlock)(struct irq_data___67 *);
	void (*irq_cpu_online)(struct irq_data___67 *);
	void (*irq_cpu_offline)(struct irq_data___67 *);
	void (*irq_suspend)(struct irq_data___67 *);
	void (*irq_resume)(struct irq_data___67 *);
	void (*irq_pm_shutdown)(struct irq_data___67 *);
	void (*irq_print_chip)(struct irq_data___67 *, struct seq_file___69 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___67 *, void *);
	long unsigned int flags;
};

struct trace_array___4;

struct tracer___4;

struct trace_buffer___4;

struct trace_iterator___35 {
	struct trace_array___4 *tr;
	struct tracer___4 *trace;
	struct trace_buffer___4 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___94 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___4;

struct trace_buffer___4 {
	struct trace_array___4 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___4 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___4 {
	struct trace_array___4 *tr;
	struct dentry___94 *dir;
	int cpu;
};

struct trace_array___4 {
	struct list_head list;
	char *name;
	struct trace_buffer___4 trace_buffer;
	struct trace_buffer___4 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___4 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___4 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___94 *dir;
	struct dentry___94 *options;
	struct dentry___94 *percpu_dir;
	struct dentry___94 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___93 *waiter;
	int ref;
};

struct tracer___4 {
	const char *name;
	int (*init)(struct trace_array___4 *);
	void (*reset)(struct trace_array___4 *);
	void (*start)(struct trace_array___4 *);
	void (*stop)(struct trace_array___4 *);
	void (*open)(struct trace_iterator___35 *);
	void (*pipe_open)(struct trace_iterator___35 *);
	int (*wait_pipe)(struct trace_iterator___35 *);
	void (*close)(struct trace_iterator___35 *);
	void (*pipe_close)(struct trace_iterator___35 *);
	ssize_t (*read)(struct trace_iterator___35 *, struct file___93 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___35 *, struct file___93 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___69 *);
	enum print_line_t (*print_line)(struct trace_iterator___35 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___4 *, u32, int);
	struct tracer___4 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___35)(struct trace_iterator___35 *, int, struct trace_event___35 *);

struct trace_event_functions___35 {
	trace_print_func___35 trace;
	trace_print_func___35 raw;
	trace_print_func___35 hex;
	trace_print_func___35 binary;
};

struct ftrace_event_class___35 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___35 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___35 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___35 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___35 *);
};

struct trace_array_cpu___4 {
	struct trace_cpu___4 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

struct stat_node {
	struct rb_node node;
	void *stat;
};

struct stat_session {
	struct list_head session_list;
	struct tracer_stat___2 *ts;
	struct rb_root stat_root;
	struct mutex___94 stat_mutex;
	struct dentry___94 *file;
};

typedef int (*cmp_stat_t)(void *, void *);

struct page___94;

typedef struct page___94 *pgtable_t___94;

struct address_space___94;

struct kmem_cache___82;

struct page___94 {
	long unsigned int flags;
	struct address_space___94 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___94 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___94 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___82 *slab_cache;
		struct page___94 *first_page;
	};
	long: 64;
};

struct thread_struct___46;

struct task_struct___94;

struct pv_cpu_ops___94 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___46 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___46 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___94 *);
	void (*end_context_switch)(struct task_struct___94 *);
};

struct perf_event___46;

struct thread_struct___46 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___46 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___51;

struct pid_link___51 {
	struct hlist_node node;
	struct pid___51 *pid;
};

struct mutex___95 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___94 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___90 {
	struct page___94 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___99;

struct nsproxy___52;

struct signal_struct___94;

struct css_set___61;

struct perf_event_context___46;

struct task_struct___94 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___94 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___99 *mm;
	struct mm_struct___99 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___94 *real_parent;
	struct task_struct___94 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___94 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___51 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___94 = 0,
		VTIME_USER___94 = 1,
		VTIME_SYS___94 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___46 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___52 *nsproxy;
	struct signal_struct___94 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___61 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___46 *perf_event_ctxp[2];
	struct mutex___95 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___90 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___99 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___99 *, struct mm_struct___99 *);
	void (*dup_mmap)(struct mm_struct___99 *, struct mm_struct___99 *);
	void (*exit_mmap)(struct mm_struct___99 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___99 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___99 *);
	void (*pgd_free)(struct mm_struct___99 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___99 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___99 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___99 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___99 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___99 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___99 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___99 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___99 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___99 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___99 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___99 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___95 lock;
	void *vdso;
} mm_context_t___95;

struct xol_area___94;

struct uprobes_state___94 {
	struct xol_area___94 *xol_area;
};

struct vm_area_struct___99;

struct file___94;

struct core_state___94;

struct mm_struct___99 {
	struct vm_area_struct___99 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___99 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___99 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___95 context;
	long unsigned int flags;
	struct core_state___94 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___94 *owner;
	struct file___94 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___94 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___50;

struct module_kobject___49 {
	struct kobject kobj;
	struct module___50 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___49;

struct ftrace_event_call___36;

struct module___50 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___49 mkobj;
	struct module_attribute___49 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___36 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___94 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___46 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___94 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___94 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___94 *target;
};

typedef void (*perf_overflow_handler_t___46)(struct perf_event___46 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___46;

typedef void (*ftrace_func_t___46)(long unsigned int, long unsigned int, struct ftrace_ops___46 *, struct pt_regs *);

struct ftrace_ops___46 {
	ftrace_func_t___46 func;
	struct ftrace_ops___46 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___95 regex_lock;
};

struct pmu___46;

struct fasync_struct___94;

struct pid_namespace___51;

struct perf_cgroup___46;

struct perf_event___46 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___46 *group_leader;
	struct pmu___46 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___46 hw;
	struct perf_event_context___46 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___95 child_mutex;
	struct list_head child_list;
	struct perf_event___46 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___94 *owner;
	struct mutex___95 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___94 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___46 *);
	struct callback_head callback_head;
	struct pid_namespace___51 *ns;
	u64 id;
	perf_overflow_handler_t___46 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___36 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___46 ftrace_ops;
	struct perf_cgroup___46 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct seq_operations___69;

struct seq_file___70 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___95 lock;
	const struct seq_operations___69 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___69 {
	void * (*start)(struct seq_file___70 *, loff_t *);
	void (*stop)(struct seq_file___70 *, void *);
	void * (*next)(struct seq_file___70 *, void *, loff_t *);
	int (*show)(struct seq_file___70 *, void *);
};

struct inode___95;

struct dentry_operations___94;

struct super_block___95;

struct dentry___95 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___95 *d_parent;
	struct qstr d_name;
	struct inode___95 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___94 *d_op;
	struct super_block___95 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___94;

struct address_space___94 {
	struct inode___95 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___95 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___94 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___94;

struct file_operations___94;

struct file_lock___94;

struct dquot___94;

struct block_device___94;

struct inode___95 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___94 *i_op;
	struct super_block___95 *i_sb;
	struct address_space___94 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___95 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___94 *i_fop;
	struct file_lock___94 *i_flock;
	struct address_space___94 i_data;
	struct dquot___94 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___94 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___94;

struct dentry_operations___94 {
	int (*d_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_hash)(const struct dentry___95 *, struct qstr *);
	int (*d_compare)(const struct dentry___95 *, const struct dentry___95 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___95 *);
	void (*d_release)(struct dentry___95 *);
	void (*d_prune)(struct dentry___95 *);
	void (*d_iput)(struct dentry___95 *, struct inode___95 *);
	char * (*d_dname)(struct dentry___95 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___94 *);
	int (*d_manage)(struct dentry___95 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___94;

struct mem_dqinfo___94 {
	struct quota_format_type___94 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___94;

struct quota_info___94 {
	unsigned int flags;
	struct mutex___95 dqio_mutex;
	struct mutex___95 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___95 *files[2];
	struct mem_dqinfo___94 info[2];
	const struct quota_format_ops___94 *ops[2];
};

struct file_system_type___94;

struct super_operations___94;

struct dquot_operations___94;

struct quotactl_ops___94;

struct xattr_handler___61;

struct super_block___95 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___94 *s_type;
	const struct super_operations___94 *s_op;
	const struct dquot_operations___94 *dq_op;
	const struct quotactl_ops___94 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___95 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___61 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___94 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___94 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___95 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___94 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___94 {
	struct vfsmount *mnt;
	struct dentry___95 *dentry;
};

struct upid___51 {
	int nr;
	struct pid_namespace___51 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___51 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___94 *child_reaper;
	struct kmem_cache___82 *pid_cachep;
	unsigned int level;
	struct pid_namespace___51 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___95 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___51 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___51 numbers[1];
};

struct irq_data___68;

struct x86_io_apic_ops___68 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___68 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___68;

struct irq_data___68 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___68 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___73;

struct dev_pm_ops___73 {
	int (*prepare)(struct device___73 *);
	void (*complete)(struct device___73 *);
	int (*suspend)(struct device___73 *);
	int (*resume)(struct device___73 *);
	int (*freeze)(struct device___73 *);
	int (*thaw)(struct device___73 *);
	int (*poweroff)(struct device___73 *);
	int (*restore)(struct device___73 *);
	int (*suspend_late)(struct device___73 *);
	int (*resume_early)(struct device___73 *);
	int (*freeze_late)(struct device___73 *);
	int (*thaw_early)(struct device___73 *);
	int (*poweroff_late)(struct device___73 *);
	int (*restore_early)(struct device___73 *);
	int (*suspend_noirq)(struct device___73 *);
	int (*resume_noirq)(struct device___73 *);
	int (*freeze_noirq)(struct device___73 *);
	int (*thaw_noirq)(struct device___73 *);
	int (*poweroff_noirq)(struct device___73 *);
	int (*restore_noirq)(struct device___73 *);
	int (*runtime_suspend)(struct device___73 *);
	int (*runtime_resume)(struct device___73 *);
	int (*runtime_idle)(struct device___73 *);
};

struct device_type___73;

struct bus_type___73;

struct device_driver___73;

struct dev_pm_domain___73;

struct class___73;

struct attribute_group___66;

struct device_rh___73;

struct device___73 {
	struct device___73 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___73 *type;
	struct mutex___95 mutex;
	struct bus_type___73 *bus;
	struct device_driver___73 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___73 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___73 *class;
	const struct attribute_group___66 **groups;
	void (*release)(struct device___73 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___73 *device_rh;
};

struct dev_pm_info_rh___73 {
	void (*set_latency_tolerance)(struct device___73 *, s32);
};

struct dev_pm_domain___73 {
	struct dev_pm_ops___73 ops;
};

struct smp_ops___94 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___94 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___94 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___95 *bd_inode;
	struct super_block___95 *bd_super;
	struct mutex___95 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___94 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___95 bd_fsfreeze_mutex;
};

struct cgroup___61;

struct cgroup_subsys_state___61 {
	struct cgroup___61 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___95 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___94 *ia_file;
};

struct fown_struct___51 {
	rwlock_t lock;
	struct pid___51 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___94 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___94 f_path;
	struct inode___95 *f_inode;
	const struct file_operations___94 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___51 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___94 *f_mapping;
	struct mutex___95 f_pos_lock;
};

struct zone___94;

struct lruvec___94 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___94 *zone;
};

struct pglist_data___94;

struct zone___94 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___94 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___94 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___94 {
	struct zone___94 *zone;
	int zone_idx;
};

struct zonelist___94 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___94 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___94 {
	struct zone___94 node_zones[4];
	struct zonelist___94 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___94 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___94 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___95 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___95 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___94 {
	int qf_fmt_id;
	const struct quota_format_ops___94 *qf_ops;
	struct module___50 *qf_owner;
	struct quota_format_type___94 *qf_next;
};

struct quota_format_ops___94 {
	int (*check_quota_file)(struct super_block___95 *, int);
	int (*read_file_info)(struct super_block___95 *, int);
	int (*write_file_info)(struct super_block___95 *, int);
	int (*free_file_info)(struct super_block___95 *, int);
	int (*read_dqblk)(struct dquot___94 *);
	int (*commit_dqblk)(struct dquot___94 *);
	int (*release_dqblk)(struct dquot___94 *);
};

struct dquot_operations___94 {
	int (*write_dquot)(struct dquot___94 *);
	struct dquot___94 * (*alloc_dquot)(struct super_block___95 *, int);
	void (*destroy_dquot)(struct dquot___94 *);
	int (*acquire_dquot)(struct dquot___94 *);
	int (*release_dquot)(struct dquot___94 *);
	int (*mark_dirty)(struct dquot___94 *);
	int (*write_info)(struct super_block___95 *, int);
	qsize_t * (*get_reserved_space)(struct inode___95 *);
};

struct quotactl_ops___94 {
	int (*quota_on)(struct super_block___95 *, int, int, struct path___94 *);
	int (*quota_on_meta)(struct super_block___95 *, int, int);
	int (*quota_off)(struct super_block___95 *, int);
	int (*quota_sync)(struct super_block___95 *, int);
	int (*get_info)(struct super_block___95 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___95 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___95 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___95 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___95 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___95 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___95 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___95 *, unsigned int);
};

struct address_space_operations___94 {
	int (*writepage)(struct page___94 *, struct writeback_control *);
	int (*readpage)(struct file___94 *, struct page___94 *);
	int (*writepages)(struct address_space___94 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___94 *);
	int (*readpages)(struct file___94 *, struct address_space___94 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___94 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___94 **, void **);
	int (*write_end)(struct file___94 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___94 *, void *);
	sector_t (*bmap)(struct address_space___94 *, sector_t);
	void (*invalidatepage)(struct page___94 *, long unsigned int);
	int (*releasepage)(struct page___94 *, gfp_t);
	void (*freepage)(struct page___94 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___94 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___94 *, struct page___94 *, struct page___94 *, enum migrate_mode);
	int (*launder_page)(struct page___94 *);
	int (*is_partially_uptodate)(struct page___94 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___94 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___94 *, struct page___94 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___94 *, sector_t *);
	void (*swap_deactivate)(struct file___94 *);
	void (*invalidatepage_range)(struct page___94 *, unsigned int, unsigned int);
};

struct inode_operations___94 {
	struct dentry___95 * (*lookup)(struct inode___95 *, struct dentry___95 *, unsigned int);
	void * (*follow_link)(struct dentry___95 *, struct nameidata *);
	int (*permission)(struct inode___95 *, int);
	struct posix_acl * (*get_acl)(struct inode___95 *, int);
	int (*readlink)(struct dentry___95 *, char *, int);
	void (*put_link)(struct dentry___95 *, struct nameidata *, void *);
	int (*create)(struct inode___95 *, struct dentry___95 *, umode_t, bool);
	int (*link)(struct dentry___95 *, struct inode___95 *, struct dentry___95 *);
	int (*unlink)(struct inode___95 *, struct dentry___95 *);
	int (*symlink)(struct inode___95 *, struct dentry___95 *, const char *);
	int (*mkdir)(struct inode___95 *, struct dentry___95 *, umode_t);
	int (*rmdir)(struct inode___95 *, struct dentry___95 *);
	int (*mknod)(struct inode___95 *, struct dentry___95 *, umode_t, dev_t);
	int (*rename)(struct inode___95 *, struct dentry___95 *, struct inode___95 *, struct dentry___95 *);
	int (*setattr)(struct dentry___95 *, struct iattr___95 *);
	int (*getattr)(struct vfsmount *, struct dentry___95 *, struct kstat *);
	int (*setxattr)(struct dentry___95 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___95 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___95 *, char *, size_t);
	int (*removexattr)(struct dentry___95 *, const char *);
	int (*fiemap)(struct inode___95 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___95 *, struct timespec *, int);
	int (*atomic_open)(struct inode___95 *, struct dentry___95 *, struct file___94 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___58;

struct file_operations___94 {
	struct module___50 *owner;
	loff_t (*llseek)(struct file___94 *, loff_t, int);
	ssize_t (*read)(struct file___94 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___94 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___94 *, void *, filldir_t);
	unsigned int (*poll)(struct file___94 *, struct poll_table_struct___58 *);
	long int (*unlocked_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___94 *, struct vm_area_struct___99 *);
	int (*open)(struct inode___95 *, struct file___94 *);
	int (*flush)(struct file___94 *, fl_owner_t);
	int (*release)(struct inode___95 *, struct file___94 *);
	int (*fsync)(struct file___94 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___94 *, int);
	int (*lock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*sendpage)(struct file___94 *, struct page___94 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___94 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___94 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___94 *, long int, struct file_lock___94 **, void **);
		struct {
			int (*setlease)(struct file___94 *, long int, struct file_lock___94 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___94 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___70 *, struct file___94 *);
};

struct file_lock_operations___94;

struct lock_manager_operations___94;

struct file_lock___94 {
	struct file_lock___94 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___51 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___94 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___94 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___94 *fl_ops;
	const struct lock_manager_operations___94 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___94 {
	void (*fl_copy_lock)(struct file_lock___94 *, struct file_lock___94 *);
	void (*fl_release_private)(struct file_lock___94 *);
};

struct lock_manager_operations___94 {
	int (*lm_compare_owner)(struct file_lock___94 *, struct file_lock___94 *);
	long unsigned int (*lm_owner_key)(struct file_lock___94 *);
	void (*lm_notify)(struct file_lock___94 *);
	int (*lm_grant)(struct file_lock___94 *, struct file_lock___94 *, int);
	void (*lm_break)(struct file_lock___94 *);
	int (*lm_change)(struct file_lock___94 **, int);
};

struct fasync_struct___94 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___94 *fa_next;
	struct file___94 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___94 {
	const char *name;
	int fs_flags;
	struct dentry___95 * (*mount)(struct file_system_type___94 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___95 *);
	struct module___50 *owner;
	struct file_system_type___94 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___94 {
	struct inode___95 * (*alloc_inode)(struct super_block___95 *);
	void (*destroy_inode)(struct inode___95 *);
	void (*dirty_inode)(struct inode___95 *, int);
	int (*write_inode)(struct inode___95 *, struct writeback_control *);
	int (*drop_inode)(struct inode___95 *);
	void (*evict_inode)(struct inode___95 *);
	void (*put_super)(struct super_block___95 *);
	int (*sync_fs)(struct super_block___95 *, int);
	int (*freeze_fs)(struct super_block___95 *);
	int (*unfreeze_fs)(struct super_block___95 *);
	int (*statfs)(struct dentry___95 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___95 *, int *, char *);
	void (*umount_begin)(struct super_block___95 *);
	int (*show_options)(struct seq_file___70 *, struct dentry___95 *);
	int (*show_devname)(struct seq_file___70 *, struct dentry___95 *);
	int (*show_path)(struct seq_file___70 *, struct dentry___95 *);
	int (*show_stats)(struct seq_file___70 *, struct dentry___95 *);
	ssize_t (*quota_read)(struct super_block___95 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___95 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___95 *);
	int (*bdev_try_to_free_page)(struct super_block___95 *, struct page___94 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___95 *);
	void (*free_cached_objects)(struct super_block___95 *, int);
};

struct xattr_handler___61 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___95 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___95 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___95 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___59)(struct file___94 *, wait_queue_head_t *, struct poll_table_struct___58 *);

struct poll_table_struct___58 {
	poll_queue_proc___59 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___82;

struct vm_area_struct___99 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___99 *vm_next;
	struct vm_area_struct___99 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___99 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___82 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___94 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xol_area___94 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___94 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___82;

struct memcg_cache_params___82;

struct kmem_cache___82 {
	struct kmem_cache_cpu___82 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___82 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___79;

struct vm_operations_struct___82 {
	void (*open)(struct vm_area_struct___99 *);
	void (*close)(struct vm_area_struct___99 *);
	int (*fault)(struct vm_area_struct___99 *, struct vm_fault___79 *);
	int (*page_mkwrite)(struct vm_area_struct___99 *, struct vm_fault___79 *);
	int (*access)(struct vm_area_struct___99 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___99 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___99 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___99 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___99 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___94 {
	struct task_struct___94 *task;
	struct core_thread___94 *next;
};

struct core_state___94 {
	atomic_t nr_threads;
	struct core_thread___94 dumper;
	struct completion startup;
};

struct nsproxy___52 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___51 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___94 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___94 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___94 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___51 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___51 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___95 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___61 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___61 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___46 {
	struct pmu___46 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___95 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___94 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___46 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___66;

struct attribute_group___66 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___66 **bin_attrs;
};

struct bin_attribute___66 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___94 *, struct kobject *, struct bin_attribute___66 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___94 *, struct kobject *, struct bin_attribute___66 *, char *, loff_t, size_t);
	int (*mmap)(struct file___94 *, struct kobject *, struct bin_attribute___66 *, struct vm_area_struct___99 *);
};

struct module_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___49 *, struct module_kobject___49 *, char *);
	ssize_t (*store)(struct module_attribute___49 *, struct module_kobject___49 *, const char *, size_t);
	void (*setup)(struct module___50 *, const char *);
	int (*test)(struct module___50 *);
	void (*free)(struct module___50 *);
};

struct trace_event_functions___36;

struct trace_event___36 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___36 *funcs;
};

struct ftrace_event_class___36;

struct ftrace_event_call___36 {
	struct list_head list;
	struct ftrace_event_class___36 *class;
	char *name;
	struct trace_event___36 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct kmem_cache_cpu___82 {
	void **freelist;
	long unsigned int tid;
	struct page___94 *page;
	struct page___94 *partial;
};

struct memcg_cache_params___82 {
	bool is_root_cache;
	union {
		struct kmem_cache___82 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___82 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___79 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___94 *page;
};

struct bus_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___73 *, char *);
	ssize_t (*store)(struct bus_type___73 *, const char *, size_t);
};

struct device_attribute___73;

struct driver_attribute___73;

struct bus_type___73 {
	const char *name;
	const char *dev_name;
	struct device___73 *dev_root;
	struct bus_attribute___73 *bus_attrs;
	struct device_attribute___73 *dev_attrs;
	struct driver_attribute___73 *drv_attrs;
	const struct attribute_group___66 **bus_groups;
	const struct attribute_group___66 **dev_groups;
	const struct attribute_group___66 **drv_groups;
	int (*match)(struct device___73 *, struct device_driver___73 *);
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	int (*probe)(struct device___73 *);
	int (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*online)(struct device___73 *);
	int (*offline)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct device___73 *, struct device_attribute___73 *, char *);
	ssize_t (*store)(struct device___73 *, struct device_attribute___73 *, const char *, size_t);
};

struct driver_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___73 *, char *);
	ssize_t (*store)(struct device_driver___73 *, const char *, size_t);
};

struct device_driver___73 {
	const char *name;
	struct bus_type___73 *bus;
	struct module___50 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___73 *);
	int (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	const struct attribute_group___66 **groups;
	const struct dev_pm_ops___73 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___73 {
	const char *name;
	const struct attribute_group___66 **groups;
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
};

struct class_attribute___73;

struct class___73 {
	const char *name;
	struct module___50 *owner;
	struct class_attribute___73 *class_attrs;
	struct device_attribute___73 *dev_attrs;
	const struct attribute_group___66 **dev_groups;
	struct bin_attribute___66 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *);
	void (*class_release)(struct class___73 *);
	void (*dev_release)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
	struct subsys_private *p;
};

struct class_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct class___73 *, struct class_attribute___73 *, char *);
	ssize_t (*store)(struct class___73 *, struct class_attribute___73 *, const char *, size_t);
	const void * (*namespace)(struct class___73 *, const struct class_attribute___73 *);
};

struct device_rh___73 {
	struct dev_pm_info_rh___73 power;
};

struct cgroupfs_root___61;

struct cgroup___61 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___61 *parent;
	struct dentry___95 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___61 *subsys[11];
	struct cgroupfs_root___61 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___95 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___61 {
	struct super_block___95 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___61 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___46;

struct pmu___46 {
	struct list_head entry;
	struct device___73 *dev;
	const struct attribute_group___66 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___46 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___46 *);
	void (*pmu_disable)(struct pmu___46 *);
	int (*event_init)(struct perf_event___46 *);
	int (*add)(struct perf_event___46 *, int);
	void (*del)(struct perf_event___46 *, int);
	void (*start)(struct perf_event___46 *, int);
	void (*stop)(struct perf_event___46 *, int);
	void (*read)(struct perf_event___46 *);
	void (*start_txn)(struct pmu___46 *);
	int (*commit_txn)(struct pmu___46 *);
	void (*cancel_txn)(struct pmu___46 *);
	int (*event_idx)(struct perf_event___46 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___50 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___46 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___46 *);
};

struct perf_cpu_context___46 {
	struct perf_event_context___46 ctx;
	struct perf_event_context___46 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___46 *unique_pmu;
	struct perf_cgroup___46 *cgrp;
};

struct perf_cgroup___46 {
	struct cgroup_subsys_state___61 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___68 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___68 *);
	void (*irq_shutdown)(struct irq_data___68 *);
	void (*irq_enable)(struct irq_data___68 *);
	void (*irq_disable)(struct irq_data___68 *);
	void (*irq_ack)(struct irq_data___68 *);
	void (*irq_mask)(struct irq_data___68 *);
	void (*irq_mask_ack)(struct irq_data___68 *);
	void (*irq_unmask)(struct irq_data___68 *);
	void (*irq_eoi)(struct irq_data___68 *);
	int (*irq_set_affinity)(struct irq_data___68 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___68 *);
	int (*irq_set_type)(struct irq_data___68 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___68 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___68 *);
	void (*irq_bus_sync_unlock)(struct irq_data___68 *);
	void (*irq_cpu_online)(struct irq_data___68 *);
	void (*irq_cpu_offline)(struct irq_data___68 *);
	void (*irq_suspend)(struct irq_data___68 *);
	void (*irq_resume)(struct irq_data___68 *);
	void (*irq_pm_shutdown)(struct irq_data___68 *);
	void (*irq_print_chip)(struct irq_data___68 *, struct seq_file___70 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___68 *, void *);
	long unsigned int flags;
};

struct trace_array___5;

struct tracer___5;

struct trace_buffer___5;

struct trace_iterator___36 {
	struct trace_array___5 *tr;
	struct tracer___5 *trace;
	struct trace_buffer___5 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___95 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___5;

struct trace_buffer___5 {
	struct trace_array___5 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___5 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___5 {
	struct trace_array___5 *tr;
	struct dentry___95 *dir;
	int cpu;
};

struct trace_array___5 {
	struct list_head list;
	char *name;
	struct trace_buffer___5 trace_buffer;
	struct trace_buffer___5 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___5 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___5 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___95 *dir;
	struct dentry___95 *options;
	struct dentry___95 *percpu_dir;
	struct dentry___95 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___94 *waiter;
	int ref;
};

struct tracer___5 {
	const char *name;
	int (*init)(struct trace_array___5 *);
	void (*reset)(struct trace_array___5 *);
	void (*start)(struct trace_array___5 *);
	void (*stop)(struct trace_array___5 *);
	void (*open)(struct trace_iterator___36 *);
	void (*pipe_open)(struct trace_iterator___36 *);
	int (*wait_pipe)(struct trace_iterator___36 *);
	void (*close)(struct trace_iterator___36 *);
	void (*pipe_close)(struct trace_iterator___36 *);
	ssize_t (*read)(struct trace_iterator___36 *, struct file___94 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___36 *, struct file___94 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___70 *);
	enum print_line_t (*print_line)(struct trace_iterator___36 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___5 *, u32, int);
	struct tracer___5 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___36)(struct trace_iterator___36 *, int, struct trace_event___36 *);

struct trace_event_functions___36 {
	trace_print_func___36 trace;
	trace_print_func___36 raw;
	trace_print_func___36 hex;
	trace_print_func___36 binary;
};

struct ftrace_event_class___36 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___36 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___36 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___36 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___36 *);
};

struct trace_array_cpu___5 {
	struct trace_cpu___5 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

struct trace_bprintk_fmt {
	struct list_head list;
	const char *fmt;
};

struct page___95;

typedef struct page___95 *pgtable_t___95;

struct address_space___95;

struct kmem_cache___83;

struct page___95 {
	long unsigned int flags;
	struct address_space___95 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___95 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___95 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___83 *slab_cache;
		struct page___95 *first_page;
	};
	long: 64;
};

struct thread_struct___47;

struct task_struct___95;

struct pv_cpu_ops___95 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___47 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___47 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___95 *);
	void (*end_context_switch)(struct task_struct___95 *);
};

struct perf_event___47;

struct thread_struct___47 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___47 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___52;

struct pid_link___52 {
	struct hlist_node node;
	struct pid___52 *pid;
};

struct mutex___96 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___95 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___91 {
	struct page___95 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___100;

struct nsproxy___53;

struct signal_struct___95;

struct css_set___62;

struct perf_event_context___47;

struct task_struct___95 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___95 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___100 *mm;
	struct mm_struct___100 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___95 *real_parent;
	struct task_struct___95 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___95 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___52 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___95 = 0,
		VTIME_USER___95 = 1,
		VTIME_SYS___95 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___47 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___53 *nsproxy;
	struct signal_struct___95 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___62 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___47 *perf_event_ctxp[2];
	struct mutex___96 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___91 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___100 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___100 *, struct mm_struct___100 *);
	void (*dup_mmap)(struct mm_struct___100 *, struct mm_struct___100 *);
	void (*exit_mmap)(struct mm_struct___100 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___100 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___100 *);
	void (*pgd_free)(struct mm_struct___100 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___100 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___100 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___100 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___100 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___100 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___100 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___100 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___100 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___100 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___100 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___100 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___96 lock;
	void *vdso;
} mm_context_t___96;

struct xol_area___95;

struct uprobes_state___95 {
	struct xol_area___95 *xol_area;
};

struct vm_area_struct___100;

struct file___95;

struct linux_binfmt___13;

struct core_state___95;

struct mm_struct___100 {
	struct vm_area_struct___100 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___100 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___100 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___13 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___96 context;
	long unsigned int flags;
	struct core_state___95 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___95 *owner;
	struct file___95 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___95 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___51;

struct exec_domain___25 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___51 *module;
	struct exec_domain___25 *next;
};

struct module_kobject___50 {
	struct kobject kobj;
	struct module___51 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___50;

struct ftrace_event_call___37;

struct module___51 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___50 mkobj;
	struct module_attribute___50 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___37 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___95 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___47 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___95 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___95 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___95 *target;
};

typedef void (*perf_overflow_handler_t___47)(struct perf_event___47 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___47;

typedef void (*ftrace_func_t___47)(long unsigned int, long unsigned int, struct ftrace_ops___47 *, struct pt_regs *);

struct ftrace_ops___47 {
	ftrace_func_t___47 func;
	struct ftrace_ops___47 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___96 regex_lock;
};

struct pmu___47;

struct fasync_struct___95;

struct pid_namespace___52;

struct perf_cgroup___47;

struct perf_event___47 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___47 *group_leader;
	struct pmu___47 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___47 hw;
	struct perf_event_context___47 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___96 child_mutex;
	struct list_head child_list;
	struct perf_event___47 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___95 *owner;
	struct mutex___96 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___95 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___47 *);
	struct callback_head callback_head;
	struct pid_namespace___52 *ns;
	u64 id;
	perf_overflow_handler_t___47 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___37 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___47 ftrace_ops;
	struct perf_cgroup___47 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___47 {
	struct task_struct___95 *task;
	struct exec_domain___25 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___95;

struct lruvec___95 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___95 *zone;
};

struct pglist_data___95;

struct zone___95 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___95 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___95 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___95 {
	struct zone___95 *zone;
	int zone_idx;
};

struct zonelist___95 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___95 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___95 {
	struct zone___95 node_zones[4];
	struct zonelist___95 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___95 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___69;

struct x86_io_apic_ops___69 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___69 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___69;

struct irq_data___69 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___69 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___74;

struct dev_pm_ops___74 {
	int (*prepare)(struct device___74 *);
	void (*complete)(struct device___74 *);
	int (*suspend)(struct device___74 *);
	int (*resume)(struct device___74 *);
	int (*freeze)(struct device___74 *);
	int (*thaw)(struct device___74 *);
	int (*poweroff)(struct device___74 *);
	int (*restore)(struct device___74 *);
	int (*suspend_late)(struct device___74 *);
	int (*resume_early)(struct device___74 *);
	int (*freeze_late)(struct device___74 *);
	int (*thaw_early)(struct device___74 *);
	int (*poweroff_late)(struct device___74 *);
	int (*restore_early)(struct device___74 *);
	int (*suspend_noirq)(struct device___74 *);
	int (*resume_noirq)(struct device___74 *);
	int (*freeze_noirq)(struct device___74 *);
	int (*thaw_noirq)(struct device___74 *);
	int (*poweroff_noirq)(struct device___74 *);
	int (*restore_noirq)(struct device___74 *);
	int (*runtime_suspend)(struct device___74 *);
	int (*runtime_resume)(struct device___74 *);
	int (*runtime_idle)(struct device___74 *);
};

struct device_type___74;

struct bus_type___74;

struct device_driver___74;

struct dev_pm_domain___74;

struct class___74;

struct attribute_group___67;

struct device_rh___74;

struct device___74 {
	struct device___74 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___74 *type;
	struct mutex___96 mutex;
	struct bus_type___74 *bus;
	struct device_driver___74 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___74 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___74 *class;
	const struct attribute_group___67 **groups;
	void (*release)(struct device___74 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___74 *device_rh;
};

struct dev_pm_info_rh___74 {
	void (*set_latency_tolerance)(struct device___74 *, s32);
};

struct dev_pm_domain___74 {
	struct dev_pm_ops___74 ops;
};

struct smp_ops___95 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___95 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___53 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___52 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___67;

struct attribute_group___67 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___67 **bin_attrs;
};

struct bin_attribute___67 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___95 *, struct kobject *, struct bin_attribute___67 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___95 *, struct kobject *, struct bin_attribute___67 *, char *, loff_t, size_t);
	int (*mmap)(struct file___95 *, struct kobject *, struct bin_attribute___67 *, struct vm_area_struct___100 *);
};

struct dentry___96;

struct path___95 {
	struct vfsmount *mnt;
	struct dentry___96 *dentry;
};

struct fown_struct___52 {
	rwlock_t lock;
	struct pid___52 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___96;

struct file_operations___95;

struct file___95 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___95 f_path;
	struct inode___96 *f_inode;
	const struct file_operations___95 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___52 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___95 *f_mapping;
	struct mutex___96 f_pos_lock;
};

struct vm_operations_struct___83;

struct vm_area_struct___100 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___100 *vm_next;
	struct vm_area_struct___100 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___100 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___83 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___95 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___50 *, struct module_kobject___50 *, char *);
	ssize_t (*store)(struct module_attribute___50 *, struct module_kobject___50 *, const char *, size_t);
	void (*setup)(struct module___51 *, const char *);
	int (*test)(struct module___51 *);
	void (*free)(struct module___51 *);
};

struct trace_event_functions___37;

struct trace_event___37 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___37 *funcs;
};

struct ftrace_event_class___37;

struct ftrace_event_call___37 {
	struct list_head list;
	struct ftrace_event_class___37 *class;
	char *name;
	struct trace_event___37 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct dentry_operations___95;

struct super_block___96;

struct dentry___96 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___96 *d_parent;
	struct qstr d_name;
	struct inode___96 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___95 *d_op;
	struct super_block___96 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___95;

struct address_space___95 {
	struct inode___96 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___96 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___95 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___95;

struct file_lock___95;

struct dquot___95;

struct block_device___95;

struct inode___96 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___95 *i_op;
	struct super_block___96 *i_sb;
	struct address_space___95 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___96 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___95 *i_fop;
	struct file_lock___95 *i_flock;
	struct address_space___95 i_data;
	struct dquot___95 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___95 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___95 {
	int (*d_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_hash)(const struct dentry___96 *, struct qstr *);
	int (*d_compare)(const struct dentry___96 *, const struct dentry___96 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___96 *);
	void (*d_release)(struct dentry___96 *);
	void (*d_prune)(struct dentry___96 *);
	void (*d_iput)(struct dentry___96 *, struct inode___96 *);
	char * (*d_dname)(struct dentry___96 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___95 *);
	int (*d_manage)(struct dentry___96 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___95;

struct mem_dqinfo___95 {
	struct quota_format_type___95 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___95;

struct quota_info___95 {
	unsigned int flags;
	struct mutex___96 dqio_mutex;
	struct mutex___96 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___96 *files[2];
	struct mem_dqinfo___95 info[2];
	const struct quota_format_ops___95 *ops[2];
};

struct file_system_type___95;

struct super_operations___95;

struct dquot_operations___95;

struct quotactl_ops___95;

struct xattr_handler___62;

struct super_block___96 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___95 *s_type;
	const struct super_operations___95 *s_op;
	const struct dquot_operations___95 *dq_op;
	const struct quotactl_ops___95 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___96 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___62 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___95 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___95 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___96 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___95 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___52 {
	int nr;
	struct pid_namespace___52 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___52 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___95 *child_reaper;
	struct kmem_cache___83 *pid_cachep;
	unsigned int level;
	struct pid_namespace___52 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___96 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___52 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___52 numbers[1];
};

struct block_device___95 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___96 *bd_inode;
	struct super_block___96 *bd_super;
	struct mutex___96 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___95 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___96 bd_fsfreeze_mutex;
};

struct cgroup___62;

struct cgroup_subsys_state___62 {
	struct cgroup___62 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___96 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___95 *ia_file;
};

struct dquot___95 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___96 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___96 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___95 {
	int qf_fmt_id;
	const struct quota_format_ops___95 *qf_ops;
	struct module___51 *qf_owner;
	struct quota_format_type___95 *qf_next;
};

struct quota_format_ops___95 {
	int (*check_quota_file)(struct super_block___96 *, int);
	int (*read_file_info)(struct super_block___96 *, int);
	int (*write_file_info)(struct super_block___96 *, int);
	int (*free_file_info)(struct super_block___96 *, int);
	int (*read_dqblk)(struct dquot___95 *);
	int (*commit_dqblk)(struct dquot___95 *);
	int (*release_dqblk)(struct dquot___95 *);
};

struct dquot_operations___95 {
	int (*write_dquot)(struct dquot___95 *);
	struct dquot___95 * (*alloc_dquot)(struct super_block___96 *, int);
	void (*destroy_dquot)(struct dquot___95 *);
	int (*acquire_dquot)(struct dquot___95 *);
	int (*release_dquot)(struct dquot___95 *);
	int (*mark_dirty)(struct dquot___95 *);
	int (*write_info)(struct super_block___96 *, int);
	qsize_t * (*get_reserved_space)(struct inode___96 *);
};

struct quotactl_ops___95 {
	int (*quota_on)(struct super_block___96 *, int, int, struct path___95 *);
	int (*quota_on_meta)(struct super_block___96 *, int, int);
	int (*quota_off)(struct super_block___96 *, int);
	int (*quota_sync)(struct super_block___96 *, int);
	int (*get_info)(struct super_block___96 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___96 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___96 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___96 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___96 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___96 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___96 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___96 *, unsigned int);
};

struct address_space_operations___95 {
	int (*writepage)(struct page___95 *, struct writeback_control *);
	int (*readpage)(struct file___95 *, struct page___95 *);
	int (*writepages)(struct address_space___95 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___95 *);
	int (*readpages)(struct file___95 *, struct address_space___95 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___95 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___95 **, void **);
	int (*write_end)(struct file___95 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___95 *, void *);
	sector_t (*bmap)(struct address_space___95 *, sector_t);
	void (*invalidatepage)(struct page___95 *, long unsigned int);
	int (*releasepage)(struct page___95 *, gfp_t);
	void (*freepage)(struct page___95 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___95 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___95 *, struct page___95 *, struct page___95 *, enum migrate_mode);
	int (*launder_page)(struct page___95 *);
	int (*is_partially_uptodate)(struct page___95 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___95 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___95 *, struct page___95 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___95 *, sector_t *);
	void (*swap_deactivate)(struct file___95 *);
	void (*invalidatepage_range)(struct page___95 *, unsigned int, unsigned int);
};

struct inode_operations___95 {
	struct dentry___96 * (*lookup)(struct inode___96 *, struct dentry___96 *, unsigned int);
	void * (*follow_link)(struct dentry___96 *, struct nameidata *);
	int (*permission)(struct inode___96 *, int);
	struct posix_acl * (*get_acl)(struct inode___96 *, int);
	int (*readlink)(struct dentry___96 *, char *, int);
	void (*put_link)(struct dentry___96 *, struct nameidata *, void *);
	int (*create)(struct inode___96 *, struct dentry___96 *, umode_t, bool);
	int (*link)(struct dentry___96 *, struct inode___96 *, struct dentry___96 *);
	int (*unlink)(struct inode___96 *, struct dentry___96 *);
	int (*symlink)(struct inode___96 *, struct dentry___96 *, const char *);
	int (*mkdir)(struct inode___96 *, struct dentry___96 *, umode_t);
	int (*rmdir)(struct inode___96 *, struct dentry___96 *);
	int (*mknod)(struct inode___96 *, struct dentry___96 *, umode_t, dev_t);
	int (*rename)(struct inode___96 *, struct dentry___96 *, struct inode___96 *, struct dentry___96 *);
	int (*setattr)(struct dentry___96 *, struct iattr___96 *);
	int (*getattr)(struct vfsmount *, struct dentry___96 *, struct kstat *);
	int (*setxattr)(struct dentry___96 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___96 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___96 *, char *, size_t);
	int (*removexattr)(struct dentry___96 *, const char *);
	int (*fiemap)(struct inode___96 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___96 *, struct timespec *, int);
	int (*atomic_open)(struct inode___96 *, struct dentry___96 *, struct file___95 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___59;

struct seq_file___71;

struct file_operations___95 {
	struct module___51 *owner;
	loff_t (*llseek)(struct file___95 *, loff_t, int);
	ssize_t (*read)(struct file___95 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___95 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___95 *, void *, filldir_t);
	unsigned int (*poll)(struct file___95 *, struct poll_table_struct___59 *);
	long int (*unlocked_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___95 *, struct vm_area_struct___100 *);
	int (*open)(struct inode___96 *, struct file___95 *);
	int (*flush)(struct file___95 *, fl_owner_t);
	int (*release)(struct inode___96 *, struct file___95 *);
	int (*fsync)(struct file___95 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___95 *, int);
	int (*lock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*sendpage)(struct file___95 *, struct page___95 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___95 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___95 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___95 *, long int, struct file_lock___95 **, void **);
		struct {
			int (*setlease)(struct file___95 *, long int, struct file_lock___95 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___95 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___71 *, struct file___95 *);
};

struct file_lock_operations___95;

struct lock_manager_operations___95;

struct file_lock___95 {
	struct file_lock___95 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___52 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___95 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___95 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___95 *fl_ops;
	const struct lock_manager_operations___95 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___95 {
	void (*fl_copy_lock)(struct file_lock___95 *, struct file_lock___95 *);
	void (*fl_release_private)(struct file_lock___95 *);
};

struct lock_manager_operations___95 {
	int (*lm_compare_owner)(struct file_lock___95 *, struct file_lock___95 *);
	long unsigned int (*lm_owner_key)(struct file_lock___95 *);
	void (*lm_notify)(struct file_lock___95 *);
	int (*lm_grant)(struct file_lock___95 *, struct file_lock___95 *, int);
	void (*lm_break)(struct file_lock___95 *);
	int (*lm_change)(struct file_lock___95 **, int);
};

struct fasync_struct___95 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___95 *fa_next;
	struct file___95 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___95 {
	const char *name;
	int fs_flags;
	struct dentry___96 * (*mount)(struct file_system_type___95 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___96 *);
	struct module___51 *owner;
	struct file_system_type___95 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___95 {
	struct inode___96 * (*alloc_inode)(struct super_block___96 *);
	void (*destroy_inode)(struct inode___96 *);
	void (*dirty_inode)(struct inode___96 *, int);
	int (*write_inode)(struct inode___96 *, struct writeback_control *);
	int (*drop_inode)(struct inode___96 *);
	void (*evict_inode)(struct inode___96 *);
	void (*put_super)(struct super_block___96 *);
	int (*sync_fs)(struct super_block___96 *, int);
	int (*freeze_fs)(struct super_block___96 *);
	int (*unfreeze_fs)(struct super_block___96 *);
	int (*statfs)(struct dentry___96 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___96 *, int *, char *);
	void (*umount_begin)(struct super_block___96 *);
	int (*show_options)(struct seq_file___71 *, struct dentry___96 *);
	int (*show_devname)(struct seq_file___71 *, struct dentry___96 *);
	int (*show_path)(struct seq_file___71 *, struct dentry___96 *);
	int (*show_stats)(struct seq_file___71 *, struct dentry___96 *);
	ssize_t (*quota_read)(struct super_block___96 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___96 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___96 *);
	int (*bdev_try_to_free_page)(struct super_block___96 *, struct page___95 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___96 *);
	void (*free_cached_objects)(struct super_block___96 *, int);
};

struct xattr_handler___62 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___96 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___96 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___96 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___60)(struct file___95 *, wait_queue_head_t *, struct poll_table_struct___59 *);

struct poll_table_struct___59 {
	poll_queue_proc___60 _qproc;
	long unsigned int _key;
};

struct seq_operations___70;

struct seq_file___71 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___96 lock;
	const struct seq_operations___70 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___70 {
	void * (*start)(struct seq_file___71 *, loff_t *);
	void (*stop)(struct seq_file___71 *, void *);
	void * (*next)(struct seq_file___71 *, void *, loff_t *);
	int (*show)(struct seq_file___71 *, void *);
};

struct xol_area___95 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___95 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___83;

struct memcg_cache_params___83;

struct kmem_cache___83 {
	struct kmem_cache_cpu___83 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___83 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___80;

struct vm_operations_struct___83 {
	void (*open)(struct vm_area_struct___100 *);
	void (*close)(struct vm_area_struct___100 *);
	int (*fault)(struct vm_area_struct___100 *, struct vm_fault___80 *);
	int (*page_mkwrite)(struct vm_area_struct___100 *, struct vm_fault___80 *);
	int (*access)(struct vm_area_struct___100 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___100 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___100 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___100 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___100 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___95 {
	struct task_struct___95 *task;
	struct core_thread___95 *next;
};

struct core_state___95 {
	atomic_t nr_threads;
	struct core_thread___95 dumper;
	struct completion startup;
};

struct linux_binprm___14;

struct coredump_params___13;

struct linux_binfmt___13 {
	struct list_head lh;
	struct module___51 *module;
	int (*load_binary)(struct linux_binprm___14 *);
	int (*load_shlib)(struct file___95 *);
	int (*core_dump)(struct coredump_params___13 *);
	long unsigned int min_coredump;
};

struct signal_struct___95 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___95 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___95 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___52 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___52 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___96 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___62 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___62 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___47 {
	struct pmu___47 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___96 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___95 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___47 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct linux_binprm___14 {
	char buf[128];
	struct vm_area_struct___100 *vma;
	long unsigned int vma_pages;
	struct mm_struct___100 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___95 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___13 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___95 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct vm_fault___80 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___95 *page;
};

struct bus_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___74 *, char *);
	ssize_t (*store)(struct bus_type___74 *, const char *, size_t);
};

struct device_attribute___74;

struct driver_attribute___74;

struct bus_type___74 {
	const char *name;
	const char *dev_name;
	struct device___74 *dev_root;
	struct bus_attribute___74 *bus_attrs;
	struct device_attribute___74 *dev_attrs;
	struct driver_attribute___74 *drv_attrs;
	const struct attribute_group___67 **bus_groups;
	const struct attribute_group___67 **dev_groups;
	const struct attribute_group___67 **drv_groups;
	int (*match)(struct device___74 *, struct device_driver___74 *);
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	int (*probe)(struct device___74 *);
	int (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*online)(struct device___74 *);
	int (*offline)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct device___74 *, struct device_attribute___74 *, char *);
	ssize_t (*store)(struct device___74 *, struct device_attribute___74 *, const char *, size_t);
};

struct driver_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___74 *, char *);
	ssize_t (*store)(struct device_driver___74 *, const char *, size_t);
};

struct device_driver___74 {
	const char *name;
	struct bus_type___74 *bus;
	struct module___51 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___74 *);
	int (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	const struct attribute_group___67 **groups;
	const struct dev_pm_ops___74 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___74 {
	const char *name;
	const struct attribute_group___67 **groups;
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
};

struct class_attribute___74;

struct class___74 {
	const char *name;
	struct module___51 *owner;
	struct class_attribute___74 *class_attrs;
	struct device_attribute___74 *dev_attrs;
	const struct attribute_group___67 **dev_groups;
	struct bin_attribute___67 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *);
	void (*class_release)(struct class___74 *);
	void (*dev_release)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
	struct subsys_private *p;
};

struct class_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct class___74 *, struct class_attribute___74 *, char *);
	ssize_t (*store)(struct class___74 *, struct class_attribute___74 *, const char *, size_t);
	const void * (*namespace)(struct class___74 *, const struct class_attribute___74 *);
};

struct device_rh___74 {
	struct dev_pm_info_rh___74 power;
};

struct kmem_cache_cpu___83 {
	void **freelist;
	long unsigned int tid;
	struct page___95 *page;
	struct page___95 *partial;
};

struct memcg_cache_params___83 {
	bool is_root_cache;
	union {
		struct kmem_cache___83 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___83 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___62;

struct cgroup___62 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___62 *parent;
	struct dentry___96 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___62 *subsys[11];
	struct cgroupfs_root___62 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___96 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___62 {
	struct super_block___96 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___62 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___47;

struct pmu___47 {
	struct list_head entry;
	struct device___74 *dev;
	const struct attribute_group___67 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___47 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___47 *);
	void (*pmu_disable)(struct pmu___47 *);
	int (*event_init)(struct perf_event___47 *);
	int (*add)(struct perf_event___47 *, int);
	void (*del)(struct perf_event___47 *, int);
	void (*start)(struct perf_event___47 *, int);
	void (*stop)(struct perf_event___47 *, int);
	void (*read)(struct perf_event___47 *);
	void (*start_txn)(struct pmu___47 *);
	int (*commit_txn)(struct pmu___47 *);
	void (*cancel_txn)(struct pmu___47 *);
	int (*event_idx)(struct perf_event___47 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___51 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___47 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___47 *);
};

struct perf_cpu_context___47 {
	struct perf_event_context___47 ctx;
	struct perf_event_context___47 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___47 *unique_pmu;
	struct perf_cgroup___47 *cgrp;
};

struct perf_cgroup___47 {
	struct cgroup_subsys_state___62 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___69 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___69 *);
	void (*irq_shutdown)(struct irq_data___69 *);
	void (*irq_enable)(struct irq_data___69 *);
	void (*irq_disable)(struct irq_data___69 *);
	void (*irq_ack)(struct irq_data___69 *);
	void (*irq_mask)(struct irq_data___69 *);
	void (*irq_mask_ack)(struct irq_data___69 *);
	void (*irq_unmask)(struct irq_data___69 *);
	void (*irq_eoi)(struct irq_data___69 *);
	int (*irq_set_affinity)(struct irq_data___69 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___69 *);
	int (*irq_set_type)(struct irq_data___69 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___69 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___69 *);
	void (*irq_bus_sync_unlock)(struct irq_data___69 *);
	void (*irq_cpu_online)(struct irq_data___69 *);
	void (*irq_cpu_offline)(struct irq_data___69 *);
	void (*irq_suspend)(struct irq_data___69 *);
	void (*irq_resume)(struct irq_data___69 *);
	void (*irq_pm_shutdown)(struct irq_data___69 *);
	void (*irq_print_chip)(struct irq_data___69 *, struct seq_file___71 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___69 *, void *);
	long unsigned int flags;
};

struct trace_array___6;

struct tracer___6;

struct trace_buffer___6;

struct trace_iterator___37 {
	struct trace_array___6 *tr;
	struct tracer___6 *trace;
	struct trace_buffer___6 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___96 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___6;

struct trace_buffer___6 {
	struct trace_array___6 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___6 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___6 {
	struct trace_array___6 *tr;
	struct dentry___96 *dir;
	int cpu;
};

struct trace_array___6 {
	struct list_head list;
	char *name;
	struct trace_buffer___6 trace_buffer;
	struct trace_buffer___6 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___6 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___6 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___96 *dir;
	struct dentry___96 *options;
	struct dentry___96 *percpu_dir;
	struct dentry___96 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___95 *waiter;
	int ref;
};

struct tracer___6 {
	const char *name;
	int (*init)(struct trace_array___6 *);
	void (*reset)(struct trace_array___6 *);
	void (*start)(struct trace_array___6 *);
	void (*stop)(struct trace_array___6 *);
	void (*open)(struct trace_iterator___37 *);
	void (*pipe_open)(struct trace_iterator___37 *);
	int (*wait_pipe)(struct trace_iterator___37 *);
	void (*close)(struct trace_iterator___37 *);
	void (*pipe_close)(struct trace_iterator___37 *);
	ssize_t (*read)(struct trace_iterator___37 *, struct file___95 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___37 *, struct file___95 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___71 *);
	enum print_line_t (*print_line)(struct trace_iterator___37 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___6 *, u32, int);
	struct tracer___6 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___37)(struct trace_iterator___37 *, int, struct trace_event___37 *);

struct trace_event_functions___37 {
	trace_print_func___37 trace;
	trace_print_func___37 raw;
	trace_print_func___37 hex;
	trace_print_func___37 binary;
};

struct ftrace_event_class___37 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___37 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___37 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___37 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___37 *);
};

struct trace_array_cpu___6 {
	struct trace_cpu___6 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

enum {
	TRACE_FUNC_OPT_STACK = 1,
};

enum {
	TRACE_NOP_OPT_ACCEPT = 1,
	TRACE_NOP_OPT_REFUSE = 2,
};

struct ftrace_graph_ent_entry {
	struct trace_entry ent;
	struct ftrace_graph_ent graph_ent;
};

struct ftrace_graph_ret_entry {
	struct trace_entry ent;
	struct ftrace_graph_ret ret;
};

struct fgraph_cpu_data {
	pid_t last_pid;
	int depth;
	int depth_irq;
	int ignore;
	long unsigned int enter_funcs[50];
};

struct fgraph_data {
	struct fgraph_cpu_data *cpu_data;
	struct ftrace_graph_ent_entry ent;
	struct ftrace_graph_ret_entry ret;
	int failed;
	int cpu;
};

enum {
	DURATION_FILL_FULL = 4294967295,
	DURATION_FILL_START = 4294967294,
	DURATION_FILL_END = 4294967293,
};

typedef __u64 __be64;

struct page___96;

typedef struct page___96 *pgtable_t___96;

struct address_space___96;

struct kmem_cache___84;

struct page___96 {
	long unsigned int flags;
	struct address_space___96 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___96 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___96 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___84 *slab_cache;
		struct page___96 *first_page;
	};
	long: 64;
};

struct thread_struct___48;

struct task_struct___96;

struct pv_cpu_ops___96 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___48 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___48 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___96 *);
	void (*end_context_switch)(struct task_struct___96 *);
};

struct perf_event___48;

struct thread_struct___48 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___48 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___53;

struct pid_link___53 {
	struct hlist_node node;
	struct pid___53 *pid;
};

struct mutex___97 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___96 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___92 {
	struct page___96 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___101;

struct nsproxy___54;

struct signal_struct___96;

struct bio_list___9;

struct backing_dev_info___12;

struct io_context___9;

struct css_set___63;

struct perf_event_context___48;

struct task_struct___96 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___96 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___101 *mm;
	struct mm_struct___101 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___96 *real_parent;
	struct task_struct___96 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___96 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___53 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___96 = 0,
		VTIME_USER___96 = 1,
		VTIME_SYS___96 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___48 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___54 *nsproxy;
	struct signal_struct___96 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___9 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___12 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___63 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___48 *perf_event_ctxp[2];
	struct mutex___97 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___92 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___101 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___101 *, struct mm_struct___101 *);
	void (*dup_mmap)(struct mm_struct___101 *, struct mm_struct___101 *);
	void (*exit_mmap)(struct mm_struct___101 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___101 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___101 *);
	void (*pgd_free)(struct mm_struct___101 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___101 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___101 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___101 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___101 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___101 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___101 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___101 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___101 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___101 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___101 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___101 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___97 lock;
	void *vdso;
} mm_context_t___97;

struct xol_area___96;

struct uprobes_state___96 {
	struct xol_area___96 *xol_area;
};

struct vm_area_struct___101;

struct file___96;

struct core_state___96;

struct mm_struct___101 {
	struct vm_area_struct___101 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___101 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___101 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___97 context;
	long unsigned int flags;
	struct core_state___96 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___96 *owner;
	struct file___96 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___96 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___48 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___96 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___96 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___96 *target;
};

typedef void (*perf_overflow_handler_t___48)(struct perf_event___48 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___48;

typedef void (*ftrace_func_t___48)(long unsigned int, long unsigned int, struct ftrace_ops___48 *, struct pt_regs *);

struct ftrace_ops___48 {
	ftrace_func_t___48 func;
	struct ftrace_ops___48 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___97 regex_lock;
};

struct pmu___48;

struct fasync_struct___96;

struct pid_namespace___53;

struct ftrace_event_call___38;

struct perf_cgroup___48;

struct perf_event___48 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___48 *group_leader;
	struct pmu___48 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___48 hw;
	struct perf_event_context___48 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___97 child_mutex;
	struct list_head child_list;
	struct perf_event___48 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___96 *owner;
	struct mutex___97 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___96 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___48 *);
	struct callback_head callback_head;
	struct pid_namespace___53 *ns;
	u64 id;
	perf_overflow_handler_t___48 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___38 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___48 ftrace_ops;
	struct perf_cgroup___48 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___48 {
	struct task_struct___96 *task;
	struct exec_domain___25 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___96 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___96 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___84;

struct memcg_cache_params___84;

struct kmem_cache___84 {
	struct kmem_cache_cpu___84 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___84 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___97;

struct address_space_operations___96;

struct address_space___96 {
	struct inode___97 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___97 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___96 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___12 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___97;

struct path___96 {
	struct vfsmount *mnt;
	struct dentry___97 *dentry;
};

struct fown_struct___53 {
	rwlock_t lock;
	struct pid___53 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___96;

struct file___96 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___96 f_path;
	struct inode___97 *f_inode;
	const struct file_operations___96 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___96 *f_mapping;
	struct mutex___97 f_pos_lock;
};

struct vm_operations_struct___84;

struct vm_area_struct___101 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___101 *vm_next;
	struct vm_area_struct___101 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___101 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___84 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___96 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___81;

struct vm_operations_struct___84 {
	void (*open)(struct vm_area_struct___101 *);
	void (*close)(struct vm_area_struct___101 *);
	int (*fault)(struct vm_area_struct___101 *, struct vm_fault___81 *);
	int (*page_mkwrite)(struct vm_area_struct___101 *, struct vm_fault___81 *);
	int (*access)(struct vm_area_struct___101 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___101 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___101 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___101 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___101 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___96 {
	struct task_struct___96 *task;
	struct core_thread___96 *next;
};

struct core_state___96 {
	atomic_t nr_threads;
	struct core_thread___96 dumper;
	struct completion startup;
};

struct irq_data___70;

struct x86_io_apic_ops___70 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___70 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___70;

struct irq_data___70 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___70 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___75;

struct dev_pm_ops___75 {
	int (*prepare)(struct device___75 *);
	void (*complete)(struct device___75 *);
	int (*suspend)(struct device___75 *);
	int (*resume)(struct device___75 *);
	int (*freeze)(struct device___75 *);
	int (*thaw)(struct device___75 *);
	int (*poweroff)(struct device___75 *);
	int (*restore)(struct device___75 *);
	int (*suspend_late)(struct device___75 *);
	int (*resume_early)(struct device___75 *);
	int (*freeze_late)(struct device___75 *);
	int (*thaw_early)(struct device___75 *);
	int (*poweroff_late)(struct device___75 *);
	int (*restore_early)(struct device___75 *);
	int (*suspend_noirq)(struct device___75 *);
	int (*resume_noirq)(struct device___75 *);
	int (*freeze_noirq)(struct device___75 *);
	int (*thaw_noirq)(struct device___75 *);
	int (*poweroff_noirq)(struct device___75 *);
	int (*restore_noirq)(struct device___75 *);
	int (*runtime_suspend)(struct device___75 *);
	int (*runtime_resume)(struct device___75 *);
	int (*runtime_idle)(struct device___75 *);
};

struct device_type___75;

struct bus_type___75;

struct device_driver___75;

struct dev_pm_domain___75;

struct class___75;

struct attribute_group___68;

struct device_rh___75;

struct device___75 {
	struct device___75 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___75 *type;
	struct mutex___97 mutex;
	struct bus_type___75 *bus;
	struct device_driver___75 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___75 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___75 *class;
	const struct attribute_group___68 **groups;
	void (*release)(struct device___75 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___75 *device_rh;
};

struct dev_pm_info_rh___75 {
	void (*set_latency_tolerance)(struct device___75 *, s32);
};

struct dev_pm_domain___75 {
	struct dev_pm_ops___75 ops;
};

struct smp_ops___96 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___96 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___53 {
	int nr;
	struct pid_namespace___53 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___53 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___96 *child_reaper;
	struct kmem_cache___84 *pid_cachep;
	unsigned int level;
	struct pid_namespace___53 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___97 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___53 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___53 numbers[1];
};

struct zone___96;

struct lruvec___96 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___96 *zone;
};

struct pglist_data___96;

struct zone___96 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___96 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___96 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___96 {
	struct zone___96 *zone;
	int zone_idx;
};

struct zonelist___96 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___96 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___96 {
	struct zone___96 node_zones[4];
	struct zonelist___96 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___96 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___54 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___53 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___96 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___96 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___96 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___53 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___53 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___97 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___9;

struct bio_list___9 {
	struct bio___9 *head;
	struct bio___9 *tail;
};

struct bdi_writeback___12 {
	struct backing_dev_info___12 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___12 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___12 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___75 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___97 *debug_dir;
	struct dentry___97 *debug_stats;
};

struct io_cq___9;

struct io_context___9 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___9 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___63;

struct css_set___63 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___63 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___48 {
	struct pmu___48 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___97 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___96 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___48 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___68;

struct attribute_group___68 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___68 **bin_attrs;
};

struct bin_attribute___68 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___96 *, struct kobject *, struct bin_attribute___68 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___96 *, struct kobject *, struct bin_attribute___68 *, char *, loff_t, size_t);
	int (*mmap)(struct file___96 *, struct kobject *, struct bin_attribute___68 *, struct vm_area_struct___101 *);
};

struct kmem_cache_cpu___84 {
	void **freelist;
	long unsigned int tid;
	struct page___96 *page;
	struct page___96 *partial;
};

struct memcg_cache_params___84 {
	bool is_root_cache;
	union {
		struct kmem_cache___84 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___84 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___75 *, char *);
	ssize_t (*store)(struct bus_type___75 *, const char *, size_t);
};

struct device_attribute___75;

struct driver_attribute___75;

struct bus_type___75 {
	const char *name;
	const char *dev_name;
	struct device___75 *dev_root;
	struct bus_attribute___75 *bus_attrs;
	struct device_attribute___75 *dev_attrs;
	struct driver_attribute___75 *drv_attrs;
	const struct attribute_group___68 **bus_groups;
	const struct attribute_group___68 **dev_groups;
	const struct attribute_group___68 **drv_groups;
	int (*match)(struct device___75 *, struct device_driver___75 *);
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	int (*probe)(struct device___75 *);
	int (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*online)(struct device___75 *);
	int (*offline)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct device___75 *, struct device_attribute___75 *, char *);
	ssize_t (*store)(struct device___75 *, struct device_attribute___75 *, const char *, size_t);
};

struct driver_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___75 *, char *);
	ssize_t (*store)(struct device_driver___75 *, const char *, size_t);
};

struct device_driver___75 {
	const char *name;
	struct bus_type___75 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___75 *);
	int (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	const struct attribute_group___68 **groups;
	const struct dev_pm_ops___75 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___75 {
	const char *name;
	const struct attribute_group___68 **groups;
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
};

struct class_attribute___75;

struct class___75 {
	const char *name;
	struct module *owner;
	struct class_attribute___75 *class_attrs;
	struct device_attribute___75 *dev_attrs;
	const struct attribute_group___68 **dev_groups;
	struct bin_attribute___68 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *);
	void (*class_release)(struct class___75 *);
	void (*dev_release)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
	struct subsys_private *p;
};

struct class_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct class___75 *, struct class_attribute___75 *, char *);
	ssize_t (*store)(struct class___75 *, struct class_attribute___75 *, const char *, size_t);
	const void * (*namespace)(struct class___75 *, const struct class_attribute___75 *);
};

struct device_rh___75 {
	struct dev_pm_info_rh___75 power;
};

struct dentry_operations___96;

struct super_block___97;

struct dentry___97 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___97 *d_parent;
	struct qstr d_name;
	struct inode___97 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___96 *d_op;
	struct super_block___97 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___96;

struct file_lock___96;

struct dquot___96;

struct block_device___96;

struct inode___97 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___96 *i_op;
	struct super_block___97 *i_sb;
	struct address_space___96 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___97 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___96 *i_fop;
	struct file_lock___96 *i_flock;
	struct address_space___96 i_data;
	struct dquot___96 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___96 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___96 {
	int (*d_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_hash)(const struct dentry___97 *, struct qstr *);
	int (*d_compare)(const struct dentry___97 *, const struct dentry___97 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___97 *);
	void (*d_release)(struct dentry___97 *);
	void (*d_prune)(struct dentry___97 *);
	void (*d_iput)(struct dentry___97 *, struct inode___97 *);
	char * (*d_dname)(struct dentry___97 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___96 *);
	int (*d_manage)(struct dentry___97 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___96;

struct mem_dqinfo___96 {
	struct quota_format_type___96 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___96;

struct quota_info___96 {
	unsigned int flags;
	struct mutex___97 dqio_mutex;
	struct mutex___97 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___97 *files[2];
	struct mem_dqinfo___96 info[2];
	const struct quota_format_ops___96 *ops[2];
};

struct file_system_type___96;

struct super_operations___96;

struct dquot_operations___96;

struct quotactl_ops___96;

struct xattr_handler___63;

struct super_block___97 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___96 *s_type;
	const struct super_operations___96 *s_op;
	const struct dquot_operations___96 *dq_op;
	const struct quotactl_ops___96 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___97 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___63 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___96 *s_bdev;
	struct backing_dev_info___12 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___96 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___97 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___96 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___9(struct bio___9 *, int);

struct bio_vec___9 {
	struct page___96 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___9;

struct bio_set___9;

struct bio___9 {
	sector_t bi_sector;
	struct bio___9 *bi_next;
	struct block_device___96 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___9 *bi_end_io;
	void *bi_private;
	struct io_context___9 *bi_ioc;
	struct cgroup_subsys_state___63 *bi_css;
	struct bio_integrity_payload___9 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___9 *bi_io_vec;
	struct bio_set___9 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___9 bi_inline_vecs[0];
};

struct hd_struct___10;

struct gendisk___10;

struct request_queue___9;

struct block_device___96 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___97 *bd_inode;
	struct super_block___97 *bd_super;
	struct mutex___97 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___96 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___10 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___10 *bd_disk;
	struct request_queue___9 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___97 bd_fsfreeze_mutex;
};

struct cgroup___63;

struct cgroup_subsys_state___63 {
	struct cgroup___63 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___9 {
	struct bio___9 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___9 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___9 *bip_vec;
	struct bio_vec___9 bip_inline_vecs[0];
};

struct bio_set___9 {
	struct kmem_cache___84 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___9 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___97 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___96 *ia_file;
};

struct dquot___96 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___97 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___97 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___96 {
	int qf_fmt_id;
	const struct quota_format_ops___96 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___96 *qf_next;
};

struct quota_format_ops___96 {
	int (*check_quota_file)(struct super_block___97 *, int);
	int (*read_file_info)(struct super_block___97 *, int);
	int (*write_file_info)(struct super_block___97 *, int);
	int (*free_file_info)(struct super_block___97 *, int);
	int (*read_dqblk)(struct dquot___96 *);
	int (*commit_dqblk)(struct dquot___96 *);
	int (*release_dqblk)(struct dquot___96 *);
};

struct dquot_operations___96 {
	int (*write_dquot)(struct dquot___96 *);
	struct dquot___96 * (*alloc_dquot)(struct super_block___97 *, int);
	void (*destroy_dquot)(struct dquot___96 *);
	int (*acquire_dquot)(struct dquot___96 *);
	int (*release_dquot)(struct dquot___96 *);
	int (*mark_dirty)(struct dquot___96 *);
	int (*write_info)(struct super_block___97 *, int);
	qsize_t * (*get_reserved_space)(struct inode___97 *);
};

struct quotactl_ops___96 {
	int (*quota_on)(struct super_block___97 *, int, int, struct path___96 *);
	int (*quota_on_meta)(struct super_block___97 *, int, int);
	int (*quota_off)(struct super_block___97 *, int);
	int (*quota_sync)(struct super_block___97 *, int);
	int (*get_info)(struct super_block___97 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___97 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___97 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___97 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___97 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___97 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___97 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___97 *, unsigned int);
};

struct address_space_operations___96 {
	int (*writepage)(struct page___96 *, struct writeback_control *);
	int (*readpage)(struct file___96 *, struct page___96 *);
	int (*writepages)(struct address_space___96 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___96 *);
	int (*readpages)(struct file___96 *, struct address_space___96 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___96 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___96 **, void **);
	int (*write_end)(struct file___96 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___96 *, void *);
	sector_t (*bmap)(struct address_space___96 *, sector_t);
	void (*invalidatepage)(struct page___96 *, long unsigned int);
	int (*releasepage)(struct page___96 *, gfp_t);
	void (*freepage)(struct page___96 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___96 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___96 *, struct page___96 *, struct page___96 *, enum migrate_mode);
	int (*launder_page)(struct page___96 *);
	int (*is_partially_uptodate)(struct page___96 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___96 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___96 *, struct page___96 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___96 *, sector_t *);
	void (*swap_deactivate)(struct file___96 *);
	void (*invalidatepage_range)(struct page___96 *, unsigned int, unsigned int);
};

struct hd_struct___10 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___75 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___10;

struct block_device_operations___9;

struct gendisk___10 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___10 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___10 *part_tbl;
	struct hd_struct___10 part0;
	const struct block_device_operations___9 *fops;
	struct request_queue___9 *queue;
	void *private_data;
	int flags;
	struct device___75 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___9 {
	struct request_queue___9 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___9(struct request_queue___9 *);

typedef void make_request_fn___9(struct request_queue___9 *, struct bio___9 *);

struct request___9;

typedef int prep_rq_fn___9(struct request_queue___9 *, struct request___9 *);

struct bvec_merge_data___9;

typedef int merge_bvec_fn___9(struct request_queue___9 *, struct bvec_merge_data___9 *, struct bio_vec___9 *);

typedef void softirq_done_fn___9(struct request___9 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___9(struct request___9 *);

typedef int dma_drain_needed_fn___9(struct request___9 *);

typedef int lld_busy_fn___9(struct request_queue___9 *);

struct bsg_class_device___9 {
	struct device___75 *class_dev;
	struct device___75 *parent;
	int minor;
	struct request_queue___9 *queue;
	struct kref ref;
	void (*release)(struct device___75 *);
};

typedef void unprep_rq_fn___9(struct request_queue___9 *, struct request___9 *);

struct elevator_queue___9;

struct blk_queue_tag___9;

struct blk_trace___2;

struct request_queue___9 {
	struct list_head queue_head;
	struct request___9 *last_merge;
	struct elevator_queue___9 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___9 root_rl;
	request_fn_proc___9 *request_fn;
	make_request_fn___9 *make_request_fn;
	prep_rq_fn___9 *prep_rq_fn;
	merge_bvec_fn___9 *merge_bvec_fn;
	softirq_done_fn___9 *softirq_done_fn;
	rq_timed_out_fn___9 *rq_timed_out_fn;
	dma_drain_needed_fn___9 *dma_drain_needed;
	lld_busy_fn___9 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___9 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___12 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___75 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___9 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___2 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___9 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___97 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___9 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___9 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___9 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___96 {
	struct dentry___97 * (*lookup)(struct inode___97 *, struct dentry___97 *, unsigned int);
	void * (*follow_link)(struct dentry___97 *, struct nameidata *);
	int (*permission)(struct inode___97 *, int);
	struct posix_acl * (*get_acl)(struct inode___97 *, int);
	int (*readlink)(struct dentry___97 *, char *, int);
	void (*put_link)(struct dentry___97 *, struct nameidata *, void *);
	int (*create)(struct inode___97 *, struct dentry___97 *, umode_t, bool);
	int (*link)(struct dentry___97 *, struct inode___97 *, struct dentry___97 *);
	int (*unlink)(struct inode___97 *, struct dentry___97 *);
	int (*symlink)(struct inode___97 *, struct dentry___97 *, const char *);
	int (*mkdir)(struct inode___97 *, struct dentry___97 *, umode_t);
	int (*rmdir)(struct inode___97 *, struct dentry___97 *);
	int (*mknod)(struct inode___97 *, struct dentry___97 *, umode_t, dev_t);
	int (*rename)(struct inode___97 *, struct dentry___97 *, struct inode___97 *, struct dentry___97 *);
	int (*setattr)(struct dentry___97 *, struct iattr___97 *);
	int (*getattr)(struct vfsmount *, struct dentry___97 *, struct kstat *);
	int (*setxattr)(struct dentry___97 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___97 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___97 *, char *, size_t);
	int (*removexattr)(struct dentry___97 *, const char *);
	int (*fiemap)(struct inode___97 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___97 *, struct timespec *, int);
	int (*atomic_open)(struct inode___97 *, struct dentry___97 *, struct file___96 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___60;

struct seq_file___72;

struct file_operations___96 {
	struct module *owner;
	loff_t (*llseek)(struct file___96 *, loff_t, int);
	ssize_t (*read)(struct file___96 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___96 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___96 *, void *, filldir_t);
	unsigned int (*poll)(struct file___96 *, struct poll_table_struct___60 *);
	long int (*unlocked_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___96 *, struct vm_area_struct___101 *);
	int (*open)(struct inode___97 *, struct file___96 *);
	int (*flush)(struct file___96 *, fl_owner_t);
	int (*release)(struct inode___97 *, struct file___96 *);
	int (*fsync)(struct file___96 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___96 *, int);
	int (*lock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*sendpage)(struct file___96 *, struct page___96 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___96 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___96 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___96 *, long int, struct file_lock___96 **, void **);
		struct {
			int (*setlease)(struct file___96 *, long int, struct file_lock___96 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___96 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___72 *, struct file___96 *);
};

struct file_lock_operations___96;

struct lock_manager_operations___96;

struct file_lock___96 {
	struct file_lock___96 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___53 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___96 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___96 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___96 *fl_ops;
	const struct lock_manager_operations___96 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___96 {
	void (*fl_copy_lock)(struct file_lock___96 *, struct file_lock___96 *);
	void (*fl_release_private)(struct file_lock___96 *);
};

struct lock_manager_operations___96 {
	int (*lm_compare_owner)(struct file_lock___96 *, struct file_lock___96 *);
	long unsigned int (*lm_owner_key)(struct file_lock___96 *);
	void (*lm_notify)(struct file_lock___96 *);
	int (*lm_grant)(struct file_lock___96 *, struct file_lock___96 *, int);
	void (*lm_break)(struct file_lock___96 *);
	int (*lm_change)(struct file_lock___96 **, int);
};

struct fasync_struct___96 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___96 *fa_next;
	struct file___96 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___96 {
	const char *name;
	int fs_flags;
	struct dentry___97 * (*mount)(struct file_system_type___96 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___97 *);
	struct module *owner;
	struct file_system_type___96 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___96 {
	struct inode___97 * (*alloc_inode)(struct super_block___97 *);
	void (*destroy_inode)(struct inode___97 *);
	void (*dirty_inode)(struct inode___97 *, int);
	int (*write_inode)(struct inode___97 *, struct writeback_control *);
	int (*drop_inode)(struct inode___97 *);
	void (*evict_inode)(struct inode___97 *);
	void (*put_super)(struct super_block___97 *);
	int (*sync_fs)(struct super_block___97 *, int);
	int (*freeze_fs)(struct super_block___97 *);
	int (*unfreeze_fs)(struct super_block___97 *);
	int (*statfs)(struct dentry___97 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___97 *, int *, char *);
	void (*umount_begin)(struct super_block___97 *);
	int (*show_options)(struct seq_file___72 *, struct dentry___97 *);
	int (*show_devname)(struct seq_file___72 *, struct dentry___97 *);
	int (*show_path)(struct seq_file___72 *, struct dentry___97 *);
	int (*show_stats)(struct seq_file___72 *, struct dentry___97 *);
	ssize_t (*quota_read)(struct super_block___97 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___97 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___97 *);
	int (*bdev_try_to_free_page)(struct super_block___97 *, struct page___96 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___97 *);
	void (*free_cached_objects)(struct super_block___97 *, int);
};

struct xattr_handler___63 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___97 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___97 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___97 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___61)(struct file___96 *, wait_queue_head_t *, struct poll_table_struct___60 *);

struct poll_table_struct___60 {
	poll_queue_proc___61 _qproc;
	long unsigned int _key;
};

struct seq_operations___71;

struct seq_file___72 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___97 lock;
	const struct seq_operations___71 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___10 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___10 *last_lookup;
	struct hd_struct___10 *part[0];
};

struct block_device_operations___9 {
	int (*open)(struct block_device___96 *, fmode_t);
	void (*release)(struct gendisk___10 *, fmode_t);
	int (*ioctl)(struct block_device___96 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___96 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___96 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___10 *, unsigned int);
	int (*media_changed)(struct gendisk___10 *);
	void (*unlock_native_capacity)(struct gendisk___10 *);
	int (*revalidate_disk)(struct gendisk___10 *);
	int (*getgeo)(struct block_device___96 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___96 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___81 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___96 *page;
};

struct irq_chip___70 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___70 *);
	void (*irq_shutdown)(struct irq_data___70 *);
	void (*irq_enable)(struct irq_data___70 *);
	void (*irq_disable)(struct irq_data___70 *);
	void (*irq_ack)(struct irq_data___70 *);
	void (*irq_mask)(struct irq_data___70 *);
	void (*irq_mask_ack)(struct irq_data___70 *);
	void (*irq_unmask)(struct irq_data___70 *);
	void (*irq_eoi)(struct irq_data___70 *);
	int (*irq_set_affinity)(struct irq_data___70 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___70 *);
	int (*irq_set_type)(struct irq_data___70 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___70 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___70 *);
	void (*irq_bus_sync_unlock)(struct irq_data___70 *);
	void (*irq_cpu_online)(struct irq_data___70 *);
	void (*irq_cpu_offline)(struct irq_data___70 *);
	void (*irq_suspend)(struct irq_data___70 *);
	void (*irq_resume)(struct irq_data___70 *);
	void (*irq_pm_shutdown)(struct irq_data___70 *);
	void (*irq_print_chip)(struct irq_data___70 *, struct seq_file___72 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___70 *, void *);
	long unsigned int flags;
};

struct io_cq___9 {
	struct request_queue___9 *q;
	struct io_context___9 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___84 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___9(struct request___9 *, int);

struct request___9 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___9 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___9 *bio;
	struct bio___9 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___9 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___9 *saved_end_io;
		} flush;
	};
	struct gendisk___10 *rq_disk;
	struct hd_struct___10 *part;
	long unsigned int start_time;
	struct request_list___9 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___9 *end_io;
	void *end_io_data;
	struct request___9 *next_rq;
};

typedef int elevator_merge_fn___9(struct request_queue___9 *, struct request___9 **, struct bio___9 *);

typedef void elevator_merge_req_fn___9(struct request_queue___9 *, struct request___9 *, struct request___9 *);

typedef void elevator_merged_fn___9(struct request_queue___9 *, struct request___9 *, int);

typedef int elevator_allow_merge_fn___9(struct request_queue___9 *, struct request___9 *, struct bio___9 *);

typedef void elevator_bio_merged_fn___9(struct request_queue___9 *, struct request___9 *, struct bio___9 *);

typedef int elevator_dispatch_fn___9(struct request_queue___9 *, int);

typedef void elevator_add_req_fn___9(struct request_queue___9 *, struct request___9 *);

typedef struct request___9 *elevator_request_list_fn___9(struct request_queue___9 *, struct request___9 *);

typedef void elevator_completed_req_fn___9(struct request_queue___9 *, struct request___9 *);

typedef int elevator_may_queue_fn___9(struct request_queue___9 *, int);

typedef void elevator_init_icq_fn___9(struct io_cq___9 *);

typedef void elevator_exit_icq_fn___9(struct io_cq___9 *);

typedef int elevator_set_req_fn___9(struct request_queue___9 *, struct request___9 *, struct bio___9 *, gfp_t);

typedef void elevator_put_req_fn___9(struct request___9 *);

typedef void elevator_activate_req_fn___9(struct request_queue___9 *, struct request___9 *);

typedef void elevator_deactivate_req_fn___9(struct request_queue___9 *, struct request___9 *);

struct elevator_type___9;

typedef int elevator_init_fn___9(struct request_queue___9 *, struct elevator_type___9 *);

typedef void elevator_exit_fn___9(struct elevator_queue___9 *);

struct elevator_ops___9 {
	elevator_merge_fn___9 *elevator_merge_fn;
	elevator_merged_fn___9 *elevator_merged_fn;
	elevator_merge_req_fn___9 *elevator_merge_req_fn;
	elevator_allow_merge_fn___9 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___9 *elevator_bio_merged_fn;
	elevator_dispatch_fn___9 *elevator_dispatch_fn;
	elevator_add_req_fn___9 *elevator_add_req_fn;
	elevator_activate_req_fn___9 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___9 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___9 *elevator_completed_req_fn;
	elevator_request_list_fn___9 *elevator_former_req_fn;
	elevator_request_list_fn___9 *elevator_latter_req_fn;
	elevator_init_icq_fn___9 *elevator_init_icq_fn;
	elevator_exit_icq_fn___9 *elevator_exit_icq_fn;
	elevator_set_req_fn___9 *elevator_set_req_fn;
	elevator_put_req_fn___9 *elevator_put_req_fn;
	elevator_may_queue_fn___9 *elevator_may_queue_fn;
	elevator_init_fn___9 *elevator_init_fn;
	elevator_exit_fn___9 *elevator_exit_fn;
};

struct elv_fs_entry___9;

struct elevator_type___9 {
	struct kmem_cache___84 *icq_cache;
	struct elevator_ops___9 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___9 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___9 {
	struct elevator_type___9 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___97 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___9 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___9 *, char *);
	ssize_t (*store)(struct elevator_queue___9 *, const char *, size_t);
};

struct bvec_merge_data___9 {
	struct block_device___96 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___9 {
	struct request___9 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct rchan___2;

struct blk_trace___2 {
	int trace_state;
	struct rchan___2 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___97 *dir;
	struct dentry___97 *dropped_file;
	struct dentry___97 *msg_file;
	atomic_t dropped;
};

struct rchan_buf___2 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___2 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___97 *dentry;
	struct kref kref;
	struct page___96 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___2;

struct rchan___2 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___2 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___2 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___97 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___2 {
	int (*subbuf_start)(struct rchan_buf___2 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___2 *, struct file___96 *);
	void (*buf_unmapped)(struct rchan_buf___2 *, struct file___96 *);
	struct dentry___97 * (*create_buf_file)(const char *, struct dentry___97 *, umode_t, struct rchan_buf___2 *, int *);
	int (*remove_buf_file)(struct dentry___97 *);
};

typedef u64 compat_u64;

enum blktrace_cat {
	BLK_TC_READ = 1,
	BLK_TC_WRITE = 2,
	BLK_TC_FLUSH = 4,
	BLK_TC_SYNC = 8,
	BLK_TC_SYNCIO = 8,
	BLK_TC_QUEUE = 16,
	BLK_TC_REQUEUE = 32,
	BLK_TC_ISSUE = 64,
	BLK_TC_COMPLETE = 128,
	BLK_TC_FS = 256,
	BLK_TC_PC = 512,
	BLK_TC_NOTIFY = 1024,
	BLK_TC_AHEAD = 2048,
	BLK_TC_META = 4096,
	BLK_TC_DISCARD = 8192,
	BLK_TC_DRV_DATA = 16384,
	BLK_TC_FUA = 32768,
	BLK_TC_END = 32768,
};

enum blktrace_act {
	__BLK_TA_QUEUE = 1,
	__BLK_TA_BACKMERGE = 2,
	__BLK_TA_FRONTMERGE = 3,
	__BLK_TA_GETRQ = 4,
	__BLK_TA_SLEEPRQ = 5,
	__BLK_TA_REQUEUE = 6,
	__BLK_TA_ISSUE = 7,
	__BLK_TA_COMPLETE = 8,
	__BLK_TA_PLUG = 9,
	__BLK_TA_UNPLUG_IO = 10,
	__BLK_TA_UNPLUG_TIMER = 11,
	__BLK_TA_INSERT = 12,
	__BLK_TA_SPLIT = 13,
	__BLK_TA_BOUNCE = 14,
	__BLK_TA_REMAP = 15,
	__BLK_TA_ABORT = 16,
	__BLK_TA_DRV_DATA = 17,
};

enum blktrace_notify {
	__BLK_TN_PROCESS = 0,
	__BLK_TN_TIMESTAMP = 1,
	__BLK_TN_MESSAGE = 2,
};

struct blk_io_trace {
	__u32 magic;
	__u32 sequence;
	__u64 time;
	__u64 sector;
	__u32 bytes;
	__u32 action;
	__u32 pid;
	__u32 device;
	__u32 cpu;
	__u16 error;
	__u16 pdu_len;
};

struct blk_io_trace_remap {
	__be32 device_from;
	__be32 device_to;
	__be64 sector_from;
};

enum {
	Blktrace_setup = 1,
	Blktrace_running = 2,
	Blktrace_stopped = 3,
};

struct blk_user_trace_setup {
	char name[32];
	__u16 act_mask;
	__u32 buf_size;
	__u32 buf_nr;
	__u64 start_lba;
	__u64 end_lba;
	__u32 pid;
};

struct compat_blk_user_trace_setup {
	char name[32];
	u16 act_mask;
	short: 16;
	u32 buf_size;
	u32 buf_nr;
	compat_u64 start_lba;
	compat_u64 end_lba;
	u32 pid;
} __attribute__((packed));

struct seq_operations___71 {
	void * (*start)(struct seq_file___72 *, loff_t *);
	void (*stop)(struct seq_file___72 *, void *);
	void * (*next)(struct seq_file___72 *, void *, loff_t *);
	int (*show)(struct seq_file___72 *, void *);
};

struct cgroupfs_root___63;

struct cgroup___63 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___63 *parent;
	struct dentry___97 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___63 *subsys[11];
	struct cgroupfs_root___63 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___97 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___63 {
	struct super_block___97 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___63 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___48;

struct pmu___48 {
	struct list_head entry;
	struct device___75 *dev;
	const struct attribute_group___68 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___48 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___48 *);
	void (*pmu_disable)(struct pmu___48 *);
	int (*event_init)(struct perf_event___48 *);
	int (*add)(struct perf_event___48 *, int);
	void (*del)(struct perf_event___48 *, int);
	void (*start)(struct perf_event___48 *, int);
	void (*stop)(struct perf_event___48 *, int);
	void (*read)(struct perf_event___48 *);
	void (*start_txn)(struct pmu___48 *);
	int (*commit_txn)(struct pmu___48 *);
	void (*cancel_txn)(struct pmu___48 *);
	int (*event_idx)(struct perf_event___48 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___48 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___48 *);
};

struct perf_cpu_context___48 {
	struct perf_event_context___48 ctx;
	struct perf_event_context___48 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___48 *unique_pmu;
	struct perf_cgroup___48 *cgrp;
};

struct trace_event_functions___38;

struct trace_event___38 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___38 *funcs;
};

struct ftrace_event_class___38;

struct ftrace_event_call___38 {
	struct list_head list;
	struct ftrace_event_class___38 *class;
	char *name;
	struct trace_event___38 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___48 {
	struct cgroup_subsys_state___63 css;
	struct perf_cgroup_info *info;
};

struct trace_array___7;

struct tracer___7;

struct trace_buffer___7;

struct trace_iterator___38 {
	struct trace_array___7 *tr;
	struct tracer___7 *trace;
	struct trace_buffer___7 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___97 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___7;

struct trace_buffer___7 {
	struct trace_array___7 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___7 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___7 {
	struct trace_array___7 *tr;
	struct dentry___97 *dir;
	int cpu;
};

struct trace_array___7 {
	struct list_head list;
	char *name;
	struct trace_buffer___7 trace_buffer;
	struct trace_buffer___7 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___7 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___7 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___97 *dir;
	struct dentry___97 *options;
	struct dentry___97 *percpu_dir;
	struct dentry___97 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___96 *waiter;
	int ref;
};

struct tracer___7 {
	const char *name;
	int (*init)(struct trace_array___7 *);
	void (*reset)(struct trace_array___7 *);
	void (*start)(struct trace_array___7 *);
	void (*stop)(struct trace_array___7 *);
	void (*open)(struct trace_iterator___38 *);
	void (*pipe_open)(struct trace_iterator___38 *);
	int (*wait_pipe)(struct trace_iterator___38 *);
	void (*close)(struct trace_iterator___38 *);
	void (*pipe_close)(struct trace_iterator___38 *);
	ssize_t (*read)(struct trace_iterator___38 *, struct file___96 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___38 *, struct file___96 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___72 *);
	enum print_line_t (*print_line)(struct trace_iterator___38 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___7 *, u32, int);
	struct tracer___7 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___38)(struct trace_iterator___38 *, int, struct trace_event___38 *);

struct trace_event_functions___38 {
	trace_print_func___38 trace;
	trace_print_func___38 raw;
	trace_print_func___38 hex;
	trace_print_func___38 binary;
};

struct ftrace_event_class___38 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___38 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___38 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___38 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___38 *);
};

struct trace_array_cpu___7 {
	struct trace_cpu___7 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

typedef int blk_log_action_t(struct trace_iterator___38 *, const char *);

struct page___97;

typedef struct page___97 *pgtable_t___97;

struct address_space___97;

struct kmem_cache___85;

struct page___97 {
	long unsigned int flags;
	struct address_space___97 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___97 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___97 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___85 *slab_cache;
		struct page___97 *first_page;
	};
	long: 64;
};

struct thread_struct___49;

struct task_struct___97;

struct pv_cpu_ops___97 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___49 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___49 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___97 *);
	void (*end_context_switch)(struct task_struct___97 *);
};

struct perf_event___49;

struct thread_struct___49 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___49 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___54;

struct pid_link___54 {
	struct hlist_node node;
	struct pid___54 *pid;
};

struct mutex___98 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___97 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___93 {
	struct page___97 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___102;

struct nsproxy___55;

struct signal_struct___97;

struct css_set___64;

struct perf_event_context___49;

struct task_struct___97 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___97 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___102 *mm;
	struct mm_struct___102 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___97 *real_parent;
	struct task_struct___97 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___97 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___54 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___97 = 0,
		VTIME_USER___97 = 1,
		VTIME_SYS___97 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___49 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___55 *nsproxy;
	struct signal_struct___97 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___64 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___49 *perf_event_ctxp[2];
	struct mutex___98 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___93 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___102 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___102 *, struct mm_struct___102 *);
	void (*dup_mmap)(struct mm_struct___102 *, struct mm_struct___102 *);
	void (*exit_mmap)(struct mm_struct___102 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___102 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___102 *);
	void (*pgd_free)(struct mm_struct___102 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___102 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___102 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___102 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___102 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___102 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___102 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___102 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___102 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___102 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___102 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___102 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___98 lock;
	void *vdso;
} mm_context_t___98;

struct xol_area___97;

struct uprobes_state___97 {
	struct xol_area___97 *xol_area;
};

struct vm_area_struct___102;

struct file___97;

struct core_state___97;

struct mm_struct___102 {
	struct vm_area_struct___102 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___102 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___102 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___98 context;
	long unsigned int flags;
	struct core_state___97 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___97 *owner;
	struct file___97 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___97 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___52;

struct module_kobject___51 {
	struct kobject kobj;
	struct module___52 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___51;

struct ftrace_event_call___39;

struct module___52 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___51 mkobj;
	struct module_attribute___51 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___39 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___97 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___49 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___97 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___97 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___97 *target;
};

typedef void (*perf_overflow_handler_t___49)(struct perf_event___49 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___49;

typedef void (*ftrace_func_t___49)(long unsigned int, long unsigned int, struct ftrace_ops___49 *, struct pt_regs *);

struct ftrace_ops___49 {
	ftrace_func_t___49 func;
	struct ftrace_ops___49 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___98 regex_lock;
};

struct pmu___49;

struct fasync_struct___97;

struct pid_namespace___54;

struct perf_cgroup___49;

struct perf_event___49 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___49 *group_leader;
	struct pmu___49 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___49 hw;
	struct perf_event_context___49 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___98 child_mutex;
	struct list_head child_list;
	struct perf_event___49 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___97 *owner;
	struct mutex___98 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___97 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___49 *);
	struct callback_head callback_head;
	struct pid_namespace___54 *ns;
	u64 id;
	perf_overflow_handler_t___49 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___39 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___49 ftrace_ops;
	struct perf_cgroup___49 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___97 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___97 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___85;

struct memcg_cache_params___85;

struct kmem_cache___85 {
	struct kmem_cache_cpu___85 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___85 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___98;

struct address_space_operations___97;

struct address_space___97 {
	struct inode___98 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___98 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___97 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___98;

struct path___97 {
	struct vfsmount *mnt;
	struct dentry___98 *dentry;
};

struct fown_struct___54 {
	rwlock_t lock;
	struct pid___54 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___97;

struct file___97 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___97 f_path;
	struct inode___98 *f_inode;
	const struct file_operations___97 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___54 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___97 *f_mapping;
	struct mutex___98 f_pos_lock;
};

struct vm_operations_struct___85;

struct vm_area_struct___102 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___102 *vm_next;
	struct vm_area_struct___102 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___102 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___85 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___97 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___82;

struct vm_operations_struct___85 {
	void (*open)(struct vm_area_struct___102 *);
	void (*close)(struct vm_area_struct___102 *);
	int (*fault)(struct vm_area_struct___102 *, struct vm_fault___82 *);
	int (*page_mkwrite)(struct vm_area_struct___102 *, struct vm_fault___82 *);
	int (*access)(struct vm_area_struct___102 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___102 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___102 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___102 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___102 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___97 {
	struct task_struct___97 *task;
	struct core_thread___97 *next;
};

struct core_state___97 {
	atomic_t nr_threads;
	struct core_thread___97 dumper;
	struct completion startup;
};

struct irq_data___71;

struct x86_io_apic_ops___71 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___71 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___71;

struct irq_data___71 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___71 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___76;

struct dev_pm_ops___76 {
	int (*prepare)(struct device___76 *);
	void (*complete)(struct device___76 *);
	int (*suspend)(struct device___76 *);
	int (*resume)(struct device___76 *);
	int (*freeze)(struct device___76 *);
	int (*thaw)(struct device___76 *);
	int (*poweroff)(struct device___76 *);
	int (*restore)(struct device___76 *);
	int (*suspend_late)(struct device___76 *);
	int (*resume_early)(struct device___76 *);
	int (*freeze_late)(struct device___76 *);
	int (*thaw_early)(struct device___76 *);
	int (*poweroff_late)(struct device___76 *);
	int (*restore_early)(struct device___76 *);
	int (*suspend_noirq)(struct device___76 *);
	int (*resume_noirq)(struct device___76 *);
	int (*freeze_noirq)(struct device___76 *);
	int (*thaw_noirq)(struct device___76 *);
	int (*poweroff_noirq)(struct device___76 *);
	int (*restore_noirq)(struct device___76 *);
	int (*runtime_suspend)(struct device___76 *);
	int (*runtime_resume)(struct device___76 *);
	int (*runtime_idle)(struct device___76 *);
};

struct device_type___76;

struct bus_type___76;

struct device_driver___76;

struct dev_pm_domain___76;

struct class___76;

struct attribute_group___69;

struct device_rh___76;

struct device___76 {
	struct device___76 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___76 *type;
	struct mutex___98 mutex;
	struct bus_type___76 *bus;
	struct device_driver___76 *driver;
	void *platform_data;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___76 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___76 *class;
	const struct attribute_group___69 **groups;
	void (*release)(struct device___76 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___76 *device_rh;
};

struct dev_pm_info_rh___76 {
	void (*set_latency_tolerance)(struct device___76 *, s32);
};

struct dev_pm_domain___76 {
	struct dev_pm_ops___76 ops;
};

struct smp_ops___97 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___97 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___54 {
	int nr;
	struct pid_namespace___54 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___54 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___97 *child_reaper;
	struct kmem_cache___85 *pid_cachep;
	unsigned int level;
	struct pid_namespace___54 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___98 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___54 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___54 numbers[1];
};

struct zone___97;

struct lruvec___97 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___97 *zone;
};

struct pglist_data___97;

struct zone___97 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___97 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___97 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___97 {
	struct zone___97 *zone;
	int zone_idx;
};

struct zonelist___97 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___97 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___97 {
	struct zone___97 node_zones[4];
	struct zonelist___97 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___97 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___55 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___54 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___97 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___97 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___97 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___54 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___54 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___98 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___64;

struct css_set___64 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___64 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___49 {
	struct pmu___49 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___98 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___97 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___49 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___97;

struct super_block___98;

struct dentry___98 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___98 *d_parent;
	struct qstr d_name;
	struct inode___98 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___97 *d_op;
	struct super_block___98 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___97;

struct file_lock___97;

struct dquot___97;

struct block_device___97;

struct inode___98 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___97 *i_op;
	struct super_block___98 *i_sb;
	struct address_space___97 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___98 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___97 *i_fop;
	struct file_lock___97 *i_flock;
	struct address_space___97 i_data;
	struct dquot___97 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___97 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___97 {
	int (*d_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_hash)(const struct dentry___98 *, struct qstr *);
	int (*d_compare)(const struct dentry___98 *, const struct dentry___98 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___98 *);
	void (*d_release)(struct dentry___98 *);
	void (*d_prune)(struct dentry___98 *);
	void (*d_iput)(struct dentry___98 *, struct inode___98 *);
	char * (*d_dname)(struct dentry___98 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___97 *);
	int (*d_manage)(struct dentry___98 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___97;

struct mem_dqinfo___97 {
	struct quota_format_type___97 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___97;

struct quota_info___97 {
	unsigned int flags;
	struct mutex___98 dqio_mutex;
	struct mutex___98 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___98 *files[2];
	struct mem_dqinfo___97 info[2];
	const struct quota_format_ops___97 *ops[2];
};

struct file_system_type___97;

struct super_operations___97;

struct dquot_operations___97;

struct quotactl_ops___97;

struct xattr_handler___64;

struct super_block___98 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___97 *s_type;
	const struct super_operations___97 *s_op;
	const struct dquot_operations___97 *dq_op;
	const struct quotactl_ops___97 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___98 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___64 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___97 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___97 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___98 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___97 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___97 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___98 *bd_inode;
	struct super_block___98 *bd_super;
	struct mutex___98 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___97 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___98 bd_fsfreeze_mutex;
};

struct cgroup___64;

struct cgroup_subsys_state___64 {
	struct cgroup___64 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___98 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___97 *ia_file;
};

struct dquot___97 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___98 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___98 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___97 {
	int qf_fmt_id;
	const struct quota_format_ops___97 *qf_ops;
	struct module___52 *qf_owner;
	struct quota_format_type___97 *qf_next;
};

struct quota_format_ops___97 {
	int (*check_quota_file)(struct super_block___98 *, int);
	int (*read_file_info)(struct super_block___98 *, int);
	int (*write_file_info)(struct super_block___98 *, int);
	int (*free_file_info)(struct super_block___98 *, int);
	int (*read_dqblk)(struct dquot___97 *);
	int (*commit_dqblk)(struct dquot___97 *);
	int (*release_dqblk)(struct dquot___97 *);
};

struct dquot_operations___97 {
	int (*write_dquot)(struct dquot___97 *);
	struct dquot___97 * (*alloc_dquot)(struct super_block___98 *, int);
	void (*destroy_dquot)(struct dquot___97 *);
	int (*acquire_dquot)(struct dquot___97 *);
	int (*release_dquot)(struct dquot___97 *);
	int (*mark_dirty)(struct dquot___97 *);
	int (*write_info)(struct super_block___98 *, int);
	qsize_t * (*get_reserved_space)(struct inode___98 *);
};

struct quotactl_ops___97 {
	int (*quota_on)(struct super_block___98 *, int, int, struct path___97 *);
	int (*quota_on_meta)(struct super_block___98 *, int, int);
	int (*quota_off)(struct super_block___98 *, int);
	int (*quota_sync)(struct super_block___98 *, int);
	int (*get_info)(struct super_block___98 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___98 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___98 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___98 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___98 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___98 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___98 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___98 *, unsigned int);
};

struct address_space_operations___97 {
	int (*writepage)(struct page___97 *, struct writeback_control *);
	int (*readpage)(struct file___97 *, struct page___97 *);
	int (*writepages)(struct address_space___97 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___97 *);
	int (*readpages)(struct file___97 *, struct address_space___97 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___97 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___97 **, void **);
	int (*write_end)(struct file___97 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___97 *, void *);
	sector_t (*bmap)(struct address_space___97 *, sector_t);
	void (*invalidatepage)(struct page___97 *, long unsigned int);
	int (*releasepage)(struct page___97 *, gfp_t);
	void (*freepage)(struct page___97 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___97 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___97 *, struct page___97 *, struct page___97 *, enum migrate_mode);
	int (*launder_page)(struct page___97 *);
	int (*is_partially_uptodate)(struct page___97 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___97 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___97 *, struct page___97 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___97 *, sector_t *);
	void (*swap_deactivate)(struct file___97 *);
	void (*invalidatepage_range)(struct page___97 *, unsigned int, unsigned int);
};

struct inode_operations___97 {
	struct dentry___98 * (*lookup)(struct inode___98 *, struct dentry___98 *, unsigned int);
	void * (*follow_link)(struct dentry___98 *, struct nameidata *);
	int (*permission)(struct inode___98 *, int);
	struct posix_acl * (*get_acl)(struct inode___98 *, int);
	int (*readlink)(struct dentry___98 *, char *, int);
	void (*put_link)(struct dentry___98 *, struct nameidata *, void *);
	int (*create)(struct inode___98 *, struct dentry___98 *, umode_t, bool);
	int (*link)(struct dentry___98 *, struct inode___98 *, struct dentry___98 *);
	int (*unlink)(struct inode___98 *, struct dentry___98 *);
	int (*symlink)(struct inode___98 *, struct dentry___98 *, const char *);
	int (*mkdir)(struct inode___98 *, struct dentry___98 *, umode_t);
	int (*rmdir)(struct inode___98 *, struct dentry___98 *);
	int (*mknod)(struct inode___98 *, struct dentry___98 *, umode_t, dev_t);
	int (*rename)(struct inode___98 *, struct dentry___98 *, struct inode___98 *, struct dentry___98 *);
	int (*setattr)(struct dentry___98 *, struct iattr___98 *);
	int (*getattr)(struct vfsmount *, struct dentry___98 *, struct kstat *);
	int (*setxattr)(struct dentry___98 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___98 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___98 *, char *, size_t);
	int (*removexattr)(struct dentry___98 *, const char *);
	int (*fiemap)(struct inode___98 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___98 *, struct timespec *, int);
	int (*atomic_open)(struct inode___98 *, struct dentry___98 *, struct file___97 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___61;

struct seq_file___73;

struct file_operations___97 {
	struct module___52 *owner;
	loff_t (*llseek)(struct file___97 *, loff_t, int);
	ssize_t (*read)(struct file___97 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___97 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___97 *, void *, filldir_t);
	unsigned int (*poll)(struct file___97 *, struct poll_table_struct___61 *);
	long int (*unlocked_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___97 *, struct vm_area_struct___102 *);
	int (*open)(struct inode___98 *, struct file___97 *);
	int (*flush)(struct file___97 *, fl_owner_t);
	int (*release)(struct inode___98 *, struct file___97 *);
	int (*fsync)(struct file___97 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___97 *, int);
	int (*lock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*sendpage)(struct file___97 *, struct page___97 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___97 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___97 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___97 *, long int, struct file_lock___97 **, void **);
		struct {
			int (*setlease)(struct file___97 *, long int, struct file_lock___97 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___97 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___73 *, struct file___97 *);
};

struct file_lock_operations___97;

struct lock_manager_operations___97;

struct file_lock___97 {
	struct file_lock___97 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___54 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___97 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___97 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___97 *fl_ops;
	const struct lock_manager_operations___97 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___97 {
	void (*fl_copy_lock)(struct file_lock___97 *, struct file_lock___97 *);
	void (*fl_release_private)(struct file_lock___97 *);
};

struct lock_manager_operations___97 {
	int (*lm_compare_owner)(struct file_lock___97 *, struct file_lock___97 *);
	long unsigned int (*lm_owner_key)(struct file_lock___97 *);
	void (*lm_notify)(struct file_lock___97 *);
	int (*lm_grant)(struct file_lock___97 *, struct file_lock___97 *, int);
	void (*lm_break)(struct file_lock___97 *);
	int (*lm_change)(struct file_lock___97 **, int);
};

struct fasync_struct___97 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___97 *fa_next;
	struct file___97 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___97 {
	const char *name;
	int fs_flags;
	struct dentry___98 * (*mount)(struct file_system_type___97 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___98 *);
	struct module___52 *owner;
	struct file_system_type___97 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___97 {
	struct inode___98 * (*alloc_inode)(struct super_block___98 *);
	void (*destroy_inode)(struct inode___98 *);
	void (*dirty_inode)(struct inode___98 *, int);
	int (*write_inode)(struct inode___98 *, struct writeback_control *);
	int (*drop_inode)(struct inode___98 *);
	void (*evict_inode)(struct inode___98 *);
	void (*put_super)(struct super_block___98 *);
	int (*sync_fs)(struct super_block___98 *, int);
	int (*freeze_fs)(struct super_block___98 *);
	int (*unfreeze_fs)(struct super_block___98 *);
	int (*statfs)(struct dentry___98 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___98 *, int *, char *);
	void (*umount_begin)(struct super_block___98 *);
	int (*show_options)(struct seq_file___73 *, struct dentry___98 *);
	int (*show_devname)(struct seq_file___73 *, struct dentry___98 *);
	int (*show_path)(struct seq_file___73 *, struct dentry___98 *);
	int (*show_stats)(struct seq_file___73 *, struct dentry___98 *);
	ssize_t (*quota_read)(struct super_block___98 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___98 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___98 *);
	int (*bdev_try_to_free_page)(struct super_block___98 *, struct page___97 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___98 *);
	void (*free_cached_objects)(struct super_block___98 *, int);
};

struct xattr_handler___64 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___98 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___98 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___98 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___62)(struct file___97 *, wait_queue_head_t *, struct poll_table_struct___61 *);

struct poll_table_struct___61 {
	poll_queue_proc___62 _qproc;
	long unsigned int _key;
};

struct seq_operations___72;

struct seq_file___73 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___98 lock;
	const struct seq_operations___72 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___72 {
	void * (*start)(struct seq_file___73 *, loff_t *);
	void (*stop)(struct seq_file___73 *, void *);
	void * (*next)(struct seq_file___73 *, void *, loff_t *);
	int (*show)(struct seq_file___73 *, void *);
};

struct bin_attribute___69;

struct attribute_group___69 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___69 **bin_attrs;
};

struct bin_attribute___69 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___97 *, struct kobject *, struct bin_attribute___69 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___97 *, struct kobject *, struct bin_attribute___69 *, char *, loff_t, size_t);
	int (*mmap)(struct file___97 *, struct kobject *, struct bin_attribute___69 *, struct vm_area_struct___102 *);
};

struct module_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___51 *, struct module_kobject___51 *, char *);
	ssize_t (*store)(struct module_attribute___51 *, struct module_kobject___51 *, const char *, size_t);
	void (*setup)(struct module___52 *, const char *);
	int (*test)(struct module___52 *);
	void (*free)(struct module___52 *);
};

struct trace_event_functions___39;

struct trace_event___39 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___39 *funcs;
};

struct ftrace_event_class___39;

struct ftrace_event_call___39 {
	struct list_head list;
	struct ftrace_event_class___39 *class;
	char *name;
	struct trace_event___39 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct kmem_cache_cpu___85 {
	void **freelist;
	long unsigned int tid;
	struct page___97 *page;
	struct page___97 *partial;
};

struct memcg_cache_params___85 {
	bool is_root_cache;
	union {
		struct kmem_cache___85 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___85 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___82 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___97 *page;
};

struct ftrace_probe_ops___3 {
	void (*func)(long unsigned int, long unsigned int, void **);
	int (*init)(struct ftrace_probe_ops___3 *, long unsigned int, void **);
	void (*free)(struct ftrace_probe_ops___3 *, long unsigned int, void **);
	int (*print)(struct seq_file___73 *, long unsigned int, struct ftrace_probe_ops___3 *, void *);
};

struct bus_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___76 *, char *);
	ssize_t (*store)(struct bus_type___76 *, const char *, size_t);
};

struct device_attribute___76;

struct driver_attribute___76;

struct bus_type___76 {
	const char *name;
	const char *dev_name;
	struct device___76 *dev_root;
	struct bus_attribute___76 *bus_attrs;
	struct device_attribute___76 *dev_attrs;
	struct driver_attribute___76 *drv_attrs;
	const struct attribute_group___69 **bus_groups;
	const struct attribute_group___69 **dev_groups;
	const struct attribute_group___69 **drv_groups;
	int (*match)(struct device___76 *, struct device_driver___76 *);
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	int (*probe)(struct device___76 *);
	int (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*online)(struct device___76 *);
	int (*offline)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct device___76 *, struct device_attribute___76 *, char *);
	ssize_t (*store)(struct device___76 *, struct device_attribute___76 *, const char *, size_t);
};

struct driver_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___76 *, char *);
	ssize_t (*store)(struct device_driver___76 *, const char *, size_t);
};

struct device_driver___76 {
	const char *name;
	struct bus_type___76 *bus;
	struct module___52 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___76 *);
	int (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	const struct attribute_group___69 **groups;
	const struct dev_pm_ops___76 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___76 {
	const char *name;
	const struct attribute_group___69 **groups;
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
};

struct class_attribute___76;

struct class___76 {
	const char *name;
	struct module___52 *owner;
	struct class_attribute___76 *class_attrs;
	struct device_attribute___76 *dev_attrs;
	const struct attribute_group___69 **dev_groups;
	struct bin_attribute___69 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *);
	void (*class_release)(struct class___76 *);
	void (*dev_release)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
	struct subsys_private *p;
};

struct class_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct class___76 *, struct class_attribute___76 *, char *);
	ssize_t (*store)(struct class___76 *, struct class_attribute___76 *, const char *, size_t);
	const void * (*namespace)(struct class___76 *, const struct class_attribute___76 *);
};

struct device_rh___76 {
	struct dev_pm_info_rh___76 power;
};

struct cgroupfs_root___64;

struct cgroup___64 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___64 *parent;
	struct dentry___98 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___64 *subsys[11];
	struct cgroupfs_root___64 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___98 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___64 {
	struct super_block___98 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___64 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___49;

struct pmu___49 {
	struct list_head entry;
	struct device___76 *dev;
	const struct attribute_group___69 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___49 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___49 *);
	void (*pmu_disable)(struct pmu___49 *);
	int (*event_init)(struct perf_event___49 *);
	int (*add)(struct perf_event___49 *, int);
	void (*del)(struct perf_event___49 *, int);
	void (*start)(struct perf_event___49 *, int);
	void (*stop)(struct perf_event___49 *, int);
	void (*read)(struct perf_event___49 *);
	void (*start_txn)(struct pmu___49 *);
	int (*commit_txn)(struct pmu___49 *);
	void (*cancel_txn)(struct pmu___49 *);
	int (*event_idx)(struct perf_event___49 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___52 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___49 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___49 *);
};

struct perf_cpu_context___49 {
	struct perf_event_context___49 ctx;
	struct perf_event_context___49 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___49 *unique_pmu;
	struct perf_cgroup___49 *cgrp;
};

struct perf_cgroup___49 {
	struct cgroup_subsys_state___64 css;
	struct perf_cgroup_info *info;
};

struct irq_chip___71 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___71 *);
	void (*irq_shutdown)(struct irq_data___71 *);
	void (*irq_enable)(struct irq_data___71 *);
	void (*irq_disable)(struct irq_data___71 *);
	void (*irq_ack)(struct irq_data___71 *);
	void (*irq_mask)(struct irq_data___71 *);
	void (*irq_mask_ack)(struct irq_data___71 *);
	void (*irq_unmask)(struct irq_data___71 *);
	void (*irq_eoi)(struct irq_data___71 *);
	int (*irq_set_affinity)(struct irq_data___71 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___71 *);
	int (*irq_set_type)(struct irq_data___71 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___71 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___71 *);
	void (*irq_bus_sync_unlock)(struct irq_data___71 *);
	void (*irq_cpu_online)(struct irq_data___71 *);
	void (*irq_cpu_offline)(struct irq_data___71 *);
	void (*irq_suspend)(struct irq_data___71 *);
	void (*irq_resume)(struct irq_data___71 *);
	void (*irq_pm_shutdown)(struct irq_data___71 *);
	void (*irq_print_chip)(struct irq_data___71 *, struct seq_file___73 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___71 *, void *);
	long unsigned int flags;
};

struct trace_array___8;

struct tracer___8;

struct trace_buffer___8;

struct trace_iterator___39 {
	struct trace_array___8 *tr;
	struct tracer___8 *trace;
	struct trace_buffer___8 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___98 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___8;

struct trace_buffer___8 {
	struct trace_array___8 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___8 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___8 {
	struct trace_array___8 *tr;
	struct dentry___98 *dir;
	int cpu;
};

struct trace_array___8 {
	struct list_head list;
	char *name;
	struct trace_buffer___8 trace_buffer;
	struct trace_buffer___8 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___8 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___8 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___98 *dir;
	struct dentry___98 *options;
	struct dentry___98 *percpu_dir;
	struct dentry___98 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___97 *waiter;
	int ref;
};

struct tracer___8 {
	const char *name;
	int (*init)(struct trace_array___8 *);
	void (*reset)(struct trace_array___8 *);
	void (*start)(struct trace_array___8 *);
	void (*stop)(struct trace_array___8 *);
	void (*open)(struct trace_iterator___39 *);
	void (*pipe_open)(struct trace_iterator___39 *);
	int (*wait_pipe)(struct trace_iterator___39 *);
	void (*close)(struct trace_iterator___39 *);
	void (*pipe_close)(struct trace_iterator___39 *);
	ssize_t (*read)(struct trace_iterator___39 *, struct file___97 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___39 *, struct file___97 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___73 *);
	enum print_line_t (*print_line)(struct trace_iterator___39 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___8 *, u32, int);
	struct tracer___8 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___39)(struct trace_iterator___39 *, int, struct trace_event___39 *);

struct trace_event_functions___39 {
	trace_print_func___39 trace;
	trace_print_func___39 raw;
	trace_print_func___39 hex;
	trace_print_func___39 binary;
};

struct ftrace_event_class___39 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___39 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___39 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___39 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___39 *);
};

enum {
	FTRACE_EVENT_FL_ENABLED = 1,
	FTRACE_EVENT_FL_RECORDED_CMD = 2,
	FTRACE_EVENT_FL_SOFT_MODE = 4,
	FTRACE_EVENT_FL_SOFT_DISABLED = 8,
};

struct ftrace_event_file___14 {
	struct list_head list;
	struct ftrace_event_call___39 *event_call;
	struct dentry___98 *dir;
	struct trace_array___8 *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_subsystem_dir {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___8 *tr;
	struct dentry___98 *entry;
	int ref_count;
	int nr_events;
};

struct trace_array_cpu___8 {
	struct trace_cpu___8 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

enum {
	FORMAT_HEADER = 1,
	FORMAT_FIELD_SEPERATOR = 2,
	FORMAT_PRINTFMT = 3,
};

struct ftrace_module_file_ops {
	struct list_head list;
	struct module___52 *mod;
	struct file_operations___97 id;
	struct file_operations___97 enable;
	struct file_operations___97 format;
	struct file_operations___97 filter;
};

struct event_probe_data {
	struct ftrace_event_file___14 *file;
	long unsigned int count;
	int ref;
	bool enable;
};

struct mmiotrace_rw {
	resource_size_t phys;
	long unsigned int value;
	long unsigned int pc;
	int map_id;
	unsigned char opcode;
	unsigned char width;
};

struct mmiotrace_map {
	resource_size_t phys;
	long unsigned int virt;
	long unsigned int len;
	int map_id;
	unsigned char opcode;
};

struct trace_mmiotrace_rw {
	struct trace_entry ent;
	struct mmiotrace_rw rw;
};

struct trace_mmiotrace_map {
	struct trace_entry ent;
	struct mmiotrace_map map;
};

struct trace_branch {
	struct trace_entry ent;
	unsigned int line;
	char func[31];
	char file[21];
	char correct;
};

struct syscall_metadata___13 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___34 *enter_event;
	struct ftrace_event_call___34 *exit_event;
};

struct syscall_trace_enter {
	struct trace_entry ent;
	int nr;
	long unsigned int args[0];
};

struct syscall_trace_exit {
	struct trace_entry ent;
	int nr;
	long int ret;
};

typedef long unsigned int perf_trace_t[256];

struct ftrace_subsystem_dir___3 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array *tr;
	struct dentry___59 *entry;
	int ref_count;
	int nr_events;
};

enum filter_op_ids {
	OP_OR = 0,
	OP_AND = 1,
	OP_GLOB = 2,
	OP_NE = 3,
	OP_EQ = 4,
	OP_LT = 5,
	OP_LE = 6,
	OP_GT = 7,
	OP_GE = 8,
	OP_NONE = 9,
	OP_OPEN_PAREN = 10,
};

struct filter_op {
	int id;
	char *string;
	int precedence;
};

enum {
	FILT_ERR_NONE = 0,
	FILT_ERR_INVALID_OP = 1,
	FILT_ERR_UNBALANCED_PAREN = 2,
	FILT_ERR_TOO_MANY_OPERANDS = 3,
	FILT_ERR_OPERAND_TOO_LONG = 4,
	FILT_ERR_FIELD_NOT_FOUND = 5,
	FILT_ERR_ILLEGAL_FIELD_OP = 6,
	FILT_ERR_ILLEGAL_INTVAL = 7,
	FILT_ERR_BAD_SUBSYS_FILTER = 8,
	FILT_ERR_TOO_MANY_PREDS = 9,
	FILT_ERR_MISSING_FIELD = 10,
	FILT_ERR_INVALID_FILTER = 11,
	FILT_ERR_IP_FIELD_ONLY = 12,
};

struct opstack_op {
	int op;
	struct list_head list;
};

struct postfix_elt {
	int op;
	char *operand;
	struct list_head list;
};

struct filter_parse_state {
	struct filter_op *ops;
	struct list_head opstack;
	struct list_head postfix;
	int lasterr;
	int lasterr_pos;
	struct {
		char *string;
		unsigned int cnt;
		unsigned int tail;
	} infix;
	struct {
		char string[256];
		int pos;
		unsigned int tail;
	} operand;
};

struct pred_stack {
	struct filter_pred **preds;
	int index;
};

enum move_type {
	MOVE_DOWN = 0,
	MOVE_UP_FROM_LEFT = 1,
	MOVE_UP_FROM_RIGHT = 2,
};

enum walk_return {
	WALK_PRED_ABORT = 0,
	WALK_PRED_PARENT = 1,
	WALK_PRED_DEFAULT = 2,
};

typedef int (*filter_pred_walkcb_t)(enum move_type, struct filter_pred *, int *, void *);

struct filter_match_preds_data {
	struct filter_pred *preds;
	int match;
	void *rec;
};

struct check_pred_data {
	int count;
	int max;
};

struct fold_pred_data {
	struct filter_pred *root;
	int count;
	int children;
};

struct filter_list {
	struct list_head list;
	struct event_filter *filter;
};

struct function_filter_data {
	struct ftrace_ops___27 *ops;
	int first_filter;
	int first_notrace;
};

struct kretprobe_instance___2;

typedef int (*kretprobe_handler_t___2)(struct kretprobe_instance___2 *, struct pt_regs *);

struct kretprobe___2;

struct kretprobe_instance___2 {
	struct hlist_node hlist;
	struct kretprobe___2 *rp;
	kprobe_opcode_t *ret_addr;
	struct task_struct___95 *task;
	char data[0];
};

struct kretprobe___2 {
	struct kprobe kp;
	kretprobe_handler_t___2 handler;
	kretprobe_handler_t___2 entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct hlist_head free_instances;
	raw_spinlock_t lock;
};

struct kprobe_insn_cache___15 {
	struct mutex___96 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct ftrace_subsystem_dir___4;

struct ftrace_event_file___15 {
	struct list_head list;
	struct ftrace_event_call___37 *event_call;
	struct dentry___96 *dir;
	struct trace_array___6 *tr;
	struct ftrace_subsystem_dir___4 *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_subsystem_dir___4 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___6 *tr;
	struct dentry___96 *entry;
	int ref_count;
	int nr_events;
};

struct kprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int ip;
};

struct kretprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int func;
	long unsigned int ret_ip;
};

typedef void (*fetch_func_t)(struct pt_regs *, void *, void *);

typedef int (*print_type_func_t)(struct trace_seq *, const char *, void *, void *);

enum {
	FETCH_MTD_reg = 0,
	FETCH_MTD_stack = 1,
	FETCH_MTD_retval = 2,
	FETCH_MTD_memory = 3,
	FETCH_MTD_symbol = 4,
	FETCH_MTD_deref = 5,
	FETCH_MTD_bitfield = 6,
	FETCH_MTD_END = 7,
};

struct fetch_type {
	const char *name;
	size_t size;
	int is_signed;
	print_type_func_t print;
	const char *fmt;
	const char *fmttype;
	fetch_func_t fetch[7];
};

struct fetch_param {
	fetch_func_t fn;
	void *data;
};

struct probe_arg {
	struct fetch_param fetch;
	struct fetch_param fetch_size;
	unsigned int offset;
	const char *name;
	const char *comm;
	const struct fetch_type *type;
};

struct trace_probe {
	struct list_head list;
	struct kretprobe___2 rp;
	long unsigned int nhit;
	unsigned int flags;
	const char *symbol;
	struct ftrace_event_class___37 class;
	struct ftrace_event_call___37 call;
	struct ftrace_event_file___15 **files;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

struct page___98;

typedef struct page___98 *pgtable_t___98;

struct address_space___98;

struct kmem_cache___86;

struct page___98 {
	long unsigned int flags;
	struct address_space___98 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___98 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___98 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___86 *slab_cache;
		struct page___98 *first_page;
	};
	long: 64;
};

struct thread_struct___50;

struct task_struct___98;

struct pv_cpu_ops___98 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___50 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___50 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___98 *);
	void (*end_context_switch)(struct task_struct___98 *);
};

struct perf_event___50;

struct thread_struct___50 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___50 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___55;

struct pid_link___55 {
	struct hlist_node node;
	struct pid___55 *pid;
};

struct mutex___99 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___98 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___94 {
	struct page___98 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___103;

struct nsproxy___56;

struct signal_struct___98;

struct css_set___65;

struct perf_event_context___50;

struct task_struct___98 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___98 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___103 *mm;
	struct mm_struct___103 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___98 *real_parent;
	struct task_struct___98 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___98 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___55 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___98 = 0,
		VTIME_USER___98 = 1,
		VTIME_SYS___98 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___50 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___56 *nsproxy;
	struct signal_struct___98 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___65 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___50 *perf_event_ctxp[2];
	struct mutex___99 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___94 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___103 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___103 *, struct mm_struct___103 *);
	void (*dup_mmap)(struct mm_struct___103 *, struct mm_struct___103 *);
	void (*exit_mmap)(struct mm_struct___103 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___103 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___103 *);
	void (*pgd_free)(struct mm_struct___103 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___103 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___103 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___103 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___103 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___103 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___103 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___103 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___103 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___103 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___103 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___103 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___99 lock;
	void *vdso;
} mm_context_t___99;

struct xol_area___98;

struct uprobes_state___98 {
	struct xol_area___98 *xol_area;
};

struct vm_area_struct___103;

struct file___98;

struct core_state___98;

struct mm_struct___103 {
	struct vm_area_struct___103 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___103 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___103 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___99 context;
	long unsigned int flags;
	struct core_state___98 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___98 *owner;
	struct file___98 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___98 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___53;

struct exec_domain___26 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___53 *module;
	struct exec_domain___26 *next;
};

struct module_kobject___52 {
	struct kobject kobj;
	struct module___53 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___52;

struct ftrace_event_call___40;

struct module___53 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___52 mkobj;
	struct module_attribute___52 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___40 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___98 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___50 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___98 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___98 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___98 *target;
};

typedef void (*perf_overflow_handler_t___50)(struct perf_event___50 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___50;

typedef void (*ftrace_func_t___50)(long unsigned int, long unsigned int, struct ftrace_ops___50 *, struct pt_regs *);

struct ftrace_ops___50 {
	ftrace_func_t___50 func;
	struct ftrace_ops___50 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___99 regex_lock;
};

struct pmu___50;

struct fasync_struct___98;

struct pid_namespace___55;

struct perf_cgroup___50;

struct perf_event___50 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___50 *group_leader;
	struct pmu___50 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___50 hw;
	struct perf_event_context___50 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___99 child_mutex;
	struct list_head child_list;
	struct perf_event___50 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___98 *owner;
	struct mutex___99 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___98 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___50 *);
	struct callback_head callback_head;
	struct pid_namespace___55 *ns;
	u64 id;
	perf_overflow_handler_t___50 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___40 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___50 ftrace_ops;
	struct perf_cgroup___50 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___49 {
	struct task_struct___98 *task;
	struct exec_domain___26 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___98 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___98 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___86;

struct memcg_cache_params___86;

struct kmem_cache___86 {
	struct kmem_cache_cpu___86 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___86 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___99;

struct address_space_operations___98;

struct address_space___98 {
	struct inode___99 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___99 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___98 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___99;

struct path___98 {
	struct vfsmount *mnt;
	struct dentry___99 *dentry;
};

struct fown_struct___55 {
	rwlock_t lock;
	struct pid___55 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___98;

struct file___98 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___98 f_path;
	struct inode___99 *f_inode;
	const struct file_operations___98 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___55 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___98 *f_mapping;
	struct mutex___99 f_pos_lock;
};

struct vm_operations_struct___86;

struct vm_area_struct___103 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___103 *vm_next;
	struct vm_area_struct___103 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___103 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___86 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___98 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___83;

struct vm_operations_struct___86 {
	void (*open)(struct vm_area_struct___103 *);
	void (*close)(struct vm_area_struct___103 *);
	int (*fault)(struct vm_area_struct___103 *, struct vm_fault___83 *);
	int (*page_mkwrite)(struct vm_area_struct___103 *, struct vm_fault___83 *);
	int (*access)(struct vm_area_struct___103 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___103 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___103 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___103 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___103 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___98 {
	struct task_struct___98 *task;
	struct core_thread___98 *next;
};

struct core_state___98 {
	atomic_t nr_threads;
	struct core_thread___98 dumper;
	struct completion startup;
};

struct irq_data___72;

struct x86_io_apic_ops___72 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___72 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___72;

struct irq_data___72 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___72 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___77;

struct dev_pm_ops___77 {
	int (*prepare)(struct device___77 *);
	void (*complete)(struct device___77 *);
	int (*suspend)(struct device___77 *);
	int (*resume)(struct device___77 *);
	int (*freeze)(struct device___77 *);
	int (*thaw)(struct device___77 *);
	int (*poweroff)(struct device___77 *);
	int (*restore)(struct device___77 *);
	int (*suspend_late)(struct device___77 *);
	int (*resume_early)(struct device___77 *);
	int (*freeze_late)(struct device___77 *);
	int (*thaw_early)(struct device___77 *);
	int (*poweroff_late)(struct device___77 *);
	int (*restore_early)(struct device___77 *);
	int (*suspend_noirq)(struct device___77 *);
	int (*resume_noirq)(struct device___77 *);
	int (*freeze_noirq)(struct device___77 *);
	int (*thaw_noirq)(struct device___77 *);
	int (*poweroff_noirq)(struct device___77 *);
	int (*restore_noirq)(struct device___77 *);
	int (*runtime_suspend)(struct device___77 *);
	int (*runtime_resume)(struct device___77 *);
	int (*runtime_idle)(struct device___77 *);
};

struct dev_pm_qos___9;

struct dev_pm_info___9 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___9 *qos;
};

struct device_type___77;

struct bus_type___77;

struct device_driver___77;

struct dev_pm_domain___77;

struct class___77;

struct attribute_group___70;

struct device_rh___77;

struct device___77 {
	struct device___77 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___77 *type;
	struct mutex___99 mutex;
	struct bus_type___77 *bus;
	struct device_driver___77 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___77 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___77 *class;
	const struct attribute_group___70 **groups;
	void (*release)(struct device___77 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___77 *device_rh;
};

struct dev_pm_qos_request___9;

struct dev_pm_qos___9 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___9 *latency_req;
	struct dev_pm_qos_request___9 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___9 *latency_tolerance_req;
};

struct dev_pm_info_rh___77 {
	void (*set_latency_tolerance)(struct device___77 *, s32);
};

struct dev_pm_domain___77 {
	struct dev_pm_ops___77 ops;
};

struct smp_ops___98 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___98 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___55 {
	int nr;
	struct pid_namespace___55 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___55 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___98 *child_reaper;
	struct kmem_cache___86 *pid_cachep;
	unsigned int level;
	struct pid_namespace___55 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___99 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___55 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___55 numbers[1];
};

struct zone___98;

struct lruvec___98 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___98 *zone;
};

struct pglist_data___98;

struct zone___98 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___98 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___98 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___98 {
	struct zone___98 *zone;
	int zone_idx;
};

struct zonelist___98 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___98 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___98 {
	struct zone___98 node_zones[4];
	struct zonelist___98 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___98 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___56 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___55 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___98 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___98 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___98 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___55 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___55 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___99 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___65;

struct css_set___65 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___65 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___50 {
	struct pmu___50 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___99 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___98 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___50 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___70;

struct attribute_group___70 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___70 **bin_attrs;
};

struct bin_attribute___70 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___98 *, struct kobject *, struct bin_attribute___70 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___98 *, struct kobject *, struct bin_attribute___70 *, char *, loff_t, size_t);
	int (*mmap)(struct file___98 *, struct kobject *, struct bin_attribute___70 *, struct vm_area_struct___103 *);
};

struct module_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___52 *, struct module_kobject___52 *, char *);
	ssize_t (*store)(struct module_attribute___52 *, struct module_kobject___52 *, const char *, size_t);
	void (*setup)(struct module___53 *, const char *);
	int (*test)(struct module___53 *);
	void (*free)(struct module___53 *);
};

struct trace_event_functions___40;

struct trace_event___40 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___40 *funcs;
};

struct ftrace_event_class___40;

struct ftrace_event_call___40 {
	struct list_head list;
	struct ftrace_event_class___40 *class;
	char *name;
	struct trace_event___40 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct poll_table_struct___62;

struct file_lock___98;

struct seq_file___74;

struct file_operations___98 {
	struct module___53 *owner;
	loff_t (*llseek)(struct file___98 *, loff_t, int);
	ssize_t (*read)(struct file___98 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___98 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___98 *, void *, filldir_t);
	unsigned int (*poll)(struct file___98 *, struct poll_table_struct___62 *);
	long int (*unlocked_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___98 *, struct vm_area_struct___103 *);
	int (*open)(struct inode___99 *, struct file___98 *);
	int (*flush)(struct file___98 *, fl_owner_t);
	int (*release)(struct inode___99 *, struct file___98 *);
	int (*fsync)(struct file___98 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___98 *, int);
	int (*lock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*sendpage)(struct file___98 *, struct page___98 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___98 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___98 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___98 *, long int, struct file_lock___98 **, void **);
		struct {
			int (*setlease)(struct file___98 *, long int, struct file_lock___98 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___98 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___74 *, struct file___98 *);
};

struct bus_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___77 *, char *);
	ssize_t (*store)(struct bus_type___77 *, const char *, size_t);
};

struct device_attribute___77;

struct driver_attribute___77;

struct bus_type___77 {
	const char *name;
	const char *dev_name;
	struct device___77 *dev_root;
	struct bus_attribute___77 *bus_attrs;
	struct device_attribute___77 *dev_attrs;
	struct driver_attribute___77 *drv_attrs;
	const struct attribute_group___70 **bus_groups;
	const struct attribute_group___70 **dev_groups;
	const struct attribute_group___70 **drv_groups;
	int (*match)(struct device___77 *, struct device_driver___77 *);
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	int (*probe)(struct device___77 *);
	int (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*online)(struct device___77 *);
	int (*offline)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct device___77 *, struct device_attribute___77 *, char *);
	ssize_t (*store)(struct device___77 *, struct device_attribute___77 *, const char *, size_t);
};

struct driver_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___77 *, char *);
	ssize_t (*store)(struct device_driver___77 *, const char *, size_t);
};

struct device_driver___77 {
	const char *name;
	struct bus_type___77 *bus;
	struct module___53 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___77 *);
	int (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	const struct attribute_group___70 **groups;
	const struct dev_pm_ops___77 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___77 {
	const char *name;
	const struct attribute_group___70 **groups;
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
};

struct class_attribute___77;

struct class___77 {
	const char *name;
	struct module___53 *owner;
	struct class_attribute___77 *class_attrs;
	struct device_attribute___77 *dev_attrs;
	const struct attribute_group___70 **dev_groups;
	struct bin_attribute___70 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *);
	void (*class_release)(struct class___77 *);
	void (*dev_release)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
	struct subsys_private *p;
};

struct class_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct class___77 *, struct class_attribute___77 *, char *);
	ssize_t (*store)(struct class___77 *, struct class_attribute___77 *, const char *, size_t);
	const void * (*namespace)(struct class___77 *, const struct class_attribute___77 *);
};

struct device_rh___77 {
	struct dev_pm_info_rh___77 power;
};

struct dev_pm_qos_request___9 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___77 *dev;
};

struct vm_fault___83 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___98 *page;
};

struct seq_operations___73;

struct seq_file___74 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___99 lock;
	const struct seq_operations___73 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___73 {
	void * (*start)(struct seq_file___74 *, loff_t *);
	void (*stop)(struct seq_file___74 *, void *);
	void * (*next)(struct seq_file___74 *, void *, loff_t *);
	int (*show)(struct seq_file___74 *, void *);
};

struct dentry_operations___98;

struct super_block___99;

struct dentry___99 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___99 *d_parent;
	struct qstr d_name;
	struct inode___99 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___98 *d_op;
	struct super_block___99 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___98;

struct dquot___98;

struct block_device___98;

struct inode___99 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___98 *i_op;
	struct super_block___99 *i_sb;
	struct address_space___98 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___99 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___98 *i_fop;
	struct file_lock___98 *i_flock;
	struct address_space___98 i_data;
	struct dquot___98 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___98 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___98 {
	int (*d_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_hash)(const struct dentry___99 *, struct qstr *);
	int (*d_compare)(const struct dentry___99 *, const struct dentry___99 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___99 *);
	void (*d_release)(struct dentry___99 *);
	void (*d_prune)(struct dentry___99 *);
	void (*d_iput)(struct dentry___99 *, struct inode___99 *);
	char * (*d_dname)(struct dentry___99 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___98 *);
	int (*d_manage)(struct dentry___99 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___98;

struct mem_dqinfo___98 {
	struct quota_format_type___98 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___98;

struct quota_info___98 {
	unsigned int flags;
	struct mutex___99 dqio_mutex;
	struct mutex___99 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___99 *files[2];
	struct mem_dqinfo___98 info[2];
	const struct quota_format_ops___98 *ops[2];
};

struct file_system_type___98;

struct super_operations___98;

struct dquot_operations___98;

struct quotactl_ops___98;

struct xattr_handler___65;

struct super_block___99 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___98 *s_type;
	const struct super_operations___98 *s_op;
	const struct dquot_operations___98 *dq_op;
	const struct quotactl_ops___98 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___99 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___65 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___98 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___98 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___99 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___98 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___98 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___99 *bd_inode;
	struct super_block___99 *bd_super;
	struct mutex___99 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___98 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___99 bd_fsfreeze_mutex;
};

struct cgroup___65;

struct cgroup_subsys_state___65 {
	struct cgroup___65 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___99 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___98 *ia_file;
};

struct dquot___98 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___99 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___99 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___98 {
	int qf_fmt_id;
	const struct quota_format_ops___98 *qf_ops;
	struct module___53 *qf_owner;
	struct quota_format_type___98 *qf_next;
};

struct quota_format_ops___98 {
	int (*check_quota_file)(struct super_block___99 *, int);
	int (*read_file_info)(struct super_block___99 *, int);
	int (*write_file_info)(struct super_block___99 *, int);
	int (*free_file_info)(struct super_block___99 *, int);
	int (*read_dqblk)(struct dquot___98 *);
	int (*commit_dqblk)(struct dquot___98 *);
	int (*release_dqblk)(struct dquot___98 *);
};

struct dquot_operations___98 {
	int (*write_dquot)(struct dquot___98 *);
	struct dquot___98 * (*alloc_dquot)(struct super_block___99 *, int);
	void (*destroy_dquot)(struct dquot___98 *);
	int (*acquire_dquot)(struct dquot___98 *);
	int (*release_dquot)(struct dquot___98 *);
	int (*mark_dirty)(struct dquot___98 *);
	int (*write_info)(struct super_block___99 *, int);
	qsize_t * (*get_reserved_space)(struct inode___99 *);
};

struct quotactl_ops___98 {
	int (*quota_on)(struct super_block___99 *, int, int, struct path___98 *);
	int (*quota_on_meta)(struct super_block___99 *, int, int);
	int (*quota_off)(struct super_block___99 *, int);
	int (*quota_sync)(struct super_block___99 *, int);
	int (*get_info)(struct super_block___99 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___99 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___99 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___99 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___99 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___99 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___99 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___99 *, unsigned int);
};

struct address_space_operations___98 {
	int (*writepage)(struct page___98 *, struct writeback_control *);
	int (*readpage)(struct file___98 *, struct page___98 *);
	int (*writepages)(struct address_space___98 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___98 *);
	int (*readpages)(struct file___98 *, struct address_space___98 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___98 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___98 **, void **);
	int (*write_end)(struct file___98 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___98 *, void *);
	sector_t (*bmap)(struct address_space___98 *, sector_t);
	void (*invalidatepage)(struct page___98 *, long unsigned int);
	int (*releasepage)(struct page___98 *, gfp_t);
	void (*freepage)(struct page___98 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___98 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___98 *, struct page___98 *, struct page___98 *, enum migrate_mode);
	int (*launder_page)(struct page___98 *);
	int (*is_partially_uptodate)(struct page___98 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___98 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___98 *, struct page___98 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___98 *, sector_t *);
	void (*swap_deactivate)(struct file___98 *);
	void (*invalidatepage_range)(struct page___98 *, unsigned int, unsigned int);
};

struct inode_operations___98 {
	struct dentry___99 * (*lookup)(struct inode___99 *, struct dentry___99 *, unsigned int);
	void * (*follow_link)(struct dentry___99 *, struct nameidata *);
	int (*permission)(struct inode___99 *, int);
	struct posix_acl * (*get_acl)(struct inode___99 *, int);
	int (*readlink)(struct dentry___99 *, char *, int);
	void (*put_link)(struct dentry___99 *, struct nameidata *, void *);
	int (*create)(struct inode___99 *, struct dentry___99 *, umode_t, bool);
	int (*link)(struct dentry___99 *, struct inode___99 *, struct dentry___99 *);
	int (*unlink)(struct inode___99 *, struct dentry___99 *);
	int (*symlink)(struct inode___99 *, struct dentry___99 *, const char *);
	int (*mkdir)(struct inode___99 *, struct dentry___99 *, umode_t);
	int (*rmdir)(struct inode___99 *, struct dentry___99 *);
	int (*mknod)(struct inode___99 *, struct dentry___99 *, umode_t, dev_t);
	int (*rename)(struct inode___99 *, struct dentry___99 *, struct inode___99 *, struct dentry___99 *);
	int (*setattr)(struct dentry___99 *, struct iattr___99 *);
	int (*getattr)(struct vfsmount *, struct dentry___99 *, struct kstat *);
	int (*setxattr)(struct dentry___99 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___99 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___99 *, char *, size_t);
	int (*removexattr)(struct dentry___99 *, const char *);
	int (*fiemap)(struct inode___99 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___99 *, struct timespec *, int);
	int (*atomic_open)(struct inode___99 *, struct dentry___99 *, struct file___98 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___98;

struct lock_manager_operations___98;

struct file_lock___98 {
	struct file_lock___98 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___55 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___98 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___98 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___98 *fl_ops;
	const struct lock_manager_operations___98 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___98 {
	void (*fl_copy_lock)(struct file_lock___98 *, struct file_lock___98 *);
	void (*fl_release_private)(struct file_lock___98 *);
};

struct lock_manager_operations___98 {
	int (*lm_compare_owner)(struct file_lock___98 *, struct file_lock___98 *);
	long unsigned int (*lm_owner_key)(struct file_lock___98 *);
	void (*lm_notify)(struct file_lock___98 *);
	int (*lm_grant)(struct file_lock___98 *, struct file_lock___98 *, int);
	void (*lm_break)(struct file_lock___98 *);
	int (*lm_change)(struct file_lock___98 **, int);
};

struct fasync_struct___98 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___98 *fa_next;
	struct file___98 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___98 {
	const char *name;
	int fs_flags;
	struct dentry___99 * (*mount)(struct file_system_type___98 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___99 *);
	struct module___53 *owner;
	struct file_system_type___98 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___98 {
	struct inode___99 * (*alloc_inode)(struct super_block___99 *);
	void (*destroy_inode)(struct inode___99 *);
	void (*dirty_inode)(struct inode___99 *, int);
	int (*write_inode)(struct inode___99 *, struct writeback_control *);
	int (*drop_inode)(struct inode___99 *);
	void (*evict_inode)(struct inode___99 *);
	void (*put_super)(struct super_block___99 *);
	int (*sync_fs)(struct super_block___99 *, int);
	int (*freeze_fs)(struct super_block___99 *);
	int (*unfreeze_fs)(struct super_block___99 *);
	int (*statfs)(struct dentry___99 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___99 *, int *, char *);
	void (*umount_begin)(struct super_block___99 *);
	int (*show_options)(struct seq_file___74 *, struct dentry___99 *);
	int (*show_devname)(struct seq_file___74 *, struct dentry___99 *);
	int (*show_path)(struct seq_file___74 *, struct dentry___99 *);
	int (*show_stats)(struct seq_file___74 *, struct dentry___99 *);
	ssize_t (*quota_read)(struct super_block___99 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___99 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___99 *);
	int (*bdev_try_to_free_page)(struct super_block___99 *, struct page___98 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___99 *);
	void (*free_cached_objects)(struct super_block___99 *, int);
};

struct xattr_handler___65 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___99 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___99 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___99 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___63)(struct file___98 *, wait_queue_head_t *, struct poll_table_struct___62 *);

struct poll_table_struct___62 {
	poll_queue_proc___63 _qproc;
	long unsigned int _key;
};

struct irq_chip___72 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___72 *);
	void (*irq_shutdown)(struct irq_data___72 *);
	void (*irq_enable)(struct irq_data___72 *);
	void (*irq_disable)(struct irq_data___72 *);
	void (*irq_ack)(struct irq_data___72 *);
	void (*irq_mask)(struct irq_data___72 *);
	void (*irq_mask_ack)(struct irq_data___72 *);
	void (*irq_unmask)(struct irq_data___72 *);
	void (*irq_eoi)(struct irq_data___72 *);
	int (*irq_set_affinity)(struct irq_data___72 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___72 *);
	int (*irq_set_type)(struct irq_data___72 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___72 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___72 *);
	void (*irq_bus_sync_unlock)(struct irq_data___72 *);
	void (*irq_cpu_online)(struct irq_data___72 *);
	void (*irq_cpu_offline)(struct irq_data___72 *);
	void (*irq_suspend)(struct irq_data___72 *);
	void (*irq_resume)(struct irq_data___72 *);
	void (*irq_pm_shutdown)(struct irq_data___72 *);
	void (*irq_print_chip)(struct irq_data___72 *, struct seq_file___74 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___72 *, void *);
	long unsigned int flags;
};

struct kmem_cache_cpu___86 {
	void **freelist;
	long unsigned int tid;
	struct page___98 *page;
	struct page___98 *partial;
};

struct memcg_cache_params___86 {
	bool is_root_cache;
	union {
		struct kmem_cache___86 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___86 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___65;

struct cgroup___65 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___65 *parent;
	struct dentry___99 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___65 *subsys[11];
	struct cgroupfs_root___65 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___99 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___65 {
	struct super_block___99 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___65 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___50;

struct pmu___50 {
	struct list_head entry;
	struct device___77 *dev;
	const struct attribute_group___70 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___50 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___50 *);
	void (*pmu_disable)(struct pmu___50 *);
	int (*event_init)(struct perf_event___50 *);
	int (*add)(struct perf_event___50 *, int);
	void (*del)(struct perf_event___50 *, int);
	void (*start)(struct perf_event___50 *, int);
	void (*stop)(struct perf_event___50 *, int);
	void (*read)(struct perf_event___50 *);
	void (*start_txn)(struct pmu___50 *);
	int (*commit_txn)(struct pmu___50 *);
	void (*cancel_txn)(struct pmu___50 *);
	int (*event_idx)(struct perf_event___50 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___53 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___50 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___50 *);
};

struct perf_cpu_context___50 {
	struct perf_event_context___50 ctx;
	struct perf_event_context___50 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___50 *unique_pmu;
	struct perf_cgroup___50 *cgrp;
};

struct perf_cgroup___50 {
	struct cgroup_subsys_state___65 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___40 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___99 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___40)(struct trace_iterator___40 *, int, struct trace_event___40 *);

struct trace_event_functions___40 {
	trace_print_func___40 trace;
	trace_print_func___40 raw;
	trace_print_func___40 hex;
	trace_print_func___40 binary;
};

struct ftrace_event_class___40 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___40 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___40 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___40 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___40 *);
};

struct ftrace_event_file___16 {
	struct list_head list;
	struct ftrace_event_call___40 *event_call;
	struct dentry___99 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_cpu {
	struct trace_entry ent;
	u32 state;
	u32 cpu_id;
	char __data[0];
};

struct ftrace_raw_pstate_sample {
	struct trace_entry ent;
	u32 core_busy;
	u32 scaled_busy;
	u32 state;
	u64 mperf;
	u64 aperf;
	u32 freq;
	char __data[0];
};

struct ftrace_raw_machine_suspend {
	struct trace_entry ent;
	u32 state;
	char __data[0];
};

struct ftrace_raw_wakeup_source {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	char __data[0];
};

struct ftrace_raw_clock {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct ftrace_raw_power_domain {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct ftrace_raw_pm_qos_request {
	struct trace_entry ent;
	int pm_qos_class;
	s32 value;
	char __data[0];
};

struct ftrace_raw_pm_qos_update_request_timeout {
	struct trace_entry ent;
	int pm_qos_class;
	s32 value;
	long unsigned int timeout_us;
	char __data[0];
};

struct ftrace_raw_pm_qos_update {
	struct trace_entry ent;
	enum pm_qos_req_action action;
	int prev_value;
	int curr_value;
	char __data[0];
};

struct ftrace_raw_dev_pm_qos_request {
	struct trace_entry ent;
	u32 __data_loc_name;
	enum dev_pm_qos_req_type type;
	s32 new_value;
	char __data[0];
};

struct ftrace_data_offsets_cpu {};

struct ftrace_data_offsets_pstate_sample {};

struct ftrace_data_offsets_machine_suspend {};

struct ftrace_data_offsets_wakeup_source {
	u32 name;
};

struct ftrace_data_offsets_clock {
	u32 name;
};

struct ftrace_data_offsets_power_domain {
	u32 name;
};

struct ftrace_data_offsets_pm_qos_request {};

struct ftrace_data_offsets_pm_qos_update_request_timeout {};

struct ftrace_data_offsets_pm_qos_update {};

struct ftrace_data_offsets_dev_pm_qos_request {
	u32 name;
};

struct ftrace_raw_rpm_internal {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flags;
	int usage_count;
	int disable_depth;
	int runtime_auto;
	int request_pending;
	int irq_safe;
	int child_count;
	char __data[0];
};

struct ftrace_raw_rpm_return_int {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int ip;
	int ret;
	char __data[0];
};

struct ftrace_data_offsets_rpm_internal {
	u32 name;
};

struct ftrace_data_offsets_rpm_return_int {
	u32 name;
};

typedef u32 string;

typedef u32 string_size;

struct symbol_cache {
	char *symbol;
	long int offset;
	long unsigned int addr;
};

struct deref_fetch_param {
	struct fetch_param orig;
	long int offset;
};

struct bitfield_fetch_param {
	struct fetch_param orig;
	unsigned char hi_shift;
	unsigned char low_shift;
};

struct page___99;

typedef struct page___99 *pgtable_t___99;

struct address_space___99;

struct kmem_cache___87;

struct page___99 {
	long unsigned int flags;
	struct address_space___99 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___99 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___99 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___87 *slab_cache;
		struct page___99 *first_page;
	};
	long: 64;
};

struct thread_struct___51;

struct task_struct___99;

struct pv_cpu_ops___99 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___51 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___51 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___99 *);
	void (*end_context_switch)(struct task_struct___99 *);
};

struct perf_event___51;

struct thread_struct___51 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___51 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___56;

struct pid_link___56 {
	struct hlist_node node;
	struct pid___56 *pid;
};

struct mutex___100 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___99 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___95 {
	struct page___99 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___104;

struct nsproxy___57;

struct signal_struct___99;

struct css_set___66;

struct perf_event_context___51;

struct task_struct___99 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___99 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___104 *mm;
	struct mm_struct___104 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___99 *real_parent;
	struct task_struct___99 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___99 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___56 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___99 = 0,
		VTIME_USER___99 = 1,
		VTIME_SYS___99 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___51 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___57 *nsproxy;
	struct signal_struct___99 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___66 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___51 *perf_event_ctxp[2];
	struct mutex___100 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___95 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___104 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___104 *, struct mm_struct___104 *);
	void (*dup_mmap)(struct mm_struct___104 *, struct mm_struct___104 *);
	void (*exit_mmap)(struct mm_struct___104 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___104 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___104 *);
	void (*pgd_free)(struct mm_struct___104 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___104 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___104 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___104 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___104 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___104 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___104 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___104 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___104 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___104 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___104 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___104 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___100 lock;
	void *vdso;
} mm_context_t___100;

struct xol_area___99;

struct uprobes_state___99 {
	struct xol_area___99 *xol_area;
};

struct vm_area_struct___104;

struct file___99;

struct core_state___99;

struct mm_struct___104 {
	struct vm_area_struct___104 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___104 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___104 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___100 context;
	long unsigned int flags;
	struct core_state___99 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___99 *owner;
	struct file___99 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___99 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___54;

struct module_kobject___53 {
	struct kobject kobj;
	struct module___54 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___53;

struct ftrace_event_call___41;

struct module___54 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___53 mkobj;
	struct module_attribute___53 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___41 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___99 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___51 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___99 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___99 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___99 *target;
};

typedef void (*perf_overflow_handler_t___51)(struct perf_event___51 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___51;

typedef void (*ftrace_func_t___51)(long unsigned int, long unsigned int, struct ftrace_ops___51 *, struct pt_regs *);

struct ftrace_ops___51 {
	ftrace_func_t___51 func;
	struct ftrace_ops___51 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___100 regex_lock;
};

struct pmu___51;

struct fasync_struct___99;

struct pid_namespace___56;

struct perf_cgroup___51;

struct perf_event___51 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___51 *group_leader;
	struct pmu___51 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___51 hw;
	struct perf_event_context___51 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___100 child_mutex;
	struct list_head child_list;
	struct perf_event___51 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___99 *owner;
	struct mutex___100 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___99 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___51 *);
	struct callback_head callback_head;
	struct pid_namespace___56 *ns;
	u64 id;
	perf_overflow_handler_t___51 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___41 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___51 ftrace_ops;
	struct perf_cgroup___51 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___99;

struct lruvec___99 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___99 *zone;
};

struct pglist_data___99;

struct zone___99 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___99 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___99 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___99 {
	struct zone___99 *zone;
	int zone_idx;
};

struct zonelist___99 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___99 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___99 {
	struct zone___99 node_zones[4];
	struct zonelist___99 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___99 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___73;

struct x86_io_apic_ops___73 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___73 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___73;

struct irq_data___73 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___73 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___78;

struct dev_pm_ops___78 {
	int (*prepare)(struct device___78 *);
	void (*complete)(struct device___78 *);
	int (*suspend)(struct device___78 *);
	int (*resume)(struct device___78 *);
	int (*freeze)(struct device___78 *);
	int (*thaw)(struct device___78 *);
	int (*poweroff)(struct device___78 *);
	int (*restore)(struct device___78 *);
	int (*suspend_late)(struct device___78 *);
	int (*resume_early)(struct device___78 *);
	int (*freeze_late)(struct device___78 *);
	int (*thaw_early)(struct device___78 *);
	int (*poweroff_late)(struct device___78 *);
	int (*restore_early)(struct device___78 *);
	int (*suspend_noirq)(struct device___78 *);
	int (*resume_noirq)(struct device___78 *);
	int (*freeze_noirq)(struct device___78 *);
	int (*thaw_noirq)(struct device___78 *);
	int (*poweroff_noirq)(struct device___78 *);
	int (*restore_noirq)(struct device___78 *);
	int (*runtime_suspend)(struct device___78 *);
	int (*runtime_resume)(struct device___78 *);
	int (*runtime_idle)(struct device___78 *);
};

struct device_type___78;

struct bus_type___78;

struct device_driver___78;

struct dev_pm_domain___78;

struct class___78;

struct attribute_group___71;

struct device_rh___78;

struct device___78 {
	struct device___78 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___78 *type;
	struct mutex___100 mutex;
	struct bus_type___78 *bus;
	struct device_driver___78 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___78 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___78 *class;
	const struct attribute_group___71 **groups;
	void (*release)(struct device___78 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___78 *device_rh;
};

struct dev_pm_info_rh___78 {
	void (*set_latency_tolerance)(struct device___78 *, s32);
};

struct dev_pm_domain___78 {
	struct dev_pm_ops___78 ops;
};

struct smp_ops___99 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___99 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___57 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___56 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___71;

struct attribute_group___71 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___71 **bin_attrs;
};

struct bin_attribute___71 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___99 *, struct kobject *, struct bin_attribute___71 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___99 *, struct kobject *, struct bin_attribute___71 *, char *, loff_t, size_t);
	int (*mmap)(struct file___99 *, struct kobject *, struct bin_attribute___71 *, struct vm_area_struct___104 *);
};

struct dentry___100;

struct path___99 {
	struct vfsmount *mnt;
	struct dentry___100 *dentry;
};

struct fown_struct___56 {
	rwlock_t lock;
	struct pid___56 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___100;

struct file_operations___99;

struct file___99 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___99 f_path;
	struct inode___100 *f_inode;
	const struct file_operations___99 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___56 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___99 *f_mapping;
	struct mutex___100 f_pos_lock;
};

struct vm_operations_struct___87;

struct vm_area_struct___104 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___104 *vm_next;
	struct vm_area_struct___104 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___104 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___87 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___99 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___53 *, struct module_kobject___53 *, char *);
	ssize_t (*store)(struct module_attribute___53 *, struct module_kobject___53 *, const char *, size_t);
	void (*setup)(struct module___54 *, const char *);
	int (*test)(struct module___54 *);
	void (*free)(struct module___54 *);
};

struct trace_event_functions___41;

struct trace_event___41 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___41 *funcs;
};

struct ftrace_event_class___41;

struct ftrace_event_call___41 {
	struct list_head list;
	struct ftrace_event_class___41 *class;
	char *name;
	struct trace_event___41 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

enum uprobe_filter_ctx {
	UPROBE_FILTER_REGISTER = 0,
	UPROBE_FILTER_UNREGISTER = 1,
	UPROBE_FILTER_MMAP = 2,
};

struct uprobe_consumer {
	int (*handler)(struct uprobe_consumer *, struct pt_regs *);
	int (*ret_handler)(struct uprobe_consumer *, long unsigned int, struct pt_regs *);
	bool (*filter)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___104 *);
	struct uprobe_consumer *next;
};

struct xol_area___99 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___99 *page;
	long unsigned int vaddr;
};

struct dentry_operations___99;

struct super_block___100;

struct dentry___100 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___100 *d_parent;
	struct qstr d_name;
	struct inode___100 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___99 *d_op;
	struct super_block___100 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___99;

struct address_space___99 {
	struct inode___100 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___100 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___99 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___99;

struct file_lock___99;

struct dquot___99;

struct block_device___99;

struct inode___100 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___99 *i_op;
	struct super_block___100 *i_sb;
	struct address_space___99 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___100 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___99 *i_fop;
	struct file_lock___99 *i_flock;
	struct address_space___99 i_data;
	struct dquot___99 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___99 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___99 {
	int (*d_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_hash)(const struct dentry___100 *, struct qstr *);
	int (*d_compare)(const struct dentry___100 *, const struct dentry___100 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___100 *);
	void (*d_release)(struct dentry___100 *);
	void (*d_prune)(struct dentry___100 *);
	void (*d_iput)(struct dentry___100 *, struct inode___100 *);
	char * (*d_dname)(struct dentry___100 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___99 *);
	int (*d_manage)(struct dentry___100 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___99;

struct mem_dqinfo___99 {
	struct quota_format_type___99 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___99;

struct quota_info___99 {
	unsigned int flags;
	struct mutex___100 dqio_mutex;
	struct mutex___100 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___100 *files[2];
	struct mem_dqinfo___99 info[2];
	const struct quota_format_ops___99 *ops[2];
};

struct file_system_type___99;

struct super_operations___99;

struct dquot_operations___99;

struct quotactl_ops___99;

struct xattr_handler___66;

struct super_block___100 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___99 *s_type;
	const struct super_operations___99 *s_op;
	const struct dquot_operations___99 *dq_op;
	const struct quotactl_ops___99 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___100 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___66 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___99 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___99 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___100 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___99 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct nameidata___5 {
	struct path___99 path;
	struct qstr last;
	struct path___99 root;
	struct inode___100 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct seq_operations___74;

struct seq_file___75 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___100 lock;
	const struct seq_operations___74 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___74 {
	void * (*start)(struct seq_file___75 *, loff_t *);
	void (*stop)(struct seq_file___75 *, void *);
	void * (*next)(struct seq_file___75 *, void *, loff_t *);
	int (*show)(struct seq_file___75 *, void *);
};

struct kmem_cache_cpu___87 {
	void **freelist;
	long unsigned int tid;
	struct page___99 *page;
	struct page___99 *partial;
};

struct memcg_cache_params___87;

struct kmem_cache___87 {
	struct kmem_cache_cpu___87 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___87 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___87 {
	bool is_root_cache;
	union {
		struct kmem_cache___87 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___87 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct upid___56 {
	int nr;
	struct pid_namespace___56 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___56 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___99 *child_reaper;
	struct kmem_cache___87 *pid_cachep;
	unsigned int level;
	struct pid_namespace___56 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___100 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___56 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___56 numbers[1];
};

struct block_device___99 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___100 *bd_inode;
	struct super_block___100 *bd_super;
	struct mutex___100 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___99 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___100 bd_fsfreeze_mutex;
};

struct cgroup___66;

struct cgroup_subsys_state___66 {
	struct cgroup___66 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___100 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___99 *ia_file;
};

struct dquot___99 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___100 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___100 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___99 {
	int qf_fmt_id;
	const struct quota_format_ops___99 *qf_ops;
	struct module___54 *qf_owner;
	struct quota_format_type___99 *qf_next;
};

struct quota_format_ops___99 {
	int (*check_quota_file)(struct super_block___100 *, int);
	int (*read_file_info)(struct super_block___100 *, int);
	int (*write_file_info)(struct super_block___100 *, int);
	int (*free_file_info)(struct super_block___100 *, int);
	int (*read_dqblk)(struct dquot___99 *);
	int (*commit_dqblk)(struct dquot___99 *);
	int (*release_dqblk)(struct dquot___99 *);
};

struct dquot_operations___99 {
	int (*write_dquot)(struct dquot___99 *);
	struct dquot___99 * (*alloc_dquot)(struct super_block___100 *, int);
	void (*destroy_dquot)(struct dquot___99 *);
	int (*acquire_dquot)(struct dquot___99 *);
	int (*release_dquot)(struct dquot___99 *);
	int (*mark_dirty)(struct dquot___99 *);
	int (*write_info)(struct super_block___100 *, int);
	qsize_t * (*get_reserved_space)(struct inode___100 *);
};

struct quotactl_ops___99 {
	int (*quota_on)(struct super_block___100 *, int, int, struct path___99 *);
	int (*quota_on_meta)(struct super_block___100 *, int, int);
	int (*quota_off)(struct super_block___100 *, int);
	int (*quota_sync)(struct super_block___100 *, int);
	int (*get_info)(struct super_block___100 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___100 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___100 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___100 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___100 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___100 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___100 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___100 *, unsigned int);
};

struct address_space_operations___99 {
	int (*writepage)(struct page___99 *, struct writeback_control *);
	int (*readpage)(struct file___99 *, struct page___99 *);
	int (*writepages)(struct address_space___99 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___99 *);
	int (*readpages)(struct file___99 *, struct address_space___99 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___99 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___99 **, void **);
	int (*write_end)(struct file___99 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___99 *, void *);
	sector_t (*bmap)(struct address_space___99 *, sector_t);
	void (*invalidatepage)(struct page___99 *, long unsigned int);
	int (*releasepage)(struct page___99 *, gfp_t);
	void (*freepage)(struct page___99 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___99 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___99 *, struct page___99 *, struct page___99 *, enum migrate_mode);
	int (*launder_page)(struct page___99 *);
	int (*is_partially_uptodate)(struct page___99 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___99 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___99 *, struct page___99 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___99 *, sector_t *);
	void (*swap_deactivate)(struct file___99 *);
	void (*invalidatepage_range)(struct page___99 *, unsigned int, unsigned int);
};

struct inode_operations___99 {
	struct dentry___100 * (*lookup)(struct inode___100 *, struct dentry___100 *, unsigned int);
	void * (*follow_link)(struct dentry___100 *, struct nameidata___5 *);
	int (*permission)(struct inode___100 *, int);
	struct posix_acl * (*get_acl)(struct inode___100 *, int);
	int (*readlink)(struct dentry___100 *, char *, int);
	void (*put_link)(struct dentry___100 *, struct nameidata___5 *, void *);
	int (*create)(struct inode___100 *, struct dentry___100 *, umode_t, bool);
	int (*link)(struct dentry___100 *, struct inode___100 *, struct dentry___100 *);
	int (*unlink)(struct inode___100 *, struct dentry___100 *);
	int (*symlink)(struct inode___100 *, struct dentry___100 *, const char *);
	int (*mkdir)(struct inode___100 *, struct dentry___100 *, umode_t);
	int (*rmdir)(struct inode___100 *, struct dentry___100 *);
	int (*mknod)(struct inode___100 *, struct dentry___100 *, umode_t, dev_t);
	int (*rename)(struct inode___100 *, struct dentry___100 *, struct inode___100 *, struct dentry___100 *);
	int (*setattr)(struct dentry___100 *, struct iattr___100 *);
	int (*getattr)(struct vfsmount *, struct dentry___100 *, struct kstat *);
	int (*setxattr)(struct dentry___100 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___100 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___100 *, char *, size_t);
	int (*removexattr)(struct dentry___100 *, const char *);
	int (*fiemap)(struct inode___100 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___100 *, struct timespec *, int);
	int (*atomic_open)(struct inode___100 *, struct dentry___100 *, struct file___99 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___63;

struct file_operations___99 {
	struct module___54 *owner;
	loff_t (*llseek)(struct file___99 *, loff_t, int);
	ssize_t (*read)(struct file___99 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___99 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___99 *, void *, filldir_t);
	unsigned int (*poll)(struct file___99 *, struct poll_table_struct___63 *);
	long int (*unlocked_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___99 *, struct vm_area_struct___104 *);
	int (*open)(struct inode___100 *, struct file___99 *);
	int (*flush)(struct file___99 *, fl_owner_t);
	int (*release)(struct inode___100 *, struct file___99 *);
	int (*fsync)(struct file___99 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___99 *, int);
	int (*lock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*sendpage)(struct file___99 *, struct page___99 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___99 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___99 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___99 *, long int, struct file_lock___99 **, void **);
		struct {
			int (*setlease)(struct file___99 *, long int, struct file_lock___99 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___99 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___75 *, struct file___99 *);
};

struct file_lock_operations___99;

struct lock_manager_operations___99;

struct file_lock___99 {
	struct file_lock___99 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___56 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___99 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___99 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___99 *fl_ops;
	const struct lock_manager_operations___99 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___99 {
	void (*fl_copy_lock)(struct file_lock___99 *, struct file_lock___99 *);
	void (*fl_release_private)(struct file_lock___99 *);
};

struct lock_manager_operations___99 {
	int (*lm_compare_owner)(struct file_lock___99 *, struct file_lock___99 *);
	long unsigned int (*lm_owner_key)(struct file_lock___99 *);
	void (*lm_notify)(struct file_lock___99 *);
	int (*lm_grant)(struct file_lock___99 *, struct file_lock___99 *, int);
	void (*lm_break)(struct file_lock___99 *);
	int (*lm_change)(struct file_lock___99 **, int);
};

struct fasync_struct___99 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___99 *fa_next;
	struct file___99 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___99 {
	const char *name;
	int fs_flags;
	struct dentry___100 * (*mount)(struct file_system_type___99 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___100 *);
	struct module___54 *owner;
	struct file_system_type___99 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___99 {
	struct inode___100 * (*alloc_inode)(struct super_block___100 *);
	void (*destroy_inode)(struct inode___100 *);
	void (*dirty_inode)(struct inode___100 *, int);
	int (*write_inode)(struct inode___100 *, struct writeback_control *);
	int (*drop_inode)(struct inode___100 *);
	void (*evict_inode)(struct inode___100 *);
	void (*put_super)(struct super_block___100 *);
	int (*sync_fs)(struct super_block___100 *, int);
	int (*freeze_fs)(struct super_block___100 *);
	int (*unfreeze_fs)(struct super_block___100 *);
	int (*statfs)(struct dentry___100 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___100 *, int *, char *);
	void (*umount_begin)(struct super_block___100 *);
	int (*show_options)(struct seq_file___75 *, struct dentry___100 *);
	int (*show_devname)(struct seq_file___75 *, struct dentry___100 *);
	int (*show_path)(struct seq_file___75 *, struct dentry___100 *);
	int (*show_stats)(struct seq_file___75 *, struct dentry___100 *);
	ssize_t (*quota_read)(struct super_block___100 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___100 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___100 *);
	int (*bdev_try_to_free_page)(struct super_block___100 *, struct page___99 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___100 *);
	void (*free_cached_objects)(struct super_block___100 *, int);
};

struct xattr_handler___66 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___100 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___100 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___100 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___64)(struct file___99 *, wait_queue_head_t *, struct poll_table_struct___63 *);

struct poll_table_struct___63 {
	poll_queue_proc___64 _qproc;
	long unsigned int _key;
};

struct vm_fault___84;

struct vm_operations_struct___87 {
	void (*open)(struct vm_area_struct___104 *);
	void (*close)(struct vm_area_struct___104 *);
	int (*fault)(struct vm_area_struct___104 *, struct vm_fault___84 *);
	int (*page_mkwrite)(struct vm_area_struct___104 *, struct vm_fault___84 *);
	int (*access)(struct vm_area_struct___104 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___104 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___104 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___104 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___104 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___99 {
	struct task_struct___99 *task;
	struct core_thread___99 *next;
};

struct core_state___99 {
	atomic_t nr_threads;
	struct core_thread___99 dumper;
	struct completion startup;
};

struct signal_struct___99 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___99 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___99 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___56 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___56 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___100 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___66 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___66 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___51 {
	struct pmu___51 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___100 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___99 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___51 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___84 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___99 *page;
};

struct bus_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___78 *, char *);
	ssize_t (*store)(struct bus_type___78 *, const char *, size_t);
};

struct device_attribute___78;

struct driver_attribute___78;

struct bus_type___78 {
	const char *name;
	const char *dev_name;
	struct device___78 *dev_root;
	struct bus_attribute___78 *bus_attrs;
	struct device_attribute___78 *dev_attrs;
	struct driver_attribute___78 *drv_attrs;
	const struct attribute_group___71 **bus_groups;
	const struct attribute_group___71 **dev_groups;
	const struct attribute_group___71 **drv_groups;
	int (*match)(struct device___78 *, struct device_driver___78 *);
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	int (*probe)(struct device___78 *);
	int (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*online)(struct device___78 *);
	int (*offline)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct device___78 *, struct device_attribute___78 *, char *);
	ssize_t (*store)(struct device___78 *, struct device_attribute___78 *, const char *, size_t);
};

struct driver_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___78 *, char *);
	ssize_t (*store)(struct device_driver___78 *, const char *, size_t);
};

struct device_driver___78 {
	const char *name;
	struct bus_type___78 *bus;
	struct module___54 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___78 *);
	int (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	const struct attribute_group___71 **groups;
	const struct dev_pm_ops___78 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___78 {
	const char *name;
	const struct attribute_group___71 **groups;
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
};

struct class_attribute___78;

struct class___78 {
	const char *name;
	struct module___54 *owner;
	struct class_attribute___78 *class_attrs;
	struct device_attribute___78 *dev_attrs;
	const struct attribute_group___71 **dev_groups;
	struct bin_attribute___71 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *);
	void (*class_release)(struct class___78 *);
	void (*dev_release)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
	struct subsys_private *p;
};

struct class_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct class___78 *, struct class_attribute___78 *, char *);
	ssize_t (*store)(struct class___78 *, struct class_attribute___78 *, const char *, size_t);
	const void * (*namespace)(struct class___78 *, const struct class_attribute___78 *);
};

struct device_rh___78 {
	struct dev_pm_info_rh___78 power;
};

struct cgroupfs_root___66;

struct cgroup___66 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___66 *parent;
	struct dentry___100 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___66 *subsys[11];
	struct cgroupfs_root___66 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___100 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___66 {
	struct super_block___100 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___66 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___51;

struct pmu___51 {
	struct list_head entry;
	struct device___78 *dev;
	const struct attribute_group___71 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___51 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___51 *);
	void (*pmu_disable)(struct pmu___51 *);
	int (*event_init)(struct perf_event___51 *);
	int (*add)(struct perf_event___51 *, int);
	void (*del)(struct perf_event___51 *, int);
	void (*start)(struct perf_event___51 *, int);
	void (*stop)(struct perf_event___51 *, int);
	void (*read)(struct perf_event___51 *);
	void (*start_txn)(struct pmu___51 *);
	int (*commit_txn)(struct pmu___51 *);
	void (*cancel_txn)(struct pmu___51 *);
	int (*event_idx)(struct perf_event___51 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___54 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___51 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___51 *);
};

struct perf_cpu_context___51 {
	struct perf_event_context___51 ctx;
	struct perf_event_context___51 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___51 *unique_pmu;
	struct perf_cgroup___51 *cgrp;
};

struct perf_cgroup___51 {
	struct cgroup_subsys_state___66 css;
	struct perf_cgroup_info *info;
};

struct kprobe_insn_cache___16 {
	struct mutex___100 mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct irq_chip___73 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___73 *);
	void (*irq_shutdown)(struct irq_data___73 *);
	void (*irq_enable)(struct irq_data___73 *);
	void (*irq_disable)(struct irq_data___73 *);
	void (*irq_ack)(struct irq_data___73 *);
	void (*irq_mask)(struct irq_data___73 *);
	void (*irq_mask_ack)(struct irq_data___73 *);
	void (*irq_unmask)(struct irq_data___73 *);
	void (*irq_eoi)(struct irq_data___73 *);
	int (*irq_set_affinity)(struct irq_data___73 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___73 *);
	int (*irq_set_type)(struct irq_data___73 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___73 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___73 *);
	void (*irq_bus_sync_unlock)(struct irq_data___73 *);
	void (*irq_cpu_online)(struct irq_data___73 *);
	void (*irq_cpu_offline)(struct irq_data___73 *);
	void (*irq_suspend)(struct irq_data___73 *);
	void (*irq_resume)(struct irq_data___73 *);
	void (*irq_pm_shutdown)(struct irq_data___73 *);
	void (*irq_print_chip)(struct irq_data___73 *, struct seq_file___75 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___73 *, void *);
	long unsigned int flags;
};

struct trace_array___9;

struct tracer___9;

struct trace_buffer___9;

struct trace_iterator___41 {
	struct trace_array___9 *tr;
	struct tracer___9 *trace;
	struct trace_buffer___9 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___100 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_array_cpu___9;

struct trace_buffer___9 {
	struct trace_array___9 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu___9 *data;
	cycle_t time_start;
	int cpu;
};

struct trace_cpu___9 {
	struct trace_array___9 *tr;
	struct dentry___100 *dir;
	int cpu;
};

struct trace_array___9 {
	struct list_head list;
	char *name;
	struct trace_buffer___9 trace_buffer;
	struct trace_buffer___9 max_buffer;
	bool allocated_snapshot;
	int buffer_disabled;
	struct trace_cpu___9 trace_cpu;
	int sys_refcount_enter;
	int sys_refcount_exit;
	long unsigned int enabled_enter_syscalls[6];
	long unsigned int enabled_exit_syscalls[6];
	int stop_count;
	int clock_id;
	struct tracer___9 *current_trace;
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___100 *dir;
	struct dentry___100 *options;
	struct dentry___100 *percpu_dir;
	struct dentry___100 *event_dir;
	struct list_head systems;
	struct list_head events;
	struct task_struct___99 *waiter;
	int ref;
};

struct tracer___9 {
	const char *name;
	int (*init)(struct trace_array___9 *);
	void (*reset)(struct trace_array___9 *);
	void (*start)(struct trace_array___9 *);
	void (*stop)(struct trace_array___9 *);
	void (*open)(struct trace_iterator___41 *);
	void (*pipe_open)(struct trace_iterator___41 *);
	int (*wait_pipe)(struct trace_iterator___41 *);
	void (*close)(struct trace_iterator___41 *);
	void (*pipe_close)(struct trace_iterator___41 *);
	ssize_t (*read)(struct trace_iterator___41 *, struct file___99 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___41 *, struct file___99 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___75 *);
	enum print_line_t (*print_line)(struct trace_iterator___41 *);
	int (*set_flag)(u32, u32, int);
	int (*flag_changed)(struct tracer___9 *, u32, int);
	struct tracer___9 *next;
	struct tracer_flags *flags;
	bool print_max;
	bool enabled;
	bool use_max_tr;
};

typedef enum print_line_t (*trace_print_func___41)(struct trace_iterator___41 *, int, struct trace_event___41 *);

struct trace_event_functions___41 {
	trace_print_func___41 trace;
	trace_print_func___41 raw;
	trace_print_func___41 hex;
	trace_print_func___41 binary;
};

struct ftrace_event_class___41 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___41 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___41 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___41 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___41 *);
};

struct trace_array_cpu___9 {
	struct trace_cpu___9 trace_cpu;
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	cycle_t preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
};

struct uprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int vaddr[0];
};

struct trace_uprobe_filter {
	rwlock_t rwlock;
	int nr_systemwide;
	struct list_head perf_events;
};

struct trace_uprobe {
	struct list_head list;
	struct ftrace_event_class___41 class;
	struct ftrace_event_call___41 call;
	struct trace_uprobe_filter filter;
	struct uprobe_consumer consumer;
	struct inode___100 *inode;
	char *filename;
	long unsigned int offset;
	long unsigned int nhit;
	unsigned int flags;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

typedef bool (*filter_func_t)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___104 *);

struct page___100;

typedef struct page___100 *pgtable_t___100;

struct address_space___100;

struct kmem_cache___88;

struct page___100 {
	long unsigned int flags;
	struct address_space___100 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___100 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___100 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___88 *slab_cache;
		struct page___100 *first_page;
	};
	long: 64;
};

struct thread_struct___52;

struct task_struct___100;

struct pv_cpu_ops___100 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___52 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___52 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___100 *);
	void (*end_context_switch)(struct task_struct___100 *);
};

struct perf_event___52;

struct thread_struct___52 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___52 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___57;

struct pid_link___57 {
	struct hlist_node node;
	struct pid___57 *pid;
};

struct mutex___101 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___100 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___96 {
	struct page___100 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___105;

struct nsproxy___58;

struct signal_struct___100;

struct css_set___67;

struct perf_event_context___52;

struct task_struct___100 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___100 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___105 *mm;
	struct mm_struct___105 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___100 *real_parent;
	struct task_struct___100 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___100 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___57 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___100 = 0,
		VTIME_USER___100 = 1,
		VTIME_SYS___100 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___52 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___58 *nsproxy;
	struct signal_struct___100 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___67 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___52 *perf_event_ctxp[2];
	struct mutex___101 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___96 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___105 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___105 *, struct mm_struct___105 *);
	void (*dup_mmap)(struct mm_struct___105 *, struct mm_struct___105 *);
	void (*exit_mmap)(struct mm_struct___105 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___105 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___105 *);
	void (*pgd_free)(struct mm_struct___105 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___105 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___105 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___105 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___105 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___105 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___105 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___105 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___105 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___105 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___105 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___105 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___101 lock;
	void *vdso;
} mm_context_t___101;

struct xol_area___100;

struct uprobes_state___100 {
	struct xol_area___100 *xol_area;
};

struct vm_area_struct___105;

struct file___100;

struct core_state___100;

struct mm_struct___105 {
	struct vm_area_struct___105 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___105 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___105 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___101 context;
	long unsigned int flags;
	struct core_state___100 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___100 *owner;
	struct file___100 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___100 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___55;

struct exec_domain___27 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___55 *module;
	struct exec_domain___27 *next;
};

struct module_kobject___54 {
	struct kobject kobj;
	struct module___55 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___54;

struct ftrace_event_call___42;

struct module___55 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___54 mkobj;
	struct module_attribute___54 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___42 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___100 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___52 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___100 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___100 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___100 *target;
};

typedef void (*perf_overflow_handler_t___52)(struct perf_event___52 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___52;

typedef void (*ftrace_func_t___52)(long unsigned int, long unsigned int, struct ftrace_ops___52 *, struct pt_regs *);

struct ftrace_ops___52 {
	ftrace_func_t___52 func;
	struct ftrace_ops___52 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___101 regex_lock;
};

struct pmu___52;

struct fasync_struct___100;

struct pid_namespace___57;

struct perf_cgroup___52;

struct perf_event___52 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___52 *group_leader;
	struct pmu___52 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___52 hw;
	struct perf_event_context___52 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___101 child_mutex;
	struct list_head child_list;
	struct perf_event___52 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___100 *owner;
	struct mutex___101 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___100 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___52 *);
	struct callback_head callback_head;
	struct pid_namespace___57 *ns;
	u64 id;
	perf_overflow_handler_t___52 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___42 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___52 ftrace_ops;
	struct perf_cgroup___52 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___50 {
	struct task_struct___100 *task;
	struct exec_domain___27 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___101;

struct dentry_operations___100;

struct super_block___101;

struct dentry___101 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___101 *d_parent;
	struct qstr d_name;
	struct inode___101 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___100 *d_op;
	struct super_block___101 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___100;

struct address_space___100 {
	struct inode___101 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___101 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___100 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___100;

struct file_operations___100;

struct file_lock___100;

struct dquot___100;

struct block_device___100;

struct inode___101 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___100 *i_op;
	struct super_block___101 *i_sb;
	struct address_space___100 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___101 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___100 *i_fop;
	struct file_lock___100 *i_flock;
	struct address_space___100 i_data;
	struct dquot___100 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___100 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___100;

struct dentry_operations___100 {
	int (*d_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_hash)(const struct dentry___101 *, struct qstr *);
	int (*d_compare)(const struct dentry___101 *, const struct dentry___101 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___101 *);
	void (*d_release)(struct dentry___101 *);
	void (*d_prune)(struct dentry___101 *);
	void (*d_iput)(struct dentry___101 *, struct inode___101 *);
	char * (*d_dname)(struct dentry___101 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___100 *);
	int (*d_manage)(struct dentry___101 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___100;

struct mem_dqinfo___100 {
	struct quota_format_type___100 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___100;

struct quota_info___100 {
	unsigned int flags;
	struct mutex___101 dqio_mutex;
	struct mutex___101 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___101 *files[2];
	struct mem_dqinfo___100 info[2];
	const struct quota_format_ops___100 *ops[2];
};

struct file_system_type___100;

struct super_operations___100;

struct dquot_operations___100;

struct quotactl_ops___100;

struct xattr_handler___67;

struct super_block___101 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___100 *s_type;
	const struct super_operations___100 *s_op;
	const struct dquot_operations___100 *dq_op;
	const struct quotactl_ops___100 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___101 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___67 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___100 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___100 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___101 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___100 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___100 {
	struct vfsmount *mnt;
	struct dentry___101 *dentry;
};

struct upid___57 {
	int nr;
	struct pid_namespace___57 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___57 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___100 *child_reaper;
	struct kmem_cache___88 *pid_cachep;
	unsigned int level;
	struct pid_namespace___57 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___101 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___57 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___57 numbers[1];
};

struct irq_data___74;

struct x86_io_apic_ops___74 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___74 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___74;

struct irq_data___74 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___74 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___79;

struct dev_pm_ops___79 {
	int (*prepare)(struct device___79 *);
	void (*complete)(struct device___79 *);
	int (*suspend)(struct device___79 *);
	int (*resume)(struct device___79 *);
	int (*freeze)(struct device___79 *);
	int (*thaw)(struct device___79 *);
	int (*poweroff)(struct device___79 *);
	int (*restore)(struct device___79 *);
	int (*suspend_late)(struct device___79 *);
	int (*resume_early)(struct device___79 *);
	int (*freeze_late)(struct device___79 *);
	int (*thaw_early)(struct device___79 *);
	int (*poweroff_late)(struct device___79 *);
	int (*restore_early)(struct device___79 *);
	int (*suspend_noirq)(struct device___79 *);
	int (*resume_noirq)(struct device___79 *);
	int (*freeze_noirq)(struct device___79 *);
	int (*thaw_noirq)(struct device___79 *);
	int (*poweroff_noirq)(struct device___79 *);
	int (*restore_noirq)(struct device___79 *);
	int (*runtime_suspend)(struct device___79 *);
	int (*runtime_resume)(struct device___79 *);
	int (*runtime_idle)(struct device___79 *);
};

struct device_type___79;

struct bus_type___79;

struct device_driver___79;

struct dev_pm_domain___79;

struct class___79;

struct attribute_group___72;

struct device_rh___79;

struct device___79 {
	struct device___79 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___79 *type;
	struct mutex___101 mutex;
	struct bus_type___79 *bus;
	struct device_driver___79 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___79 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___14 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___79 *class;
	const struct attribute_group___72 **groups;
	void (*release)(struct device___79 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___79 *device_rh;
};

struct dev_pm_info_rh___79 {
	void (*set_latency_tolerance)(struct device___79 *, s32);
};

struct dev_pm_domain___79 {
	struct dev_pm_ops___79 ops;
};

struct smp_ops___100 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___100 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___100 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___101 *bd_inode;
	struct super_block___101 *bd_super;
	struct mutex___101 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___100 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___101 bd_fsfreeze_mutex;
};

struct cgroup___67;

struct cgroup_subsys_state___67 {
	struct cgroup___67 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___101 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___100 *ia_file;
};

struct fown_struct___57 {
	rwlock_t lock;
	struct pid___57 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___100 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___100 f_path;
	struct inode___101 *f_inode;
	const struct file_operations___100 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___57 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___100 *f_mapping;
	struct mutex___101 f_pos_lock;
};

struct zone___100;

struct lruvec___100 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___100 *zone;
};

struct pglist_data___100;

struct zone___100 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___100 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___100 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___100 {
	struct zone___100 *zone;
	int zone_idx;
};

struct zonelist___100 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___100 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___100 {
	struct zone___100 node_zones[4];
	struct zonelist___100 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___100 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___100 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___101 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___101 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___100 {
	int qf_fmt_id;
	const struct quota_format_ops___100 *qf_ops;
	struct module___55 *qf_owner;
	struct quota_format_type___100 *qf_next;
};

struct quota_format_ops___100 {
	int (*check_quota_file)(struct super_block___101 *, int);
	int (*read_file_info)(struct super_block___101 *, int);
	int (*write_file_info)(struct super_block___101 *, int);
	int (*free_file_info)(struct super_block___101 *, int);
	int (*read_dqblk)(struct dquot___100 *);
	int (*commit_dqblk)(struct dquot___100 *);
	int (*release_dqblk)(struct dquot___100 *);
};

struct dquot_operations___100 {
	int (*write_dquot)(struct dquot___100 *);
	struct dquot___100 * (*alloc_dquot)(struct super_block___101 *, int);
	void (*destroy_dquot)(struct dquot___100 *);
	int (*acquire_dquot)(struct dquot___100 *);
	int (*release_dquot)(struct dquot___100 *);
	int (*mark_dirty)(struct dquot___100 *);
	int (*write_info)(struct super_block___101 *, int);
	qsize_t * (*get_reserved_space)(struct inode___101 *);
};

struct quotactl_ops___100 {
	int (*quota_on)(struct super_block___101 *, int, int, struct path___100 *);
	int (*quota_on_meta)(struct super_block___101 *, int, int);
	int (*quota_off)(struct super_block___101 *, int);
	int (*quota_sync)(struct super_block___101 *, int);
	int (*get_info)(struct super_block___101 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___101 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___101 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___101 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___101 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___101 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___101 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___101 *, unsigned int);
};

struct address_space_operations___100 {
	int (*writepage)(struct page___100 *, struct writeback_control *);
	int (*readpage)(struct file___100 *, struct page___100 *);
	int (*writepages)(struct address_space___100 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___100 *);
	int (*readpages)(struct file___100 *, struct address_space___100 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___100 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___100 **, void **);
	int (*write_end)(struct file___100 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___100 *, void *);
	sector_t (*bmap)(struct address_space___100 *, sector_t);
	void (*invalidatepage)(struct page___100 *, long unsigned int);
	int (*releasepage)(struct page___100 *, gfp_t);
	void (*freepage)(struct page___100 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___100 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___100 *, struct page___100 *, struct page___100 *, enum migrate_mode);
	int (*launder_page)(struct page___100 *);
	int (*is_partially_uptodate)(struct page___100 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___100 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___100 *, struct page___100 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___100 *, sector_t *);
	void (*swap_deactivate)(struct file___100 *);
	void (*invalidatepage_range)(struct page___100 *, unsigned int, unsigned int);
};

struct inode_operations___100 {
	struct dentry___101 * (*lookup)(struct inode___101 *, struct dentry___101 *, unsigned int);
	void * (*follow_link)(struct dentry___101 *, struct nameidata *);
	int (*permission)(struct inode___101 *, int);
	struct posix_acl * (*get_acl)(struct inode___101 *, int);
	int (*readlink)(struct dentry___101 *, char *, int);
	void (*put_link)(struct dentry___101 *, struct nameidata *, void *);
	int (*create)(struct inode___101 *, struct dentry___101 *, umode_t, bool);
	int (*link)(struct dentry___101 *, struct inode___101 *, struct dentry___101 *);
	int (*unlink)(struct inode___101 *, struct dentry___101 *);
	int (*symlink)(struct inode___101 *, struct dentry___101 *, const char *);
	int (*mkdir)(struct inode___101 *, struct dentry___101 *, umode_t);
	int (*rmdir)(struct inode___101 *, struct dentry___101 *);
	int (*mknod)(struct inode___101 *, struct dentry___101 *, umode_t, dev_t);
	int (*rename)(struct inode___101 *, struct dentry___101 *, struct inode___101 *, struct dentry___101 *);
	int (*setattr)(struct dentry___101 *, struct iattr___101 *);
	int (*getattr)(struct vfsmount *, struct dentry___101 *, struct kstat *);
	int (*setxattr)(struct dentry___101 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___101 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___101 *, char *, size_t);
	int (*removexattr)(struct dentry___101 *, const char *);
	int (*fiemap)(struct inode___101 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___101 *, struct timespec *, int);
	int (*atomic_open)(struct inode___101 *, struct dentry___101 *, struct file___100 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___64;

struct seq_file___76;

struct file_operations___100 {
	struct module___55 *owner;
	loff_t (*llseek)(struct file___100 *, loff_t, int);
	ssize_t (*read)(struct file___100 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___100 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___100 *, void *, filldir_t);
	unsigned int (*poll)(struct file___100 *, struct poll_table_struct___64 *);
	long int (*unlocked_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___100 *, struct vm_area_struct___105 *);
	int (*open)(struct inode___101 *, struct file___100 *);
	int (*flush)(struct file___100 *, fl_owner_t);
	int (*release)(struct inode___101 *, struct file___100 *);
	int (*fsync)(struct file___100 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___100 *, int);
	int (*lock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*sendpage)(struct file___100 *, struct page___100 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___100 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___100 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___100 *, long int, struct file_lock___100 **, void **);
		struct {
			int (*setlease)(struct file___100 *, long int, struct file_lock___100 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___100 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___76 *, struct file___100 *);
};

struct file_lock_operations___100;

struct lock_manager_operations___100;

struct file_lock___100 {
	struct file_lock___100 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___57 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___100 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___100 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___100 *fl_ops;
	const struct lock_manager_operations___100 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___100 {
	void (*fl_copy_lock)(struct file_lock___100 *, struct file_lock___100 *);
	void (*fl_release_private)(struct file_lock___100 *);
};

struct lock_manager_operations___100 {
	int (*lm_compare_owner)(struct file_lock___100 *, struct file_lock___100 *);
	long unsigned int (*lm_owner_key)(struct file_lock___100 *);
	void (*lm_notify)(struct file_lock___100 *);
	int (*lm_grant)(struct file_lock___100 *, struct file_lock___100 *, int);
	void (*lm_break)(struct file_lock___100 *);
	int (*lm_change)(struct file_lock___100 **, int);
};

struct fasync_struct___100 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___100 *fa_next;
	struct file___100 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___100 {
	const char *name;
	int fs_flags;
	struct dentry___101 * (*mount)(struct file_system_type___100 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___101 *);
	struct module___55 *owner;
	struct file_system_type___100 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___100 {
	struct inode___101 * (*alloc_inode)(struct super_block___101 *);
	void (*destroy_inode)(struct inode___101 *);
	void (*dirty_inode)(struct inode___101 *, int);
	int (*write_inode)(struct inode___101 *, struct writeback_control *);
	int (*drop_inode)(struct inode___101 *);
	void (*evict_inode)(struct inode___101 *);
	void (*put_super)(struct super_block___101 *);
	int (*sync_fs)(struct super_block___101 *, int);
	int (*freeze_fs)(struct super_block___101 *);
	int (*unfreeze_fs)(struct super_block___101 *);
	int (*statfs)(struct dentry___101 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___101 *, int *, char *);
	void (*umount_begin)(struct super_block___101 *);
	int (*show_options)(struct seq_file___76 *, struct dentry___101 *);
	int (*show_devname)(struct seq_file___76 *, struct dentry___101 *);
	int (*show_path)(struct seq_file___76 *, struct dentry___101 *);
	int (*show_stats)(struct seq_file___76 *, struct dentry___101 *);
	ssize_t (*quota_read)(struct super_block___101 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___101 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___101 *);
	int (*bdev_try_to_free_page)(struct super_block___101 *, struct page___100 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___101 *);
	void (*free_cached_objects)(struct super_block___101 *, int);
};

struct xattr_handler___67 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___101 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___101 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___101 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___65)(struct file___100 *, wait_queue_head_t *, struct poll_table_struct___64 *);

struct poll_table_struct___64 {
	poll_queue_proc___65 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___88;

struct vm_area_struct___105 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___105 *vm_next;
	struct vm_area_struct___105 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___105 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___88 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___100 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___75;

struct seq_file___76 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___101 lock;
	const struct seq_operations___75 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___100 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___100 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___88;

struct memcg_cache_params___88;

struct kmem_cache___88 {
	struct kmem_cache_cpu___88 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___88 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___85;

struct vm_operations_struct___88 {
	void (*open)(struct vm_area_struct___105 *);
	void (*close)(struct vm_area_struct___105 *);
	int (*fault)(struct vm_area_struct___105 *, struct vm_fault___85 *);
	int (*page_mkwrite)(struct vm_area_struct___105 *, struct vm_fault___85 *);
	int (*access)(struct vm_area_struct___105 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___105 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___105 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___105 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___105 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___100 {
	struct task_struct___100 *task;
	struct core_thread___100 *next;
};

struct core_state___100 {
	atomic_t nr_threads;
	struct core_thread___100 dumper;
	struct completion startup;
};

struct vm_fault___85 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___100 *page;
};

struct bin_attribute___72;

struct attribute_group___72 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___72 **bin_attrs;
};

struct bin_attribute___72 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___100 *, struct kobject *, struct bin_attribute___72 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___100 *, struct kobject *, struct bin_attribute___72 *, char *, loff_t, size_t);
	int (*mmap)(struct file___100 *, struct kobject *, struct bin_attribute___72 *, struct vm_area_struct___105 *);
};

struct bus_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___79 *, char *);
	ssize_t (*store)(struct bus_type___79 *, const char *, size_t);
};

struct device_attribute___79;

struct driver_attribute___79;

struct bus_type___79 {
	const char *name;
	const char *dev_name;
	struct device___79 *dev_root;
	struct bus_attribute___79 *bus_attrs;
	struct device_attribute___79 *dev_attrs;
	struct driver_attribute___79 *drv_attrs;
	const struct attribute_group___72 **bus_groups;
	const struct attribute_group___72 **dev_groups;
	const struct attribute_group___72 **drv_groups;
	int (*match)(struct device___79 *, struct device_driver___79 *);
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	int (*probe)(struct device___79 *);
	int (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*online)(struct device___79 *);
	int (*offline)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct device___79 *, struct device_attribute___79 *, char *);
	ssize_t (*store)(struct device___79 *, struct device_attribute___79 *, const char *, size_t);
};

struct driver_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___79 *, char *);
	ssize_t (*store)(struct device_driver___79 *, const char *, size_t);
};

struct device_driver___79 {
	const char *name;
	struct bus_type___79 *bus;
	struct module___55 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___79 *);
	int (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	const struct attribute_group___72 **groups;
	const struct dev_pm_ops___79 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___79 {
	const char *name;
	const struct attribute_group___72 **groups;
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
};

struct class_attribute___79;

struct class___79 {
	const char *name;
	struct module___55 *owner;
	struct class_attribute___79 *class_attrs;
	struct device_attribute___79 *dev_attrs;
	const struct attribute_group___72 **dev_groups;
	struct bin_attribute___72 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *);
	void (*class_release)(struct class___79 *);
	void (*dev_release)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
	struct subsys_private *p;
};

struct class_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct class___79 *, struct class_attribute___79 *, char *);
	ssize_t (*store)(struct class___79 *, struct class_attribute___79 *, const char *, size_t);
	const void * (*namespace)(struct class___79 *, const struct class_attribute___79 *);
};

struct device_rh___79 {
	struct dev_pm_info_rh___79 power;
};

struct fd___4 {
	struct file___100 *file;
	unsigned int flags;
};

struct nsproxy___58 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___57 *pid_ns;
	struct net *net_ns;
};

typedef struct poll_table_struct___64 poll_table___8;

struct kmem_cache_cpu___88 {
	void **freelist;
	long unsigned int tid;
	struct page___100 *page;
	struct page___100 *partial;
};

struct memcg_cache_params___88 {
	bool is_root_cache;
	union {
		struct kmem_cache___88 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___88 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___100 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___100 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___100 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___57 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___57 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___101 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___67 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___67 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___52 {
	struct pmu___52 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___101 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___100 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___52 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct irq_chip___74 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___74 *);
	void (*irq_shutdown)(struct irq_data___74 *);
	void (*irq_enable)(struct irq_data___74 *);
	void (*irq_disable)(struct irq_data___74 *);
	void (*irq_ack)(struct irq_data___74 *);
	void (*irq_mask)(struct irq_data___74 *);
	void (*irq_mask_ack)(struct irq_data___74 *);
	void (*irq_unmask)(struct irq_data___74 *);
	void (*irq_eoi)(struct irq_data___74 *);
	int (*irq_set_affinity)(struct irq_data___74 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___74 *);
	int (*irq_set_type)(struct irq_data___74 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___74 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___74 *);
	void (*irq_bus_sync_unlock)(struct irq_data___74 *);
	void (*irq_cpu_online)(struct irq_data___74 *);
	void (*irq_cpu_offline)(struct irq_data___74 *);
	void (*irq_suspend)(struct irq_data___74 *);
	void (*irq_resume)(struct irq_data___74 *);
	void (*irq_pm_shutdown)(struct irq_data___74 *);
	void (*irq_print_chip)(struct irq_data___74 *, struct seq_file___76 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___74 *, void *);
	long unsigned int flags;
};

struct seq_operations___75 {
	void * (*start)(struct seq_file___76 *, loff_t *);
	void (*stop)(struct seq_file___76 *, void *);
	void * (*next)(struct seq_file___76 *, void *, loff_t *);
	int (*show)(struct seq_file___76 *, void *);
};

enum perf_event_read_format {
	PERF_FORMAT_TOTAL_TIME_ENABLED = 1,
	PERF_FORMAT_TOTAL_TIME_RUNNING = 2,
	PERF_FORMAT_ID = 4,
	PERF_FORMAT_GROUP = 8,
	PERF_FORMAT_MAX = 16,
};

enum perf_event_ioc_flags {
	PERF_IOC_FLAG_GROUP = 1,
};

enum perf_event_type {
	PERF_RECORD_MMAP = 1,
	PERF_RECORD_LOST = 2,
	PERF_RECORD_COMM = 3,
	PERF_RECORD_EXIT = 4,
	PERF_RECORD_THROTTLE = 5,
	PERF_RECORD_UNTHROTTLE = 6,
	PERF_RECORD_FORK = 7,
	PERF_RECORD_READ = 8,
	PERF_RECORD_SAMPLE = 9,
	PERF_RECORD_MMAP2 = 10,
	PERF_RECORD_MAX = 11,
};

struct cgroupfs_root___67;

struct cgroup___67 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___67 *parent;
	struct dentry___101 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___67 *subsys[11];
	struct cgroupfs_root___67 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___101 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___67 {
	struct super_block___101 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___67 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___25 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___101 *, struct file___100 *);
	ssize_t (*read)(struct cgroup___67 *, struct cftype___25 *, struct file___100 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___67 *, struct cftype___25 *);
	s64 (*read_s64)(struct cgroup___67 *, struct cftype___25 *);
	int (*read_map)(struct cgroup___67 *, struct cftype___25 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___67 *, struct cftype___25 *, struct seq_file___76 *);
	ssize_t (*write)(struct cgroup___67 *, struct cftype___25 *, struct file___100 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___67 *, struct cftype___25 *, u64);
	int (*write_s64)(struct cgroup___67 *, struct cftype___25 *, s64);
	int (*write_string)(struct cgroup___67 *, struct cftype___25 *, const char *);
	int (*trigger)(struct cgroup___67 *, unsigned int);
	int (*release)(struct inode___101 *, struct file___100 *);
	int (*register_event)(struct cgroup___67 *, struct cftype___25 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___67 *, struct cftype___25 *, struct eventfd_ctx *);
};

struct cftype_set___23 {
	struct list_head node;
	struct cftype___25 *cfts;
};

struct task_and_cgroup___23 {
	struct task_struct___100 *task;
	struct cgroup___67 *cgrp;
	struct css_set___67 *cg;
};

struct cgroup_taskset___23 {
	struct task_and_cgroup___23 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___67 *cur_cgrp;
};

struct cgroup_subsys___23 {
	struct cgroup_subsys_state___67 * (*css_alloc)(struct cgroup___67 *);
	int (*css_online)(struct cgroup___67 *);
	void (*css_offline)(struct cgroup___67 *);
	void (*css_free)(struct cgroup___67 *);
	int (*can_attach)(struct cgroup___67 *, struct cgroup_taskset___23 *);
	void (*cancel_attach)(struct cgroup___67 *, struct cgroup_taskset___23 *);
	void (*attach)(struct cgroup___67 *, struct cgroup_taskset___23 *);
	void (*fork)(struct task_struct___100 *);
	void (*exit)(struct cgroup___67 *, struct cgroup___67 *, struct task_struct___100 *);
	void (*bind)(struct cgroup___67 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___67 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___25 *base_cftypes;
	struct cftype_set___23 base_cftset;
	struct module___55 *module;
};

struct perf_cpu_context___52;

struct pmu___52 {
	struct list_head entry;
	struct device___79 *dev;
	const struct attribute_group___72 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___52 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___52 *);
	void (*pmu_disable)(struct pmu___52 *);
	int (*event_init)(struct perf_event___52 *);
	int (*add)(struct perf_event___52 *, int);
	void (*del)(struct perf_event___52 *, int);
	void (*start)(struct perf_event___52 *, int);
	void (*stop)(struct perf_event___52 *, int);
	void (*read)(struct perf_event___52 *);
	void (*start_txn)(struct pmu___52 *);
	int (*commit_txn)(struct pmu___52 *);
	void (*cancel_txn)(struct pmu___52 *);
	int (*event_idx)(struct perf_event___52 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___55 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___52 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___52 *);
};

struct perf_cpu_context___52 {
	struct perf_event_context___52 ctx;
	struct perf_event_context___52 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___52 *unique_pmu;
	struct perf_cgroup___52 *cgrp;
};

enum perf_group_flag {
	PERF_GROUP_SOFTWARE = 1,
};

struct swevent_hlist {
	struct hlist_head heads[256];
	struct callback_head callback_head;
};

struct ring_buffer {
	atomic_t refcount;
	struct callback_head callback_head;
	int nr_pages;
	int overwrite;
	atomic_t poll;
	local_t head;
	local_t nest;
	local_t events;
	local_t wakeup;
	local_t lost;
	long int watermark;
	spinlock_t event_lock;
	struct list_head event_list;
	atomic_t mmap_count;
	long unsigned int mmap_locked;
	struct user_struct *mmap_user;
	struct perf_event_mmap_page *user_page;
	void *data_pages[0];
};

struct trace_event_functions___42;

struct trace_event___42 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___42 *funcs;
};

struct ftrace_event_class___42;

struct ftrace_event_call___42 {
	struct list_head list;
	struct ftrace_event_class___42 *class;
	char *name;
	struct trace_event___42 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___52 {
	struct cgroup_subsys_state___67 css;
	struct perf_cgroup_info *info;
};

struct perf_output_handle___2 {
	struct perf_event___52 *event;
	struct ring_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	void *addr;
	int page;
};

struct perf_pmu_events_attr___4 {
	struct device_attribute___79 attr;
	u64 id;
	const char *event_str;
};

struct trace_iterator___42 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___101 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___42)(struct trace_iterator___42 *, int, struct trace_event___42 *);

struct trace_event_functions___42 {
	trace_print_func___42 trace;
	trace_print_func___42 raw;
	trace_print_func___42 hex;
	trace_print_func___42 binary;
};

struct ftrace_event_class___42 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___42 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___42 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___42 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___42 *);
};

struct syscall_metadata___14 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___42 *enter_event;
	struct ftrace_event_call___42 *exit_event;
};

struct module_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___54 *, struct module_kobject___54 *, char *);
	ssize_t (*store)(struct module_attribute___54 *, struct module_kobject___54 *, const char *, size_t);
	void (*setup)(struct module___55 *, const char *);
	int (*test)(struct module___55 *);
	void (*free)(struct module___55 *);
};

struct remote_function_call {
	struct task_struct___100 *p;
	int (*func)(void *);
	void *info;
	int ret;
};

enum event_type_t {
	EVENT_FLEXIBLE = 1,
	EVENT_PINNED = 2,
	EVENT_ALL = 3,
};

struct remove_event {
	struct perf_event___52 *event;
	bool detach_group;
};

struct perf_read_event {
	struct perf_event_header header;
	u32 pid;
	u32 tid;
};

typedef void perf_event_aux_output_cb(struct perf_event___52 *, void *);

struct perf_task_event {
	struct task_struct___100 *task;
	struct perf_event_context___52 *task_ctx;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 ppid;
		u32 tid;
		u32 ptid;
		u64 time;
	} event_id;
};

struct perf_comm_event {
	struct task_struct___100 *task;
	char *comm;
	int comm_size;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
	} event_id;
};

struct perf_mmap_event {
	struct vm_area_struct___105 *vma;
	const char *file_name;
	int file_size;
	int maj;
	int min;
	u64 ino;
	u64 ino_generation;
	u32 prot;
	u32 flags;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
		u64 start;
		u64 len;
		u64 pgoff;
	} event_id;
};

struct swevent_htable {
	struct swevent_hlist *swevent_hlist;
	struct mutex___101 hlist_mutex;
	int hlist_refcount;
	int recursion[4];
	bool online;
};

struct perf_output_handle___3 {
	struct perf_event___49 *event;
	struct ring_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	void *addr;
	int page;
};

enum perf_callchain_context {
	PERF_CONTEXT_HV = 4294967264,
	PERF_CONTEXT_KERNEL = 4294967168,
	PERF_CONTEXT_USER = 4294966784,
	PERF_CONTEXT_GUEST = 4294965248,
	PERF_CONTEXT_GUEST_KERNEL = 4294965120,
	PERF_CONTEXT_GUEST_USER = 4294964736,
	PERF_CONTEXT_MAX = 4294963201,
};

struct callchain_cpus_entries {
	struct callback_head callback_head;
	struct perf_callchain_entry *cpu_entries[0];
};

enum bp_type_idx {
	TYPE_INST = 0,
	TYPE_DATA = 0,
	TYPE_MAX = 1,
};

struct bp_cpuinfo {
	unsigned int cpu_pinned;
	unsigned int *tsk_pinned;
	unsigned int flexible;
};

struct bp_busy_slots {
	unsigned int pinned;
	unsigned int flexible;
};

struct percpu_rw_semaphore {
	unsigned int *fast_read_ctr;
	atomic_t write_ctr;
	struct rw_semaphore rw_sem;
	atomic_t slow_read_ctr;
	wait_queue_head_t write_waitq;
};

typedef u8 uprobe_opcode_t;

struct uprobe {
	struct rb_node rb_node;
	atomic_t ref;
	struct rw_semaphore register_rwsem;
	struct rw_semaphore consumer_rwsem;
	struct list_head pending_list;
	struct uprobe_consumer *consumers;
	struct inode___100 *inode;
	loff_t offset;
	long unsigned int flags;
	struct arch_uprobe arch;
};

typedef int filler_t(void *, struct page___99 *);

struct map_info {
	struct map_info *next;
	struct mm_struct___104 *mm;
	long unsigned int vaddr;
};

struct user_return_notifier {
	void (*on_user_return)(struct user_return_notifier *);
	struct hlist_node link;
};

struct parallel_data;

struct padata_priv {
	struct list_head list;
	struct parallel_data *pd;
	int cb_cpu;
	int info;
	void (*parallel)(struct padata_priv *);
	void (*serial)(struct padata_priv *);
};

struct padata_cpumask {
	cpumask_var_t pcpu;
	cpumask_var_t cbcpu;
};

struct padata_instance;

struct padata_parallel_queue;

struct padata_serial_queue;

struct parallel_data {
	struct padata_instance *pinst;
	struct padata_parallel_queue *pqueue;
	struct padata_serial_queue *squeue;
	atomic_t reorder_objects;
	atomic_t refcnt;
	struct padata_cpumask cpumask;
	long: 64;
	long: 64;
	spinlock_t lock;
	spinlock_t seq_lock;
	unsigned int seq_nr;
	unsigned int processed;
	struct timer_list timer;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct padata_list {
	struct list_head list;
	spinlock_t lock;
};

struct padata_serial_queue {
	struct padata_list serial;
	struct work_struct work;
	struct parallel_data *pd;
};

struct padata_parallel_queue {
	struct padata_list parallel;
	struct padata_list reorder;
	struct parallel_data *pd;
	struct work_struct work;
	atomic_t num_obj;
	int cpu_index;
};

struct padata_instance {
	struct notifier_block cpu_notifier;
	struct workqueue_struct *wq;
	struct parallel_data *pd;
	struct padata_cpumask cpumask;
	struct blocking_notifier_head cpumask_change_notifier;
	struct kobject kobj;
	struct mutex___91 lock;
	u8 flags;
};

struct padata_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct padata_instance *, struct attribute *, char *);
	ssize_t (*store)(struct padata_instance *, struct attribute *, const char *, size_t);
};

struct static_key_mod {
	struct static_key_mod *next;
	struct jump_entry *entries;
	struct module___55 *mod;
};

struct ftrace_raw_context_tracking_user {
	struct trace_entry ent;
	int dummy;
	char __data[0];
};

struct ftrace_data_offsets_context_tracking_user {};

typedef enum ctx_state pto_T_____8;

struct page___101;

typedef struct page___101 *pgtable_t___101;

struct address_space___101;

struct kmem_cache___89;

struct page___101 {
	long unsigned int flags;
	struct address_space___101 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___101 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___101 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___89 *slab_cache;
		struct page___101 *first_page;
	};
	long: 64;
};

struct thread_struct___53;

struct task_struct___101;

struct pv_cpu_ops___101 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___53 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___53 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___101 *);
	void (*end_context_switch)(struct task_struct___101 *);
};

struct perf_event___53;

struct thread_struct___53 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___53 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___58;

struct pid_link___58 {
	struct hlist_node node;
	struct pid___58 *pid;
};

struct mutex___102 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___101 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___97 {
	struct page___101 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___106;

struct nsproxy___59;

struct signal_struct___101;

struct bio_list___10;

struct backing_dev_info___13;

struct io_context___10;

struct css_set___68;

struct perf_event_context___53;

struct task_struct___101 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___101 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___106 *mm;
	struct mm_struct___106 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___101 *real_parent;
	struct task_struct___101 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___101 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___58 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___101 = 0,
		VTIME_USER___101 = 1,
		VTIME_SYS___101 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___53 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___59 *nsproxy;
	struct signal_struct___101 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___10 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___13 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___68 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___53 *perf_event_ctxp[2];
	struct mutex___102 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___97 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___106 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___106 *, struct mm_struct___106 *);
	void (*dup_mmap)(struct mm_struct___106 *, struct mm_struct___106 *);
	void (*exit_mmap)(struct mm_struct___106 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___106 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___106 *);
	void (*pgd_free)(struct mm_struct___106 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___106 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___106 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___106 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___106 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___106 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___106 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___106 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___106 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___106 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___106 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___106 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___102 lock;
	void *vdso;
} mm_context_t___102;

struct xol_area___101;

struct uprobes_state___101 {
	struct xol_area___101 *xol_area;
};

struct vm_area_struct___106;

struct file___101;

struct core_state___101;

struct mm_struct___106 {
	struct vm_area_struct___106 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___106 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___106 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___102 context;
	long unsigned int flags;
	struct core_state___101 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___101 *owner;
	struct file___101 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___101 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___53 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___101 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___101 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___101 *target;
};

typedef void (*perf_overflow_handler_t___53)(struct perf_event___53 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___53;

typedef void (*ftrace_func_t___53)(long unsigned int, long unsigned int, struct ftrace_ops___53 *, struct pt_regs *);

struct ftrace_ops___53 {
	ftrace_func_t___53 func;
	struct ftrace_ops___53 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___102 regex_lock;
};

struct pmu___53;

struct fasync_struct___101;

struct pid_namespace___58;

struct ftrace_event_call___43;

struct perf_cgroup___53;

struct perf_event___53 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___53 *group_leader;
	struct pmu___53 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___53 hw;
	struct perf_event_context___53 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___102 child_mutex;
	struct list_head child_list;
	struct perf_event___53 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___101 *owner;
	struct mutex___102 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___101 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___53 *);
	struct callback_head callback_head;
	struct pid_namespace___58 *ns;
	u64 id;
	perf_overflow_handler_t___53 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___43 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___53 ftrace_ops;
	struct perf_cgroup___53 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___51 {
	struct task_struct___101 *task;
	struct exec_domain___27 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct dentry_operations___101;

struct dentry___2 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___2 *d_parent;
	struct qstr d_name;
	struct inode___2 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___101 *d_op;
	struct super_block___2 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___101;

struct address_space___101 {
	struct inode___2 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___102 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___101 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___13 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___101;

struct file_operations___101;

struct file_lock___101;

struct dquot___101;

struct block_device___101;

struct inode___2 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___101 *i_op;
	struct super_block___2 *i_sb;
	struct address_space___101 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___102 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___101 *i_fop;
	struct file_lock___101 *i_flock;
	struct address_space___101 i_data;
	struct dquot___101 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___101 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___101;

struct dentry_operations___101 {
	int (*d_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_hash)(const struct dentry___2 *, struct qstr *);
	int (*d_compare)(const struct dentry___2 *, const struct dentry___2 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___2 *);
	void (*d_release)(struct dentry___2 *);
	void (*d_prune)(struct dentry___2 *);
	void (*d_iput)(struct dentry___2 *, struct inode___2 *);
	char * (*d_dname)(struct dentry___2 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___101 *);
	int (*d_manage)(struct dentry___2 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___101;

struct mem_dqinfo___101 {
	struct quota_format_type___101 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___101;

struct quota_info___101 {
	unsigned int flags;
	struct mutex___102 dqio_mutex;
	struct mutex___102 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___2 *files[2];
	struct mem_dqinfo___101 info[2];
	const struct quota_format_ops___101 *ops[2];
};

struct file_system_type___101;

struct super_operations___101;

struct dquot_operations___101;

struct quotactl_ops___101;

struct xattr_handler___68;

struct super_block___2 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___101 *s_type;
	const struct super_operations___101 *s_op;
	const struct dquot_operations___101 *dq_op;
	const struct quotactl_ops___101 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___2 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___68 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___101 *s_bdev;
	struct backing_dev_info___13 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___101 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___102 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___101 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___101 {
	struct vfsmount *mnt;
	struct dentry___2 *dentry;
};

struct radix_tree_iter {
	long unsigned int index;
	long unsigned int next_index;
	long unsigned int tags;
};

struct upid___58 {
	int nr;
	struct pid_namespace___58 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___58 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___101 *child_reaper;
	struct kmem_cache___89 *pid_cachep;
	unsigned int level;
	struct pid_namespace___58 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___2 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___58 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___58 numbers[1];
};

struct irq_data___75;

struct x86_io_apic_ops___75 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___75 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___75;

struct irq_data___75 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___75 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___80;

struct dev_pm_ops___80 {
	int (*prepare)(struct device___80 *);
	void (*complete)(struct device___80 *);
	int (*suspend)(struct device___80 *);
	int (*resume)(struct device___80 *);
	int (*freeze)(struct device___80 *);
	int (*thaw)(struct device___80 *);
	int (*poweroff)(struct device___80 *);
	int (*restore)(struct device___80 *);
	int (*suspend_late)(struct device___80 *);
	int (*resume_early)(struct device___80 *);
	int (*freeze_late)(struct device___80 *);
	int (*thaw_early)(struct device___80 *);
	int (*poweroff_late)(struct device___80 *);
	int (*restore_early)(struct device___80 *);
	int (*suspend_noirq)(struct device___80 *);
	int (*resume_noirq)(struct device___80 *);
	int (*freeze_noirq)(struct device___80 *);
	int (*thaw_noirq)(struct device___80 *);
	int (*poweroff_noirq)(struct device___80 *);
	int (*restore_noirq)(struct device___80 *);
	int (*runtime_suspend)(struct device___80 *);
	int (*runtime_resume)(struct device___80 *);
	int (*runtime_idle)(struct device___80 *);
};

struct device_type___80;

struct bus_type___80;

struct device_driver___80;

struct dev_pm_domain___80;

struct class___80;

struct attribute_group___73;

struct device_rh___80;

struct device___80 {
	struct device___80 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___80 *type;
	struct mutex___102 mutex;
	struct bus_type___80 *bus;
	struct device_driver___80 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___80 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___80 *class;
	const struct attribute_group___73 **groups;
	void (*release)(struct device___80 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___80 *device_rh;
};

struct dev_pm_info_rh___80 {
	void (*set_latency_tolerance)(struct device___80 *, s32);
};

struct dev_pm_domain___80 {
	struct dev_pm_ops___80 ops;
};

struct smp_ops___101 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___101 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___10;

typedef void bio_end_io_t___10(struct bio___10 *, int);

struct bio_vec___10 {
	struct page___101 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___68;

struct bio_integrity_payload___10;

struct bio_set___10;

struct bio___10 {
	sector_t bi_sector;
	struct bio___10 *bi_next;
	struct block_device___101 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___10 *bi_end_io;
	void *bi_private;
	struct io_context___10 *bi_ioc;
	struct cgroup_subsys_state___68 *bi_css;
	struct bio_integrity_payload___10 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___10 *bi_io_vec;
	struct bio_set___10 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___10 bi_inline_vecs[0];
};

struct hd_struct___11;

struct gendisk___11;

struct request_queue___10;

struct block_device___101 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___2 *bd_inode;
	struct super_block___2 *bd_super;
	struct mutex___102 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___101 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___11 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___11 *bd_disk;
	struct request_queue___10 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___102 bd_fsfreeze_mutex;
};

struct io_cq___10;

struct io_context___10 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___10 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___68;

struct cgroup_subsys_state___68 {
	struct cgroup___68 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___10 {
	struct bio___10 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___10 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___10 *bip_vec;
	struct bio_vec___10 bip_inline_vecs[0];
};

struct bio_list___10 {
	struct bio___10 *head;
	struct bio___10 *tail;
};

struct bio_set___10 {
	struct kmem_cache___89 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___10 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct kiocb___6;

typedef int kiocb_cancel_fn___6(struct kiocb___6 *, struct io_event *);

struct kiocb___6 {
	atomic_t ki_users;
	struct file___101 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___6 *ki_cancel;
	void (*ki_dtor)(struct kiocb___6 *);
	union {
		void *user;
		struct task_struct___101 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___2 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___101 *ia_file;
};

struct fown_struct___58 {
	rwlock_t lock;
	struct pid___58 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___101 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___101 f_path;
	struct inode___2 *f_inode;
	const struct file_operations___101 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___58 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___101 *f_mapping;
	struct mutex___102 f_pos_lock;
};

struct zone___101;

struct lruvec___101 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___101 *zone;
};

struct pglist_data___101;

struct zone___101 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___101 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___101 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___101 {
	struct zone___101 *zone;
	int zone_idx;
};

struct zonelist___101 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___101 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___101 {
	struct zone___101 node_zones[4];
	struct zonelist___101 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___101 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___101 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___102 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___2 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___101 {
	int qf_fmt_id;
	const struct quota_format_ops___101 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___101 *qf_next;
};

struct quota_format_ops___101 {
	int (*check_quota_file)(struct super_block___2 *, int);
	int (*read_file_info)(struct super_block___2 *, int);
	int (*write_file_info)(struct super_block___2 *, int);
	int (*free_file_info)(struct super_block___2 *, int);
	int (*read_dqblk)(struct dquot___101 *);
	int (*commit_dqblk)(struct dquot___101 *);
	int (*release_dqblk)(struct dquot___101 *);
};

struct dquot_operations___101 {
	int (*write_dquot)(struct dquot___101 *);
	struct dquot___101 * (*alloc_dquot)(struct super_block___2 *, int);
	void (*destroy_dquot)(struct dquot___101 *);
	int (*acquire_dquot)(struct dquot___101 *);
	int (*release_dquot)(struct dquot___101 *);
	int (*mark_dirty)(struct dquot___101 *);
	int (*write_info)(struct super_block___2 *, int);
	qsize_t * (*get_reserved_space)(struct inode___2 *);
};

struct quotactl_ops___101 {
	int (*quota_on)(struct super_block___2 *, int, int, struct path___101 *);
	int (*quota_on_meta)(struct super_block___2 *, int, int);
	int (*quota_off)(struct super_block___2 *, int);
	int (*quota_sync)(struct super_block___2 *, int);
	int (*get_info)(struct super_block___2 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___2 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___2 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___2 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___2 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___2 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___2 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___2 *, unsigned int);
};

enum positive_aop_returns {
	AOP_WRITEPAGE_ACTIVATE = 524288,
	AOP_TRUNCATED_PAGE = 524289,
};

struct iov_iter {
	const struct iovec *iov;
	long unsigned int nr_segs;
	size_t iov_offset;
	size_t count;
};

typedef int (*read_actor_t)(read_descriptor_t *, struct page___101 *, long unsigned int, long unsigned int);

struct swap_info_struct___18;

struct address_space_operations___101 {
	int (*writepage)(struct page___101 *, struct writeback_control *);
	int (*readpage)(struct file___101 *, struct page___101 *);
	int (*writepages)(struct address_space___101 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___101 *);
	int (*readpages)(struct file___101 *, struct address_space___101 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___101 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___101 **, void **);
	int (*write_end)(struct file___101 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___101 *, void *);
	sector_t (*bmap)(struct address_space___101 *, sector_t);
	void (*invalidatepage)(struct page___101 *, long unsigned int);
	int (*releasepage)(struct page___101 *, gfp_t);
	void (*freepage)(struct page___101 *);
	ssize_t (*direct_IO)(int, struct kiocb___6 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___101 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___101 *, struct page___101 *, struct page___101 *, enum migrate_mode);
	int (*launder_page)(struct page___101 *);
	int (*is_partially_uptodate)(struct page___101 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___101 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___101 *, struct page___101 *);
	int (*swap_activate)(struct swap_info_struct___18 *, struct file___101 *, sector_t *);
	void (*swap_deactivate)(struct file___101 *);
	void (*invalidatepage_range)(struct page___101 *, unsigned int, unsigned int);
};

struct swap_info_struct___18 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___101 *bdev;
	struct file___101 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___13 {
	struct backing_dev_info___13 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___13 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___13 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___80 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___2 *debug_dir;
	struct dentry___2 *debug_stats;
};

struct hd_struct___11 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___80 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___11;

struct block_device_operations___10;

struct gendisk___11 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___11 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___11 *part_tbl;
	struct hd_struct___11 part0;
	const struct block_device_operations___10 *fops;
	struct request_queue___10 *queue;
	void *private_data;
	int flags;
	struct device___80 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___10 {
	struct request_queue___10 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___10(struct request_queue___10 *);

typedef void make_request_fn___10(struct request_queue___10 *, struct bio___10 *);

struct request___10;

typedef int prep_rq_fn___10(struct request_queue___10 *, struct request___10 *);

struct bvec_merge_data___10;

typedef int merge_bvec_fn___10(struct request_queue___10 *, struct bvec_merge_data___10 *, struct bio_vec___10 *);

typedef void softirq_done_fn___10(struct request___10 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___10(struct request___10 *);

typedef int dma_drain_needed_fn___10(struct request___10 *);

typedef int lld_busy_fn___10(struct request_queue___10 *);

struct bsg_class_device___10 {
	struct device___80 *class_dev;
	struct device___80 *parent;
	int minor;
	struct request_queue___10 *queue;
	struct kref ref;
	void (*release)(struct device___80 *);
};

typedef void unprep_rq_fn___10(struct request_queue___10 *, struct request___10 *);

struct elevator_queue___10;

struct blk_queue_tag___10;

struct request_queue___10 {
	struct list_head queue_head;
	struct request___10 *last_merge;
	struct elevator_queue___10 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___10 root_rl;
	request_fn_proc___10 *request_fn;
	make_request_fn___10 *make_request_fn;
	prep_rq_fn___10 *prep_rq_fn;
	merge_bvec_fn___10 *merge_bvec_fn;
	softirq_done_fn___10 *softirq_done_fn;
	rq_timed_out_fn___10 *rq_timed_out_fn;
	dma_drain_needed_fn___10 *dma_drain_needed;
	lld_busy_fn___10 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___10 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___13 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___80 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___10 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___10 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___102 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___10 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___10 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___10 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___101 {
	struct dentry___2 * (*lookup)(struct inode___2 *, struct dentry___2 *, unsigned int);
	void * (*follow_link)(struct dentry___2 *, struct nameidata *);
	int (*permission)(struct inode___2 *, int);
	struct posix_acl * (*get_acl)(struct inode___2 *, int);
	int (*readlink)(struct dentry___2 *, char *, int);
	void (*put_link)(struct dentry___2 *, struct nameidata *, void *);
	int (*create)(struct inode___2 *, struct dentry___2 *, umode_t, bool);
	int (*link)(struct dentry___2 *, struct inode___2 *, struct dentry___2 *);
	int (*unlink)(struct inode___2 *, struct dentry___2 *);
	int (*symlink)(struct inode___2 *, struct dentry___2 *, const char *);
	int (*mkdir)(struct inode___2 *, struct dentry___2 *, umode_t);
	int (*rmdir)(struct inode___2 *, struct dentry___2 *);
	int (*mknod)(struct inode___2 *, struct dentry___2 *, umode_t, dev_t);
	int (*rename)(struct inode___2 *, struct dentry___2 *, struct inode___2 *, struct dentry___2 *);
	int (*setattr)(struct dentry___2 *, struct iattr___2 *);
	int (*getattr)(struct vfsmount *, struct dentry___2 *, struct kstat *);
	int (*setxattr)(struct dentry___2 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___2 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___2 *, char *, size_t);
	int (*removexattr)(struct dentry___2 *, const char *);
	int (*fiemap)(struct inode___2 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___2 *, struct timespec *, int);
	int (*atomic_open)(struct inode___2 *, struct dentry___2 *, struct file___101 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___65;

struct seq_file___77;

struct file_operations___101 {
	struct module *owner;
	loff_t (*llseek)(struct file___101 *, loff_t, int);
	ssize_t (*read)(struct file___101 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___101 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___6 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___6 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___101 *, void *, filldir_t);
	unsigned int (*poll)(struct file___101 *, struct poll_table_struct___65 *);
	long int (*unlocked_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___101 *, struct vm_area_struct___106 *);
	int (*open)(struct inode___2 *, struct file___101 *);
	int (*flush)(struct file___101 *, fl_owner_t);
	int (*release)(struct inode___2 *, struct file___101 *);
	int (*fsync)(struct file___101 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___6 *, int);
	int (*fasync)(int, struct file___101 *, int);
	int (*lock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*sendpage)(struct file___101 *, struct page___101 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___101 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___101 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___101 *, long int, struct file_lock___101 **, void **);
		struct {
			int (*setlease)(struct file___101 *, long int, struct file_lock___101 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___101 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___77 *, struct file___101 *);
};

struct file_lock_operations___101;

struct lock_manager_operations___101;

struct file_lock___101 {
	struct file_lock___101 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___58 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___101 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___101 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___101 *fl_ops;
	const struct lock_manager_operations___101 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___101 {
	void (*fl_copy_lock)(struct file_lock___101 *, struct file_lock___101 *);
	void (*fl_release_private)(struct file_lock___101 *);
};

struct lock_manager_operations___101 {
	int (*lm_compare_owner)(struct file_lock___101 *, struct file_lock___101 *);
	long unsigned int (*lm_owner_key)(struct file_lock___101 *);
	void (*lm_notify)(struct file_lock___101 *);
	int (*lm_grant)(struct file_lock___101 *, struct file_lock___101 *, int);
	void (*lm_break)(struct file_lock___101 *);
	int (*lm_change)(struct file_lock___101 **, int);
};

struct fasync_struct___101 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___101 *fa_next;
	struct file___101 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___101 {
	const char *name;
	int fs_flags;
	struct dentry___2 * (*mount)(struct file_system_type___101 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___2 *);
	struct module *owner;
	struct file_system_type___101 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___101 {
	struct inode___2 * (*alloc_inode)(struct super_block___2 *);
	void (*destroy_inode)(struct inode___2 *);
	void (*dirty_inode)(struct inode___2 *, int);
	int (*write_inode)(struct inode___2 *, struct writeback_control *);
	int (*drop_inode)(struct inode___2 *);
	void (*evict_inode)(struct inode___2 *);
	void (*put_super)(struct super_block___2 *);
	int (*sync_fs)(struct super_block___2 *, int);
	int (*freeze_fs)(struct super_block___2 *);
	int (*unfreeze_fs)(struct super_block___2 *);
	int (*statfs)(struct dentry___2 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___2 *, int *, char *);
	void (*umount_begin)(struct super_block___2 *);
	int (*show_options)(struct seq_file___77 *, struct dentry___2 *);
	int (*show_devname)(struct seq_file___77 *, struct dentry___2 *);
	int (*show_path)(struct seq_file___77 *, struct dentry___2 *);
	int (*show_stats)(struct seq_file___77 *, struct dentry___2 *);
	ssize_t (*quota_read)(struct super_block___2 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___2 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___2 *);
	int (*bdev_try_to_free_page)(struct super_block___2 *, struct page___101 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___2 *);
	void (*free_cached_objects)(struct super_block___2 *, int);
};

struct xattr_handler___68 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___2 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___2 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___2 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___66)(struct file___101 *, wait_queue_head_t *, struct poll_table_struct___65 *);

struct poll_table_struct___65 {
	poll_queue_proc___66 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___89;

struct vm_area_struct___106 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___106 *vm_next;
	struct vm_area_struct___106 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___106 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___89 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___101 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___76;

struct seq_file___77 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___102 lock;
	const struct seq_operations___76 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___75 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___75 *);
	void (*irq_shutdown)(struct irq_data___75 *);
	void (*irq_enable)(struct irq_data___75 *);
	void (*irq_disable)(struct irq_data___75 *);
	void (*irq_ack)(struct irq_data___75 *);
	void (*irq_mask)(struct irq_data___75 *);
	void (*irq_mask_ack)(struct irq_data___75 *);
	void (*irq_unmask)(struct irq_data___75 *);
	void (*irq_eoi)(struct irq_data___75 *);
	int (*irq_set_affinity)(struct irq_data___75 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___75 *);
	int (*irq_set_type)(struct irq_data___75 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___75 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___75 *);
	void (*irq_bus_sync_unlock)(struct irq_data___75 *);
	void (*irq_cpu_online)(struct irq_data___75 *);
	void (*irq_cpu_offline)(struct irq_data___75 *);
	void (*irq_suspend)(struct irq_data___75 *);
	void (*irq_resume)(struct irq_data___75 *);
	void (*irq_pm_shutdown)(struct irq_data___75 *);
	void (*irq_print_chip)(struct irq_data___75 *, struct seq_file___77 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___75 *, void *);
	long unsigned int flags;
};

struct xol_area___101 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___101 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___89;

struct memcg_cache_params___89;

struct kmem_cache___89 {
	struct kmem_cache_cpu___89 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___89 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___86;

struct vm_operations_struct___89 {
	void (*open)(struct vm_area_struct___106 *);
	void (*close)(struct vm_area_struct___106 *);
	int (*fault)(struct vm_area_struct___106 *, struct vm_fault___86 *);
	int (*page_mkwrite)(struct vm_area_struct___106 *, struct vm_fault___86 *);
	int (*access)(struct vm_area_struct___106 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___106 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___106 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___106 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___106 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___101 {
	struct task_struct___101 *task;
	struct core_thread___101 *next;
};

struct core_state___101 {
	atomic_t nr_threads;
	struct core_thread___101 dumper;
	struct completion startup;
};

struct nsproxy___59 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___58 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___101 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___101 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___101 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___58 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___58 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___102 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___68 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___68 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___53 {
	struct pmu___53 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___102 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___101 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___53 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___86 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___101 *page;
};

struct bin_attribute___73;

struct attribute_group___73 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___73 **bin_attrs;
};

struct bin_attribute___73 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___101 *, struct kobject *, struct bin_attribute___73 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___101 *, struct kobject *, struct bin_attribute___73 *, char *, loff_t, size_t);
	int (*mmap)(struct file___101 *, struct kobject *, struct bin_attribute___73 *, struct vm_area_struct___106 *);
};

struct kmem_cache_cpu___89 {
	void **freelist;
	long unsigned int tid;
	struct page___101 *page;
	struct page___101 *partial;
};

struct memcg_cache_params___89 {
	bool is_root_cache;
	union {
		struct kmem_cache___89 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___89 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___68;

struct cgroup___68 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___68 *parent;
	struct dentry___2 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___68 *subsys[11];
	struct cgroupfs_root___68 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___102 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___68 {
	struct super_block___2 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___68 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___26 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___2 *, struct file___101 *);
	ssize_t (*read)(struct cgroup___68 *, struct cftype___26 *, struct file___101 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___68 *, struct cftype___26 *);
	s64 (*read_s64)(struct cgroup___68 *, struct cftype___26 *);
	int (*read_map)(struct cgroup___68 *, struct cftype___26 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___68 *, struct cftype___26 *, struct seq_file___77 *);
	ssize_t (*write)(struct cgroup___68 *, struct cftype___26 *, struct file___101 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___68 *, struct cftype___26 *, u64);
	int (*write_s64)(struct cgroup___68 *, struct cftype___26 *, s64);
	int (*write_string)(struct cgroup___68 *, struct cftype___26 *, const char *);
	int (*trigger)(struct cgroup___68 *, unsigned int);
	int (*release)(struct inode___2 *, struct file___101 *);
	int (*register_event)(struct cgroup___68 *, struct cftype___26 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___68 *, struct cftype___26 *, struct eventfd_ctx *);
};

struct cftype_set___24 {
	struct list_head node;
	struct cftype___26 *cfts;
};

struct task_and_cgroup___24 {
	struct task_struct___101 *task;
	struct cgroup___68 *cgrp;
	struct css_set___68 *cg;
};

struct cgroup_taskset___24 {
	struct task_and_cgroup___24 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___68 *cur_cgrp;
};

struct cgroup_subsys___24 {
	struct cgroup_subsys_state___68 * (*css_alloc)(struct cgroup___68 *);
	int (*css_online)(struct cgroup___68 *);
	void (*css_offline)(struct cgroup___68 *);
	void (*css_free)(struct cgroup___68 *);
	int (*can_attach)(struct cgroup___68 *, struct cgroup_taskset___24 *);
	void (*cancel_attach)(struct cgroup___68 *, struct cgroup_taskset___24 *);
	void (*attach)(struct cgroup___68 *, struct cgroup_taskset___24 *);
	void (*fork)(struct task_struct___101 *);
	void (*exit)(struct cgroup___68 *, struct cgroup___68 *, struct task_struct___101 *);
	void (*bind)(struct cgroup___68 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___68 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___26 *base_cftypes;
	struct cftype_set___24 base_cftset;
	struct module *module;
};

struct bus_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___80 *, char *);
	ssize_t (*store)(struct bus_type___80 *, const char *, size_t);
};

struct device_attribute___80;

struct driver_attribute___80;

struct bus_type___80 {
	const char *name;
	const char *dev_name;
	struct device___80 *dev_root;
	struct bus_attribute___80 *bus_attrs;
	struct device_attribute___80 *dev_attrs;
	struct driver_attribute___80 *drv_attrs;
	const struct attribute_group___73 **bus_groups;
	const struct attribute_group___73 **dev_groups;
	const struct attribute_group___73 **drv_groups;
	int (*match)(struct device___80 *, struct device_driver___80 *);
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	int (*probe)(struct device___80 *);
	int (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*online)(struct device___80 *);
	int (*offline)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct device___80 *, struct device_attribute___80 *, char *);
	ssize_t (*store)(struct device___80 *, struct device_attribute___80 *, const char *, size_t);
};

struct driver_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___80 *, char *);
	ssize_t (*store)(struct device_driver___80 *, const char *, size_t);
};

struct device_driver___80 {
	const char *name;
	struct bus_type___80 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___80 *);
	int (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	const struct attribute_group___73 **groups;
	const struct dev_pm_ops___80 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___80 {
	const char *name;
	const struct attribute_group___73 **groups;
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
};

struct class_attribute___80;

struct class___80 {
	const char *name;
	struct module *owner;
	struct class_attribute___80 *class_attrs;
	struct device_attribute___80 *dev_attrs;
	const struct attribute_group___73 **dev_groups;
	struct bin_attribute___73 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *);
	void (*class_release)(struct class___80 *);
	void (*dev_release)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
	struct subsys_private *p;
};

struct class_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct class___80 *, struct class_attribute___80 *, char *);
	ssize_t (*store)(struct class___80 *, struct class_attribute___80 *, const char *, size_t);
	const void * (*namespace)(struct class___80 *, const struct class_attribute___80 *);
};

struct device_rh___80 {
	struct dev_pm_info_rh___80 power;
};

enum mapping_flags {
	AS_EIO = 25,
	AS_ENOSPC = 26,
	AS_MM_ALL_LOCKS = 27,
	AS_UNEVICTABLE = 28,
	AS_BALLOON_MAP = 29,
	AS_EXITING = 30,
};

typedef int filler_t___2(void *, struct page___101 *);

struct pagevec {
	long unsigned int nr;
	long unsigned int cold;
	struct page___101 *pages[14];
};

struct disk_part_tbl___11 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___11 *last_lookup;
	struct hd_struct___11 *part[0];
};

struct block_device_operations___10 {
	int (*open)(struct block_device___101 *, fmode_t);
	void (*release)(struct gendisk___11 *, fmode_t);
	int (*ioctl)(struct block_device___101 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___101 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___101 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___11 *, unsigned int);
	int (*media_changed)(struct gendisk___11 *);
	void (*unlock_native_capacity)(struct gendisk___11 *);
	int (*revalidate_disk)(struct gendisk___11 *);
	int (*getgeo)(struct block_device___101 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___101 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___10 {
	struct request_queue___10 *q;
	struct io_context___10 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___89 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___10(struct request___10 *, int);

struct request___10 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___10 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___10 *bio;
	struct bio___10 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___10 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___10 *saved_end_io;
		} flush;
	};
	struct gendisk___11 *rq_disk;
	struct hd_struct___11 *part;
	long unsigned int start_time;
	struct request_list___10 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___10 *end_io;
	void *end_io_data;
	struct request___10 *next_rq;
};

typedef int elevator_merge_fn___10(struct request_queue___10 *, struct request___10 **, struct bio___10 *);

typedef void elevator_merge_req_fn___10(struct request_queue___10 *, struct request___10 *, struct request___10 *);

typedef void elevator_merged_fn___10(struct request_queue___10 *, struct request___10 *, int);

typedef int elevator_allow_merge_fn___10(struct request_queue___10 *, struct request___10 *, struct bio___10 *);

typedef void elevator_bio_merged_fn___10(struct request_queue___10 *, struct request___10 *, struct bio___10 *);

typedef int elevator_dispatch_fn___10(struct request_queue___10 *, int);

typedef void elevator_add_req_fn___10(struct request_queue___10 *, struct request___10 *);

typedef struct request___10 *elevator_request_list_fn___10(struct request_queue___10 *, struct request___10 *);

typedef void elevator_completed_req_fn___10(struct request_queue___10 *, struct request___10 *);

typedef int elevator_may_queue_fn___10(struct request_queue___10 *, int);

typedef void elevator_init_icq_fn___10(struct io_cq___10 *);

typedef void elevator_exit_icq_fn___10(struct io_cq___10 *);

typedef int elevator_set_req_fn___10(struct request_queue___10 *, struct request___10 *, struct bio___10 *, gfp_t);

typedef void elevator_put_req_fn___10(struct request___10 *);

typedef void elevator_activate_req_fn___10(struct request_queue___10 *, struct request___10 *);

typedef void elevator_deactivate_req_fn___10(struct request_queue___10 *, struct request___10 *);

struct elevator_type___10;

typedef int elevator_init_fn___10(struct request_queue___10 *, struct elevator_type___10 *);

typedef void elevator_exit_fn___10(struct elevator_queue___10 *);

struct elevator_ops___10 {
	elevator_merge_fn___10 *elevator_merge_fn;
	elevator_merged_fn___10 *elevator_merged_fn;
	elevator_merge_req_fn___10 *elevator_merge_req_fn;
	elevator_allow_merge_fn___10 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___10 *elevator_bio_merged_fn;
	elevator_dispatch_fn___10 *elevator_dispatch_fn;
	elevator_add_req_fn___10 *elevator_add_req_fn;
	elevator_activate_req_fn___10 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___10 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___10 *elevator_completed_req_fn;
	elevator_request_list_fn___10 *elevator_former_req_fn;
	elevator_request_list_fn___10 *elevator_latter_req_fn;
	elevator_init_icq_fn___10 *elevator_init_icq_fn;
	elevator_exit_icq_fn___10 *elevator_exit_icq_fn;
	elevator_set_req_fn___10 *elevator_set_req_fn;
	elevator_put_req_fn___10 *elevator_put_req_fn;
	elevator_may_queue_fn___10 *elevator_may_queue_fn;
	elevator_init_fn___10 *elevator_init_fn;
	elevator_exit_fn___10 *elevator_exit_fn;
};

struct elv_fs_entry___10;

struct elevator_type___10 {
	struct kmem_cache___89 *icq_cache;
	struct elevator_ops___10 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___10 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___10 {
	struct elevator_type___10 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___102 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___10 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___10 *, char *);
	ssize_t (*store)(struct elevator_queue___10 *, const char *, size_t);
};

struct bvec_merge_data___10 {
	struct block_device___101 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___10 {
	struct request___10 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct fid {
	union {
		struct {
			u32 ino;
			u32 gen;
			u32 parent_ino;
			u32 parent_gen;
		} i32;
		struct {
			u32 block;
			u16 partref;
			u16 parent_partref;
			u32 generation;
			u32 parent_block;
			u32 parent_generation;
		} udf;
		__u32 raw[0];
	};
};

struct iomap {
	sector_t blkno;
	loff_t offset;
	u64 length;
	int type;
};

struct seq_operations___76 {
	void * (*start)(struct seq_file___77 *, loff_t *);
	void (*stop)(struct seq_file___77 *, void *);
	void * (*next)(struct seq_file___77 *, void *, loff_t *);
	int (*show)(struct seq_file___77 *, void *);
};

struct perf_cpu_context___53;

struct pmu___53 {
	struct list_head entry;
	struct device___80 *dev;
	const struct attribute_group___73 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___53 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___53 *);
	void (*pmu_disable)(struct pmu___53 *);
	int (*event_init)(struct perf_event___53 *);
	int (*add)(struct perf_event___53 *, int);
	void (*del)(struct perf_event___53 *, int);
	void (*start)(struct perf_event___53 *, int);
	void (*stop)(struct perf_event___53 *, int);
	void (*read)(struct perf_event___53 *);
	void (*start_txn)(struct pmu___53 *);
	int (*commit_txn)(struct pmu___53 *);
	void (*cancel_txn)(struct pmu___53 *);
	int (*event_idx)(struct perf_event___53 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___53 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___53 *);
};

struct perf_cpu_context___53 {
	struct perf_event_context___53 ctx;
	struct perf_event_context___53 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___53 *unique_pmu;
	struct perf_cgroup___53 *cgrp;
};

struct trace_event_functions___43;

struct trace_event___43 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___43 *funcs;
};

struct ftrace_event_class___43;

struct ftrace_event_call___43 {
	struct list_head list;
	struct ftrace_event_class___43 *class;
	char *name;
	struct trace_event___43 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___53 {
	struct cgroup_subsys_state___68 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___43 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___102 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___43)(struct trace_iterator___43 *, int, struct trace_event___43 *);

struct trace_event_functions___43 {
	trace_print_func___43 trace;
	trace_print_func___43 raw;
	trace_print_func___43 hex;
	trace_print_func___43 binary;
};

struct ftrace_event_class___43 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___43 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___43 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___43 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___43 *);
};

struct ftrace_event_file___17 {
	struct list_head list;
	struct ftrace_event_call___43 *event_call;
	struct dentry___2 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_mm_filemap_op_page_cache {
	struct trace_entry ent;
	struct page___101 *page;
	long unsigned int i_ino;
	long unsigned int index;
	dev_t s_dev;
	char __data[0];
};

struct ftrace_data_offsets_mm_filemap_op_page_cache {};

struct page___102;

typedef struct page___102 *pgtable_t___102;

struct address_space___102;

struct kmem_cache___90;

struct page___102 {
	long unsigned int flags;
	struct address_space___102 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___102 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___102 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___90 *slab_cache;
		struct page___102 *first_page;
	};
	long: 64;
};

struct task_struct___102;

struct pv_cpu_ops___102 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___53 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___53 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___102 *);
	void (*end_context_switch)(struct task_struct___102 *);
};

struct mutex___103 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___102 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___98 {
	struct page___102 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___107;

struct signal_struct___102;

struct bio_list___11;

struct backing_dev_info___14;

struct io_context___11;

struct task_struct___102 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___102 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___107 *mm;
	struct mm_struct___107 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___102 *real_parent;
	struct task_struct___102 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___102 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___58 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___102 = 0,
		VTIME_USER___102 = 1,
		VTIME_SYS___102 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___53 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___102 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___11 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___14 *backing_dev_info;
	struct io_context___11 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___103 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___98 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___107 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___107 *, struct mm_struct___107 *);
	void (*dup_mmap)(struct mm_struct___107 *, struct mm_struct___107 *);
	void (*exit_mmap)(struct mm_struct___107 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___107 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___107 *);
	void (*pgd_free)(struct mm_struct___107 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___107 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___107 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___107 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___107 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___107 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___107 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___107 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___107 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___107 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___107 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___107 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___103 lock;
	void *vdso;
} mm_context_t___103;

struct xol_area___102;

struct uprobes_state___102 {
	struct xol_area___102 *xol_area;
};

struct vm_area_struct___107;

struct file___102;

struct core_state___102;

struct mm_struct___107 {
	struct vm_area_struct___107 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___107 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___107 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___103 context;
	long unsigned int flags;
	struct core_state___102 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___102 *owner;
	struct file___102 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___102 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___102;

struct lruvec___102 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___102 *zone;
};

struct pglist_data___102;

struct zone___102 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___102 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___102 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___102 {
	struct zone___102 *zone;
	int zone_idx;
};

struct zonelist___102 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___102 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___102 {
	struct zone___102 node_zones[4];
	struct zonelist___102 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___102 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___81;

struct dev_pm_ops___81 {
	int (*prepare)(struct device___81 *);
	void (*complete)(struct device___81 *);
	int (*suspend)(struct device___81 *);
	int (*resume)(struct device___81 *);
	int (*freeze)(struct device___81 *);
	int (*thaw)(struct device___81 *);
	int (*poweroff)(struct device___81 *);
	int (*restore)(struct device___81 *);
	int (*suspend_late)(struct device___81 *);
	int (*resume_early)(struct device___81 *);
	int (*freeze_late)(struct device___81 *);
	int (*thaw_early)(struct device___81 *);
	int (*poweroff_late)(struct device___81 *);
	int (*restore_early)(struct device___81 *);
	int (*suspend_noirq)(struct device___81 *);
	int (*resume_noirq)(struct device___81 *);
	int (*freeze_noirq)(struct device___81 *);
	int (*thaw_noirq)(struct device___81 *);
	int (*poweroff_noirq)(struct device___81 *);
	int (*restore_noirq)(struct device___81 *);
	int (*runtime_suspend)(struct device___81 *);
	int (*runtime_resume)(struct device___81 *);
	int (*runtime_idle)(struct device___81 *);
};

struct device_type___81;

struct bus_type___81;

struct device_driver___81;

struct dev_pm_domain___81;

struct class___81;

struct attribute_group___74;

struct device_rh___81;

struct device___81 {
	struct device___81 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___81 *type;
	struct mutex___103 mutex;
	struct bus_type___81 *bus;
	struct device_driver___81 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___81 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___81 *class;
	const struct attribute_group___74 **groups;
	void (*release)(struct device___81 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___81 *device_rh;
};

struct dev_pm_info_rh___81 {
	void (*set_latency_tolerance)(struct device___81 *, s32);
};

struct dev_pm_domain___81 {
	struct dev_pm_ops___81 ops;
};

struct smp_ops___102 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___102 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___102 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___102 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___90;

struct memcg_cache_params___90;

struct kmem_cache___90 {
	struct kmem_cache_cpu___90 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___90 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___102;

struct address_space_operations___102;

struct address_space___102 {
	struct inode___102 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___103 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___102 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___14 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___102;

struct path___102 {
	struct vfsmount *mnt;
	struct dentry___102 *dentry;
};

struct file_operations___102;

struct file___102 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___102 f_path;
	struct inode___102 *f_inode;
	const struct file_operations___102 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___58 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___102 *f_mapping;
	struct mutex___103 f_pos_lock;
};

struct vm_operations_struct___90;

struct vm_area_struct___107 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___107 *vm_next;
	struct vm_area_struct___107 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___107 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___90 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___102 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___87;

struct vm_operations_struct___90 {
	void (*open)(struct vm_area_struct___107 *);
	void (*close)(struct vm_area_struct___107 *);
	int (*fault)(struct vm_area_struct___107 *, struct vm_fault___87 *);
	int (*page_mkwrite)(struct vm_area_struct___107 *, struct vm_fault___87 *);
	int (*access)(struct vm_area_struct___107 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___107 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___107 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___107 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___107 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___102 {
	struct task_struct___102 *task;
	struct core_thread___102 *next;
};

struct core_state___102 {
	atomic_t nr_threads;
	struct core_thread___102 dumper;
	struct completion startup;
};

struct vm_fault___87 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___102 *page;
};

struct bin_attribute___74;

struct attribute_group___74 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___74 **bin_attrs;
};

struct bin_attribute___74 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___102 *, struct kobject *, struct bin_attribute___74 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___102 *, struct kobject *, struct bin_attribute___74 *, char *, loff_t, size_t);
	int (*mmap)(struct file___102 *, struct kobject *, struct bin_attribute___74 *, struct vm_area_struct___107 *);
};

struct kmem_cache_cpu___90 {
	void **freelist;
	long unsigned int tid;
	struct page___102 *page;
	struct page___102 *partial;
};

struct memcg_cache_params___90 {
	bool is_root_cache;
	union {
		struct kmem_cache___90 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___90 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___102 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___102 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___102 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___58 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___58 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___103 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___11;

struct bio_list___11 {
	struct bio___11 *head;
	struct bio___11 *tail;
};

struct bdi_writeback___14 {
	struct backing_dev_info___14 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___14 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___14 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___81 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___102 *debug_dir;
	struct dentry___102 *debug_stats;
};

struct io_cq___11;

struct io_context___11 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___11 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bus_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___81 *, char *);
	ssize_t (*store)(struct bus_type___81 *, const char *, size_t);
};

struct device_attribute___81;

struct driver_attribute___81;

struct bus_type___81 {
	const char *name;
	const char *dev_name;
	struct device___81 *dev_root;
	struct bus_attribute___81 *bus_attrs;
	struct device_attribute___81 *dev_attrs;
	struct driver_attribute___81 *drv_attrs;
	const struct attribute_group___74 **bus_groups;
	const struct attribute_group___74 **dev_groups;
	const struct attribute_group___74 **drv_groups;
	int (*match)(struct device___81 *, struct device_driver___81 *);
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	int (*probe)(struct device___81 *);
	int (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*online)(struct device___81 *);
	int (*offline)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct device___81 *, struct device_attribute___81 *, char *);
	ssize_t (*store)(struct device___81 *, struct device_attribute___81 *, const char *, size_t);
};

struct driver_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___81 *, char *);
	ssize_t (*store)(struct device_driver___81 *, const char *, size_t);
};

struct device_driver___81 {
	const char *name;
	struct bus_type___81 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___81 *);
	int (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	const struct attribute_group___74 **groups;
	const struct dev_pm_ops___81 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___81 {
	const char *name;
	const struct attribute_group___74 **groups;
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
};

struct class_attribute___81;

struct class___81 {
	const char *name;
	struct module *owner;
	struct class_attribute___81 *class_attrs;
	struct device_attribute___81 *dev_attrs;
	const struct attribute_group___74 **dev_groups;
	struct bin_attribute___74 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *);
	void (*class_release)(struct class___81 *);
	void (*dev_release)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
	struct subsys_private *p;
};

struct class_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct class___81 *, struct class_attribute___81 *, char *);
	ssize_t (*store)(struct class___81 *, struct class_attribute___81 *, const char *, size_t);
	const void * (*namespace)(struct class___81 *, const struct class_attribute___81 *);
};

struct device_rh___81 {
	struct dev_pm_info_rh___81 power;
};

struct dentry_operations___102;

struct super_block___102;

struct dentry___102 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___102 *d_parent;
	struct qstr d_name;
	struct inode___102 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___102 *d_op;
	struct super_block___102 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___102;

struct file_lock___102;

struct dquot___102;

struct block_device___102;

struct inode___102 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___102 *i_op;
	struct super_block___102 *i_sb;
	struct address_space___102 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___103 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___102 *i_fop;
	struct file_lock___102 *i_flock;
	struct address_space___102 i_data;
	struct dquot___102 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___102 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___102 {
	int (*d_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_hash)(const struct dentry___102 *, struct qstr *);
	int (*d_compare)(const struct dentry___102 *, const struct dentry___102 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___102 *);
	void (*d_release)(struct dentry___102 *);
	void (*d_prune)(struct dentry___102 *);
	void (*d_iput)(struct dentry___102 *, struct inode___102 *);
	char * (*d_dname)(struct dentry___102 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___102 *);
	int (*d_manage)(struct dentry___102 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___102;

struct mem_dqinfo___102 {
	struct quota_format_type___102 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___102;

struct quota_info___102 {
	unsigned int flags;
	struct mutex___103 dqio_mutex;
	struct mutex___103 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___102 *files[2];
	struct mem_dqinfo___102 info[2];
	const struct quota_format_ops___102 *ops[2];
};

struct file_system_type___102;

struct super_operations___102;

struct dquot_operations___102;

struct quotactl_ops___102;

struct super_block___102 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___102 *s_type;
	const struct super_operations___102 *s_op;
	const struct dquot_operations___102 *dq_op;
	const struct quotactl_ops___102 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___102 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___102 *s_bdev;
	struct backing_dev_info___14 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___102 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___103 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___102 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___11(struct bio___11 *, int);

struct bio_vec___11 {
	struct page___102 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___69;

struct bio_integrity_payload___11;

struct bio_set___11;

struct bio___11 {
	sector_t bi_sector;
	struct bio___11 *bi_next;
	struct block_device___102 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___11 *bi_end_io;
	void *bi_private;
	struct io_context___11 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___11 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___11 *bi_io_vec;
	struct bio_set___11 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___11 bi_inline_vecs[0];
};

struct hd_struct___12;

struct gendisk___12;

struct request_queue___11;

struct block_device___102 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___102 *bd_inode;
	struct super_block___102 *bd_super;
	struct mutex___103 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___102 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___12 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___12 *bd_disk;
	struct request_queue___11 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___103 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___11 {
	struct bio___11 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___11 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___11 *bip_vec;
	struct bio_vec___11 bip_inline_vecs[0];
};

struct bio_set___11 {
	struct kmem_cache___90 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___11 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___102 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___102 *ia_file;
};

struct dquot___102 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___103 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___102 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___102 {
	int qf_fmt_id;
	const struct quota_format_ops___102 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___102 *qf_next;
};

struct quota_format_ops___102 {
	int (*check_quota_file)(struct super_block___102 *, int);
	int (*read_file_info)(struct super_block___102 *, int);
	int (*write_file_info)(struct super_block___102 *, int);
	int (*free_file_info)(struct super_block___102 *, int);
	int (*read_dqblk)(struct dquot___102 *);
	int (*commit_dqblk)(struct dquot___102 *);
	int (*release_dqblk)(struct dquot___102 *);
};

struct dquot_operations___102 {
	int (*write_dquot)(struct dquot___102 *);
	struct dquot___102 * (*alloc_dquot)(struct super_block___102 *, int);
	void (*destroy_dquot)(struct dquot___102 *);
	int (*acquire_dquot)(struct dquot___102 *);
	int (*release_dquot)(struct dquot___102 *);
	int (*mark_dirty)(struct dquot___102 *);
	int (*write_info)(struct super_block___102 *, int);
	qsize_t * (*get_reserved_space)(struct inode___102 *);
};

struct quotactl_ops___102 {
	int (*quota_on)(struct super_block___102 *, int, int, struct path___102 *);
	int (*quota_on_meta)(struct super_block___102 *, int, int);
	int (*quota_off)(struct super_block___102 *, int);
	int (*quota_sync)(struct super_block___102 *, int);
	int (*get_info)(struct super_block___102 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___102 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___102 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___102 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___102 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___102 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___102 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___102 *, unsigned int);
};

struct address_space_operations___102 {
	int (*writepage)(struct page___102 *, struct writeback_control *);
	int (*readpage)(struct file___102 *, struct page___102 *);
	int (*writepages)(struct address_space___102 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___102 *);
	int (*readpages)(struct file___102 *, struct address_space___102 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___102 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___102 **, void **);
	int (*write_end)(struct file___102 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___102 *, void *);
	sector_t (*bmap)(struct address_space___102 *, sector_t);
	void (*invalidatepage)(struct page___102 *, long unsigned int);
	int (*releasepage)(struct page___102 *, gfp_t);
	void (*freepage)(struct page___102 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___102 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___102 *, struct page___102 *, struct page___102 *, enum migrate_mode);
	int (*launder_page)(struct page___102 *);
	int (*is_partially_uptodate)(struct page___102 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___102 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___102 *, struct page___102 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___102 *, sector_t *);
	void (*swap_deactivate)(struct file___102 *);
	void (*invalidatepage_range)(struct page___102 *, unsigned int, unsigned int);
};

struct hd_struct___12 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___81 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___12;

struct block_device_operations___11;

struct gendisk___12 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___12 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___12 *part_tbl;
	struct hd_struct___12 part0;
	const struct block_device_operations___11 *fops;
	struct request_queue___11 *queue;
	void *private_data;
	int flags;
	struct device___81 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___11 {
	struct request_queue___11 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___11(struct request_queue___11 *);

typedef void make_request_fn___11(struct request_queue___11 *, struct bio___11 *);

struct request___11;

typedef int prep_rq_fn___11(struct request_queue___11 *, struct request___11 *);

struct bvec_merge_data___11;

typedef int merge_bvec_fn___11(struct request_queue___11 *, struct bvec_merge_data___11 *, struct bio_vec___11 *);

typedef void softirq_done_fn___11(struct request___11 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___11(struct request___11 *);

typedef int dma_drain_needed_fn___11(struct request___11 *);

typedef int lld_busy_fn___11(struct request_queue___11 *);

struct bsg_class_device___11 {
	struct device___81 *class_dev;
	struct device___81 *parent;
	int minor;
	struct request_queue___11 *queue;
	struct kref ref;
	void (*release)(struct device___81 *);
};

typedef void unprep_rq_fn___11(struct request_queue___11 *, struct request___11 *);

struct elevator_queue___11;

struct blk_queue_tag___11;

struct request_queue___11 {
	struct list_head queue_head;
	struct request___11 *last_merge;
	struct elevator_queue___11 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___11 root_rl;
	request_fn_proc___11 *request_fn;
	make_request_fn___11 *make_request_fn;
	prep_rq_fn___11 *prep_rq_fn;
	merge_bvec_fn___11 *merge_bvec_fn;
	softirq_done_fn___11 *softirq_done_fn;
	rq_timed_out_fn___11 *rq_timed_out_fn;
	dma_drain_needed_fn___11 *dma_drain_needed;
	lld_busy_fn___11 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___11 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___14 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___81 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___11 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___11 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___103 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___11 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___11 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___11 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___102 {
	struct dentry___102 * (*lookup)(struct inode___102 *, struct dentry___102 *, unsigned int);
	void * (*follow_link)(struct dentry___102 *, struct nameidata *);
	int (*permission)(struct inode___102 *, int);
	struct posix_acl * (*get_acl)(struct inode___102 *, int);
	int (*readlink)(struct dentry___102 *, char *, int);
	void (*put_link)(struct dentry___102 *, struct nameidata *, void *);
	int (*create)(struct inode___102 *, struct dentry___102 *, umode_t, bool);
	int (*link)(struct dentry___102 *, struct inode___102 *, struct dentry___102 *);
	int (*unlink)(struct inode___102 *, struct dentry___102 *);
	int (*symlink)(struct inode___102 *, struct dentry___102 *, const char *);
	int (*mkdir)(struct inode___102 *, struct dentry___102 *, umode_t);
	int (*rmdir)(struct inode___102 *, struct dentry___102 *);
	int (*mknod)(struct inode___102 *, struct dentry___102 *, umode_t, dev_t);
	int (*rename)(struct inode___102 *, struct dentry___102 *, struct inode___102 *, struct dentry___102 *);
	int (*setattr)(struct dentry___102 *, struct iattr___102 *);
	int (*getattr)(struct vfsmount *, struct dentry___102 *, struct kstat *);
	int (*setxattr)(struct dentry___102 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___102 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___102 *, char *, size_t);
	int (*removexattr)(struct dentry___102 *, const char *);
	int (*fiemap)(struct inode___102 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___102 *, struct timespec *, int);
	int (*atomic_open)(struct inode___102 *, struct dentry___102 *, struct file___102 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___102 {
	struct module *owner;
	loff_t (*llseek)(struct file___102 *, loff_t, int);
	ssize_t (*read)(struct file___102 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___102 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___102 *, void *, filldir_t);
	unsigned int (*poll)(struct file___102 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___102 *, struct vm_area_struct___107 *);
	int (*open)(struct inode___102 *, struct file___102 *);
	int (*flush)(struct file___102 *, fl_owner_t);
	int (*release)(struct inode___102 *, struct file___102 *);
	int (*fsync)(struct file___102 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___102 *, int);
	int (*lock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*sendpage)(struct file___102 *, struct page___102 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___102 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___102 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___102 *, long int, struct file_lock___102 **, void **);
		struct {
			int (*setlease)(struct file___102 *, long int, struct file_lock___102 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___102 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___102 *);
};

struct fasync_struct___102;

struct file_lock_operations___102;

struct lock_manager_operations___102;

struct file_lock___102 {
	struct file_lock___102 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___58 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___102 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___102 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___102 *fl_ops;
	const struct lock_manager_operations___102 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___102 {
	void (*fl_copy_lock)(struct file_lock___102 *, struct file_lock___102 *);
	void (*fl_release_private)(struct file_lock___102 *);
};

struct lock_manager_operations___102 {
	int (*lm_compare_owner)(struct file_lock___102 *, struct file_lock___102 *);
	long unsigned int (*lm_owner_key)(struct file_lock___102 *);
	void (*lm_notify)(struct file_lock___102 *);
	int (*lm_grant)(struct file_lock___102 *, struct file_lock___102 *, int);
	void (*lm_break)(struct file_lock___102 *);
	int (*lm_change)(struct file_lock___102 **, int);
};

struct fasync_struct___102 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___102 *fa_next;
	struct file___102 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___102 {
	const char *name;
	int fs_flags;
	struct dentry___102 * (*mount)(struct file_system_type___102 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___102 *);
	struct module *owner;
	struct file_system_type___102 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___102 {
	struct inode___102 * (*alloc_inode)(struct super_block___102 *);
	void (*destroy_inode)(struct inode___102 *);
	void (*dirty_inode)(struct inode___102 *, int);
	int (*write_inode)(struct inode___102 *, struct writeback_control *);
	int (*drop_inode)(struct inode___102 *);
	void (*evict_inode)(struct inode___102 *);
	void (*put_super)(struct super_block___102 *);
	int (*sync_fs)(struct super_block___102 *, int);
	int (*freeze_fs)(struct super_block___102 *);
	int (*unfreeze_fs)(struct super_block___102 *);
	int (*statfs)(struct dentry___102 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___102 *, int *, char *);
	void (*umount_begin)(struct super_block___102 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___102 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___102 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___102 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___102 *);
	ssize_t (*quota_read)(struct super_block___102 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___102 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___102 *);
	int (*bdev_try_to_free_page)(struct super_block___102 *, struct page___102 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___102 *);
	void (*free_cached_objects)(struct super_block___102 *, int);
};

struct disk_part_tbl___12 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___12 *last_lookup;
	struct hd_struct___12 *part[0];
};

struct block_device_operations___11 {
	int (*open)(struct block_device___102 *, fmode_t);
	void (*release)(struct gendisk___12 *, fmode_t);
	int (*ioctl)(struct block_device___102 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___102 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___102 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___12 *, unsigned int);
	int (*media_changed)(struct gendisk___12 *);
	void (*unlock_native_capacity)(struct gendisk___12 *);
	int (*revalidate_disk)(struct gendisk___12 *);
	int (*getgeo)(struct block_device___102 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___102 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___11 {
	struct request_queue___11 *q;
	struct io_context___11 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___90 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___11(struct request___11 *, int);

struct request___11 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___11 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___11 *bio;
	struct bio___11 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___11 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___11 *saved_end_io;
		} flush;
	};
	struct gendisk___12 *rq_disk;
	struct hd_struct___12 *part;
	long unsigned int start_time;
	struct request_list___11 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___11 *end_io;
	void *end_io_data;
	struct request___11 *next_rq;
};

typedef int elevator_merge_fn___11(struct request_queue___11 *, struct request___11 **, struct bio___11 *);

typedef void elevator_merge_req_fn___11(struct request_queue___11 *, struct request___11 *, struct request___11 *);

typedef void elevator_merged_fn___11(struct request_queue___11 *, struct request___11 *, int);

typedef int elevator_allow_merge_fn___11(struct request_queue___11 *, struct request___11 *, struct bio___11 *);

typedef void elevator_bio_merged_fn___11(struct request_queue___11 *, struct request___11 *, struct bio___11 *);

typedef int elevator_dispatch_fn___11(struct request_queue___11 *, int);

typedef void elevator_add_req_fn___11(struct request_queue___11 *, struct request___11 *);

typedef struct request___11 *elevator_request_list_fn___11(struct request_queue___11 *, struct request___11 *);

typedef void elevator_completed_req_fn___11(struct request_queue___11 *, struct request___11 *);

typedef int elevator_may_queue_fn___11(struct request_queue___11 *, int);

typedef void elevator_init_icq_fn___11(struct io_cq___11 *);

typedef void elevator_exit_icq_fn___11(struct io_cq___11 *);

typedef int elevator_set_req_fn___11(struct request_queue___11 *, struct request___11 *, struct bio___11 *, gfp_t);

typedef void elevator_put_req_fn___11(struct request___11 *);

typedef void elevator_activate_req_fn___11(struct request_queue___11 *, struct request___11 *);

typedef void elevator_deactivate_req_fn___11(struct request_queue___11 *, struct request___11 *);

struct elevator_type___11;

typedef int elevator_init_fn___11(struct request_queue___11 *, struct elevator_type___11 *);

typedef void elevator_exit_fn___11(struct elevator_queue___11 *);

struct elevator_ops___11 {
	elevator_merge_fn___11 *elevator_merge_fn;
	elevator_merged_fn___11 *elevator_merged_fn;
	elevator_merge_req_fn___11 *elevator_merge_req_fn;
	elevator_allow_merge_fn___11 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___11 *elevator_bio_merged_fn;
	elevator_dispatch_fn___11 *elevator_dispatch_fn;
	elevator_add_req_fn___11 *elevator_add_req_fn;
	elevator_activate_req_fn___11 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___11 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___11 *elevator_completed_req_fn;
	elevator_request_list_fn___11 *elevator_former_req_fn;
	elevator_request_list_fn___11 *elevator_latter_req_fn;
	elevator_init_icq_fn___11 *elevator_init_icq_fn;
	elevator_exit_icq_fn___11 *elevator_exit_icq_fn;
	elevator_set_req_fn___11 *elevator_set_req_fn;
	elevator_put_req_fn___11 *elevator_put_req_fn;
	elevator_may_queue_fn___11 *elevator_may_queue_fn;
	elevator_init_fn___11 *elevator_init_fn;
	elevator_exit_fn___11 *elevator_exit_fn;
};

struct elv_fs_entry___11;

struct elevator_type___11 {
	struct kmem_cache___90 *icq_cache;
	struct elevator_ops___11 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___11 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___11 {
	struct elevator_type___11 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___103 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___11 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___11 *, char *);
	ssize_t (*store)(struct elevator_queue___11 *, const char *, size_t);
};

struct bvec_merge_data___11 {
	struct block_device___102 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___11 {
	struct request___11 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

typedef enum {
	ZONE_RECLAIM_LOCKED = 0,
	ZONE_OOM_LOCKED = 1,
	ZONE_CONGESTED = 2,
	ZONE_TAIL_LRU_DIRTY = 3,
	ZONE_WRITEBACK = 4,
} zone_flags_t;

enum oom_constraint {
	CONSTRAINT_NONE = 0,
	CONSTRAINT_CPUSET = 1,
	CONSTRAINT_MEMORY_POLICY = 2,
	CONSTRAINT_MEMCG = 3,
};

enum oom_scan_t {
	OOM_SCAN_OK = 0,
	OOM_SCAN_CONTINUE = 1,
	OOM_SCAN_ABORT = 2,
	OOM_SCAN_SELECT = 3,
};

struct ftrace_event_file___18 {
	struct list_head list;
	struct ftrace_event_call___27 *event_call;
	struct dentry___75 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_oom_score_adj_update {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	short int oom_score_adj;
	char __data[0];
};

struct ftrace_data_offsets_oom_score_adj_update {};

struct cgroup___69;

struct cgroup_subsys_state___70 {
	struct cgroup___69 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct task_struct___103;

struct mutex___104 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___103 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct vmpressure {
	long unsigned int scanned;
	long unsigned int reclaimed;
	struct mutex___104 sr_lock;
	struct list_head events;
	struct mutex___104 events_lock;
	struct work_struct work;
};

struct mem_cgroup_threshold_ary;

struct mem_cgroup_thresholds {
	struct mem_cgroup_threshold_ary *primary;
	struct mem_cgroup_threshold_ary *spare;
};

struct mem_cgroup_stat_cpu {
	long int count[5];
	long unsigned int events[4];
	long unsigned int nr_page_events;
	long unsigned int targets[3];
};

struct sock___6;

struct cg_proto___5 {
	void (*enter_memory_pressure)(struct sock___6 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct tcp_memcontrol {
	struct cg_proto___5 cg_proto;
	struct res_counter tcp_memory_allocated;
	struct percpu_counter tcp_sockets_allocated;
	long int tcp_prot_mem[3];
	int tcp_memory_pressure;
};

struct mem_cgroup_per_node;

struct mem_cgroup_lru_info {
	struct mem_cgroup_per_node *nodeinfo[0];
};

struct mem_cgroup {
	struct cgroup_subsys_state___70 css;
	struct res_counter res;
	struct vmpressure vmpressure;
	union {
		struct res_counter memsw;
		struct callback_head rcu_freeing;
		struct work_struct work_freeing;
	};
	struct res_counter kmem;
	bool use_hierarchy;
	long unsigned int kmem_account_flags;
	bool oom_lock;
	atomic_t under_oom;
	atomic_t oom_wakeups;
	atomic_t refcnt;
	int swappiness;
	int oom_kill_disable;
	bool memsw_is_minimum;
	struct mutex___104 thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	atomic_t moving_account;
	spinlock_t move_lock;
	struct mem_cgroup_stat_cpu *stat;
	struct mem_cgroup_stat_cpu nocpu_base;
	spinlock_t pcp_counter_lock;
	atomic_t dead_count;
	struct tcp_memcontrol tcp_mem;
	struct list_head memcg_slab_caches;
	struct mutex___104 slab_caches_mutex;
	int kmemcg_id;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct mem_cgroup_lru_info info;
};

struct fd___5 {
	struct file___99 *file;
	unsigned int flags;
};

enum bdi_state {
	BDI_wb_alloc = 0,
	BDI_async_congested = 1,
	BDI_sync_congested = 2,
	BDI_registered = 3,
	BDI_writeback_running = 4,
	BDI_unused = 5,
};

typedef void (*poll_queue_proc___67)(struct file___99 *, wait_queue_head_t *, struct poll_table_struct *);

struct va_format {
	const char *fmt;
	va_list *va;
};

struct page___103;

typedef struct page___103 *pgtable_t___103;

struct address_space___103;

struct kmem_cache___91;

struct page___103 {
	long unsigned int flags;
	struct address_space___103 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___103 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___103 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___91 *slab_cache;
		struct page___103 *first_page;
	};
	long: 64;
};

struct thread_struct___54;

struct task_struct___104;

struct pv_cpu_ops___103 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___54 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___54 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___104 *);
	void (*end_context_switch)(struct task_struct___104 *);
};

struct perf_event___54;

struct thread_struct___54 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___54 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___59;

struct pid_link___59 {
	struct hlist_node node;
	struct pid___59 *pid;
};

struct mutex___105 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___104 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___99 {
	struct page___103 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___108;

struct nsproxy___60;

struct signal_struct___103;

struct bio_list___12;

struct backing_dev_info___15;

struct io_context___12;

struct css_set___69;

struct perf_event_context___54;

struct task_struct___104 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___104 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___108 *mm;
	struct mm_struct___108 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___104 *real_parent;
	struct task_struct___104 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___104 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___59 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___103 = 0,
		VTIME_USER___103 = 1,
		VTIME_SYS___103 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___54 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___60 *nsproxy;
	struct signal_struct___103 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___12 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___15 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___69 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___54 *perf_event_ctxp[2];
	struct mutex___105 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___99 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___108 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___108 *, struct mm_struct___108 *);
	void (*dup_mmap)(struct mm_struct___108 *, struct mm_struct___108 *);
	void (*exit_mmap)(struct mm_struct___108 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___108 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___108 *);
	void (*pgd_free)(struct mm_struct___108 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___108 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___108 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___108 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___108 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___108 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___108 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___108 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___108 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___108 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___108 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___108 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___105 lock;
	void *vdso;
} mm_context_t___104;

struct xol_area___103;

struct uprobes_state___103 {
	struct xol_area___103 *xol_area;
};

struct vm_area_struct___108;

struct file___103;

struct core_state___103;

struct mm_struct___108 {
	struct vm_area_struct___108 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___108 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___108 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___104 context;
	long unsigned int flags;
	struct core_state___103 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___104 *owner;
	struct file___103 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___103 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___56;

struct exec_domain___28 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___56 *module;
	struct exec_domain___28 *next;
};

struct module_kobject___55 {
	struct kobject kobj;
	struct module___56 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___55;

struct ftrace_event_call___44;

struct module___56 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___55 mkobj;
	struct module_attribute___55 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___44 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___104 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___54 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___104 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___104 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___104 *target;
};

typedef void (*perf_overflow_handler_t___54)(struct perf_event___54 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___54;

typedef void (*ftrace_func_t___54)(long unsigned int, long unsigned int, struct ftrace_ops___54 *, struct pt_regs *);

struct ftrace_ops___54 {
	ftrace_func_t___54 func;
	struct ftrace_ops___54 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___105 regex_lock;
};

struct pmu___54;

struct fasync_struct___103;

struct pid_namespace___59;

struct perf_cgroup___54;

struct perf_event___54 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___54 *group_leader;
	struct pmu___54 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___54 hw;
	struct perf_event_context___54 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___105 child_mutex;
	struct list_head child_list;
	struct perf_event___54 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___104 *owner;
	struct mutex___105 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___103 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___54 *);
	struct callback_head callback_head;
	struct pid_namespace___59 *ns;
	u64 id;
	perf_overflow_handler_t___54 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___44 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___54 ftrace_ops;
	struct perf_cgroup___54 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___52 {
	struct task_struct___104 *task;
	struct exec_domain___28 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

enum pageblock_bits {
	PB_migrate = 0,
	PB_migrate_end = 2,
	PB_migrate_skip = 3,
	NR_PAGEBLOCK_BITS = 4,
};

struct zone___103;

struct lruvec___103 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___103 *zone;
};

struct pglist_data___103;

struct zone___103 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___103 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___103 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___103 {
	struct zone___103 *zone;
	int zone_idx;
};

struct zonelist___103 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___103 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___103 {
	struct zone___103 node_zones[4];
	struct zonelist___103 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___104 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct pglist_data___103 pg_data_t___4;

enum memmap_context {
	MEMMAP_EARLY = 0,
	MEMMAP_HOTPLUG = 1,
};

struct irq_data___76;

struct x86_io_apic_ops___76 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___76 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___76;

struct irq_data___76 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___76 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___82;

struct dev_pm_ops___82 {
	int (*prepare)(struct device___82 *);
	void (*complete)(struct device___82 *);
	int (*suspend)(struct device___82 *);
	int (*resume)(struct device___82 *);
	int (*freeze)(struct device___82 *);
	int (*thaw)(struct device___82 *);
	int (*poweroff)(struct device___82 *);
	int (*restore)(struct device___82 *);
	int (*suspend_late)(struct device___82 *);
	int (*resume_early)(struct device___82 *);
	int (*freeze_late)(struct device___82 *);
	int (*thaw_early)(struct device___82 *);
	int (*poweroff_late)(struct device___82 *);
	int (*restore_early)(struct device___82 *);
	int (*suspend_noirq)(struct device___82 *);
	int (*resume_noirq)(struct device___82 *);
	int (*freeze_noirq)(struct device___82 *);
	int (*thaw_noirq)(struct device___82 *);
	int (*poweroff_noirq)(struct device___82 *);
	int (*restore_noirq)(struct device___82 *);
	int (*runtime_suspend)(struct device___82 *);
	int (*runtime_resume)(struct device___82 *);
	int (*runtime_idle)(struct device___82 *);
};

struct device_type___82;

struct bus_type___82;

struct device_driver___82;

struct dev_pm_domain___82;

struct class___82;

struct attribute_group___75;

struct device_rh___82;

struct device___82 {
	struct device___82 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___82 *type;
	struct mutex___105 mutex;
	struct bus_type___82 *bus;
	struct device_driver___82 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___82 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___82 *class;
	const struct attribute_group___75 **groups;
	void (*release)(struct device___82 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___82 *device_rh;
};

struct dev_pm_info_rh___82 {
	void (*set_latency_tolerance)(struct device___82 *, s32);
};

struct dev_pm_domain___82 {
	struct dev_pm_ops___82 ops;
};

struct smp_ops___103 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___104 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___103 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___103 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___91;

struct memcg_cache_params___91;

struct kmem_cache___91 {
	struct kmem_cache_cpu___91 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___91 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___103;

struct address_space_operations___103;

struct address_space___103 {
	struct inode___103 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___105 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___103 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___15 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___103;

struct path___103 {
	struct vfsmount *mnt;
	struct dentry___103 *dentry;
};

struct fown_struct___59 {
	rwlock_t lock;
	struct pid___59 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___103;

struct file___103 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___103 f_path;
	struct inode___103 *f_inode;
	const struct file_operations___103 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___59 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___103 *f_mapping;
	struct mutex___105 f_pos_lock;
};

struct vm_operations_struct___91;

struct vm_area_struct___108 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___108 *vm_next;
	struct vm_area_struct___108 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___108 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___91 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___103 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___88;

struct vm_operations_struct___91 {
	void (*open)(struct vm_area_struct___108 *);
	void (*close)(struct vm_area_struct___108 *);
	int (*fault)(struct vm_area_struct___108 *, struct vm_fault___88 *);
	int (*page_mkwrite)(struct vm_area_struct___108 *, struct vm_fault___88 *);
	int (*access)(struct vm_area_struct___108 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___108 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___108 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___108 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___108 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___103 {
	struct task_struct___104 *task;
	struct core_thread___103 *next;
};

struct core_state___103 {
	atomic_t nr_threads;
	struct core_thread___103 dumper;
	struct completion startup;
};

struct vm_fault___88 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___103 *page;
};

typedef void compound_page_dtor(struct page___103 *);

struct upid___59 {
	int nr;
	struct pid_namespace___59 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___59 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___104 *child_reaper;
	struct kmem_cache___91 *pid_cachep;
	unsigned int level;
	struct pid_namespace___59 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___103 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___59 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___59 numbers[1];
};

struct nsproxy___60 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___59 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___103 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___104 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___104 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___59 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___59 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___105 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___12;

struct bio_list___12 {
	struct bio___12 *head;
	struct bio___12 *tail;
};

struct bdi_writeback___15 {
	struct backing_dev_info___15 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___15 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___15 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___82 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___103 *debug_dir;
	struct dentry___103 *debug_stats;
};

struct io_cq___12;

struct io_context___12 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___12 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___71;

struct css_set___69 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___71 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___54 {
	struct pmu___54 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___105 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___104 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___54 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___75;

struct attribute_group___75 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___75 **bin_attrs;
};

struct bin_attribute___75 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___103 *, struct kobject *, struct bin_attribute___75 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___103 *, struct kobject *, struct bin_attribute___75 *, char *, loff_t, size_t);
	int (*mmap)(struct file___103 *, struct kobject *, struct bin_attribute___75 *, struct vm_area_struct___108 *);
};

struct kmem_cache_cpu___91 {
	void **freelist;
	long unsigned int tid;
	struct page___103 *page;
	struct page___103 *partial;
};

struct memcg_cache_params___91 {
	bool is_root_cache;
	union {
		struct kmem_cache___91 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___91 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___69 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___103 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___103 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___103 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___103;

struct super_block___103;

struct dentry___103 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___103 *d_parent;
	struct qstr d_name;
	struct inode___103 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___103 *d_op;
	struct super_block___103 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___103;

struct file_lock___103;

struct dquot___103;

struct block_device___103;

struct inode___103 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___103 *i_op;
	struct super_block___103 *i_sb;
	struct address_space___103 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___105 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___103 *i_fop;
	struct file_lock___103 *i_flock;
	struct address_space___103 i_data;
	struct dquot___103 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___103 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___103 {
	int (*d_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_hash)(const struct dentry___103 *, struct qstr *);
	int (*d_compare)(const struct dentry___103 *, const struct dentry___103 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___103 *);
	void (*d_release)(struct dentry___103 *);
	void (*d_prune)(struct dentry___103 *);
	void (*d_iput)(struct dentry___103 *, struct inode___103 *);
	char * (*d_dname)(struct dentry___103 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___103 *);
	int (*d_manage)(struct dentry___103 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___103;

struct mem_dqinfo___103 {
	struct quota_format_type___103 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___103;

struct quota_info___103 {
	unsigned int flags;
	struct mutex___105 dqio_mutex;
	struct mutex___105 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___103 *files[2];
	struct mem_dqinfo___103 info[2];
	const struct quota_format_ops___103 *ops[2];
};

struct file_system_type___103;

struct super_operations___103;

struct dquot_operations___103;

struct quotactl_ops___103;

struct super_block___103 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___103 *s_type;
	const struct super_operations___103 *s_op;
	const struct dquot_operations___103 *dq_op;
	const struct quotactl_ops___103 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___103 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___69 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___103 *s_bdev;
	struct backing_dev_info___15 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___103 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___105 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___103 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___12(struct bio___12 *, int);

struct bio_vec___12 {
	struct page___103 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___12;

struct bio_set___12;

struct bio___12 {
	sector_t bi_sector;
	struct bio___12 *bi_next;
	struct block_device___103 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___12 *bi_end_io;
	void *bi_private;
	struct io_context___12 *bi_ioc;
	struct cgroup_subsys_state___71 *bi_css;
	struct bio_integrity_payload___12 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___12 *bi_io_vec;
	struct bio_set___12 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	struct bio_vec___12 bi_inline_vecs[0];
};

struct hd_struct___13;

struct gendisk___13;

struct request_queue___12;

struct block_device___103 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___103 *bd_inode;
	struct super_block___103 *bd_super;
	struct mutex___105 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___103 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___13 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___13 *bd_disk;
	struct request_queue___12 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___105 bd_fsfreeze_mutex;
};

struct cgroup___70;

struct cgroup_subsys_state___71 {
	struct cgroup___70 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___12 {
	struct bio___12 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___12 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___12 *bip_vec;
	struct bio_vec___12 bip_inline_vecs[0];
};

struct bio_set___12 {
	struct kmem_cache___91 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___12 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___103 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___103 *ia_file;
};

struct dquot___103 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___105 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___103 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___103 {
	int qf_fmt_id;
	const struct quota_format_ops___103 *qf_ops;
	struct module___56 *qf_owner;
	struct quota_format_type___103 *qf_next;
};

struct quota_format_ops___103 {
	int (*check_quota_file)(struct super_block___103 *, int);
	int (*read_file_info)(struct super_block___103 *, int);
	int (*write_file_info)(struct super_block___103 *, int);
	int (*free_file_info)(struct super_block___103 *, int);
	int (*read_dqblk)(struct dquot___103 *);
	int (*commit_dqblk)(struct dquot___103 *);
	int (*release_dqblk)(struct dquot___103 *);
};

struct dquot_operations___103 {
	int (*write_dquot)(struct dquot___103 *);
	struct dquot___103 * (*alloc_dquot)(struct super_block___103 *, int);
	void (*destroy_dquot)(struct dquot___103 *);
	int (*acquire_dquot)(struct dquot___103 *);
	int (*release_dquot)(struct dquot___103 *);
	int (*mark_dirty)(struct dquot___103 *);
	int (*write_info)(struct super_block___103 *, int);
	qsize_t * (*get_reserved_space)(struct inode___103 *);
};

struct quotactl_ops___103 {
	int (*quota_on)(struct super_block___103 *, int, int, struct path___103 *);
	int (*quota_on_meta)(struct super_block___103 *, int, int);
	int (*quota_off)(struct super_block___103 *, int);
	int (*quota_sync)(struct super_block___103 *, int);
	int (*get_info)(struct super_block___103 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___103 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___103 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___103 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___103 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___103 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___103 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___103 *, unsigned int);
};

struct swap_info_struct___19;

struct address_space_operations___103 {
	int (*writepage)(struct page___103 *, struct writeback_control *);
	int (*readpage)(struct file___103 *, struct page___103 *);
	int (*writepages)(struct address_space___103 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___103 *);
	int (*readpages)(struct file___103 *, struct address_space___103 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___103 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___103 **, void **);
	int (*write_end)(struct file___103 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___103 *, void *);
	sector_t (*bmap)(struct address_space___103 *, sector_t);
	void (*invalidatepage)(struct page___103 *, long unsigned int);
	int (*releasepage)(struct page___103 *, gfp_t);
	void (*freepage)(struct page___103 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___103 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___103 *, struct page___103 *, struct page___103 *, enum migrate_mode);
	int (*launder_page)(struct page___103 *);
	int (*is_partially_uptodate)(struct page___103 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___103 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___103 *, struct page___103 *);
	int (*swap_activate)(struct swap_info_struct___19 *, struct file___103 *, sector_t *);
	void (*swap_deactivate)(struct file___103 *);
	void (*invalidatepage_range)(struct page___103 *, unsigned int, unsigned int);
};

struct swap_info_struct___19 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___103 *bdev;
	struct file___103 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___13 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___82 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___13;

struct block_device_operations___12;

struct gendisk___13 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___13 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___13 *part_tbl;
	struct hd_struct___13 part0;
	const struct block_device_operations___12 *fops;
	struct request_queue___12 *queue;
	void *private_data;
	int flags;
	struct device___82 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___12 {
	struct request_queue___12 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___12(struct request_queue___12 *);

typedef void make_request_fn___12(struct request_queue___12 *, struct bio___12 *);

struct request___12;

typedef int prep_rq_fn___12(struct request_queue___12 *, struct request___12 *);

struct bvec_merge_data___12;

typedef int merge_bvec_fn___12(struct request_queue___12 *, struct bvec_merge_data___12 *, struct bio_vec___12 *);

typedef void softirq_done_fn___12(struct request___12 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___12(struct request___12 *);

typedef int dma_drain_needed_fn___12(struct request___12 *);

typedef int lld_busy_fn___12(struct request_queue___12 *);

struct bsg_class_device___12 {
	struct device___82 *class_dev;
	struct device___82 *parent;
	int minor;
	struct request_queue___12 *queue;
	struct kref ref;
	void (*release)(struct device___82 *);
};

typedef void unprep_rq_fn___12(struct request_queue___12 *, struct request___12 *);

struct elevator_queue___12;

struct blk_queue_tag___12;

struct request_queue___12 {
	struct list_head queue_head;
	struct request___12 *last_merge;
	struct elevator_queue___12 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___12 root_rl;
	request_fn_proc___12 *request_fn;
	make_request_fn___12 *make_request_fn;
	prep_rq_fn___12 *prep_rq_fn;
	merge_bvec_fn___12 *merge_bvec_fn;
	softirq_done_fn___12 *softirq_done_fn;
	rq_timed_out_fn___12 *rq_timed_out_fn;
	dma_drain_needed_fn___12 *dma_drain_needed;
	lld_busy_fn___12 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___12 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___15 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___82 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___12 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___12 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___105 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___12 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___12 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___12 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___103 {
	struct dentry___103 * (*lookup)(struct inode___103 *, struct dentry___103 *, unsigned int);
	void * (*follow_link)(struct dentry___103 *, struct nameidata *);
	int (*permission)(struct inode___103 *, int);
	struct posix_acl * (*get_acl)(struct inode___103 *, int);
	int (*readlink)(struct dentry___103 *, char *, int);
	void (*put_link)(struct dentry___103 *, struct nameidata *, void *);
	int (*create)(struct inode___103 *, struct dentry___103 *, umode_t, bool);
	int (*link)(struct dentry___103 *, struct inode___103 *, struct dentry___103 *);
	int (*unlink)(struct inode___103 *, struct dentry___103 *);
	int (*symlink)(struct inode___103 *, struct dentry___103 *, const char *);
	int (*mkdir)(struct inode___103 *, struct dentry___103 *, umode_t);
	int (*rmdir)(struct inode___103 *, struct dentry___103 *);
	int (*mknod)(struct inode___103 *, struct dentry___103 *, umode_t, dev_t);
	int (*rename)(struct inode___103 *, struct dentry___103 *, struct inode___103 *, struct dentry___103 *);
	int (*setattr)(struct dentry___103 *, struct iattr___103 *);
	int (*getattr)(struct vfsmount *, struct dentry___103 *, struct kstat *);
	int (*setxattr)(struct dentry___103 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___103 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___103 *, char *, size_t);
	int (*removexattr)(struct dentry___103 *, const char *);
	int (*fiemap)(struct inode___103 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___103 *, struct timespec *, int);
	int (*atomic_open)(struct inode___103 *, struct dentry___103 *, struct file___103 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___66;

struct seq_file___78;

struct file_operations___103 {
	struct module___56 *owner;
	loff_t (*llseek)(struct file___103 *, loff_t, int);
	ssize_t (*read)(struct file___103 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___103 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___103 *, void *, filldir_t);
	unsigned int (*poll)(struct file___103 *, struct poll_table_struct___66 *);
	long int (*unlocked_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___103 *, struct vm_area_struct___108 *);
	int (*open)(struct inode___103 *, struct file___103 *);
	int (*flush)(struct file___103 *, fl_owner_t);
	int (*release)(struct inode___103 *, struct file___103 *);
	int (*fsync)(struct file___103 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___103 *, int);
	int (*lock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*sendpage)(struct file___103 *, struct page___103 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___103 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___103 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___103 *, long int, struct file_lock___103 **, void **);
		struct {
			int (*setlease)(struct file___103 *, long int, struct file_lock___103 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___103 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___78 *, struct file___103 *);
};

struct file_lock_operations___103;

struct lock_manager_operations___103;

struct file_lock___103 {
	struct file_lock___103 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___59 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___103 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___103 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___103 *fl_ops;
	const struct lock_manager_operations___103 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___103 {
	void (*fl_copy_lock)(struct file_lock___103 *, struct file_lock___103 *);
	void (*fl_release_private)(struct file_lock___103 *);
};

struct lock_manager_operations___103 {
	int (*lm_compare_owner)(struct file_lock___103 *, struct file_lock___103 *);
	long unsigned int (*lm_owner_key)(struct file_lock___103 *);
	void (*lm_notify)(struct file_lock___103 *);
	int (*lm_grant)(struct file_lock___103 *, struct file_lock___103 *, int);
	void (*lm_break)(struct file_lock___103 *);
	int (*lm_change)(struct file_lock___103 **, int);
};

struct fasync_struct___103 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___103 *fa_next;
	struct file___103 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___103 {
	const char *name;
	int fs_flags;
	struct dentry___103 * (*mount)(struct file_system_type___103 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___103 *);
	struct module___56 *owner;
	struct file_system_type___103 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___103 {
	struct inode___103 * (*alloc_inode)(struct super_block___103 *);
	void (*destroy_inode)(struct inode___103 *);
	void (*dirty_inode)(struct inode___103 *, int);
	int (*write_inode)(struct inode___103 *, struct writeback_control *);
	int (*drop_inode)(struct inode___103 *);
	void (*evict_inode)(struct inode___103 *);
	void (*put_super)(struct super_block___103 *);
	int (*sync_fs)(struct super_block___103 *, int);
	int (*freeze_fs)(struct super_block___103 *);
	int (*unfreeze_fs)(struct super_block___103 *);
	int (*statfs)(struct dentry___103 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___103 *, int *, char *);
	void (*umount_begin)(struct super_block___103 *);
	int (*show_options)(struct seq_file___78 *, struct dentry___103 *);
	int (*show_devname)(struct seq_file___78 *, struct dentry___103 *);
	int (*show_path)(struct seq_file___78 *, struct dentry___103 *);
	int (*show_stats)(struct seq_file___78 *, struct dentry___103 *);
	ssize_t (*quota_read)(struct super_block___103 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___103 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___103 *);
	int (*bdev_try_to_free_page)(struct super_block___103 *, struct page___103 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___103 *);
	void (*free_cached_objects)(struct super_block___103 *, int);
};

typedef void (*poll_queue_proc___68)(struct file___103 *, wait_queue_head_t *, struct poll_table_struct___66 *);

struct poll_table_struct___66 {
	poll_queue_proc___68 _qproc;
	long unsigned int _key;
};

struct seq_operations___77;

struct seq_file___78 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___105 lock;
	const struct seq_operations___77 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___69;

struct cgroup___70 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___70 *parent;
	struct dentry___103 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___71 *subsys[11];
	struct cgroupfs_root___69 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___105 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___69 {
	struct super_block___103 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___70 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___27 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___103 *, struct file___103 *);
	ssize_t (*read)(struct cgroup___70 *, struct cftype___27 *, struct file___103 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___70 *, struct cftype___27 *);
	s64 (*read_s64)(struct cgroup___70 *, struct cftype___27 *);
	int (*read_map)(struct cgroup___70 *, struct cftype___27 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___70 *, struct cftype___27 *, struct seq_file___78 *);
	ssize_t (*write)(struct cgroup___70 *, struct cftype___27 *, struct file___103 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___70 *, struct cftype___27 *, u64);
	int (*write_s64)(struct cgroup___70 *, struct cftype___27 *, s64);
	int (*write_string)(struct cgroup___70 *, struct cftype___27 *, const char *);
	int (*trigger)(struct cgroup___70 *, unsigned int);
	int (*release)(struct inode___103 *, struct file___103 *);
	int (*register_event)(struct cgroup___70 *, struct cftype___27 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___70 *, struct cftype___27 *, struct eventfd_ctx *);
};

struct cftype_set___25 {
	struct list_head node;
	struct cftype___27 *cfts;
};

struct task_and_cgroup___25 {
	struct task_struct___104 *task;
	struct cgroup___70 *cgrp;
	struct css_set___69 *cg;
};

struct cgroup_taskset___25 {
	struct task_and_cgroup___25 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___70 *cur_cgrp;
};

struct cgroup_subsys___25 {
	struct cgroup_subsys_state___71 * (*css_alloc)(struct cgroup___70 *);
	int (*css_online)(struct cgroup___70 *);
	void (*css_offline)(struct cgroup___70 *);
	void (*css_free)(struct cgroup___70 *);
	int (*can_attach)(struct cgroup___70 *, struct cgroup_taskset___25 *);
	void (*cancel_attach)(struct cgroup___70 *, struct cgroup_taskset___25 *);
	void (*attach)(struct cgroup___70 *, struct cgroup_taskset___25 *);
	void (*fork)(struct task_struct___104 *);
	void (*exit)(struct cgroup___70 *, struct cgroup___70 *, struct task_struct___104 *);
	void (*bind)(struct cgroup___70 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___69 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___27 *base_cftypes;
	struct cftype_set___25 base_cftset;
	struct module___56 *module;
};

struct irq_chip___76 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___76 *);
	void (*irq_shutdown)(struct irq_data___76 *);
	void (*irq_enable)(struct irq_data___76 *);
	void (*irq_disable)(struct irq_data___76 *);
	void (*irq_ack)(struct irq_data___76 *);
	void (*irq_mask)(struct irq_data___76 *);
	void (*irq_mask_ack)(struct irq_data___76 *);
	void (*irq_unmask)(struct irq_data___76 *);
	void (*irq_eoi)(struct irq_data___76 *);
	int (*irq_set_affinity)(struct irq_data___76 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___76 *);
	int (*irq_set_type)(struct irq_data___76 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___76 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___76 *);
	void (*irq_bus_sync_unlock)(struct irq_data___76 *);
	void (*irq_cpu_online)(struct irq_data___76 *);
	void (*irq_cpu_offline)(struct irq_data___76 *);
	void (*irq_suspend)(struct irq_data___76 *);
	void (*irq_resume)(struct irq_data___76 *);
	void (*irq_pm_shutdown)(struct irq_data___76 *);
	void (*irq_print_chip)(struct irq_data___76 *, struct seq_file___78 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___76 *, void *);
	long unsigned int flags;
};

struct bus_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___82 *, char *);
	ssize_t (*store)(struct bus_type___82 *, const char *, size_t);
};

struct device_attribute___82;

struct driver_attribute___82;

struct bus_type___82 {
	const char *name;
	const char *dev_name;
	struct device___82 *dev_root;
	struct bus_attribute___82 *bus_attrs;
	struct device_attribute___82 *dev_attrs;
	struct driver_attribute___82 *drv_attrs;
	const struct attribute_group___75 **bus_groups;
	const struct attribute_group___75 **dev_groups;
	const struct attribute_group___75 **drv_groups;
	int (*match)(struct device___82 *, struct device_driver___82 *);
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	int (*probe)(struct device___82 *);
	int (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*online)(struct device___82 *);
	int (*offline)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct device___82 *, struct device_attribute___82 *, char *);
	ssize_t (*store)(struct device___82 *, struct device_attribute___82 *, const char *, size_t);
};

struct driver_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___82 *, char *);
	ssize_t (*store)(struct device_driver___82 *, const char *, size_t);
};

struct device_driver___82 {
	const char *name;
	struct bus_type___82 *bus;
	struct module___56 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___82 *);
	int (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	const struct attribute_group___75 **groups;
	const struct dev_pm_ops___82 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___82 {
	const char *name;
	const struct attribute_group___75 **groups;
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
};

struct class_attribute___82;

struct class___82 {
	const char *name;
	struct module___56 *owner;
	struct class_attribute___82 *class_attrs;
	struct device_attribute___82 *dev_attrs;
	const struct attribute_group___75 **dev_groups;
	struct bin_attribute___75 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *);
	void (*class_release)(struct class___82 *);
	void (*dev_release)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
	struct subsys_private *p;
};

struct class_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct class___82 *, struct class_attribute___82 *, char *);
	ssize_t (*store)(struct class___82 *, struct class_attribute___82 *, const char *, size_t);
	const void * (*namespace)(struct class___82 *, const struct class_attribute___82 *);
};

struct device_rh___82 {
	struct dev_pm_info_rh___82 power;
};

struct module_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___55 *, struct module_kobject___55 *, char *);
	ssize_t (*store)(struct module_attribute___55 *, struct module_kobject___55 *, const char *, size_t);
	void (*setup)(struct module___56 *, const char *);
	int (*test)(struct module___56 *);
	void (*free)(struct module___56 *);
};

struct trace_event_functions___44;

struct trace_event___44 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___44 *funcs;
};

struct ftrace_event_class___44;

struct ftrace_event_call___44 {
	struct list_head list;
	struct ftrace_event_class___44 *class;
	char *name;
	struct trace_event___44 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct disk_part_tbl___13 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___13 *last_lookup;
	struct hd_struct___13 *part[0];
};

struct block_device_operations___12 {
	int (*open)(struct block_device___103 *, fmode_t);
	void (*release)(struct gendisk___13 *, fmode_t);
	int (*ioctl)(struct block_device___103 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___103 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___103 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___13 *, unsigned int);
	int (*media_changed)(struct gendisk___13 *);
	void (*unlock_native_capacity)(struct gendisk___13 *);
	int (*revalidate_disk)(struct gendisk___13 *);
	int (*getgeo)(struct block_device___103 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___103 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___56 *owner;
};

enum {
	BLK_RW_ASYNC = 0,
	BLK_RW_SYNC = 1,
};

struct io_cq___12 {
	struct request_queue___12 *q;
	struct io_context___12 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___91 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___12(struct request___12 *, int);

struct request___12 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___12 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___12 *bio;
	struct bio___12 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___12 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___12 *saved_end_io;
		} flush;
	};
	struct gendisk___13 *rq_disk;
	struct hd_struct___13 *part;
	long unsigned int start_time;
	struct request_list___12 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___12 *end_io;
	void *end_io_data;
	struct request___12 *next_rq;
};

typedef int elevator_merge_fn___12(struct request_queue___12 *, struct request___12 **, struct bio___12 *);

typedef void elevator_merge_req_fn___12(struct request_queue___12 *, struct request___12 *, struct request___12 *);

typedef void elevator_merged_fn___12(struct request_queue___12 *, struct request___12 *, int);

typedef int elevator_allow_merge_fn___12(struct request_queue___12 *, struct request___12 *, struct bio___12 *);

typedef void elevator_bio_merged_fn___12(struct request_queue___12 *, struct request___12 *, struct bio___12 *);

typedef int elevator_dispatch_fn___12(struct request_queue___12 *, int);

typedef void elevator_add_req_fn___12(struct request_queue___12 *, struct request___12 *);

typedef struct request___12 *elevator_request_list_fn___12(struct request_queue___12 *, struct request___12 *);

typedef void elevator_completed_req_fn___12(struct request_queue___12 *, struct request___12 *);

typedef int elevator_may_queue_fn___12(struct request_queue___12 *, int);

typedef void elevator_init_icq_fn___12(struct io_cq___12 *);

typedef void elevator_exit_icq_fn___12(struct io_cq___12 *);

typedef int elevator_set_req_fn___12(struct request_queue___12 *, struct request___12 *, struct bio___12 *, gfp_t);

typedef void elevator_put_req_fn___12(struct request___12 *);

typedef void elevator_activate_req_fn___12(struct request_queue___12 *, struct request___12 *);

typedef void elevator_deactivate_req_fn___12(struct request_queue___12 *, struct request___12 *);

struct elevator_type___12;

typedef int elevator_init_fn___12(struct request_queue___12 *, struct elevator_type___12 *);

typedef void elevator_exit_fn___12(struct elevator_queue___12 *);

struct elevator_ops___12 {
	elevator_merge_fn___12 *elevator_merge_fn;
	elevator_merged_fn___12 *elevator_merged_fn;
	elevator_merge_req_fn___12 *elevator_merge_req_fn;
	elevator_allow_merge_fn___12 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___12 *elevator_bio_merged_fn;
	elevator_dispatch_fn___12 *elevator_dispatch_fn;
	elevator_add_req_fn___12 *elevator_add_req_fn;
	elevator_activate_req_fn___12 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___12 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___12 *elevator_completed_req_fn;
	elevator_request_list_fn___12 *elevator_former_req_fn;
	elevator_request_list_fn___12 *elevator_latter_req_fn;
	elevator_init_icq_fn___12 *elevator_init_icq_fn;
	elevator_exit_icq_fn___12 *elevator_exit_icq_fn;
	elevator_set_req_fn___12 *elevator_set_req_fn;
	elevator_put_req_fn___12 *elevator_put_req_fn;
	elevator_may_queue_fn___12 *elevator_may_queue_fn;
	elevator_init_fn___12 *elevator_init_fn;
	elevator_exit_fn___12 *elevator_exit_fn;
};

struct elv_fs_entry___12;

struct elevator_type___12 {
	struct kmem_cache___91 *icq_cache;
	struct elevator_ops___12 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___12 *elevator_attrs;
	char elevator_name[16];
	struct module___56 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___12 {
	struct elevator_type___12 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___105 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___12 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___12 *, char *);
	ssize_t (*store)(struct elevator_queue___12 *, const char *, size_t);
};

struct bvec_merge_data___12 {
	struct block_device___103 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___12 {
	struct request___12 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___77 {
	void * (*start)(struct seq_file___78 *, loff_t *);
	void (*stop)(struct seq_file___78 *, void *);
	void * (*next)(struct seq_file___78 *, void *, loff_t *);
	int (*show)(struct seq_file___78 *, void *);
};

struct perf_cpu_context___54;

struct pmu___54 {
	struct list_head entry;
	struct device___82 *dev;
	const struct attribute_group___75 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___54 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___54 *);
	void (*pmu_disable)(struct pmu___54 *);
	int (*event_init)(struct perf_event___54 *);
	int (*add)(struct perf_event___54 *, int);
	void (*del)(struct perf_event___54 *, int);
	void (*start)(struct perf_event___54 *, int);
	void (*stop)(struct perf_event___54 *, int);
	void (*read)(struct perf_event___54 *);
	void (*start_txn)(struct pmu___54 *);
	int (*commit_txn)(struct pmu___54 *);
	void (*cancel_txn)(struct pmu___54 *);
	int (*event_idx)(struct perf_event___54 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___56 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___54 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___54 *);
};

struct perf_cpu_context___54 {
	struct perf_event_context___54 ctx;
	struct perf_event_context___54 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___54 *unique_pmu;
	struct perf_cgroup___54 *cgrp;
};

struct perf_cgroup___54 {
	struct cgroup_subsys_state___71 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___44 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___105 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___44)(struct trace_iterator___44 *, int, struct trace_event___44 *);

struct trace_event_functions___44 {
	trace_print_func___44 trace;
	trace_print_func___44 raw;
	trace_print_func___44 hex;
	trace_print_func___44 binary;
};

struct ftrace_event_class___44 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___44 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___44 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___44 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___44 *);
};

typedef struct page___103 *new_page_t(struct page___103 *, long unsigned int, int **);

typedef void free_page_t(struct page___103 *, long unsigned int);

enum migrate_reason {
	MR_COMPACTION = 0,
	MR_MEMORY_FAILURE = 1,
	MR_MEMORY_HOTPLUG = 2,
	MR_SYSCALL = 3,
	MR_MEMPOLICY_MBIND = 4,
	MR_NUMA_MISPLACED = 5,
	MR_CMA = 6,
};

struct tlb_state___26 {
	struct mm_struct___108 *active_mm;
	int state;
};

struct hstate___6 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___27 cgroup_files[5];
	char name[32];
};

struct compact_control {
	struct list_head freepages;
	struct list_head migratepages;
	long unsigned int nr_freepages;
	long unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	int order;
	const gfp_t gfp_mask;
	const int alloc_flags;
	const int classzone_idx;
	struct zone___103 *zone;
	int contended;
};

enum mminit_level {
	MMINIT_WARNING = 0,
	MMINIT_VERIFY = 1,
	MMINIT_TRACE = 2,
};

enum wb_reason {
	WB_REASON_BACKGROUND = 0,
	WB_REASON_TRY_TO_FREE_PAGES = 1,
	WB_REASON_SYNC = 2,
	WB_REASON_PERIODIC = 3,
	WB_REASON_LAPTOP_TIMER = 4,
	WB_REASON_FREE_MORE_MEM = 5,
	WB_REASON_FS_FREE_SPACE = 6,
	WB_REASON_FORKER_THREAD = 7,
	WB_REASON_MAX = 8,
};

typedef int (*writepage_t)(struct page___101 *, struct writeback_control *, void *);

struct fprop_global {
	struct percpu_counter events;
	unsigned int period;
	seqcount_t sequence;
};

struct syscall_metadata___15 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___43 *enter_event;
	struct ftrace_event_call___43 *exit_event;
};

struct fd___6 {
	struct file___101 *file;
	unsigned int flags;
};

typedef void compound_page_dtor___2(struct page___65 *);

struct pagevec___2 {
	long unsigned int nr;
	long unsigned int cold;
	struct page___65 *pages[14];
};

struct kvec {
	void *iov_base;
	size_t iov_len;
};

struct ftrace_raw_mm_lru_insertion {
	struct trace_entry ent;
	struct page___65 *page;
	long unsigned int pfn;
	int lru;
	long unsigned int flags;
	char __data[0];
};

struct ftrace_raw_mm_lru_activate {
	struct trace_entry ent;
	struct page___65 *page;
	long unsigned int pfn;
	char __data[0];
};

struct ftrace_data_offsets_mm_lru_insertion {};

struct ftrace_data_offsets_mm_lru_activate {};

struct page___104;

typedef struct page___104 *pgtable_t___104;

struct address_space___104;

struct kmem_cache___92;

struct page___104 {
	long unsigned int flags;
	struct address_space___104 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___104 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___104 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___92 *slab_cache;
		struct page___104 *first_page;
	};
	long: 64;
};

struct task_struct___105;

struct pv_cpu_ops___104 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___54 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___54 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___105 *);
	void (*end_context_switch)(struct task_struct___105 *);
};

struct mutex___106 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___105 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___100 {
	struct page___104 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___109;

struct signal_struct___104;

struct backing_dev_info___16;

struct css_set___70;

struct task_struct___105 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___105 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___109 *mm;
	struct mm_struct___109 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___105 *real_parent;
	struct task_struct___105 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___105 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___59 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___104 = 0,
		VTIME_USER___104 = 1,
		VTIME_SYS___104 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___54 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___104 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___16 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___70 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___106 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___100 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___109 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___109 *, struct mm_struct___109 *);
	void (*dup_mmap)(struct mm_struct___109 *, struct mm_struct___109 *);
	void (*exit_mmap)(struct mm_struct___109 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___109 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___109 *);
	void (*pgd_free)(struct mm_struct___109 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___109 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___109 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___109 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___109 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___109 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___109 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___109 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___109 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___109 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___109 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___109 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___106 lock;
	void *vdso;
} mm_context_t___105;

struct xol_area___104;

struct uprobes_state___104 {
	struct xol_area___104 *xol_area;
};

struct vm_area_struct___109;

struct file___104;

struct core_state___104;

struct mm_struct___109 {
	struct vm_area_struct___109 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___109 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___109 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___105 context;
	long unsigned int flags;
	struct core_state___104 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___105 *owner;
	struct file___104 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___104 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___53 {
	struct task_struct___105 *task;
	struct exec_domain___28 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct device___83;

struct dev_pm_ops___83 {
	int (*prepare)(struct device___83 *);
	void (*complete)(struct device___83 *);
	int (*suspend)(struct device___83 *);
	int (*resume)(struct device___83 *);
	int (*freeze)(struct device___83 *);
	int (*thaw)(struct device___83 *);
	int (*poweroff)(struct device___83 *);
	int (*restore)(struct device___83 *);
	int (*suspend_late)(struct device___83 *);
	int (*resume_early)(struct device___83 *);
	int (*freeze_late)(struct device___83 *);
	int (*thaw_early)(struct device___83 *);
	int (*poweroff_late)(struct device___83 *);
	int (*restore_early)(struct device___83 *);
	int (*suspend_noirq)(struct device___83 *);
	int (*resume_noirq)(struct device___83 *);
	int (*freeze_noirq)(struct device___83 *);
	int (*thaw_noirq)(struct device___83 *);
	int (*poweroff_noirq)(struct device___83 *);
	int (*restore_noirq)(struct device___83 *);
	int (*runtime_suspend)(struct device___83 *);
	int (*runtime_resume)(struct device___83 *);
	int (*runtime_idle)(struct device___83 *);
};

struct device_type___83;

struct bus_type___83;

struct device_driver___83;

struct dev_pm_domain___83;

struct class___83;

struct attribute_group___76;

struct device_rh___83;

struct device___83 {
	struct device___83 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___83 *type;
	struct mutex___106 mutex;
	struct bus_type___83 *bus;
	struct device_driver___83 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___83 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___83 *class;
	const struct attribute_group___76 **groups;
	void (*release)(struct device___83 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___83 *device_rh;
};

struct dev_pm_info_rh___83 {
	void (*set_latency_tolerance)(struct device___83 *, s32);
};

struct dev_pm_domain___83 {
	struct dev_pm_ops___83 ops;
};

struct smp_ops___104 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___105 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___104;

struct lruvec___104 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___104 *zone;
};

struct pglist_data___104;

struct zone___104 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___104 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___104 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___104 {
	struct zone___104 *zone;
	int zone_idx;
};

struct zonelist___104 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___104 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___104 {
	struct zone___104 node_zones[4];
	struct zonelist___104 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___105 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inode___104;

struct dentry_operations___104;

struct super_block___104;

struct dentry___104 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___104 *d_parent;
	struct qstr d_name;
	struct inode___104 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___104 *d_op;
	struct super_block___104 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___104;

struct address_space___104 {
	struct inode___104 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___106 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___104 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___16 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___104;

struct file_operations___104;

struct file_lock___104;

struct dquot___104;

struct block_device___104;

struct inode___104 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___104 *i_op;
	struct super_block___104 *i_sb;
	struct address_space___104 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___106 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___104 *i_fop;
	struct file_lock___104 *i_flock;
	struct address_space___104 i_data;
	struct dquot___104 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___104 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___104;

struct dentry_operations___104 {
	int (*d_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_hash)(const struct dentry___104 *, struct qstr *);
	int (*d_compare)(const struct dentry___104 *, const struct dentry___104 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___104 *);
	void (*d_release)(struct dentry___104 *);
	void (*d_prune)(struct dentry___104 *);
	void (*d_iput)(struct dentry___104 *, struct inode___104 *);
	char * (*d_dname)(struct dentry___104 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___104 *);
	int (*d_manage)(struct dentry___104 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___104;

struct mem_dqinfo___104 {
	struct quota_format_type___104 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___104;

struct quota_info___104 {
	unsigned int flags;
	struct mutex___106 dqio_mutex;
	struct mutex___106 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___104 *files[2];
	struct mem_dqinfo___104 info[2];
	const struct quota_format_ops___104 *ops[2];
};

struct file_system_type___104;

struct super_operations___104;

struct dquot_operations___104;

struct quotactl_ops___104;

struct export_operations___2;

struct xattr_handler___70;

struct super_block___104 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___104 *s_type;
	const struct super_operations___104 *s_op;
	const struct dquot_operations___104 *dq_op;
	const struct quotactl_ops___104 *s_qcop;
	const struct export_operations___2 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___104 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___70 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___104 *s_bdev;
	struct backing_dev_info___16 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___104 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___106 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___104 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___104 {
	struct vfsmount *mnt;
	struct dentry___104 *dentry;
};

struct block_device___104 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___104 *bd_inode;
	struct super_block___104 *bd_super;
	struct mutex___106 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___104 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___106 bd_fsfreeze_mutex;
};

struct cgroup___71;

struct cgroup_subsys_state___72 {
	struct cgroup___71 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___104 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___104 *ia_file;
};

struct file___104 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___104 f_path;
	struct inode___104 *f_inode;
	const struct file_operations___104 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___59 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___104 *f_mapping;
	struct mutex___106 f_pos_lock;
};

struct dquot___104 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___106 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___104 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___104 {
	int qf_fmt_id;
	const struct quota_format_ops___104 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___104 *qf_next;
};

struct quota_format_ops___104 {
	int (*check_quota_file)(struct super_block___104 *, int);
	int (*read_file_info)(struct super_block___104 *, int);
	int (*write_file_info)(struct super_block___104 *, int);
	int (*free_file_info)(struct super_block___104 *, int);
	int (*read_dqblk)(struct dquot___104 *);
	int (*commit_dqblk)(struct dquot___104 *);
	int (*release_dqblk)(struct dquot___104 *);
};

struct dquot_operations___104 {
	int (*write_dquot)(struct dquot___104 *);
	struct dquot___104 * (*alloc_dquot)(struct super_block___104 *, int);
	void (*destroy_dquot)(struct dquot___104 *);
	int (*acquire_dquot)(struct dquot___104 *);
	int (*release_dquot)(struct dquot___104 *);
	int (*mark_dirty)(struct dquot___104 *);
	int (*write_info)(struct super_block___104 *, int);
	qsize_t * (*get_reserved_space)(struct inode___104 *);
};

struct quotactl_ops___104 {
	int (*quota_on)(struct super_block___104 *, int, int, struct path___104 *);
	int (*quota_on_meta)(struct super_block___104 *, int, int);
	int (*quota_off)(struct super_block___104 *, int);
	int (*quota_sync)(struct super_block___104 *, int);
	int (*get_info)(struct super_block___104 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___104 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___104 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___104 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___104 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___104 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___104 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___104 *, unsigned int);
};

struct swap_info_struct___20;

struct address_space_operations___104 {
	int (*writepage)(struct page___104 *, struct writeback_control *);
	int (*readpage)(struct file___104 *, struct page___104 *);
	int (*writepages)(struct address_space___104 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___104 *);
	int (*readpages)(struct file___104 *, struct address_space___104 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___104 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___104 **, void **);
	int (*write_end)(struct file___104 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___104 *, void *);
	sector_t (*bmap)(struct address_space___104 *, sector_t);
	void (*invalidatepage)(struct page___104 *, long unsigned int);
	int (*releasepage)(struct page___104 *, gfp_t);
	void (*freepage)(struct page___104 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___104 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___104 *, struct page___104 *, struct page___104 *, enum migrate_mode);
	int (*launder_page)(struct page___104 *);
	int (*is_partially_uptodate)(struct page___104 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___104 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___104 *, struct page___104 *);
	int (*swap_activate)(struct swap_info_struct___20 *, struct file___104 *, sector_t *);
	void (*swap_deactivate)(struct file___104 *);
	void (*invalidatepage_range)(struct page___104 *, unsigned int, unsigned int);
};

struct swap_info_struct___20 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___104 *bdev;
	struct file___104 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___16 {
	struct backing_dev_info___16 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___16 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___16 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___83 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___104 *debug_dir;
	struct dentry___104 *debug_stats;
};

struct inode_operations___104 {
	struct dentry___104 * (*lookup)(struct inode___104 *, struct dentry___104 *, unsigned int);
	void * (*follow_link)(struct dentry___104 *, struct nameidata *);
	int (*permission)(struct inode___104 *, int);
	struct posix_acl * (*get_acl)(struct inode___104 *, int);
	int (*readlink)(struct dentry___104 *, char *, int);
	void (*put_link)(struct dentry___104 *, struct nameidata *, void *);
	int (*create)(struct inode___104 *, struct dentry___104 *, umode_t, bool);
	int (*link)(struct dentry___104 *, struct inode___104 *, struct dentry___104 *);
	int (*unlink)(struct inode___104 *, struct dentry___104 *);
	int (*symlink)(struct inode___104 *, struct dentry___104 *, const char *);
	int (*mkdir)(struct inode___104 *, struct dentry___104 *, umode_t);
	int (*rmdir)(struct inode___104 *, struct dentry___104 *);
	int (*mknod)(struct inode___104 *, struct dentry___104 *, umode_t, dev_t);
	int (*rename)(struct inode___104 *, struct dentry___104 *, struct inode___104 *, struct dentry___104 *);
	int (*setattr)(struct dentry___104 *, struct iattr___104 *);
	int (*getattr)(struct vfsmount *, struct dentry___104 *, struct kstat *);
	int (*setxattr)(struct dentry___104 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___104 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___104 *, char *, size_t);
	int (*removexattr)(struct dentry___104 *, const char *);
	int (*fiemap)(struct inode___104 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___104 *, struct timespec *, int);
	int (*atomic_open)(struct inode___104 *, struct dentry___104 *, struct file___104 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___104 {
	struct module *owner;
	loff_t (*llseek)(struct file___104 *, loff_t, int);
	ssize_t (*read)(struct file___104 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___104 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___104 *, void *, filldir_t);
	unsigned int (*poll)(struct file___104 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___104 *, struct vm_area_struct___109 *);
	int (*open)(struct inode___104 *, struct file___104 *);
	int (*flush)(struct file___104 *, fl_owner_t);
	int (*release)(struct inode___104 *, struct file___104 *);
	int (*fsync)(struct file___104 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___104 *, int);
	int (*lock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*sendpage)(struct file___104 *, struct page___104 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___104 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___104 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___104 *, long int, struct file_lock___104 **, void **);
		struct {
			int (*setlease)(struct file___104 *, long int, struct file_lock___104 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___104 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___104 *);
};

struct fasync_struct___104;

struct file_lock_operations___104;

struct lock_manager_operations___104;

struct file_lock___104 {
	struct file_lock___104 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___59 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___104 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___104 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___104 *fl_ops;
	const struct lock_manager_operations___104 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___104 {
	void (*fl_copy_lock)(struct file_lock___104 *, struct file_lock___104 *);
	void (*fl_release_private)(struct file_lock___104 *);
};

struct lock_manager_operations___104 {
	int (*lm_compare_owner)(struct file_lock___104 *, struct file_lock___104 *);
	long unsigned int (*lm_owner_key)(struct file_lock___104 *);
	void (*lm_notify)(struct file_lock___104 *);
	int (*lm_grant)(struct file_lock___104 *, struct file_lock___104 *, int);
	void (*lm_break)(struct file_lock___104 *);
	int (*lm_change)(struct file_lock___104 **, int);
};

struct fasync_struct___104 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___104 *fa_next;
	struct file___104 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___104 {
	const char *name;
	int fs_flags;
	struct dentry___104 * (*mount)(struct file_system_type___104 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___104 *);
	struct module *owner;
	struct file_system_type___104 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___104 {
	struct inode___104 * (*alloc_inode)(struct super_block___104 *);
	void (*destroy_inode)(struct inode___104 *);
	void (*dirty_inode)(struct inode___104 *, int);
	int (*write_inode)(struct inode___104 *, struct writeback_control *);
	int (*drop_inode)(struct inode___104 *);
	void (*evict_inode)(struct inode___104 *);
	void (*put_super)(struct super_block___104 *);
	int (*sync_fs)(struct super_block___104 *, int);
	int (*freeze_fs)(struct super_block___104 *);
	int (*unfreeze_fs)(struct super_block___104 *);
	int (*statfs)(struct dentry___104 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___104 *, int *, char *);
	void (*umount_begin)(struct super_block___104 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___104 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___104 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___104 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___104 *);
	ssize_t (*quota_read)(struct super_block___104 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___104 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___104 *);
	int (*bdev_try_to_free_page)(struct super_block___104 *, struct page___104 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___104 *);
	void (*free_cached_objects)(struct super_block___104 *, int);
};

struct export_operations___2 {
	int (*encode_fh)(struct inode___104 *, __u32 *, int *, struct inode___104 *);
	struct dentry___104 * (*fh_to_dentry)(struct super_block___104 *, struct fid *, int, int);
	struct dentry___104 * (*fh_to_parent)(struct super_block___104 *, struct fid *, int, int);
	int (*get_name)(struct dentry___104 *, char *, struct dentry___104 *);
	struct dentry___104 * (*get_parent)(struct dentry___104 *);
	int (*commit_metadata)(struct inode___104 *);
	int (*get_uuid)(struct super_block___104 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___104 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___104 *, struct iomap *, int, struct iattr___104 *);
};

struct xattr_handler___70 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___104 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___104 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___104 *, const char *, const void *, size_t, int, int);
};

struct vm_operations_struct___92;

struct vm_area_struct___109 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___109 *vm_next;
	struct vm_area_struct___109 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___109 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___92 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___104 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xol_area___104 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___104 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___92;

struct memcg_cache_params___92;

struct kmem_cache___92 {
	struct kmem_cache_cpu___92 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___92 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___89;

struct vm_operations_struct___92 {
	void (*open)(struct vm_area_struct___109 *);
	void (*close)(struct vm_area_struct___109 *);
	int (*fault)(struct vm_area_struct___109 *, struct vm_fault___89 *);
	int (*page_mkwrite)(struct vm_area_struct___109 *, struct vm_fault___89 *);
	int (*access)(struct vm_area_struct___109 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___109 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___109 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___109 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___109 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___104 {
	struct task_struct___105 *task;
	struct core_thread___104 *next;
};

struct core_state___104 {
	atomic_t nr_threads;
	struct core_thread___104 dumper;
	struct completion startup;
};

struct signal_struct___104 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___105 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___105 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___59 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___59 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___106 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___70 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___72 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___89 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___104 *page;
};

struct bin_attribute___76;

struct attribute_group___76 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___76 **bin_attrs;
};

struct bin_attribute___76 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___104 *, struct kobject *, struct bin_attribute___76 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___104 *, struct kobject *, struct bin_attribute___76 *, char *, loff_t, size_t);
	int (*mmap)(struct file___104 *, struct kobject *, struct bin_attribute___76 *, struct vm_area_struct___109 *);
};

struct kmem_cache_cpu___92 {
	void **freelist;
	long unsigned int tid;
	struct page___104 *page;
	struct page___104 *partial;
};

struct memcg_cache_params___92 {
	bool is_root_cache;
	union {
		struct kmem_cache___92 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___92 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___70;

struct cgroup___71 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___71 *parent;
	struct dentry___104 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___72 *subsys[11];
	struct cgroupfs_root___70 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___106 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___70 {
	struct super_block___104 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___71 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___28 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___104 *, struct file___104 *);
	ssize_t (*read)(struct cgroup___71 *, struct cftype___28 *, struct file___104 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___71 *, struct cftype___28 *);
	s64 (*read_s64)(struct cgroup___71 *, struct cftype___28 *);
	int (*read_map)(struct cgroup___71 *, struct cftype___28 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___71 *, struct cftype___28 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___71 *, struct cftype___28 *, struct file___104 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___71 *, struct cftype___28 *, u64);
	int (*write_s64)(struct cgroup___71 *, struct cftype___28 *, s64);
	int (*write_string)(struct cgroup___71 *, struct cftype___28 *, const char *);
	int (*trigger)(struct cgroup___71 *, unsigned int);
	int (*release)(struct inode___104 *, struct file___104 *);
	int (*register_event)(struct cgroup___71 *, struct cftype___28 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___71 *, struct cftype___28 *, struct eventfd_ctx *);
};

struct cftype_set___26 {
	struct list_head node;
	struct cftype___28 *cfts;
};

struct task_and_cgroup___26 {
	struct task_struct___105 *task;
	struct cgroup___71 *cgrp;
	struct css_set___70 *cg;
};

struct cgroup_taskset___26 {
	struct task_and_cgroup___26 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___71 *cur_cgrp;
};

struct cgroup_subsys___26 {
	struct cgroup_subsys_state___72 * (*css_alloc)(struct cgroup___71 *);
	int (*css_online)(struct cgroup___71 *);
	void (*css_offline)(struct cgroup___71 *);
	void (*css_free)(struct cgroup___71 *);
	int (*can_attach)(struct cgroup___71 *, struct cgroup_taskset___26 *);
	void (*cancel_attach)(struct cgroup___71 *, struct cgroup_taskset___26 *);
	void (*attach)(struct cgroup___71 *, struct cgroup_taskset___26 *);
	void (*fork)(struct task_struct___105 *);
	void (*exit)(struct cgroup___71 *, struct cgroup___71 *, struct task_struct___105 *);
	void (*bind)(struct cgroup___71 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___70 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___28 *base_cftypes;
	struct cftype_set___26 base_cftset;
	struct module *module;
};

struct bus_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___83 *, char *);
	ssize_t (*store)(struct bus_type___83 *, const char *, size_t);
};

struct device_attribute___83;

struct driver_attribute___83;

struct bus_type___83 {
	const char *name;
	const char *dev_name;
	struct device___83 *dev_root;
	struct bus_attribute___83 *bus_attrs;
	struct device_attribute___83 *dev_attrs;
	struct driver_attribute___83 *drv_attrs;
	const struct attribute_group___76 **bus_groups;
	const struct attribute_group___76 **dev_groups;
	const struct attribute_group___76 **drv_groups;
	int (*match)(struct device___83 *, struct device_driver___83 *);
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	int (*probe)(struct device___83 *);
	int (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*online)(struct device___83 *);
	int (*offline)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct device___83 *, struct device_attribute___83 *, char *);
	ssize_t (*store)(struct device___83 *, struct device_attribute___83 *, const char *, size_t);
};

struct driver_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___83 *, char *);
	ssize_t (*store)(struct device_driver___83 *, const char *, size_t);
};

struct device_driver___83 {
	const char *name;
	struct bus_type___83 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___83 *);
	int (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	const struct attribute_group___76 **groups;
	const struct dev_pm_ops___83 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___83 {
	const char *name;
	const struct attribute_group___76 **groups;
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
};

struct class_attribute___83;

struct class___83 {
	const char *name;
	struct module *owner;
	struct class_attribute___83 *class_attrs;
	struct device_attribute___83 *dev_attrs;
	const struct attribute_group___76 **dev_groups;
	struct bin_attribute___76 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *);
	void (*class_release)(struct class___83 *);
	void (*dev_release)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
	struct subsys_private *p;
};

struct class_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct class___83 *, struct class_attribute___83 *, char *);
	ssize_t (*store)(struct class___83 *, struct class_attribute___83 *, const char *, size_t);
	const void * (*namespace)(struct class___83 *, const struct class_attribute___83 *);
};

struct device_rh___83 {
	struct dev_pm_info_rh___83 power;
};

struct pagevec___3 {
	long unsigned int nr;
	long unsigned int cold;
	struct page___104 *pages[14];
};

typedef unsigned int isolate_mode_t;

struct mem_cgroup_reclaim_cookie {
	struct zone___103 *zone;
	int priority;
	unsigned int generation;
};

enum ttu_flags {
	TTU_UNMAP = 0,
	TTU_MIGRATION = 1,
	TTU_MUNLOCK = 2,
	TTU_ACTION_MASK = 255,
	TTU_IGNORE_MLOCK = 256,
	TTU_IGNORE_ACCESS = 512,
	TTU_IGNORE_HWPOISON = 1024,
};

struct ftrace_event_file___19 {
	struct list_head list;
	struct ftrace_event_call___44 *event_call;
	struct dentry___103 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_mm_vmscan_kswapd_sleep {
	struct trace_entry ent;
	int nid;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_kswapd_wake {
	struct trace_entry ent;
	int nid;
	int order;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_wakeup_kswapd {
	struct trace_entry ent;
	int nid;
	int zid;
	int order;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_direct_reclaim_begin_template {
	struct trace_entry ent;
	int order;
	int may_writepage;
	gfp_t gfp_flags;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_direct_reclaim_end_template {
	struct trace_entry ent;
	long unsigned int nr_reclaimed;
	char __data[0];
};

struct ftrace_raw_mm_shrink_slab_start {
	struct trace_entry ent;
	struct shrinker *shr;
	void *shrink;
	long int nr_objects_to_shrink;
	gfp_t gfp_flags;
	long unsigned int pgs_scanned;
	long unsigned int lru_pgs;
	long unsigned int cache_items;
	long long unsigned int delta;
	long unsigned int total_scan;
	char __data[0];
};

struct ftrace_raw_mm_shrink_slab_end {
	struct trace_entry ent;
	struct shrinker *shr;
	void *shrink;
	long int unused_scan;
	long int new_scan;
	int retval;
	long int total_scan;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_lru_isolate_template {
	struct trace_entry ent;
	int order;
	long unsigned int nr_requested;
	long unsigned int nr_scanned;
	long unsigned int nr_taken;
	isolate_mode_t isolate_mode;
	int file;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_writepage {
	struct trace_entry ent;
	struct page___103 *page;
	int reclaim_flags;
	char __data[0];
};

struct ftrace_raw_mm_vmscan_lru_shrink_inactive {
	struct trace_entry ent;
	int nid;
	int zid;
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	int priority;
	int reclaim_flags;
	char __data[0];
};

struct ftrace_data_offsets_mm_vmscan_kswapd_sleep {};

struct ftrace_data_offsets_mm_vmscan_kswapd_wake {};

struct ftrace_data_offsets_mm_vmscan_wakeup_kswapd {};

struct ftrace_data_offsets_mm_vmscan_direct_reclaim_begin_template {};

struct ftrace_data_offsets_mm_vmscan_direct_reclaim_end_template {};

struct ftrace_data_offsets_mm_shrink_slab_start {};

struct ftrace_data_offsets_mm_shrink_slab_end {};

struct ftrace_data_offsets_mm_vmscan_lru_isolate_template {};

struct ftrace_data_offsets_mm_vmscan_writepage {};

struct ftrace_data_offsets_mm_vmscan_lru_shrink_inactive {};

struct scan_control {
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	int compaction_ready;
	long unsigned int nr_to_reclaim;
	long unsigned int hibernation_mode;
	gfp_t gfp_mask;
	int may_writepage;
	int may_unmap;
	int may_swap;
	int order;
	int priority;
	struct mem_cgroup *target_mem_cgroup;
	nodemask_t *nodemask;
};

typedef enum {
	PAGE_KEEP = 0,
	PAGE_ACTIVATE = 1,
	PAGE_SUCCESS = 2,
	PAGE_CLEAN = 3,
} pageout_t;

enum page_references {
	PAGEREF_RECLAIM = 0,
	PAGEREF_RECLAIM_CLEAN = 1,
	PAGEREF_KEEP = 2,
	PAGEREF_ACTIVATE = 3,
};

enum scan_balance {
	SCAN_EQUAL = 0,
	SCAN_FRACT = 1,
	SCAN_ANON = 2,
	SCAN_FILE = 3,
};

struct page___105;

typedef struct page___105 *pgtable_t___105;

struct address_space___105;

struct kmem_cache___93;

struct page___105 {
	long unsigned int flags;
	struct address_space___105 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___105 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___105 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___93 *slab_cache;
		struct page___105 *first_page;
	};
	long: 64;
};

struct thread_struct___55;

struct task_struct___106;

struct pv_cpu_ops___105 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___55 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___55 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___106 *);
	void (*end_context_switch)(struct task_struct___106 *);
};

struct perf_event___55;

struct thread_struct___55 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___55 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___60;

struct pid_link___60 {
	struct hlist_node node;
	struct pid___60 *pid;
};

struct mutex___107 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___106 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___101 {
	struct page___105 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___110;

struct nsproxy___61;

struct signal_struct___105;

struct bio_list___13;

struct backing_dev_info___17;

struct io_context___13;

struct css_set___71;

struct perf_event_context___55;

struct pipe_inode_info___4;

struct task_struct___106 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___106 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___110 *mm;
	struct mm_struct___110 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___106 *real_parent;
	struct task_struct___106 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___106 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___60 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___105 = 0,
		VTIME_USER___105 = 1,
		VTIME_SYS___105 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___55 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___61 *nsproxy;
	struct signal_struct___105 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___13 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___17 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___71 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___55 *perf_event_ctxp[2];
	struct mutex___107 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___4 *splice_pipe;
	struct page_frag___101 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___110 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___110 *, struct mm_struct___110 *);
	void (*dup_mmap)(struct mm_struct___110 *, struct mm_struct___110 *);
	void (*exit_mmap)(struct mm_struct___110 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___110 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___110 *);
	void (*pgd_free)(struct mm_struct___110 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___110 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___110 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___110 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___110 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___110 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___110 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___110 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___110 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___110 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___110 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___110 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___107 lock;
	void *vdso;
} mm_context_t___106;

struct xol_area___105;

struct uprobes_state___105 {
	struct xol_area___105 *xol_area;
};

struct vm_area_struct___110;

struct file___105;

struct core_state___105;

struct mm_struct___110 {
	struct vm_area_struct___110 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___110 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___110 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___106 context;
	long unsigned int flags;
	struct core_state___105 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___106 *owner;
	struct file___105 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___105 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___55 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___106 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___106 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___106 *target;
};

typedef void (*perf_overflow_handler_t___55)(struct perf_event___55 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___55;

typedef void (*ftrace_func_t___55)(long unsigned int, long unsigned int, struct ftrace_ops___55 *, struct pt_regs *);

struct ftrace_ops___55 {
	ftrace_func_t___55 func;
	struct ftrace_ops___55 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___107 regex_lock;
};

struct pmu___55;

struct fasync_struct___105;

struct pid_namespace___60;

struct ftrace_event_call___45;

struct perf_cgroup___55;

struct perf_event___55 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___55 *group_leader;
	struct pmu___55 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___55 hw;
	struct perf_event_context___55 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___107 child_mutex;
	struct list_head child_list;
	struct perf_event___55 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___106 *owner;
	struct mutex___107 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___105 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___55 *);
	struct callback_head callback_head;
	struct pid_namespace___60 *ns;
	u64 id;
	perf_overflow_handler_t___55 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___45 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___55 ftrace_ops;
	struct perf_cgroup___55 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___54 {
	struct task_struct___106 *task;
	struct exec_domain___28 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___105;

struct dentry_operations___105;

struct super_block___105;

struct dentry___105 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___105 *d_parent;
	struct qstr d_name;
	struct inode___105 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___105 *d_op;
	struct super_block___105 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___105;

struct address_space___105 {
	struct inode___105 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___107 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___105 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___17 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___105;

struct file_operations___105;

struct file_lock___105;

struct dquot___105;

struct block_device___105;

struct inode___105 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___105 *i_op;
	struct super_block___105 *i_sb;
	struct address_space___105 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___107 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___105 *i_fop;
	struct file_lock___105 *i_flock;
	struct address_space___105 i_data;
	struct dquot___105 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct block_device___105 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___14;

struct path___105;

struct dentry_operations___105 {
	int (*d_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_hash)(const struct dentry___105 *, struct qstr *);
	int (*d_compare)(const struct dentry___105 *, const struct dentry___105 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___105 *);
	void (*d_release)(struct dentry___105 *);
	void (*d_prune)(struct dentry___105 *);
	void (*d_iput)(struct dentry___105 *, struct inode___105 *);
	char * (*d_dname)(struct dentry___105 *, char *, int);
	struct vfsmount___14 * (*d_automount)(struct path___105 *);
	int (*d_manage)(struct dentry___105 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___105;

struct mem_dqinfo___105 {
	struct quota_format_type___105 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___105;

struct quota_info___105 {
	unsigned int flags;
	struct mutex___107 dqio_mutex;
	struct mutex___107 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___105 *files[2];
	struct mem_dqinfo___105 info[2];
	const struct quota_format_ops___105 *ops[2];
};

struct file_system_type___105;

struct super_operations___105;

struct dquot_operations___105;

struct quotactl_ops___105;

struct export_operations___3;

struct xattr_handler___71;

struct super_block___105 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___105 *s_type;
	const struct super_operations___105 *s_op;
	const struct dquot_operations___105 *dq_op;
	const struct quotactl_ops___105 *s_qcop;
	const struct export_operations___3 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___105 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___71 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___105 *s_bdev;
	struct backing_dev_info___17 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___105 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___107 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___105 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___14 {
	struct dentry___105 *mnt_root;
	struct super_block___105 *mnt_sb;
	int mnt_flags;
};

struct path___105 {
	struct vfsmount___14 *mnt;
	struct dentry___105 *dentry;
};

struct upid___60 {
	int nr;
	struct pid_namespace___60 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___60 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___106 *child_reaper;
	struct kmem_cache___93 *pid_cachep;
	unsigned int level;
	struct pid_namespace___60 *parent;
	struct vfsmount___14 *proc_mnt;
	struct dentry___105 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___60 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___60 numbers[1];
};

struct irq_data___77;

struct x86_io_apic_ops___77 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___77 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___77;

struct irq_data___77 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___77 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___84;

struct dev_pm_ops___84 {
	int (*prepare)(struct device___84 *);
	void (*complete)(struct device___84 *);
	int (*suspend)(struct device___84 *);
	int (*resume)(struct device___84 *);
	int (*freeze)(struct device___84 *);
	int (*thaw)(struct device___84 *);
	int (*poweroff)(struct device___84 *);
	int (*restore)(struct device___84 *);
	int (*suspend_late)(struct device___84 *);
	int (*resume_early)(struct device___84 *);
	int (*freeze_late)(struct device___84 *);
	int (*thaw_early)(struct device___84 *);
	int (*poweroff_late)(struct device___84 *);
	int (*restore_early)(struct device___84 *);
	int (*suspend_noirq)(struct device___84 *);
	int (*resume_noirq)(struct device___84 *);
	int (*freeze_noirq)(struct device___84 *);
	int (*thaw_noirq)(struct device___84 *);
	int (*poweroff_noirq)(struct device___84 *);
	int (*restore_noirq)(struct device___84 *);
	int (*runtime_suspend)(struct device___84 *);
	int (*runtime_resume)(struct device___84 *);
	int (*runtime_idle)(struct device___84 *);
};

struct device_type___84;

struct bus_type___84;

struct device_driver___84;

struct dev_pm_domain___84;

struct class___84;

struct attribute_group___77;

struct device_rh___84;

struct device___84 {
	struct device___84 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___84 *type;
	struct mutex___107 mutex;
	struct bus_type___84 *bus;
	struct device_driver___84 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___84 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___84 *class;
	const struct attribute_group___77 **groups;
	void (*release)(struct device___84 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___84 *device_rh;
};

struct dev_pm_info_rh___84 {
	void (*set_latency_tolerance)(struct device___84 *, s32);
};

struct dev_pm_domain___84 {
	struct dev_pm_ops___84 ops;
};

struct smp_ops___105 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___106 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___13;

typedef void bio_end_io_t___13(struct bio___13 *, int);

struct bio_vec___13 {
	struct page___105 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___73;

struct bio_integrity_payload___13;

struct bio_set___13;

struct bio___13 {
	sector_t bi_sector;
	struct bio___13 *bi_next;
	struct block_device___105 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___13 *bi_end_io;
	void *bi_private;
	struct io_context___13 *bi_ioc;
	struct cgroup_subsys_state___73 *bi_css;
	struct bio_integrity_payload___13 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___13 *bi_io_vec;
	struct bio_set___13 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___13 bi_inline_vecs[0];
};

struct hd_struct___14;

struct gendisk___14;

struct request_queue___13;

struct block_device___105 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___105 *bd_inode;
	struct super_block___105 *bd_super;
	struct mutex___107 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___105 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___14 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___14 *bd_disk;
	struct request_queue___13 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___107 bd_fsfreeze_mutex;
};

struct io_cq___13;

struct io_context___13 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___13 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___72;

struct cgroup_subsys_state___73 {
	struct cgroup___72 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___13 {
	struct bio___13 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___13 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___13 *bip_vec;
	struct bio_vec___13 bip_inline_vecs[0];
};

struct bio_list___13 {
	struct bio___13 *head;
	struct bio___13 *tail;
};

struct bio_set___13 {
	struct kmem_cache___93 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___13 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct kiocb___7;

typedef int kiocb_cancel_fn___7(struct kiocb___7 *, struct io_event *);

struct kiocb___7 {
	atomic_t ki_users;
	struct file___105 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___7 *ki_cancel;
	void (*ki_dtor)(struct kiocb___7 *);
	union {
		void *user;
		struct task_struct___106 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___105 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___105 *ia_file;
};

struct fown_struct___60 {
	rwlock_t lock;
	struct pid___60 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___105 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___105 f_path;
	struct inode___105 *f_inode;
	const struct file_operations___105 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___60 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___105 *f_mapping;
	struct mutex___107 f_pos_lock;
};

struct zone___105;

struct lruvec___105 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___105 *zone;
};

struct pglist_data___105;

struct zone___105 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___105 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___105 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___105 {
	struct zone___105 *zone;
	int zone_idx;
};

struct zonelist___105 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___105 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___105 {
	struct zone___105 node_zones[4];
	struct zonelist___105 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___106 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___105 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___107 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___105 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___105 {
	int qf_fmt_id;
	const struct quota_format_ops___105 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___105 *qf_next;
};

struct quota_format_ops___105 {
	int (*check_quota_file)(struct super_block___105 *, int);
	int (*read_file_info)(struct super_block___105 *, int);
	int (*write_file_info)(struct super_block___105 *, int);
	int (*free_file_info)(struct super_block___105 *, int);
	int (*read_dqblk)(struct dquot___105 *);
	int (*commit_dqblk)(struct dquot___105 *);
	int (*release_dqblk)(struct dquot___105 *);
};

struct dquot_operations___105 {
	int (*write_dquot)(struct dquot___105 *);
	struct dquot___105 * (*alloc_dquot)(struct super_block___105 *, int);
	void (*destroy_dquot)(struct dquot___105 *);
	int (*acquire_dquot)(struct dquot___105 *);
	int (*release_dquot)(struct dquot___105 *);
	int (*mark_dirty)(struct dquot___105 *);
	int (*write_info)(struct super_block___105 *, int);
	qsize_t * (*get_reserved_space)(struct inode___105 *);
};

struct quotactl_ops___105 {
	int (*quota_on)(struct super_block___105 *, int, int, struct path___105 *);
	int (*quota_on_meta)(struct super_block___105 *, int, int);
	int (*quota_off)(struct super_block___105 *, int);
	int (*quota_sync)(struct super_block___105 *, int);
	int (*get_info)(struct super_block___105 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___105 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___105 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___105 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___105 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___105 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___105 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___105 *, unsigned int);
};

typedef int (*read_actor_t___2)(read_descriptor_t *, struct page___105 *, long unsigned int, long unsigned int);

struct swap_info_struct___21;

struct address_space_operations___105 {
	int (*writepage)(struct page___105 *, struct writeback_control *);
	int (*readpage)(struct file___105 *, struct page___105 *);
	int (*writepages)(struct address_space___105 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___105 *);
	int (*readpages)(struct file___105 *, struct address_space___105 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___105 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___105 **, void **);
	int (*write_end)(struct file___105 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___105 *, void *);
	sector_t (*bmap)(struct address_space___105 *, sector_t);
	void (*invalidatepage)(struct page___105 *, long unsigned int);
	int (*releasepage)(struct page___105 *, gfp_t);
	void (*freepage)(struct page___105 *);
	ssize_t (*direct_IO)(int, struct kiocb___7 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___105 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___105 *, struct page___105 *, struct page___105 *, enum migrate_mode);
	int (*launder_page)(struct page___105 *);
	int (*is_partially_uptodate)(struct page___105 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___105 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___105 *, struct page___105 *);
	int (*swap_activate)(struct swap_info_struct___21 *, struct file___105 *, sector_t *);
	void (*swap_deactivate)(struct file___105 *);
	void (*invalidatepage_range)(struct page___105 *, unsigned int, unsigned int);
};

struct swap_info_struct___21 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___105 *bdev;
	struct file___105 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___17 {
	struct backing_dev_info___17 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___17 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___17 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___84 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___105 *debug_dir;
	struct dentry___105 *debug_stats;
};

struct hd_struct___14 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___84 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___14;

struct block_device_operations___13;

struct gendisk___14 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___14 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___14 *part_tbl;
	struct hd_struct___14 part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___13 *queue;
	void *private_data;
	int flags;
	struct device___84 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___13 {
	struct request_queue___13 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___13(struct request_queue___13 *);

typedef void make_request_fn___13(struct request_queue___13 *, struct bio___13 *);

struct request___13;

typedef int prep_rq_fn___13(struct request_queue___13 *, struct request___13 *);

struct bvec_merge_data___13;

typedef int merge_bvec_fn___13(struct request_queue___13 *, struct bvec_merge_data___13 *, struct bio_vec___13 *);

typedef void softirq_done_fn___13(struct request___13 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___13(struct request___13 *);

typedef int dma_drain_needed_fn___13(struct request___13 *);

typedef int lld_busy_fn___13(struct request_queue___13 *);

struct bsg_class_device___13 {
	struct device___84 *class_dev;
	struct device___84 *parent;
	int minor;
	struct request_queue___13 *queue;
	struct kref ref;
	void (*release)(struct device___84 *);
};

typedef void unprep_rq_fn___13(struct request_queue___13 *, struct request___13 *);

struct elevator_queue___13;

struct blk_queue_tag___13;

struct request_queue___13 {
	struct list_head queue_head;
	struct request___13 *last_merge;
	struct elevator_queue___13 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___13 root_rl;
	request_fn_proc___13 *request_fn;
	make_request_fn___13 *make_request_fn;
	prep_rq_fn___13 *prep_rq_fn;
	merge_bvec_fn___13 *merge_bvec_fn;
	softirq_done_fn___13 *softirq_done_fn;
	rq_timed_out_fn___13 *rq_timed_out_fn;
	dma_drain_needed_fn___13 *dma_drain_needed;
	lld_busy_fn___13 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___13 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___17 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___84 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___13 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___13 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___107 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___13 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___13 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___13 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct pipe_buffer___4;

struct pipe_inode_info___4 {
	struct mutex___107 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___105 *tmp_page;
	struct fasync_struct___105 *fasync_readers;
	struct fasync_struct___105 *fasync_writers;
	struct pipe_buffer___4 *bufs;
};

struct nameidata___6;

struct inode_operations___105 {
	struct dentry___105 * (*lookup)(struct inode___105 *, struct dentry___105 *, unsigned int);
	void * (*follow_link)(struct dentry___105 *, struct nameidata___6 *);
	int (*permission)(struct inode___105 *, int);
	struct posix_acl * (*get_acl)(struct inode___105 *, int);
	int (*readlink)(struct dentry___105 *, char *, int);
	void (*put_link)(struct dentry___105 *, struct nameidata___6 *, void *);
	int (*create)(struct inode___105 *, struct dentry___105 *, umode_t, bool);
	int (*link)(struct dentry___105 *, struct inode___105 *, struct dentry___105 *);
	int (*unlink)(struct inode___105 *, struct dentry___105 *);
	int (*symlink)(struct inode___105 *, struct dentry___105 *, const char *);
	int (*mkdir)(struct inode___105 *, struct dentry___105 *, umode_t);
	int (*rmdir)(struct inode___105 *, struct dentry___105 *);
	int (*mknod)(struct inode___105 *, struct dentry___105 *, umode_t, dev_t);
	int (*rename)(struct inode___105 *, struct dentry___105 *, struct inode___105 *, struct dentry___105 *);
	int (*setattr)(struct dentry___105 *, struct iattr___105 *);
	int (*getattr)(struct vfsmount___14 *, struct dentry___105 *, struct kstat *);
	int (*setxattr)(struct dentry___105 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___105 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___105 *, char *, size_t);
	int (*removexattr)(struct dentry___105 *, const char *);
	int (*fiemap)(struct inode___105 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___105 *, struct timespec *, int);
	int (*atomic_open)(struct inode___105 *, struct dentry___105 *, struct file___105 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___67;

struct seq_file___79;

struct file_operations___105 {
	struct module *owner;
	loff_t (*llseek)(struct file___105 *, loff_t, int);
	ssize_t (*read)(struct file___105 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___105 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___7 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___7 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___105 *, void *, filldir_t);
	unsigned int (*poll)(struct file___105 *, struct poll_table_struct___67 *);
	long int (*unlocked_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___105 *, struct vm_area_struct___110 *);
	int (*open)(struct inode___105 *, struct file___105 *);
	int (*flush)(struct file___105 *, fl_owner_t);
	int (*release)(struct inode___105 *, struct file___105 *);
	int (*fsync)(struct file___105 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___7 *, int);
	int (*fasync)(int, struct file___105 *, int);
	int (*lock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*sendpage)(struct file___105 *, struct page___105 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*splice_write)(struct pipe_inode_info___4 *, struct file___105 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___105 *, loff_t *, struct pipe_inode_info___4 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___105 *, long int, struct file_lock___105 **, void **);
		struct {
			int (*setlease)(struct file___105 *, long int, struct file_lock___105 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___105 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___79 *, struct file___105 *);
};

struct file_lock_operations___105;

struct lock_manager_operations___105;

struct file_lock___105 {
	struct file_lock___105 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___60 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___105 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___105 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___105 *fl_ops;
	const struct lock_manager_operations___105 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___105 {
	void (*fl_copy_lock)(struct file_lock___105 *, struct file_lock___105 *);
	void (*fl_release_private)(struct file_lock___105 *);
};

struct lock_manager_operations___105 {
	int (*lm_compare_owner)(struct file_lock___105 *, struct file_lock___105 *);
	long unsigned int (*lm_owner_key)(struct file_lock___105 *);
	void (*lm_notify)(struct file_lock___105 *);
	int (*lm_grant)(struct file_lock___105 *, struct file_lock___105 *, int);
	void (*lm_break)(struct file_lock___105 *);
	int (*lm_change)(struct file_lock___105 **, int);
};

struct fasync_struct___105 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___105 *fa_next;
	struct file___105 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___105 {
	const char *name;
	int fs_flags;
	struct dentry___105 * (*mount)(struct file_system_type___105 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___105 *);
	struct module *owner;
	struct file_system_type___105 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___105 {
	struct inode___105 * (*alloc_inode)(struct super_block___105 *);
	void (*destroy_inode)(struct inode___105 *);
	void (*dirty_inode)(struct inode___105 *, int);
	int (*write_inode)(struct inode___105 *, struct writeback_control *);
	int (*drop_inode)(struct inode___105 *);
	void (*evict_inode)(struct inode___105 *);
	void (*put_super)(struct super_block___105 *);
	int (*sync_fs)(struct super_block___105 *, int);
	int (*freeze_fs)(struct super_block___105 *);
	int (*unfreeze_fs)(struct super_block___105 *);
	int (*statfs)(struct dentry___105 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___105 *, int *, char *);
	void (*umount_begin)(struct super_block___105 *);
	int (*show_options)(struct seq_file___79 *, struct dentry___105 *);
	int (*show_devname)(struct seq_file___79 *, struct dentry___105 *);
	int (*show_path)(struct seq_file___79 *, struct dentry___105 *);
	int (*show_stats)(struct seq_file___79 *, struct dentry___105 *);
	ssize_t (*quota_read)(struct super_block___105 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___105 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___105 *);
	int (*bdev_try_to_free_page)(struct super_block___105 *, struct page___105 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___105 *);
	void (*free_cached_objects)(struct super_block___105 *, int);
};

struct export_operations___3 {
	int (*encode_fh)(struct inode___105 *, __u32 *, int *, struct inode___105 *);
	struct dentry___105 * (*fh_to_dentry)(struct super_block___105 *, struct fid *, int, int);
	struct dentry___105 * (*fh_to_parent)(struct super_block___105 *, struct fid *, int, int);
	int (*get_name)(struct dentry___105 *, char *, struct dentry___105 *);
	struct dentry___105 * (*get_parent)(struct dentry___105 *);
	int (*commit_metadata)(struct inode___105 *);
	int (*get_uuid)(struct super_block___105 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___105 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___105 *, struct iomap *, int, struct iattr___105 *);
};

struct xattr_handler___71 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___105 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___105 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___105 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___69)(struct file___105 *, wait_queue_head_t *, struct poll_table_struct___67 *);

struct poll_table_struct___67 {
	poll_queue_proc___69 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___93;

struct vm_area_struct___110 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___110 *vm_next;
	struct vm_area_struct___110 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___110 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___93 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___105 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___78;

struct seq_file___79 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___107 lock;
	const struct seq_operations___78 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___6 {
	struct path___105 path;
	struct qstr last;
	struct path___105 root;
	struct inode___105 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct inode_operations_wrapper {
	struct inode_operations___105 ops;
	unsigned int version;
	int (*rename2)(struct inode___105 *, struct dentry___105 *, struct inode___105 *, struct dentry___105 *, unsigned int);
	int (*dentry_open)(struct dentry___105 *, struct file___105 *, const struct cred *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xol_area___105 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___105 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___93;

struct memcg_cache_params___93;

struct kmem_cache___93 {
	struct kmem_cache_cpu___93 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___93 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___90;

struct vm_operations_struct___93 {
	void (*open)(struct vm_area_struct___110 *);
	void (*close)(struct vm_area_struct___110 *);
	int (*fault)(struct vm_area_struct___110 *, struct vm_fault___90 *);
	int (*page_mkwrite)(struct vm_area_struct___110 *, struct vm_fault___90 *);
	int (*access)(struct vm_area_struct___110 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___110 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___110 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___110 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___110 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___105 {
	struct task_struct___106 *task;
	struct core_thread___105 *next;
};

struct core_state___105 {
	atomic_t nr_threads;
	struct core_thread___105 dumper;
	struct completion startup;
};

struct vm_fault___90 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___105 *page;
};

struct irq_chip___77 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___77 *);
	void (*irq_shutdown)(struct irq_data___77 *);
	void (*irq_enable)(struct irq_data___77 *);
	void (*irq_disable)(struct irq_data___77 *);
	void (*irq_ack)(struct irq_data___77 *);
	void (*irq_mask)(struct irq_data___77 *);
	void (*irq_mask_ack)(struct irq_data___77 *);
	void (*irq_unmask)(struct irq_data___77 *);
	void (*irq_eoi)(struct irq_data___77 *);
	int (*irq_set_affinity)(struct irq_data___77 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___77 *);
	int (*irq_set_type)(struct irq_data___77 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___77 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___77 *);
	void (*irq_bus_sync_unlock)(struct irq_data___77 *);
	void (*irq_cpu_online)(struct irq_data___77 *);
	void (*irq_cpu_offline)(struct irq_data___77 *);
	void (*irq_suspend)(struct irq_data___77 *);
	void (*irq_resume)(struct irq_data___77 *);
	void (*irq_pm_shutdown)(struct irq_data___77 *);
	void (*irq_print_chip)(struct irq_data___77 *, struct seq_file___79 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___77 *, void *);
	long unsigned int flags;
};

struct nsproxy___61 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___60 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___105 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___106 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___106 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___60 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___60 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___107 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___71 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___73 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___55 {
	struct pmu___55 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___107 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___106 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___55 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___77;

struct attribute_group___77 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___77 **bin_attrs;
};

struct bin_attribute___77 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___105 *, struct kobject *, struct bin_attribute___77 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___105 *, struct kobject *, struct bin_attribute___77 *, char *, loff_t, size_t);
	int (*mmap)(struct file___105 *, struct kobject *, struct bin_attribute___77 *, struct vm_area_struct___110 *);
};

struct kmem_cache_cpu___93 {
	void **freelist;
	long unsigned int tid;
	struct page___105 *page;
	struct page___105 *partial;
};

struct memcg_cache_params___93 {
	bool is_root_cache;
	union {
		struct kmem_cache___93 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___93 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr {
	char *name;
	void *value;
	size_t value_len;
};

struct cgroupfs_root___71;

struct cgroup___72 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___72 *parent;
	struct dentry___105 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___73 *subsys[11];
	struct cgroupfs_root___71 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___107 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___71 {
	struct super_block___105 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___72 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___29 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___105 *, struct file___105 *);
	ssize_t (*read)(struct cgroup___72 *, struct cftype___29 *, struct file___105 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___72 *, struct cftype___29 *);
	s64 (*read_s64)(struct cgroup___72 *, struct cftype___29 *);
	int (*read_map)(struct cgroup___72 *, struct cftype___29 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___72 *, struct cftype___29 *, struct seq_file___79 *);
	ssize_t (*write)(struct cgroup___72 *, struct cftype___29 *, struct file___105 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___72 *, struct cftype___29 *, u64);
	int (*write_s64)(struct cgroup___72 *, struct cftype___29 *, s64);
	int (*write_string)(struct cgroup___72 *, struct cftype___29 *, const char *);
	int (*trigger)(struct cgroup___72 *, unsigned int);
	int (*release)(struct inode___105 *, struct file___105 *);
	int (*register_event)(struct cgroup___72 *, struct cftype___29 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___72 *, struct cftype___29 *, struct eventfd_ctx *);
};

struct cftype_set___27 {
	struct list_head node;
	struct cftype___29 *cfts;
};

struct task_and_cgroup___27 {
	struct task_struct___106 *task;
	struct cgroup___72 *cgrp;
	struct css_set___71 *cg;
};

struct cgroup_taskset___27 {
	struct task_and_cgroup___27 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___72 *cur_cgrp;
};

struct cgroup_subsys___27 {
	struct cgroup_subsys_state___73 * (*css_alloc)(struct cgroup___72 *);
	int (*css_online)(struct cgroup___72 *);
	void (*css_offline)(struct cgroup___72 *);
	void (*css_free)(struct cgroup___72 *);
	int (*can_attach)(struct cgroup___72 *, struct cgroup_taskset___27 *);
	void (*cancel_attach)(struct cgroup___72 *, struct cgroup_taskset___27 *);
	void (*attach)(struct cgroup___72 *, struct cgroup_taskset___27 *);
	void (*fork)(struct task_struct___106 *);
	void (*exit)(struct cgroup___72 *, struct cgroup___72 *, struct task_struct___106 *);
	void (*bind)(struct cgroup___72 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___71 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___29 *base_cftypes;
	struct cftype_set___27 base_cftset;
	struct module *module;
};

struct bus_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___84 *, char *);
	ssize_t (*store)(struct bus_type___84 *, const char *, size_t);
};

struct device_attribute___84;

struct driver_attribute___84;

struct bus_type___84 {
	const char *name;
	const char *dev_name;
	struct device___84 *dev_root;
	struct bus_attribute___84 *bus_attrs;
	struct device_attribute___84 *dev_attrs;
	struct driver_attribute___84 *drv_attrs;
	const struct attribute_group___77 **bus_groups;
	const struct attribute_group___77 **dev_groups;
	const struct attribute_group___77 **drv_groups;
	int (*match)(struct device___84 *, struct device_driver___84 *);
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	int (*probe)(struct device___84 *);
	int (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*online)(struct device___84 *);
	int (*offline)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct device___84 *, struct device_attribute___84 *, char *);
	ssize_t (*store)(struct device___84 *, struct device_attribute___84 *, const char *, size_t);
};

struct driver_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___84 *, char *);
	ssize_t (*store)(struct device_driver___84 *, const char *, size_t);
};

struct device_driver___84 {
	const char *name;
	struct bus_type___84 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___84 *);
	int (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	const struct attribute_group___77 **groups;
	const struct dev_pm_ops___84 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___84 {
	const char *name;
	const struct attribute_group___77 **groups;
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
};

struct class_attribute___84;

struct class___84 {
	const char *name;
	struct module *owner;
	struct class_attribute___84 *class_attrs;
	struct device_attribute___84 *dev_attrs;
	const struct attribute_group___77 **dev_groups;
	struct bin_attribute___77 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *);
	void (*class_release)(struct class___84 *);
	void (*dev_release)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
	struct subsys_private *p;
};

struct class_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct class___84 *, struct class_attribute___84 *, char *);
	ssize_t (*store)(struct class___84 *, struct class_attribute___84 *, const char *, size_t);
	const void * (*namespace)(struct class___84 *, const struct class_attribute___84 *);
};

struct device_rh___84 {
	struct dev_pm_info_rh___84 power;
};

struct seq_operations___78 {
	void * (*start)(struct seq_file___79 *, loff_t *);
	void (*stop)(struct seq_file___79 *, void *);
	void * (*next)(struct seq_file___79 *, void *, loff_t *);
	int (*show)(struct seq_file___79 *, void *);
};

struct perf_cpu_context___55;

struct pmu___55 {
	struct list_head entry;
	struct device___84 *dev;
	const struct attribute_group___77 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___55 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___55 *);
	void (*pmu_disable)(struct pmu___55 *);
	int (*event_init)(struct perf_event___55 *);
	int (*add)(struct perf_event___55 *, int);
	void (*del)(struct perf_event___55 *, int);
	void (*start)(struct perf_event___55 *, int);
	void (*stop)(struct perf_event___55 *, int);
	void (*read)(struct perf_event___55 *);
	void (*start_txn)(struct pmu___55 *);
	int (*commit_txn)(struct pmu___55 *);
	void (*cancel_txn)(struct pmu___55 *);
	int (*event_idx)(struct perf_event___55 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___55 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___55 *);
};

struct perf_cpu_context___55 {
	struct perf_event_context___55 ctx;
	struct perf_event_context___55 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___55 *unique_pmu;
	struct perf_cgroup___55 *cgrp;
};

struct trace_event_functions___45;

struct trace_event___45 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___45 *funcs;
};

struct ftrace_event_class___45;

struct ftrace_event_call___45 {
	struct list_head list;
	struct ftrace_event_class___45 *class;
	char *name;
	struct trace_event___45 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___55 {
	struct cgroup_subsys_state___73 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___45 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___107 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___45)(struct trace_iterator___45 *, int, struct trace_event___45 *);

struct trace_event_functions___45 {
	trace_print_func___45 trace;
	trace_print_func___45 raw;
	trace_print_func___45 hex;
	trace_print_func___45 binary;
};

struct ftrace_event_class___45 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___45 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___45 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___45 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___45 *);
};

struct syscall_metadata___16 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___45 *enter_event;
	struct ftrace_event_call___45 *exit_event;
};

enum fid_type {
	FILEID_ROOT = 0,
	FILEID_INO32_GEN = 1,
	FILEID_INO32_GEN_PARENT = 2,
	FILEID_BTRFS_WITHOUT_PARENT = 77,
	FILEID_BTRFS_WITH_PARENT = 78,
	FILEID_BTRFS_WITH_PARENT_ROOT = 79,
	FILEID_UDF_WITHOUT_PARENT = 81,
	FILEID_UDF_WITH_PARENT = 82,
	FILEID_NILFS_WITHOUT_PARENT = 97,
	FILEID_NILFS_WITH_PARENT = 98,
	FILEID_FAT_WITHOUT_PARENT = 113,
	FILEID_FAT_WITH_PARENT = 114,
	FILEID_INVALID = 255,
};

enum {
	MPOL_DEFAULT = 0,
	MPOL_PREFERRED = 1,
	MPOL_BIND = 2,
	MPOL_INTERLEAVE = 3,
	MPOL_LOCAL = 4,
	MPOL_MAX = 5,
};

struct shared_policy {
	struct rb_root root;
	spinlock_t lock;
};

struct shmem_inode_info {
	spinlock_t lock;
	long unsigned int flags;
	long unsigned int alloced;
	union {
		long unsigned int swapped;
		char *symlink;
	};
	struct shared_policy policy;
	struct list_head swaplist;
	struct simple_xattrs xattrs;
	struct inode___105 vfs_inode;
};

struct shmem_sb_info {
	long unsigned int max_blocks;
	struct percpu_counter used_blocks;
	long unsigned int max_inodes;
	long unsigned int free_inodes;
	spinlock_t stat_lock;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	struct mempolicy *mpol;
};

struct disk_part_tbl___14 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___14 *last_lookup;
	struct hd_struct___14 *part[0];
};

struct block_device_operations___13 {
	int (*open)(struct block_device___105 *, fmode_t);
	void (*release)(struct gendisk___14 *, fmode_t);
	int (*ioctl)(struct block_device___105 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___105 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___105 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___14 *, unsigned int);
	int (*media_changed)(struct gendisk___14 *);
	void (*unlock_native_capacity)(struct gendisk___14 *);
	int (*revalidate_disk)(struct gendisk___14 *);
	int (*getgeo)(struct block_device___105 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___105 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___13 {
	struct request_queue___13 *q;
	struct io_context___13 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___93 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___13(struct request___13 *, int);

struct request___13 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue___13 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___13 *bio;
	struct bio___13 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___13 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___13 *saved_end_io;
		} flush;
	};
	struct gendisk___14 *rq_disk;
	struct hd_struct___14 *part;
	long unsigned int start_time;
	struct request_list___13 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___13 *end_io;
	void *end_io_data;
	struct request___13 *next_rq;
};

typedef int elevator_merge_fn___13(struct request_queue___13 *, struct request___13 **, struct bio___13 *);

typedef void elevator_merge_req_fn___13(struct request_queue___13 *, struct request___13 *, struct request___13 *);

typedef void elevator_merged_fn___13(struct request_queue___13 *, struct request___13 *, int);

typedef int elevator_allow_merge_fn___13(struct request_queue___13 *, struct request___13 *, struct bio___13 *);

typedef void elevator_bio_merged_fn___13(struct request_queue___13 *, struct request___13 *, struct bio___13 *);

typedef int elevator_dispatch_fn___13(struct request_queue___13 *, int);

typedef void elevator_add_req_fn___13(struct request_queue___13 *, struct request___13 *);

typedef struct request___13 *elevator_request_list_fn___13(struct request_queue___13 *, struct request___13 *);

typedef void elevator_completed_req_fn___13(struct request_queue___13 *, struct request___13 *);

typedef int elevator_may_queue_fn___13(struct request_queue___13 *, int);

typedef void elevator_init_icq_fn___13(struct io_cq___13 *);

typedef void elevator_exit_icq_fn___13(struct io_cq___13 *);

typedef int elevator_set_req_fn___13(struct request_queue___13 *, struct request___13 *, struct bio___13 *, gfp_t);

typedef void elevator_put_req_fn___13(struct request___13 *);

typedef void elevator_activate_req_fn___13(struct request_queue___13 *, struct request___13 *);

typedef void elevator_deactivate_req_fn___13(struct request_queue___13 *, struct request___13 *);

struct elevator_type___13;

typedef int elevator_init_fn___13(struct request_queue___13 *, struct elevator_type___13 *);

typedef void elevator_exit_fn___13(struct elevator_queue___13 *);

struct elevator_ops___13 {
	elevator_merge_fn___13 *elevator_merge_fn;
	elevator_merged_fn___13 *elevator_merged_fn;
	elevator_merge_req_fn___13 *elevator_merge_req_fn;
	elevator_allow_merge_fn___13 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___13 *elevator_bio_merged_fn;
	elevator_dispatch_fn___13 *elevator_dispatch_fn;
	elevator_add_req_fn___13 *elevator_add_req_fn;
	elevator_activate_req_fn___13 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___13 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___13 *elevator_completed_req_fn;
	elevator_request_list_fn___13 *elevator_former_req_fn;
	elevator_request_list_fn___13 *elevator_latter_req_fn;
	elevator_init_icq_fn___13 *elevator_init_icq_fn;
	elevator_exit_icq_fn___13 *elevator_exit_icq_fn;
	elevator_set_req_fn___13 *elevator_set_req_fn;
	elevator_put_req_fn___13 *elevator_put_req_fn;
	elevator_may_queue_fn___13 *elevator_may_queue_fn;
	elevator_init_fn___13 *elevator_init_fn;
	elevator_exit_fn___13 *elevator_exit_fn;
};

struct elv_fs_entry___13;

struct elevator_type___13 {
	struct kmem_cache___93 *icq_cache;
	struct elevator_ops___13 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___13 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___13 {
	struct elevator_type___13 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___107 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___13 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___13 *, char *);
	ssize_t (*store)(struct elevator_queue___13 *, const char *, size_t);
};

struct bvec_merge_data___13 {
	struct block_device___105 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___13 {
	struct request___13 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct pagevec___4 {
	long unsigned int nr;
	long unsigned int cold;
	struct page___105 *pages[14];
};

struct pipe_buf_operations___4;

struct pipe_buffer___4 {
	struct page___105 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___4 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___4 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *, int);
	void (*unmap)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *, void *);
	int (*confirm)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	void (*release)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	int (*steal)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	void (*get)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
};

struct splice_pipe_desc___3 {
	struct page___105 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___4 *ops;
	void (*spd_release)(struct splice_pipe_desc___3 *, unsigned int);
};

typedef int (*initxattrs)(struct inode___105 *, const struct xattr *, void *);

struct shmem_falloc {
	wait_queue_head_t *waitq;
	long unsigned int start;
	long unsigned int next;
	long unsigned int nr_falloced;
	long unsigned int nr_unswapped;
};

enum sgp_type {
	SGP_READ = 0,
	SGP_CACHE = 1,
	SGP_DIRTY = 2,
	SGP_WRITE = 3,
	SGP_FALLOC = 4,
};

struct hstate___7 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___11 cgroup_files[5];
	char name[32];
};

struct ftrace_raw_kmem_alloc {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	char __data[0];
};

struct ftrace_raw_kmem_alloc_node {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	int node;
	char __data[0];
};

struct ftrace_raw_kmem_free {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	char __data[0];
};

struct ftrace_raw_mm_page_free {
	struct trace_entry ent;
	struct page___58 *page;
	unsigned int order;
	char __data[0];
};

struct ftrace_raw_mm_page_free_batched {
	struct trace_entry ent;
	struct page___58 *page;
	int cold;
	char __data[0];
};

struct ftrace_raw_mm_page_alloc {
	struct trace_entry ent;
	struct page___58 *page;
	unsigned int order;
	gfp_t gfp_flags;
	int migratetype;
	char __data[0];
};

struct ftrace_raw_mm_page {
	struct trace_entry ent;
	struct page___58 *page;
	unsigned int order;
	int migratetype;
	char __data[0];
};

struct ftrace_raw_mm_page_alloc_extfrag {
	struct trace_entry ent;
	struct page___58 *page;
	int alloc_order;
	int fallback_order;
	int alloc_migratetype;
	int fallback_migratetype;
	char __data[0];
};

struct ftrace_data_offsets_kmem_alloc {};

struct ftrace_data_offsets_kmem_alloc_node {};

struct ftrace_data_offsets_kmem_free {};

struct ftrace_data_offsets_mm_page_free {};

struct ftrace_data_offsets_mm_page_free_batched {};

struct ftrace_data_offsets_mm_page_alloc {};

struct ftrace_data_offsets_mm_page {};

struct ftrace_data_offsets_mm_page_alloc_extfrag {};

typedef struct pglist_data___105 pg_data_t___5;

typedef struct pglist_data___100 pg_data_t___6;

struct contig_page_info {
	long unsigned int free_pages;
	long unsigned int free_blocks_total;
	long unsigned int free_blocks_suitable;
};

enum writeback_stat_item {
	NR_DIRTY_THRESHOLD = 0,
	NR_DIRTY_BG_THRESHOLD = 1,
	NR_VM_WRITEBACK_STAT_ITEMS = 2,
};

struct page___106;

typedef struct page___106 *pgtable_t___106;

struct address_space___106;

struct page___106 {
	long unsigned int flags;
	struct address_space___106 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___106 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___106 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___106 *first_page;
	};
	long: 64;
};

struct task_struct___107;

struct pv_cpu_ops___106 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___55 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___55 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___107 *);
	void (*end_context_switch)(struct task_struct___107 *);
};

struct mutex___108 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___107 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___102 {
	struct page___106 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___111;

struct signal_struct___106;

struct backing_dev_info___18;

struct task_struct___107 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___107 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___111 *mm;
	struct mm_struct___111 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___107 *real_parent;
	struct task_struct___107 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___107 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___60 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___106 = 0,
		VTIME_USER___106 = 1,
		VTIME_SYS___106 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___55 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___106 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___18 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___108 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___102 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___111 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___111 *, struct mm_struct___111 *);
	void (*dup_mmap)(struct mm_struct___111 *, struct mm_struct___111 *);
	void (*exit_mmap)(struct mm_struct___111 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___111 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___111 *);
	void (*pgd_free)(struct mm_struct___111 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___111 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___111 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___111 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___111 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___111 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___111 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___111 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___111 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___111 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___111 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___111 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___108 lock;
	void *vdso;
} mm_context_t___107;

struct xol_area___106;

struct uprobes_state___106 {
	struct xol_area___106 *xol_area;
};

struct vm_area_struct___111;

struct file___106;

struct core_state___106;

struct mm_struct___111 {
	struct vm_area_struct___111 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___111 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___111 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___107 context;
	long unsigned int flags;
	struct core_state___106 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___107 *owner;
	struct file___106 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___106 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___57;

struct module_kobject___56 {
	struct kobject kobj;
	struct module___57 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___56;

struct module___57 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___56 mkobj;
	struct module_attribute___56 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___107 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct irq_data___78;

struct x86_io_apic_ops___78 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___78 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___78;

struct irq_data___78 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___78 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___85;

struct dev_pm_ops___85 {
	int (*prepare)(struct device___85 *);
	void (*complete)(struct device___85 *);
	int (*suspend)(struct device___85 *);
	int (*resume)(struct device___85 *);
	int (*freeze)(struct device___85 *);
	int (*thaw)(struct device___85 *);
	int (*poweroff)(struct device___85 *);
	int (*restore)(struct device___85 *);
	int (*suspend_late)(struct device___85 *);
	int (*resume_early)(struct device___85 *);
	int (*freeze_late)(struct device___85 *);
	int (*thaw_early)(struct device___85 *);
	int (*poweroff_late)(struct device___85 *);
	int (*restore_early)(struct device___85 *);
	int (*suspend_noirq)(struct device___85 *);
	int (*resume_noirq)(struct device___85 *);
	int (*freeze_noirq)(struct device___85 *);
	int (*thaw_noirq)(struct device___85 *);
	int (*poweroff_noirq)(struct device___85 *);
	int (*restore_noirq)(struct device___85 *);
	int (*runtime_suspend)(struct device___85 *);
	int (*runtime_resume)(struct device___85 *);
	int (*runtime_idle)(struct device___85 *);
};

struct device_type___85;

struct bus_type___85;

struct device_driver___85;

struct dev_pm_domain___85;

struct class___85;

struct attribute_group___78;

struct device_rh___85;

struct device___85 {
	struct device___85 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___85 *type;
	struct mutex___108 mutex;
	struct bus_type___85 *bus;
	struct device_driver___85 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___85 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___85 *class;
	const struct attribute_group___78 **groups;
	void (*release)(struct device___85 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___85 *device_rh;
};

struct dev_pm_info_rh___85 {
	void (*set_latency_tolerance)(struct device___85 *, s32);
};

struct dev_pm_domain___85 {
	struct dev_pm_ops___85 ops;
};

struct smp_ops___106 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___107 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___106;

struct lruvec___106 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___106 *zone;
};

struct pglist_data___106;

struct zone___106 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___106 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___106 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___106 {
	struct zone___106 *zone;
	int zone_idx;
};

struct zonelist___106 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___106 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___106 {
	struct zone___106 node_zones[4];
	struct zonelist___106 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___107 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inode___106;

struct dentry_operations___106;

struct super_block___106;

struct dentry___106 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___106 *d_parent;
	struct qstr d_name;
	struct inode___106 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___106 *d_op;
	struct super_block___106 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___106;

struct address_space___106 {
	struct inode___106 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___108 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___106 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___18 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___106;

struct file_operations___106;

struct file_lock___106;

struct dquot___106;

struct block_device___106;

struct inode___106 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___106 *i_op;
	struct super_block___106 *i_sb;
	struct address_space___106 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___108 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___106 *i_fop;
	struct file_lock___106 *i_flock;
	struct address_space___106 i_data;
	struct dquot___106 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___106 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___106;

struct dentry_operations___106 {
	int (*d_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_hash)(const struct dentry___106 *, struct qstr *);
	int (*d_compare)(const struct dentry___106 *, const struct dentry___106 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___106 *);
	void (*d_release)(struct dentry___106 *);
	void (*d_prune)(struct dentry___106 *);
	void (*d_iput)(struct dentry___106 *, struct inode___106 *);
	char * (*d_dname)(struct dentry___106 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___106 *);
	int (*d_manage)(struct dentry___106 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___106;

struct mem_dqinfo___106 {
	struct quota_format_type___106 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___106;

struct quota_info___106 {
	unsigned int flags;
	struct mutex___108 dqio_mutex;
	struct mutex___108 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___106 *files[2];
	struct mem_dqinfo___106 info[2];
	const struct quota_format_ops___106 *ops[2];
};

struct file_system_type___106;

struct super_operations___106;

struct dquot_operations___106;

struct quotactl_ops___106;

struct super_block___106 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___106 *s_type;
	const struct super_operations___106 *s_op;
	const struct dquot_operations___106 *dq_op;
	const struct quotactl_ops___106 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___106 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___106 *s_bdev;
	struct backing_dev_info___18 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___106 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___108 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___106 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___106 {
	struct vfsmount *mnt;
	struct dentry___106 *dentry;
};

struct block_device___106 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___106 *bd_inode;
	struct super_block___106 *bd_super;
	struct mutex___108 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___106 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___108 bd_fsfreeze_mutex;
};

struct iattr___106 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___106 *ia_file;
};

struct file___106 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___106 f_path;
	struct inode___106 *f_inode;
	const struct file_operations___106 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___60 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___106 *f_mapping;
	struct mutex___108 f_pos_lock;
};

struct dquot___106 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___108 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___106 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___106 {
	int qf_fmt_id;
	const struct quota_format_ops___106 *qf_ops;
	struct module___57 *qf_owner;
	struct quota_format_type___106 *qf_next;
};

struct quota_format_ops___106 {
	int (*check_quota_file)(struct super_block___106 *, int);
	int (*read_file_info)(struct super_block___106 *, int);
	int (*write_file_info)(struct super_block___106 *, int);
	int (*free_file_info)(struct super_block___106 *, int);
	int (*read_dqblk)(struct dquot___106 *);
	int (*commit_dqblk)(struct dquot___106 *);
	int (*release_dqblk)(struct dquot___106 *);
};

struct dquot_operations___106 {
	int (*write_dquot)(struct dquot___106 *);
	struct dquot___106 * (*alloc_dquot)(struct super_block___106 *, int);
	void (*destroy_dquot)(struct dquot___106 *);
	int (*acquire_dquot)(struct dquot___106 *);
	int (*release_dquot)(struct dquot___106 *);
	int (*mark_dirty)(struct dquot___106 *);
	int (*write_info)(struct super_block___106 *, int);
	qsize_t * (*get_reserved_space)(struct inode___106 *);
};

struct quotactl_ops___106 {
	int (*quota_on)(struct super_block___106 *, int, int, struct path___106 *);
	int (*quota_on_meta)(struct super_block___106 *, int, int);
	int (*quota_off)(struct super_block___106 *, int);
	int (*quota_sync)(struct super_block___106 *, int);
	int (*get_info)(struct super_block___106 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___106 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___106 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___106 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___106 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___106 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___106 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___106 *, unsigned int);
};

struct address_space_operations___106 {
	int (*writepage)(struct page___106 *, struct writeback_control *);
	int (*readpage)(struct file___106 *, struct page___106 *);
	int (*writepages)(struct address_space___106 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___106 *);
	int (*readpages)(struct file___106 *, struct address_space___106 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___106 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___106 **, void **);
	int (*write_end)(struct file___106 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___106 *, void *);
	sector_t (*bmap)(struct address_space___106 *, sector_t);
	void (*invalidatepage)(struct page___106 *, long unsigned int);
	int (*releasepage)(struct page___106 *, gfp_t);
	void (*freepage)(struct page___106 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___106 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___106 *, struct page___106 *, struct page___106 *, enum migrate_mode);
	int (*launder_page)(struct page___106 *);
	int (*is_partially_uptodate)(struct page___106 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___106 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___106 *, struct page___106 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___106 *, sector_t *);
	void (*swap_deactivate)(struct file___106 *);
	void (*invalidatepage_range)(struct page___106 *, unsigned int, unsigned int);
};

struct bdi_writeback___18 {
	struct backing_dev_info___18 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___18 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___18 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___85 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___106 *debug_dir;
	struct dentry___106 *debug_stats;
};

struct inode_operations___106 {
	struct dentry___106 * (*lookup)(struct inode___106 *, struct dentry___106 *, unsigned int);
	void * (*follow_link)(struct dentry___106 *, struct nameidata *);
	int (*permission)(struct inode___106 *, int);
	struct posix_acl * (*get_acl)(struct inode___106 *, int);
	int (*readlink)(struct dentry___106 *, char *, int);
	void (*put_link)(struct dentry___106 *, struct nameidata *, void *);
	int (*create)(struct inode___106 *, struct dentry___106 *, umode_t, bool);
	int (*link)(struct dentry___106 *, struct inode___106 *, struct dentry___106 *);
	int (*unlink)(struct inode___106 *, struct dentry___106 *);
	int (*symlink)(struct inode___106 *, struct dentry___106 *, const char *);
	int (*mkdir)(struct inode___106 *, struct dentry___106 *, umode_t);
	int (*rmdir)(struct inode___106 *, struct dentry___106 *);
	int (*mknod)(struct inode___106 *, struct dentry___106 *, umode_t, dev_t);
	int (*rename)(struct inode___106 *, struct dentry___106 *, struct inode___106 *, struct dentry___106 *);
	int (*setattr)(struct dentry___106 *, struct iattr___106 *);
	int (*getattr)(struct vfsmount *, struct dentry___106 *, struct kstat *);
	int (*setxattr)(struct dentry___106 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___106 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___106 *, char *, size_t);
	int (*removexattr)(struct dentry___106 *, const char *);
	int (*fiemap)(struct inode___106 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___106 *, struct timespec *, int);
	int (*atomic_open)(struct inode___106 *, struct dentry___106 *, struct file___106 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___80;

struct file_operations___106 {
	struct module___57 *owner;
	loff_t (*llseek)(struct file___106 *, loff_t, int);
	ssize_t (*read)(struct file___106 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___106 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___106 *, void *, filldir_t);
	unsigned int (*poll)(struct file___106 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___106 *, struct vm_area_struct___111 *);
	int (*open)(struct inode___106 *, struct file___106 *);
	int (*flush)(struct file___106 *, fl_owner_t);
	int (*release)(struct inode___106 *, struct file___106 *);
	int (*fsync)(struct file___106 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___106 *, int);
	int (*lock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*sendpage)(struct file___106 *, struct page___106 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___106 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___106 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___106 *, long int, struct file_lock___106 **, void **);
		struct {
			int (*setlease)(struct file___106 *, long int, struct file_lock___106 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___106 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___80 *, struct file___106 *);
};

struct fasync_struct___106;

struct file_lock_operations___106;

struct lock_manager_operations___106;

struct file_lock___106 {
	struct file_lock___106 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___60 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___106 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___106 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___106 *fl_ops;
	const struct lock_manager_operations___106 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___106 {
	void (*fl_copy_lock)(struct file_lock___106 *, struct file_lock___106 *);
	void (*fl_release_private)(struct file_lock___106 *);
};

struct lock_manager_operations___106 {
	int (*lm_compare_owner)(struct file_lock___106 *, struct file_lock___106 *);
	long unsigned int (*lm_owner_key)(struct file_lock___106 *);
	void (*lm_notify)(struct file_lock___106 *);
	int (*lm_grant)(struct file_lock___106 *, struct file_lock___106 *, int);
	void (*lm_break)(struct file_lock___106 *);
	int (*lm_change)(struct file_lock___106 **, int);
};

struct fasync_struct___106 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___106 *fa_next;
	struct file___106 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___106 {
	const char *name;
	int fs_flags;
	struct dentry___106 * (*mount)(struct file_system_type___106 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___106 *);
	struct module___57 *owner;
	struct file_system_type___106 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___106 {
	struct inode___106 * (*alloc_inode)(struct super_block___106 *);
	void (*destroy_inode)(struct inode___106 *);
	void (*dirty_inode)(struct inode___106 *, int);
	int (*write_inode)(struct inode___106 *, struct writeback_control *);
	int (*drop_inode)(struct inode___106 *);
	void (*evict_inode)(struct inode___106 *);
	void (*put_super)(struct super_block___106 *);
	int (*sync_fs)(struct super_block___106 *, int);
	int (*freeze_fs)(struct super_block___106 *);
	int (*unfreeze_fs)(struct super_block___106 *);
	int (*statfs)(struct dentry___106 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___106 *, int *, char *);
	void (*umount_begin)(struct super_block___106 *);
	int (*show_options)(struct seq_file___80 *, struct dentry___106 *);
	int (*show_devname)(struct seq_file___80 *, struct dentry___106 *);
	int (*show_path)(struct seq_file___80 *, struct dentry___106 *);
	int (*show_stats)(struct seq_file___80 *, struct dentry___106 *);
	ssize_t (*quota_read)(struct super_block___106 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___106 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___106 *);
	int (*bdev_try_to_free_page)(struct super_block___106 *, struct page___106 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___106 *);
	void (*free_cached_objects)(struct super_block___106 *, int);
};

struct vm_operations_struct___94;

struct vm_area_struct___111 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___111 *vm_next;
	struct vm_area_struct___111 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___111 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___94 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___106 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___79;

struct seq_file___80 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___108 lock;
	const struct seq_operations___79 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___106 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___106 *page;
	long unsigned int vaddr;
};

struct vm_fault___91;

struct vm_operations_struct___94 {
	void (*open)(struct vm_area_struct___111 *);
	void (*close)(struct vm_area_struct___111 *);
	int (*fault)(struct vm_area_struct___111 *, struct vm_fault___91 *);
	int (*page_mkwrite)(struct vm_area_struct___111 *, struct vm_fault___91 *);
	int (*access)(struct vm_area_struct___111 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___111 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___111 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___111 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___111 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___106 {
	struct task_struct___107 *task;
	struct core_thread___106 *next;
};

struct core_state___106 {
	atomic_t nr_threads;
	struct core_thread___106 dumper;
	struct completion startup;
};

struct signal_struct___106 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___107 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___107 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___60 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___60 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___108 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___91 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___106 *page;
};

struct irq_chip___78 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___78 *);
	void (*irq_shutdown)(struct irq_data___78 *);
	void (*irq_enable)(struct irq_data___78 *);
	void (*irq_disable)(struct irq_data___78 *);
	void (*irq_ack)(struct irq_data___78 *);
	void (*irq_mask)(struct irq_data___78 *);
	void (*irq_mask_ack)(struct irq_data___78 *);
	void (*irq_unmask)(struct irq_data___78 *);
	void (*irq_eoi)(struct irq_data___78 *);
	int (*irq_set_affinity)(struct irq_data___78 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___78 *);
	int (*irq_set_type)(struct irq_data___78 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___78 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___78 *);
	void (*irq_bus_sync_unlock)(struct irq_data___78 *);
	void (*irq_cpu_online)(struct irq_data___78 *);
	void (*irq_cpu_offline)(struct irq_data___78 *);
	void (*irq_suspend)(struct irq_data___78 *);
	void (*irq_resume)(struct irq_data___78 *);
	void (*irq_pm_shutdown)(struct irq_data___78 *);
	void (*irq_print_chip)(struct irq_data___78 *, struct seq_file___80 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___78 *, void *);
	long unsigned int flags;
};

struct bin_attribute___78;

struct attribute_group___78 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___78 **bin_attrs;
};

struct bin_attribute___78 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___106 *, struct kobject *, struct bin_attribute___78 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___106 *, struct kobject *, struct bin_attribute___78 *, char *, loff_t, size_t);
	int (*mmap)(struct file___106 *, struct kobject *, struct bin_attribute___78 *, struct vm_area_struct___111 *);
};

struct module_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___56 *, struct module_kobject___56 *, char *);
	ssize_t (*store)(struct module_attribute___56 *, struct module_kobject___56 *, const char *, size_t);
	void (*setup)(struct module___57 *, const char *);
	int (*test)(struct module___57 *);
	void (*free)(struct module___57 *);
};

struct bus_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___85 *, char *);
	ssize_t (*store)(struct bus_type___85 *, const char *, size_t);
};

struct device_attribute___85;

struct driver_attribute___85;

struct bus_type___85 {
	const char *name;
	const char *dev_name;
	struct device___85 *dev_root;
	struct bus_attribute___85 *bus_attrs;
	struct device_attribute___85 *dev_attrs;
	struct driver_attribute___85 *drv_attrs;
	const struct attribute_group___78 **bus_groups;
	const struct attribute_group___78 **dev_groups;
	const struct attribute_group___78 **drv_groups;
	int (*match)(struct device___85 *, struct device_driver___85 *);
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	int (*probe)(struct device___85 *);
	int (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*online)(struct device___85 *);
	int (*offline)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct device___85 *, struct device_attribute___85 *, char *);
	ssize_t (*store)(struct device___85 *, struct device_attribute___85 *, const char *, size_t);
};

struct driver_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___85 *, char *);
	ssize_t (*store)(struct device_driver___85 *, const char *, size_t);
};

struct device_driver___85 {
	const char *name;
	struct bus_type___85 *bus;
	struct module___57 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___85 *);
	int (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	const struct attribute_group___78 **groups;
	const struct dev_pm_ops___85 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___85 {
	const char *name;
	const struct attribute_group___78 **groups;
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
};

struct class_attribute___85;

struct class___85 {
	const char *name;
	struct module___57 *owner;
	struct class_attribute___85 *class_attrs;
	struct device_attribute___85 *dev_attrs;
	const struct attribute_group___78 **dev_groups;
	struct bin_attribute___78 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *);
	void (*class_release)(struct class___85 *);
	void (*dev_release)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
	struct subsys_private *p;
};

struct class_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct class___85 *, struct class_attribute___85 *, char *);
	ssize_t (*store)(struct class___85 *, struct class_attribute___85 *, const char *, size_t);
	const void * (*namespace)(struct class___85 *, const struct class_attribute___85 *);
};

struct device_rh___85 {
	struct dev_pm_info_rh___85 power;
};

struct seq_operations___79 {
	void * (*start)(struct seq_file___80 *, loff_t *);
	void (*stop)(struct seq_file___80 *, void *);
	void * (*next)(struct seq_file___80 *, void *, loff_t *);
	int (*show)(struct seq_file___80 *, void *);
};

typedef struct pglist_data___106 pg_data_t___7;

struct pcpu_group_info {
	int nr_units;
	long unsigned int base_offset;
	unsigned int *cpu_map;
};

struct pcpu_alloc_info {
	size_t static_size;
	size_t reserved_size;
	size_t dyn_size;
	size_t unit_size;
	size_t atom_size;
	size_t alloc_size;
	size_t __ai_size;
	int nr_groups;
	struct pcpu_group_info groups[0];
};

struct pcpu_chunk {
	struct list_head list;
	int free_size;
	int contig_hint;
	void *base_addr;
	int map_used;
	int map_alloc;
	int *map;
	struct work_struct map_extend_work;
	void *data;
	int first_free;
	bool immutable;
	int nr_populated;
	long unsigned int populated[0];
};

struct kmem_cache_node {
	spinlock_t list_lock;
	long unsigned int nr_partial;
	struct list_head partial;
	atomic_long_t nr_slabs;
	atomic_long_t total_objects;
	struct list_head full;
};

struct tlb_state___27 {
	struct mm_struct___53 *active_mm;
	int state;
};

struct cftype___30 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___50 *, struct file___49 *);
	ssize_t (*read)(struct cgroup___22 *, struct cftype___30 *, struct file___49 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___22 *, struct cftype___30 *);
	s64 (*read_s64)(struct cgroup___22 *, struct cftype___30 *);
	int (*read_map)(struct cgroup___22 *, struct cftype___30 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___22 *, struct cftype___30 *, struct seq_file___33 *);
	ssize_t (*write)(struct cgroup___22 *, struct cftype___30 *, struct file___49 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___22 *, struct cftype___30 *, u64);
	int (*write_s64)(struct cgroup___22 *, struct cftype___30 *, s64);
	int (*write_string)(struct cgroup___22 *, struct cftype___30 *, const char *);
	int (*trigger)(struct cgroup___22 *, unsigned int);
	int (*release)(struct inode___50 *, struct file___49 *);
	int (*register_event)(struct cgroup___22 *, struct cftype___30 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___22 *, struct cftype___30 *, struct eventfd_ctx *);
};

struct cftype_set___28 {
	struct list_head node;
	struct cftype___30 *cfts;
};

struct task_and_cgroup___28 {
	struct task_struct___50 *task;
	struct cgroup___22 *cgrp;
	struct css_set___22 *cg;
};

struct cgroup_taskset___28 {
	struct task_and_cgroup___28 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___22 *cur_cgrp;
};

struct cgroup_subsys___28 {
	struct cgroup_subsys_state___22 * (*css_alloc)(struct cgroup___22 *);
	int (*css_online)(struct cgroup___22 *);
	void (*css_offline)(struct cgroup___22 *);
	void (*css_free)(struct cgroup___22 *);
	int (*can_attach)(struct cgroup___22 *, struct cgroup_taskset___28 *);
	void (*cancel_attach)(struct cgroup___22 *, struct cgroup_taskset___28 *);
	void (*attach)(struct cgroup___22 *, struct cgroup_taskset___28 *);
	void (*fork)(struct task_struct___50 *);
	void (*exit)(struct cgroup___22 *, struct cgroup___22 *, struct task_struct___50 *);
	void (*bind)(struct cgroup___22 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___22 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___30 *base_cftypes;
	struct cftype_set___28 base_cftset;
	struct module___32 *module;
};

enum slab_state {
	DOWN = 0,
	PARTIAL = 1,
	PARTIAL_ARRAYCACHE = 2,
	PARTIAL_NODE = 3,
	UP = 4,
	FULL = 5,
};

struct slabinfo {
	long unsigned int active_objs;
	long unsigned int num_objs;
	long unsigned int active_slabs;
	long unsigned int num_slabs;
	long unsigned int shared_avail;
	unsigned int limit;
	unsigned int batchcount;
	unsigned int shared;
	unsigned int objects_per_slab;
	unsigned int cache_order;
};

struct page___107;

typedef struct page___107 *pgtable_t___107;

struct address_space___107;

struct kmem_cache___94;

struct page___107 {
	long unsigned int flags;
	struct address_space___107 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___107 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___107 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___94 *slab_cache;
		struct page___107 *first_page;
	};
	long: 64;
};

struct thread_struct___56;

struct task_struct___108;

struct pv_cpu_ops___107 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___56 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___56 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___108 *);
	void (*end_context_switch)(struct task_struct___108 *);
};

struct perf_event___56;

struct thread_struct___56 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___56 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___61;

struct pid_link___61 {
	struct hlist_node node;
	struct pid___61 *pid;
};

struct mutex___109 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___108 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___103 {
	struct page___107 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___112;

struct nsproxy___62;

struct signal_struct___107;

struct backing_dev_info___19;

struct css_set___72;

struct perf_event_context___56;

struct task_struct___108 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___108 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___112 *mm;
	struct mm_struct___112 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___108 *real_parent;
	struct task_struct___108 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___108 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___61 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___107 = 0,
		VTIME_USER___107 = 1,
		VTIME_SYS___107 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___56 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___62 *nsproxy;
	struct signal_struct___107 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___19 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___72 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___56 *perf_event_ctxp[2];
	struct mutex___109 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___103 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___112 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___112 *, struct mm_struct___112 *);
	void (*dup_mmap)(struct mm_struct___112 *, struct mm_struct___112 *);
	void (*exit_mmap)(struct mm_struct___112 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___112 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___112 *);
	void (*pgd_free)(struct mm_struct___112 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___112 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___112 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___112 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___112 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___112 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___112 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___112 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___112 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___112 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___112 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___112 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___109 lock;
	void *vdso;
} mm_context_t___108;

struct xol_area___107;

struct uprobes_state___107 {
	struct xol_area___107 *xol_area;
};

struct vm_area_struct___112;

struct file___107;

struct core_state___107;

struct mm_struct___112 {
	struct vm_area_struct___112 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___112 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___112 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___108 context;
	long unsigned int flags;
	struct core_state___107 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___108 *owner;
	struct file___107 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___107 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___56 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___108 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___108 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___108 *target;
};

typedef void (*perf_overflow_handler_t___56)(struct perf_event___56 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___56;

typedef void (*ftrace_func_t___56)(long unsigned int, long unsigned int, struct ftrace_ops___56 *, struct pt_regs *);

struct ftrace_ops___56 {
	ftrace_func_t___56 func;
	struct ftrace_ops___56 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___109 regex_lock;
};

struct pmu___56;

struct fasync_struct___107;

struct pid_namespace___61;

struct ftrace_event_call___46;

struct perf_cgroup___56;

struct perf_event___56 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___56 *group_leader;
	struct pmu___56 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___56 hw;
	struct perf_event_context___56 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___109 child_mutex;
	struct list_head child_list;
	struct perf_event___56 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___108 *owner;
	struct mutex___109 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___107 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___56 *);
	struct callback_head callback_head;
	struct pid_namespace___61 *ns;
	u64 id;
	perf_overflow_handler_t___56 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___46 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___56 ftrace_ops;
	struct perf_cgroup___56 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___55 {
	struct task_struct___108 *task;
	struct exec_domain___28 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___107;

struct lruvec___107 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___107 *zone;
};

struct pglist_data___107;

struct zone___107 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___107 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___107 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___107 {
	struct zone___107 *zone;
	int zone_idx;
};

struct zonelist___107 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___107 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___107 {
	struct zone___107 node_zones[4];
	struct zonelist___107 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___108 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct pglist_data___107 pg_data_t___8;

struct irq_data___79;

struct x86_io_apic_ops___79 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___79 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___79;

struct irq_data___79 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___79 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___86;

struct dev_pm_ops___86 {
	int (*prepare)(struct device___86 *);
	void (*complete)(struct device___86 *);
	int (*suspend)(struct device___86 *);
	int (*resume)(struct device___86 *);
	int (*freeze)(struct device___86 *);
	int (*thaw)(struct device___86 *);
	int (*poweroff)(struct device___86 *);
	int (*restore)(struct device___86 *);
	int (*suspend_late)(struct device___86 *);
	int (*resume_early)(struct device___86 *);
	int (*freeze_late)(struct device___86 *);
	int (*thaw_early)(struct device___86 *);
	int (*poweroff_late)(struct device___86 *);
	int (*restore_early)(struct device___86 *);
	int (*suspend_noirq)(struct device___86 *);
	int (*resume_noirq)(struct device___86 *);
	int (*freeze_noirq)(struct device___86 *);
	int (*thaw_noirq)(struct device___86 *);
	int (*poweroff_noirq)(struct device___86 *);
	int (*restore_noirq)(struct device___86 *);
	int (*runtime_suspend)(struct device___86 *);
	int (*runtime_resume)(struct device___86 *);
	int (*runtime_idle)(struct device___86 *);
};

struct device_type___86;

struct bus_type___86;

struct device_driver___86;

struct dev_pm_domain___86;

struct class___86;

struct attribute_group___79;

struct device_rh___86;

struct device___86 {
	struct device___86 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___86 *type;
	struct mutex___109 mutex;
	struct bus_type___86 *bus;
	struct device_driver___86 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___86 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___86 *class;
	const struct attribute_group___79 **groups;
	void (*release)(struct device___86 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___86 *device_rh;
};

struct dev_pm_info_rh___86 {
	void (*set_latency_tolerance)(struct device___86 *, s32);
};

struct dev_pm_domain___86 {
	struct dev_pm_ops___86 ops;
};

struct smp_ops___107 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___108 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___107 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___107 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___94;

struct memcg_cache_params___94;

struct kmem_cache___94 {
	struct kmem_cache_cpu___94 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___94 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___107;

struct address_space_operations___107;

struct address_space___107 {
	struct inode___107 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___109 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___107 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___19 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___107;

struct path___107 {
	struct vfsmount *mnt;
	struct dentry___107 *dentry;
};

struct fown_struct___61 {
	rwlock_t lock;
	struct pid___61 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___107;

struct file___107 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___107 f_path;
	struct inode___107 *f_inode;
	const struct file_operations___107 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___61 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___107 *f_mapping;
	struct mutex___109 f_pos_lock;
};

struct vm_operations_struct___95;

struct vm_area_struct___112 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___112 *vm_next;
	struct vm_area_struct___112 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___112 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___95 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___107 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___92;

struct vm_operations_struct___95 {
	void (*open)(struct vm_area_struct___112 *);
	void (*close)(struct vm_area_struct___112 *);
	int (*fault)(struct vm_area_struct___112 *, struct vm_fault___92 *);
	int (*page_mkwrite)(struct vm_area_struct___112 *, struct vm_fault___92 *);
	int (*access)(struct vm_area_struct___112 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___112 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___112 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___112 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___112 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___107 {
	struct task_struct___108 *task;
	struct core_thread___107 *next;
};

struct core_state___107 {
	atomic_t nr_threads;
	struct core_thread___107 dumper;
	struct completion startup;
};

struct upid___61 {
	int nr;
	struct pid_namespace___61 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___61 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___108 *child_reaper;
	struct kmem_cache___94 *pid_cachep;
	unsigned int level;
	struct pid_namespace___61 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___107 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___61 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___61 numbers[1];
};

struct nsproxy___62 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___61 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___107 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___108 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___108 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___61 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___61 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___109 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback___19 {
	struct backing_dev_info___19 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___19 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___19 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___86 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___107 *debug_dir;
	struct dentry___107 *debug_stats;
};

struct cgroup_subsys_state___74;

struct css_set___72 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___74 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___56 {
	struct pmu___56 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___109 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___108 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___56 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___79;

struct attribute_group___79 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___79 **bin_attrs;
};

struct bin_attribute___79 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___107 *, struct kobject *, struct bin_attribute___79 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___107 *, struct kobject *, struct bin_attribute___79 *, char *, loff_t, size_t);
	int (*mmap)(struct file___107 *, struct kobject *, struct bin_attribute___79 *, struct vm_area_struct___112 *);
};

struct kmem_cache_cpu___94 {
	void **freelist;
	long unsigned int tid;
	struct page___107 *page;
	struct page___107 *partial;
};

struct memcg_cache_params___94 {
	bool is_root_cache;
	union {
		struct kmem_cache___94 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___94 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___72 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___107 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___107 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___107 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___107;

struct super_block___107;

struct dentry___107 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___107 *d_parent;
	struct qstr d_name;
	struct inode___107 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___107 *d_op;
	struct super_block___107 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___107;

struct file_lock___107;

struct dquot___107;

struct block_device___107;

struct inode___107 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___107 *i_op;
	struct super_block___107 *i_sb;
	struct address_space___107 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___109 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___107 *i_fop;
	struct file_lock___107 *i_flock;
	struct address_space___107 i_data;
	struct dquot___107 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___107 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___107 {
	int (*d_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_hash)(const struct dentry___107 *, struct qstr *);
	int (*d_compare)(const struct dentry___107 *, const struct dentry___107 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___107 *);
	void (*d_release)(struct dentry___107 *);
	void (*d_prune)(struct dentry___107 *);
	void (*d_iput)(struct dentry___107 *, struct inode___107 *);
	char * (*d_dname)(struct dentry___107 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___107 *);
	int (*d_manage)(struct dentry___107 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___107;

struct mem_dqinfo___107 {
	struct quota_format_type___107 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___107;

struct quota_info___107 {
	unsigned int flags;
	struct mutex___109 dqio_mutex;
	struct mutex___109 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___107 *files[2];
	struct mem_dqinfo___107 info[2];
	const struct quota_format_ops___107 *ops[2];
};

struct file_system_type___107;

struct super_operations___107;

struct dquot_operations___107;

struct quotactl_ops___107;

struct super_block___107 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___107 *s_type;
	const struct super_operations___107 *s_op;
	const struct dquot_operations___107 *dq_op;
	const struct quotactl_ops___107 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___107 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___72 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___107 *s_bdev;
	struct backing_dev_info___19 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___107 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___109 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___107 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___107 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___107 *bd_inode;
	struct super_block___107 *bd_super;
	struct mutex___109 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___107 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___109 bd_fsfreeze_mutex;
};

struct cgroup___73;

struct cgroup_subsys_state___74 {
	struct cgroup___73 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___107 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___107 *ia_file;
};

struct dquot___107 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___109 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___107 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___107 {
	int qf_fmt_id;
	const struct quota_format_ops___107 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___107 *qf_next;
};

struct quota_format_ops___107 {
	int (*check_quota_file)(struct super_block___107 *, int);
	int (*read_file_info)(struct super_block___107 *, int);
	int (*write_file_info)(struct super_block___107 *, int);
	int (*free_file_info)(struct super_block___107 *, int);
	int (*read_dqblk)(struct dquot___107 *);
	int (*commit_dqblk)(struct dquot___107 *);
	int (*release_dqblk)(struct dquot___107 *);
};

struct dquot_operations___107 {
	int (*write_dquot)(struct dquot___107 *);
	struct dquot___107 * (*alloc_dquot)(struct super_block___107 *, int);
	void (*destroy_dquot)(struct dquot___107 *);
	int (*acquire_dquot)(struct dquot___107 *);
	int (*release_dquot)(struct dquot___107 *);
	int (*mark_dirty)(struct dquot___107 *);
	int (*write_info)(struct super_block___107 *, int);
	qsize_t * (*get_reserved_space)(struct inode___107 *);
};

struct quotactl_ops___107 {
	int (*quota_on)(struct super_block___107 *, int, int, struct path___107 *);
	int (*quota_on_meta)(struct super_block___107 *, int, int);
	int (*quota_off)(struct super_block___107 *, int);
	int (*quota_sync)(struct super_block___107 *, int);
	int (*get_info)(struct super_block___107 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___107 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___107 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___107 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___107 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___107 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___107 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___107 *, unsigned int);
};

struct swap_info_struct___22;

struct address_space_operations___107 {
	int (*writepage)(struct page___107 *, struct writeback_control *);
	int (*readpage)(struct file___107 *, struct page___107 *);
	int (*writepages)(struct address_space___107 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___107 *);
	int (*readpages)(struct file___107 *, struct address_space___107 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___107 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___107 **, void **);
	int (*write_end)(struct file___107 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___107 *, void *);
	sector_t (*bmap)(struct address_space___107 *, sector_t);
	void (*invalidatepage)(struct page___107 *, long unsigned int);
	int (*releasepage)(struct page___107 *, gfp_t);
	void (*freepage)(struct page___107 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___107 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___107 *, struct page___107 *, struct page___107 *, enum migrate_mode);
	int (*launder_page)(struct page___107 *);
	int (*is_partially_uptodate)(struct page___107 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___107 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___107 *, struct page___107 *);
	int (*swap_activate)(struct swap_info_struct___22 *, struct file___107 *, sector_t *);
	void (*swap_deactivate)(struct file___107 *);
	void (*invalidatepage_range)(struct page___107 *, unsigned int, unsigned int);
};

struct swap_info_struct___22 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___107 *bdev;
	struct file___107 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___107 {
	struct dentry___107 * (*lookup)(struct inode___107 *, struct dentry___107 *, unsigned int);
	void * (*follow_link)(struct dentry___107 *, struct nameidata *);
	int (*permission)(struct inode___107 *, int);
	struct posix_acl * (*get_acl)(struct inode___107 *, int);
	int (*readlink)(struct dentry___107 *, char *, int);
	void (*put_link)(struct dentry___107 *, struct nameidata *, void *);
	int (*create)(struct inode___107 *, struct dentry___107 *, umode_t, bool);
	int (*link)(struct dentry___107 *, struct inode___107 *, struct dentry___107 *);
	int (*unlink)(struct inode___107 *, struct dentry___107 *);
	int (*symlink)(struct inode___107 *, struct dentry___107 *, const char *);
	int (*mkdir)(struct inode___107 *, struct dentry___107 *, umode_t);
	int (*rmdir)(struct inode___107 *, struct dentry___107 *);
	int (*mknod)(struct inode___107 *, struct dentry___107 *, umode_t, dev_t);
	int (*rename)(struct inode___107 *, struct dentry___107 *, struct inode___107 *, struct dentry___107 *);
	int (*setattr)(struct dentry___107 *, struct iattr___107 *);
	int (*getattr)(struct vfsmount *, struct dentry___107 *, struct kstat *);
	int (*setxattr)(struct dentry___107 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___107 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___107 *, char *, size_t);
	int (*removexattr)(struct dentry___107 *, const char *);
	int (*fiemap)(struct inode___107 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___107 *, struct timespec *, int);
	int (*atomic_open)(struct inode___107 *, struct dentry___107 *, struct file___107 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___68;

struct seq_file___81;

struct file_operations___107 {
	struct module *owner;
	loff_t (*llseek)(struct file___107 *, loff_t, int);
	ssize_t (*read)(struct file___107 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___107 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___107 *, void *, filldir_t);
	unsigned int (*poll)(struct file___107 *, struct poll_table_struct___68 *);
	long int (*unlocked_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___107 *, struct vm_area_struct___112 *);
	int (*open)(struct inode___107 *, struct file___107 *);
	int (*flush)(struct file___107 *, fl_owner_t);
	int (*release)(struct inode___107 *, struct file___107 *);
	int (*fsync)(struct file___107 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___107 *, int);
	int (*lock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*sendpage)(struct file___107 *, struct page___107 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___107 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___107 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___107 *, long int, struct file_lock___107 **, void **);
		struct {
			int (*setlease)(struct file___107 *, long int, struct file_lock___107 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___107 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___81 *, struct file___107 *);
};

struct file_lock_operations___107;

struct lock_manager_operations___107;

struct file_lock___107 {
	struct file_lock___107 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___61 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___107 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___107 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___107 *fl_ops;
	const struct lock_manager_operations___107 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___107 {
	void (*fl_copy_lock)(struct file_lock___107 *, struct file_lock___107 *);
	void (*fl_release_private)(struct file_lock___107 *);
};

struct lock_manager_operations___107 {
	int (*lm_compare_owner)(struct file_lock___107 *, struct file_lock___107 *);
	long unsigned int (*lm_owner_key)(struct file_lock___107 *);
	void (*lm_notify)(struct file_lock___107 *);
	int (*lm_grant)(struct file_lock___107 *, struct file_lock___107 *, int);
	void (*lm_break)(struct file_lock___107 *);
	int (*lm_change)(struct file_lock___107 **, int);
};

struct fasync_struct___107 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___107 *fa_next;
	struct file___107 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___107 {
	const char *name;
	int fs_flags;
	struct dentry___107 * (*mount)(struct file_system_type___107 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___107 *);
	struct module *owner;
	struct file_system_type___107 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___107 {
	struct inode___107 * (*alloc_inode)(struct super_block___107 *);
	void (*destroy_inode)(struct inode___107 *);
	void (*dirty_inode)(struct inode___107 *, int);
	int (*write_inode)(struct inode___107 *, struct writeback_control *);
	int (*drop_inode)(struct inode___107 *);
	void (*evict_inode)(struct inode___107 *);
	void (*put_super)(struct super_block___107 *);
	int (*sync_fs)(struct super_block___107 *, int);
	int (*freeze_fs)(struct super_block___107 *);
	int (*unfreeze_fs)(struct super_block___107 *);
	int (*statfs)(struct dentry___107 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___107 *, int *, char *);
	void (*umount_begin)(struct super_block___107 *);
	int (*show_options)(struct seq_file___81 *, struct dentry___107 *);
	int (*show_devname)(struct seq_file___81 *, struct dentry___107 *);
	int (*show_path)(struct seq_file___81 *, struct dentry___107 *);
	int (*show_stats)(struct seq_file___81 *, struct dentry___107 *);
	ssize_t (*quota_read)(struct super_block___107 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___107 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___107 *);
	int (*bdev_try_to_free_page)(struct super_block___107 *, struct page___107 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___107 *);
	void (*free_cached_objects)(struct super_block___107 *, int);
};

typedef void (*poll_queue_proc___70)(struct file___107 *, wait_queue_head_t *, struct poll_table_struct___68 *);

struct poll_table_struct___68 {
	poll_queue_proc___70 _qproc;
	long unsigned int _key;
};

struct seq_operations___80;

struct seq_file___81 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___109 lock;
	const struct seq_operations___80 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___72;

struct cgroup___73 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___73 *parent;
	struct dentry___107 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___74 *subsys[11];
	struct cgroupfs_root___72 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___109 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___72 {
	struct super_block___107 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___73 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___31 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___107 *, struct file___107 *);
	ssize_t (*read)(struct cgroup___73 *, struct cftype___31 *, struct file___107 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___73 *, struct cftype___31 *);
	s64 (*read_s64)(struct cgroup___73 *, struct cftype___31 *);
	int (*read_map)(struct cgroup___73 *, struct cftype___31 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___73 *, struct cftype___31 *, struct seq_file___81 *);
	ssize_t (*write)(struct cgroup___73 *, struct cftype___31 *, struct file___107 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___73 *, struct cftype___31 *, u64);
	int (*write_s64)(struct cgroup___73 *, struct cftype___31 *, s64);
	int (*write_string)(struct cgroup___73 *, struct cftype___31 *, const char *);
	int (*trigger)(struct cgroup___73 *, unsigned int);
	int (*release)(struct inode___107 *, struct file___107 *);
	int (*register_event)(struct cgroup___73 *, struct cftype___31 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___73 *, struct cftype___31 *, struct eventfd_ctx *);
};

struct cftype_set___29 {
	struct list_head node;
	struct cftype___31 *cfts;
};

struct task_and_cgroup___29 {
	struct task_struct___108 *task;
	struct cgroup___73 *cgrp;
	struct css_set___72 *cg;
};

struct cgroup_taskset___29 {
	struct task_and_cgroup___29 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___73 *cur_cgrp;
};

struct cgroup_subsys___29 {
	struct cgroup_subsys_state___74 * (*css_alloc)(struct cgroup___73 *);
	int (*css_online)(struct cgroup___73 *);
	void (*css_offline)(struct cgroup___73 *);
	void (*css_free)(struct cgroup___73 *);
	int (*can_attach)(struct cgroup___73 *, struct cgroup_taskset___29 *);
	void (*cancel_attach)(struct cgroup___73 *, struct cgroup_taskset___29 *);
	void (*attach)(struct cgroup___73 *, struct cgroup_taskset___29 *);
	void (*fork)(struct task_struct___108 *);
	void (*exit)(struct cgroup___73 *, struct cgroup___73 *, struct task_struct___108 *);
	void (*bind)(struct cgroup___73 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___72 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___31 *base_cftypes;
	struct cftype_set___29 base_cftset;
	struct module *module;
};

struct irq_chip___79 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___79 *);
	void (*irq_shutdown)(struct irq_data___79 *);
	void (*irq_enable)(struct irq_data___79 *);
	void (*irq_disable)(struct irq_data___79 *);
	void (*irq_ack)(struct irq_data___79 *);
	void (*irq_mask)(struct irq_data___79 *);
	void (*irq_mask_ack)(struct irq_data___79 *);
	void (*irq_unmask)(struct irq_data___79 *);
	void (*irq_eoi)(struct irq_data___79 *);
	int (*irq_set_affinity)(struct irq_data___79 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___79 *);
	int (*irq_set_type)(struct irq_data___79 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___79 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___79 *);
	void (*irq_bus_sync_unlock)(struct irq_data___79 *);
	void (*irq_cpu_online)(struct irq_data___79 *);
	void (*irq_cpu_offline)(struct irq_data___79 *);
	void (*irq_suspend)(struct irq_data___79 *);
	void (*irq_resume)(struct irq_data___79 *);
	void (*irq_pm_shutdown)(struct irq_data___79 *);
	void (*irq_print_chip)(struct irq_data___79 *, struct seq_file___81 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___79 *, void *);
	long unsigned int flags;
};

struct bus_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___86 *, char *);
	ssize_t (*store)(struct bus_type___86 *, const char *, size_t);
};

struct device_attribute___86;

struct driver_attribute___86;

struct bus_type___86 {
	const char *name;
	const char *dev_name;
	struct device___86 *dev_root;
	struct bus_attribute___86 *bus_attrs;
	struct device_attribute___86 *dev_attrs;
	struct driver_attribute___86 *drv_attrs;
	const struct attribute_group___79 **bus_groups;
	const struct attribute_group___79 **dev_groups;
	const struct attribute_group___79 **drv_groups;
	int (*match)(struct device___86 *, struct device_driver___86 *);
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	int (*probe)(struct device___86 *);
	int (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*online)(struct device___86 *);
	int (*offline)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct device___86 *, struct device_attribute___86 *, char *);
	ssize_t (*store)(struct device___86 *, struct device_attribute___86 *, const char *, size_t);
};

struct driver_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___86 *, char *);
	ssize_t (*store)(struct device_driver___86 *, const char *, size_t);
};

struct device_driver___86 {
	const char *name;
	struct bus_type___86 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___86 *);
	int (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	const struct attribute_group___79 **groups;
	const struct dev_pm_ops___86 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___86 {
	const char *name;
	const struct attribute_group___79 **groups;
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
};

struct class_attribute___86;

struct class___86 {
	const char *name;
	struct module *owner;
	struct class_attribute___86 *class_attrs;
	struct device_attribute___86 *dev_attrs;
	const struct attribute_group___79 **dev_groups;
	struct bin_attribute___79 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *);
	void (*class_release)(struct class___86 *);
	void (*dev_release)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
	struct subsys_private *p;
};

struct class_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct class___86 *, struct class_attribute___86 *, char *);
	ssize_t (*store)(struct class___86 *, struct class_attribute___86 *, const char *, size_t);
	const void * (*namespace)(struct class___86 *, const struct class_attribute___86 *);
};

struct device_rh___86 {
	struct dev_pm_info_rh___86 power;
};

struct node___2 {
	struct device___86 dev;
	struct work_struct node_work;
};

struct vm_fault___92 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___107 *page;
};

typedef struct page___107 *new_page_t___2(struct page___107 *, long unsigned int, int **);

typedef void free_page_t___2(struct page___107 *, long unsigned int);

struct compact_control___2 {
	struct list_head freepages;
	struct list_head migratepages;
	long unsigned int nr_freepages;
	long unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	int order;
	const gfp_t gfp_mask;
	const int alloc_flags;
	const int classzone_idx;
	struct zone___107 *zone;
	int contended;
};

struct seq_operations___80 {
	void * (*start)(struct seq_file___81 *, loff_t *);
	void (*stop)(struct seq_file___81 *, void *);
	void * (*next)(struct seq_file___81 *, void *, loff_t *);
	int (*show)(struct seq_file___81 *, void *);
};

struct perf_cpu_context___56;

struct pmu___56 {
	struct list_head entry;
	struct device___86 *dev;
	const struct attribute_group___79 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___56 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___56 *);
	void (*pmu_disable)(struct pmu___56 *);
	int (*event_init)(struct perf_event___56 *);
	int (*add)(struct perf_event___56 *, int);
	void (*del)(struct perf_event___56 *, int);
	void (*start)(struct perf_event___56 *, int);
	void (*stop)(struct perf_event___56 *, int);
	void (*read)(struct perf_event___56 *);
	void (*start_txn)(struct pmu___56 *);
	int (*commit_txn)(struct pmu___56 *);
	void (*cancel_txn)(struct pmu___56 *);
	int (*event_idx)(struct perf_event___56 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___56 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___56 *);
};

struct perf_cpu_context___56 {
	struct perf_event_context___56 ctx;
	struct perf_event_context___56 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___56 *unique_pmu;
	struct perf_cgroup___56 *cgrp;
};

struct trace_event_functions___46;

struct trace_event___46 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___46 *funcs;
};

struct ftrace_event_class___46;

struct ftrace_event_call___46 {
	struct list_head list;
	struct ftrace_event_class___46 *class;
	char *name;
	struct trace_event___46 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___56 {
	struct cgroup_subsys_state___74 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___46 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___109 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___46)(struct trace_iterator___46 *, int, struct trace_event___46 *);

struct trace_event_functions___46 {
	trace_print_func___46 trace;
	trace_print_func___46 raw;
	trace_print_func___46 hex;
	trace_print_func___46 binary;
};

struct ftrace_event_class___46 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___46 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___46 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___46 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___46 *);
};

struct ftrace_event_file___20 {
	struct list_head list;
	struct ftrace_event_call___46 *event_call;
	struct dentry___107 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_mm_compaction_isolate_template {
	struct trace_entry ent;
	long unsigned int nr_scanned;
	long unsigned int nr_taken;
	char __data[0];
};

struct ftrace_raw_mm_compaction_migratepages {
	struct trace_entry ent;
	long unsigned int nr_migrated;
	long unsigned int nr_failed;
	char __data[0];
};

struct ftrace_data_offsets_mm_compaction_isolate_template {};

struct ftrace_data_offsets_mm_compaction_migratepages {};

typedef enum {
	ISOLATE_ABORT = 0,
	ISOLATE_NONE = 1,
	ISOLATE_SUCCESS = 2,
} isolate_migrate_t;

struct balloon_dev_info {
	void *balloon_device;
	struct address_space___37 *mapping;
	long unsigned int isolated_pages;
	spinlock_t pages_lock;
	struct list_head pages;
};

struct anon_vma_chain {
	struct vm_area_struct___40 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

enum lru_status {
	LRU_REMOVED = 0,
	LRU_REMOVED_RETRY = 1,
	LRU_ROTATE = 2,
	LRU_SKIP = 3,
	LRU_RETRY = 4,
};

struct list_lru_node {
	spinlock_t lock;
	struct list_head list;
	long int nr_items;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct list_lru {
	struct list_lru_node *node;
	nodemask_t active_nodes;
};

typedef enum lru_status (*list_lru_walk_cb)(struct list_head *, spinlock_t *, void *);

struct page___108;

typedef struct page___108 *pgtable_t___108;

struct address_space___108;

struct kmem_cache___95;

struct page___108 {
	long unsigned int flags;
	struct address_space___108 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___108 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___108 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___95 *slab_cache;
		struct page___108 *first_page;
	};
	long: 64;
};

struct thread_struct___57;

struct task_struct___109;

struct pv_cpu_ops___108 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___57 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___57 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___109 *);
	void (*end_context_switch)(struct task_struct___109 *);
};

struct perf_event___57;

struct thread_struct___57 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___57 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___62;

struct pid_link___62 {
	struct hlist_node node;
	struct pid___62 *pid;
};

struct mutex___110 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___109 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___104 {
	struct page___108 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___113;

struct nsproxy___63;

struct signal_struct___108;

struct backing_dev_info___20;

struct css_set___73;

struct perf_event_context___57;

struct task_struct___109 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___109 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___113 *mm;
	struct mm_struct___113 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___109 *real_parent;
	struct task_struct___109 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___109 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___62 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___108 = 0,
		VTIME_USER___108 = 1,
		VTIME_SYS___108 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___57 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___63 *nsproxy;
	struct signal_struct___108 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___20 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___73 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___57 *perf_event_ctxp[2];
	struct mutex___110 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___104 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___113 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___113 *, struct mm_struct___113 *);
	void (*dup_mmap)(struct mm_struct___113 *, struct mm_struct___113 *);
	void (*exit_mmap)(struct mm_struct___113 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___113 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___113 *);
	void (*pgd_free)(struct mm_struct___113 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___113 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___113 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___113 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___113 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___113 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___113 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___113 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___113 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___113 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___113 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___113 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___110 lock;
	void *vdso;
} mm_context_t___109;

struct xol_area___108;

struct uprobes_state___108 {
	struct xol_area___108 *xol_area;
};

struct vm_area_struct___113;

struct file___108;

struct core_state___108;

struct mm_struct___113 {
	struct vm_area_struct___113 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___113 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___113 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___109 context;
	long unsigned int flags;
	struct core_state___108 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___109 *owner;
	struct file___108 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___108 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___57 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___109 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___109 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___109 *target;
};

typedef void (*perf_overflow_handler_t___57)(struct perf_event___57 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___57;

typedef void (*ftrace_func_t___57)(long unsigned int, long unsigned int, struct ftrace_ops___57 *, struct pt_regs *);

struct ftrace_ops___57 {
	ftrace_func_t___57 func;
	struct ftrace_ops___57 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___110 regex_lock;
};

struct pmu___57;

struct fasync_struct___108;

struct pid_namespace___62;

struct ftrace_event_call___47;

struct perf_cgroup___57;

struct perf_event___57 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___57 *group_leader;
	struct pmu___57 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___57 hw;
	struct perf_event_context___57 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___110 child_mutex;
	struct list_head child_list;
	struct perf_event___57 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___109 *owner;
	struct mutex___110 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___108 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___57 *);
	struct callback_head callback_head;
	struct pid_namespace___62 *ns;
	u64 id;
	perf_overflow_handler_t___57 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___47 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___57 ftrace_ops;
	struct perf_cgroup___57 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct irq_data___80;

struct x86_io_apic_ops___80 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___80 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___80;

struct irq_data___80 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___80 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___87;

struct dev_pm_ops___87 {
	int (*prepare)(struct device___87 *);
	void (*complete)(struct device___87 *);
	int (*suspend)(struct device___87 *);
	int (*resume)(struct device___87 *);
	int (*freeze)(struct device___87 *);
	int (*thaw)(struct device___87 *);
	int (*poweroff)(struct device___87 *);
	int (*restore)(struct device___87 *);
	int (*suspend_late)(struct device___87 *);
	int (*resume_early)(struct device___87 *);
	int (*freeze_late)(struct device___87 *);
	int (*thaw_early)(struct device___87 *);
	int (*poweroff_late)(struct device___87 *);
	int (*restore_early)(struct device___87 *);
	int (*suspend_noirq)(struct device___87 *);
	int (*resume_noirq)(struct device___87 *);
	int (*freeze_noirq)(struct device___87 *);
	int (*thaw_noirq)(struct device___87 *);
	int (*poweroff_noirq)(struct device___87 *);
	int (*restore_noirq)(struct device___87 *);
	int (*runtime_suspend)(struct device___87 *);
	int (*runtime_resume)(struct device___87 *);
	int (*runtime_idle)(struct device___87 *);
};

struct device_type___87;

struct bus_type___87;

struct device_driver___87;

struct dev_pm_domain___87;

struct class___87;

struct attribute_group___80;

struct device_rh___87;

struct device___87 {
	struct device___87 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___87 *type;
	struct mutex___110 mutex;
	struct bus_type___87 *bus;
	struct device_driver___87 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___87 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___87 *class;
	const struct attribute_group___80 **groups;
	void (*release)(struct device___87 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___87 *device_rh;
};

struct dev_pm_info_rh___87 {
	void (*set_latency_tolerance)(struct device___87 *, s32);
};

struct dev_pm_domain___87 {
	struct dev_pm_ops___87 ops;
};

struct smp_ops___108 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___109 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___108;

struct lruvec___108 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___108 *zone;
};

struct pglist_data___108;

struct zone___108 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___108 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___108 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___108 {
	struct zone___108 *zone;
	int zone_idx;
};

struct zonelist___108 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___108 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___108 {
	struct zone___108 node_zones[4];
	struct zonelist___108 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___109 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inode___108;

struct dentry_operations___108;

struct super_block___108;

struct dentry___108 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___108 *d_parent;
	struct qstr d_name;
	struct inode___108 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___108 *d_op;
	struct super_block___108 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___108;

struct address_space___108 {
	struct inode___108 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___110 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___108 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___20 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___108;

struct file_operations___108;

struct file_lock___108;

struct dquot___108;

struct block_device___108;

struct inode___108 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___108 *i_op;
	struct super_block___108 *i_sb;
	struct address_space___108 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___110 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___108 *i_fop;
	struct file_lock___108 *i_flock;
	struct address_space___108 i_data;
	struct dquot___108 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___108 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___108;

struct dentry_operations___108 {
	int (*d_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_hash)(const struct dentry___108 *, struct qstr *);
	int (*d_compare)(const struct dentry___108 *, const struct dentry___108 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___108 *);
	void (*d_release)(struct dentry___108 *);
	void (*d_prune)(struct dentry___108 *);
	void (*d_iput)(struct dentry___108 *, struct inode___108 *);
	char * (*d_dname)(struct dentry___108 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___108 *);
	int (*d_manage)(struct dentry___108 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___108;

struct mem_dqinfo___108 {
	struct quota_format_type___108 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___108;

struct quota_info___108 {
	unsigned int flags;
	struct mutex___110 dqio_mutex;
	struct mutex___110 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___108 *files[2];
	struct mem_dqinfo___108 info[2];
	const struct quota_format_ops___108 *ops[2];
};

struct file_system_type___108;

struct super_operations___108;

struct dquot_operations___108;

struct quotactl_ops___108;

struct xattr_handler___73;

struct super_block___108 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___108 *s_type;
	const struct super_operations___108 *s_op;
	const struct dquot_operations___108 *dq_op;
	const struct quotactl_ops___108 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___108 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___73 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___108 *s_bdev;
	struct backing_dev_info___20 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___108 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___110 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___108 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___108 {
	struct vfsmount *mnt;
	struct dentry___108 *dentry;
};

struct upid___62 {
	int nr;
	struct pid_namespace___62 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___62 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___109 *child_reaper;
	struct kmem_cache___95 *pid_cachep;
	unsigned int level;
	struct pid_namespace___62 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___108 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___62 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___62 numbers[1];
};

struct block_device___108 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___108 *bd_inode;
	struct super_block___108 *bd_super;
	struct mutex___110 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___108 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___110 bd_fsfreeze_mutex;
};

struct cgroup___74;

struct cgroup_subsys_state___75 {
	struct cgroup___74 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___108 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___108 *ia_file;
};

struct fown_struct___62 {
	rwlock_t lock;
	struct pid___62 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___108 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___108 f_path;
	struct inode___108 *f_inode;
	const struct file_operations___108 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___62 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___108 *f_mapping;
	struct mutex___110 f_pos_lock;
};

struct dquot___108 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___110 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___108 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___108 {
	int qf_fmt_id;
	const struct quota_format_ops___108 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___108 *qf_next;
};

struct quota_format_ops___108 {
	int (*check_quota_file)(struct super_block___108 *, int);
	int (*read_file_info)(struct super_block___108 *, int);
	int (*write_file_info)(struct super_block___108 *, int);
	int (*free_file_info)(struct super_block___108 *, int);
	int (*read_dqblk)(struct dquot___108 *);
	int (*commit_dqblk)(struct dquot___108 *);
	int (*release_dqblk)(struct dquot___108 *);
};

struct dquot_operations___108 {
	int (*write_dquot)(struct dquot___108 *);
	struct dquot___108 * (*alloc_dquot)(struct super_block___108 *, int);
	void (*destroy_dquot)(struct dquot___108 *);
	int (*acquire_dquot)(struct dquot___108 *);
	int (*release_dquot)(struct dquot___108 *);
	int (*mark_dirty)(struct dquot___108 *);
	int (*write_info)(struct super_block___108 *, int);
	qsize_t * (*get_reserved_space)(struct inode___108 *);
};

struct quotactl_ops___108 {
	int (*quota_on)(struct super_block___108 *, int, int, struct path___108 *);
	int (*quota_on_meta)(struct super_block___108 *, int, int);
	int (*quota_off)(struct super_block___108 *, int);
	int (*quota_sync)(struct super_block___108 *, int);
	int (*get_info)(struct super_block___108 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___108 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___108 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___108 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___108 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___108 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___108 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___108 *, unsigned int);
};

struct swap_info_struct___23;

struct address_space_operations___108 {
	int (*writepage)(struct page___108 *, struct writeback_control *);
	int (*readpage)(struct file___108 *, struct page___108 *);
	int (*writepages)(struct address_space___108 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___108 *);
	int (*readpages)(struct file___108 *, struct address_space___108 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___108 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___108 **, void **);
	int (*write_end)(struct file___108 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___108 *, void *);
	sector_t (*bmap)(struct address_space___108 *, sector_t);
	void (*invalidatepage)(struct page___108 *, long unsigned int);
	int (*releasepage)(struct page___108 *, gfp_t);
	void (*freepage)(struct page___108 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___108 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___108 *, struct page___108 *, struct page___108 *, enum migrate_mode);
	int (*launder_page)(struct page___108 *);
	int (*is_partially_uptodate)(struct page___108 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___108 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___108 *, struct page___108 *);
	int (*swap_activate)(struct swap_info_struct___23 *, struct file___108 *, sector_t *);
	void (*swap_deactivate)(struct file___108 *);
	void (*invalidatepage_range)(struct page___108 *, unsigned int, unsigned int);
};

struct swap_info_struct___23 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___108 *bdev;
	struct file___108 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___20 {
	struct backing_dev_info___20 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___20 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___20 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___87 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___108 *debug_dir;
	struct dentry___108 *debug_stats;
};

struct inode_operations___108 {
	struct dentry___108 * (*lookup)(struct inode___108 *, struct dentry___108 *, unsigned int);
	void * (*follow_link)(struct dentry___108 *, struct nameidata *);
	int (*permission)(struct inode___108 *, int);
	struct posix_acl * (*get_acl)(struct inode___108 *, int);
	int (*readlink)(struct dentry___108 *, char *, int);
	void (*put_link)(struct dentry___108 *, struct nameidata *, void *);
	int (*create)(struct inode___108 *, struct dentry___108 *, umode_t, bool);
	int (*link)(struct dentry___108 *, struct inode___108 *, struct dentry___108 *);
	int (*unlink)(struct inode___108 *, struct dentry___108 *);
	int (*symlink)(struct inode___108 *, struct dentry___108 *, const char *);
	int (*mkdir)(struct inode___108 *, struct dentry___108 *, umode_t);
	int (*rmdir)(struct inode___108 *, struct dentry___108 *);
	int (*mknod)(struct inode___108 *, struct dentry___108 *, umode_t, dev_t);
	int (*rename)(struct inode___108 *, struct dentry___108 *, struct inode___108 *, struct dentry___108 *);
	int (*setattr)(struct dentry___108 *, struct iattr___108 *);
	int (*getattr)(struct vfsmount *, struct dentry___108 *, struct kstat *);
	int (*setxattr)(struct dentry___108 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___108 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___108 *, char *, size_t);
	int (*removexattr)(struct dentry___108 *, const char *);
	int (*fiemap)(struct inode___108 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___108 *, struct timespec *, int);
	int (*atomic_open)(struct inode___108 *, struct dentry___108 *, struct file___108 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___69;

struct seq_file___82;

struct file_operations___108 {
	struct module *owner;
	loff_t (*llseek)(struct file___108 *, loff_t, int);
	ssize_t (*read)(struct file___108 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___108 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___108 *, void *, filldir_t);
	unsigned int (*poll)(struct file___108 *, struct poll_table_struct___69 *);
	long int (*unlocked_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___108 *, struct vm_area_struct___113 *);
	int (*open)(struct inode___108 *, struct file___108 *);
	int (*flush)(struct file___108 *, fl_owner_t);
	int (*release)(struct inode___108 *, struct file___108 *);
	int (*fsync)(struct file___108 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___108 *, int);
	int (*lock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*sendpage)(struct file___108 *, struct page___108 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___108 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___108 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___108 *, long int, struct file_lock___108 **, void **);
		struct {
			int (*setlease)(struct file___108 *, long int, struct file_lock___108 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___108 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___82 *, struct file___108 *);
};

struct file_lock_operations___108;

struct lock_manager_operations___108;

struct file_lock___108 {
	struct file_lock___108 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___62 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___108 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___108 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___108 *fl_ops;
	const struct lock_manager_operations___108 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___108 {
	void (*fl_copy_lock)(struct file_lock___108 *, struct file_lock___108 *);
	void (*fl_release_private)(struct file_lock___108 *);
};

struct lock_manager_operations___108 {
	int (*lm_compare_owner)(struct file_lock___108 *, struct file_lock___108 *);
	long unsigned int (*lm_owner_key)(struct file_lock___108 *);
	void (*lm_notify)(struct file_lock___108 *);
	int (*lm_grant)(struct file_lock___108 *, struct file_lock___108 *, int);
	void (*lm_break)(struct file_lock___108 *);
	int (*lm_change)(struct file_lock___108 **, int);
};

struct fasync_struct___108 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___108 *fa_next;
	struct file___108 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___108 {
	const char *name;
	int fs_flags;
	struct dentry___108 * (*mount)(struct file_system_type___108 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___108 *);
	struct module *owner;
	struct file_system_type___108 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___108 {
	struct inode___108 * (*alloc_inode)(struct super_block___108 *);
	void (*destroy_inode)(struct inode___108 *);
	void (*dirty_inode)(struct inode___108 *, int);
	int (*write_inode)(struct inode___108 *, struct writeback_control *);
	int (*drop_inode)(struct inode___108 *);
	void (*evict_inode)(struct inode___108 *);
	void (*put_super)(struct super_block___108 *);
	int (*sync_fs)(struct super_block___108 *, int);
	int (*freeze_fs)(struct super_block___108 *);
	int (*unfreeze_fs)(struct super_block___108 *);
	int (*statfs)(struct dentry___108 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___108 *, int *, char *);
	void (*umount_begin)(struct super_block___108 *);
	int (*show_options)(struct seq_file___82 *, struct dentry___108 *);
	int (*show_devname)(struct seq_file___82 *, struct dentry___108 *);
	int (*show_path)(struct seq_file___82 *, struct dentry___108 *);
	int (*show_stats)(struct seq_file___82 *, struct dentry___108 *);
	ssize_t (*quota_read)(struct super_block___108 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___108 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___108 *);
	int (*bdev_try_to_free_page)(struct super_block___108 *, struct page___108 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___108 *);
	void (*free_cached_objects)(struct super_block___108 *, int);
};

struct xattr_handler___73 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___108 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___108 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___108 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___71)(struct file___108 *, wait_queue_head_t *, struct poll_table_struct___69 *);

struct poll_table_struct___69 {
	poll_queue_proc___71 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___96;

struct vm_area_struct___113 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___113 *vm_next;
	struct vm_area_struct___113 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___113 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___96 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___108 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___81;

struct seq_file___82 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___110 lock;
	const struct seq_operations___81 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___108 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___108 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___95;

struct memcg_cache_params___95;

struct kmem_cache___95 {
	struct kmem_cache_cpu___95 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___95 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___93;

struct vm_operations_struct___96 {
	void (*open)(struct vm_area_struct___113 *);
	void (*close)(struct vm_area_struct___113 *);
	int (*fault)(struct vm_area_struct___113 *, struct vm_fault___93 *);
	int (*page_mkwrite)(struct vm_area_struct___113 *, struct vm_fault___93 *);
	int (*access)(struct vm_area_struct___113 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___113 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___113 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___113 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___113 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___108 {
	struct task_struct___109 *task;
	struct core_thread___108 *next;
};

struct core_state___108 {
	atomic_t nr_threads;
	struct core_thread___108 dumper;
	struct completion startup;
};

struct nsproxy___63 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___62 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___108 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___109 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___109 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___62 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___62 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___110 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___73 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___75 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___57 {
	struct pmu___57 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___110 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___109 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___57 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___93 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___108 *page;
};

struct bin_attribute___80;

struct attribute_group___80 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___80 **bin_attrs;
};

struct bin_attribute___80 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___108 *, struct kobject *, struct bin_attribute___80 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___108 *, struct kobject *, struct bin_attribute___80 *, char *, loff_t, size_t);
	int (*mmap)(struct file___108 *, struct kobject *, struct bin_attribute___80 *, struct vm_area_struct___113 *);
};

struct kmem_cache_cpu___95 {
	void **freelist;
	long unsigned int tid;
	struct page___108 *page;
	struct page___108 *partial;
};

struct memcg_cache_params___95 {
	bool is_root_cache;
	union {
		struct kmem_cache___95 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___95 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___73;

struct cgroup___74 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___74 *parent;
	struct dentry___108 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___75 *subsys[11];
	struct cgroupfs_root___73 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___110 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___73 {
	struct super_block___108 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___74 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___32 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___108 *, struct file___108 *);
	ssize_t (*read)(struct cgroup___74 *, struct cftype___32 *, struct file___108 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___74 *, struct cftype___32 *);
	s64 (*read_s64)(struct cgroup___74 *, struct cftype___32 *);
	int (*read_map)(struct cgroup___74 *, struct cftype___32 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___74 *, struct cftype___32 *, struct seq_file___82 *);
	ssize_t (*write)(struct cgroup___74 *, struct cftype___32 *, struct file___108 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___74 *, struct cftype___32 *, u64);
	int (*write_s64)(struct cgroup___74 *, struct cftype___32 *, s64);
	int (*write_string)(struct cgroup___74 *, struct cftype___32 *, const char *);
	int (*trigger)(struct cgroup___74 *, unsigned int);
	int (*release)(struct inode___108 *, struct file___108 *);
	int (*register_event)(struct cgroup___74 *, struct cftype___32 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___74 *, struct cftype___32 *, struct eventfd_ctx *);
};

struct cftype_set___30 {
	struct list_head node;
	struct cftype___32 *cfts;
};

struct task_and_cgroup___30 {
	struct task_struct___109 *task;
	struct cgroup___74 *cgrp;
	struct css_set___73 *cg;
};

struct cgroup_taskset___30 {
	struct task_and_cgroup___30 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___74 *cur_cgrp;
};

struct cgroup_subsys___30 {
	struct cgroup_subsys_state___75 * (*css_alloc)(struct cgroup___74 *);
	int (*css_online)(struct cgroup___74 *);
	void (*css_offline)(struct cgroup___74 *);
	void (*css_free)(struct cgroup___74 *);
	int (*can_attach)(struct cgroup___74 *, struct cgroup_taskset___30 *);
	void (*cancel_attach)(struct cgroup___74 *, struct cgroup_taskset___30 *);
	void (*attach)(struct cgroup___74 *, struct cgroup_taskset___30 *);
	void (*fork)(struct task_struct___109 *);
	void (*exit)(struct cgroup___74 *, struct cgroup___74 *, struct task_struct___109 *);
	void (*bind)(struct cgroup___74 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___73 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___32 *base_cftypes;
	struct cftype_set___30 base_cftset;
	struct module *module;
};

struct irq_chip___80 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___80 *);
	void (*irq_shutdown)(struct irq_data___80 *);
	void (*irq_enable)(struct irq_data___80 *);
	void (*irq_disable)(struct irq_data___80 *);
	void (*irq_ack)(struct irq_data___80 *);
	void (*irq_mask)(struct irq_data___80 *);
	void (*irq_mask_ack)(struct irq_data___80 *);
	void (*irq_unmask)(struct irq_data___80 *);
	void (*irq_eoi)(struct irq_data___80 *);
	int (*irq_set_affinity)(struct irq_data___80 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___80 *);
	int (*irq_set_type)(struct irq_data___80 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___80 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___80 *);
	void (*irq_bus_sync_unlock)(struct irq_data___80 *);
	void (*irq_cpu_online)(struct irq_data___80 *);
	void (*irq_cpu_offline)(struct irq_data___80 *);
	void (*irq_suspend)(struct irq_data___80 *);
	void (*irq_resume)(struct irq_data___80 *);
	void (*irq_pm_shutdown)(struct irq_data___80 *);
	void (*irq_print_chip)(struct irq_data___80 *, struct seq_file___82 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___80 *, void *);
	long unsigned int flags;
};

struct bus_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___87 *, char *);
	ssize_t (*store)(struct bus_type___87 *, const char *, size_t);
};

struct device_attribute___87;

struct driver_attribute___87;

struct bus_type___87 {
	const char *name;
	const char *dev_name;
	struct device___87 *dev_root;
	struct bus_attribute___87 *bus_attrs;
	struct device_attribute___87 *dev_attrs;
	struct driver_attribute___87 *drv_attrs;
	const struct attribute_group___80 **bus_groups;
	const struct attribute_group___80 **dev_groups;
	const struct attribute_group___80 **drv_groups;
	int (*match)(struct device___87 *, struct device_driver___87 *);
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	int (*probe)(struct device___87 *);
	int (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*online)(struct device___87 *);
	int (*offline)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct device___87 *, struct device_attribute___87 *, char *);
	ssize_t (*store)(struct device___87 *, struct device_attribute___87 *, const char *, size_t);
};

struct driver_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___87 *, char *);
	ssize_t (*store)(struct device_driver___87 *, const char *, size_t);
};

struct device_driver___87 {
	const char *name;
	struct bus_type___87 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___87 *);
	int (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	const struct attribute_group___80 **groups;
	const struct dev_pm_ops___87 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___87 {
	const char *name;
	const struct attribute_group___80 **groups;
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
};

struct class_attribute___87;

struct class___87 {
	const char *name;
	struct module *owner;
	struct class_attribute___87 *class_attrs;
	struct device_attribute___87 *dev_attrs;
	const struct attribute_group___80 **dev_groups;
	struct bin_attribute___80 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *);
	void (*class_release)(struct class___87 *);
	void (*dev_release)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
	struct subsys_private *p;
};

struct class_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct class___87 *, struct class_attribute___87 *, char *);
	ssize_t (*store)(struct class___87 *, struct class_attribute___87 *, const char *, size_t);
	const void * (*namespace)(struct class___87 *, const struct class_attribute___87 *);
};

struct device_rh___87 {
	struct dev_pm_info_rh___87 power;
};

struct seq_operations___81 {
	void * (*start)(struct seq_file___82 *, loff_t *);
	void (*stop)(struct seq_file___82 *, void *);
	void * (*next)(struct seq_file___82 *, void *, loff_t *);
	int (*show)(struct seq_file___82 *, void *);
};

struct perf_cpu_context___57;

struct pmu___57 {
	struct list_head entry;
	struct device___87 *dev;
	const struct attribute_group___80 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___57 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___57 *);
	void (*pmu_disable)(struct pmu___57 *);
	int (*event_init)(struct perf_event___57 *);
	int (*add)(struct perf_event___57 *, int);
	void (*del)(struct perf_event___57 *, int);
	void (*start)(struct perf_event___57 *, int);
	void (*stop)(struct perf_event___57 *, int);
	void (*read)(struct perf_event___57 *);
	void (*start_txn)(struct pmu___57 *);
	int (*commit_txn)(struct pmu___57 *);
	void (*cancel_txn)(struct pmu___57 *);
	int (*event_idx)(struct perf_event___57 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___57 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___57 *);
};

struct perf_cpu_context___57 {
	struct perf_event_context___57 ctx;
	struct perf_event_context___57 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___57 *unique_pmu;
	struct perf_cgroup___57 *cgrp;
};

struct trace_event_functions___47;

struct trace_event___47 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___47 *funcs;
};

struct ftrace_event_class___47;

struct ftrace_event_call___47 {
	struct list_head list;
	struct ftrace_event_class___47 *class;
	char *name;
	struct trace_event___47 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___57 {
	struct cgroup_subsys_state___75 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___47 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___110 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___47)(struct trace_iterator___47 *, int, struct trace_event___47 *);

struct trace_event_functions___47 {
	trace_print_func___47 trace;
	trace_print_func___47 raw;
	trace_print_func___47 hex;
	trace_print_func___47 binary;
};

struct ftrace_event_class___47 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___47 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___47 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___47 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___47 *);
};

struct syscall_metadata___17 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___47 *enter_event;
	struct ftrace_event_call___47 *exit_event;
};

struct tlb_state___28 {
	struct mm_struct___113 *active_mm;
	int state;
};

struct zap_details___2 {
	struct vm_area_struct___54 *nonlinear_vma;
	struct address_space___50 *check_mapping;
	long unsigned int first_index;
	long unsigned int last_index;
};

struct mm_walk {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk *);
	struct mm_struct___54 *mm;
	void *private;
};

enum transparent_hugepage_flag {
	TRANSPARENT_HUGEPAGE_FLAG = 0,
	TRANSPARENT_HUGEPAGE_REQ_MADV_FLAG = 1,
	TRANSPARENT_HUGEPAGE_DEFRAG_FLAG = 2,
	TRANSPARENT_HUGEPAGE_DEFRAG_REQ_MADV_FLAG = 3,
	TRANSPARENT_HUGEPAGE_DEFRAG_KHUGEPAGED_FLAG = 4,
	TRANSPARENT_HUGEPAGE_USE_ZERO_PAGE_FLAG = 5,
};

struct zap_details___3 {
	struct vm_area_struct___60 *nonlinear_vma;
	struct address_space___56 *check_mapping;
	long unsigned int first_index;
	long unsigned int last_index;
};

typedef int (*pte_fn_t___2)(pte_t *, pgtable_t___56, long unsigned int, void *);

struct tlb_state___29 {
	struct mm_struct___60 *active_mm;
	int state;
};

struct hstate___8 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___10 cgroup_files[5];
	char name[32];
};

struct mmu_gather_batch___2 {
	struct mmu_gather_batch___2 *next;
	unsigned int nr;
	unsigned int max;
	struct page___56 *pages[0];
};

struct mmu_gather___2 {
	struct mm_struct___60 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___2 *active;
	struct mmu_gather_batch___2 local;
	struct page___56 *__pages[8];
	unsigned int batch_count;
};

struct hugetlbfs_sb_info___2 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___3 *hstate;
	struct hugepage_subpool *spool;
};

struct tlb_state___30 {
	struct mm_struct___110 *active_mm;
	int state;
};

enum {
	HUGETLB_SHMFS_INODE = 1,
	HUGETLB_ANONHUGE_INODE = 2,
};

struct hstate___9;

struct hugetlbfs_sb_info___3 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___9 *hstate;
	struct hugepage_subpool *spool;
};

struct hstate___9 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___29 cgroup_files[5];
	char name[32];
};

struct anon_vma_chain___2 {
	struct vm_area_struct___110 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct mmu_gather_batch___3 {
	struct mmu_gather_batch___3 *next;
	unsigned int nr;
	unsigned int max;
	struct page___105 *pages[0];
};

struct mmu_gather___3 {
	struct mm_struct___110 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___3 *active;
	struct mmu_gather_batch___3 local;
	struct page___105 *__pages[8];
	unsigned int batch_count;
};

struct file_operations_extend {
	struct file_operations___50 kabi_fops;
	void (*mremap)(struct file___50 *, struct vm_area_struct___54 *);
};

enum page_check_address_pmd_flag {
	PAGE_CHECK_ADDRESS_PMD_FLAG = 0,
	PAGE_CHECK_ADDRESS_PMD_NOTSPLITTING_FLAG = 1,
	PAGE_CHECK_ADDRESS_PMD_SPLITTING_FLAG = 2,
};

enum mem_cgroup_page_stat_item {
	MEMCG_NR_FILE_MAPPED = 0,
};

struct anon_vma_chain___3 {
	struct vm_area_struct___54 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct vm_struct___3 {
	struct vm_struct___3 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___50 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct vmap_area {
	long unsigned int va_start;
	long unsigned int va_end;
	long unsigned int flags;
	struct rb_node rb_node;
	struct list_head list;
	struct list_head purge_list;
	struct vm_struct___3 *vm;
	struct callback_head callback_head;
};

struct vmalloc_info {
	long unsigned int used;
	long unsigned int largest_chunk;
};

typedef int (*pte_fn_t___3)(pte_t *, pgtable_t___50, long unsigned int, void *);

struct vfree_deferred {
	struct llist_head list;
	struct work_struct wq;
};

struct vmap_block_queue {
	spinlock_t lock;
	struct list_head free;
};

struct vmap_block {
	spinlock_t lock;
	struct vmap_area *va;
	struct vmap_block_queue *vbq;
	long unsigned int free;
	long unsigned int dirty;
	long unsigned int alloc_map[4];
	long unsigned int dirty_map[4];
	struct list_head free_list;
	struct callback_head callback_head;
	struct list_head purge;
};

typedef struct pglist_data___108 pg_data_t___9;

struct rchan___3;

struct blk_trace {
	int trace_state;
	struct rchan___3 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___103 *dir;
	struct dentry___103 *dropped_file;
	struct dentry___103 *msg_file;
	atomic_t dropped;
};

struct rchan_buf___3 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___3 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___103 *dentry;
	struct kref kref;
	struct page___103 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___3;

struct rchan___3 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___3 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___3 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___103 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___3 {
	int (*subbuf_start)(struct rchan_buf___3 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___3 *, struct file___103 *);
	void (*buf_unmapped)(struct rchan_buf___3 *, struct file___103 *);
	struct dentry___103 * (*create_buf_file)(const char *, struct dentry___103 *, umode_t, struct rchan_buf___3 *, int *);
	int (*remove_buf_file)(struct dentry___103 *);
};

enum {
	SWP_USED = 1,
	SWP_WRITEOK = 2,
	SWP_DISCARDABLE = 4,
	SWP_DISCARDING = 8,
	SWP_SOLIDSTATE = 16,
	SWP_CONTINUED = 32,
	SWP_BLKDEV = 64,
	SWP_FILE = 128,
	SWP_AREA_DISCARD = 256,
	SWP_PAGE_DISCARD = 512,
	SWP_SCANNING = 1024,
};

struct page___109;

typedef struct page___109 *pgtable_t___109;

struct address_space___109;

struct kmem_cache___96;

struct page___109 {
	long unsigned int flags;
	struct address_space___109 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___109 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___109 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___96 *slab_cache;
		struct page___109 *first_page;
	};
	long: 64;
};

struct thread_struct___58;

struct task_struct___110;

struct pv_cpu_ops___109 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___58 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___58 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___110 *);
	void (*end_context_switch)(struct task_struct___110 *);
};

struct perf_event___58;

struct thread_struct___58 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___58 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___63;

struct pid_link___63 {
	struct hlist_node node;
	struct pid___63 *pid;
};

struct mutex___111 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___110 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___105 {
	struct page___109 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___114;

struct nsproxy___64;

struct signal_struct___109;

struct bio_list___14;

struct backing_dev_info___21;

struct io_context___14;

struct css_set___74;

struct perf_event_context___58;

struct task_struct___110 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___110 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___114 *mm;
	struct mm_struct___114 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___110 *real_parent;
	struct task_struct___110 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___110 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___63 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___109 = 0,
		VTIME_USER___109 = 1,
		VTIME_SYS___109 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___58 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___64 *nsproxy;
	struct signal_struct___109 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___14 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___21 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___74 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___58 *perf_event_ctxp[2];
	struct mutex___111 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___105 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___114 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___114 *, struct mm_struct___114 *);
	void (*dup_mmap)(struct mm_struct___114 *, struct mm_struct___114 *);
	void (*exit_mmap)(struct mm_struct___114 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___114 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___114 *);
	void (*pgd_free)(struct mm_struct___114 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___114 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___114 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___114 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___114 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___114 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___114 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___114 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___114 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___114 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___114 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___114 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___111 lock;
	void *vdso;
} mm_context_t___110;

struct xol_area___109;

struct uprobes_state___109 {
	struct xol_area___109 *xol_area;
};

struct vm_area_struct___114;

struct file___109;

struct core_state___109;

struct mm_struct___114 {
	struct vm_area_struct___114 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___114 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___114 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___110 context;
	long unsigned int flags;
	struct core_state___109 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___110 *owner;
	struct file___109 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___109 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___58 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___110 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___110 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___110 *target;
};

typedef void (*perf_overflow_handler_t___58)(struct perf_event___58 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___58;

typedef void (*ftrace_func_t___58)(long unsigned int, long unsigned int, struct ftrace_ops___58 *, struct pt_regs *);

struct ftrace_ops___58 {
	ftrace_func_t___58 func;
	struct ftrace_ops___58 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___111 regex_lock;
};

struct pmu___58;

struct fasync_struct___109;

struct pid_namespace___63;

struct ftrace_event_call___48;

struct perf_cgroup___58;

struct perf_event___58 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___58 *group_leader;
	struct pmu___58 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___58 hw;
	struct perf_event_context___58 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___111 child_mutex;
	struct list_head child_list;
	struct perf_event___58 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___110 *owner;
	struct mutex___111 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___109 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___58 *);
	struct callback_head callback_head;
	struct pid_namespace___63 *ns;
	u64 id;
	perf_overflow_handler_t___58 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___48 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___58 ftrace_ops;
	struct perf_cgroup___58 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___56 {
	struct task_struct___110 *task;
	struct exec_domain___28 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___109;

struct lruvec___109 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___109 *zone;
};

struct pglist_data___109;

struct zone___109 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___109 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___109 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___109 {
	struct zone___109 *zone;
	int zone_idx;
};

struct zonelist___109 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___109 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___109 {
	struct zone___109 node_zones[4];
	struct zonelist___109 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___110 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___81;

struct x86_io_apic_ops___81 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___81 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___81;

struct irq_data___81 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___81 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___88;

struct dev_pm_ops___88 {
	int (*prepare)(struct device___88 *);
	void (*complete)(struct device___88 *);
	int (*suspend)(struct device___88 *);
	int (*resume)(struct device___88 *);
	int (*freeze)(struct device___88 *);
	int (*thaw)(struct device___88 *);
	int (*poweroff)(struct device___88 *);
	int (*restore)(struct device___88 *);
	int (*suspend_late)(struct device___88 *);
	int (*resume_early)(struct device___88 *);
	int (*freeze_late)(struct device___88 *);
	int (*thaw_early)(struct device___88 *);
	int (*poweroff_late)(struct device___88 *);
	int (*restore_early)(struct device___88 *);
	int (*suspend_noirq)(struct device___88 *);
	int (*resume_noirq)(struct device___88 *);
	int (*freeze_noirq)(struct device___88 *);
	int (*thaw_noirq)(struct device___88 *);
	int (*poweroff_noirq)(struct device___88 *);
	int (*restore_noirq)(struct device___88 *);
	int (*runtime_suspend)(struct device___88 *);
	int (*runtime_resume)(struct device___88 *);
	int (*runtime_idle)(struct device___88 *);
};

struct device_type___88;

struct bus_type___88;

struct device_driver___88;

struct dev_pm_domain___88;

struct class___88;

struct attribute_group___81;

struct device_rh___88;

struct device___88 {
	struct device___88 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___88 *type;
	struct mutex___111 mutex;
	struct bus_type___88 *bus;
	struct device_driver___88 *driver;
	void *platform_data;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___88 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___31 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___88 *class;
	const struct attribute_group___81 **groups;
	void (*release)(struct device___88 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___88 *device_rh;
};

struct dev_pm_info_rh___88 {
	void (*set_latency_tolerance)(struct device___88 *, s32);
};

struct dev_pm_domain___88 {
	struct dev_pm_ops___88 ops;
};

struct smp_ops___109 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___110 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___109 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___109 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___96;

struct memcg_cache_params___96;

struct kmem_cache___96 {
	struct kmem_cache_cpu___96 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___96 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___109;

struct address_space_operations___109;

struct address_space___109 {
	struct inode___109 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___111 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___109 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___21 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___109;

struct path___109 {
	struct vfsmount *mnt;
	struct dentry___109 *dentry;
};

struct fown_struct___63 {
	rwlock_t lock;
	struct pid___63 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___109;

struct file___109 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___109 f_path;
	struct inode___109 *f_inode;
	const struct file_operations___109 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___109 *f_mapping;
	struct mutex___111 f_pos_lock;
};

struct vm_operations_struct___97;

struct vm_area_struct___114 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___114 *vm_next;
	struct vm_area_struct___114 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___114 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___97 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___109 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___94;

struct vm_operations_struct___97 {
	void (*open)(struct vm_area_struct___114 *);
	void (*close)(struct vm_area_struct___114 *);
	int (*fault)(struct vm_area_struct___114 *, struct vm_fault___94 *);
	int (*page_mkwrite)(struct vm_area_struct___114 *, struct vm_fault___94 *);
	int (*access)(struct vm_area_struct___114 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___114 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___114 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___114 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___114 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___109 {
	struct task_struct___110 *task;
	struct core_thread___109 *next;
};

struct core_state___109 {
	atomic_t nr_threads;
	struct core_thread___109 dumper;
	struct completion startup;
};

struct vm_fault___94 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___109 *page;
};

struct dentry_operations___109;

struct super_block___109;

struct dentry___109 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___109 *d_parent;
	struct qstr d_name;
	struct inode___109 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___109 *d_op;
	struct super_block___109 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___109;

struct file_lock___109;

struct dquot___109;

struct block_device___109;

struct inode___109 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___109 *i_op;
	struct super_block___109 *i_sb;
	struct address_space___109 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___111 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___109 *i_fop;
	struct file_lock___109 *i_flock;
	struct address_space___109 i_data;
	struct dquot___109 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___109 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___109 {
	int (*d_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_hash)(const struct dentry___109 *, struct qstr *);
	int (*d_compare)(const struct dentry___109 *, const struct dentry___109 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___109 *);
	void (*d_release)(struct dentry___109 *);
	void (*d_prune)(struct dentry___109 *);
	void (*d_iput)(struct dentry___109 *, struct inode___109 *);
	char * (*d_dname)(struct dentry___109 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___109 *);
	int (*d_manage)(struct dentry___109 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___109;

struct mem_dqinfo___109 {
	struct quota_format_type___109 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___109;

struct quota_info___109 {
	unsigned int flags;
	struct mutex___111 dqio_mutex;
	struct mutex___111 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___109 *files[2];
	struct mem_dqinfo___109 info[2];
	const struct quota_format_ops___109 *ops[2];
};

struct file_system_type___109;

struct super_operations___109;

struct dquot_operations___109;

struct quotactl_ops___109;

struct xattr_handler___74;

struct super_block___109 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___109 *s_type;
	const struct super_operations___109 *s_op;
	const struct dquot_operations___109 *dq_op;
	const struct quotactl_ops___109 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___109 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___74 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___109 *s_bdev;
	struct backing_dev_info___21 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___109 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___111 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___109 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___63 {
	int nr;
	struct pid_namespace___63 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___63 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___110 *child_reaper;
	struct kmem_cache___96 *pid_cachep;
	unsigned int level;
	struct pid_namespace___63 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___109 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___63 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___63 numbers[1];
};

struct bio___14;

typedef void bio_end_io_t___14(struct bio___14 *, int);

struct bio_vec___14 {
	struct page___109 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___76;

struct bio_integrity_payload___14;

struct bio_set___14;

struct bio___14 {
	sector_t bi_sector;
	struct bio___14 *bi_next;
	struct block_device___109 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___14 *bi_end_io;
	void *bi_private;
	struct io_context___14 *bi_ioc;
	struct cgroup_subsys_state___76 *bi_css;
	struct bio_integrity_payload___14 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___14 *bi_io_vec;
	struct bio_set___14 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___14 bi_inline_vecs[0];
};

struct hd_struct___15;

struct gendisk___15;

struct request_queue___14;

struct block_device___109 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___109 *bd_inode;
	struct super_block___109 *bd_super;
	struct mutex___111 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___109 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___15 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___15 *bd_disk;
	struct request_queue___14 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___111 bd_fsfreeze_mutex;
};

struct io_cq___14;

struct io_context___14 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___14 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___75;

struct cgroup_subsys_state___76 {
	struct cgroup___75 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___14 {
	struct bio___14 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___14 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___14 *bip_vec;
	struct bio_vec___14 bip_inline_vecs[0];
};

struct bio_list___14 {
	struct bio___14 *head;
	struct bio___14 *tail;
};

struct bio_set___14 {
	struct kmem_cache___96 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___14 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___109 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___109 *ia_file;
};

struct dquot___109 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___111 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___109 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___109 {
	int qf_fmt_id;
	const struct quota_format_ops___109 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___109 *qf_next;
};

struct quota_format_ops___109 {
	int (*check_quota_file)(struct super_block___109 *, int);
	int (*read_file_info)(struct super_block___109 *, int);
	int (*write_file_info)(struct super_block___109 *, int);
	int (*free_file_info)(struct super_block___109 *, int);
	int (*read_dqblk)(struct dquot___109 *);
	int (*commit_dqblk)(struct dquot___109 *);
	int (*release_dqblk)(struct dquot___109 *);
};

struct dquot_operations___109 {
	int (*write_dquot)(struct dquot___109 *);
	struct dquot___109 * (*alloc_dquot)(struct super_block___109 *, int);
	void (*destroy_dquot)(struct dquot___109 *);
	int (*acquire_dquot)(struct dquot___109 *);
	int (*release_dquot)(struct dquot___109 *);
	int (*mark_dirty)(struct dquot___109 *);
	int (*write_info)(struct super_block___109 *, int);
	qsize_t * (*get_reserved_space)(struct inode___109 *);
};

struct quotactl_ops___109 {
	int (*quota_on)(struct super_block___109 *, int, int, struct path___109 *);
	int (*quota_on_meta)(struct super_block___109 *, int, int);
	int (*quota_off)(struct super_block___109 *, int);
	int (*quota_sync)(struct super_block___109 *, int);
	int (*get_info)(struct super_block___109 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___109 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___109 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___109 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___109 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___109 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___109 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___109 *, unsigned int);
};

struct swap_info_struct___24;

struct address_space_operations___109 {
	int (*writepage)(struct page___109 *, struct writeback_control *);
	int (*readpage)(struct file___109 *, struct page___109 *);
	int (*writepages)(struct address_space___109 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___109 *);
	int (*readpages)(struct file___109 *, struct address_space___109 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___109 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___109 **, void **);
	int (*write_end)(struct file___109 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___109 *, void *);
	sector_t (*bmap)(struct address_space___109 *, sector_t);
	void (*invalidatepage)(struct page___109 *, long unsigned int);
	int (*releasepage)(struct page___109 *, gfp_t);
	void (*freepage)(struct page___109 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___109 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___109 *, struct page___109 *, struct page___109 *, enum migrate_mode);
	int (*launder_page)(struct page___109 *);
	int (*is_partially_uptodate)(struct page___109 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___109 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___109 *, struct page___109 *);
	int (*swap_activate)(struct swap_info_struct___24 *, struct file___109 *, sector_t *);
	void (*swap_deactivate)(struct file___109 *);
	void (*invalidatepage_range)(struct page___109 *, unsigned int, unsigned int);
};

struct swap_info_struct___24 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___109 *bdev;
	struct file___109 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___21 {
	struct backing_dev_info___21 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___21 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___21 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___88 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___109 *debug_dir;
	struct dentry___109 *debug_stats;
};

struct hd_struct___15 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___88 __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___15;

struct block_device_operations___14;

struct gendisk___15 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___15 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___15 *part_tbl;
	struct hd_struct___15 part0;
	const struct block_device_operations___14 *fops;
	struct request_queue___14 *queue;
	void *private_data;
	int flags;
	struct device___88 *driverfs_dev;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___14 {
	struct request_queue___14 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___14(struct request_queue___14 *);

typedef void make_request_fn___14(struct request_queue___14 *, struct bio___14 *);

struct request___14;

typedef int prep_rq_fn___14(struct request_queue___14 *, struct request___14 *);

struct bvec_merge_data___14;

typedef int merge_bvec_fn___14(struct request_queue___14 *, struct bvec_merge_data___14 *, struct bio_vec___14 *);

typedef void softirq_done_fn___14(struct request___14 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___14(struct request___14 *);

typedef int dma_drain_needed_fn___14(struct request___14 *);

typedef int lld_busy_fn___14(struct request_queue___14 *);

struct bsg_class_device___14 {
	struct device___88 *class_dev;
	struct device___88 *parent;
	int minor;
	struct request_queue___14 *queue;
	struct kref ref;
	void (*release)(struct device___88 *);
};

typedef void unprep_rq_fn___14(struct request_queue___14 *, struct request___14 *);

struct elevator_queue___14;

struct blk_queue_tag___14;

struct request_queue___14 {
	struct list_head queue_head;
	struct request___14 *last_merge;
	struct elevator_queue___14 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___14 root_rl;
	request_fn_proc___14 *request_fn;
	make_request_fn___14 *make_request_fn;
	prep_rq_fn___14 *prep_rq_fn;
	merge_bvec_fn___14 *merge_bvec_fn;
	softirq_done_fn___14 *softirq_done_fn;
	rq_timed_out_fn___14 *rq_timed_out_fn;
	dma_drain_needed_fn___14 *dma_drain_needed;
	lld_busy_fn___14 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___14 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___21 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject kobj;
	struct kobject mq_kobj;
	struct device___88 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___14 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___14 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___111 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___14 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___14 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___14 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct nameidata___7;

struct inode_operations___109 {
	struct dentry___109 * (*lookup)(struct inode___109 *, struct dentry___109 *, unsigned int);
	void * (*follow_link)(struct dentry___109 *, struct nameidata___7 *);
	int (*permission)(struct inode___109 *, int);
	struct posix_acl * (*get_acl)(struct inode___109 *, int);
	int (*readlink)(struct dentry___109 *, char *, int);
	void (*put_link)(struct dentry___109 *, struct nameidata___7 *, void *);
	int (*create)(struct inode___109 *, struct dentry___109 *, umode_t, bool);
	int (*link)(struct dentry___109 *, struct inode___109 *, struct dentry___109 *);
	int (*unlink)(struct inode___109 *, struct dentry___109 *);
	int (*symlink)(struct inode___109 *, struct dentry___109 *, const char *);
	int (*mkdir)(struct inode___109 *, struct dentry___109 *, umode_t);
	int (*rmdir)(struct inode___109 *, struct dentry___109 *);
	int (*mknod)(struct inode___109 *, struct dentry___109 *, umode_t, dev_t);
	int (*rename)(struct inode___109 *, struct dentry___109 *, struct inode___109 *, struct dentry___109 *);
	int (*setattr)(struct dentry___109 *, struct iattr___109 *);
	int (*getattr)(struct vfsmount *, struct dentry___109 *, struct kstat *);
	int (*setxattr)(struct dentry___109 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___109 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___109 *, char *, size_t);
	int (*removexattr)(struct dentry___109 *, const char *);
	int (*fiemap)(struct inode___109 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___109 *, struct timespec *, int);
	int (*atomic_open)(struct inode___109 *, struct dentry___109 *, struct file___109 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___70;

struct seq_file___83;

struct file_operations___109 {
	struct module *owner;
	loff_t (*llseek)(struct file___109 *, loff_t, int);
	ssize_t (*read)(struct file___109 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___109 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___109 *, void *, filldir_t);
	unsigned int (*poll)(struct file___109 *, struct poll_table_struct___70 *);
	long int (*unlocked_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___109 *, struct vm_area_struct___114 *);
	int (*open)(struct inode___109 *, struct file___109 *);
	int (*flush)(struct file___109 *, fl_owner_t);
	int (*release)(struct inode___109 *, struct file___109 *);
	int (*fsync)(struct file___109 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___109 *, int);
	int (*lock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*sendpage)(struct file___109 *, struct page___109 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___109 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___109 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___109 *, long int, struct file_lock___109 **, void **);
		struct {
			int (*setlease)(struct file___109 *, long int, struct file_lock___109 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___109 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___83 *, struct file___109 *);
};

struct file_lock_operations___109;

struct lock_manager_operations___109;

struct file_lock___109 {
	struct file_lock___109 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___63 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___109 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___109 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___109 *fl_ops;
	const struct lock_manager_operations___109 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___109 {
	void (*fl_copy_lock)(struct file_lock___109 *, struct file_lock___109 *);
	void (*fl_release_private)(struct file_lock___109 *);
};

struct lock_manager_operations___109 {
	int (*lm_compare_owner)(struct file_lock___109 *, struct file_lock___109 *);
	long unsigned int (*lm_owner_key)(struct file_lock___109 *);
	void (*lm_notify)(struct file_lock___109 *);
	int (*lm_grant)(struct file_lock___109 *, struct file_lock___109 *, int);
	void (*lm_break)(struct file_lock___109 *);
	int (*lm_change)(struct file_lock___109 **, int);
};

struct fasync_struct___109 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___109 *fa_next;
	struct file___109 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___109 {
	const char *name;
	int fs_flags;
	struct dentry___109 * (*mount)(struct file_system_type___109 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___109 *);
	struct module *owner;
	struct file_system_type___109 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___109 {
	struct inode___109 * (*alloc_inode)(struct super_block___109 *);
	void (*destroy_inode)(struct inode___109 *);
	void (*dirty_inode)(struct inode___109 *, int);
	int (*write_inode)(struct inode___109 *, struct writeback_control *);
	int (*drop_inode)(struct inode___109 *);
	void (*evict_inode)(struct inode___109 *);
	void (*put_super)(struct super_block___109 *);
	int (*sync_fs)(struct super_block___109 *, int);
	int (*freeze_fs)(struct super_block___109 *);
	int (*unfreeze_fs)(struct super_block___109 *);
	int (*statfs)(struct dentry___109 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___109 *, int *, char *);
	void (*umount_begin)(struct super_block___109 *);
	int (*show_options)(struct seq_file___83 *, struct dentry___109 *);
	int (*show_devname)(struct seq_file___83 *, struct dentry___109 *);
	int (*show_path)(struct seq_file___83 *, struct dentry___109 *);
	int (*show_stats)(struct seq_file___83 *, struct dentry___109 *);
	ssize_t (*quota_read)(struct super_block___109 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___109 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___109 *);
	int (*bdev_try_to_free_page)(struct super_block___109 *, struct page___109 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___109 *);
	void (*free_cached_objects)(struct super_block___109 *, int);
};

struct xattr_handler___74 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___109 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___109 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___109 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___72)(struct file___109 *, wait_queue_head_t *, struct poll_table_struct___70 *);

struct poll_table_struct___70 {
	poll_queue_proc___72 _qproc;
	long unsigned int _key;
};

struct seq_operations___82;

struct seq_file___83 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___111 lock;
	const struct seq_operations___82 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___7 {
	struct path___109 path;
	struct qstr last;
	struct path___109 root;
	struct inode___109 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct nsproxy___64 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___63 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___109 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___110 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___110 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___63 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___111 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___74 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___76 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___58 {
	struct pmu___58 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___111 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___110 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___58 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___81;

struct attribute_group___81 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___81 **bin_attrs;
};

struct bin_attribute___81 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___109 *, struct kobject *, struct bin_attribute___81 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___109 *, struct kobject *, struct bin_attribute___81 *, char *, loff_t, size_t);
	int (*mmap)(struct file___109 *, struct kobject *, struct bin_attribute___81 *, struct vm_area_struct___114 *);
};

struct kmem_cache_cpu___96 {
	void **freelist;
	long unsigned int tid;
	struct page___109 *page;
	struct page___109 *partial;
};

struct memcg_cache_params___96 {
	bool is_root_cache;
	union {
		struct kmem_cache___96 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___96 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___74;

struct cgroup___75 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___75 *parent;
	struct dentry___109 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___76 *subsys[11];
	struct cgroupfs_root___74 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___111 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___74 {
	struct super_block___109 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___75 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___33 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___109 *, struct file___109 *);
	ssize_t (*read)(struct cgroup___75 *, struct cftype___33 *, struct file___109 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___75 *, struct cftype___33 *);
	s64 (*read_s64)(struct cgroup___75 *, struct cftype___33 *);
	int (*read_map)(struct cgroup___75 *, struct cftype___33 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___75 *, struct cftype___33 *, struct seq_file___83 *);
	ssize_t (*write)(struct cgroup___75 *, struct cftype___33 *, struct file___109 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___75 *, struct cftype___33 *, u64);
	int (*write_s64)(struct cgroup___75 *, struct cftype___33 *, s64);
	int (*write_string)(struct cgroup___75 *, struct cftype___33 *, const char *);
	int (*trigger)(struct cgroup___75 *, unsigned int);
	int (*release)(struct inode___109 *, struct file___109 *);
	int (*register_event)(struct cgroup___75 *, struct cftype___33 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___75 *, struct cftype___33 *, struct eventfd_ctx *);
};

struct cftype_set___31 {
	struct list_head node;
	struct cftype___33 *cfts;
};

struct task_and_cgroup___31 {
	struct task_struct___110 *task;
	struct cgroup___75 *cgrp;
	struct css_set___74 *cg;
};

struct cgroup_taskset___31 {
	struct task_and_cgroup___31 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___75 *cur_cgrp;
};

struct cgroup_subsys___31 {
	struct cgroup_subsys_state___76 * (*css_alloc)(struct cgroup___75 *);
	int (*css_online)(struct cgroup___75 *);
	void (*css_offline)(struct cgroup___75 *);
	void (*css_free)(struct cgroup___75 *);
	int (*can_attach)(struct cgroup___75 *, struct cgroup_taskset___31 *);
	void (*cancel_attach)(struct cgroup___75 *, struct cgroup_taskset___31 *);
	void (*attach)(struct cgroup___75 *, struct cgroup_taskset___31 *);
	void (*fork)(struct task_struct___110 *);
	void (*exit)(struct cgroup___75 *, struct cgroup___75 *, struct task_struct___110 *);
	void (*bind)(struct cgroup___75 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___74 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___33 *base_cftypes;
	struct cftype_set___31 base_cftset;
	struct module *module;
};

struct irq_chip___81 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___81 *);
	void (*irq_shutdown)(struct irq_data___81 *);
	void (*irq_enable)(struct irq_data___81 *);
	void (*irq_disable)(struct irq_data___81 *);
	void (*irq_ack)(struct irq_data___81 *);
	void (*irq_mask)(struct irq_data___81 *);
	void (*irq_mask_ack)(struct irq_data___81 *);
	void (*irq_unmask)(struct irq_data___81 *);
	void (*irq_eoi)(struct irq_data___81 *);
	int (*irq_set_affinity)(struct irq_data___81 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___81 *);
	int (*irq_set_type)(struct irq_data___81 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___81 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___81 *);
	void (*irq_bus_sync_unlock)(struct irq_data___81 *);
	void (*irq_cpu_online)(struct irq_data___81 *);
	void (*irq_cpu_offline)(struct irq_data___81 *);
	void (*irq_suspend)(struct irq_data___81 *);
	void (*irq_resume)(struct irq_data___81 *);
	void (*irq_pm_shutdown)(struct irq_data___81 *);
	void (*irq_print_chip)(struct irq_data___81 *, struct seq_file___83 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___81 *, void *);
	long unsigned int flags;
};

typedef int filler_t___3(void *, struct page___109 *);

struct tlb_state___31 {
	struct mm_struct___114 *active_mm;
	int state;
};

struct hstate___10 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___33 cgroup_files[5];
	char name[32];
};

struct bus_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___88 *, char *);
	ssize_t (*store)(struct bus_type___88 *, const char *, size_t);
};

struct device_attribute___88;

struct driver_attribute___88;

struct bus_type___88 {
	const char *name;
	const char *dev_name;
	struct device___88 *dev_root;
	struct bus_attribute___88 *bus_attrs;
	struct device_attribute___88 *dev_attrs;
	struct driver_attribute___88 *drv_attrs;
	const struct attribute_group___81 **bus_groups;
	const struct attribute_group___81 **dev_groups;
	const struct attribute_group___81 **drv_groups;
	int (*match)(struct device___88 *, struct device_driver___88 *);
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	int (*probe)(struct device___88 *);
	int (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*online)(struct device___88 *);
	int (*offline)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct device___88 *, struct device_attribute___88 *, char *);
	ssize_t (*store)(struct device___88 *, struct device_attribute___88 *, const char *, size_t);
};

struct driver_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___88 *, char *);
	ssize_t (*store)(struct device_driver___88 *, const char *, size_t);
};

struct device_driver___88 {
	const char *name;
	struct bus_type___88 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___88 *);
	int (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	const struct attribute_group___81 **groups;
	const struct dev_pm_ops___88 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___88 {
	const char *name;
	const struct attribute_group___81 **groups;
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
};

struct class_attribute___88;

struct class___88 {
	const char *name;
	struct module *owner;
	struct class_attribute___88 *class_attrs;
	struct device_attribute___88 *dev_attrs;
	const struct attribute_group___81 **dev_groups;
	struct bin_attribute___81 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *);
	void (*class_release)(struct class___88 *);
	void (*dev_release)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
	struct subsys_private *p;
};

struct class_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct class___88 *, struct class_attribute___88 *, char *);
	ssize_t (*store)(struct class___88 *, struct class_attribute___88 *, const char *, size_t);
	const void * (*namespace)(struct class___88 *, const struct class_attribute___88 *);
};

struct device_rh___88 {
	struct dev_pm_info_rh___88 power;
};

union swap_header {
	struct {
		char reserved[4086];
		char magic[10];
	} magic;
	struct {
		char bootbits[1024];
		__u32 version;
		__u32 last_page;
		__u32 nr_badpages;
		unsigned char sws_uuid[16];
		unsigned char sws_volume[16];
		__u32 padding[117];
		__u32 badpages[1];
	} info;
};

struct disk_part_tbl___15 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___15 *last_lookup;
	struct hd_struct___15 *part[0];
};

struct block_device_operations___14 {
	int (*open)(struct block_device___109 *, fmode_t);
	void (*release)(struct gendisk___15 *, fmode_t);
	int (*ioctl)(struct block_device___109 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___109 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___109 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___15 *, unsigned int);
	int (*media_changed)(struct gendisk___15 *);
	void (*unlock_native_capacity)(struct gendisk___15 *);
	int (*revalidate_disk)(struct gendisk___15 *);
	int (*getgeo)(struct block_device___109 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___109 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___14 {
	struct request_queue___14 *q;
	struct io_context___14 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___96 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___14(struct request___14 *, int);

struct request___14 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___14 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___14 *bio;
	struct bio___14 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___14 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___14 *saved_end_io;
		} flush;
	};
	struct gendisk___15 *rq_disk;
	struct hd_struct___15 *part;
	long unsigned int start_time;
	struct request_list___14 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___14 *end_io;
	void *end_io_data;
	struct request___14 *next_rq;
};

typedef int elevator_merge_fn___14(struct request_queue___14 *, struct request___14 **, struct bio___14 *);

typedef void elevator_merge_req_fn___14(struct request_queue___14 *, struct request___14 *, struct request___14 *);

typedef void elevator_merged_fn___14(struct request_queue___14 *, struct request___14 *, int);

typedef int elevator_allow_merge_fn___14(struct request_queue___14 *, struct request___14 *, struct bio___14 *);

typedef void elevator_bio_merged_fn___14(struct request_queue___14 *, struct request___14 *, struct bio___14 *);

typedef int elevator_dispatch_fn___14(struct request_queue___14 *, int);

typedef void elevator_add_req_fn___14(struct request_queue___14 *, struct request___14 *);

typedef struct request___14 *elevator_request_list_fn___14(struct request_queue___14 *, struct request___14 *);

typedef void elevator_completed_req_fn___14(struct request_queue___14 *, struct request___14 *);

typedef int elevator_may_queue_fn___14(struct request_queue___14 *, int);

typedef void elevator_init_icq_fn___14(struct io_cq___14 *);

typedef void elevator_exit_icq_fn___14(struct io_cq___14 *);

typedef int elevator_set_req_fn___14(struct request_queue___14 *, struct request___14 *, struct bio___14 *, gfp_t);

typedef void elevator_put_req_fn___14(struct request___14 *);

typedef void elevator_activate_req_fn___14(struct request_queue___14 *, struct request___14 *);

typedef void elevator_deactivate_req_fn___14(struct request_queue___14 *, struct request___14 *);

struct elevator_type___14;

typedef int elevator_init_fn___14(struct request_queue___14 *, struct elevator_type___14 *);

typedef void elevator_exit_fn___14(struct elevator_queue___14 *);

struct elevator_ops___14 {
	elevator_merge_fn___14 *elevator_merge_fn;
	elevator_merged_fn___14 *elevator_merged_fn;
	elevator_merge_req_fn___14 *elevator_merge_req_fn;
	elevator_allow_merge_fn___14 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___14 *elevator_bio_merged_fn;
	elevator_dispatch_fn___14 *elevator_dispatch_fn;
	elevator_add_req_fn___14 *elevator_add_req_fn;
	elevator_activate_req_fn___14 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___14 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___14 *elevator_completed_req_fn;
	elevator_request_list_fn___14 *elevator_former_req_fn;
	elevator_request_list_fn___14 *elevator_latter_req_fn;
	elevator_init_icq_fn___14 *elevator_init_icq_fn;
	elevator_exit_icq_fn___14 *elevator_exit_icq_fn;
	elevator_set_req_fn___14 *elevator_set_req_fn;
	elevator_put_req_fn___14 *elevator_put_req_fn;
	elevator_may_queue_fn___14 *elevator_may_queue_fn;
	elevator_init_fn___14 *elevator_init_fn;
	elevator_exit_fn___14 *elevator_exit_fn;
};

struct elv_fs_entry___14;

struct elevator_type___14 {
	struct kmem_cache___96 *icq_cache;
	struct elevator_ops___14 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___14 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___14 {
	struct elevator_type___14 *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex___111 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___14 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___14 *, char *);
	ssize_t (*store)(struct elevator_queue___14 *, const char *, size_t);
};

struct bvec_merge_data___14 {
	struct block_device___109 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___14 {
	struct request___14 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___82 {
	void * (*start)(struct seq_file___83 *, loff_t *);
	void (*stop)(struct seq_file___83 *, void *);
	void * (*next)(struct seq_file___83 *, void *, loff_t *);
	int (*show)(struct seq_file___83 *, void *);
};

typedef struct poll_table_struct___70 poll_table___9;

struct perf_cpu_context___58;

struct pmu___58 {
	struct list_head entry;
	struct device___88 *dev;
	const struct attribute_group___81 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___58 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___58 *);
	void (*pmu_disable)(struct pmu___58 *);
	int (*event_init)(struct perf_event___58 *);
	int (*add)(struct perf_event___58 *, int);
	void (*del)(struct perf_event___58 *, int);
	void (*start)(struct perf_event___58 *, int);
	void (*stop)(struct perf_event___58 *, int);
	void (*read)(struct perf_event___58 *);
	void (*start_txn)(struct pmu___58 *);
	int (*commit_txn)(struct pmu___58 *);
	void (*cancel_txn)(struct pmu___58 *);
	int (*event_idx)(struct perf_event___58 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___58 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___58 *);
};

struct perf_cpu_context___58 {
	struct perf_event_context___58 ctx;
	struct perf_event_context___58 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___58 *unique_pmu;
	struct perf_cgroup___58 *cgrp;
};

struct trace_event_functions___48;

struct trace_event___48 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___48 *funcs;
};

struct ftrace_event_class___48;

struct ftrace_event_call___48 {
	struct list_head list;
	struct ftrace_event_class___48 *class;
	char *name;
	struct trace_event___48 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___58 {
	struct cgroup_subsys_state___76 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___48 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___111 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___48)(struct trace_iterator___48 *, int, struct trace_event___48 *);

struct trace_event_functions___48 {
	trace_print_func___48 trace;
	trace_print_func___48 raw;
	trace_print_func___48 hex;
	trace_print_func___48 binary;
};

struct ftrace_event_class___48 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___48 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___48 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___48 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___48 *);
};

struct syscall_metadata___18 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___48 *enter_event;
	struct ftrace_event_call___48 *exit_event;
};

struct frontswap_ops {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___103 *);
	int (*load)(unsigned int, long unsigned int, struct page___103 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
};

struct page___110;

typedef struct page___110 *pgtable_t___110;

struct address_space___110;

struct kmem_cache___97;

struct page___110 {
	long unsigned int flags;
	struct address_space___110 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___110 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___110 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___97 *slab_cache;
		struct page___110 *first_page;
	};
	long: 64;
};

struct task_struct___111;

struct pv_cpu_ops___110 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___58 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___58 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___111 *);
	void (*end_context_switch)(struct task_struct___111 *);
};

struct mutex___112 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___111 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___106 {
	struct page___110 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___115;

struct signal_struct___110;

struct css_set___75;

struct task_struct___111 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___111 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___115 *mm;
	struct mm_struct___115 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___111 *real_parent;
	struct task_struct___111 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___111 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___63 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___110 = 0,
		VTIME_USER___110 = 1,
		VTIME_SYS___110 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___58 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___110 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___75 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___112 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___106 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___115 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___115 *, struct mm_struct___115 *);
	void (*dup_mmap)(struct mm_struct___115 *, struct mm_struct___115 *);
	void (*exit_mmap)(struct mm_struct___115 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___115 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___115 *);
	void (*pgd_free)(struct mm_struct___115 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___115 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___115 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___115 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___115 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___115 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___115 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___115 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___115 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___115 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___115 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___115 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___112 lock;
	void *vdso;
} mm_context_t___111;

struct xol_area___110;

struct uprobes_state___110 {
	struct xol_area___110 *xol_area;
};

struct vm_area_struct___115;

struct file___110;

struct core_state___110;

struct mm_struct___115 {
	struct vm_area_struct___115 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___115 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___115 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___111 context;
	long unsigned int flags;
	struct core_state___110 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___111 *owner;
	struct file___110 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___110 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___58;

struct exec_domain___29 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___58 *module;
	struct exec_domain___29 *next;
};

struct module_kobject___57 {
	struct kobject kobj;
	struct module___58 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___57;

struct module___58 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___57 mkobj;
	struct module_attribute___57 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___111 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___57 {
	struct task_struct___111 *task;
	struct exec_domain___29 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___110;

struct lruvec___110 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___110 *zone;
};

struct pglist_data___110;

struct zone___110 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___110 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___110 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___110 {
	struct zone___110 *zone;
	int zone_idx;
};

struct zonelist___110 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___110 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___110 {
	struct zone___110 node_zones[4];
	struct zonelist___110 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___111 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___82;

struct x86_io_apic_ops___82 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___82 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___82;

struct irq_data___82 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___82 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___110 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___111 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dentry___110;

struct path___110 {
	struct vfsmount *mnt;
	struct dentry___110 *dentry;
};

struct inode___110;

struct file_operations___110;

struct file___110 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___110 f_path;
	struct inode___110 *f_inode;
	const struct file_operations___110 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___110 *f_mapping;
	struct mutex___112 f_pos_lock;
};

struct vm_operations_struct___98;

struct vm_area_struct___115 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___115 *vm_next;
	struct vm_area_struct___115 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___115 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___98 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___110 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___57 *, struct module_kobject___57 *, char *);
	ssize_t (*store)(struct module_attribute___57 *, struct module_kobject___57 *, const char *, size_t);
	void (*setup)(struct module___58 *, const char *);
	int (*test)(struct module___58 *);
	void (*free)(struct module___58 *);
};

struct dentry_operations___110;

struct super_block___110;

struct dentry___110 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___110 *d_parent;
	struct qstr d_name;
	struct inode___110 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___110 *d_op;
	struct super_block___110 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___110;

struct address_space___110 {
	struct inode___110 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___112 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___110 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___110;

struct file_lock___110;

struct dquot___110;

struct block_device___110;

struct inode___110 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___110 *i_op;
	struct super_block___110 *i_sb;
	struct address_space___110 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___112 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___110 *i_fop;
	struct file_lock___110 *i_flock;
	struct address_space___110 i_data;
	struct dquot___110 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___110 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___110 {
	int (*d_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_hash)(const struct dentry___110 *, struct qstr *);
	int (*d_compare)(const struct dentry___110 *, const struct dentry___110 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___110 *);
	void (*d_release)(struct dentry___110 *);
	void (*d_prune)(struct dentry___110 *);
	void (*d_iput)(struct dentry___110 *, struct inode___110 *);
	char * (*d_dname)(struct dentry___110 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___110 *);
	int (*d_manage)(struct dentry___110 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___110;

struct mem_dqinfo___110 {
	struct quota_format_type___110 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___110;

struct quota_info___110 {
	unsigned int flags;
	struct mutex___112 dqio_mutex;
	struct mutex___112 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___110 *files[2];
	struct mem_dqinfo___110 info[2];
	const struct quota_format_ops___110 *ops[2];
};

struct file_system_type___110;

struct super_operations___110;

struct dquot_operations___110;

struct quotactl_ops___110;

struct xattr_handler___75;

struct super_block___110 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___110 *s_type;
	const struct super_operations___110 *s_op;
	const struct dquot_operations___110 *dq_op;
	const struct quotactl_ops___110 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___110 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___75 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___110 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___110 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___112 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___110 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___15;

typedef void bio_end_io_t___15(struct bio___15 *, int);

struct bio_integrity_payload___15;

struct bio_set___15;

struct bio_vec___15 {
	struct page___110 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___77;

struct bio___15 {
	sector_t bi_sector;
	struct bio___15 *bi_next;
	struct block_device___110 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___15 *bi_end_io;
	void *bi_private;
	struct io_context *bi_ioc;
	struct cgroup_subsys_state___77 *bi_css;
	struct bio_integrity_payload___15 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___15 *bi_io_vec;
	struct bio_set___15 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	struct bio_vec___15 bi_inline_vecs[0];
};

struct block_device___110 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___110 *bd_inode;
	struct super_block___110 *bd_super;
	struct mutex___112 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___110 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___112 bd_fsfreeze_mutex;
};

struct cgroup___76;

struct cgroup_subsys_state___77 {
	struct cgroup___76 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___110 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___110 *ia_file;
};

struct dquot___110 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___112 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___110 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___110 {
	int qf_fmt_id;
	const struct quota_format_ops___110 *qf_ops;
	struct module___58 *qf_owner;
	struct quota_format_type___110 *qf_next;
};

struct quota_format_ops___110 {
	int (*check_quota_file)(struct super_block___110 *, int);
	int (*read_file_info)(struct super_block___110 *, int);
	int (*write_file_info)(struct super_block___110 *, int);
	int (*free_file_info)(struct super_block___110 *, int);
	int (*read_dqblk)(struct dquot___110 *);
	int (*commit_dqblk)(struct dquot___110 *);
	int (*release_dqblk)(struct dquot___110 *);
};

struct dquot_operations___110 {
	int (*write_dquot)(struct dquot___110 *);
	struct dquot___110 * (*alloc_dquot)(struct super_block___110 *, int);
	void (*destroy_dquot)(struct dquot___110 *);
	int (*acquire_dquot)(struct dquot___110 *);
	int (*release_dquot)(struct dquot___110 *);
	int (*mark_dirty)(struct dquot___110 *);
	int (*write_info)(struct super_block___110 *, int);
	qsize_t * (*get_reserved_space)(struct inode___110 *);
};

struct quotactl_ops___110 {
	int (*quota_on)(struct super_block___110 *, int, int, struct path___110 *);
	int (*quota_on_meta)(struct super_block___110 *, int, int);
	int (*quota_off)(struct super_block___110 *, int);
	int (*quota_sync)(struct super_block___110 *, int);
	int (*get_info)(struct super_block___110 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___110 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___110 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___110 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___110 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___110 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___110 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___110 *, unsigned int);
};

struct swap_info_struct___25;

struct address_space_operations___110 {
	int (*writepage)(struct page___110 *, struct writeback_control *);
	int (*readpage)(struct file___110 *, struct page___110 *);
	int (*writepages)(struct address_space___110 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___110 *);
	int (*readpages)(struct file___110 *, struct address_space___110 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___110 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___110 **, void **);
	int (*write_end)(struct file___110 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___110 *, void *);
	sector_t (*bmap)(struct address_space___110 *, sector_t);
	void (*invalidatepage)(struct page___110 *, long unsigned int);
	int (*releasepage)(struct page___110 *, gfp_t);
	void (*freepage)(struct page___110 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___110 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___110 *, struct page___110 *, struct page___110 *, enum migrate_mode);
	int (*launder_page)(struct page___110 *);
	int (*is_partially_uptodate)(struct page___110 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___110 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___110 *, struct page___110 *);
	int (*swap_activate)(struct swap_info_struct___25 *, struct file___110 *, sector_t *);
	void (*swap_deactivate)(struct file___110 *);
	void (*invalidatepage_range)(struct page___110 *, unsigned int, unsigned int);
};

struct swap_info_struct___25 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___110 *bdev;
	struct file___110 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___110 {
	struct dentry___110 * (*lookup)(struct inode___110 *, struct dentry___110 *, unsigned int);
	void * (*follow_link)(struct dentry___110 *, struct nameidata *);
	int (*permission)(struct inode___110 *, int);
	struct posix_acl * (*get_acl)(struct inode___110 *, int);
	int (*readlink)(struct dentry___110 *, char *, int);
	void (*put_link)(struct dentry___110 *, struct nameidata *, void *);
	int (*create)(struct inode___110 *, struct dentry___110 *, umode_t, bool);
	int (*link)(struct dentry___110 *, struct inode___110 *, struct dentry___110 *);
	int (*unlink)(struct inode___110 *, struct dentry___110 *);
	int (*symlink)(struct inode___110 *, struct dentry___110 *, const char *);
	int (*mkdir)(struct inode___110 *, struct dentry___110 *, umode_t);
	int (*rmdir)(struct inode___110 *, struct dentry___110 *);
	int (*mknod)(struct inode___110 *, struct dentry___110 *, umode_t, dev_t);
	int (*rename)(struct inode___110 *, struct dentry___110 *, struct inode___110 *, struct dentry___110 *);
	int (*setattr)(struct dentry___110 *, struct iattr___110 *);
	int (*getattr)(struct vfsmount *, struct dentry___110 *, struct kstat *);
	int (*setxattr)(struct dentry___110 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___110 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___110 *, char *, size_t);
	int (*removexattr)(struct dentry___110 *, const char *);
	int (*fiemap)(struct inode___110 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___110 *, struct timespec *, int);
	int (*atomic_open)(struct inode___110 *, struct dentry___110 *, struct file___110 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___84;

struct file_operations___110 {
	struct module___58 *owner;
	loff_t (*llseek)(struct file___110 *, loff_t, int);
	ssize_t (*read)(struct file___110 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___110 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___110 *, void *, filldir_t);
	unsigned int (*poll)(struct file___110 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___110 *, struct vm_area_struct___115 *);
	int (*open)(struct inode___110 *, struct file___110 *);
	int (*flush)(struct file___110 *, fl_owner_t);
	int (*release)(struct inode___110 *, struct file___110 *);
	int (*fsync)(struct file___110 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___110 *, int);
	int (*lock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*sendpage)(struct file___110 *, struct page___110 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___110 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___110 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___110 *, long int, struct file_lock___110 **, void **);
		struct {
			int (*setlease)(struct file___110 *, long int, struct file_lock___110 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___110 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___84 *, struct file___110 *);
};

struct fasync_struct___110;

struct file_lock_operations___110;

struct lock_manager_operations___110;

struct file_lock___110 {
	struct file_lock___110 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___63 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___110 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___110 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___110 *fl_ops;
	const struct lock_manager_operations___110 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___110 {
	void (*fl_copy_lock)(struct file_lock___110 *, struct file_lock___110 *);
	void (*fl_release_private)(struct file_lock___110 *);
};

struct lock_manager_operations___110 {
	int (*lm_compare_owner)(struct file_lock___110 *, struct file_lock___110 *);
	long unsigned int (*lm_owner_key)(struct file_lock___110 *);
	void (*lm_notify)(struct file_lock___110 *);
	int (*lm_grant)(struct file_lock___110 *, struct file_lock___110 *, int);
	void (*lm_break)(struct file_lock___110 *);
	int (*lm_change)(struct file_lock___110 **, int);
};

struct fasync_struct___110 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___110 *fa_next;
	struct file___110 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___110 {
	const char *name;
	int fs_flags;
	struct dentry___110 * (*mount)(struct file_system_type___110 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___110 *);
	struct module___58 *owner;
	struct file_system_type___110 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___110 {
	struct inode___110 * (*alloc_inode)(struct super_block___110 *);
	void (*destroy_inode)(struct inode___110 *);
	void (*dirty_inode)(struct inode___110 *, int);
	int (*write_inode)(struct inode___110 *, struct writeback_control *);
	int (*drop_inode)(struct inode___110 *);
	void (*evict_inode)(struct inode___110 *);
	void (*put_super)(struct super_block___110 *);
	int (*sync_fs)(struct super_block___110 *, int);
	int (*freeze_fs)(struct super_block___110 *);
	int (*unfreeze_fs)(struct super_block___110 *);
	int (*statfs)(struct dentry___110 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___110 *, int *, char *);
	void (*umount_begin)(struct super_block___110 *);
	int (*show_options)(struct seq_file___84 *, struct dentry___110 *);
	int (*show_devname)(struct seq_file___84 *, struct dentry___110 *);
	int (*show_path)(struct seq_file___84 *, struct dentry___110 *);
	int (*show_stats)(struct seq_file___84 *, struct dentry___110 *);
	ssize_t (*quota_read)(struct super_block___110 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___110 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___110 *);
	int (*bdev_try_to_free_page)(struct super_block___110 *, struct page___110 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___110 *);
	void (*free_cached_objects)(struct super_block___110 *, int);
};

struct xattr_handler___75 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___110 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___110 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___110 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___83;

struct seq_file___84 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___112 lock;
	const struct seq_operations___83 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___110 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___110 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___97;

struct memcg_cache_params___97;

struct kmem_cache___97 {
	struct kmem_cache_cpu___97 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___97 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___95;

struct vm_operations_struct___98 {
	void (*open)(struct vm_area_struct___115 *);
	void (*close)(struct vm_area_struct___115 *);
	int (*fault)(struct vm_area_struct___115 *, struct vm_fault___95 *);
	int (*page_mkwrite)(struct vm_area_struct___115 *, struct vm_fault___95 *);
	int (*access)(struct vm_area_struct___115 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___115 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___115 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___115 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___115 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___110 {
	struct task_struct___111 *task;
	struct core_thread___110 *next;
};

struct core_state___110 {
	atomic_t nr_threads;
	struct core_thread___110 dumper;
	struct completion startup;
};

struct vm_fault___95 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___110 *page;
};

struct irq_chip___82 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___82 *);
	void (*irq_shutdown)(struct irq_data___82 *);
	void (*irq_enable)(struct irq_data___82 *);
	void (*irq_disable)(struct irq_data___82 *);
	void (*irq_ack)(struct irq_data___82 *);
	void (*irq_mask)(struct irq_data___82 *);
	void (*irq_mask_ack)(struct irq_data___82 *);
	void (*irq_unmask)(struct irq_data___82 *);
	void (*irq_eoi)(struct irq_data___82 *);
	int (*irq_set_affinity)(struct irq_data___82 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___82 *);
	int (*irq_set_type)(struct irq_data___82 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___82 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___82 *);
	void (*irq_bus_sync_unlock)(struct irq_data___82 *);
	void (*irq_cpu_online)(struct irq_data___82 *);
	void (*irq_cpu_offline)(struct irq_data___82 *);
	void (*irq_suspend)(struct irq_data___82 *);
	void (*irq_resume)(struct irq_data___82 *);
	void (*irq_pm_shutdown)(struct irq_data___82 *);
	void (*irq_print_chip)(struct irq_data___82 *, struct seq_file___84 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___82 *, void *);
	long unsigned int flags;
};

struct kmem_cache_cpu___97 {
	void **freelist;
	long unsigned int tid;
	struct page___110 *page;
	struct page___110 *partial;
};

struct memcg_cache_params___97 {
	bool is_root_cache;
	union {
		struct kmem_cache___97 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___97 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___110 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___111 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___111 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___63 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___112 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___75 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___77 *subsys[11];
	struct callback_head callback_head;
};

struct cgroupfs_root___75;

struct cgroup___76 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___76 *parent;
	struct dentry___110 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___77 *subsys[11];
	struct cgroupfs_root___75 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___112 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___75 {
	struct super_block___110 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___76 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___34 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___110 *, struct file___110 *);
	ssize_t (*read)(struct cgroup___76 *, struct cftype___34 *, struct file___110 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___76 *, struct cftype___34 *);
	s64 (*read_s64)(struct cgroup___76 *, struct cftype___34 *);
	int (*read_map)(struct cgroup___76 *, struct cftype___34 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___76 *, struct cftype___34 *, struct seq_file___84 *);
	ssize_t (*write)(struct cgroup___76 *, struct cftype___34 *, struct file___110 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___76 *, struct cftype___34 *, u64);
	int (*write_s64)(struct cgroup___76 *, struct cftype___34 *, s64);
	int (*write_string)(struct cgroup___76 *, struct cftype___34 *, const char *);
	int (*trigger)(struct cgroup___76 *, unsigned int);
	int (*release)(struct inode___110 *, struct file___110 *);
	int (*register_event)(struct cgroup___76 *, struct cftype___34 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___76 *, struct cftype___34 *, struct eventfd_ctx *);
};

struct cftype_set___32 {
	struct list_head node;
	struct cftype___34 *cfts;
};

struct task_and_cgroup___32 {
	struct task_struct___111 *task;
	struct cgroup___76 *cgrp;
	struct css_set___75 *cg;
};

struct cgroup_taskset___32 {
	struct task_and_cgroup___32 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___76 *cur_cgrp;
};

struct cgroup_subsys___32 {
	struct cgroup_subsys_state___77 * (*css_alloc)(struct cgroup___76 *);
	int (*css_online)(struct cgroup___76 *);
	void (*css_offline)(struct cgroup___76 *);
	void (*css_free)(struct cgroup___76 *);
	int (*can_attach)(struct cgroup___76 *, struct cgroup_taskset___32 *);
	void (*cancel_attach)(struct cgroup___76 *, struct cgroup_taskset___32 *);
	void (*attach)(struct cgroup___76 *, struct cgroup_taskset___32 *);
	void (*fork)(struct task_struct___111 *);
	void (*exit)(struct cgroup___76 *, struct cgroup___76 *, struct task_struct___111 *);
	void (*bind)(struct cgroup___76 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___75 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___34 *base_cftypes;
	struct cftype_set___32 base_cftset;
	struct module___58 *module;
};

struct frontswap_ops___2 {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___110 *);
	int (*load)(unsigned int, long unsigned int, struct page___110 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
};

struct crypto_async_request___3;

typedef void (*crypto_completion_t___3)(struct crypto_async_request___3 *, int);

struct crypto_tfm___4;

struct crypto_async_request___3 {
	struct list_head list;
	crypto_completion_t___3 complete;
	void *data;
	struct crypto_tfm___4 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___3;

struct ablkcipher_request___3;

struct ablkcipher_tfm___3 {
	int (*setkey)(struct crypto_ablkcipher___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___3 *);
	int (*decrypt)(struct ablkcipher_request___3 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___3 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___3;

struct aead_request___3;

struct aead_tfm___3 {
	int (*setkey)(struct crypto_aead___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___3 *);
	int (*decrypt)(struct aead_request___3 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___3 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___3;

struct blkcipher_tfm___3 {
	void *iv;
	int (*setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___3 {
	int (*cit_setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___4 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___4 *, u8 *, const u8 *);
};

struct hash_desc___3;

struct crypto_hash___3;

struct hash_tfm___3 {
	int (*init)(struct hash_desc___3 *);
	int (*update)(struct hash_desc___3 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___3 *, u8 *);
	int (*digest)(struct hash_desc___3 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___3 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___3 {
	int (*cot_compress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___3;

struct rng_tfm___3 {
	int (*rng_gen_random)(struct crypto_rng___3 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___3 *, u8 *, unsigned int);
};

struct crypto_alg___4;

struct crypto_tfm___4 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___3 ablkcipher;
		struct aead_tfm___3 aead;
		struct blkcipher_tfm___3 blkcipher;
		struct cipher_tfm___3 cipher;
		struct hash_tfm___3 hash;
		struct compress_tfm___3 compress;
		struct rng_tfm___3 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___4 *);
	struct crypto_alg___4 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___3 {
	struct crypto_async_request___3 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___3 {
	struct crypto_async_request___3 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___3;

struct blkcipher_desc___3 {
	struct crypto_blkcipher___3 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___3 {
	struct crypto_tfm___4 base;
};

struct hash_desc___3 {
	struct crypto_hash___3 *tfm;
	u32 flags;
};

struct crypto_hash___3 {
	struct crypto_tfm___4 base;
};

struct ablkcipher_alg___3 {
	int (*setkey)(struct crypto_ablkcipher___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___3 *);
	int (*decrypt)(struct ablkcipher_request___3 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___3 {
	struct crypto_tfm___4 base;
};

struct aead_alg___3 {
	int (*setkey)(struct crypto_aead___3 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___3 *, unsigned int);
	int (*encrypt)(struct aead_request___3 *);
	int (*decrypt)(struct aead_request___3 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___3 {
	struct crypto_tfm___4 base;
};

struct blkcipher_alg___3 {
	int (*setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___3 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
};

struct compress_alg___3 {
	int (*coa_compress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___3 {
	int (*rng_make_random)(struct crypto_rng___3 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___3 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___3 {
	struct crypto_tfm___4 base;
};

struct crypto_alg___4 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___3 ablkcipher;
		struct aead_alg___3 aead;
		struct blkcipher_alg___3 blkcipher;
		struct cipher_alg___3 cipher;
		struct compress_alg___3 compress;
		struct rng_alg___3 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___4 *);
	void (*cra_exit)(struct crypto_tfm___4 *);
	void (*cra_destroy)(struct crypto_alg___4 *);
	struct module___58 *cra_module;
};

struct crypto_comp {
	struct crypto_tfm___4 base;
};

struct zpool;

struct zpool_ops {
	int (*evict)(struct zpool *, long unsigned int);
};

enum zpool_mapmode {
	ZPOOL_MM_RW = 0,
	ZPOOL_MM_RO = 1,
	ZPOOL_MM_WO = 2,
	ZPOOL_MM_DEFAULT = 0,
};

enum comp_op {
	ZSWAP_COMPOP_COMPRESS = 0,
	ZSWAP_COMPOP_DECOMPRESS = 1,
};

struct zswap_entry {
	struct rb_node rbnode;
	long unsigned int offset;
	int refcount;
	unsigned int length;
	long unsigned int handle;
};

struct zswap_header {
	swp_entry_t swpentry;
};

struct zswap_tree {
	struct rb_root rbroot;
	spinlock_t lock;
};

enum zswap_get_swap_ret {
	ZSWAP_SWAPCACHE_NEW = 0,
	ZSWAP_SWAPCACHE_EXIST = 1,
	ZSWAP_SWAPCACHE_FAIL = 2,
};

struct seq_operations___83 {
	void * (*start)(struct seq_file___84 *, loff_t *);
	void (*stop)(struct seq_file___84 *, void *);
	void * (*next)(struct seq_file___84 *, void *, loff_t *);
	int (*show)(struct seq_file___84 *, void *);
};

struct dma_pool {
	struct list_head page_list;
	spinlock_t lock;
	size_t size;
	struct device___25 *dev;
	size_t allocation;
	size_t boundary;
	char name[32];
	struct list_head pools;
};

struct dma_page {
	struct list_head page_list;
	void *vaddr;
	dma_addr_t dma;
	unsigned int in_use;
	unsigned int offset;
};

typedef struct pglist_data___50 pg_data_t___10;

typedef void compound_page_dtor___3(struct page___50 *);

struct node___3 {
	struct device___39 dev;
	struct work_struct node_work;
};

typedef void (*node_registration_func_t)(struct node___3 *);

struct mmu_gather_batch___4 {
	struct mmu_gather_batch___4 *next;
	unsigned int nr;
	unsigned int max;
	struct page___50 *pages[0];
};

struct mmu_gather___4 {
	struct mm_struct___54 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___4 *active;
	struct mmu_gather_batch___4 local;
	struct page___50 *__pages[8];
	unsigned int batch_count;
};

struct resv_map {
	struct kref refs;
	spinlock_t lock;
	struct list_head regions;
};

struct huge_bootmem_page {
	struct list_head list;
	struct hstate___3 *hstate;
};

struct file_region {
	struct list_head link;
	long int from;
	long int to;
};

struct node_hstate {
	struct kobject *hugepages_kobj;
	struct kobject *hstate_kobjs[2];
};

struct hugetlb_cgroup;

struct nodemask_scratch {
	nodemask_t mask1;
	nodemask_t mask2;
};

struct sp_node {
	struct rb_node nd;
	long unsigned int start;
	long unsigned int end;
	struct mempolicy *policy;
};

typedef struct page___50 *new_page_t___3(struct page___50 *, long unsigned int, int **);

typedef void free_page_t___3(struct page___50 *, long unsigned int);

struct mempolicy_operations {
	int (*create)(struct mempolicy *, const nodemask_t *);
	void (*rebind)(struct mempolicy *, const nodemask_t *, enum mpol_rebind_step);
};

typedef struct pglist_data___110 pg_data_t___11;

typedef struct pglist_data___109 pg_data_t___12;

struct mmu_notifier;

struct mmu_notifier_ops {
	void (*release)(struct mmu_notifier *, struct mm_struct___112 *);
	int (*clear_flush_young)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int);
	int (*test_young)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int, pte_t);
	void (*invalidate_page)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int);
	void (*invalidate_range_start)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier *, struct mm_struct___112 *, long unsigned int, long unsigned int);
};

struct mmu_notifier {
	struct hlist_node hlist;
	const struct mmu_notifier_ops *ops;
};

struct mmu_notifier_rhel7;

struct mmu_notifier_ops_rhel7 {
	void (*release)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *);
	int (*clear_flush_young)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int);
	int (*test_young)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int, pte_t);
	void (*invalidate_page)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int);
	void (*invalidate_range_start)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier_rhel7 *, struct mm_struct___112 *, long unsigned int, long unsigned int);
};

struct mmu_notifier_rhel7 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops_rhel7 *ops;
};

struct mmu_notifier_mm_rhel7 {
	struct mmu_notifier_mm b;
	struct hlist_head list_rhel7;
};

struct memory_notify {
	long unsigned int start_pfn;
	long unsigned int nr_pages;
	int status_change_nid_normal;
	int status_change_nid_high;
	int status_change_nid;
};

struct rmap_item;

struct mm_slot {
	struct hlist_node link;
	struct list_head mm_list;
	struct rmap_item *rmap_list;
	struct mm_struct___114 *mm;
};

struct stable_node;

struct rmap_item {
	struct rmap_item *rmap_list;
	union {
		struct anon_vma *anon_vma;
		int nid;
	};
	struct mm_struct___114 *mm;
	long unsigned int address;
	unsigned int oldchecksum;
	union {
		struct rb_node node;
		struct {
			struct stable_node *head;
			struct hlist_node hlist;
		};
	};
};

struct ksm_scan {
	struct mm_slot *mm_slot;
	long unsigned int address;
	struct rmap_item **rmap_list;
	long unsigned int seqnr;
};

struct stable_node {
	union {
		struct rb_node node;
		struct {
			struct list_head *head;
			struct list_head list;
		};
	};
	struct hlist_head hlist;
	long unsigned int kpfn;
	int nid;
};

enum stat_item {
	ALLOC_FASTPATH = 0,
	ALLOC_SLOWPATH = 1,
	FREE_FASTPATH = 2,
	FREE_SLOWPATH = 3,
	FREE_FROZEN = 4,
	FREE_ADD_PARTIAL = 5,
	FREE_REMOVE_PARTIAL = 6,
	ALLOC_FROM_PARTIAL = 7,
	ALLOC_SLAB = 8,
	ALLOC_REFILL = 9,
	ALLOC_NODE_MISMATCH = 10,
	FREE_SLAB = 11,
	CPUSLAB_FLUSH = 12,
	DEACTIVATE_FULL = 13,
	DEACTIVATE_EMPTY = 14,
	DEACTIVATE_TO_HEAD = 15,
	DEACTIVATE_TO_TAIL = 16,
	DEACTIVATE_REMOTE_FREES = 17,
	DEACTIVATE_BYPASS = 18,
	ORDER_FALLBACK = 19,
	CMPXCHG_DOUBLE_CPU_FAIL = 20,
	CMPXCHG_DOUBLE_FAIL = 21,
	CPU_PARTIAL_ALLOC = 22,
	CPU_PARTIAL_FREE = 23,
	CPU_PARTIAL_NODE = 24,
	CPU_PARTIAL_DRAIN = 25,
	NR_SLUB_STAT_ITEMS = 26,
};

struct track {
	long unsigned int addr;
	long unsigned int addrs[16];
	int cpu;
	int pid;
	long unsigned int when;
};

enum track_item {
	TRACK_ALLOC = 0,
	TRACK_FREE = 1,
};

struct location {
	long unsigned int count;
	long unsigned int addr;
	long long int sum_time;
	long int min_time;
	long int max_time;
	long int min_pid;
	long int max_pid;
	long unsigned int cpus[80];
	nodemask_t nodes;
};

struct loc_track {
	long unsigned int max;
	long unsigned int count;
	struct location *loc;
};

enum slab_stat_type {
	SL_ALL = 0,
	SL_PARTIAL = 1,
	SL_CPU = 2,
	SL_OBJECTS = 3,
	SL_TOTAL = 4,
};

struct slab_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kmem_cache___91 *, char *);
	ssize_t (*store)(struct kmem_cache___91 *, const char *, size_t);
};

struct saved_alias {
	struct kmem_cache___91 *s;
	const char *name;
	struct saved_alias *next;
};

enum slab_modes {
	M_NONE = 0,
	M_PARTIAL = 1,
	M_FULL = 2,
	M_FREE = 3,
};

enum {
	ONLINE_KEEP = 0,
	ONLINE_KERNEL = 1,
	ONLINE_MOVABLE = 2,
};

typedef void (*online_page_callback_t)(struct page___103 *);

struct memory_block {
	long unsigned int start_section_nr;
	long unsigned int end_section_nr;
	long unsigned int state;
	int section_count;
	int online_type;
	int phys_device;
	void *hw;
	int (*phys_callback)(struct memory_block *);
	struct device___82 dev;
};

struct buffer_head;

typedef void bh_end_io_t(struct buffer_head *, int);

struct buffer_head {
	long unsigned int b_state;
	struct buffer_head *b_this_page;
	struct page___50 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___50 *b_bdev;
	bh_end_io_t *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___50 *b_assoc_map;
	atomic_t b_count;
};

enum bh_state_bits {
	BH_Uptodate = 0,
	BH_Dirty = 1,
	BH_Lock = 2,
	BH_Req = 3,
	BH_Uptodate_Lock = 4,
	BH_Mapped = 5,
	BH_New = 6,
	BH_Async_Read = 7,
	BH_Async_Write = 8,
	BH_Delay = 9,
	BH_Boundary = 10,
	BH_Write_EIO = 11,
	BH_Unwritten = 12,
	BH_Quiet = 13,
	BH_Meta = 14,
	BH_Prio = 15,
	BH_PrivateStart = 16,
};

struct ftrace_raw_mm_migrate_pages {
	struct trace_entry ent;
	long unsigned int succeeded;
	long unsigned int failed;
	enum migrate_mode mode;
	int reason;
	char __data[0];
};

struct ftrace_raw_mm_numa_migrate_ratelimit {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int dst_nid;
	long unsigned int nr_pages;
	char __data[0];
};

struct ftrace_data_offsets_mm_migrate_pages {};

struct ftrace_data_offsets_mm_numa_migrate_ratelimit {};

struct page_to_node {
	long unsigned int addr;
	struct page___50 *page;
	int node;
	int status;
};

struct anon_vma_chain___4 {
	struct vm_area_struct___108 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct mmu_gather_batch___5 {
	struct mmu_gather_batch___5 *next;
	unsigned int nr;
	unsigned int max;
	struct page___103 *pages[0];
};

struct mmu_gather___5 {
	struct mm_struct___108 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___5 *active;
	struct mmu_gather_batch___5 local;
	struct page___103 *__pages[8];
	unsigned int batch_count;
};

struct mm_slot___2 {
	struct hlist_node hash;
	struct list_head mm_node;
	struct mm_struct___108 *mm;
};

struct khugepaged_scan {
	struct list_head mm_head;
	struct mm_slot___2 *mm_slot;
	long unsigned int address;
};

struct page___111;

typedef struct page___111 *pgtable_t___111;

struct address_space___111;

struct kmem_cache___98;

struct page___111 {
	long unsigned int flags;
	struct address_space___111 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___111 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___111 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___98 *slab_cache;
		struct page___111 *first_page;
	};
	long: 64;
};

struct pv_cpu_ops___111 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___58 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___58 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___103 *);
	void (*end_context_switch)(struct task_struct___103 *);
};

struct page_frag___107 {
	struct page___111 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___116;

struct nsproxy___65;

struct signal_struct___111;

struct bio_list___15;

struct backing_dev_info___22;

struct io_context___15;

struct css_set___76;

struct task_struct___103 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___103 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___116 *mm;
	struct mm_struct___116 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___103 *real_parent;
	struct task_struct___103 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___103 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___63 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___111 = 0,
		VTIME_USER___111 = 1,
		VTIME_SYS___111 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___58 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___65 *nsproxy;
	struct signal_struct___111 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___15 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___22 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___76 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___104 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___107 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___116 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___116 *, struct mm_struct___116 *);
	void (*dup_mmap)(struct mm_struct___116 *, struct mm_struct___116 *);
	void (*exit_mmap)(struct mm_struct___116 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___116 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___116 *);
	void (*pgd_free)(struct mm_struct___116 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___116 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___116 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___116 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___116 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___116 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___116 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___116 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___116 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___116 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___116 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___116 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___104 lock;
	void *vdso;
} mm_context_t___112;

struct xol_area___111;

struct uprobes_state___111 {
	struct xol_area___111 *xol_area;
};

struct vm_area_struct___116;

struct file___111;

struct core_state___111;

struct mm_struct___116 {
	struct vm_area_struct___116 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___116 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___116 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___112 context;
	long unsigned int flags;
	struct core_state___111 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___103 *owner;
	struct file___111 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___111 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___58 {
	struct task_struct___103 *task;
	struct exec_domain___29 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___111 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___111 *page;
	long unsigned int vaddr;
};

struct kset___5;

struct kobj_type___5;

struct kobject___5 {
	const char *name;
	struct list_head entry;
	struct kobject___5 *parent;
	struct kset___5 *kset;
	struct kobj_type___5 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___98;

struct memcg_cache_params___98;

struct kmem_cache___98 {
	struct kmem_cache_cpu___98 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___98 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___111;

struct address_space_operations___111;

struct address_space___111 {
	struct inode___111 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___104 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___111 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___22 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___111;

struct path___111 {
	struct vfsmount *mnt;
	struct dentry___111 *dentry;
};

struct file_operations___111;

struct file___111 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___111 f_path;
	struct inode___111 *f_inode;
	const struct file_operations___111 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___111 *f_mapping;
	struct mutex___104 f_pos_lock;
};

struct vm_operations_struct___99;

struct vm_area_struct___116 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___116 *vm_next;
	struct vm_area_struct___116 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___116 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___99 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___111 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___96;

struct vm_operations_struct___99 {
	void (*open)(struct vm_area_struct___116 *);
	void (*close)(struct vm_area_struct___116 *);
	int (*fault)(struct vm_area_struct___116 *, struct vm_fault___96 *);
	int (*page_mkwrite)(struct vm_area_struct___116 *, struct vm_fault___96 *);
	int (*access)(struct vm_area_struct___116 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___116 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___116 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___116 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___116 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___111 {
	struct task_struct___103 *task;
	struct core_thread___111 *next;
};

struct core_state___111 {
	atomic_t nr_threads;
	struct core_thread___111 dumper;
	struct completion startup;
};

struct irq_data___83;

struct x86_io_apic_ops___83 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___83 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___83;

struct irq_data___83 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___83 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___89;

struct dev_pm_ops___89 {
	int (*prepare)(struct device___89 *);
	void (*complete)(struct device___89 *);
	int (*suspend)(struct device___89 *);
	int (*resume)(struct device___89 *);
	int (*freeze)(struct device___89 *);
	int (*thaw)(struct device___89 *);
	int (*poweroff)(struct device___89 *);
	int (*restore)(struct device___89 *);
	int (*suspend_late)(struct device___89 *);
	int (*resume_early)(struct device___89 *);
	int (*freeze_late)(struct device___89 *);
	int (*thaw_early)(struct device___89 *);
	int (*poweroff_late)(struct device___89 *);
	int (*restore_early)(struct device___89 *);
	int (*suspend_noirq)(struct device___89 *);
	int (*resume_noirq)(struct device___89 *);
	int (*freeze_noirq)(struct device___89 *);
	int (*thaw_noirq)(struct device___89 *);
	int (*poweroff_noirq)(struct device___89 *);
	int (*restore_noirq)(struct device___89 *);
	int (*runtime_suspend)(struct device___89 *);
	int (*runtime_resume)(struct device___89 *);
	int (*runtime_idle)(struct device___89 *);
};

struct dev_pm_qos___10;

struct dev_pm_info___10 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___10 *qos;
};

struct dma_map_ops___32;

struct dev_archdata___32 {
	struct dma_map_ops___32 *dma_ops;
	void *iommu;
};

struct device_type___89;

struct bus_type___89;

struct device_driver___89;

struct dev_pm_domain___89;

struct class___89;

struct attribute_group___82;

struct device_rh___89;

struct device___89 {
	struct device___89 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___89 *type;
	struct mutex___104 mutex;
	struct bus_type___89 *bus;
	struct device_driver___89 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___89 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___89 *class;
	const struct attribute_group___82 **groups;
	void (*release)(struct device___89 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___89 *device_rh;
};

struct dev_pm_qos_request___10;

struct dev_pm_qos___10 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___10 *latency_req;
	struct dev_pm_qos_request___10 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___10 *latency_tolerance_req;
};

struct dev_pm_info_rh___89 {
	void (*set_latency_tolerance)(struct device___89 *, s32);
};

struct dev_pm_domain___89 {
	struct dev_pm_ops___89 ops;
};

struct smp_ops___111 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___103 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___111;

struct lruvec___111 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___111 *zone;
};

struct pglist_data___111;

struct zone___111 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___111 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___111 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___111 {
	struct zone___111 *zone;
	int zone_idx;
};

struct zonelist___111 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___111 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___111 {
	struct zone___111 node_zones[4];
	struct zonelist___111 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___103 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___13;

struct ctl_node___13 {
	struct rb_node node;
	struct ctl_table_header___13 *header;
};

struct ctl_table_root___13;

struct ctl_table_set___13;

struct ctl_dir___13;

struct ctl_table_header___13 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___13 *root;
	struct ctl_table_set___13 *set;
	struct ctl_dir___13 *parent;
	struct ctl_node___13 *node;
};

struct ctl_dir___13 {
	struct ctl_table_header___13 header;
	struct rb_root root;
};

struct ctl_table_set___13 {
	int (*is_seen)(struct ctl_table_set___13 *);
	struct ctl_dir___13 dir;
};

struct ctl_table_root___13 {
	struct ctl_table_set___13 default_set;
	struct ctl_table_set___13 * (*lookup)(struct ctl_table_root___13 *, struct nsproxy___65 *);
	int (*permissions)(struct ctl_table_header___13 *, struct ctl_table *);
};

struct net___14;

struct nsproxy___65 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___14 *net_ns;
};

struct signal_struct___111 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___103 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___103 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___63 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___104 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___16;

struct bio_list___15 {
	struct bio___16 *head;
	struct bio___16 *tail;
};

struct bdi_writeback___22 {
	struct backing_dev_info___22 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___22 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___22 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___89 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___111 *debug_dir;
	struct dentry___111 *debug_stats;
};

struct io_cq___15;

struct io_context___15 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___15 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___76 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___70 *subsys[11];
	struct callback_head callback_head;
};

struct kobj_ns_type_operations___5 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___6 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___5;

struct sock_common___5 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___5 *skc_prot;
	struct net___14 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___10;

struct sk_buff_head___7 {
	struct sk_buff___10 *next;
	struct sk_buff___10 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___6;

struct socket_wq___5;

struct dst_entry___5;

struct socket___5;

struct sock___6 {
	struct sock_common___5 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___7 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___10 *head;
		struct sk_buff___10 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___6 *sk_filter;
	struct socket_wq___5 *sk_wq;
	struct sk_buff_head___7 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___5 *sk_rx_dst;
	struct dst_entry___5 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___7 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___7 sk_error_queue;
	struct proto___5 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___63 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___5 *sk_socket;
	void *sk_user_data;
	struct page_frag___107 sk_frag;
	struct sk_buff___10 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___5 *sk_cgrp;
	void (*sk_state_change)(struct sock___6 *);
	void (*sk_data_ready)(struct sock___6 *, int);
	void (*sk_write_space)(struct sock___6 *);
	void (*sk_error_report)(struct sock___6 *);
	int (*sk_backlog_rcv)(struct sock___6 *, struct sk_buff___10 *);
	void (*sk_destruct)(struct sock___6 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___82;

struct attribute_group___82 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___82 **bin_attrs;
};

struct bin_attribute___82 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___111 *, struct kobject___5 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___111 *, struct kobject___5 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	int (*mmap)(struct file___111 *, struct kobject___5 *, struct bin_attribute___82 *, struct vm_area_struct___116 *);
};

struct sysfs_ops___5 {
	ssize_t (*show)(struct kobject___5 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___5 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___5 *, const struct attribute *);
};

struct kset_uevent_ops___5;

struct kset___5 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___5 kobj;
	const struct kset_uevent_ops___5 *uevent_ops;
};

struct kobj_type___5 {
	void (*release)(struct kobject___5 *);
	const struct sysfs_ops___5 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___5 *);
	const void * (*namespace)(struct kobject___5 *);
};

struct kset_uevent_ops___5 {
	int (* const filter)(struct kset___5 *, struct kobject___5 *);
	const char * (* const name)(struct kset___5 *, struct kobject___5 *);
	int (* const uevent)(struct kset___5 *, struct kobject___5 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___98 {
	void **freelist;
	long unsigned int tid;
	struct page___111 *page;
	struct page___111 *partial;
};

struct memcg_cache_params___98 {
	bool is_root_cache;
	union {
		struct kmem_cache___98 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___98 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___76 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___111 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___111 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___111 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___111;

struct super_block___111;

struct dentry___111 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___111 *d_parent;
	struct qstr d_name;
	struct inode___111 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___111 *d_op;
	struct super_block___111 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___111;

struct file_lock___111;

struct dquot___111;

struct block_device___111;

struct inode___111 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___111 *i_op;
	struct super_block___111 *i_sb;
	struct address_space___111 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___104 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___111 *i_fop;
	struct file_lock___111 *i_flock;
	struct address_space___111 i_data;
	struct dquot___111 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___111 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___111 {
	int (*d_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_hash)(const struct dentry___111 *, struct qstr *);
	int (*d_compare)(const struct dentry___111 *, const struct dentry___111 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___111 *);
	void (*d_release)(struct dentry___111 *);
	void (*d_prune)(struct dentry___111 *);
	void (*d_iput)(struct dentry___111 *, struct inode___111 *);
	char * (*d_dname)(struct dentry___111 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___111 *);
	int (*d_manage)(struct dentry___111 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___111;

struct mem_dqinfo___111 {
	struct quota_format_type___111 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___111;

struct quota_info___111 {
	unsigned int flags;
	struct mutex___104 dqio_mutex;
	struct mutex___104 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___111 *files[2];
	struct mem_dqinfo___111 info[2];
	const struct quota_format_ops___111 *ops[2];
};

struct file_system_type___111;

struct super_operations___111;

struct dquot_operations___111;

struct quotactl_ops___111;

struct super_block___111 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___111 *s_type;
	const struct super_operations___111 *s_op;
	const struct dquot_operations___111 *dq_op;
	const struct quotactl_ops___111 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___111 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___76 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___111 *s_bdev;
	struct backing_dev_info___22 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___111 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___104 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___111 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___16(struct bio___16 *, int);

struct bio_vec___16 {
	struct page___111 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___16;

struct bio_set___16;

struct bio___16 {
	sector_t bi_sector;
	struct bio___16 *bi_next;
	struct block_device___111 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___16 *bi_end_io;
	void *bi_private;
	struct io_context___15 *bi_ioc;
	struct cgroup_subsys_state___70 *bi_css;
	struct bio_integrity_payload___16 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___16 *bi_io_vec;
	struct bio_set___16 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	struct bio_vec___16 bi_inline_vecs[0];
};

struct hd_struct___16;

struct gendisk___16;

struct request_queue___15;

struct block_device___111 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___111 *bd_inode;
	struct super_block___111 *bd_super;
	struct mutex___104 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___111 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___16 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___16 *bd_disk;
	struct request_queue___15 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___104 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___16 {
	struct bio___16 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___16 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___16 *bip_vec;
	struct bio_vec___16 bip_inline_vecs[0];
};

struct bio_set___16 {
	struct kmem_cache___98 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___15 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct kiocb___8;

typedef int kiocb_cancel_fn___8(struct kiocb___8 *, struct io_event *);

struct kiocb___8 {
	atomic_t ki_users;
	struct file___111 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___8 *ki_cancel;
	void (*ki_dtor)(struct kiocb___8 *);
	union {
		void *user;
		struct task_struct___103 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___111 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___111 *ia_file;
};

struct dquot___111 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___104 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___111 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___111 {
	int qf_fmt_id;
	const struct quota_format_ops___111 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___111 *qf_next;
};

struct quota_format_ops___111 {
	int (*check_quota_file)(struct super_block___111 *, int);
	int (*read_file_info)(struct super_block___111 *, int);
	int (*write_file_info)(struct super_block___111 *, int);
	int (*free_file_info)(struct super_block___111 *, int);
	int (*read_dqblk)(struct dquot___111 *);
	int (*commit_dqblk)(struct dquot___111 *);
	int (*release_dqblk)(struct dquot___111 *);
};

struct dquot_operations___111 {
	int (*write_dquot)(struct dquot___111 *);
	struct dquot___111 * (*alloc_dquot)(struct super_block___111 *, int);
	void (*destroy_dquot)(struct dquot___111 *);
	int (*acquire_dquot)(struct dquot___111 *);
	int (*release_dquot)(struct dquot___111 *);
	int (*mark_dirty)(struct dquot___111 *);
	int (*write_info)(struct super_block___111 *, int);
	qsize_t * (*get_reserved_space)(struct inode___111 *);
};

struct quotactl_ops___111 {
	int (*quota_on)(struct super_block___111 *, int, int, struct path___111 *);
	int (*quota_on_meta)(struct super_block___111 *, int, int);
	int (*quota_off)(struct super_block___111 *, int);
	int (*quota_sync)(struct super_block___111 *, int);
	int (*get_info)(struct super_block___111 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___111 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___111 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___111 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___111 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___111 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___111 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___111 *, unsigned int);
};

struct swap_info_struct___26;

struct address_space_operations___111 {
	int (*writepage)(struct page___111 *, struct writeback_control *);
	int (*readpage)(struct file___111 *, struct page___111 *);
	int (*writepages)(struct address_space___111 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___111 *);
	int (*readpages)(struct file___111 *, struct address_space___111 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___111 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___111 **, void **);
	int (*write_end)(struct file___111 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___111 *, void *);
	sector_t (*bmap)(struct address_space___111 *, sector_t);
	void (*invalidatepage)(struct page___111 *, long unsigned int);
	int (*releasepage)(struct page___111 *, gfp_t);
	void (*freepage)(struct page___111 *);
	ssize_t (*direct_IO)(int, struct kiocb___8 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___111 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___111 *, struct page___111 *, struct page___111 *, enum migrate_mode);
	int (*launder_page)(struct page___111 *);
	int (*is_partially_uptodate)(struct page___111 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___111 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___111 *, struct page___111 *);
	int (*swap_activate)(struct swap_info_struct___26 *, struct file___111 *, sector_t *);
	void (*swap_deactivate)(struct file___111 *);
	void (*invalidatepage_range)(struct page___111 *, unsigned int, unsigned int);
};

struct swap_info_struct___26 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___111 *bdev;
	struct file___111 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___16 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___89 __dev;
	struct kobject___5 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___16;

struct block_device_operations___15;

struct blk_integrity___2;

struct gendisk___16 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___16 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___16 *part_tbl;
	struct hd_struct___16 part0;
	const struct block_device_operations___15 *fops;
	struct request_queue___15 *queue;
	void *private_data;
	int flags;
	struct device___89 *driverfs_dev;
	struct kobject___5 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct request_list___15 {
	struct request_queue___15 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___15(struct request_queue___15 *);

typedef void make_request_fn___15(struct request_queue___15 *, struct bio___16 *);

struct request___15;

typedef int prep_rq_fn___15(struct request_queue___15 *, struct request___15 *);

struct bvec_merge_data___15;

typedef int merge_bvec_fn___15(struct request_queue___15 *, struct bvec_merge_data___15 *, struct bio_vec___16 *);

typedef void softirq_done_fn___15(struct request___15 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___15(struct request___15 *);

typedef int dma_drain_needed_fn___15(struct request___15 *);

typedef int lld_busy_fn___15(struct request_queue___15 *);

struct bsg_class_device___15 {
	struct device___89 *class_dev;
	struct device___89 *parent;
	int minor;
	struct request_queue___15 *queue;
	struct kref ref;
	void (*release)(struct device___89 *);
};

typedef void unprep_rq_fn___15(struct request_queue___15 *, struct request___15 *);

struct elevator_queue___15;

struct blk_queue_tag___15;

struct request_queue___15 {
	struct list_head queue_head;
	struct request___15 *last_merge;
	struct elevator_queue___15 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___15 root_rl;
	request_fn_proc___15 *request_fn;
	make_request_fn___15 *make_request_fn;
	prep_rq_fn___15 *prep_rq_fn;
	merge_bvec_fn___15 *merge_bvec_fn;
	softirq_done_fn___15 *softirq_done_fn;
	rq_timed_out_fn___15 *rq_timed_out_fn;
	dma_drain_needed_fn___15 *dma_drain_needed;
	lld_busy_fn___15 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___15 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___22 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___5 kobj;
	struct kobject___5 mq_kobj;
	struct device___89 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___15 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___15 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___104 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___15 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___15 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___16 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___111 {
	struct dentry___111 * (*lookup)(struct inode___111 *, struct dentry___111 *, unsigned int);
	void * (*follow_link)(struct dentry___111 *, struct nameidata *);
	int (*permission)(struct inode___111 *, int);
	struct posix_acl * (*get_acl)(struct inode___111 *, int);
	int (*readlink)(struct dentry___111 *, char *, int);
	void (*put_link)(struct dentry___111 *, struct nameidata *, void *);
	int (*create)(struct inode___111 *, struct dentry___111 *, umode_t, bool);
	int (*link)(struct dentry___111 *, struct inode___111 *, struct dentry___111 *);
	int (*unlink)(struct inode___111 *, struct dentry___111 *);
	int (*symlink)(struct inode___111 *, struct dentry___111 *, const char *);
	int (*mkdir)(struct inode___111 *, struct dentry___111 *, umode_t);
	int (*rmdir)(struct inode___111 *, struct dentry___111 *);
	int (*mknod)(struct inode___111 *, struct dentry___111 *, umode_t, dev_t);
	int (*rename)(struct inode___111 *, struct dentry___111 *, struct inode___111 *, struct dentry___111 *);
	int (*setattr)(struct dentry___111 *, struct iattr___111 *);
	int (*getattr)(struct vfsmount *, struct dentry___111 *, struct kstat *);
	int (*setxattr)(struct dentry___111 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___111 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___111 *, char *, size_t);
	int (*removexattr)(struct dentry___111 *, const char *);
	int (*fiemap)(struct inode___111 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___111 *, struct timespec *, int);
	int (*atomic_open)(struct inode___111 *, struct dentry___111 *, struct file___111 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___71;

struct seq_file___85;

struct file_operations___111 {
	struct module *owner;
	loff_t (*llseek)(struct file___111 *, loff_t, int);
	ssize_t (*read)(struct file___111 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___111 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___8 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___8 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___111 *, void *, filldir_t);
	unsigned int (*poll)(struct file___111 *, struct poll_table_struct___71 *);
	long int (*unlocked_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___111 *, struct vm_area_struct___116 *);
	int (*open)(struct inode___111 *, struct file___111 *);
	int (*flush)(struct file___111 *, fl_owner_t);
	int (*release)(struct inode___111 *, struct file___111 *);
	int (*fsync)(struct file___111 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___8 *, int);
	int (*fasync)(int, struct file___111 *, int);
	int (*lock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*sendpage)(struct file___111 *, struct page___111 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___111 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___111 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___111 *, long int, struct file_lock___111 **, void **);
		struct {
			int (*setlease)(struct file___111 *, long int, struct file_lock___111 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___111 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___85 *, struct file___111 *);
};

struct fasync_struct___111;

struct file_lock_operations___111;

struct lock_manager_operations___111;

struct file_lock___111 {
	struct file_lock___111 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___63 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___111 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___111 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___111 *fl_ops;
	const struct lock_manager_operations___111 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___111 {
	void (*fl_copy_lock)(struct file_lock___111 *, struct file_lock___111 *);
	void (*fl_release_private)(struct file_lock___111 *);
};

struct lock_manager_operations___111 {
	int (*lm_compare_owner)(struct file_lock___111 *, struct file_lock___111 *);
	long unsigned int (*lm_owner_key)(struct file_lock___111 *);
	void (*lm_notify)(struct file_lock___111 *);
	int (*lm_grant)(struct file_lock___111 *, struct file_lock___111 *, int);
	void (*lm_break)(struct file_lock___111 *);
	int (*lm_change)(struct file_lock___111 **, int);
};

struct fasync_struct___111 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___111 *fa_next;
	struct file___111 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___111 {
	const char *name;
	int fs_flags;
	struct dentry___111 * (*mount)(struct file_system_type___111 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___111 *);
	struct module *owner;
	struct file_system_type___111 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___111 {
	struct inode___111 * (*alloc_inode)(struct super_block___111 *);
	void (*destroy_inode)(struct inode___111 *);
	void (*dirty_inode)(struct inode___111 *, int);
	int (*write_inode)(struct inode___111 *, struct writeback_control *);
	int (*drop_inode)(struct inode___111 *);
	void (*evict_inode)(struct inode___111 *);
	void (*put_super)(struct super_block___111 *);
	int (*sync_fs)(struct super_block___111 *, int);
	int (*freeze_fs)(struct super_block___111 *);
	int (*unfreeze_fs)(struct super_block___111 *);
	int (*statfs)(struct dentry___111 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___111 *, int *, char *);
	void (*umount_begin)(struct super_block___111 *);
	int (*show_options)(struct seq_file___85 *, struct dentry___111 *);
	int (*show_devname)(struct seq_file___85 *, struct dentry___111 *);
	int (*show_path)(struct seq_file___85 *, struct dentry___111 *);
	int (*show_stats)(struct seq_file___85 *, struct dentry___111 *);
	ssize_t (*quota_read)(struct super_block___111 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___111 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___111 *);
	int (*bdev_try_to_free_page)(struct super_block___111 *, struct page___111 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___111 *);
	void (*free_cached_objects)(struct super_block___111 *, int);
};

typedef void (*poll_queue_proc___73)(struct file___111 *, wait_queue_head_t *, struct poll_table_struct___71 *);

struct poll_table_struct___71 {
	poll_queue_proc___73 _qproc;
	long unsigned int _key;
};

struct seq_operations___84;

struct seq_file___85 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___104 lock;
	const struct seq_operations___84 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___76;

struct cgroup___69 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___69 *parent;
	struct dentry___111 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___70 *subsys[11];
	struct cgroupfs_root___76 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___104 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___76 {
	struct super_block___111 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___69 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___35 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___111 *, struct file___111 *);
	ssize_t (*read)(struct cgroup___69 *, struct cftype___35 *, struct file___111 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___69 *, struct cftype___35 *);
	s64 (*read_s64)(struct cgroup___69 *, struct cftype___35 *);
	int (*read_map)(struct cgroup___69 *, struct cftype___35 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___69 *, struct cftype___35 *, struct seq_file___85 *);
	ssize_t (*write)(struct cgroup___69 *, struct cftype___35 *, struct file___111 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___69 *, struct cftype___35 *, u64);
	int (*write_s64)(struct cgroup___69 *, struct cftype___35 *, s64);
	int (*write_string)(struct cgroup___69 *, struct cftype___35 *, const char *);
	int (*trigger)(struct cgroup___69 *, unsigned int);
	int (*release)(struct inode___111 *, struct file___111 *);
	int (*register_event)(struct cgroup___69 *, struct cftype___35 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___69 *, struct cftype___35 *, struct eventfd_ctx *);
};

struct cftype_set___33 {
	struct list_head node;
	struct cftype___35 *cfts;
};

struct task_and_cgroup___33 {
	struct task_struct___103 *task;
	struct cgroup___69 *cgrp;
	struct css_set___76 *cg;
};

struct cgroup_taskset___33 {
	struct task_and_cgroup___33 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___69 *cur_cgrp;
};

struct cgroup_subsys___33 {
	struct cgroup_subsys_state___70 * (*css_alloc)(struct cgroup___69 *);
	int (*css_online)(struct cgroup___69 *);
	void (*css_offline)(struct cgroup___69 *);
	void (*css_free)(struct cgroup___69 *);
	int (*can_attach)(struct cgroup___69 *, struct cgroup_taskset___33 *);
	void (*cancel_attach)(struct cgroup___69 *, struct cgroup_taskset___33 *);
	void (*attach)(struct cgroup___69 *, struct cgroup_taskset___33 *);
	void (*fork)(struct task_struct___103 *);
	void (*exit)(struct cgroup___69 *, struct cgroup___69 *, struct task_struct___103 *);
	void (*bind)(struct cgroup___69 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___76 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___35 *base_cftypes;
	struct cftype_set___33 base_cftset;
	struct module *module;
};

struct irq_chip___83 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___83 *);
	void (*irq_shutdown)(struct irq_data___83 *);
	void (*irq_enable)(struct irq_data___83 *);
	void (*irq_disable)(struct irq_data___83 *);
	void (*irq_ack)(struct irq_data___83 *);
	void (*irq_mask)(struct irq_data___83 *);
	void (*irq_mask_ack)(struct irq_data___83 *);
	void (*irq_unmask)(struct irq_data___83 *);
	void (*irq_eoi)(struct irq_data___83 *);
	int (*irq_set_affinity)(struct irq_data___83 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___83 *);
	int (*irq_set_type)(struct irq_data___83 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___83 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___83 *);
	void (*irq_bus_sync_unlock)(struct irq_data___83 *);
	void (*irq_cpu_online)(struct irq_data___83 *);
	void (*irq_cpu_offline)(struct irq_data___83 *);
	void (*irq_suspend)(struct irq_data___83 *);
	void (*irq_resume)(struct irq_data___83 *);
	void (*irq_pm_shutdown)(struct irq_data___83 *);
	void (*irq_print_chip)(struct irq_data___83 *, struct seq_file___85 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___83 *, void *);
	long unsigned int flags;
};

struct mem_cgroup_reclaim_cookie___2 {
	struct zone___111 *zone;
	int priority;
	unsigned int generation;
};

struct vm_fault___96 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___111 *page;
};

struct mm_walk___2 {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___2 *);
	struct mm_struct___116 *mm;
	void *private;
};

struct tlb_state___32 {
	struct mm_struct___116 *active_mm;
	int state;
};

struct hstate___11 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___35 cgroup_files[5];
	char name[32];
};

struct dma_map_ops___32 {
	void * (*alloc)(struct device___89 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___89 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___89 *, struct vm_area_struct___116 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___89 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___89 *, struct page___111 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___89 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___89 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___89 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___89 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___89 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___89 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___89 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___89 *, dma_addr_t);
	int (*dma_supported)(struct device___89 *, u64);
	int (*set_dma_mask)(struct device___89 *, u64);
	int is_phys;
};

struct bus_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___89 *, char *);
	ssize_t (*store)(struct bus_type___89 *, const char *, size_t);
};

struct device_attribute___89;

struct driver_attribute___89;

struct bus_type___89 {
	const char *name;
	const char *dev_name;
	struct device___89 *dev_root;
	struct bus_attribute___89 *bus_attrs;
	struct device_attribute___89 *dev_attrs;
	struct driver_attribute___89 *drv_attrs;
	const struct attribute_group___82 **bus_groups;
	const struct attribute_group___82 **dev_groups;
	const struct attribute_group___82 **drv_groups;
	int (*match)(struct device___89 *, struct device_driver___89 *);
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	int (*probe)(struct device___89 *);
	int (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*online)(struct device___89 *);
	int (*offline)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct device___89 *, struct device_attribute___89 *, char *);
	ssize_t (*store)(struct device___89 *, struct device_attribute___89 *, const char *, size_t);
};

struct driver_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___89 *, char *);
	ssize_t (*store)(struct device_driver___89 *, const char *, size_t);
};

struct device_driver___89 {
	const char *name;
	struct bus_type___89 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___89 *);
	int (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	const struct attribute_group___82 **groups;
	const struct dev_pm_ops___89 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___89 {
	const char *name;
	const struct attribute_group___82 **groups;
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
};

struct class_attribute___89;

struct class___89 {
	const char *name;
	struct module *owner;
	struct class_attribute___89 *class_attrs;
	struct device_attribute___89 *dev_attrs;
	const struct attribute_group___82 **dev_groups;
	struct bin_attribute___82 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *);
	void (*class_release)(struct class___89 *);
	void (*dev_release)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
	struct subsys_private *p;
};

struct class_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct class___89 *, struct class_attribute___89 *, char *);
	ssize_t (*store)(struct class___89 *, struct class_attribute___89 *, const char *, size_t);
	const void * (*namespace)(struct class___89 *, const struct class_attribute___89 *);
};

struct device_rh___89 {
	struct dev_pm_info_rh___89 power;
};

struct seq_operations___84 {
	void * (*start)(struct seq_file___85 *, loff_t *);
	void (*stop)(struct seq_file___85 *, void *);
	void * (*next)(struct seq_file___85 *, void *, loff_t *);
	int (*show)(struct seq_file___85 *, void *);
};

enum {
	PCG_LOCK = 0,
	PCG_USED = 1,
	PCG_MIGRATION = 2,
	__NR_PCG_FLAGS = 3,
};

struct disk_part_tbl___16 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___16 *last_lookup;
	struct hd_struct___16 *part[0];
};

struct block_device_operations___15 {
	int (*open)(struct block_device___111 *, fmode_t);
	void (*release)(struct gendisk___16 *, fmode_t);
	int (*ioctl)(struct block_device___111 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___111 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___111 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___16 *, unsigned int);
	int (*media_changed)(struct gendisk___16 *);
	void (*unlock_native_capacity)(struct gendisk___16 *);
	int (*revalidate_disk)(struct gendisk___16 *);
	int (*getgeo)(struct block_device___111 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___111 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct blk_integrity___2 {
	integrity_gen_fn *generate_fn;
	integrity_vrfy_fn *verify_fn;
	integrity_set_tag_fn *set_tag_fn;
	integrity_get_tag_fn *get_tag_fn;
	short unsigned int flags;
	short unsigned int tuple_size;
	short unsigned int sector_size;
	short unsigned int tag_size;
	const char *name;
	struct kobject___5 kobj;
};

struct io_cq___15 {
	struct request_queue___15 *q;
	struct io_context___15 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___98 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___15(struct request___15 *, int);

struct request___15 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___15 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___16 *bio;
	struct bio___16 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___15 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___15 *saved_end_io;
		} flush;
	};
	struct gendisk___16 *rq_disk;
	struct hd_struct___16 *part;
	long unsigned int start_time;
	struct request_list___15 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___15 *end_io;
	void *end_io_data;
	struct request___15 *next_rq;
};

typedef int elevator_merge_fn___15(struct request_queue___15 *, struct request___15 **, struct bio___16 *);

typedef void elevator_merge_req_fn___15(struct request_queue___15 *, struct request___15 *, struct request___15 *);

typedef void elevator_merged_fn___15(struct request_queue___15 *, struct request___15 *, int);

typedef int elevator_allow_merge_fn___15(struct request_queue___15 *, struct request___15 *, struct bio___16 *);

typedef void elevator_bio_merged_fn___15(struct request_queue___15 *, struct request___15 *, struct bio___16 *);

typedef int elevator_dispatch_fn___15(struct request_queue___15 *, int);

typedef void elevator_add_req_fn___15(struct request_queue___15 *, struct request___15 *);

typedef struct request___15 *elevator_request_list_fn___15(struct request_queue___15 *, struct request___15 *);

typedef void elevator_completed_req_fn___15(struct request_queue___15 *, struct request___15 *);

typedef int elevator_may_queue_fn___15(struct request_queue___15 *, int);

typedef void elevator_init_icq_fn___15(struct io_cq___15 *);

typedef void elevator_exit_icq_fn___15(struct io_cq___15 *);

typedef int elevator_set_req_fn___15(struct request_queue___15 *, struct request___15 *, struct bio___16 *, gfp_t);

typedef void elevator_put_req_fn___15(struct request___15 *);

typedef void elevator_activate_req_fn___15(struct request_queue___15 *, struct request___15 *);

typedef void elevator_deactivate_req_fn___15(struct request_queue___15 *, struct request___15 *);

struct elevator_type___15;

typedef int elevator_init_fn___15(struct request_queue___15 *, struct elevator_type___15 *);

typedef void elevator_exit_fn___15(struct elevator_queue___15 *);

struct elevator_ops___15 {
	elevator_merge_fn___15 *elevator_merge_fn;
	elevator_merged_fn___15 *elevator_merged_fn;
	elevator_merge_req_fn___15 *elevator_merge_req_fn;
	elevator_allow_merge_fn___15 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___15 *elevator_bio_merged_fn;
	elevator_dispatch_fn___15 *elevator_dispatch_fn;
	elevator_add_req_fn___15 *elevator_add_req_fn;
	elevator_activate_req_fn___15 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___15 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___15 *elevator_completed_req_fn;
	elevator_request_list_fn___15 *elevator_former_req_fn;
	elevator_request_list_fn___15 *elevator_latter_req_fn;
	elevator_init_icq_fn___15 *elevator_init_icq_fn;
	elevator_exit_icq_fn___15 *elevator_exit_icq_fn;
	elevator_set_req_fn___15 *elevator_set_req_fn;
	elevator_put_req_fn___15 *elevator_put_req_fn;
	elevator_may_queue_fn___15 *elevator_may_queue_fn;
	elevator_init_fn___15 *elevator_init_fn;
	elevator_exit_fn___15 *elevator_exit_fn;
};

struct elv_fs_entry___15;

struct elevator_type___15 {
	struct kmem_cache___98 *icq_cache;
	struct elevator_ops___15 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___15 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___15 {
	struct elevator_type___15 *type;
	void *elevator_data;
	struct kobject___5 kobj;
	struct mutex___104 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___15 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___15 *, char *);
	ssize_t (*store)(struct elevator_queue___15 *, const char *, size_t);
};

struct bvec_merge_data___15 {
	struct block_device___111 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___15 {
	struct request___15 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct dev_pm_qos_request___10 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___89 *dev;
};

struct socket_wq___5 {
	wait_queue_head_t wait;
	struct fasync_struct___111 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___5;

struct socket___5 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___5 *wq;
	struct file___111 *file;
	struct sock___6 *sk;
	const struct proto_ops___5 *ops;
};

struct proto_ops___5 {
	int family;
	struct module *owner;
	int (*release)(struct socket___5 *);
	int (*bind)(struct socket___5 *, struct sockaddr *, int);
	int (*connect)(struct socket___5 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___5 *, struct socket___5 *);
	int (*accept)(struct socket___5 *, struct socket___5 *, int);
	int (*getname)(struct socket___5 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___111 *, struct socket___5 *, struct poll_table_struct___71 *);
	int (*ioctl)(struct socket___5 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___5 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___5 *, int);
	int (*shutdown)(struct socket___5 *, int);
	int (*setsockopt)(struct socket___5 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___5 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___5 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___5 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___8 *, struct socket___5 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___8 *, struct socket___5 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___111 *, struct socket___5 *, struct vm_area_struct___116 *);
	ssize_t (*sendpage)(struct socket___5 *, struct page___111 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___5 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___6 *, int);
		struct {
			void (*set_peek_off)(struct sock___6 *, int);
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
};

struct netns_core___13 {
	struct ctl_table_header___13 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___13 {
	struct mutex___104 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___13 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___13 *ctl;
};

struct netns_ipv4___13 {
	struct ctl_table_header___13 *forw_hdr;
	struct ctl_table_header___13 *frags_hdr;
	struct ctl_table_header___13 *ipv4_hdr;
	struct ctl_table_header___13 *route_hdr;
	struct ctl_table_header___13 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___6 *fibnl;
	struct sock___6 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___13 {
	struct ctl_table_header___13 *hdr;
	struct ctl_table_header___13 *route_hdr;
	struct ctl_table_header___13 *icmp_hdr;
	struct ctl_table_header___13 *frags_hdr;
	struct ctl_table_header___13 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___8;

struct neighbour___5;

struct dst_ops___13 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___13 *);
	struct dst_entry___5 * (*check)(struct dst_entry___5 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___5 *);
	unsigned int (*mtu)(const struct dst_entry___5 *);
	u32 * (*cow_metrics)(struct dst_entry___5 *, long unsigned int);
	void (*destroy)(struct dst_entry___5 *);
	void (*ifdown)(struct dst_entry___5 *, struct net_device___8 *, int);
	struct dst_entry___5 * (*negative_advice)(struct dst_entry___5 *);
	void (*link_failure)(struct sk_buff___10 *);
	void (*update_pmtu)(struct dst_entry___5 *, struct sock___6 *, struct sk_buff___10 *, u32);
	void (*redirect)(struct dst_entry___5 *, struct sock___6 *, struct sk_buff___10 *);
	int (*local_out)(struct sk_buff___10 *);
	struct neighbour___5 * (*neigh_lookup)(const struct dst_entry___5 *, struct sk_buff___10 *, const void *);
	struct kmem_cache___98 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___13 {
	struct netns_sysctl_ipv6___13 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___13 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___6 **icmp_sk;
	struct sock___6 *ndisc_sk;
	struct sock___6 *tcp_sk;
	struct sock___6 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___13 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___13 *sysctl_header;
	struct sock___6 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___5 {
	struct sock___6 *v4_ctl_sk;
	struct sock___6 *v6_ctl_sk;
};

struct netns_nf___13 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___13 *nf_log_dir_header;
};

struct nf_proto_net___13 {
	struct ctl_table_header___13 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___13 {
	struct nf_proto_net___13 pn;
	unsigned int timeout;
};

struct nf_tcp_net___13 {
	struct nf_proto_net___13 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___13 {
	struct nf_proto_net___13 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___13 {
	struct nf_proto_net___13 pn;
	unsigned int timeout;
};

struct nf_ip_net___13 {
	struct nf_generic_net___13 generic;
	struct nf_tcp_net___13 tcp;
	struct nf_udp_net___13 udp;
	struct nf_icmp_net___13 icmp;
	struct nf_icmp_net___13 icmpv6;
};

struct netns_ct___13 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___13 *sysctl_header;
	struct ctl_table_header___13 *acct_sysctl_header;
	struct ctl_table_header___13 *tstamp_sysctl_header;
	struct ctl_table_header___13 *event_sysctl_header;
	struct ctl_table_header___13 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___98 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___13 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___13 {
	struct netns_sysctl_ipv6___13 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___13 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___6 *nlsk;
	struct sock___6 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___13 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___13 xfrm4_dst_ops;
	struct dst_ops___13 xfrm6_dst_ops;
};

struct net___14 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___13 sysctls;
	struct sock___6 *rtnl;
	struct sock___6 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___8 *loopback_dev;
	struct netns_core___13 core;
	struct netns_mib mib;
	struct netns_packet___13 packet;
	struct netns_unix___13 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___13 ipv4;
	struct netns_ipv6___13 ipv6;
	struct netns_sctp___13 sctp;
	struct netns_dccp___5 dccp;
	struct netns_nf___13 nf;
	struct netns_xt xt;
	struct netns_ct___13 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___13 nf_frag;
	struct sock___6 *nfnl;
	struct sock___6 *nfnl_stash;
	struct sk_buff_head___7 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___13 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___6 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___6 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___104 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___104 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___6 {
	atomic_t use;
	unsigned int mask;
	struct net_device___8 *physindev;
	struct net_device___8 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___6(struct sk_buff___10 **);

struct net_device_ops___6;

struct ethtool_ops___6;

struct header_ops___6;

struct inet6_dev___4;

struct netdev_rx_queue___6;

struct netdev_queue___6;

struct rtnl_link_ops___5;

struct dcbnl_rtnl_ops___6;

struct net_device___8 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___6 *netdev_ops;
	const struct ethtool_ops___6 *ethtool_ops;
	const struct header_ops___6 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___5 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___4 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___6 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___6 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___6 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___6 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___6 = 0,
		NETREG_REGISTERED___6 = 1,
		NETREG_UNREGISTERING___6 = 2,
		NETREG_UNREGISTERED___6 = 3,
		NETREG_RELEASED___6 = 4,
		NETREG_DUMMY___6 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___6 = 0,
		RTNL_LINK_INITIALIZING___6 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___8 *);
	struct netpoll_info *npinfo;
	struct net___14 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide24;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___89 dev;
	const struct attribute_group___82 *sysfs_groups[4];
	const struct rtnl_link_ops___5 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___6 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___10 {
	struct sk_buff___10 *next;
	struct sk_buff___10 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___6 *sk;
	struct net_device___8 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___10 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___6 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___6 {
	int (*get_settings)(struct net_device___8 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___8 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___8 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___8 *);
	void (*get_regs)(struct net_device___8 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___8 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___8 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___8 *);
	void (*set_msglevel)(struct net_device___8 *, u32);
	int (*nway_reset)(struct net_device___8 *);
	u32 (*get_link)(struct net_device___8 *);
	int (*get_eeprom_len)(struct net_device___8 *);
	int (*get_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___8 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___8 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___8 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___8 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___8 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___8 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___8 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___8 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___8 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___8 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___8 *);
	void (*complete)(struct net_device___8 *);
	u32 (*get_priv_flags)(struct net_device___8 *);
	int (*set_priv_flags)(struct net_device___8 *, u32);
	int (*get_sset_count)(struct net_device___8 *, int);
	int (*get_rxnfc)(struct net_device___8 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___8 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___8 *, struct ethtool_flash *);
	int (*reset)(struct net_device___8 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___8 *);
	int (*get_rxfh_indir)(struct net_device___8 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___8 *, const u32 *);
	void (*get_channels)(struct net_device___8 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___8 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___8 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___8 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___8 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___8 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___8 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___8 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___8 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___8 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___8 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___8 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct inet_peer;

struct inet_peer_base {
	struct inet_peer *root;
	seqlock_t lock;
	u32 flush_seq;
	int total;
};

struct rtable___2;

struct dst_entry___5 {
	struct callback_head callback_head;
	struct dst_entry___5 *child;
	struct net_device___8 *dev;
	struct dst_ops___13 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___5 *path;
	struct dst_entry___5 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___10 *);
	union {
		int (*output)(struct sock___6 *, struct sk_buff___10 *);
		struct {
			int (*output)(struct sk_buff___10 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___5 *next;
		struct rtable___2 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___5;

struct neigh_parms___5;

struct neigh_ops___5;

struct neighbour___5 {
	struct neighbour___5 *next;
	struct neigh_table___5 *tbl;
	struct neigh_parms___5 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___7 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___5 *, struct sk_buff___10 *);
	const struct neigh_ops___5 *ops;
	struct callback_head rcu;
	struct net_device___8 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___13 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___10 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___10 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___14 *, struct dst_entry___5 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___10 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___10 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___6 {
	int (*ieee_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___8 *);
	u8 (*setstate)(struct net_device___8 *, u8);
	void (*getpermhwaddr)(struct net_device___8 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___8 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___8 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___8 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___8 *, int, u8 *);
	void (*setpfccfg)(struct net_device___8 *, int, u8);
	void (*getpfccfg)(struct net_device___8 *, int, u8 *);
	u8 (*setall)(struct net_device___8 *);
	u8 (*getcap)(struct net_device___8 *, int, u8 *);
	int (*getnumtcs)(struct net_device___8 *, int, u8 *);
	int (*setnumtcs)(struct net_device___8 *, int, u8);
	u8 (*getpfcstate)(struct net_device___8 *);
	void (*setpfcstate)(struct net_device___8 *, u8);
	void (*getbcncfg)(struct net_device___8 *, int, u32 *);
	void (*setbcncfg)(struct net_device___8 *, int, u32);
	void (*getbcnrp)(struct net_device___8 *, int, u8 *);
	void (*setbcnrp)(struct net_device___8 *, int, u8);
	u8 (*setapp)(struct net_device___8 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___8 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___8 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___8 *, int, u8);
	u8 (*getdcbx)(struct net_device___8 *);
	u8 (*setdcbx)(struct net_device___8 *, u8);
	int (*peer_getappinfo)(struct net_device___8 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___8 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___8 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___8 *, struct cee_pfc *);
};

struct request_sock_ops___5;

struct request_sock___4 {
	struct sock_common___5 __req_common;
	struct request_sock___4 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___5 *rsk_ops;
	struct sock___6 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___6 {
	struct sk_buff___10 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___10 *, struct netlink_callback___6 *);
	int (*done)(struct netlink_callback___6 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct ifla_vf_info___3 {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	union {
		__u32 max_tx_rate;
		struct {
			__u32 tx_rate;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 rss_query_en;
};

struct header_ops___6 {
	int (*create)(struct sk_buff___10 *, struct net_device___8 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___10 *, unsigned char *);
	int (*rebuild)(struct sk_buff___10 *);
	int (*cache)(const struct neighbour___5 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___8 *, const unsigned char *);
};

struct napi_struct___6 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___6 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___8 *dev;
	struct sk_buff___10 *gro_list;
	struct sk_buff___10 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___6 {
	struct net_device___8 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___5 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___6 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___5 kobj;
	struct net_device___8 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___6 {
	int (*ndo_init)(struct net_device___8 *);
	void (*ndo_uninit)(struct net_device___8 *);
	int (*ndo_open)(struct net_device___8 *);
	int (*ndo_stop)(struct net_device___8 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___10 *, struct net_device___8 *);
	u16 (*ndo_select_queue)(struct net_device___8 *, struct sk_buff___10 *);
	void (*ndo_change_rx_flags)(struct net_device___8 *, int);
	void (*ndo_set_rx_mode)(struct net_device___8 *);
	int (*ndo_set_mac_address)(struct net_device___8 *, void *);
	int (*ndo_validate_addr)(struct net_device___8 *);
	int (*ndo_do_ioctl)(struct net_device___8 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___8 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___8 *, int);
	int (*ndo_neigh_setup)(struct net_device___8 *, struct neigh_parms___5 *);
	void (*ndo_tx_timeout)(struct net_device___8 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___8 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___8 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___8 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___8 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___8 *);
	int (*ndo_netpoll_setup)(struct net_device___8 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___8 *);
	int (*ndo_busy_poll)(struct napi_struct___6 *);
	int (*ndo_set_vf_mac)(struct net_device___8 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___8 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___8 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___8 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___8 *, int, struct ifla_vf_info___3 *);
	int (*ndo_set_vf_link_state)(struct net_device___8 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___8 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___8 *, int, struct sk_buff___10 *);
	int (*ndo_setup_tc)(struct net_device___8 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___8 *);
	int (*ndo_fcoe_disable)(struct net_device___8 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___8 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___8 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___8 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___8 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___8 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___8 *, const struct sk_buff___10 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___8 *, struct net_device___8 *);
	int (*ndo_del_slave)(struct net_device___8 *, struct net_device___8 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___5 *);
	void (*ndo_neigh_destroy)(struct neighbour___5 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___10 *, struct netlink_callback___6 *, struct net_device___8 *, int);
	int (*ndo_bridge_setlink)(struct net_device___8 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___10 *, u32, u32, struct net_device___8 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___8 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___8 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___8 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___8 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___8 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___8 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___10 *, struct net_device___8 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___8 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___8 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___8 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___5 {
	struct net___14 *net;
	struct net_device___8 *dev;
	struct neigh_parms___5 *next;
	int (*neigh_setup)(struct neighbour___5 *);
	void (*neigh_cleanup)(struct neighbour___5 *);
	struct neigh_table___5 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___4;

struct ifacaddr6___4;

struct inet6_dev___4 {
	struct net_device___8 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___4 *mc_list;
	struct ifmcaddr6___4 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___4 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___5 *nd_parms;
	struct inet6_dev___4 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___5 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___8 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___14 *, struct net_device___8 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___8 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___8 *, struct list_head *);
	size_t (*get_size)(const struct net_device___8 *);
	int (*fill_info)(struct sk_buff___10 *, const struct net_device___8 *);
	size_t (*get_xstats_size)(const struct net_device___8 *);
	int (*fill_xstats)(struct sk_buff___10 *, const struct net_device___8 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___14 * (*get_link_net)(const struct net_device___8 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___8 *, struct net_device___8 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___8 *, const struct net_device___8 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___10 *, const struct net_device___8 *, const struct net_device___8 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___6 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___10 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

enum {
	RTAX_UNSPEC = 0,
	RTAX_LOCK = 1,
	RTAX_MTU = 2,
	RTAX_WINDOW = 3,
	RTAX_RTT = 4,
	RTAX_RTTVAR = 5,
	RTAX_SSTHRESH = 6,
	RTAX_CWND = 7,
	RTAX_ADVMSS = 8,
	RTAX_REORDERING = 9,
	RTAX_HOPLIMIT = 10,
	RTAX_INITCWND = 11,
	RTAX_FEATURES = 12,
	RTAX_RTO_MIN = 13,
	RTAX_INITRWND = 14,
	RTAX_QUICKACK = 15,
	RTAX_CC_ALGO = 16,
	RTAX_RESERVED2 = 17,
	RTAX_RESERVED3 = 18,
	RTAX_RESERVED4 = 19,
	RTAX_RESERVED5 = 20,
	RTAX_RESERVED6 = 21,
	RTAX_RESERVED7 = 22,
	RTAX_RESERVED8 = 23,
	__RTAX_MAX = 24,
};

struct pneigh_entry___5;

struct neigh_hash_table___5;

struct neigh_table___5 {
	struct neigh_table___5 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___8 *, __u32 *);
	int (*constructor)(struct neighbour___5 *);
	int (*pconstructor)(struct pneigh_entry___5 *);
	void (*pdestructor)(struct pneigh_entry___5 *);
	void (*proxy_redo)(struct sk_buff___10 *);
	char *id;
	struct neigh_parms___5 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___7 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___5 *nht;
	struct pneigh_entry___5 **phash_buckets;
};

struct neigh_ops___5 {
	int family;
	void (*solicit)(struct neighbour___5 *, struct sk_buff___10 *);
	void (*error_report)(struct neighbour___5 *, struct sk_buff___10 *);
	int (*output)(struct neighbour___5 *, struct sk_buff___10 *);
	int (*connected_output)(struct neighbour___5 *, struct sk_buff___10 *);
};

struct pneigh_entry___5 {
	struct pneigh_entry___5 *next;
	struct net___14 *net;
	struct net_device___8 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___5 {
	struct neighbour___5 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___2 {
	struct dst_entry___5 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___5;

struct proto___5 {
	void (*close)(struct sock___6 *, long int);
	int (*connect)(struct sock___6 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___6 *, int);
	struct sock___6 * (*accept)(struct sock___6 *, int, int *);
	int (*ioctl)(struct sock___6 *, int, long unsigned int);
	int (*init)(struct sock___6 *);
	void (*destroy)(struct sock___6 *);
	void (*shutdown)(struct sock___6 *, int);
	int (*setsockopt)(struct sock___6 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___6 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___6 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___6 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___6 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___8 *, struct sock___6 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___8 *, struct sock___6 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___6 *, struct page___111 *, int, size_t, int);
	int (*bind)(struct sock___6 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___6 *, struct sk_buff___10 *);
	void (*release_cb)(struct sock___6 *);
	void (*mtu_reduced)(struct sock___6 *);
	void (*hash)(struct sock___6 *);
	void (*unhash)(struct sock___6 *);
	void (*rehash)(struct sock___6 *);
	int (*get_port)(struct sock___6 *, short unsigned int);
	void (*clear_sk)(struct sock___6 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___6 *);
	void (*enter_memory_pressure)(struct sock___6 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___98 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___5 *rsk_prot;
	struct timewait_sock_ops___5 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___33 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___5 * (*proto_cgroup)(struct mem_cgroup *);
};

struct request_sock_ops___5 {
	int family;
	int obj_size;
	struct kmem_cache___98 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___6 *, struct request_sock___4 *);
	void (*send_ack)(struct sock___6 *, struct sk_buff___10 *, struct request_sock___4 *);
	void (*send_reset)(struct sock___6 *, struct sk_buff___10 *);
	void (*destructor)(struct request_sock___4 *);
	void (*syn_ack_timeout)(struct sock___6 *, struct request_sock___4 *);
};

struct timewait_sock_ops___5 {
	struct kmem_cache___98 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___6 *, struct sock___6 *, void *);
	void (*twsk_destructor)(struct sock___6 *);
};

enum cg_proto_flags {
	MEMCG_SOCK_ACTIVE = 0,
	MEMCG_SOCK_ACTIVATED = 1,
};

struct ifmcaddr6___4 {
	struct in6_addr mca_addr;
	struct inet6_dev___4 *idev;
	struct ifmcaddr6___4 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___4 {
	struct in6_addr aca_addr;
	struct inet6_dev___4 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___4 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct inetpeer_addr_base {
	union {
		__be32 a4;
		__be32 a6[4];
		struct in6_addr in6;
	};
};

struct inetpeer_addr {
	struct inetpeer_addr_base addr;
	__u16 family;
};

struct inet_peer {
	struct inet_peer *avl_left;
	struct inet_peer *avl_right;
	struct inetpeer_addr daddr;
	__u32 avl_height;
	u32 metrics[23];
	u32 rate_tokens;
	long unsigned int rate_last;
	union {
		struct list_head gc_list;
		struct callback_head gc_rcu;
	};
	union {
		struct {
			atomic_t rid;
			atomic_t ip_id_count;
		};
		struct callback_head rcu;
		struct inet_peer *gc_next;
	};
	__u32 dtime;
	atomic_t refcnt;
};

enum mem_cgroup_stat_index {
	MEM_CGROUP_STAT_CACHE = 0,
	MEM_CGROUP_STAT_RSS = 1,
	MEM_CGROUP_STAT_RSS_HUGE = 2,
	MEM_CGROUP_STAT_FILE_MAPPED = 3,
	MEM_CGROUP_STAT_SWAP = 4,
	MEM_CGROUP_STAT_NSTATS = 5,
};

enum mem_cgroup_events_index {
	MEM_CGROUP_EVENTS_PGPGIN = 0,
	MEM_CGROUP_EVENTS_PGPGOUT = 1,
	MEM_CGROUP_EVENTS_PGFAULT = 2,
	MEM_CGROUP_EVENTS_PGMAJFAULT = 3,
	MEM_CGROUP_EVENTS_NSTATS = 4,
};

enum mem_cgroup_events_target {
	MEM_CGROUP_TARGET_THRESH = 0,
	MEM_CGROUP_TARGET_SOFTLIMIT = 1,
	MEM_CGROUP_TARGET_NUMAINFO = 2,
	MEM_CGROUP_NTARGETS = 3,
};

struct mem_cgroup_reclaim_iter {
	struct mem_cgroup *last_visited;
	long unsigned int last_dead_count;
	unsigned int generation;
};

struct mem_cgroup_per_zone {
	struct lruvec___111 lruvec;
	long unsigned int lru_size[5];
	struct mem_cgroup_reclaim_iter reclaim_iter[13];
	struct rb_node tree_node;
	long long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup *memcg;
};

struct mem_cgroup_per_node {
	struct mem_cgroup_per_zone zoneinfo[4];
};

struct mem_cgroup_tree_per_zone {
	struct rb_root rb_root;
	spinlock_t lock;
};

struct mem_cgroup_tree_per_node {
	struct mem_cgroup_tree_per_zone rb_tree_per_zone[4];
};

struct mem_cgroup_tree {
	struct mem_cgroup_tree_per_node *rb_tree_per_node[1024];
};

struct mem_cgroup_threshold {
	struct eventfd_ctx *eventfd;
	u64 threshold;
};

struct mem_cgroup_threshold_ary {
	int current_threshold;
	unsigned int size;
	struct mem_cgroup_threshold entries[0];
};

struct mem_cgroup_eventfd_list {
	struct list_head list;
	struct eventfd_ctx *eventfd;
};

enum {
	KMEM_ACCOUNTED_ACTIVE = 0,
	KMEM_ACCOUNTED_ACTIVATED = 1,
	KMEM_ACCOUNTED_DEAD = 2,
};

enum move_type___2 {
	MOVE_CHARGE_TYPE_ANON = 0,
	MOVE_CHARGE_TYPE_FILE = 1,
	NR_MOVE_TYPE = 2,
};

struct move_charge_struct {
	spinlock_t lock;
	struct mem_cgroup *from;
	struct mem_cgroup *to;
	long unsigned int immigrate_flags;
	long unsigned int precharge;
	long unsigned int moved_charge;
	long unsigned int moved_swap;
	struct task_struct___103 *moving_task;
	wait_queue_head_t waitq;
};

enum charge_type {
	MEM_CGROUP_CHARGE_TYPE_CACHE = 0,
	MEM_CGROUP_CHARGE_TYPE_ANON = 1,
	MEM_CGROUP_CHARGE_TYPE_SWAPOUT = 2,
	MEM_CGROUP_CHARGE_TYPE_DROP = 3,
	NR_CHARGE_TYPE = 4,
};

enum res_type {
	_MEM = 0,
	_MEMSWAP = 1,
	_OOM_TYPE = 2,
	_KMEM = 3,
};

struct oom_wait_info {
	struct mem_cgroup *memcg;
	wait_queue_t wait;
};

struct memcg_stock_pcp {
	struct mem_cgroup *cached;
	unsigned int nr_pages;
	struct work_struct work;
	long unsigned int flags;
};

enum {
	CHARGE_OK = 0,
	CHARGE_RETRY = 1,
	CHARGE_NOMEM = 2,
	CHARGE_WOULDBLOCK = 3,
};

struct create_work {
	struct mem_cgroup *memcg;
	struct kmem_cache___98 *cachep;
	struct work_struct work;
};

union mc_target {
	struct page___111 *page;
	swp_entry_t ent;
};

enum mc_target_type {
	MC_TARGET_NONE = 0,
	MC_TARGET_PAGE = 1,
	MC_TARGET_SWAP = 2,
};

typedef long unsigned int pao_T_____3;

struct swap_cgroup_ctrl {
	struct page___103 **map;
	long unsigned int length;
	spinlock_t lock;
};

struct swap_cgroup {
	short unsigned int id;
};

enum vmpressure_levels {
	VMPRESSURE_LOW = 0,
	VMPRESSURE_MEDIUM = 1,
	VMPRESSURE_CRITICAL = 2,
	VMPRESSURE_NUM_LEVELS = 3,
};

struct vmpressure_event {
	struct eventfd_ctx *efd;
	enum vmpressure_levels level;
	struct list_head node;
};

struct hugetlb_cgroup___2 {
	struct cgroup_subsys_state___70 css;
	struct res_counter hugepage[2];
};

struct __kfifo {
	unsigned int in;
	unsigned int out;
	unsigned int mask;
	unsigned int esize;
	void *data;
};

struct to_kill {
	struct list_head nd;
	struct task_struct___104 *tsk;
	long unsigned int addr;
	char addr_valid;
};

enum outcome {
	IGNORED = 0,
	FAILED = 1,
	DELAYED = 2,
	RECOVERED = 3,
};

struct page_state {
	long unsigned int mask;
	long unsigned int res;
	char *msg;
	int (*action)(struct page___103 *, long unsigned int);
};

struct memory_failure_entry {
	long unsigned int pfn;
	int trapno;
	int flags;
};

struct memory_failure_cpu {
	struct {
		union {
			struct __kfifo kfifo;
			struct memory_failure_entry *type;
			char (*rectype)[0];
			struct memory_failure_entry *ptr;
			const struct memory_failure_entry *ptr_const;
		};
		struct memory_failure_entry buf[16];
	} fifo;
	spinlock_t lock;
	struct work_struct work;
};

typedef __kernel_ulong_t __kernel_ino_t;

typedef __kernel_ino_t ino_t;

struct cleancache_filekey {
	union {
		ino_t ino;
		__u32 fh[6];
		u32 key[6];
	} u;
};

struct cleancache_ops {
	int (*init_fs)(size_t);
	int (*init_shared_fs)(char *, size_t);
	int (*get_page)(int, struct cleancache_filekey, long unsigned int, struct page___105 *);
	void (*put_page)(int, struct cleancache_filekey, long unsigned int, struct page___105 *);
	void (*invalidate_page)(int, struct cleancache_filekey, long unsigned int);
	void (*invalidate_inode)(int, struct cleancache_filekey);
	void (*invalidate_fs)(int);
};

struct memory_isolate_notify {
	long unsigned int start_pfn;
	unsigned int nr_pages;
	unsigned int pages_found;
};

struct zpool_driver;

struct zpool {
	char *type;
	struct zpool_driver *driver;
	void *pool;
	struct zpool_ops *ops;
	struct list_head list;
};

struct zpool_driver {
	char *type;
	struct module___58 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(gfp_t, struct zpool_ops *);
	void (*destroy)(void *);
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

struct zbud_pool;

struct zbud_ops {
	int (*evict)(struct zbud_pool *, long unsigned int);
};

struct zbud_pool {
	spinlock_t lock;
	struct list_head unbuddied[63];
	struct list_head buddied;
	struct list_head lru;
	u64 pages_nr;
	struct zbud_ops *ops;
};

struct zbud_header {
	struct list_head buddy;
	struct list_head lru;
	unsigned int first_chunks;
	unsigned int last_chunks;
	bool under_reclaim;
};

enum buddy {
	FIRST = 0,
	LAST = 1,
};

enum zs_mapmode {
	ZS_MM_RW = 0,
	ZS_MM_RO = 1,
	ZS_MM_WO = 2,
};

struct zpool_driver___2 {
	char *type;
	struct module *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(gfp_t, struct zpool_ops *);
	void (*destroy)(void *);
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

enum fullness_group {
	ZS_ALMOST_FULL = 0,
	ZS_ALMOST_EMPTY = 1,
	_ZS_NR_FULLNESS_GROUPS = 2,
	ZS_EMPTY = 3,
	ZS_FULL = 4,
};

struct size_class {
	int size;
	unsigned int index;
	int pages_per_zspage;
	spinlock_t lock;
	struct page___105 *fullness_list[2];
};

struct link_free {
	void *next;
};

struct zs_pool {
	struct size_class size_class[255];
	gfp_t flags;
	atomic_long_t pages_allocated;
};

struct mapping_area {
	char *vm_buf;
	char *vm_addr;
	enum zs_mapmode vm_mm;
};

struct page___112;

typedef struct page___112 *pgtable_t___112;

struct address_space___112;

struct kmem_cache___99;

struct page___112 {
	long unsigned int flags;
	struct address_space___112 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___112 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___112 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___99 *slab_cache;
		struct page___112 *first_page;
	};
	long: 64;
};

struct thread_struct___59;

struct task_struct___112;

struct pv_cpu_ops___112 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___59 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___59 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___112 *);
	void (*end_context_switch)(struct task_struct___112 *);
};

struct perf_event___59;

struct thread_struct___59 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___59 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___64;

struct pid_link___64 {
	struct hlist_node node;
	struct pid___64 *pid;
};

struct mutex___113 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___112 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___108 {
	struct page___112 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___117;

struct fs_struct___8;

struct files_struct___4;

struct nsproxy___66;

struct signal_struct___112;

struct backing_dev_info___23;

struct css_set___77;

struct perf_event_context___59;

struct task_struct___112 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___112 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___117 *mm;
	struct mm_struct___117 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___112 *real_parent;
	struct task_struct___112 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___112 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___64 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___112 = 0,
		VTIME_USER___112 = 1,
		VTIME_SYS___112 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___59 thread;
	struct fs_struct___8 *fs;
	struct files_struct___4 *files;
	struct nsproxy___66 *nsproxy;
	struct signal_struct___112 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___23 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___77 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___59 *perf_event_ctxp[2];
	struct mutex___113 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___108 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___117 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___117 *, struct mm_struct___117 *);
	void (*dup_mmap)(struct mm_struct___117 *, struct mm_struct___117 *);
	void (*exit_mmap)(struct mm_struct___117 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___117 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___117 *);
	void (*pgd_free)(struct mm_struct___117 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___117 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___117 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___117 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___117 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___117 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___117 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___117 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___117 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___117 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___117 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___117 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___113 lock;
	void *vdso;
} mm_context_t___113;

struct xol_area___112;

struct uprobes_state___112 {
	struct xol_area___112 *xol_area;
};

struct vm_area_struct___117;

struct file___112;

struct core_state___112;

struct mm_struct___117 {
	struct vm_area_struct___117 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___117 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___117 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___113 context;
	long unsigned int flags;
	struct core_state___112 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___112 *owner;
	struct file___112 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___112 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___59;

struct module_kobject___58 {
	struct kobject___5 kobj;
	struct module___59 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___58;

struct ftrace_event_call___49;

struct module___59 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___58 mkobj;
	struct module_attribute___58 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___49 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___112 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___59 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___112 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___112 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___112 *target;
};

typedef void (*perf_overflow_handler_t___59)(struct perf_event___59 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___59;

typedef void (*ftrace_func_t___59)(long unsigned int, long unsigned int, struct ftrace_ops___59 *, struct pt_regs *);

struct ftrace_ops___59 {
	ftrace_func_t___59 func;
	struct ftrace_ops___59 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___113 regex_lock;
};

struct pmu___59;

struct fasync_struct___112;

struct pid_namespace___64;

struct perf_cgroup___59;

struct perf_event___59 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___59 *group_leader;
	struct pmu___59 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___59 hw;
	struct perf_event_context___59 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___113 child_mutex;
	struct list_head child_list;
	struct perf_event___59 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___112 *owner;
	struct mutex___113 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___112 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___59 *);
	struct callback_head callback_head;
	struct pid_namespace___64 *ns;
	u64 id;
	perf_overflow_handler_t___59 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___49 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___59 ftrace_ops;
	struct perf_cgroup___59 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___112;

struct lruvec___112 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___112 *zone;
};

struct pglist_data___112;

struct zone___112 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___112 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___112 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___112 {
	struct zone___112 *zone;
	int zone_idx;
};

struct zonelist___112 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___112 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___112 {
	struct zone___112 node_zones[4];
	struct zonelist___112 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___112 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___84;

struct x86_io_apic_ops___84 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___84 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___84;

struct irq_data___84 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___84 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___90;

struct dev_pm_ops___90 {
	int (*prepare)(struct device___90 *);
	void (*complete)(struct device___90 *);
	int (*suspend)(struct device___90 *);
	int (*resume)(struct device___90 *);
	int (*freeze)(struct device___90 *);
	int (*thaw)(struct device___90 *);
	int (*poweroff)(struct device___90 *);
	int (*restore)(struct device___90 *);
	int (*suspend_late)(struct device___90 *);
	int (*resume_early)(struct device___90 *);
	int (*freeze_late)(struct device___90 *);
	int (*thaw_early)(struct device___90 *);
	int (*poweroff_late)(struct device___90 *);
	int (*restore_early)(struct device___90 *);
	int (*suspend_noirq)(struct device___90 *);
	int (*resume_noirq)(struct device___90 *);
	int (*freeze_noirq)(struct device___90 *);
	int (*thaw_noirq)(struct device___90 *);
	int (*poweroff_noirq)(struct device___90 *);
	int (*restore_noirq)(struct device___90 *);
	int (*runtime_suspend)(struct device___90 *);
	int (*runtime_resume)(struct device___90 *);
	int (*runtime_idle)(struct device___90 *);
};

struct device_type___90;

struct bus_type___90;

struct device_driver___90;

struct dev_pm_domain___90;

struct class___90;

struct attribute_group___83;

struct device_rh___90;

struct device___90 {
	struct device___90 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___90 *type;
	struct mutex___113 mutex;
	struct bus_type___90 *bus;
	struct device_driver___90 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___90 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___90 *class;
	const struct attribute_group___83 **groups;
	void (*release)(struct device___90 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___90 *device_rh;
};

struct dev_pm_info_rh___90 {
	void (*set_latency_tolerance)(struct device___90 *, s32);
};

struct dev_pm_domain___90 {
	struct dev_pm_ops___90 ops;
};

struct smp_ops___112 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___112 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___112 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___112 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___99;

struct memcg_cache_params___99;

struct kmem_cache___99 {
	struct kmem_cache_cpu___99 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___99 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___112;

struct address_space_operations___112;

struct address_space___112 {
	struct inode___112 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___113 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___112 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___23 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___15;

struct dentry___112;

struct path___112 {
	struct vfsmount___15 *mnt;
	struct dentry___112 *dentry;
};

struct fown_struct___64 {
	rwlock_t lock;
	struct pid___64 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___112;

struct file___112 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___112 f_path;
	struct inode___112 *f_inode;
	const struct file_operations___112 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___64 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___112 *f_mapping;
	struct mutex___113 f_pos_lock;
};

struct vm_operations_struct___100;

struct vm_area_struct___117 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___117 *vm_next;
	struct vm_area_struct___117 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___117 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___100 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___112 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___97;

struct vm_operations_struct___100 {
	void (*open)(struct vm_area_struct___117 *);
	void (*close)(struct vm_area_struct___117 *);
	int (*fault)(struct vm_area_struct___117 *, struct vm_fault___97 *);
	int (*page_mkwrite)(struct vm_area_struct___117 *, struct vm_fault___97 *);
	int (*access)(struct vm_area_struct___117 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___117 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___117 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___117 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___117 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___112 {
	struct task_struct___112 *task;
	struct core_thread___112 *next;
};

struct core_state___112 {
	atomic_t nr_threads;
	struct core_thread___112 dumper;
	struct completion startup;
};

struct vm_fault___97 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___112 *page;
};

struct fd___7 {
	struct file___112 *file;
	unsigned int flags;
};

struct dentry_operations___112;

struct super_block___112;

struct dentry___112 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___112 *d_parent;
	struct qstr d_name;
	struct inode___112 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___112 *d_op;
	struct super_block___112 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___112;

struct file_lock___112;

struct dquot___112;

struct block_device___112;

struct cdev___34;

struct inode___112 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___112 *i_op;
	struct super_block___112 *i_sb;
	struct address_space___112 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___113 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___112 *i_fop;
	struct file_lock___112 *i_flock;
	struct address_space___112 i_data;
	struct dquot___112 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___112 *i_bdev;
		struct cdev___34 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___112 {
	int (*d_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_hash)(const struct dentry___112 *, struct qstr *);
	int (*d_compare)(const struct dentry___112 *, const struct dentry___112 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___112 *);
	void (*d_release)(struct dentry___112 *);
	void (*d_prune)(struct dentry___112 *);
	void (*d_iput)(struct dentry___112 *, struct inode___112 *);
	char * (*d_dname)(struct dentry___112 *, char *, int);
	struct vfsmount___15 * (*d_automount)(struct path___112 *);
	int (*d_manage)(struct dentry___112 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___112;

struct mem_dqinfo___112 {
	struct quota_format_type___112 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___112;

struct quota_info___112 {
	unsigned int flags;
	struct mutex___113 dqio_mutex;
	struct mutex___113 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___112 *files[2];
	struct mem_dqinfo___112 info[2];
	const struct quota_format_ops___112 *ops[2];
};

struct file_system_type___112;

struct super_operations___112;

struct dquot_operations___112;

struct quotactl_ops___112;

struct xattr_handler___77;

struct super_block___112 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___112 *s_type;
	const struct super_operations___112 *s_op;
	const struct dquot_operations___112 *dq_op;
	const struct quotactl_ops___112 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___112 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___77 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___112 *s_bdev;
	struct backing_dev_info___23 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___112 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___113 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___112 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___15 {
	struct dentry___112 *mnt_root;
	struct super_block___112 *mnt_sb;
	int mnt_flags;
};

struct upid___64 {
	int nr;
	struct pid_namespace___64 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___64 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___112 *child_reaper;
	struct kmem_cache___99 *pid_cachep;
	unsigned int level;
	struct pid_namespace___64 *parent;
	struct vfsmount___15 *proc_mnt;
	struct dentry___112 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___64 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___64 numbers[1];
};

struct block_device___112 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___112 *bd_inode;
	struct super_block___112 *bd_super;
	struct mutex___113 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___112 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___113 bd_fsfreeze_mutex;
};

struct cgroup___77;

struct cgroup_subsys_state___78 {
	struct cgroup___77 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___112 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___112 *ia_file;
};

struct dquot___112 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___113 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___112 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___112 {
	int qf_fmt_id;
	const struct quota_format_ops___112 *qf_ops;
	struct module___59 *qf_owner;
	struct quota_format_type___112 *qf_next;
};

struct quota_format_ops___112 {
	int (*check_quota_file)(struct super_block___112 *, int);
	int (*read_file_info)(struct super_block___112 *, int);
	int (*write_file_info)(struct super_block___112 *, int);
	int (*free_file_info)(struct super_block___112 *, int);
	int (*read_dqblk)(struct dquot___112 *);
	int (*commit_dqblk)(struct dquot___112 *);
	int (*release_dqblk)(struct dquot___112 *);
};

struct dquot_operations___112 {
	int (*write_dquot)(struct dquot___112 *);
	struct dquot___112 * (*alloc_dquot)(struct super_block___112 *, int);
	void (*destroy_dquot)(struct dquot___112 *);
	int (*acquire_dquot)(struct dquot___112 *);
	int (*release_dquot)(struct dquot___112 *);
	int (*mark_dirty)(struct dquot___112 *);
	int (*write_info)(struct super_block___112 *, int);
	qsize_t * (*get_reserved_space)(struct inode___112 *);
};

struct quotactl_ops___112 {
	int (*quota_on)(struct super_block___112 *, int, int, struct path___112 *);
	int (*quota_on_meta)(struct super_block___112 *, int, int);
	int (*quota_off)(struct super_block___112 *, int);
	int (*quota_sync)(struct super_block___112 *, int);
	int (*get_info)(struct super_block___112 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___112 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___112 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___112 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___112 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___112 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___112 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___112 *, unsigned int);
};

struct address_space_operations___112 {
	int (*writepage)(struct page___112 *, struct writeback_control *);
	int (*readpage)(struct file___112 *, struct page___112 *);
	int (*writepages)(struct address_space___112 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___112 *);
	int (*readpages)(struct file___112 *, struct address_space___112 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___112 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___112 **, void **);
	int (*write_end)(struct file___112 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___112 *, void *);
	sector_t (*bmap)(struct address_space___112 *, sector_t);
	void (*invalidatepage)(struct page___112 *, long unsigned int);
	int (*releasepage)(struct page___112 *, gfp_t);
	void (*freepage)(struct page___112 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___112 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___112 *, struct page___112 *, struct page___112 *, enum migrate_mode);
	int (*launder_page)(struct page___112 *);
	int (*is_partially_uptodate)(struct page___112 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___112 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___112 *, struct page___112 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___112 *, sector_t *);
	void (*swap_deactivate)(struct file___112 *);
	void (*invalidatepage_range)(struct page___112 *, unsigned int, unsigned int);
};

struct bdi_writeback___23 {
	struct backing_dev_info___23 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___23 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___23 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___90 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___112 *debug_dir;
	struct dentry___112 *debug_stats;
};

struct cdev___34 {
	struct kobject___5 kobj;
	struct module___59 *owner;
	const struct file_operations___112 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct nameidata___8;

struct inode_operations___112 {
	struct dentry___112 * (*lookup)(struct inode___112 *, struct dentry___112 *, unsigned int);
	void * (*follow_link)(struct dentry___112 *, struct nameidata___8 *);
	int (*permission)(struct inode___112 *, int);
	struct posix_acl * (*get_acl)(struct inode___112 *, int);
	int (*readlink)(struct dentry___112 *, char *, int);
	void (*put_link)(struct dentry___112 *, struct nameidata___8 *, void *);
	int (*create)(struct inode___112 *, struct dentry___112 *, umode_t, bool);
	int (*link)(struct dentry___112 *, struct inode___112 *, struct dentry___112 *);
	int (*unlink)(struct inode___112 *, struct dentry___112 *);
	int (*symlink)(struct inode___112 *, struct dentry___112 *, const char *);
	int (*mkdir)(struct inode___112 *, struct dentry___112 *, umode_t);
	int (*rmdir)(struct inode___112 *, struct dentry___112 *);
	int (*mknod)(struct inode___112 *, struct dentry___112 *, umode_t, dev_t);
	int (*rename)(struct inode___112 *, struct dentry___112 *, struct inode___112 *, struct dentry___112 *);
	int (*setattr)(struct dentry___112 *, struct iattr___112 *);
	int (*getattr)(struct vfsmount___15 *, struct dentry___112 *, struct kstat *);
	int (*setxattr)(struct dentry___112 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___112 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___112 *, char *, size_t);
	int (*removexattr)(struct dentry___112 *, const char *);
	int (*fiemap)(struct inode___112 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___112 *, struct timespec *, int);
	int (*atomic_open)(struct inode___112 *, struct dentry___112 *, struct file___112 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___4 *fl_owner_t___4;

struct poll_table_struct___72;

struct seq_file___86;

struct file_operations___112 {
	struct module___59 *owner;
	loff_t (*llseek)(struct file___112 *, loff_t, int);
	ssize_t (*read)(struct file___112 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___112 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___112 *, void *, filldir_t);
	unsigned int (*poll)(struct file___112 *, struct poll_table_struct___72 *);
	long int (*unlocked_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___112 *, struct vm_area_struct___117 *);
	int (*open)(struct inode___112 *, struct file___112 *);
	int (*flush)(struct file___112 *, fl_owner_t___4);
	int (*release)(struct inode___112 *, struct file___112 *);
	int (*fsync)(struct file___112 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___112 *, int);
	int (*lock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*sendpage)(struct file___112 *, struct page___112 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___112 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___112 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___112 *, long int, struct file_lock___112 **, void **);
		struct {
			int (*setlease)(struct file___112 *, long int, struct file_lock___112 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___112 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___86 *, struct file___112 *);
};

struct file_lock_operations___112;

struct lock_manager_operations___112;

struct file_lock___112 {
	struct file_lock___112 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___4 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___64 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___112 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___112 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___112 *fl_ops;
	const struct lock_manager_operations___112 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___4 {
	unsigned int max_fds;
	struct file___112 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___4 {
	atomic_t count;
	struct fdtable___4 *fdt;
	struct fdtable___4 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___112 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___112 {
	void (*fl_copy_lock)(struct file_lock___112 *, struct file_lock___112 *);
	void (*fl_release_private)(struct file_lock___112 *);
};

struct lock_manager_operations___112 {
	int (*lm_compare_owner)(struct file_lock___112 *, struct file_lock___112 *);
	long unsigned int (*lm_owner_key)(struct file_lock___112 *);
	void (*lm_notify)(struct file_lock___112 *);
	int (*lm_grant)(struct file_lock___112 *, struct file_lock___112 *, int);
	void (*lm_break)(struct file_lock___112 *);
	int (*lm_change)(struct file_lock___112 **, int);
};

struct fasync_struct___112 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___112 *fa_next;
	struct file___112 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___112 {
	const char *name;
	int fs_flags;
	struct dentry___112 * (*mount)(struct file_system_type___112 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___112 *);
	struct module___59 *owner;
	struct file_system_type___112 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___112 {
	struct inode___112 * (*alloc_inode)(struct super_block___112 *);
	void (*destroy_inode)(struct inode___112 *);
	void (*dirty_inode)(struct inode___112 *, int);
	int (*write_inode)(struct inode___112 *, struct writeback_control *);
	int (*drop_inode)(struct inode___112 *);
	void (*evict_inode)(struct inode___112 *);
	void (*put_super)(struct super_block___112 *);
	int (*sync_fs)(struct super_block___112 *, int);
	int (*freeze_fs)(struct super_block___112 *);
	int (*unfreeze_fs)(struct super_block___112 *);
	int (*statfs)(struct dentry___112 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___112 *, int *, char *);
	void (*umount_begin)(struct super_block___112 *);
	int (*show_options)(struct seq_file___86 *, struct dentry___112 *);
	int (*show_devname)(struct seq_file___86 *, struct dentry___112 *);
	int (*show_path)(struct seq_file___86 *, struct dentry___112 *);
	int (*show_stats)(struct seq_file___86 *, struct dentry___112 *);
	ssize_t (*quota_read)(struct super_block___112 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___112 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___112 *);
	int (*bdev_try_to_free_page)(struct super_block___112 *, struct page___112 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___112 *);
	void (*free_cached_objects)(struct super_block___112 *, int);
};

struct xattr_handler___77 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___112 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___112 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___112 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___74)(struct file___112 *, wait_queue_head_t *, struct poll_table_struct___72 *);

struct poll_table_struct___72 {
	poll_queue_proc___74 _qproc;
	long unsigned int _key;
};

struct seq_operations___85;

struct seq_file___86 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___113 lock;
	const struct seq_operations___85 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___8 {
	struct path___112 path;
	struct qstr last;
	struct path___112 root;
	struct inode___112 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

typedef int (*iop_dentry_open_t)(struct dentry___112 *, struct file___112 *, const struct cred *);

struct inode_operations_wrapper___2 {
	struct inode_operations___112 ops;
	unsigned int version;
	int (*rename2)(struct inode___112 *, struct dentry___112 *, struct inode___112 *, struct dentry___112 *, unsigned int);
	int (*dentry_open)(struct dentry___112 *, struct file___112 *, const struct cred *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	FILE_CREATED = 1,
	FILE_OPENED = 2,
};

struct nsproxy___66 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___64 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___10;

struct signal_struct___112 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___112 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___112 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___64 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___64 *tty_old_pgrp;
	int leader;
	struct tty_struct___10 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___113 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___10;

struct tty_operations___10;

struct tty_ldisc___10;

struct tty_port___10;

struct tty_struct___10 {
	int magic;
	struct kref kref;
	struct device___90 *dev;
	struct tty_driver___10 *driver;
	const struct tty_operations___10 *ops;
	int index;
	struct mutex___113 ldisc_mutex;
	struct tty_ldisc___10 *ldisc;
	struct mutex___113 atomic_write_lock;
	struct mutex___113 legacy_mutex;
	struct mutex___113 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___64 *pgrp;
	struct pid___64 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___10 *link;
	struct fasync_struct___112 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___10 *port;
	struct ld_semaphore ldisc_sem;
};

struct fs_struct___8 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___112 root;
	struct path___112 pwd;
};

struct css_set___77 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___78 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___59 {
	struct pmu___59 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___113 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___112 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___59 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___83;

struct attribute_group___83 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___83 **bin_attrs;
};

struct bin_attribute___83 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___112 *, struct kobject___5 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___112 *, struct kobject___5 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	int (*mmap)(struct file___112 *, struct kobject___5 *, struct bin_attribute___83 *, struct vm_area_struct___117 *);
};

struct kmem_cache_cpu___99 {
	void **freelist;
	long unsigned int tid;
	struct page___112 *page;
	struct page___112 *partial;
};

struct memcg_cache_params___99 {
	bool is_root_cache;
	union {
		struct kmem_cache___99 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___99 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct module_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___58 *, struct module_kobject___58 *, char *);
	ssize_t (*store)(struct module_attribute___58 *, struct module_kobject___58 *, const char *, size_t);
	void (*setup)(struct module___59 *, const char *);
	int (*test)(struct module___59 *);
	void (*free)(struct module___59 *);
};

struct trace_event_functions___49;

struct trace_event___49 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___49 *funcs;
};

struct ftrace_event_class___49;

struct ftrace_event_call___49 {
	struct list_head list;
	struct ftrace_event_class___49 *class;
	char *name;
	struct trace_event___49 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct tty_operations___10 {
	struct tty_struct___10 * (*lookup)(struct tty_driver___10 *, struct inode___112 *, int);
	int (*install)(struct tty_driver___10 *, struct tty_struct___10 *);
	void (*remove)(struct tty_driver___10 *, struct tty_struct___10 *);
	int (*open)(struct tty_struct___10 *, struct file___112 *);
	void (*close)(struct tty_struct___10 *, struct file___112 *);
	void (*shutdown)(struct tty_struct___10 *);
	void (*cleanup)(struct tty_struct___10 *);
	int (*write)(struct tty_struct___10 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___10 *, unsigned char);
	void (*flush_chars)(struct tty_struct___10 *);
	int (*write_room)(struct tty_struct___10 *);
	int (*chars_in_buffer)(struct tty_struct___10 *);
	int (*ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	void (*throttle)(struct tty_struct___10 *);
	void (*unthrottle)(struct tty_struct___10 *);
	void (*stop)(struct tty_struct___10 *);
	void (*start)(struct tty_struct___10 *);
	void (*hangup)(struct tty_struct___10 *);
	int (*break_ctl)(struct tty_struct___10 *, int);
	void (*flush_buffer)(struct tty_struct___10 *);
	void (*set_ldisc)(struct tty_struct___10 *);
	void (*wait_until_sent)(struct tty_struct___10 *, int);
	void (*send_xchar)(struct tty_struct___10 *, char);
	int (*tiocmget)(struct tty_struct___10 *);
	int (*tiocmset)(struct tty_struct___10 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___10 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___10 *, struct termiox *);
	int (*get_icount)(struct tty_struct___10 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___10 *, int, char *);
	int (*poll_get_char)(struct tty_driver___10 *, int);
	void (*poll_put_char)(struct tty_driver___10 *, int, char);
	const struct file_operations___112 *proc_fops;
};

struct tty_driver___10 {
	int magic;
	struct kref kref;
	struct cdev___34 *cdevs;
	struct module___59 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___10 *other;
	struct tty_struct___10 **ttys;
	struct tty_port___10 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___10 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___10;

struct tty_port___10 {
	struct tty_bufhead buf;
	struct tty_struct___10 *tty;
	struct tty_struct___10 *itty;
	const struct tty_port_operations___10 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___113 mutex;
	struct mutex___113 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___10 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___10 *);
	void (*close)(struct tty_struct___10 *);
	void (*flush_buffer)(struct tty_struct___10 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___10 *);
	ssize_t (*read)(struct tty_struct___10 *, struct file___112 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___10 *, struct file___112 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___10 *, struct file___112 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___10 *, struct file___112 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___10 *, struct file___112 *, struct poll_table_struct___72 *);
	int (*hangup)(struct tty_struct___10 *);
	void (*receive_buf)(struct tty_struct___10 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___10 *);
	void (*dcd_change)(struct tty_struct___10 *, unsigned int);
	struct module___59 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___10 *, int);
};

struct tty_ldisc___10 {
	struct tty_ldisc_ops___10 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___10 *tty;
};

struct tty_port_operations___10 {
	int (*carrier_raised)(struct tty_port___10 *);
	void (*dtr_rts)(struct tty_port___10 *, int);
	void (*shutdown)(struct tty_port___10 *);
	void (*drop)(struct tty_port___10 *);
	int (*activate)(struct tty_port___10 *, struct tty_struct___10 *);
	void (*destruct)(struct tty_port___10 *);
};

struct irq_chip___84 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___84 *);
	void (*irq_shutdown)(struct irq_data___84 *);
	void (*irq_enable)(struct irq_data___84 *);
	void (*irq_disable)(struct irq_data___84 *);
	void (*irq_ack)(struct irq_data___84 *);
	void (*irq_mask)(struct irq_data___84 *);
	void (*irq_mask_ack)(struct irq_data___84 *);
	void (*irq_unmask)(struct irq_data___84 *);
	void (*irq_eoi)(struct irq_data___84 *);
	int (*irq_set_affinity)(struct irq_data___84 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___84 *);
	int (*irq_set_type)(struct irq_data___84 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___84 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___84 *);
	void (*irq_bus_sync_unlock)(struct irq_data___84 *);
	void (*irq_cpu_online)(struct irq_data___84 *);
	void (*irq_cpu_offline)(struct irq_data___84 *);
	void (*irq_suspend)(struct irq_data___84 *);
	void (*irq_resume)(struct irq_data___84 *);
	void (*irq_pm_shutdown)(struct irq_data___84 *);
	void (*irq_print_chip)(struct irq_data___84 *, struct seq_file___86 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___84 *, void *);
	long unsigned int flags;
};

struct seq_operations___85 {
	void * (*start)(struct seq_file___86 *, loff_t *);
	void (*stop)(struct seq_file___86 *, void *);
	void * (*next)(struct seq_file___86 *, void *, loff_t *);
	int (*show)(struct seq_file___86 *, void *);
};

typedef s32 compat_off_t;

struct bus_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___90 *, char *);
	ssize_t (*store)(struct bus_type___90 *, const char *, size_t);
};

struct device_attribute___90;

struct driver_attribute___90;

struct bus_type___90 {
	const char *name;
	const char *dev_name;
	struct device___90 *dev_root;
	struct bus_attribute___90 *bus_attrs;
	struct device_attribute___90 *dev_attrs;
	struct driver_attribute___90 *drv_attrs;
	const struct attribute_group___83 **bus_groups;
	const struct attribute_group___83 **dev_groups;
	const struct attribute_group___83 **drv_groups;
	int (*match)(struct device___90 *, struct device_driver___90 *);
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	int (*probe)(struct device___90 *);
	int (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*online)(struct device___90 *);
	int (*offline)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct device___90 *, struct device_attribute___90 *, char *);
	ssize_t (*store)(struct device___90 *, struct device_attribute___90 *, const char *, size_t);
};

struct driver_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___90 *, char *);
	ssize_t (*store)(struct device_driver___90 *, const char *, size_t);
};

struct device_driver___90 {
	const char *name;
	struct bus_type___90 *bus;
	struct module___59 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___90 *);
	int (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	const struct attribute_group___83 **groups;
	const struct dev_pm_ops___90 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___90 {
	const char *name;
	const struct attribute_group___83 **groups;
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
};

struct class_attribute___90;

struct class___90 {
	const char *name;
	struct module___59 *owner;
	struct class_attribute___90 *class_attrs;
	struct device_attribute___90 *dev_attrs;
	const struct attribute_group___83 **dev_groups;
	struct bin_attribute___83 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *);
	void (*class_release)(struct class___90 *);
	void (*dev_release)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
	struct subsys_private *p;
};

struct class_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct class___90 *, struct class_attribute___90 *, char *);
	ssize_t (*store)(struct class___90 *, struct class_attribute___90 *, const char *, size_t);
	const void * (*namespace)(struct class___90 *, const struct class_attribute___90 *);
};

struct device_rh___90 {
	struct dev_pm_info_rh___90 power;
};

struct cgroupfs_root___77;

struct cgroup___77 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___77 *parent;
	struct dentry___112 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___78 *subsys[11];
	struct cgroupfs_root___77 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___113 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___77 {
	struct super_block___112 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___77 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___59;

struct pmu___59 {
	struct list_head entry;
	struct device___90 *dev;
	const struct attribute_group___83 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___59 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___59 *);
	void (*pmu_disable)(struct pmu___59 *);
	int (*event_init)(struct perf_event___59 *);
	int (*add)(struct perf_event___59 *, int);
	void (*del)(struct perf_event___59 *, int);
	void (*start)(struct perf_event___59 *, int);
	void (*stop)(struct perf_event___59 *, int);
	void (*read)(struct perf_event___59 *);
	void (*start_txn)(struct pmu___59 *);
	int (*commit_txn)(struct pmu___59 *);
	void (*cancel_txn)(struct pmu___59 *);
	int (*event_idx)(struct perf_event___59 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___59 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___59 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___59 *);
};

struct perf_cpu_context___59 {
	struct perf_event_context___59 ctx;
	struct perf_event_context___59 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___59 *unique_pmu;
	struct perf_cgroup___59 *cgrp;
};

struct perf_cgroup___59 {
	struct cgroup_subsys_state___78 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___49 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___113 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___49)(struct trace_iterator___49 *, int, struct trace_event___49 *);

struct trace_event_functions___49 {
	trace_print_func___49 trace;
	trace_print_func___49 raw;
	trace_print_func___49 hex;
	trace_print_func___49 binary;
};

struct ftrace_event_class___49 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___49 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___49 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___49 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___49 *);
};

struct syscall_metadata___19 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___49 *enter_event;
	struct ftrace_event_call___49 *exit_event;
};

struct open_flags {
	int open_flag;
	umode_t mode;
	int acc_mode;
	int intent;
};

typedef __kernel_long_t __kernel_off_t;

typedef __kernel_off_t off_t;

struct fd___8 {
	struct file___105 *file;
	unsigned int flags;
};

typedef s32 compat_ssize_t;

typedef ssize_t (*io_fn_t)(struct file___105 *, char *, size_t, loff_t *);

typedef ssize_t (*iov_fn_t)(struct kiocb___7 *, const struct iovec *, long unsigned int, loff_t);

struct page___113;

typedef struct page___113 *pgtable_t___113;

struct address_space___113;

struct kmem_cache___100;

struct page___113 {
	long unsigned int flags;
	struct address_space___113 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___113 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___113 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___100 *slab_cache;
		struct page___113 *first_page;
	};
	long: 64;
};

struct task_struct___113;

struct pv_cpu_ops___113 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___59 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___59 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___113 *);
	void (*end_context_switch)(struct task_struct___113 *);
};

struct mutex___114 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___113 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___109 {
	struct page___113 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___118;

struct files_struct___5;

struct signal_struct___113;

struct task_struct___113 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___113 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___118 *mm;
	struct mm_struct___118 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___113 *real_parent;
	struct task_struct___113 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___113 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___64 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___113 = 0,
		VTIME_USER___113 = 1,
		VTIME_SYS___113 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___59 thread;
	struct fs_struct *fs;
	struct files_struct___5 *files;
	struct nsproxy *nsproxy;
	struct signal_struct___113 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___114 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___109 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___118 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___118 *, struct mm_struct___118 *);
	void (*dup_mmap)(struct mm_struct___118 *, struct mm_struct___118 *);
	void (*exit_mmap)(struct mm_struct___118 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___118 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___118 *);
	void (*pgd_free)(struct mm_struct___118 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___118 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___118 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___118 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___118 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___118 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___118 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___118 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___118 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___118 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___118 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___118 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___114 lock;
	void *vdso;
} mm_context_t___114;

struct xol_area___113;

struct uprobes_state___113 {
	struct xol_area___113 *xol_area;
};

struct vm_area_struct___118;

struct file___113;

struct core_state___113;

struct mm_struct___118 {
	struct vm_area_struct___118 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___118 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___118 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___114 context;
	long unsigned int flags;
	struct core_state___113 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___113 *owner;
	struct file___113 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___113 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___60;

struct exec_domain___30 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___60 *module;
	struct exec_domain___30 *next;
};

struct module_kobject___59 {
	struct kobject___5 kobj;
	struct module___60 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___59;

struct module___60 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___59 mkobj;
	struct module_attribute___59 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___113 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___59 {
	struct task_struct___113 *task;
	struct exec_domain___30 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___113;

struct lruvec___113 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___113 *zone;
};

struct pglist_data___113;

struct zone___113 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___113 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___113 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___113 {
	struct zone___113 *zone;
	int zone_idx;
};

struct zonelist___113 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___113 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___113 {
	struct zone___113 node_zones[4];
	struct zonelist___113 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___113 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___113 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___113 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vfsmount___16;

struct dentry___113;

struct path___113 {
	struct vfsmount___16 *mnt;
	struct dentry___113 *dentry;
};

struct inode___113;

struct file_operations___113;

struct file___113 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___113 f_path;
	struct inode___113 *f_inode;
	const struct file_operations___113 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___64 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___113 *f_mapping;
	struct mutex___114 f_pos_lock;
};

struct vm_area_struct___118 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___118 *vm_next;
	struct vm_area_struct___118 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___118 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___113 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___100 {
	void **freelist;
	long unsigned int tid;
	struct page___113 *page;
	struct page___113 *partial;
};

struct memcg_cache_params___100;

struct kmem_cache___100 {
	struct kmem_cache_cpu___100 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___100 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___100 {
	bool is_root_cache;
	union {
		struct kmem_cache___100 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___100 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___113;

struct super_block___113;

struct dentry___113 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___113 *d_parent;
	struct qstr d_name;
	struct inode___113 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___113 *d_op;
	struct super_block___113 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___113;

struct address_space___113 {
	struct inode___113 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___114 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___113 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___113;

struct file_lock___113;

struct dquot___113;

struct block_device___113;

struct cdev___35;

struct inode___113 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___113 *i_op;
	struct super_block___113 *i_sb;
	struct address_space___113 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___114 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___113 *i_fop;
	struct file_lock___113 *i_flock;
	struct address_space___113 i_data;
	struct dquot___113 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___113 *i_bdev;
		struct cdev___35 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___113 {
	int (*d_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_hash)(const struct dentry___113 *, struct qstr *);
	int (*d_compare)(const struct dentry___113 *, const struct dentry___113 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___113 *);
	void (*d_release)(struct dentry___113 *);
	void (*d_prune)(struct dentry___113 *);
	void (*d_iput)(struct dentry___113 *, struct inode___113 *);
	char * (*d_dname)(struct dentry___113 *, char *, int);
	struct vfsmount___16 * (*d_automount)(struct path___113 *);
	int (*d_manage)(struct dentry___113 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___113;

struct mem_dqinfo___113 {
	struct quota_format_type___113 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___113;

struct quota_info___113 {
	unsigned int flags;
	struct mutex___114 dqio_mutex;
	struct mutex___114 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___113 *files[2];
	struct mem_dqinfo___113 info[2];
	const struct quota_format_ops___113 *ops[2];
};

struct file_system_type___113;

struct super_operations___113;

struct dquot_operations___113;

struct quotactl_ops___113;

struct super_block___113 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___113 *s_type;
	const struct super_operations___113 *s_op;
	const struct dquot_operations___113 *dq_op;
	const struct quotactl_ops___113 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___113 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___113 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___113 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___114 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___113 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___16 {
	struct dentry___113 *mnt_root;
	struct super_block___113 *mnt_sb;
	int mnt_flags;
};

struct block_device___113 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___113 *bd_inode;
	struct super_block___113 *bd_super;
	struct mutex___114 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___113 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___114 bd_fsfreeze_mutex;
};

struct iattr___113 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___113 *ia_file;
};

struct dquot___113 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___114 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___113 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___113 {
	int qf_fmt_id;
	const struct quota_format_ops___113 *qf_ops;
	struct module___60 *qf_owner;
	struct quota_format_type___113 *qf_next;
};

struct quota_format_ops___113 {
	int (*check_quota_file)(struct super_block___113 *, int);
	int (*read_file_info)(struct super_block___113 *, int);
	int (*write_file_info)(struct super_block___113 *, int);
	int (*free_file_info)(struct super_block___113 *, int);
	int (*read_dqblk)(struct dquot___113 *);
	int (*commit_dqblk)(struct dquot___113 *);
	int (*release_dqblk)(struct dquot___113 *);
};

struct dquot_operations___113 {
	int (*write_dquot)(struct dquot___113 *);
	struct dquot___113 * (*alloc_dquot)(struct super_block___113 *, int);
	void (*destroy_dquot)(struct dquot___113 *);
	int (*acquire_dquot)(struct dquot___113 *);
	int (*release_dquot)(struct dquot___113 *);
	int (*mark_dirty)(struct dquot___113 *);
	int (*write_info)(struct super_block___113 *, int);
	qsize_t * (*get_reserved_space)(struct inode___113 *);
};

struct quotactl_ops___113 {
	int (*quota_on)(struct super_block___113 *, int, int, struct path___113 *);
	int (*quota_on_meta)(struct super_block___113 *, int, int);
	int (*quota_off)(struct super_block___113 *, int);
	int (*quota_sync)(struct super_block___113 *, int);
	int (*get_info)(struct super_block___113 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___113 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___113 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___113 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___113 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___113 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___113 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___113 *, unsigned int);
};

struct address_space_operations___113 {
	int (*writepage)(struct page___113 *, struct writeback_control *);
	int (*readpage)(struct file___113 *, struct page___113 *);
	int (*writepages)(struct address_space___113 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___113 *);
	int (*readpages)(struct file___113 *, struct address_space___113 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___113 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___113 **, void **);
	int (*write_end)(struct file___113 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___113 *, void *);
	sector_t (*bmap)(struct address_space___113 *, sector_t);
	void (*invalidatepage)(struct page___113 *, long unsigned int);
	int (*releasepage)(struct page___113 *, gfp_t);
	void (*freepage)(struct page___113 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___113 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___113 *, struct page___113 *, struct page___113 *, enum migrate_mode);
	int (*launder_page)(struct page___113 *);
	int (*is_partially_uptodate)(struct page___113 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___113 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___113 *, struct page___113 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___113 *, sector_t *);
	void (*swap_deactivate)(struct file___113 *);
	void (*invalidatepage_range)(struct page___113 *, unsigned int, unsigned int);
};

struct cdev___35 {
	struct kobject___5 kobj;
	struct module___60 *owner;
	const struct file_operations___113 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___113 {
	struct dentry___113 * (*lookup)(struct inode___113 *, struct dentry___113 *, unsigned int);
	void * (*follow_link)(struct dentry___113 *, struct nameidata *);
	int (*permission)(struct inode___113 *, int);
	struct posix_acl * (*get_acl)(struct inode___113 *, int);
	int (*readlink)(struct dentry___113 *, char *, int);
	void (*put_link)(struct dentry___113 *, struct nameidata *, void *);
	int (*create)(struct inode___113 *, struct dentry___113 *, umode_t, bool);
	int (*link)(struct dentry___113 *, struct inode___113 *, struct dentry___113 *);
	int (*unlink)(struct inode___113 *, struct dentry___113 *);
	int (*symlink)(struct inode___113 *, struct dentry___113 *, const char *);
	int (*mkdir)(struct inode___113 *, struct dentry___113 *, umode_t);
	int (*rmdir)(struct inode___113 *, struct dentry___113 *);
	int (*mknod)(struct inode___113 *, struct dentry___113 *, umode_t, dev_t);
	int (*rename)(struct inode___113 *, struct dentry___113 *, struct inode___113 *, struct dentry___113 *);
	int (*setattr)(struct dentry___113 *, struct iattr___113 *);
	int (*getattr)(struct vfsmount___16 *, struct dentry___113 *, struct kstat *);
	int (*setxattr)(struct dentry___113 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___113 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___113 *, char *, size_t);
	int (*removexattr)(struct dentry___113 *, const char *);
	int (*fiemap)(struct inode___113 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___113 *, struct timespec *, int);
	int (*atomic_open)(struct inode___113 *, struct dentry___113 *, struct file___113 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___5 *fl_owner_t___5;

struct file_operations___113 {
	struct module___60 *owner;
	loff_t (*llseek)(struct file___113 *, loff_t, int);
	ssize_t (*read)(struct file___113 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___113 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___113 *, void *, filldir_t);
	unsigned int (*poll)(struct file___113 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___113 *, struct vm_area_struct___118 *);
	int (*open)(struct inode___113 *, struct file___113 *);
	int (*flush)(struct file___113 *, fl_owner_t___5);
	int (*release)(struct inode___113 *, struct file___113 *);
	int (*fsync)(struct file___113 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___113 *, int);
	int (*lock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*sendpage)(struct file___113 *, struct page___113 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___113 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___113 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___113 *, long int, struct file_lock___113 **, void **);
		struct {
			int (*setlease)(struct file___113 *, long int, struct file_lock___113 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___113 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___113 *);
};

struct fasync_struct___113;

struct file_lock_operations___113;

struct lock_manager_operations___113;

struct file_lock___113 {
	struct file_lock___113 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___5 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___64 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___113 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___113 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___113 *fl_ops;
	const struct lock_manager_operations___113 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___5 {
	unsigned int max_fds;
	struct file___113 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___5 {
	atomic_t count;
	struct fdtable___5 *fdt;
	struct fdtable___5 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___113 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___113 {
	void (*fl_copy_lock)(struct file_lock___113 *, struct file_lock___113 *);
	void (*fl_release_private)(struct file_lock___113 *);
};

struct lock_manager_operations___113 {
	int (*lm_compare_owner)(struct file_lock___113 *, struct file_lock___113 *);
	long unsigned int (*lm_owner_key)(struct file_lock___113 *);
	void (*lm_notify)(struct file_lock___113 *);
	int (*lm_grant)(struct file_lock___113 *, struct file_lock___113 *, int);
	void (*lm_break)(struct file_lock___113 *);
	int (*lm_change)(struct file_lock___113 **, int);
};

struct fasync_struct___113 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___113 *fa_next;
	struct file___113 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___113 {
	const char *name;
	int fs_flags;
	struct dentry___113 * (*mount)(struct file_system_type___113 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___113 *);
	struct module___60 *owner;
	struct file_system_type___113 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___113 {
	struct inode___113 * (*alloc_inode)(struct super_block___113 *);
	void (*destroy_inode)(struct inode___113 *);
	void (*dirty_inode)(struct inode___113 *, int);
	int (*write_inode)(struct inode___113 *, struct writeback_control *);
	int (*drop_inode)(struct inode___113 *);
	void (*evict_inode)(struct inode___113 *);
	void (*put_super)(struct super_block___113 *);
	int (*sync_fs)(struct super_block___113 *, int);
	int (*freeze_fs)(struct super_block___113 *);
	int (*unfreeze_fs)(struct super_block___113 *);
	int (*statfs)(struct dentry___113 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___113 *, int *, char *);
	void (*umount_begin)(struct super_block___113 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___113 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___113 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___113 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___113 *);
	ssize_t (*quota_read)(struct super_block___113 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___113 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___113 *);
	int (*bdev_try_to_free_page)(struct super_block___113 *, struct page___113 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___113 *);
	void (*free_cached_objects)(struct super_block___113 *, int);
};

struct module_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___59 *, struct module_kobject___59 *, char *);
	ssize_t (*store)(struct module_attribute___59 *, struct module_kobject___59 *, const char *, size_t);
	void (*setup)(struct module___60 *, const char *);
	int (*test)(struct module___60 *);
	void (*free)(struct module___60 *);
};

struct xol_area___113 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___113 *page;
	long unsigned int vaddr;
};

struct core_thread___113 {
	struct task_struct___113 *task;
	struct core_thread___113 *next;
};

struct core_state___113 {
	atomic_t nr_threads;
	struct core_thread___113 dumper;
	struct completion startup;
};

struct signal_struct___113 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___113 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___113 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___64 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___64 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___114 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct page___114;

typedef struct page___114 *pgtable_t___114;

struct address_space___114;

struct kmem_cache___101;

struct page___114 {
	long unsigned int flags;
	struct address_space___114 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___114 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___114 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___101 *slab_cache;
		struct page___114 *first_page;
	};
	long: 64;
};

struct task_struct___114;

struct pv_cpu_ops___114 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___59 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___59 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___114 *);
	void (*end_context_switch)(struct task_struct___114 *);
};

struct mutex___115 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___114 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___110 {
	struct page___114 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___119;

struct signal_struct___114;

struct bio_list___16;

struct backing_dev_info___24;

struct io_context___16;

struct task_struct___114 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___114 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___119 *mm;
	struct mm_struct___119 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___114 *real_parent;
	struct task_struct___114 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___114 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___64 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___114 = 0,
		VTIME_USER___114 = 1,
		VTIME_SYS___114 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___59 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___114 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___16 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___24 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___115 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___110 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___119 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___119 *, struct mm_struct___119 *);
	void (*dup_mmap)(struct mm_struct___119 *, struct mm_struct___119 *);
	void (*exit_mmap)(struct mm_struct___119 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___119 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___119 *);
	void (*pgd_free)(struct mm_struct___119 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___119 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___119 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___119 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___119 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___119 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___119 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___119 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___119 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___119 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___119 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___119 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___115 lock;
	void *vdso;
} mm_context_t___115;

struct xol_area___114;

struct uprobes_state___114 {
	struct xol_area___114 *xol_area;
};

struct vm_area_struct___119;

struct file___114;

struct core_state___114;

struct mm_struct___119 {
	struct vm_area_struct___119 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___119 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___119 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___115 context;
	long unsigned int flags;
	struct core_state___114 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___114 *owner;
	struct file___114 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___114 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___114;

struct lruvec___114 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___114 *zone;
};

struct pglist_data___114;

struct zone___114 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___114 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___114 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___114 {
	struct zone___114 *zone;
	int zone_idx;
};

struct zonelist___114 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___114 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___114 {
	struct zone___114 node_zones[4];
	struct zonelist___114 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___114 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___91;

struct dev_pm_ops___91 {
	int (*prepare)(struct device___91 *);
	void (*complete)(struct device___91 *);
	int (*suspend)(struct device___91 *);
	int (*resume)(struct device___91 *);
	int (*freeze)(struct device___91 *);
	int (*thaw)(struct device___91 *);
	int (*poweroff)(struct device___91 *);
	int (*restore)(struct device___91 *);
	int (*suspend_late)(struct device___91 *);
	int (*resume_early)(struct device___91 *);
	int (*freeze_late)(struct device___91 *);
	int (*thaw_early)(struct device___91 *);
	int (*poweroff_late)(struct device___91 *);
	int (*restore_early)(struct device___91 *);
	int (*suspend_noirq)(struct device___91 *);
	int (*resume_noirq)(struct device___91 *);
	int (*freeze_noirq)(struct device___91 *);
	int (*thaw_noirq)(struct device___91 *);
	int (*poweroff_noirq)(struct device___91 *);
	int (*restore_noirq)(struct device___91 *);
	int (*runtime_suspend)(struct device___91 *);
	int (*runtime_resume)(struct device___91 *);
	int (*runtime_idle)(struct device___91 *);
};

struct device_type___91;

struct bus_type___91;

struct device_driver___91;

struct dev_pm_domain___91;

struct class___91;

struct attribute_group___84;

struct device_rh___91;

struct device___91 {
	struct device___91 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___91 *type;
	struct mutex___115 mutex;
	struct bus_type___91 *bus;
	struct device_driver___91 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___91 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___91 *class;
	const struct attribute_group___84 **groups;
	void (*release)(struct device___91 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___91 *device_rh;
};

struct dev_pm_info_rh___91 {
	void (*set_latency_tolerance)(struct device___91 *, s32);
};

struct dev_pm_domain___91 {
	struct dev_pm_ops___91 ops;
};

struct smp_ops___114 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___114 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___84;

struct attribute_group___84 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___84 **bin_attrs;
};

struct bin_attribute___84 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___114 *, struct kobject___5 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___114 *, struct kobject___5 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	int (*mmap)(struct file___114 *, struct kobject___5 *, struct bin_attribute___84 *, struct vm_area_struct___119 *);
};

struct vfsmount___17;

struct dentry___114;

struct path___114 {
	struct vfsmount___17 *mnt;
	struct dentry___114 *dentry;
};

struct inode___114;

struct file_operations___114;

struct file___114 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___114 f_path;
	struct inode___114 *f_inode;
	const struct file_operations___114 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___64 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___114 *f_mapping;
	struct mutex___115 f_pos_lock;
};

struct vm_operations_struct___101;

struct vm_area_struct___119 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___119 *vm_next;
	struct vm_area_struct___119 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___119 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___101 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___114 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___101 {
	void **freelist;
	long unsigned int tid;
	struct page___114 *page;
	struct page___114 *partial;
};

struct memcg_cache_params___101;

struct kmem_cache___101 {
	struct kmem_cache_cpu___101 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___101 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___101 {
	bool is_root_cache;
	union {
		struct kmem_cache___101 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___101 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___114 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___114 *page;
	long unsigned int vaddr;
};

struct address_space_operations___114;

struct address_space___114 {
	struct inode___114 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___115 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___114 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___24 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___98;

struct vm_operations_struct___101 {
	void (*open)(struct vm_area_struct___119 *);
	void (*close)(struct vm_area_struct___119 *);
	int (*fault)(struct vm_area_struct___119 *, struct vm_fault___98 *);
	int (*page_mkwrite)(struct vm_area_struct___119 *, struct vm_fault___98 *);
	int (*access)(struct vm_area_struct___119 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___119 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___119 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___119 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___119 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___114 {
	struct task_struct___114 *task;
	struct core_thread___114 *next;
};

struct core_state___114 {
	atomic_t nr_threads;
	struct core_thread___114 dumper;
	struct completion startup;
};

struct signal_struct___114 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___114 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___114 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___64 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___64 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___115 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___17;

struct bio_list___16 {
	struct bio___17 *head;
	struct bio___17 *tail;
};

struct bdi_writeback___24 {
	struct backing_dev_info___24 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___24 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___24 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___91 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___114 *debug_dir;
	struct dentry___114 *debug_stats;
};

struct io_cq___16;

struct io_context___16 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___16 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bus_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___91 *, char *);
	ssize_t (*store)(struct bus_type___91 *, const char *, size_t);
};

struct device_attribute___91;

struct driver_attribute___91;

struct bus_type___91 {
	const char *name;
	const char *dev_name;
	struct device___91 *dev_root;
	struct bus_attribute___91 *bus_attrs;
	struct device_attribute___91 *dev_attrs;
	struct driver_attribute___91 *drv_attrs;
	const struct attribute_group___84 **bus_groups;
	const struct attribute_group___84 **dev_groups;
	const struct attribute_group___84 **drv_groups;
	int (*match)(struct device___91 *, struct device_driver___91 *);
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	int (*probe)(struct device___91 *);
	int (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*online)(struct device___91 *);
	int (*offline)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct device___91 *, struct device_attribute___91 *, char *);
	ssize_t (*store)(struct device___91 *, struct device_attribute___91 *, const char *, size_t);
};

struct driver_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___91 *, char *);
	ssize_t (*store)(struct device_driver___91 *, const char *, size_t);
};

struct device_driver___91 {
	const char *name;
	struct bus_type___91 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___91 *);
	int (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	const struct attribute_group___84 **groups;
	const struct dev_pm_ops___91 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___91 {
	const char *name;
	const struct attribute_group___84 **groups;
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
};

struct class_attribute___91;

struct class___91 {
	const char *name;
	struct module *owner;
	struct class_attribute___91 *class_attrs;
	struct device_attribute___91 *dev_attrs;
	const struct attribute_group___84 **dev_groups;
	struct bin_attribute___84 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *);
	void (*class_release)(struct class___91 *);
	void (*dev_release)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
	struct subsys_private *p;
};

struct class_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct class___91 *, struct class_attribute___91 *, char *);
	ssize_t (*store)(struct class___91 *, struct class_attribute___91 *, const char *, size_t);
	const void * (*namespace)(struct class___91 *, const struct class_attribute___91 *);
};

struct device_rh___91 {
	struct dev_pm_info_rh___91 power;
};

struct dentry_operations___114;

struct super_block___114;

struct dentry___114 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___114 *d_parent;
	struct qstr d_name;
	struct inode___114 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___114 *d_op;
	struct super_block___114 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___114;

struct file_lock___114;

struct dquot___114;

struct block_device___114;

struct inode___114 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___114 *i_op;
	struct super_block___114 *i_sb;
	struct address_space___114 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___115 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___114 *i_fop;
	struct file_lock___114 *i_flock;
	struct address_space___114 i_data;
	struct dquot___114 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___114 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___114 {
	int (*d_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_hash)(const struct dentry___114 *, struct qstr *);
	int (*d_compare)(const struct dentry___114 *, const struct dentry___114 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___114 *);
	void (*d_release)(struct dentry___114 *);
	void (*d_prune)(struct dentry___114 *);
	void (*d_iput)(struct dentry___114 *, struct inode___114 *);
	char * (*d_dname)(struct dentry___114 *, char *, int);
	struct vfsmount___17 * (*d_automount)(struct path___114 *);
	int (*d_manage)(struct dentry___114 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___114;

struct mem_dqinfo___114 {
	struct quota_format_type___114 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___114;

struct quota_info___114 {
	unsigned int flags;
	struct mutex___115 dqio_mutex;
	struct mutex___115 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___114 *files[2];
	struct mem_dqinfo___114 info[2];
	const struct quota_format_ops___114 *ops[2];
};

struct file_system_type___114;

struct super_operations___114;

struct dquot_operations___114;

struct quotactl_ops___114;

struct export_operations___4;

struct super_block___114 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___114 *s_type;
	const struct super_operations___114 *s_op;
	const struct dquot_operations___114 *dq_op;
	const struct quotactl_ops___114 *s_qcop;
	const struct export_operations___4 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___114 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___114 *s_bdev;
	struct backing_dev_info___24 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___114 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___115 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___114 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___17 {
	struct dentry___114 *mnt_root;
	struct super_block___114 *mnt_sb;
	int mnt_flags;
};

typedef void bio_end_io_t___17(struct bio___17 *, int);

struct bio_vec___17 {
	struct page___114 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___17;

struct bio_set___17;

struct bio___17 {
	sector_t bi_sector;
	struct bio___17 *bi_next;
	struct block_device___114 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___17 *bi_end_io;
	void *bi_private;
	struct io_context___16 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___17 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___17 *bi_io_vec;
	struct bio_set___17 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___17 bi_inline_vecs[0];
};

struct hd_struct___17;

struct gendisk___17;

struct request_queue___16;

struct block_device___114 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___114 *bd_inode;
	struct super_block___114 *bd_super;
	struct mutex___115 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___114 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___17 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___17 *bd_disk;
	struct request_queue___16 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___115 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___17 {
	struct bio___17 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___17 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___17 *bip_vec;
	struct bio_vec___17 bip_inline_vecs[0];
};

struct bio_set___17 {
	struct kmem_cache___101 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___16 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___114 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___114 *ia_file;
};

struct dquot___114 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___115 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___114 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___114 {
	int qf_fmt_id;
	const struct quota_format_ops___114 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___114 *qf_next;
};

struct quota_format_ops___114 {
	int (*check_quota_file)(struct super_block___114 *, int);
	int (*read_file_info)(struct super_block___114 *, int);
	int (*write_file_info)(struct super_block___114 *, int);
	int (*free_file_info)(struct super_block___114 *, int);
	int (*read_dqblk)(struct dquot___114 *);
	int (*commit_dqblk)(struct dquot___114 *);
	int (*release_dqblk)(struct dquot___114 *);
};

struct dquot_operations___114 {
	int (*write_dquot)(struct dquot___114 *);
	struct dquot___114 * (*alloc_dquot)(struct super_block___114 *, int);
	void (*destroy_dquot)(struct dquot___114 *);
	int (*acquire_dquot)(struct dquot___114 *);
	int (*release_dquot)(struct dquot___114 *);
	int (*mark_dirty)(struct dquot___114 *);
	int (*write_info)(struct super_block___114 *, int);
	qsize_t * (*get_reserved_space)(struct inode___114 *);
};

struct quotactl_ops___114 {
	int (*quota_on)(struct super_block___114 *, int, int, struct path___114 *);
	int (*quota_on_meta)(struct super_block___114 *, int, int);
	int (*quota_off)(struct super_block___114 *, int);
	int (*quota_sync)(struct super_block___114 *, int);
	int (*get_info)(struct super_block___114 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___114 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___114 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___114 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___114 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___114 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___114 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___114 *, unsigned int);
};

struct address_space_operations___114 {
	int (*writepage)(struct page___114 *, struct writeback_control *);
	int (*readpage)(struct file___114 *, struct page___114 *);
	int (*writepages)(struct address_space___114 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___114 *);
	int (*readpages)(struct file___114 *, struct address_space___114 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___114 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___114 **, void **);
	int (*write_end)(struct file___114 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___114 *, void *);
	sector_t (*bmap)(struct address_space___114 *, sector_t);
	void (*invalidatepage)(struct page___114 *, long unsigned int);
	int (*releasepage)(struct page___114 *, gfp_t);
	void (*freepage)(struct page___114 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___114 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___114 *, struct page___114 *, struct page___114 *, enum migrate_mode);
	int (*launder_page)(struct page___114 *);
	int (*is_partially_uptodate)(struct page___114 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___114 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___114 *, struct page___114 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___114 *, sector_t *);
	void (*swap_deactivate)(struct file___114 *);
	void (*invalidatepage_range)(struct page___114 *, unsigned int, unsigned int);
};

struct hd_struct___17 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___91 __dev;
	struct kobject___5 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___17;

struct block_device_operations___16;

struct gendisk___17 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___17 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___17 *part_tbl;
	struct hd_struct___17 part0;
	const struct block_device_operations___16 *fops;
	struct request_queue___16 *queue;
	void *private_data;
	int flags;
	struct device___91 *driverfs_dev;
	struct kobject___5 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct request_list___16 {
	struct request_queue___16 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___16(struct request_queue___16 *);

typedef void make_request_fn___16(struct request_queue___16 *, struct bio___17 *);

struct request___16;

typedef int prep_rq_fn___16(struct request_queue___16 *, struct request___16 *);

struct bvec_merge_data___16;

typedef int merge_bvec_fn___16(struct request_queue___16 *, struct bvec_merge_data___16 *, struct bio_vec___17 *);

typedef void softirq_done_fn___16(struct request___16 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___16(struct request___16 *);

typedef int dma_drain_needed_fn___16(struct request___16 *);

typedef int lld_busy_fn___16(struct request_queue___16 *);

struct bsg_class_device___16 {
	struct device___91 *class_dev;
	struct device___91 *parent;
	int minor;
	struct request_queue___16 *queue;
	struct kref ref;
	void (*release)(struct device___91 *);
};

typedef void unprep_rq_fn___16(struct request_queue___16 *, struct request___16 *);

struct elevator_queue___16;

struct blk_queue_tag___16;

struct request_queue___16 {
	struct list_head queue_head;
	struct request___16 *last_merge;
	struct elevator_queue___16 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___16 root_rl;
	request_fn_proc___16 *request_fn;
	make_request_fn___16 *make_request_fn;
	prep_rq_fn___16 *prep_rq_fn;
	merge_bvec_fn___16 *merge_bvec_fn;
	softirq_done_fn___16 *softirq_done_fn;
	rq_timed_out_fn___16 *rq_timed_out_fn;
	dma_drain_needed_fn___16 *dma_drain_needed;
	lld_busy_fn___16 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___16 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___24 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___5 kobj;
	struct kobject___5 mq_kobj;
	struct device___91 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___16 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___16 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___115 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___16 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___16 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___17 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___114 {
	struct dentry___114 * (*lookup)(struct inode___114 *, struct dentry___114 *, unsigned int);
	void * (*follow_link)(struct dentry___114 *, struct nameidata *);
	int (*permission)(struct inode___114 *, int);
	struct posix_acl * (*get_acl)(struct inode___114 *, int);
	int (*readlink)(struct dentry___114 *, char *, int);
	void (*put_link)(struct dentry___114 *, struct nameidata *, void *);
	int (*create)(struct inode___114 *, struct dentry___114 *, umode_t, bool);
	int (*link)(struct dentry___114 *, struct inode___114 *, struct dentry___114 *);
	int (*unlink)(struct inode___114 *, struct dentry___114 *);
	int (*symlink)(struct inode___114 *, struct dentry___114 *, const char *);
	int (*mkdir)(struct inode___114 *, struct dentry___114 *, umode_t);
	int (*rmdir)(struct inode___114 *, struct dentry___114 *);
	int (*mknod)(struct inode___114 *, struct dentry___114 *, umode_t, dev_t);
	int (*rename)(struct inode___114 *, struct dentry___114 *, struct inode___114 *, struct dentry___114 *);
	int (*setattr)(struct dentry___114 *, struct iattr___114 *);
	int (*getattr)(struct vfsmount___17 *, struct dentry___114 *, struct kstat *);
	int (*setxattr)(struct dentry___114 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___114 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___114 *, char *, size_t);
	int (*removexattr)(struct dentry___114 *, const char *);
	int (*fiemap)(struct inode___114 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___114 *, struct timespec *, int);
	int (*atomic_open)(struct inode___114 *, struct dentry___114 *, struct file___114 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___114 {
	struct module *owner;
	loff_t (*llseek)(struct file___114 *, loff_t, int);
	ssize_t (*read)(struct file___114 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___114 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___114 *, void *, filldir_t);
	unsigned int (*poll)(struct file___114 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___114 *, struct vm_area_struct___119 *);
	int (*open)(struct inode___114 *, struct file___114 *);
	int (*flush)(struct file___114 *, fl_owner_t);
	int (*release)(struct inode___114 *, struct file___114 *);
	int (*fsync)(struct file___114 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___114 *, int);
	int (*lock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*sendpage)(struct file___114 *, struct page___114 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___114 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___114 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___114 *, long int, struct file_lock___114 **, void **);
		struct {
			int (*setlease)(struct file___114 *, long int, struct file_lock___114 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___114 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___114 *);
};

struct fasync_struct___114;

struct file_lock_operations___114;

struct lock_manager_operations___114;

struct file_lock___114 {
	struct file_lock___114 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___64 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___114 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___114 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___114 *fl_ops;
	const struct lock_manager_operations___114 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___114 {
	void (*fl_copy_lock)(struct file_lock___114 *, struct file_lock___114 *);
	void (*fl_release_private)(struct file_lock___114 *);
};

struct lock_manager_operations___114 {
	int (*lm_compare_owner)(struct file_lock___114 *, struct file_lock___114 *);
	long unsigned int (*lm_owner_key)(struct file_lock___114 *);
	void (*lm_notify)(struct file_lock___114 *);
	int (*lm_grant)(struct file_lock___114 *, struct file_lock___114 *, int);
	void (*lm_break)(struct file_lock___114 *);
	int (*lm_change)(struct file_lock___114 **, int);
};

struct fasync_struct___114 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___114 *fa_next;
	struct file___114 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___114 {
	const char *name;
	int fs_flags;
	struct dentry___114 * (*mount)(struct file_system_type___114 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___114 *);
	struct module *owner;
	struct file_system_type___114 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___114 {
	struct inode___114 * (*alloc_inode)(struct super_block___114 *);
	void (*destroy_inode)(struct inode___114 *);
	void (*dirty_inode)(struct inode___114 *, int);
	int (*write_inode)(struct inode___114 *, struct writeback_control *);
	int (*drop_inode)(struct inode___114 *);
	void (*evict_inode)(struct inode___114 *);
	void (*put_super)(struct super_block___114 *);
	int (*sync_fs)(struct super_block___114 *, int);
	int (*freeze_fs)(struct super_block___114 *);
	int (*unfreeze_fs)(struct super_block___114 *);
	int (*statfs)(struct dentry___114 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___114 *, int *, char *);
	void (*umount_begin)(struct super_block___114 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___114 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___114 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___114 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___114 *);
	ssize_t (*quota_read)(struct super_block___114 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___114 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___114 *);
	int (*bdev_try_to_free_page)(struct super_block___114 *, struct page___114 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___114 *);
	void (*free_cached_objects)(struct super_block___114 *, int);
};

struct export_operations___4 {
	int (*encode_fh)(struct inode___114 *, __u32 *, int *, struct inode___114 *);
	struct dentry___114 * (*fh_to_dentry)(struct super_block___114 *, struct fid *, int, int);
	struct dentry___114 * (*fh_to_parent)(struct super_block___114 *, struct fid *, int, int);
	int (*get_name)(struct dentry___114 *, char *, struct dentry___114 *);
	struct dentry___114 * (*get_parent)(struct dentry___114 *);
	int (*commit_metadata)(struct inode___114 *);
	int (*get_uuid)(struct super_block___114 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___114 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___114 *, struct iomap *, int, struct iattr___114 *);
};

struct disk_part_tbl___17 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___17 *last_lookup;
	struct hd_struct___17 *part[0];
};

struct block_device_operations___16 {
	int (*open)(struct block_device___114 *, fmode_t);
	void (*release)(struct gendisk___17 *, fmode_t);
	int (*ioctl)(struct block_device___114 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___114 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___114 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___17 *, unsigned int);
	int (*media_changed)(struct gendisk___17 *);
	void (*unlock_native_capacity)(struct gendisk___17 *);
	int (*revalidate_disk)(struct gendisk___17 *);
	int (*getgeo)(struct block_device___114 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___114 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___98 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___114 *page;
};

struct io_cq___16 {
	struct request_queue___16 *q;
	struct io_context___16 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___101 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___16(struct request___16 *, int);

struct request___16 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___16 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___17 *bio;
	struct bio___17 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___16 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___16 *saved_end_io;
		} flush;
	};
	struct gendisk___17 *rq_disk;
	struct hd_struct___17 *part;
	long unsigned int start_time;
	struct request_list___16 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___16 *end_io;
	void *end_io_data;
	struct request___16 *next_rq;
};

typedef int elevator_merge_fn___16(struct request_queue___16 *, struct request___16 **, struct bio___17 *);

typedef void elevator_merge_req_fn___16(struct request_queue___16 *, struct request___16 *, struct request___16 *);

typedef void elevator_merged_fn___16(struct request_queue___16 *, struct request___16 *, int);

typedef int elevator_allow_merge_fn___16(struct request_queue___16 *, struct request___16 *, struct bio___17 *);

typedef void elevator_bio_merged_fn___16(struct request_queue___16 *, struct request___16 *, struct bio___17 *);

typedef int elevator_dispatch_fn___16(struct request_queue___16 *, int);

typedef void elevator_add_req_fn___16(struct request_queue___16 *, struct request___16 *);

typedef struct request___16 *elevator_request_list_fn___16(struct request_queue___16 *, struct request___16 *);

typedef void elevator_completed_req_fn___16(struct request_queue___16 *, struct request___16 *);

typedef int elevator_may_queue_fn___16(struct request_queue___16 *, int);

typedef void elevator_init_icq_fn___16(struct io_cq___16 *);

typedef void elevator_exit_icq_fn___16(struct io_cq___16 *);

typedef int elevator_set_req_fn___16(struct request_queue___16 *, struct request___16 *, struct bio___17 *, gfp_t);

typedef void elevator_put_req_fn___16(struct request___16 *);

typedef void elevator_activate_req_fn___16(struct request_queue___16 *, struct request___16 *);

typedef void elevator_deactivate_req_fn___16(struct request_queue___16 *, struct request___16 *);

struct elevator_type___16;

typedef int elevator_init_fn___16(struct request_queue___16 *, struct elevator_type___16 *);

typedef void elevator_exit_fn___16(struct elevator_queue___16 *);

struct elevator_ops___16 {
	elevator_merge_fn___16 *elevator_merge_fn;
	elevator_merged_fn___16 *elevator_merged_fn;
	elevator_merge_req_fn___16 *elevator_merge_req_fn;
	elevator_allow_merge_fn___16 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___16 *elevator_bio_merged_fn;
	elevator_dispatch_fn___16 *elevator_dispatch_fn;
	elevator_add_req_fn___16 *elevator_add_req_fn;
	elevator_activate_req_fn___16 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___16 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___16 *elevator_completed_req_fn;
	elevator_request_list_fn___16 *elevator_former_req_fn;
	elevator_request_list_fn___16 *elevator_latter_req_fn;
	elevator_init_icq_fn___16 *elevator_init_icq_fn;
	elevator_exit_icq_fn___16 *elevator_exit_icq_fn;
	elevator_set_req_fn___16 *elevator_set_req_fn;
	elevator_put_req_fn___16 *elevator_put_req_fn;
	elevator_may_queue_fn___16 *elevator_may_queue_fn;
	elevator_init_fn___16 *elevator_init_fn;
	elevator_exit_fn___16 *elevator_exit_fn;
};

struct elv_fs_entry___16;

struct elevator_type___16 {
	struct kmem_cache___101 *icq_cache;
	struct elevator_ops___16 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___16 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___16 {
	struct elevator_type___16 *type;
	void *elevator_data;
	struct kobject___5 kobj;
	struct mutex___115 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___16 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___16 *, char *);
	ssize_t (*store)(struct elevator_queue___16 *, const char *, size_t);
};

struct bvec_merge_data___16 {
	struct block_device___114 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___16 {
	struct request___16 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

typedef struct kobject *kobj_probe_t(dev_t, int *, void *);

struct char_device_struct {
	struct char_device_struct *next;
	unsigned int major;
	unsigned int baseminor;
	int minorct;
	char name[64];
	struct cdev *cdev;
};

struct kobj_map;

struct __old_kernel_stat {
	short unsigned int st_dev;
	short unsigned int st_ino;
	short unsigned int st_mode;
	short unsigned int st_nlink;
	short unsigned int st_uid;
	short unsigned int st_gid;
	short unsigned int st_rdev;
	unsigned int st_size;
	unsigned int st_atime;
	unsigned int st_mtime;
	unsigned int st_ctime;
};

struct page___115;

typedef struct page___115 *pgtable_t___115;

struct address_space___115;

struct kmem_cache___102;

struct page___115 {
	long unsigned int flags;
	struct address_space___115 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___115 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___115 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___102 *slab_cache;
		struct page___115 *first_page;
	};
	long: 64;
};

struct thread_struct___60;

struct task_struct___115;

struct pv_cpu_ops___115 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___60 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___60 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___115 *);
	void (*end_context_switch)(struct task_struct___115 *);
};

struct perf_event___60;

struct thread_struct___60 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___60 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___65;

struct pid_link___65 {
	struct hlist_node node;
	struct pid___65 *pid;
};

struct mutex___116 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___115 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___111 {
	struct page___115 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___120;

struct fs_struct___9;

struct files_struct___6;

struct nsproxy___67;

struct signal_struct___115;

struct css_set___78;

struct perf_event_context___60;

struct pipe_inode_info___5;

struct task_struct___115 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___115 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___120 *mm;
	struct mm_struct___120 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___115 *real_parent;
	struct task_struct___115 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___115 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___65 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___115 = 0,
		VTIME_USER___115 = 1,
		VTIME_SYS___115 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___60 thread;
	struct fs_struct___9 *fs;
	struct files_struct___6 *files;
	struct nsproxy___67 *nsproxy;
	struct signal_struct___115 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___78 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___60 *perf_event_ctxp[2];
	struct mutex___116 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___5 *splice_pipe;
	struct page_frag___111 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___120 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___120 *, struct mm_struct___120 *);
	void (*dup_mmap)(struct mm_struct___120 *, struct mm_struct___120 *);
	void (*exit_mmap)(struct mm_struct___120 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___120 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___120 *);
	void (*pgd_free)(struct mm_struct___120 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___120 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___120 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___120 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___120 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___120 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___120 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___120 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___120 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___120 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___120 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___120 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___116 lock;
	void *vdso;
} mm_context_t___116;

struct xol_area___115;

struct uprobes_state___115 {
	struct xol_area___115 *xol_area;
};

struct vm_area_struct___120;

struct file___115;

struct linux_binfmt___14;

struct core_state___115;

struct mm_struct___120 {
	struct vm_area_struct___120 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___120 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___120 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___14 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___116 context;
	long unsigned int flags;
	struct core_state___115 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___115 *owner;
	struct file___115 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___115 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___61;

struct exec_domain___31 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___61 *module;
	struct exec_domain___31 *next;
};

struct module_kobject___60 {
	struct kobject___5 kobj;
	struct module___61 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___60;

struct ftrace_event_call___50;

struct module___61 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___60 mkobj;
	struct module_attribute___60 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___50 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___115 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___60 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___115 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___115 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___115 *target;
};

typedef void (*perf_overflow_handler_t___60)(struct perf_event___60 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___60;

typedef void (*ftrace_func_t___60)(long unsigned int, long unsigned int, struct ftrace_ops___60 *, struct pt_regs *);

struct ftrace_ops___60 {
	ftrace_func_t___60 func;
	struct ftrace_ops___60 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___116 regex_lock;
};

struct pmu___60;

struct fasync_struct___115;

struct pid_namespace___65;

struct perf_cgroup___60;

struct perf_event___60 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___60 *group_leader;
	struct pmu___60 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___60 hw;
	struct perf_event_context___60 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___116 child_mutex;
	struct list_head child_list;
	struct perf_event___60 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___115 *owner;
	struct mutex___116 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___115 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___60 *);
	struct callback_head callback_head;
	struct pid_namespace___65 *ns;
	u64 id;
	perf_overflow_handler_t___60 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___50 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___60 ftrace_ops;
	struct perf_cgroup___60 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___60 {
	struct task_struct___115 *task;
	struct exec_domain___31 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___115;

struct lruvec___115 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___115 *zone;
};

struct pglist_data___115;

struct zone___115 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___115 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___115 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___115 {
	struct zone___115 *zone;
	int zone_idx;
};

struct zonelist___115 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___115 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___115 {
	struct zone___115 node_zones[4];
	struct zonelist___115 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___115 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___85;

struct x86_io_apic_ops___85 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___85 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___85;

struct irq_data___85 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___85 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___92;

struct dev_pm_ops___92 {
	int (*prepare)(struct device___92 *);
	void (*complete)(struct device___92 *);
	int (*suspend)(struct device___92 *);
	int (*resume)(struct device___92 *);
	int (*freeze)(struct device___92 *);
	int (*thaw)(struct device___92 *);
	int (*poweroff)(struct device___92 *);
	int (*restore)(struct device___92 *);
	int (*suspend_late)(struct device___92 *);
	int (*resume_early)(struct device___92 *);
	int (*freeze_late)(struct device___92 *);
	int (*thaw_early)(struct device___92 *);
	int (*poweroff_late)(struct device___92 *);
	int (*restore_early)(struct device___92 *);
	int (*suspend_noirq)(struct device___92 *);
	int (*resume_noirq)(struct device___92 *);
	int (*freeze_noirq)(struct device___92 *);
	int (*thaw_noirq)(struct device___92 *);
	int (*poweroff_noirq)(struct device___92 *);
	int (*restore_noirq)(struct device___92 *);
	int (*runtime_suspend)(struct device___92 *);
	int (*runtime_resume)(struct device___92 *);
	int (*runtime_idle)(struct device___92 *);
};

struct device_type___92;

struct bus_type___92;

struct device_driver___92;

struct dev_pm_domain___92;

struct class___92;

struct attribute_group___85;

struct device_rh___92;

struct device___92 {
	struct device___92 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___92 *type;
	struct mutex___116 mutex;
	struct bus_type___92 *bus;
	struct device_driver___92 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___92 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___92 *class;
	const struct attribute_group___85 **groups;
	void (*release)(struct device___92 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___92 *device_rh;
};

struct dev_pm_info_rh___92 {
	void (*set_latency_tolerance)(struct device___92 *, s32);
};

struct dev_pm_domain___92 {
	struct dev_pm_ops___92 ops;
};

struct smp_ops___115 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___115 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___85;

struct attribute_group___85 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___85 **bin_attrs;
};

struct bin_attribute___85 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___115 *, struct kobject___5 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___115 *, struct kobject___5 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	int (*mmap)(struct file___115 *, struct kobject___5 *, struct bin_attribute___85 *, struct vm_area_struct___120 *);
};

struct vfsmount___18;

struct dentry___115;

struct path___115 {
	struct vfsmount___18 *mnt;
	struct dentry___115 *dentry;
};

struct fown_struct___65 {
	rwlock_t lock;
	struct pid___65 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___115;

struct file_operations___115;

struct file___115 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___115 f_path;
	struct inode___115 *f_inode;
	const struct file_operations___115 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___65 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___115 *f_mapping;
	struct mutex___116 f_pos_lock;
};

struct vm_operations_struct___102;

struct vm_area_struct___120 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___120 *vm_next;
	struct vm_area_struct___120 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___120 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___102 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___115 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___102 {
	void **freelist;
	long unsigned int tid;
	struct page___115 *page;
	struct page___115 *partial;
};

struct memcg_cache_params___102;

struct kmem_cache___102 {
	struct kmem_cache_cpu___102 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___102 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___102 {
	bool is_root_cache;
	union {
		struct kmem_cache___102 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___102 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___115;

struct super_block___115;

struct dentry___115 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___115 *d_parent;
	struct qstr d_name;
	struct inode___115 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___115 *d_op;
	struct super_block___115 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___115;

struct address_space___115 {
	struct inode___115 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___116 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___115 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___115;

struct file_lock___115;

struct dquot___115;

struct block_device___115;

struct inode___115 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___115 *i_op;
	struct super_block___115 *i_sb;
	struct address_space___115 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___116 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___115 *i_fop;
	struct file_lock___115 *i_flock;
	struct address_space___115 i_data;
	struct dquot___115 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___5 *i_pipe;
		struct block_device___115 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___115 {
	int (*d_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_hash)(const struct dentry___115 *, struct qstr *);
	int (*d_compare)(const struct dentry___115 *, const struct dentry___115 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___115 *);
	void (*d_release)(struct dentry___115 *);
	void (*d_prune)(struct dentry___115 *);
	void (*d_iput)(struct dentry___115 *, struct inode___115 *);
	char * (*d_dname)(struct dentry___115 *, char *, int);
	struct vfsmount___18 * (*d_automount)(struct path___115 *);
	int (*d_manage)(struct dentry___115 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___115;

struct mem_dqinfo___115 {
	struct quota_format_type___115 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___115;

struct quota_info___115 {
	unsigned int flags;
	struct mutex___116 dqio_mutex;
	struct mutex___116 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___115 *files[2];
	struct mem_dqinfo___115 info[2];
	const struct quota_format_ops___115 *ops[2];
};

struct file_system_type___115;

struct super_operations___115;

struct dquot_operations___115;

struct quotactl_ops___115;

struct xattr_handler___78;

struct super_block___115 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___115 *s_type;
	const struct super_operations___115 *s_op;
	const struct dquot_operations___115 *dq_op;
	const struct quotactl_ops___115 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___115 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___78 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___115 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___115 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___116 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___115 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___18 {
	struct dentry___115 *mnt_root;
	struct super_block___115 *mnt_sb;
	int mnt_flags;
};

struct upid___65 {
	int nr;
	struct pid_namespace___65 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___65 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___115 *child_reaper;
	struct kmem_cache___102 *pid_cachep;
	unsigned int level;
	struct pid_namespace___65 *parent;
	struct vfsmount___18 *proc_mnt;
	struct dentry___115 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___65 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___65 numbers[1];
};

struct block_device___115 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___115 *bd_inode;
	struct super_block___115 *bd_super;
	struct mutex___116 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___115 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___116 bd_fsfreeze_mutex;
};

struct cgroup___78;

struct cgroup_subsys_state___79 {
	struct cgroup___78 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___115 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___115 *ia_file;
};

struct dquot___115 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___116 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___115 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___115 {
	int qf_fmt_id;
	const struct quota_format_ops___115 *qf_ops;
	struct module___61 *qf_owner;
	struct quota_format_type___115 *qf_next;
};

struct quota_format_ops___115 {
	int (*check_quota_file)(struct super_block___115 *, int);
	int (*read_file_info)(struct super_block___115 *, int);
	int (*write_file_info)(struct super_block___115 *, int);
	int (*free_file_info)(struct super_block___115 *, int);
	int (*read_dqblk)(struct dquot___115 *);
	int (*commit_dqblk)(struct dquot___115 *);
	int (*release_dqblk)(struct dquot___115 *);
};

struct dquot_operations___115 {
	int (*write_dquot)(struct dquot___115 *);
	struct dquot___115 * (*alloc_dquot)(struct super_block___115 *, int);
	void (*destroy_dquot)(struct dquot___115 *);
	int (*acquire_dquot)(struct dquot___115 *);
	int (*release_dquot)(struct dquot___115 *);
	int (*mark_dirty)(struct dquot___115 *);
	int (*write_info)(struct super_block___115 *, int);
	qsize_t * (*get_reserved_space)(struct inode___115 *);
};

struct quotactl_ops___115 {
	int (*quota_on)(struct super_block___115 *, int, int, struct path___115 *);
	int (*quota_on_meta)(struct super_block___115 *, int, int);
	int (*quota_off)(struct super_block___115 *, int);
	int (*quota_sync)(struct super_block___115 *, int);
	int (*get_info)(struct super_block___115 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___115 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___115 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___115 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___115 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___115 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___115 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___115 *, unsigned int);
};

struct swap_info_struct___27;

struct address_space_operations___115 {
	int (*writepage)(struct page___115 *, struct writeback_control *);
	int (*readpage)(struct file___115 *, struct page___115 *);
	int (*writepages)(struct address_space___115 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___115 *);
	int (*readpages)(struct file___115 *, struct address_space___115 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___115 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___115 **, void **);
	int (*write_end)(struct file___115 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___115 *, void *);
	sector_t (*bmap)(struct address_space___115 *, sector_t);
	void (*invalidatepage)(struct page___115 *, long unsigned int);
	int (*releasepage)(struct page___115 *, gfp_t);
	void (*freepage)(struct page___115 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___115 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___115 *, struct page___115 *, struct page___115 *, enum migrate_mode);
	int (*launder_page)(struct page___115 *);
	int (*is_partially_uptodate)(struct page___115 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___115 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___115 *, struct page___115 *);
	int (*swap_activate)(struct swap_info_struct___27 *, struct file___115 *, sector_t *);
	void (*swap_deactivate)(struct file___115 *);
	void (*invalidatepage_range)(struct page___115 *, unsigned int, unsigned int);
};

struct swap_info_struct___27 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___115 *bdev;
	struct file___115 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct pipe_buffer___5;

struct pipe_inode_info___5 {
	struct mutex___116 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___115 *tmp_page;
	struct fasync_struct___115 *fasync_readers;
	struct fasync_struct___115 *fasync_writers;
	struct pipe_buffer___5 *bufs;
};

struct nameidata___9;

struct inode_operations___115 {
	struct dentry___115 * (*lookup)(struct inode___115 *, struct dentry___115 *, unsigned int);
	void * (*follow_link)(struct dentry___115 *, struct nameidata___9 *);
	int (*permission)(struct inode___115 *, int);
	struct posix_acl * (*get_acl)(struct inode___115 *, int);
	int (*readlink)(struct dentry___115 *, char *, int);
	void (*put_link)(struct dentry___115 *, struct nameidata___9 *, void *);
	int (*create)(struct inode___115 *, struct dentry___115 *, umode_t, bool);
	int (*link)(struct dentry___115 *, struct inode___115 *, struct dentry___115 *);
	int (*unlink)(struct inode___115 *, struct dentry___115 *);
	int (*symlink)(struct inode___115 *, struct dentry___115 *, const char *);
	int (*mkdir)(struct inode___115 *, struct dentry___115 *, umode_t);
	int (*rmdir)(struct inode___115 *, struct dentry___115 *);
	int (*mknod)(struct inode___115 *, struct dentry___115 *, umode_t, dev_t);
	int (*rename)(struct inode___115 *, struct dentry___115 *, struct inode___115 *, struct dentry___115 *);
	int (*setattr)(struct dentry___115 *, struct iattr___115 *);
	int (*getattr)(struct vfsmount___18 *, struct dentry___115 *, struct kstat *);
	int (*setxattr)(struct dentry___115 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___115 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___115 *, char *, size_t);
	int (*removexattr)(struct dentry___115 *, const char *);
	int (*fiemap)(struct inode___115 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___115 *, struct timespec *, int);
	int (*atomic_open)(struct inode___115 *, struct dentry___115 *, struct file___115 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___6 *fl_owner_t___6;

struct poll_table_struct___73;

struct seq_file___87;

struct file_operations___115 {
	struct module___61 *owner;
	loff_t (*llseek)(struct file___115 *, loff_t, int);
	ssize_t (*read)(struct file___115 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___115 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___115 *, void *, filldir_t);
	unsigned int (*poll)(struct file___115 *, struct poll_table_struct___73 *);
	long int (*unlocked_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___115 *, struct vm_area_struct___120 *);
	int (*open)(struct inode___115 *, struct file___115 *);
	int (*flush)(struct file___115 *, fl_owner_t___6);
	int (*release)(struct inode___115 *, struct file___115 *);
	int (*fsync)(struct file___115 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___115 *, int);
	int (*lock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*sendpage)(struct file___115 *, struct page___115 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*splice_write)(struct pipe_inode_info___5 *, struct file___115 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___115 *, loff_t *, struct pipe_inode_info___5 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___115 *, long int, struct file_lock___115 **, void **);
		struct {
			int (*setlease)(struct file___115 *, long int, struct file_lock___115 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___115 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___87 *, struct file___115 *);
};

struct file_lock_operations___115;

struct lock_manager_operations___115;

struct file_lock___115 {
	struct file_lock___115 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___6 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___65 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___115 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___115 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___115 *fl_ops;
	const struct lock_manager_operations___115 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___6 {
	unsigned int max_fds;
	struct file___115 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___6 {
	atomic_t count;
	struct fdtable___6 *fdt;
	struct fdtable___6 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___115 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___115 {
	void (*fl_copy_lock)(struct file_lock___115 *, struct file_lock___115 *);
	void (*fl_release_private)(struct file_lock___115 *);
};

struct lock_manager_operations___115 {
	int (*lm_compare_owner)(struct file_lock___115 *, struct file_lock___115 *);
	long unsigned int (*lm_owner_key)(struct file_lock___115 *);
	void (*lm_notify)(struct file_lock___115 *);
	int (*lm_grant)(struct file_lock___115 *, struct file_lock___115 *, int);
	void (*lm_break)(struct file_lock___115 *);
	int (*lm_change)(struct file_lock___115 **, int);
};

struct fasync_struct___115 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___115 *fa_next;
	struct file___115 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___115 {
	const char *name;
	int fs_flags;
	struct dentry___115 * (*mount)(struct file_system_type___115 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___115 *);
	struct module___61 *owner;
	struct file_system_type___115 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___115 {
	struct inode___115 * (*alloc_inode)(struct super_block___115 *);
	void (*destroy_inode)(struct inode___115 *);
	void (*dirty_inode)(struct inode___115 *, int);
	int (*write_inode)(struct inode___115 *, struct writeback_control *);
	int (*drop_inode)(struct inode___115 *);
	void (*evict_inode)(struct inode___115 *);
	void (*put_super)(struct super_block___115 *);
	int (*sync_fs)(struct super_block___115 *, int);
	int (*freeze_fs)(struct super_block___115 *);
	int (*unfreeze_fs)(struct super_block___115 *);
	int (*statfs)(struct dentry___115 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___115 *, int *, char *);
	void (*umount_begin)(struct super_block___115 *);
	int (*show_options)(struct seq_file___87 *, struct dentry___115 *);
	int (*show_devname)(struct seq_file___87 *, struct dentry___115 *);
	int (*show_path)(struct seq_file___87 *, struct dentry___115 *);
	int (*show_stats)(struct seq_file___87 *, struct dentry___115 *);
	ssize_t (*quota_read)(struct super_block___115 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___115 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___115 *);
	int (*bdev_try_to_free_page)(struct super_block___115 *, struct page___115 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___115 *);
	void (*free_cached_objects)(struct super_block___115 *, int);
};

struct xattr_handler___78 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___115 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___115 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___115 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___75)(struct file___115 *, wait_queue_head_t *, struct poll_table_struct___73 *);

struct poll_table_struct___73 {
	poll_queue_proc___75 _qproc;
	long unsigned int _key;
};

struct seq_operations___86;

struct seq_file___87 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___116 lock;
	const struct seq_operations___86 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___9 {
	struct path___115 path;
	struct qstr last;
	struct path___115 root;
	struct inode___115 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___115 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___115 *page;
	long unsigned int vaddr;
};

struct vm_fault___99;

struct vm_operations_struct___102 {
	void (*open)(struct vm_area_struct___120 *);
	void (*close)(struct vm_area_struct___120 *);
	int (*fault)(struct vm_area_struct___120 *, struct vm_fault___99 *);
	int (*page_mkwrite)(struct vm_area_struct___120 *, struct vm_fault___99 *);
	int (*access)(struct vm_area_struct___120 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___120 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___120 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___120 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___120 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___115 {
	struct task_struct___115 *task;
	struct core_thread___115 *next;
};

struct core_state___115 {
	atomic_t nr_threads;
	struct core_thread___115 dumper;
	struct completion startup;
};

struct linux_binprm___15;

struct coredump_params___14;

struct linux_binfmt___14 {
	struct list_head lh;
	struct module___61 *module;
	int (*load_binary)(struct linux_binprm___15 *);
	int (*load_shlib)(struct file___115 *);
	int (*core_dump)(struct coredump_params___14 *);
	long unsigned int min_coredump;
};

struct vm_fault___99 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___115 *page;
};

struct nsproxy___67 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___65 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___115 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___115 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___115 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___65 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___65 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___116 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___9 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___115 root;
	struct path___115 pwd;
};

struct css_set___78 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___79 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___60 {
	struct pmu___60 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___116 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___115 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___60 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct cgroupfs_root___78;

struct cgroup___78 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___78 *parent;
	struct dentry___115 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___79 *subsys[11];
	struct cgroupfs_root___78 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___116 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___78 {
	struct super_block___115 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___78 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___36 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___115 *, struct file___115 *);
	ssize_t (*read)(struct cgroup___78 *, struct cftype___36 *, struct file___115 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___78 *, struct cftype___36 *);
	s64 (*read_s64)(struct cgroup___78 *, struct cftype___36 *);
	int (*read_map)(struct cgroup___78 *, struct cftype___36 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___78 *, struct cftype___36 *, struct seq_file___87 *);
	ssize_t (*write)(struct cgroup___78 *, struct cftype___36 *, struct file___115 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___78 *, struct cftype___36 *, u64);
	int (*write_s64)(struct cgroup___78 *, struct cftype___36 *, s64);
	int (*write_string)(struct cgroup___78 *, struct cftype___36 *, const char *);
	int (*trigger)(struct cgroup___78 *, unsigned int);
	int (*release)(struct inode___115 *, struct file___115 *);
	int (*register_event)(struct cgroup___78 *, struct cftype___36 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___78 *, struct cftype___36 *, struct eventfd_ctx *);
};

struct cftype_set___34 {
	struct list_head node;
	struct cftype___36 *cfts;
};

struct task_and_cgroup___34 {
	struct task_struct___115 *task;
	struct cgroup___78 *cgrp;
	struct css_set___78 *cg;
};

struct cgroup_taskset___34 {
	struct task_and_cgroup___34 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___78 *cur_cgrp;
};

struct cgroup_subsys___34 {
	struct cgroup_subsys_state___79 * (*css_alloc)(struct cgroup___78 *);
	int (*css_online)(struct cgroup___78 *);
	void (*css_offline)(struct cgroup___78 *);
	void (*css_free)(struct cgroup___78 *);
	int (*can_attach)(struct cgroup___78 *, struct cgroup_taskset___34 *);
	void (*cancel_attach)(struct cgroup___78 *, struct cgroup_taskset___34 *);
	void (*attach)(struct cgroup___78 *, struct cgroup_taskset___34 *);
	void (*fork)(struct task_struct___115 *);
	void (*exit)(struct cgroup___78 *, struct cgroup___78 *, struct task_struct___115 *);
	void (*bind)(struct cgroup___78 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___78 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___36 *base_cftypes;
	struct cftype_set___34 base_cftset;
	struct module___61 *module;
};

struct irq_chip___85 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___85 *);
	void (*irq_shutdown)(struct irq_data___85 *);
	void (*irq_enable)(struct irq_data___85 *);
	void (*irq_disable)(struct irq_data___85 *);
	void (*irq_ack)(struct irq_data___85 *);
	void (*irq_mask)(struct irq_data___85 *);
	void (*irq_mask_ack)(struct irq_data___85 *);
	void (*irq_unmask)(struct irq_data___85 *);
	void (*irq_eoi)(struct irq_data___85 *);
	int (*irq_set_affinity)(struct irq_data___85 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___85 *);
	int (*irq_set_type)(struct irq_data___85 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___85 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___85 *);
	void (*irq_bus_sync_unlock)(struct irq_data___85 *);
	void (*irq_cpu_online)(struct irq_data___85 *);
	void (*irq_cpu_offline)(struct irq_data___85 *);
	void (*irq_suspend)(struct irq_data___85 *);
	void (*irq_resume)(struct irq_data___85 *);
	void (*irq_pm_shutdown)(struct irq_data___85 *);
	void (*irq_print_chip)(struct irq_data___85 *, struct seq_file___87 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___85 *, void *);
	long unsigned int flags;
};

struct bus_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___92 *, char *);
	ssize_t (*store)(struct bus_type___92 *, const char *, size_t);
};

struct device_attribute___92;

struct driver_attribute___92;

struct bus_type___92 {
	const char *name;
	const char *dev_name;
	struct device___92 *dev_root;
	struct bus_attribute___92 *bus_attrs;
	struct device_attribute___92 *dev_attrs;
	struct driver_attribute___92 *drv_attrs;
	const struct attribute_group___85 **bus_groups;
	const struct attribute_group___85 **dev_groups;
	const struct attribute_group___85 **drv_groups;
	int (*match)(struct device___92 *, struct device_driver___92 *);
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	int (*probe)(struct device___92 *);
	int (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*online)(struct device___92 *);
	int (*offline)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct device___92 *, struct device_attribute___92 *, char *);
	ssize_t (*store)(struct device___92 *, struct device_attribute___92 *, const char *, size_t);
};

struct driver_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___92 *, char *);
	ssize_t (*store)(struct device_driver___92 *, const char *, size_t);
};

struct device_driver___92 {
	const char *name;
	struct bus_type___92 *bus;
	struct module___61 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___92 *);
	int (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	const struct attribute_group___85 **groups;
	const struct dev_pm_ops___92 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___92 {
	const char *name;
	const struct attribute_group___85 **groups;
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
};

struct class_attribute___92;

struct class___92 {
	const char *name;
	struct module___61 *owner;
	struct class_attribute___92 *class_attrs;
	struct device_attribute___92 *dev_attrs;
	const struct attribute_group___85 **dev_groups;
	struct bin_attribute___85 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *);
	void (*class_release)(struct class___92 *);
	void (*dev_release)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
	struct subsys_private *p;
};

struct class_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct class___92 *, struct class_attribute___92 *, char *);
	ssize_t (*store)(struct class___92 *, struct class_attribute___92 *, const char *, size_t);
	const void * (*namespace)(struct class___92 *, const struct class_attribute___92 *);
};

struct device_rh___92 {
	struct dev_pm_info_rh___92 power;
};

struct perf_cpu_context___60;

struct pmu___60 {
	struct list_head entry;
	struct device___92 *dev;
	const struct attribute_group___85 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___60 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___60 *);
	void (*pmu_disable)(struct pmu___60 *);
	int (*event_init)(struct perf_event___60 *);
	int (*add)(struct perf_event___60 *, int);
	void (*del)(struct perf_event___60 *, int);
	void (*start)(struct perf_event___60 *, int);
	void (*stop)(struct perf_event___60 *, int);
	void (*read)(struct perf_event___60 *);
	void (*start_txn)(struct pmu___60 *);
	int (*commit_txn)(struct pmu___60 *);
	void (*cancel_txn)(struct pmu___60 *);
	int (*event_idx)(struct perf_event___60 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___61 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___60 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___60 *);
};

struct perf_cpu_context___60 {
	struct perf_event_context___60 ctx;
	struct perf_event_context___60 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___60 *unique_pmu;
	struct perf_cgroup___60 *cgrp;
};

struct trace_event_functions___50;

struct trace_event___50 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___50 *funcs;
};

struct ftrace_event_class___50;

struct ftrace_event_call___50 {
	struct list_head list;
	struct ftrace_event_class___50 *class;
	char *name;
	struct trace_event___50 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___60 {
	struct cgroup_subsys_state___79 css;
	struct perf_cgroup_info *info;
};

struct linux_binprm___15 {
	char buf[128];
	struct vm_area_struct___120 *vma;
	long unsigned int vma_pages;
	struct mm_struct___120 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___115 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___14 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___115 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct module_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___60 *, struct module_kobject___60 *, char *);
	ssize_t (*store)(struct module_attribute___60 *, struct module_kobject___60 *, const char *, size_t);
	void (*setup)(struct module___61 *, const char *);
	int (*test)(struct module___61 *);
	void (*free)(struct module___61 *);
};

struct seq_operations___86 {
	void * (*start)(struct seq_file___87 *, loff_t *);
	void (*stop)(struct seq_file___87 *, void *);
	void * (*next)(struct seq_file___87 *, void *, loff_t *);
	int (*show)(struct seq_file___87 *, void *);
};

struct trace_iterator___50 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___116 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___50)(struct trace_iterator___50 *, int, struct trace_event___50 *);

struct trace_event_functions___50 {
	trace_print_func___50 trace;
	trace_print_func___50 raw;
	trace_print_func___50 hex;
	trace_print_func___50 binary;
};

struct ftrace_event_class___50 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___50 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___50 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___50 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___50 *);
};

struct syscall_metadata___20 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___50 *enter_event;
	struct ftrace_event_call___50 *exit_event;
};

struct pipe_buf_operations___5;

struct pipe_buffer___5 {
	struct page___115 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___5 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___5 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *, int);
	void (*unmap)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *, void *);
	int (*confirm)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	void (*release)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	int (*steal)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	void (*get)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
};

struct tlb_state___33 {
	struct mm_struct___120 *active_mm;
	int state;
};

struct mmu_gather_batch___6 {
	struct mmu_gather_batch___6 *next;
	unsigned int nr;
	unsigned int max;
	struct page___115 *pages[0];
};

struct mmu_gather___6 {
	struct mm_struct___120 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int need_flush: 1;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___6 *active;
	struct mmu_gather_batch___6 local;
	struct page___115 *__pages[8];
	unsigned int batch_count;
};

struct user_arg_ptr {
	bool is_compat;
	union {
		const char * const *native;
		const compat_uptr_t *compat;
	} ptr;
};

struct page___116;

typedef struct page___116 *pgtable_t___116;

struct address_space___116;

struct kmem_cache___103;

struct page___116 {
	long unsigned int flags;
	struct address_space___116 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___116 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___116 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___103 *slab_cache;
		struct page___116 *first_page;
	};
	long: 64;
};

struct thread_struct___61;

struct task_struct___116;

struct pv_cpu_ops___116 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___61 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___61 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___116 *);
	void (*end_context_switch)(struct task_struct___116 *);
};

struct perf_event___61;

struct thread_struct___61 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___61 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___66;

struct pid_link___66 {
	struct hlist_node node;
	struct pid___66 *pid;
};

struct mutex___117 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___116 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___112 {
	struct page___116 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___121;

struct nsproxy___68;

struct signal_struct___116;

struct css_set___79;

struct perf_event_context___61;

struct pipe_inode_info___6;

struct task_struct___116 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___116 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___121 *mm;
	struct mm_struct___121 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___116 *real_parent;
	struct task_struct___116 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___116 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___66 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___116 = 0,
		VTIME_USER___116 = 1,
		VTIME_SYS___116 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___61 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___68 *nsproxy;
	struct signal_struct___116 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___79 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___61 *perf_event_ctxp[2];
	struct mutex___117 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___6 *splice_pipe;
	struct page_frag___112 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___121 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___121 *, struct mm_struct___121 *);
	void (*dup_mmap)(struct mm_struct___121 *, struct mm_struct___121 *);
	void (*exit_mmap)(struct mm_struct___121 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___121 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___121 *);
	void (*pgd_free)(struct mm_struct___121 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___121 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___121 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___121 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___121 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___121 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___121 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___121 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___121 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___121 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___121 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___121 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___117 lock;
	void *vdso;
} mm_context_t___117;

struct xol_area___116;

struct uprobes_state___116 {
	struct xol_area___116 *xol_area;
};

struct vm_area_struct___121;

struct file___116;

struct core_state___116;

struct mm_struct___121 {
	struct vm_area_struct___121 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___121 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___121 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___117 context;
	long unsigned int flags;
	struct core_state___116 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___116 *owner;
	struct file___116 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___116 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___62;

struct exec_domain___32 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___62 *module;
	struct exec_domain___32 *next;
};

struct module_kobject___61 {
	struct kobject___5 kobj;
	struct module___62 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___61;

struct ftrace_event_call___51;

struct module___62 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___61 mkobj;
	struct module_attribute___61 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___51 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___116 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___61 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___116 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___116 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___116 *target;
};

typedef void (*perf_overflow_handler_t___61)(struct perf_event___61 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___61;

typedef void (*ftrace_func_t___61)(long unsigned int, long unsigned int, struct ftrace_ops___61 *, struct pt_regs *);

struct ftrace_ops___61 {
	ftrace_func_t___61 func;
	struct ftrace_ops___61 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___117 regex_lock;
};

struct pmu___61;

struct fasync_struct___116;

struct pid_namespace___66;

struct perf_cgroup___61;

struct perf_event___61 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___61 *group_leader;
	struct pmu___61 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___61 hw;
	struct perf_event_context___61 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___117 child_mutex;
	struct list_head child_list;
	struct perf_event___61 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___116 *owner;
	struct mutex___117 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___116 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___61 *);
	struct callback_head callback_head;
	struct pid_namespace___66 *ns;
	u64 id;
	perf_overflow_handler_t___61 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___51 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___61 ftrace_ops;
	struct perf_cgroup___61 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___61 {
	struct task_struct___116 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___116;

struct lruvec___116 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___116 *zone;
};

struct pglist_data___116;

struct zone___116 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___116 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___116 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___116 {
	struct zone___116 *zone;
	int zone_idx;
};

struct zonelist___116 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___116 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___116 {
	struct zone___116 node_zones[4];
	struct zonelist___116 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___116 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___86;

struct x86_io_apic_ops___86 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___86 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___86;

struct irq_data___86 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___86 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___93;

struct dev_pm_ops___93 {
	int (*prepare)(struct device___93 *);
	void (*complete)(struct device___93 *);
	int (*suspend)(struct device___93 *);
	int (*resume)(struct device___93 *);
	int (*freeze)(struct device___93 *);
	int (*thaw)(struct device___93 *);
	int (*poweroff)(struct device___93 *);
	int (*restore)(struct device___93 *);
	int (*suspend_late)(struct device___93 *);
	int (*resume_early)(struct device___93 *);
	int (*freeze_late)(struct device___93 *);
	int (*thaw_early)(struct device___93 *);
	int (*poweroff_late)(struct device___93 *);
	int (*restore_early)(struct device___93 *);
	int (*suspend_noirq)(struct device___93 *);
	int (*resume_noirq)(struct device___93 *);
	int (*freeze_noirq)(struct device___93 *);
	int (*thaw_noirq)(struct device___93 *);
	int (*poweroff_noirq)(struct device___93 *);
	int (*restore_noirq)(struct device___93 *);
	int (*runtime_suspend)(struct device___93 *);
	int (*runtime_resume)(struct device___93 *);
	int (*runtime_idle)(struct device___93 *);
};

struct device_type___93;

struct bus_type___93;

struct device_driver___93;

struct dev_pm_domain___93;

struct class___93;

struct attribute_group___86;

struct device_rh___93;

struct device___93 {
	struct device___93 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___93 *type;
	struct mutex___117 mutex;
	struct bus_type___93 *bus;
	struct device_driver___93 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___93 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___93 *class;
	const struct attribute_group___86 **groups;
	void (*release)(struct device___93 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___93 *device_rh;
};

struct dev_pm_info_rh___93 {
	void (*set_latency_tolerance)(struct device___93 *, s32);
};

struct dev_pm_domain___93 {
	struct dev_pm_ops___93 ops;
};

struct smp_ops___116 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___116 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___116 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___116 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___103;

struct memcg_cache_params___103;

struct kmem_cache___103 {
	struct kmem_cache_cpu___103 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___103 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___116;

struct address_space_operations___116;

struct address_space___116 {
	struct inode___116 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___117 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___116 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___19;

struct dentry___116;

struct path___116 {
	struct vfsmount___19 *mnt;
	struct dentry___116 *dentry;
};

struct fown_struct___66 {
	rwlock_t lock;
	struct pid___66 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___116;

struct file___116 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___116 f_path;
	struct inode___116 *f_inode;
	const struct file_operations___116 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___66 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___116 *f_mapping;
	struct mutex___117 f_pos_lock;
};

struct vm_operations_struct___103;

struct vm_area_struct___121 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___121 *vm_next;
	struct vm_area_struct___121 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___121 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___103 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___116 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___100;

struct vm_operations_struct___103 {
	void (*open)(struct vm_area_struct___121 *);
	void (*close)(struct vm_area_struct___121 *);
	int (*fault)(struct vm_area_struct___121 *, struct vm_fault___100 *);
	int (*page_mkwrite)(struct vm_area_struct___121 *, struct vm_fault___100 *);
	int (*access)(struct vm_area_struct___121 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___121 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___121 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___121 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___121 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___116 {
	struct task_struct___116 *task;
	struct core_thread___116 *next;
};

struct core_state___116 {
	atomic_t nr_threads;
	struct core_thread___116 dumper;
	struct completion startup;
};

struct vm_fault___100 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___116 *page;
};

struct dentry_operations___116;

struct super_block___116;

struct dentry___116 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___116 *d_parent;
	struct qstr d_name;
	struct inode___116 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___116 *d_op;
	struct super_block___116 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___116;

struct file_lock___116;

struct dquot___116;

struct block_device___116;

struct inode___116 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___116 *i_op;
	struct super_block___116 *i_sb;
	struct address_space___116 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___117 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___116 *i_fop;
	struct file_lock___116 *i_flock;
	struct address_space___116 i_data;
	struct dquot___116 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___6 *i_pipe;
		struct block_device___116 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___116 {
	int (*d_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_hash)(const struct dentry___116 *, struct qstr *);
	int (*d_compare)(const struct dentry___116 *, const struct dentry___116 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___116 *);
	void (*d_release)(struct dentry___116 *);
	void (*d_prune)(struct dentry___116 *);
	void (*d_iput)(struct dentry___116 *, struct inode___116 *);
	char * (*d_dname)(struct dentry___116 *, char *, int);
	struct vfsmount___19 * (*d_automount)(struct path___116 *);
	int (*d_manage)(struct dentry___116 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___116;

struct mem_dqinfo___116 {
	struct quota_format_type___116 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___116;

struct quota_info___116 {
	unsigned int flags;
	struct mutex___117 dqio_mutex;
	struct mutex___117 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___116 *files[2];
	struct mem_dqinfo___116 info[2];
	const struct quota_format_ops___116 *ops[2];
};

struct file_system_type___116;

struct super_operations___116;

struct dquot_operations___116;

struct quotactl_ops___116;

struct xattr_handler___79;

struct super_block___116 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___116 *s_type;
	const struct super_operations___116 *s_op;
	const struct dquot_operations___116 *dq_op;
	const struct quotactl_ops___116 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___116 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___79 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___116 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___116 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___117 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___116 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___19 {
	struct dentry___116 *mnt_root;
	struct super_block___116 *mnt_sb;
	int mnt_flags;
};

struct upid___66 {
	int nr;
	struct pid_namespace___66 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___66 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___116 *child_reaper;
	struct kmem_cache___103 *pid_cachep;
	unsigned int level;
	struct pid_namespace___66 *parent;
	struct vfsmount___19 *proc_mnt;
	struct dentry___116 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___66 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___66 numbers[1];
};

struct block_device___116 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___116 *bd_inode;
	struct super_block___116 *bd_super;
	struct mutex___117 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___116 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___117 bd_fsfreeze_mutex;
};

struct cgroup___79;

struct cgroup_subsys_state___80 {
	struct cgroup___79 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___9;

typedef int kiocb_cancel_fn___9(struct kiocb___9 *, struct io_event *);

struct kiocb___9 {
	atomic_t ki_users;
	struct file___116 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___9 *ki_cancel;
	void (*ki_dtor)(struct kiocb___9 *);
	union {
		void *user;
		struct task_struct___116 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___116 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___116 *ia_file;
};

struct dquot___116 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___117 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___116 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___116 {
	int qf_fmt_id;
	const struct quota_format_ops___116 *qf_ops;
	struct module___62 *qf_owner;
	struct quota_format_type___116 *qf_next;
};

struct quota_format_ops___116 {
	int (*check_quota_file)(struct super_block___116 *, int);
	int (*read_file_info)(struct super_block___116 *, int);
	int (*write_file_info)(struct super_block___116 *, int);
	int (*free_file_info)(struct super_block___116 *, int);
	int (*read_dqblk)(struct dquot___116 *);
	int (*commit_dqblk)(struct dquot___116 *);
	int (*release_dqblk)(struct dquot___116 *);
};

struct dquot_operations___116 {
	int (*write_dquot)(struct dquot___116 *);
	struct dquot___116 * (*alloc_dquot)(struct super_block___116 *, int);
	void (*destroy_dquot)(struct dquot___116 *);
	int (*acquire_dquot)(struct dquot___116 *);
	int (*release_dquot)(struct dquot___116 *);
	int (*mark_dirty)(struct dquot___116 *);
	int (*write_info)(struct super_block___116 *, int);
	qsize_t * (*get_reserved_space)(struct inode___116 *);
};

struct quotactl_ops___116 {
	int (*quota_on)(struct super_block___116 *, int, int, struct path___116 *);
	int (*quota_on_meta)(struct super_block___116 *, int, int);
	int (*quota_off)(struct super_block___116 *, int);
	int (*quota_sync)(struct super_block___116 *, int);
	int (*get_info)(struct super_block___116 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___116 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___116 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___116 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___116 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___116 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___116 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___116 *, unsigned int);
};

struct address_space_operations___116 {
	int (*writepage)(struct page___116 *, struct writeback_control *);
	int (*readpage)(struct file___116 *, struct page___116 *);
	int (*writepages)(struct address_space___116 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___116 *);
	int (*readpages)(struct file___116 *, struct address_space___116 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___116 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___116 **, void **);
	int (*write_end)(struct file___116 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___116 *, void *);
	sector_t (*bmap)(struct address_space___116 *, sector_t);
	void (*invalidatepage)(struct page___116 *, long unsigned int);
	int (*releasepage)(struct page___116 *, gfp_t);
	void (*freepage)(struct page___116 *);
	ssize_t (*direct_IO)(int, struct kiocb___9 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___116 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___116 *, struct page___116 *, struct page___116 *, enum migrate_mode);
	int (*launder_page)(struct page___116 *);
	int (*is_partially_uptodate)(struct page___116 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___116 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___116 *, struct page___116 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___116 *, sector_t *);
	void (*swap_deactivate)(struct file___116 *);
	void (*invalidatepage_range)(struct page___116 *, unsigned int, unsigned int);
};

struct pipe_buffer___6;

struct pipe_inode_info___6 {
	struct mutex___117 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___116 *tmp_page;
	struct fasync_struct___116 *fasync_readers;
	struct fasync_struct___116 *fasync_writers;
	struct pipe_buffer___6 *bufs;
};

struct inode_operations___116 {
	struct dentry___116 * (*lookup)(struct inode___116 *, struct dentry___116 *, unsigned int);
	void * (*follow_link)(struct dentry___116 *, struct nameidata *);
	int (*permission)(struct inode___116 *, int);
	struct posix_acl * (*get_acl)(struct inode___116 *, int);
	int (*readlink)(struct dentry___116 *, char *, int);
	void (*put_link)(struct dentry___116 *, struct nameidata *, void *);
	int (*create)(struct inode___116 *, struct dentry___116 *, umode_t, bool);
	int (*link)(struct dentry___116 *, struct inode___116 *, struct dentry___116 *);
	int (*unlink)(struct inode___116 *, struct dentry___116 *);
	int (*symlink)(struct inode___116 *, struct dentry___116 *, const char *);
	int (*mkdir)(struct inode___116 *, struct dentry___116 *, umode_t);
	int (*rmdir)(struct inode___116 *, struct dentry___116 *);
	int (*mknod)(struct inode___116 *, struct dentry___116 *, umode_t, dev_t);
	int (*rename)(struct inode___116 *, struct dentry___116 *, struct inode___116 *, struct dentry___116 *);
	int (*setattr)(struct dentry___116 *, struct iattr___116 *);
	int (*getattr)(struct vfsmount___19 *, struct dentry___116 *, struct kstat *);
	int (*setxattr)(struct dentry___116 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___116 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___116 *, char *, size_t);
	int (*removexattr)(struct dentry___116 *, const char *);
	int (*fiemap)(struct inode___116 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___116 *, struct timespec *, int);
	int (*atomic_open)(struct inode___116 *, struct dentry___116 *, struct file___116 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___74;

struct seq_file___88;

struct file_operations___116 {
	struct module___62 *owner;
	loff_t (*llseek)(struct file___116 *, loff_t, int);
	ssize_t (*read)(struct file___116 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___116 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___9 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___9 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___116 *, void *, filldir_t);
	unsigned int (*poll)(struct file___116 *, struct poll_table_struct___74 *);
	long int (*unlocked_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___116 *, struct vm_area_struct___121 *);
	int (*open)(struct inode___116 *, struct file___116 *);
	int (*flush)(struct file___116 *, fl_owner_t);
	int (*release)(struct inode___116 *, struct file___116 *);
	int (*fsync)(struct file___116 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___9 *, int);
	int (*fasync)(int, struct file___116 *, int);
	int (*lock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*sendpage)(struct file___116 *, struct page___116 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*splice_write)(struct pipe_inode_info___6 *, struct file___116 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___116 *, loff_t *, struct pipe_inode_info___6 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___116 *, long int, struct file_lock___116 **, void **);
		struct {
			int (*setlease)(struct file___116 *, long int, struct file_lock___116 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___116 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___88 *, struct file___116 *);
};

struct file_lock_operations___116;

struct lock_manager_operations___116;

struct file_lock___116 {
	struct file_lock___116 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___66 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___116 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___116 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___116 *fl_ops;
	const struct lock_manager_operations___116 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

enum inode_i_mutex_lock_class {
	I_MUTEX_NORMAL = 0,
	I_MUTEX_PARENT = 1,
	I_MUTEX_CHILD = 2,
	I_MUTEX_XATTR = 3,
	I_MUTEX_NONDIR2 = 4,
	I_MUTEX_PARENT2 = 5,
};

struct file_lock_operations___116 {
	void (*fl_copy_lock)(struct file_lock___116 *, struct file_lock___116 *);
	void (*fl_release_private)(struct file_lock___116 *);
};

struct lock_manager_operations___116 {
	int (*lm_compare_owner)(struct file_lock___116 *, struct file_lock___116 *);
	long unsigned int (*lm_owner_key)(struct file_lock___116 *);
	void (*lm_notify)(struct file_lock___116 *);
	int (*lm_grant)(struct file_lock___116 *, struct file_lock___116 *, int);
	void (*lm_break)(struct file_lock___116 *);
	int (*lm_change)(struct file_lock___116 **, int);
};

struct fasync_struct___116 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___116 *fa_next;
	struct file___116 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___116 {
	const char *name;
	int fs_flags;
	struct dentry___116 * (*mount)(struct file_system_type___116 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___116 *);
	struct module___62 *owner;
	struct file_system_type___116 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___116 {
	struct inode___116 * (*alloc_inode)(struct super_block___116 *);
	void (*destroy_inode)(struct inode___116 *);
	void (*dirty_inode)(struct inode___116 *, int);
	int (*write_inode)(struct inode___116 *, struct writeback_control *);
	int (*drop_inode)(struct inode___116 *);
	void (*evict_inode)(struct inode___116 *);
	void (*put_super)(struct super_block___116 *);
	int (*sync_fs)(struct super_block___116 *, int);
	int (*freeze_fs)(struct super_block___116 *);
	int (*unfreeze_fs)(struct super_block___116 *);
	int (*statfs)(struct dentry___116 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___116 *, int *, char *);
	void (*umount_begin)(struct super_block___116 *);
	int (*show_options)(struct seq_file___88 *, struct dentry___116 *);
	int (*show_devname)(struct seq_file___88 *, struct dentry___116 *);
	int (*show_path)(struct seq_file___88 *, struct dentry___116 *);
	int (*show_stats)(struct seq_file___88 *, struct dentry___116 *);
	ssize_t (*quota_read)(struct super_block___116 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___116 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___116 *);
	int (*bdev_try_to_free_page)(struct super_block___116 *, struct page___116 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___116 *);
	void (*free_cached_objects)(struct super_block___116 *, int);
};

struct xattr_handler___79 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___116 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___116 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___116 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___76)(struct file___116 *, wait_queue_head_t *, struct poll_table_struct___74 *);

struct poll_table_struct___74 {
	poll_queue_proc___76 _qproc;
	long unsigned int _key;
};

struct seq_operations___87;

struct seq_file___88 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___117 lock;
	const struct seq_operations___87 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nsproxy___68 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___66 *pid_ns;
	struct net *net_ns;
};

typedef struct poll_table_struct___74 poll_table___10;

struct bin_attribute___86;

struct attribute_group___86 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___86 **bin_attrs;
};

struct bin_attribute___86 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___116 *, struct kobject___5 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___116 *, struct kobject___5 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	int (*mmap)(struct file___116 *, struct kobject___5 *, struct bin_attribute___86 *, struct vm_area_struct___121 *);
};

struct kmem_cache_cpu___103 {
	void **freelist;
	long unsigned int tid;
	struct page___116 *page;
	struct page___116 *partial;
};

struct memcg_cache_params___103 {
	bool is_root_cache;
	union {
		struct kmem_cache___103 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___103 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct module_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___61 *, struct module_kobject___61 *, char *);
	ssize_t (*store)(struct module_attribute___61 *, struct module_kobject___61 *, const char *, size_t);
	void (*setup)(struct module___62 *, const char *);
	int (*test)(struct module___62 *);
	void (*free)(struct module___62 *);
};

struct trace_event_functions___51;

struct trace_event___51 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___51 *funcs;
};

struct ftrace_event_class___51;

struct ftrace_event_call___51 {
	struct list_head list;
	struct ftrace_event_class___51 *class;
	char *name;
	struct trace_event___51 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct pipe_buf_operations___6;

struct pipe_buffer___6 {
	struct page___116 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___6 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___6 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *, int);
	void (*unmap)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *, void *);
	int (*confirm)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	void (*release)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	int (*steal)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	void (*get)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
};

struct irq_chip___86 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___86 *);
	void (*irq_shutdown)(struct irq_data___86 *);
	void (*irq_enable)(struct irq_data___86 *);
	void (*irq_disable)(struct irq_data___86 *);
	void (*irq_ack)(struct irq_data___86 *);
	void (*irq_mask)(struct irq_data___86 *);
	void (*irq_mask_ack)(struct irq_data___86 *);
	void (*irq_unmask)(struct irq_data___86 *);
	void (*irq_eoi)(struct irq_data___86 *);
	int (*irq_set_affinity)(struct irq_data___86 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___86 *);
	int (*irq_set_type)(struct irq_data___86 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___86 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___86 *);
	void (*irq_bus_sync_unlock)(struct irq_data___86 *);
	void (*irq_cpu_online)(struct irq_data___86 *);
	void (*irq_cpu_offline)(struct irq_data___86 *);
	void (*irq_suspend)(struct irq_data___86 *);
	void (*irq_resume)(struct irq_data___86 *);
	void (*irq_pm_shutdown)(struct irq_data___86 *);
	void (*irq_print_chip)(struct irq_data___86 *, struct seq_file___88 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___86 *, void *);
	long unsigned int flags;
};

struct signal_struct___116 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___116 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___116 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___66 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___66 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___117 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___79 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___80 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___61 {
	struct pmu___61 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___117 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___116 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___61 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct seq_operations___87 {
	void * (*start)(struct seq_file___88 *, loff_t *);
	void (*stop)(struct seq_file___88 *, void *);
	void * (*next)(struct seq_file___88 *, void *, loff_t *);
	int (*show)(struct seq_file___88 *, void *);
};

struct bus_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___93 *, char *);
	ssize_t (*store)(struct bus_type___93 *, const char *, size_t);
};

struct device_attribute___93;

struct driver_attribute___93;

struct bus_type___93 {
	const char *name;
	const char *dev_name;
	struct device___93 *dev_root;
	struct bus_attribute___93 *bus_attrs;
	struct device_attribute___93 *dev_attrs;
	struct driver_attribute___93 *drv_attrs;
	const struct attribute_group___86 **bus_groups;
	const struct attribute_group___86 **dev_groups;
	const struct attribute_group___86 **drv_groups;
	int (*match)(struct device___93 *, struct device_driver___93 *);
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	int (*probe)(struct device___93 *);
	int (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*online)(struct device___93 *);
	int (*offline)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct device___93 *, struct device_attribute___93 *, char *);
	ssize_t (*store)(struct device___93 *, struct device_attribute___93 *, const char *, size_t);
};

struct driver_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___93 *, char *);
	ssize_t (*store)(struct device_driver___93 *, const char *, size_t);
};

struct device_driver___93 {
	const char *name;
	struct bus_type___93 *bus;
	struct module___62 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___93 *);
	int (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	const struct attribute_group___86 **groups;
	const struct dev_pm_ops___93 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___93 {
	const char *name;
	const struct attribute_group___86 **groups;
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
};

struct class_attribute___93;

struct class___93 {
	const char *name;
	struct module___62 *owner;
	struct class_attribute___93 *class_attrs;
	struct device_attribute___93 *dev_attrs;
	const struct attribute_group___86 **dev_groups;
	struct bin_attribute___86 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *);
	void (*class_release)(struct class___93 *);
	void (*dev_release)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
	struct subsys_private *p;
};

struct class_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct class___93 *, struct class_attribute___93 *, char *);
	ssize_t (*store)(struct class___93 *, struct class_attribute___93 *, const char *, size_t);
	const void * (*namespace)(struct class___93 *, const struct class_attribute___93 *);
};

struct device_rh___93 {
	struct dev_pm_info_rh___93 power;
};

struct cgroupfs_root___79;

struct cgroup___79 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___79 *parent;
	struct dentry___116 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___80 *subsys[11];
	struct cgroupfs_root___79 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___117 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___79 {
	struct super_block___116 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___79 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___61;

struct pmu___61 {
	struct list_head entry;
	struct device___93 *dev;
	const struct attribute_group___86 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___61 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___61 *);
	void (*pmu_disable)(struct pmu___61 *);
	int (*event_init)(struct perf_event___61 *);
	int (*add)(struct perf_event___61 *, int);
	void (*del)(struct perf_event___61 *, int);
	void (*start)(struct perf_event___61 *, int);
	void (*stop)(struct perf_event___61 *, int);
	void (*read)(struct perf_event___61 *);
	void (*start_txn)(struct pmu___61 *);
	int (*commit_txn)(struct pmu___61 *);
	void (*cancel_txn)(struct pmu___61 *);
	int (*event_idx)(struct perf_event___61 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___62 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___61 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___61 *);
};

struct perf_cpu_context___61 {
	struct perf_event_context___61 ctx;
	struct perf_event_context___61 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___61 *unique_pmu;
	struct perf_cgroup___61 *cgrp;
};

struct perf_cgroup___61 {
	struct cgroup_subsys_state___80 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___51 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___117 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___51)(struct trace_iterator___51 *, int, struct trace_event___51 *);

struct trace_event_functions___51 {
	trace_print_func___51 trace;
	trace_print_func___51 raw;
	trace_print_func___51 hex;
	trace_print_func___51 binary;
};

struct ftrace_event_class___51 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___51 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___51 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___51 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___51 *);
};

struct syscall_metadata___21 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___51 *enter_event;
	struct ftrace_event_call___51 *exit_event;
};

typedef int (*iop_rename2_t)(struct inode___115 *, struct dentry___115 *, struct inode___115 *, struct dentry___115 *, unsigned int);

struct inode_operations_wrapper___3 {
	struct inode_operations___115 ops;
	unsigned int version;
	int (*rename2)(struct inode___115 *, struct dentry___115 *, struct inode___115 *, struct dentry___115 *, unsigned int);
	int (*dentry_open)(struct dentry___115 *, struct file___115 *, const struct cred *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	LAST_NORM = 0,
	LAST_ROOT = 1,
	LAST_DOT = 2,
	LAST_DOTDOT = 3,
	LAST_BIND = 4,
};

typedef int filler_t___4(void *, struct page___115 *);

struct mount;

struct mnt_namespace {
	atomic_t count;
	unsigned int proc_inum;
	struct mount *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct fd___9 {
	struct file___115 *file;
	unsigned int flags;
};

struct mnt_pcp;

struct mountpoint;

struct mount {
	struct list_head mnt_hash;
	struct mount *mnt_parent;
	struct dentry___115 *mnt_mountpoint;
	struct vfsmount___18 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount *mnt_master;
	struct mnt_namespace *mnt_ns;
	struct mountpoint *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mnt_pcp {
	int mnt_count;
	int mnt_writers;
};

struct mountpoint {
	struct list_head m_hash;
	struct dentry___115 *m_dentry;
	int m_count;
};

struct word_at_a_time {
	const long unsigned int one_bits;
	const long unsigned int high_bits;
};

struct page___117;

typedef struct page___117 *pgtable_t___117;

struct address_space___117;

struct kmem_cache___104;

struct page___117 {
	long unsigned int flags;
	struct address_space___117 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___117 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___117 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___104 *slab_cache;
		struct page___117 *first_page;
	};
	long: 64;
};

struct thread_struct___62;

struct task_struct___117;

struct pv_cpu_ops___117 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___62 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___62 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___117 *);
	void (*end_context_switch)(struct task_struct___117 *);
};

struct perf_event___62;

struct thread_struct___62 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___62 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___67;

struct pid_link___67 {
	struct hlist_node node;
	struct pid___67 *pid;
};

struct mutex___118 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___117 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___113 {
	struct page___117 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___122;

struct files_struct___7;

struct nsproxy___69;

struct signal_struct___117;

struct css_set___80;

struct perf_event_context___62;

struct pipe_inode_info___7;

struct task_struct___117 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___117 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___122 *mm;
	struct mm_struct___122 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___117 *real_parent;
	struct task_struct___117 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___117 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___67 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___117 = 0,
		VTIME_USER___117 = 1,
		VTIME_SYS___117 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___62 thread;
	struct fs_struct *fs;
	struct files_struct___7 *files;
	struct nsproxy___69 *nsproxy;
	struct signal_struct___117 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___80 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___62 *perf_event_ctxp[2];
	struct mutex___118 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___7 *splice_pipe;
	struct page_frag___113 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___122 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___122 *, struct mm_struct___122 *);
	void (*dup_mmap)(struct mm_struct___122 *, struct mm_struct___122 *);
	void (*exit_mmap)(struct mm_struct___122 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___122 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___122 *);
	void (*pgd_free)(struct mm_struct___122 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___122 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___122 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___122 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___122 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___122 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___122 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___122 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___122 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___122 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___122 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___122 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___118 lock;
	void *vdso;
} mm_context_t___118;

struct xol_area___117;

struct uprobes_state___117 {
	struct xol_area___117 *xol_area;
};

struct vm_area_struct___122;

struct file___117;

struct core_state___117;

struct mm_struct___122 {
	struct vm_area_struct___122 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___122 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___122 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___118 context;
	long unsigned int flags;
	struct core_state___117 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___117 *owner;
	struct file___117 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___117 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___63;

struct module_kobject___62 {
	struct kobject___5 kobj;
	struct module___63 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___62;

struct ftrace_event_call___52;

struct module___63 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___62 mkobj;
	struct module_attribute___62 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___52 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___117 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___62 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___117 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___117 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___117 *target;
};

typedef void (*perf_overflow_handler_t___62)(struct perf_event___62 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___62;

typedef void (*ftrace_func_t___62)(long unsigned int, long unsigned int, struct ftrace_ops___62 *, struct pt_regs *);

struct ftrace_ops___62 {
	ftrace_func_t___62 func;
	struct ftrace_ops___62 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___118 regex_lock;
};

struct pmu___62;

struct fasync_struct___117;

struct pid_namespace___67;

struct perf_cgroup___62;

struct perf_event___62 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___62 *group_leader;
	struct pmu___62 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___62 hw;
	struct perf_event_context___62 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___118 child_mutex;
	struct list_head child_list;
	struct perf_event___62 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___117 *owner;
	struct mutex___118 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___117 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___62 *);
	struct callback_head callback_head;
	struct pid_namespace___67 *ns;
	u64 id;
	perf_overflow_handler_t___62 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___52 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___62 ftrace_ops;
	struct perf_cgroup___62 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct irq_data___87;

struct x86_io_apic_ops___87 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___87 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___87;

struct irq_data___87 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___87 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___94;

struct dev_pm_ops___94 {
	int (*prepare)(struct device___94 *);
	void (*complete)(struct device___94 *);
	int (*suspend)(struct device___94 *);
	int (*resume)(struct device___94 *);
	int (*freeze)(struct device___94 *);
	int (*thaw)(struct device___94 *);
	int (*poweroff)(struct device___94 *);
	int (*restore)(struct device___94 *);
	int (*suspend_late)(struct device___94 *);
	int (*resume_early)(struct device___94 *);
	int (*freeze_late)(struct device___94 *);
	int (*thaw_early)(struct device___94 *);
	int (*poweroff_late)(struct device___94 *);
	int (*restore_early)(struct device___94 *);
	int (*suspend_noirq)(struct device___94 *);
	int (*resume_noirq)(struct device___94 *);
	int (*freeze_noirq)(struct device___94 *);
	int (*thaw_noirq)(struct device___94 *);
	int (*poweroff_noirq)(struct device___94 *);
	int (*restore_noirq)(struct device___94 *);
	int (*runtime_suspend)(struct device___94 *);
	int (*runtime_resume)(struct device___94 *);
	int (*runtime_idle)(struct device___94 *);
};

struct device_type___94;

struct bus_type___94;

struct device_driver___94;

struct dev_pm_domain___94;

struct class___94;

struct attribute_group___87;

struct device_rh___94;

struct device___94 {
	struct device___94 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___94 *type;
	struct mutex___118 mutex;
	struct bus_type___94 *bus;
	struct device_driver___94 *driver;
	void *platform_data;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___94 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___32 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___94 *class;
	const struct attribute_group___87 **groups;
	void (*release)(struct device___94 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___94 *device_rh;
};

struct dev_pm_info_rh___94 {
	void (*set_latency_tolerance)(struct device___94 *, s32);
};

struct dev_pm_domain___94 {
	struct dev_pm_ops___94 ops;
};

struct smp_ops___117 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___117 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___117;

struct lruvec___117 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___117 *zone;
};

struct pglist_data___117;

struct zone___117 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___117 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___117 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___117 {
	struct zone___117 *zone;
	int zone_idx;
};

struct zonelist___117 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___117 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___117 {
	struct zone___117 node_zones[4];
	struct zonelist___117 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___117 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___117;

struct dquot___117 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___118 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___117 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___117;

struct mem_dqinfo___117 {
	struct quota_format_type___117 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___117;

struct quota_format_ops___117;

struct quota_info___117 {
	unsigned int flags;
	struct mutex___118 dqio_mutex;
	struct mutex___118 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___117 *files[2];
	struct mem_dqinfo___117 info[2];
	const struct quota_format_ops___117 *ops[2];
};

struct file_system_type___117;

struct super_operations___117;

struct dquot_operations___117;

struct quotactl_ops___117;

struct dentry___117;

struct xattr_handler___80;

struct block_device___117;

struct dentry_operations___117;

struct super_block___117 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___117 *s_type;
	const struct super_operations___117 *s_op;
	const struct dquot_operations___117 *dq_op;
	const struct quotactl_ops___117 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___117 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___80 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___117 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___117 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___118 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___117 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___117 {
	int qf_fmt_id;
	const struct quota_format_ops___117 *qf_ops;
	struct module___63 *qf_owner;
	struct quota_format_type___117 *qf_next;
};

struct quota_format_ops___117 {
	int (*check_quota_file)(struct super_block___117 *, int);
	int (*read_file_info)(struct super_block___117 *, int);
	int (*write_file_info)(struct super_block___117 *, int);
	int (*free_file_info)(struct super_block___117 *, int);
	int (*read_dqblk)(struct dquot___117 *);
	int (*commit_dqblk)(struct dquot___117 *);
	int (*release_dqblk)(struct dquot___117 *);
};

struct dquot_operations___117 {
	int (*write_dquot)(struct dquot___117 *);
	struct dquot___117 * (*alloc_dquot)(struct super_block___117 *, int);
	void (*destroy_dquot)(struct dquot___117 *);
	int (*acquire_dquot)(struct dquot___117 *);
	int (*release_dquot)(struct dquot___117 *);
	int (*mark_dirty)(struct dquot___117 *);
	int (*write_info)(struct super_block___117 *, int);
	qsize_t * (*get_reserved_space)(struct inode___117 *);
};

struct address_space_operations___117;

struct address_space___117 {
	struct inode___117 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___118 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___117 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___117;

struct file_operations___117;

struct file_lock___117;

struct inode___117 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___117 *i_op;
	struct super_block___117 *i_sb;
	struct address_space___117 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___118 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___117 *i_fop;
	struct file_lock___117 *i_flock;
	struct address_space___117 i_data;
	struct dquot___117 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___7 *i_pipe;
		struct block_device___117 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___117;

struct quotactl_ops___117 {
	int (*quota_on)(struct super_block___117 *, int, int, struct path___117 *);
	int (*quota_on_meta)(struct super_block___117 *, int, int);
	int (*quota_off)(struct super_block___117 *, int);
	int (*quota_sync)(struct super_block___117 *, int);
	int (*get_info)(struct super_block___117 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___117 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___117 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___117 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___117 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___117 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___117 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___117 *, unsigned int);
};

struct path___117 {
	struct vfsmount *mnt;
	struct dentry___117 *dentry;
};

struct nsproxy___69 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___67 *pid_ns;
	struct net *net_ns;
};

struct xol_area___117 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___117 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___104;

struct memcg_cache_params___104;

struct kmem_cache___104 {
	struct kmem_cache_cpu___104 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___5 kobj;
	struct memcg_cache_params___104 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___67 {
	rwlock_t lock;
	struct pid___67 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___117 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___117 f_path;
	struct inode___117 *f_inode;
	const struct file_operations___117 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___67 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___117 *f_mapping;
	struct mutex___118 f_pos_lock;
};

struct vm_operations_struct___104;

struct vm_area_struct___122 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___122 *vm_next;
	struct vm_area_struct___122 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___122 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___104 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___117 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___101;

struct vm_operations_struct___104 {
	void (*open)(struct vm_area_struct___122 *);
	void (*close)(struct vm_area_struct___122 *);
	int (*fault)(struct vm_area_struct___122 *, struct vm_fault___101 *);
	int (*page_mkwrite)(struct vm_area_struct___122 *, struct vm_fault___101 *);
	int (*access)(struct vm_area_struct___122 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___122 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___122 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___122 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___122 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___117 {
	struct task_struct___117 *task;
	struct core_thread___117 *next;
};

struct core_state___117 {
	atomic_t nr_threads;
	struct core_thread___117 dumper;
	struct completion startup;
};

struct vm_fault___101 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___117 *page;
};

struct seq_operations___88;

struct seq_file___89 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___118 lock;
	const struct seq_operations___88 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___88 {
	void * (*start)(struct seq_file___89 *, loff_t *);
	void (*stop)(struct seq_file___89 *, void *);
	void * (*next)(struct seq_file___89 *, void *, loff_t *);
	int (*show)(struct seq_file___89 *, void *);
};

struct dentry___117 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___117 *d_parent;
	struct qstr d_name;
	struct inode___117 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___117 *d_op;
	struct super_block___117 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___117 {
	int (*d_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_hash)(const struct dentry___117 *, struct qstr *);
	int (*d_compare)(const struct dentry___117 *, const struct dentry___117 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___117 *);
	void (*d_release)(struct dentry___117 *);
	void (*d_prune)(struct dentry___117 *);
	void (*d_iput)(struct dentry___117 *, struct inode___117 *);
	char * (*d_dname)(struct dentry___117 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___117 *);
	int (*d_manage)(struct dentry___117 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___67 {
	int nr;
	struct pid_namespace___67 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___67 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___117 *child_reaper;
	struct kmem_cache___104 *pid_cachep;
	unsigned int level;
	struct pid_namespace___67 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___117 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___67 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___67 numbers[1];
};

struct block_device___117 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___117 *bd_inode;
	struct super_block___117 *bd_super;
	struct mutex___118 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___117 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___118 bd_fsfreeze_mutex;
};

struct cgroup___80;

struct cgroup_subsys_state___81 {
	struct cgroup___80 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___117 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___117 *ia_file;
};

struct address_space_operations___117 {
	int (*writepage)(struct page___117 *, struct writeback_control *);
	int (*readpage)(struct file___117 *, struct page___117 *);
	int (*writepages)(struct address_space___117 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___117 *);
	int (*readpages)(struct file___117 *, struct address_space___117 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___117 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___117 **, void **);
	int (*write_end)(struct file___117 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___117 *, void *);
	sector_t (*bmap)(struct address_space___117 *, sector_t);
	void (*invalidatepage)(struct page___117 *, long unsigned int);
	int (*releasepage)(struct page___117 *, gfp_t);
	void (*freepage)(struct page___117 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___117 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___117 *, struct page___117 *, struct page___117 *, enum migrate_mode);
	int (*launder_page)(struct page___117 *);
	int (*is_partially_uptodate)(struct page___117 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___117 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___117 *, struct page___117 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___117 *, sector_t *);
	void (*swap_deactivate)(struct file___117 *);
	void (*invalidatepage_range)(struct page___117 *, unsigned int, unsigned int);
};

struct pipe_buffer___7;

struct pipe_inode_info___7 {
	struct mutex___118 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___117 *tmp_page;
	struct fasync_struct___117 *fasync_readers;
	struct fasync_struct___117 *fasync_writers;
	struct pipe_buffer___7 *bufs;
};

struct inode_operations___117 {
	struct dentry___117 * (*lookup)(struct inode___117 *, struct dentry___117 *, unsigned int);
	void * (*follow_link)(struct dentry___117 *, struct nameidata *);
	int (*permission)(struct inode___117 *, int);
	struct posix_acl * (*get_acl)(struct inode___117 *, int);
	int (*readlink)(struct dentry___117 *, char *, int);
	void (*put_link)(struct dentry___117 *, struct nameidata *, void *);
	int (*create)(struct inode___117 *, struct dentry___117 *, umode_t, bool);
	int (*link)(struct dentry___117 *, struct inode___117 *, struct dentry___117 *);
	int (*unlink)(struct inode___117 *, struct dentry___117 *);
	int (*symlink)(struct inode___117 *, struct dentry___117 *, const char *);
	int (*mkdir)(struct inode___117 *, struct dentry___117 *, umode_t);
	int (*rmdir)(struct inode___117 *, struct dentry___117 *);
	int (*mknod)(struct inode___117 *, struct dentry___117 *, umode_t, dev_t);
	int (*rename)(struct inode___117 *, struct dentry___117 *, struct inode___117 *, struct dentry___117 *);
	int (*setattr)(struct dentry___117 *, struct iattr___117 *);
	int (*getattr)(struct vfsmount *, struct dentry___117 *, struct kstat *);
	int (*setxattr)(struct dentry___117 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___117 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___117 *, char *, size_t);
	int (*removexattr)(struct dentry___117 *, const char *);
	int (*fiemap)(struct inode___117 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___117 *, struct timespec *, int);
	int (*atomic_open)(struct inode___117 *, struct dentry___117 *, struct file___117 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___7 *fl_owner_t___7;

struct poll_table_struct___75;

struct file_operations___117 {
	struct module___63 *owner;
	loff_t (*llseek)(struct file___117 *, loff_t, int);
	ssize_t (*read)(struct file___117 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___117 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___117 *, void *, filldir_t);
	unsigned int (*poll)(struct file___117 *, struct poll_table_struct___75 *);
	long int (*unlocked_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___117 *, struct vm_area_struct___122 *);
	int (*open)(struct inode___117 *, struct file___117 *);
	int (*flush)(struct file___117 *, fl_owner_t___7);
	int (*release)(struct inode___117 *, struct file___117 *);
	int (*fsync)(struct file___117 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___117 *, int);
	int (*lock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*sendpage)(struct file___117 *, struct page___117 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*splice_write)(struct pipe_inode_info___7 *, struct file___117 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___117 *, loff_t *, struct pipe_inode_info___7 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___117 *, long int, struct file_lock___117 **, void **);
		struct {
			int (*setlease)(struct file___117 *, long int, struct file_lock___117 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___117 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___89 *, struct file___117 *);
};

struct file_lock_operations___117;

struct lock_manager_operations___117;

struct file_lock___117 {
	struct file_lock___117 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___7 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___67 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___117 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___117 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___117 *fl_ops;
	const struct lock_manager_operations___117 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___7 {
	unsigned int max_fds;
	struct file___117 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___7 {
	atomic_t count;
	struct fdtable___7 *fdt;
	struct fdtable___7 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___117 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___117 {
	void (*fl_copy_lock)(struct file_lock___117 *, struct file_lock___117 *);
	void (*fl_release_private)(struct file_lock___117 *);
};

struct lock_manager_operations___117 {
	int (*lm_compare_owner)(struct file_lock___117 *, struct file_lock___117 *);
	long unsigned int (*lm_owner_key)(struct file_lock___117 *);
	void (*lm_notify)(struct file_lock___117 *);
	int (*lm_grant)(struct file_lock___117 *, struct file_lock___117 *, int);
	void (*lm_break)(struct file_lock___117 *);
	int (*lm_change)(struct file_lock___117 **, int);
};

struct fasync_struct___117 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___117 *fa_next;
	struct file___117 *fa_file;
	struct callback_head fa_rcu;
};

struct f_owner_ex {
	int type;
	__kernel_pid_t pid;
};

struct flock {
	short int l_type;
	short int l_whence;
	__kernel_off_t l_start;
	__kernel_off_t l_len;
	__kernel_pid_t l_pid;
};

struct file_system_type___117 {
	const char *name;
	int fs_flags;
	struct dentry___117 * (*mount)(struct file_system_type___117 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___117 *);
	struct module___63 *owner;
	struct file_system_type___117 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___117 {
	struct inode___117 * (*alloc_inode)(struct super_block___117 *);
	void (*destroy_inode)(struct inode___117 *);
	void (*dirty_inode)(struct inode___117 *, int);
	int (*write_inode)(struct inode___117 *, struct writeback_control *);
	int (*drop_inode)(struct inode___117 *);
	void (*evict_inode)(struct inode___117 *);
	void (*put_super)(struct super_block___117 *);
	int (*sync_fs)(struct super_block___117 *, int);
	int (*freeze_fs)(struct super_block___117 *);
	int (*unfreeze_fs)(struct super_block___117 *);
	int (*statfs)(struct dentry___117 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___117 *, int *, char *);
	void (*umount_begin)(struct super_block___117 *);
	int (*show_options)(struct seq_file___89 *, struct dentry___117 *);
	int (*show_devname)(struct seq_file___89 *, struct dentry___117 *);
	int (*show_path)(struct seq_file___89 *, struct dentry___117 *);
	int (*show_stats)(struct seq_file___89 *, struct dentry___117 *);
	ssize_t (*quota_read)(struct super_block___117 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___117 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___117 *);
	int (*bdev_try_to_free_page)(struct super_block___117 *, struct page___117 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___117 *);
	void (*free_cached_objects)(struct super_block___117 *, int);
};

struct xattr_handler___80 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___117 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___117 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___117 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___77)(struct file___117 *, wait_queue_head_t *, struct poll_table_struct___75 *);

struct poll_table_struct___75 {
	poll_queue_proc___77 _qproc;
	long unsigned int _key;
};

struct irq_chip___87 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___87 *);
	void (*irq_shutdown)(struct irq_data___87 *);
	void (*irq_enable)(struct irq_data___87 *);
	void (*irq_disable)(struct irq_data___87 *);
	void (*irq_ack)(struct irq_data___87 *);
	void (*irq_mask)(struct irq_data___87 *);
	void (*irq_mask_ack)(struct irq_data___87 *);
	void (*irq_unmask)(struct irq_data___87 *);
	void (*irq_eoi)(struct irq_data___87 *);
	int (*irq_set_affinity)(struct irq_data___87 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___87 *);
	int (*irq_set_type)(struct irq_data___87 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___87 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___87 *);
	void (*irq_bus_sync_unlock)(struct irq_data___87 *);
	void (*irq_cpu_online)(struct irq_data___87 *);
	void (*irq_cpu_offline)(struct irq_data___87 *);
	void (*irq_suspend)(struct irq_data___87 *);
	void (*irq_resume)(struct irq_data___87 *);
	void (*irq_pm_shutdown)(struct irq_data___87 *);
	void (*irq_print_chip)(struct irq_data___87 *, struct seq_file___89 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___87 *, void *);
	long unsigned int flags;
};

struct signal_struct___117 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___117 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___117 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___67 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___67 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___118 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___80 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___81 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___62 {
	struct pmu___62 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___118 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___117 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___62 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___87;

struct attribute_group___87 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___87 **bin_attrs;
};

struct bin_attribute___87 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___117 *, struct kobject___5 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___117 *, struct kobject___5 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	int (*mmap)(struct file___117 *, struct kobject___5 *, struct bin_attribute___87 *, struct vm_area_struct___122 *);
};

struct bus_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___94 *, char *);
	ssize_t (*store)(struct bus_type___94 *, const char *, size_t);
};

struct device_attribute___94;

struct driver_attribute___94;

struct bus_type___94 {
	const char *name;
	const char *dev_name;
	struct device___94 *dev_root;
	struct bus_attribute___94 *bus_attrs;
	struct device_attribute___94 *dev_attrs;
	struct driver_attribute___94 *drv_attrs;
	const struct attribute_group___87 **bus_groups;
	const struct attribute_group___87 **dev_groups;
	const struct attribute_group___87 **drv_groups;
	int (*match)(struct device___94 *, struct device_driver___94 *);
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	int (*probe)(struct device___94 *);
	int (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*online)(struct device___94 *);
	int (*offline)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct device___94 *, struct device_attribute___94 *, char *);
	ssize_t (*store)(struct device___94 *, struct device_attribute___94 *, const char *, size_t);
};

struct driver_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___94 *, char *);
	ssize_t (*store)(struct device_driver___94 *, const char *, size_t);
};

struct device_driver___94 {
	const char *name;
	struct bus_type___94 *bus;
	struct module___63 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___94 *);
	int (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	const struct attribute_group___87 **groups;
	const struct dev_pm_ops___94 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___94 {
	const char *name;
	const struct attribute_group___87 **groups;
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
};

struct class_attribute___94;

struct class___94 {
	const char *name;
	struct module___63 *owner;
	struct class_attribute___94 *class_attrs;
	struct device_attribute___94 *dev_attrs;
	const struct attribute_group___87 **dev_groups;
	struct bin_attribute___87 *dev_bin_attrs;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *);
	void (*class_release)(struct class___94 *);
	void (*dev_release)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
	struct subsys_private *p;
};

struct class_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct class___94 *, struct class_attribute___94 *, char *);
	ssize_t (*store)(struct class___94 *, struct class_attribute___94 *, const char *, size_t);
	const void * (*namespace)(struct class___94 *, const struct class_attribute___94 *);
};

struct device_rh___94 {
	struct dev_pm_info_rh___94 power;
};

struct kmem_cache_cpu___104 {
	void **freelist;
	long unsigned int tid;
	struct page___117 *page;
	struct page___117 *partial;
};

struct memcg_cache_params___104 {
	bool is_root_cache;
	union {
		struct kmem_cache___104 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___104 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___80;

struct cgroup___80 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___80 *parent;
	struct dentry___117 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___81 *subsys[11];
	struct cgroupfs_root___80 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___118 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___80 {
	struct super_block___117 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___80 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___62;

struct pmu___62 {
	struct list_head entry;
	struct device___94 *dev;
	const struct attribute_group___87 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___62 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___62 *);
	void (*pmu_disable)(struct pmu___62 *);
	int (*event_init)(struct perf_event___62 *);
	int (*add)(struct perf_event___62 *, int);
	void (*del)(struct perf_event___62 *, int);
	void (*start)(struct perf_event___62 *, int);
	void (*stop)(struct perf_event___62 *, int);
	void (*read)(struct perf_event___62 *);
	void (*start_txn)(struct pmu___62 *);
	int (*commit_txn)(struct pmu___62 *);
	void (*cancel_txn)(struct pmu___62 *);
	int (*event_idx)(struct perf_event___62 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___63 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___62 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___62 *);
};

struct perf_cpu_context___62 {
	struct perf_event_context___62 ctx;
	struct perf_event_context___62 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___62 *unique_pmu;
	struct perf_cgroup___62 *cgrp;
};

struct trace_event_functions___52;

struct trace_event___52 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___52 *funcs;
};

struct ftrace_event_class___52;

struct ftrace_event_call___52 {
	struct list_head list;
	struct ftrace_event_class___52 *class;
	char *name;
	struct trace_event___52 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___62 {
	struct cgroup_subsys_state___81 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___52 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___118 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___52)(struct trace_iterator___52 *, int, struct trace_event___52 *);

struct trace_event_functions___52 {
	trace_print_func___52 trace;
	trace_print_func___52 raw;
	trace_print_func___52 hex;
	trace_print_func___52 binary;
};

struct ftrace_event_class___52 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___52 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___52 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___52 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___52 *);
};

struct syscall_metadata___22 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___52 *enter_event;
	struct ftrace_event_call___52 *exit_event;
};

struct fd___10 {
	struct file___117 *file;
	unsigned int flags;
};

struct module_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___62 *, struct module_kobject___62 *, char *);
	ssize_t (*store)(struct module_attribute___62 *, struct module_kobject___62 *, const char *, size_t);
	void (*setup)(struct module___63 *, const char *);
	int (*test)(struct module___63 *);
	void (*free)(struct module___63 *);
};

struct pipe_buf_operations___7;

struct pipe_buffer___7 {
	struct page___117 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___7 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___7 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *, int);
	void (*unmap)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *, void *);
	int (*confirm)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	void (*release)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	int (*steal)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	void (*get)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
};

struct fiemap {
	__u64 fm_start;
	__u64 fm_length;
	__u32 fm_flags;
	__u32 fm_mapped_extents;
	__u32 fm_extent_count;
	__u32 fm_reserved;
	struct fiemap_extent fm_extents[0];
};

typedef int get_block_t(struct inode___117 *, sector_t, struct buffer_head *, int);

struct space_resv {
	__s16 l_type;
	__s16 l_whence;
	__s64 l_start;
	__s64 l_len;
	__s32 l_sysid;
	__u32 l_pid;
	__s32 l_pad[4];
};

struct linux_dirent64 {
	u64 d_ino;
	s64 d_off;
	short unsigned int d_reclen;
	unsigned char d_type;
	char d_name[0];
};

struct old_linux_dirent {
	long unsigned int d_ino;
	long unsigned int d_offset;
	short unsigned int d_namlen;
	char d_name[1];
};

struct readdir_callback {
	struct old_linux_dirent *dirent;
	int result;
};

struct linux_dirent {
	long unsigned int d_ino;
	long unsigned int d_off;
	short unsigned int d_reclen;
	char d_name[1];
};

struct getdents_callback {
	struct linux_dirent *current_dir;
	struct linux_dirent *previous;
	int count;
	int error;
};

struct getdents_callback64 {
	struct linux_dirent64 *current_dir;
	struct linux_dirent64 *previous;
	int count;
	int error;
};

typedef struct {
	long unsigned int fds_bits[16];
} __kernel_fd_set;

typedef __kernel_fd_set fd_set;

struct page___118;

typedef struct page___118 *pgtable_t___118;

struct address_space___118;

struct kmem_cache___105;

struct page___118 {
	long unsigned int flags;
	struct address_space___118 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___118 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___118 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___105 *slab_cache;
		struct page___118 *first_page;
	};
	long: 64;
};

struct thread_struct___63;

struct task_struct___118;

struct pv_cpu_ops___118 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___63 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___63 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___118 *);
	void (*end_context_switch)(struct task_struct___118 *);
};

struct perf_event___63;

struct thread_struct___63 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___63 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___68;

struct pid_link___68 {
	struct hlist_node node;
	struct pid___68 *pid;
};

struct mutex___119 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___118 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___114 {
	struct page___118 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___123;

struct files_struct___8;

struct nsproxy___70;

struct signal_struct___118;

struct css_set___81;

struct perf_event_context___63;

struct task_struct___118 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___118 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___123 *mm;
	struct mm_struct___123 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___118 *real_parent;
	struct task_struct___118 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___118 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___68 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___118 = 0,
		VTIME_USER___118 = 1,
		VTIME_SYS___118 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___63 thread;
	struct fs_struct *fs;
	struct files_struct___8 *files;
	struct nsproxy___70 *nsproxy;
	struct signal_struct___118 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___81 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___63 *perf_event_ctxp[2];
	struct mutex___119 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___114 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___123 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___123 *, struct mm_struct___123 *);
	void (*dup_mmap)(struct mm_struct___123 *, struct mm_struct___123 *);
	void (*exit_mmap)(struct mm_struct___123 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___123 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___123 *);
	void (*pgd_free)(struct mm_struct___123 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___123 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___123 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___123 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___123 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___123 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___123 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___123 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___123 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___123 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___123 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___123 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___119 lock;
	void *vdso;
} mm_context_t___119;

struct xol_area___118;

struct uprobes_state___118 {
	struct xol_area___118 *xol_area;
};

struct vm_area_struct___123;

struct file___118;

struct core_state___118;

struct mm_struct___123 {
	struct vm_area_struct___123 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___123 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___123 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___119 context;
	long unsigned int flags;
	struct core_state___118 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___118 *owner;
	struct file___118 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___118 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___63 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___118 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___118 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___118 *target;
};

typedef void (*perf_overflow_handler_t___63)(struct perf_event___63 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___63;

typedef void (*ftrace_func_t___63)(long unsigned int, long unsigned int, struct ftrace_ops___63 *, struct pt_regs *);

struct ftrace_ops___63 {
	ftrace_func_t___63 func;
	struct ftrace_ops___63 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___119 regex_lock;
};

struct pmu___63;

struct fasync_struct___118;

struct pid_namespace___68;

struct ftrace_event_call___53;

struct perf_cgroup___63;

struct perf_event___63 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___63 *group_leader;
	struct pmu___63 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___63 hw;
	struct perf_event_context___63 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___119 child_mutex;
	struct list_head child_list;
	struct perf_event___63 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___118 *owner;
	struct mutex___119 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___118 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___63 *);
	struct callback_head callback_head;
	struct pid_namespace___68 *ns;
	u64 id;
	perf_overflow_handler_t___63 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___53 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___63 ftrace_ops;
	struct perf_cgroup___63 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___62 {
	struct task_struct___118 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___118 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___118 *page;
	long unsigned int vaddr;
};

struct kset___6;

struct kobj_type___6;

struct kobject___6 {
	const char *name;
	struct list_head entry;
	struct kobject___6 *parent;
	struct kset___6 *kset;
	struct kobj_type___6 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___105;

struct memcg_cache_params___105;

struct kmem_cache___105 {
	struct kmem_cache_cpu___105 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___105 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___118;

struct address_space_operations___118;

struct address_space___118 {
	struct inode___118 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___119 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___118 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___118;

struct path___118 {
	struct vfsmount *mnt;
	struct dentry___118 *dentry;
};

struct fown_struct___68 {
	rwlock_t lock;
	struct pid___68 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___118;

struct file___118 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___118 f_path;
	struct inode___118 *f_inode;
	const struct file_operations___118 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___68 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___118 *f_mapping;
	struct mutex___119 f_pos_lock;
};

struct vm_operations_struct___105;

struct vm_area_struct___123 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___123 *vm_next;
	struct vm_area_struct___123 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___123 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___105 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___118 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___102;

struct vm_operations_struct___105 {
	void (*open)(struct vm_area_struct___123 *);
	void (*close)(struct vm_area_struct___123 *);
	int (*fault)(struct vm_area_struct___123 *, struct vm_fault___102 *);
	int (*page_mkwrite)(struct vm_area_struct___123 *, struct vm_fault___102 *);
	int (*access)(struct vm_area_struct___123 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___123 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___123 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___123 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___123 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___118 {
	struct task_struct___118 *task;
	struct core_thread___118 *next;
};

struct core_state___118 {
	atomic_t nr_threads;
	struct core_thread___118 dumper;
	struct completion startup;
};

struct irq_data___88;

struct x86_io_apic_ops___88 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___88 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___88;

struct irq_data___88 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___88 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___95;

struct dev_pm_ops___95 {
	int (*prepare)(struct device___95 *);
	void (*complete)(struct device___95 *);
	int (*suspend)(struct device___95 *);
	int (*resume)(struct device___95 *);
	int (*freeze)(struct device___95 *);
	int (*thaw)(struct device___95 *);
	int (*poweroff)(struct device___95 *);
	int (*restore)(struct device___95 *);
	int (*suspend_late)(struct device___95 *);
	int (*resume_early)(struct device___95 *);
	int (*freeze_late)(struct device___95 *);
	int (*thaw_early)(struct device___95 *);
	int (*poweroff_late)(struct device___95 *);
	int (*restore_early)(struct device___95 *);
	int (*suspend_noirq)(struct device___95 *);
	int (*resume_noirq)(struct device___95 *);
	int (*freeze_noirq)(struct device___95 *);
	int (*thaw_noirq)(struct device___95 *);
	int (*poweroff_noirq)(struct device___95 *);
	int (*restore_noirq)(struct device___95 *);
	int (*runtime_suspend)(struct device___95 *);
	int (*runtime_resume)(struct device___95 *);
	int (*runtime_idle)(struct device___95 *);
};

struct dev_pm_qos___11;

struct dev_pm_info___11 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___11 *qos;
};

struct dma_map_ops___33;

struct dev_archdata___33 {
	struct dma_map_ops___33 *dma_ops;
	void *iommu;
};

struct device_type___95;

struct bus_type___95;

struct device_driver___95;

struct dev_pm_domain___95;

struct class___95;

struct attribute_group___88;

struct device_rh___95;

struct device___95 {
	struct device___95 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___95 *type;
	struct mutex___119 mutex;
	struct bus_type___95 *bus;
	struct device_driver___95 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___95 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___95 *class;
	const struct attribute_group___88 **groups;
	void (*release)(struct device___95 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___95 *device_rh;
};

struct dev_pm_qos_request___11;

struct dev_pm_qos___11 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___11 *latency_req;
	struct dev_pm_qos_request___11 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___11 *latency_tolerance_req;
};

struct dev_pm_info_rh___95 {
	void (*set_latency_tolerance)(struct device___95 *, s32);
};

struct dev_pm_domain___95 {
	struct dev_pm_ops___95 ops;
};

struct smp_ops___118 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___118 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___68 {
	int nr;
	struct pid_namespace___68 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___68 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___118 *child_reaper;
	struct kmem_cache___105 *pid_cachep;
	unsigned int level;
	struct pid_namespace___68 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___118 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___68 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___68 numbers[1];
};

struct zone___118;

struct lruvec___118 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___118 *zone;
};

struct pglist_data___118;

struct zone___118 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___118 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___118 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___118 {
	struct zone___118 *zone;
	int zone_idx;
};

struct zonelist___118 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___118 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___118 {
	struct zone___118 node_zones[4];
	struct zonelist___118 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___118 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___14;

struct ctl_node___14 {
	struct rb_node node;
	struct ctl_table_header___14 *header;
};

struct ctl_table_root___14;

struct ctl_table_set___14;

struct ctl_dir___14;

struct ctl_table_header___14 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___14 *root;
	struct ctl_table_set___14 *set;
	struct ctl_dir___14 *parent;
	struct ctl_node___14 *node;
};

struct ctl_dir___14 {
	struct ctl_table_header___14 header;
	struct rb_root root;
};

struct ctl_table_set___14 {
	int (*is_seen)(struct ctl_table_set___14 *);
	struct ctl_dir___14 dir;
};

struct ctl_table_root___14 {
	struct ctl_table_set___14 default_set;
	struct ctl_table_set___14 * (*lookup)(struct ctl_table_root___14 *, struct nsproxy___70 *);
	int (*permissions)(struct ctl_table_header___14 *, struct ctl_table *);
};

struct net___15;

struct nsproxy___70 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___68 *pid_ns;
	struct net___15 *net_ns;
};

struct signal_struct___118 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___118 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___118 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___68 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___68 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___119 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fdtable___8 {
	unsigned int max_fds;
	struct file___118 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___8 {
	atomic_t count;
	struct fdtable___8 *fdt;
	struct fdtable___8 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___118 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_subsys_state___82;

struct css_set___81 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___82 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___63 {
	struct pmu___63 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___119 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___118 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___63 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct super_block___118;

struct dquot___118 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___119 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___118 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___118;

struct mem_dqinfo___118 {
	struct quota_format_type___118 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___118;

struct quota_info___118 {
	unsigned int flags;
	struct mutex___119 dqio_mutex;
	struct mutex___119 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___118 *files[2];
	struct mem_dqinfo___118 info[2];
	const struct quota_format_ops___118 *ops[2];
};

struct file_system_type___118;

struct super_operations___118;

struct dquot_operations___118;

struct quotactl_ops___118;

struct xattr_handler___81;

struct block_device___118;

struct dentry_operations___118;

struct super_block___118 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___118 *s_type;
	const struct super_operations___118 *s_op;
	const struct dquot_operations___118 *dq_op;
	const struct quotactl_ops___118 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___118 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___81 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___118 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___118 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___119 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___118 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___118 {
	int qf_fmt_id;
	const struct quota_format_ops___118 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___118 *qf_next;
};

struct quota_format_ops___118 {
	int (*check_quota_file)(struct super_block___118 *, int);
	int (*read_file_info)(struct super_block___118 *, int);
	int (*write_file_info)(struct super_block___118 *, int);
	int (*free_file_info)(struct super_block___118 *, int);
	int (*read_dqblk)(struct dquot___118 *);
	int (*commit_dqblk)(struct dquot___118 *);
	int (*release_dqblk)(struct dquot___118 *);
};

struct dquot_operations___118 {
	int (*write_dquot)(struct dquot___118 *);
	struct dquot___118 * (*alloc_dquot)(struct super_block___118 *, int);
	void (*destroy_dquot)(struct dquot___118 *);
	int (*acquire_dquot)(struct dquot___118 *);
	int (*release_dquot)(struct dquot___118 *);
	int (*mark_dirty)(struct dquot___118 *);
	int (*write_info)(struct super_block___118 *, int);
	qsize_t * (*get_reserved_space)(struct inode___118 *);
};

struct inode_operations___118;

struct file_lock___118;

struct inode___118 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___118 *i_op;
	struct super_block___118 *i_sb;
	struct address_space___118 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___119 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___118 *i_fop;
	struct file_lock___118 *i_flock;
	struct address_space___118 i_data;
	struct dquot___118 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___118 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___118 {
	int (*quota_on)(struct super_block___118 *, int, int, struct path___118 *);
	int (*quota_on_meta)(struct super_block___118 *, int, int);
	int (*quota_off)(struct super_block___118 *, int);
	int (*quota_sync)(struct super_block___118 *, int);
	int (*get_info)(struct super_block___118 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___118 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___118 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___118 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___118 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___118 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___118 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___118 *, unsigned int);
};

struct vm_fault___102 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___118 *page;
};

struct seq_operations___89;

struct seq_file___90 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___119 lock;
	const struct seq_operations___89 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___89 {
	void * (*start)(struct seq_file___90 *, loff_t *);
	void (*stop)(struct seq_file___90 *, void *);
	void * (*next)(struct seq_file___90 *, void *, loff_t *);
	int (*show)(struct seq_file___90 *, void *);
};

struct dentry___118 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___118 *d_parent;
	struct qstr d_name;
	struct inode___118 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___118 *d_op;
	struct super_block___118 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___118 {
	int (*d_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_hash)(const struct dentry___118 *, struct qstr *);
	int (*d_compare)(const struct dentry___118 *, const struct dentry___118 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___118 *);
	void (*d_release)(struct dentry___118 *);
	void (*d_prune)(struct dentry___118 *);
	void (*d_iput)(struct dentry___118 *, struct inode___118 *);
	char * (*d_dname)(struct dentry___118 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___118 *);
	int (*d_manage)(struct dentry___118 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___118 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___118 *bd_inode;
	struct super_block___118 *bd_super;
	struct mutex___119 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___118 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___119 bd_fsfreeze_mutex;
};

struct cgroup___81;

struct cgroup_subsys_state___82 {
	struct cgroup___81 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___10;

typedef int kiocb_cancel_fn___10(struct kiocb___10 *, struct io_event *);

struct kiocb___10 {
	atomic_t ki_users;
	struct file___118 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___10 *ki_cancel;
	void (*ki_dtor)(struct kiocb___10 *);
	union {
		void *user;
		struct task_struct___118 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___118 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___118 *ia_file;
};

struct address_space_operations___118 {
	int (*writepage)(struct page___118 *, struct writeback_control *);
	int (*readpage)(struct file___118 *, struct page___118 *);
	int (*writepages)(struct address_space___118 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___118 *);
	int (*readpages)(struct file___118 *, struct address_space___118 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___118 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___118 **, void **);
	int (*write_end)(struct file___118 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___118 *, void *);
	sector_t (*bmap)(struct address_space___118 *, sector_t);
	void (*invalidatepage)(struct page___118 *, long unsigned int);
	int (*releasepage)(struct page___118 *, gfp_t);
	void (*freepage)(struct page___118 *);
	ssize_t (*direct_IO)(int, struct kiocb___10 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___118 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___118 *, struct page___118 *, struct page___118 *, enum migrate_mode);
	int (*launder_page)(struct page___118 *);
	int (*is_partially_uptodate)(struct page___118 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___118 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___118 *, struct page___118 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___118 *, sector_t *);
	void (*swap_deactivate)(struct file___118 *);
	void (*invalidatepage_range)(struct page___118 *, unsigned int, unsigned int);
};

struct inode_operations___118 {
	struct dentry___118 * (*lookup)(struct inode___118 *, struct dentry___118 *, unsigned int);
	void * (*follow_link)(struct dentry___118 *, struct nameidata *);
	int (*permission)(struct inode___118 *, int);
	struct posix_acl * (*get_acl)(struct inode___118 *, int);
	int (*readlink)(struct dentry___118 *, char *, int);
	void (*put_link)(struct dentry___118 *, struct nameidata *, void *);
	int (*create)(struct inode___118 *, struct dentry___118 *, umode_t, bool);
	int (*link)(struct dentry___118 *, struct inode___118 *, struct dentry___118 *);
	int (*unlink)(struct inode___118 *, struct dentry___118 *);
	int (*symlink)(struct inode___118 *, struct dentry___118 *, const char *);
	int (*mkdir)(struct inode___118 *, struct dentry___118 *, umode_t);
	int (*rmdir)(struct inode___118 *, struct dentry___118 *);
	int (*mknod)(struct inode___118 *, struct dentry___118 *, umode_t, dev_t);
	int (*rename)(struct inode___118 *, struct dentry___118 *, struct inode___118 *, struct dentry___118 *);
	int (*setattr)(struct dentry___118 *, struct iattr___118 *);
	int (*getattr)(struct vfsmount *, struct dentry___118 *, struct kstat *);
	int (*setxattr)(struct dentry___118 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___118 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___118 *, char *, size_t);
	int (*removexattr)(struct dentry___118 *, const char *);
	int (*fiemap)(struct inode___118 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___118 *, struct timespec *, int);
	int (*atomic_open)(struct inode___118 *, struct dentry___118 *, struct file___118 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___8 *fl_owner_t___8;

struct poll_table_struct___76;

struct file_operations___118 {
	struct module *owner;
	loff_t (*llseek)(struct file___118 *, loff_t, int);
	ssize_t (*read)(struct file___118 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___118 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___10 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___10 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___118 *, void *, filldir_t);
	unsigned int (*poll)(struct file___118 *, struct poll_table_struct___76 *);
	long int (*unlocked_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___118 *, struct vm_area_struct___123 *);
	int (*open)(struct inode___118 *, struct file___118 *);
	int (*flush)(struct file___118 *, fl_owner_t___8);
	int (*release)(struct inode___118 *, struct file___118 *);
	int (*fsync)(struct file___118 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___10 *, int);
	int (*fasync)(int, struct file___118 *, int);
	int (*lock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*sendpage)(struct file___118 *, struct page___118 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___118 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___118 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___118 *, long int, struct file_lock___118 **, void **);
		struct {
			int (*setlease)(struct file___118 *, long int, struct file_lock___118 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___118 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___90 *, struct file___118 *);
};

struct file_lock_operations___118;

struct lock_manager_operations___118;

struct file_lock___118 {
	struct file_lock___118 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___8 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___68 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___118 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___118 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___118 *fl_ops;
	const struct lock_manager_operations___118 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___118 {
	void (*fl_copy_lock)(struct file_lock___118 *, struct file_lock___118 *);
	void (*fl_release_private)(struct file_lock___118 *);
};

struct lock_manager_operations___118 {
	int (*lm_compare_owner)(struct file_lock___118 *, struct file_lock___118 *);
	long unsigned int (*lm_owner_key)(struct file_lock___118 *);
	void (*lm_notify)(struct file_lock___118 *);
	int (*lm_grant)(struct file_lock___118 *, struct file_lock___118 *, int);
	void (*lm_break)(struct file_lock___118 *);
	int (*lm_change)(struct file_lock___118 **, int);
};

struct fasync_struct___118 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___118 *fa_next;
	struct file___118 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___118 {
	const char *name;
	int fs_flags;
	struct dentry___118 * (*mount)(struct file_system_type___118 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___118 *);
	struct module *owner;
	struct file_system_type___118 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___118 {
	struct inode___118 * (*alloc_inode)(struct super_block___118 *);
	void (*destroy_inode)(struct inode___118 *);
	void (*dirty_inode)(struct inode___118 *, int);
	int (*write_inode)(struct inode___118 *, struct writeback_control *);
	int (*drop_inode)(struct inode___118 *);
	void (*evict_inode)(struct inode___118 *);
	void (*put_super)(struct super_block___118 *);
	int (*sync_fs)(struct super_block___118 *, int);
	int (*freeze_fs)(struct super_block___118 *);
	int (*unfreeze_fs)(struct super_block___118 *);
	int (*statfs)(struct dentry___118 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___118 *, int *, char *);
	void (*umount_begin)(struct super_block___118 *);
	int (*show_options)(struct seq_file___90 *, struct dentry___118 *);
	int (*show_devname)(struct seq_file___90 *, struct dentry___118 *);
	int (*show_path)(struct seq_file___90 *, struct dentry___118 *);
	int (*show_stats)(struct seq_file___90 *, struct dentry___118 *);
	ssize_t (*quota_read)(struct super_block___118 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___118 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___118 *);
	int (*bdev_try_to_free_page)(struct super_block___118 *, struct page___118 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___118 *);
	void (*free_cached_objects)(struct super_block___118 *, int);
};

struct xattr_handler___81 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___118 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___118 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___118 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___78)(struct file___118 *, wait_queue_head_t *, struct poll_table_struct___76 *);

struct poll_table_struct___76 {
	poll_queue_proc___78 _qproc;
	long unsigned int _key;
};

typedef struct poll_table_struct___76 poll_table___11;

struct poll_table_entry {
	struct file___118 *filp;
	long unsigned int key;
	wait_queue_t wait;
	wait_queue_head_t *wait_address;
};

struct poll_table_page;

struct poll_wqueues {
	poll_table___11 pt;
	struct poll_table_page *table;
	struct task_struct___118 *polling_task;
	int triggered;
	int error;
	int inline_index;
	struct poll_table_entry inline_entries[9];
};

struct poll_table_page {
	struct poll_table_page *next;
	struct poll_table_entry *entry;
	struct poll_table_entry entries[0];
};

typedef struct {
	long unsigned int *in;
	long unsigned int *out;
	long unsigned int *ex;
	long unsigned int *res_in;
	long unsigned int *res_out;
	long unsigned int *res_ex;
} fd_set_bits;

struct irq_chip___88 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___88 *);
	void (*irq_shutdown)(struct irq_data___88 *);
	void (*irq_enable)(struct irq_data___88 *);
	void (*irq_disable)(struct irq_data___88 *);
	void (*irq_ack)(struct irq_data___88 *);
	void (*irq_mask)(struct irq_data___88 *);
	void (*irq_mask_ack)(struct irq_data___88 *);
	void (*irq_unmask)(struct irq_data___88 *);
	void (*irq_eoi)(struct irq_data___88 *);
	int (*irq_set_affinity)(struct irq_data___88 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___88 *);
	int (*irq_set_type)(struct irq_data___88 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___88 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___88 *);
	void (*irq_bus_sync_unlock)(struct irq_data___88 *);
	void (*irq_cpu_online)(struct irq_data___88 *);
	void (*irq_cpu_offline)(struct irq_data___88 *);
	void (*irq_suspend)(struct irq_data___88 *);
	void (*irq_resume)(struct irq_data___88 *);
	void (*irq_pm_shutdown)(struct irq_data___88 *);
	void (*irq_print_chip)(struct irq_data___88 *, struct seq_file___90 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___88 *, void *);
	long unsigned int flags;
};

struct netns_core___14 {
	struct ctl_table_header___14 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___14 {
	struct mutex___119 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___14 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___14 *ctl;
};

struct sock___7;

struct netns_ipv4___14 {
	struct ctl_table_header___14 *forw_hdr;
	struct ctl_table_header___14 *frags_hdr;
	struct ctl_table_header___14 *ipv4_hdr;
	struct ctl_table_header___14 *route_hdr;
	struct ctl_table_header___14 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___7 *fibnl;
	struct sock___7 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___14 {
	struct ctl_table_header___14 *hdr;
	struct ctl_table_header___14 *route_hdr;
	struct ctl_table_header___14 *icmp_hdr;
	struct ctl_table_header___14 *frags_hdr;
	struct ctl_table_header___14 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_entry___6;

struct net_device___9;

struct sk_buff___11;

struct neighbour___6;

struct dst_ops___14 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___14 *);
	struct dst_entry___6 * (*check)(struct dst_entry___6 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___6 *);
	unsigned int (*mtu)(const struct dst_entry___6 *);
	u32 * (*cow_metrics)(struct dst_entry___6 *, long unsigned int);
	void (*destroy)(struct dst_entry___6 *);
	void (*ifdown)(struct dst_entry___6 *, struct net_device___9 *, int);
	struct dst_entry___6 * (*negative_advice)(struct dst_entry___6 *);
	void (*link_failure)(struct sk_buff___11 *);
	void (*update_pmtu)(struct dst_entry___6 *, struct sock___7 *, struct sk_buff___11 *, u32);
	void (*redirect)(struct dst_entry___6 *, struct sock___7 *, struct sk_buff___11 *);
	int (*local_out)(struct sk_buff___11 *);
	struct neighbour___6 * (*neigh_lookup)(const struct dst_entry___6 *, struct sk_buff___11 *, const void *);
	struct kmem_cache___105 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___14 {
	struct netns_sysctl_ipv6___14 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___14 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___7 **icmp_sk;
	struct sock___7 *ndisc_sk;
	struct sock___7 *tcp_sk;
	struct sock___7 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___14 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___14 *sysctl_header;
	struct sock___7 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___6 {
	struct sock___7 *v4_ctl_sk;
	struct sock___7 *v6_ctl_sk;
};

struct netns_nf___14 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___14 *nf_log_dir_header;
};

struct nf_proto_net___14 {
	struct ctl_table_header___14 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___14 {
	struct nf_proto_net___14 pn;
	unsigned int timeout;
};

struct nf_tcp_net___14 {
	struct nf_proto_net___14 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___14 {
	struct nf_proto_net___14 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___14 {
	struct nf_proto_net___14 pn;
	unsigned int timeout;
};

struct nf_ip_net___14 {
	struct nf_generic_net___14 generic;
	struct nf_tcp_net___14 tcp;
	struct nf_udp_net___14 udp;
	struct nf_icmp_net___14 icmp;
	struct nf_icmp_net___14 icmpv6;
};

struct netns_ct___14 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___14 *sysctl_header;
	struct ctl_table_header___14 *acct_sysctl_header;
	struct ctl_table_header___14 *tstamp_sysctl_header;
	struct ctl_table_header___14 *event_sysctl_header;
	struct ctl_table_header___14 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___105 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___14 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___14 {
	struct netns_sysctl_ipv6___14 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___8 {
	struct sk_buff___11 *next;
	struct sk_buff___11 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___14 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___7 *nlsk;
	struct sock___7 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___14 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___14 xfrm4_dst_ops;
	struct dst_ops___14 xfrm6_dst_ops;
};

struct net___15 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___14 sysctls;
	struct sock___7 *rtnl;
	struct sock___7 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___9 *loopback_dev;
	struct netns_core___14 core;
	struct netns_mib mib;
	struct netns_packet___14 packet;
	struct netns_unix___14 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___14 ipv4;
	struct netns_ipv6___14 ipv6;
	struct netns_sctp___14 sctp;
	struct netns_dccp___6 dccp;
	struct netns_nf___14 nf;
	struct netns_xt xt;
	struct netns_ct___14 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___14 nf_frag;
	struct sock___7 *nfnl;
	struct sock___7 *nfnl_stash;
	struct sk_buff_head___8 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___14 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___7 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___7 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___119 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___119 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___6 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___7 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___6;

struct sock_common___6 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___6 *skc_prot;
	struct net___15 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_filter___7;

struct socket_wq___6;

struct socket___6;

struct cg_proto___6;

struct sock___7 {
	struct sock_common___6 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___8 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___11 *head;
		struct sk_buff___11 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___7 *sk_filter;
	struct socket_wq___6 *sk_wq;
	struct sk_buff_head___8 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___6 *sk_rx_dst;
	struct dst_entry___6 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___8 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___8 sk_error_queue;
	struct proto___6 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___68 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___6 *sk_socket;
	void *sk_user_data;
	struct page_frag___114 sk_frag;
	struct sk_buff___11 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___6 *sk_cgrp;
	void (*sk_state_change)(struct sock___7 *);
	void (*sk_data_ready)(struct sock___7 *, int);
	void (*sk_write_space)(struct sock___7 *);
	void (*sk_error_report)(struct sock___7 *);
	int (*sk_backlog_rcv)(struct sock___7 *, struct sk_buff___11 *);
	void (*sk_destruct)(struct sock___7 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___88;

struct attribute_group___88 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___88 **bin_attrs;
};

struct bin_attribute___88 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___118 *, struct kobject___6 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___118 *, struct kobject___6 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	int (*mmap)(struct file___118 *, struct kobject___6 *, struct bin_attribute___88 *, struct vm_area_struct___123 *);
};

struct sysfs_ops___6 {
	ssize_t (*show)(struct kobject___6 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___6 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___6 *, const struct attribute *);
};

struct kset_uevent_ops___6;

struct kset___6 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___6 kobj;
	const struct kset_uevent_ops___6 *uevent_ops;
};

struct kobj_type___6 {
	void (*release)(struct kobject___6 *);
	const struct sysfs_ops___6 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___6 * (*child_ns_type)(struct kobject___6 *);
	const void * (*namespace)(struct kobject___6 *);
};

struct kset_uevent_ops___6 {
	int (* const filter)(struct kset___6 *, struct kobject___6 *);
	const char * (* const name)(struct kset___6 *, struct kobject___6 *);
	int (* const uevent)(struct kset___6 *, struct kobject___6 *, struct kobj_uevent_env *);
};

struct dma_map_ops___33 {
	void * (*alloc)(struct device___95 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___95 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___95 *, struct vm_area_struct___123 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___95 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___95 *, struct page___118 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___95 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___95 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___95 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___95 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___95 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___95 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___95 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___95 *, dma_addr_t);
	int (*dma_supported)(struct device___95 *, u64);
	int (*set_dma_mask)(struct device___95 *, u64);
	int is_phys;
};

struct bus_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___95 *, char *);
	ssize_t (*store)(struct bus_type___95 *, const char *, size_t);
};

struct device_attribute___95;

struct driver_attribute___95;

struct bus_type___95 {
	const char *name;
	const char *dev_name;
	struct device___95 *dev_root;
	struct bus_attribute___95 *bus_attrs;
	struct device_attribute___95 *dev_attrs;
	struct driver_attribute___95 *drv_attrs;
	const struct attribute_group___88 **bus_groups;
	const struct attribute_group___88 **dev_groups;
	const struct attribute_group___88 **drv_groups;
	int (*match)(struct device___95 *, struct device_driver___95 *);
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	int (*probe)(struct device___95 *);
	int (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*online)(struct device___95 *);
	int (*offline)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct device___95 *, struct device_attribute___95 *, char *);
	ssize_t (*store)(struct device___95 *, struct device_attribute___95 *, const char *, size_t);
};

struct driver_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___95 *, char *);
	ssize_t (*store)(struct device_driver___95 *, const char *, size_t);
};

struct device_driver___95 {
	const char *name;
	struct bus_type___95 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___95 *);
	int (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	const struct attribute_group___88 **groups;
	const struct dev_pm_ops___95 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___95 {
	const char *name;
	const struct attribute_group___88 **groups;
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
};

struct class_attribute___95;

struct class___95 {
	const char *name;
	struct module *owner;
	struct class_attribute___95 *class_attrs;
	struct device_attribute___95 *dev_attrs;
	const struct attribute_group___88 **dev_groups;
	struct bin_attribute___88 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *);
	void (*class_release)(struct class___95 *);
	void (*dev_release)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
	struct subsys_private *p;
};

struct class_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct class___95 *, struct class_attribute___95 *, char *);
	ssize_t (*store)(struct class___95 *, struct class_attribute___95 *, const char *, size_t);
	const void * (*namespace)(struct class___95 *, const struct class_attribute___95 *);
};

struct device_rh___95 {
	struct dev_pm_info_rh___95 power;
};

struct kmem_cache_cpu___105 {
	void **freelist;
	long unsigned int tid;
	struct page___118 *page;
	struct page___118 *partial;
};

struct memcg_cache_params___105 {
	bool is_root_cache;
	union {
		struct kmem_cache___105 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___105 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___81;

struct cgroup___81 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___81 *parent;
	struct dentry___118 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___82 *subsys[11];
	struct cgroupfs_root___81 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___119 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___81 {
	struct super_block___118 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___81 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___37 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___118 *, struct file___118 *);
	ssize_t (*read)(struct cgroup___81 *, struct cftype___37 *, struct file___118 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___81 *, struct cftype___37 *);
	s64 (*read_s64)(struct cgroup___81 *, struct cftype___37 *);
	int (*read_map)(struct cgroup___81 *, struct cftype___37 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___81 *, struct cftype___37 *, struct seq_file___90 *);
	ssize_t (*write)(struct cgroup___81 *, struct cftype___37 *, struct file___118 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___81 *, struct cftype___37 *, u64);
	int (*write_s64)(struct cgroup___81 *, struct cftype___37 *, s64);
	int (*write_string)(struct cgroup___81 *, struct cftype___37 *, const char *);
	int (*trigger)(struct cgroup___81 *, unsigned int);
	int (*release)(struct inode___118 *, struct file___118 *);
	int (*register_event)(struct cgroup___81 *, struct cftype___37 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___81 *, struct cftype___37 *, struct eventfd_ctx *);
};

struct cftype_set___35 {
	struct list_head node;
	struct cftype___37 *cfts;
};

struct task_and_cgroup___35 {
	struct task_struct___118 *task;
	struct cgroup___81 *cgrp;
	struct css_set___81 *cg;
};

struct cgroup_taskset___35 {
	struct task_and_cgroup___35 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___81 *cur_cgrp;
};

struct cgroup_subsys___35 {
	struct cgroup_subsys_state___82 * (*css_alloc)(struct cgroup___81 *);
	int (*css_online)(struct cgroup___81 *);
	void (*css_offline)(struct cgroup___81 *);
	void (*css_free)(struct cgroup___81 *);
	int (*can_attach)(struct cgroup___81 *, struct cgroup_taskset___35 *);
	void (*cancel_attach)(struct cgroup___81 *, struct cgroup_taskset___35 *);
	void (*attach)(struct cgroup___81 *, struct cgroup_taskset___35 *);
	void (*fork)(struct task_struct___118 *);
	void (*exit)(struct cgroup___81 *, struct cgroup___81 *, struct task_struct___118 *);
	void (*bind)(struct cgroup___81 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___81 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___37 *base_cftypes;
	struct cftype_set___35 base_cftset;
	struct module *module;
};

struct perf_cpu_context___63;

struct pmu___63 {
	struct list_head entry;
	struct device___95 *dev;
	const struct attribute_group___88 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___63 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___63 *);
	void (*pmu_disable)(struct pmu___63 *);
	int (*event_init)(struct perf_event___63 *);
	int (*add)(struct perf_event___63 *, int);
	void (*del)(struct perf_event___63 *, int);
	void (*start)(struct perf_event___63 *, int);
	void (*stop)(struct perf_event___63 *, int);
	void (*read)(struct perf_event___63 *);
	void (*start_txn)(struct pmu___63 *);
	int (*commit_txn)(struct pmu___63 *);
	void (*cancel_txn)(struct pmu___63 *);
	int (*event_idx)(struct perf_event___63 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___63 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___63 *);
};

struct perf_cpu_context___63 {
	struct perf_event_context___63 ctx;
	struct perf_event_context___63 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___63 *unique_pmu;
	struct perf_cgroup___63 *cgrp;
};

struct trace_event_functions___53;

struct trace_event___53 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___53 *funcs;
};

struct ftrace_event_class___53;

struct ftrace_event_call___53 {
	struct list_head list;
	struct ftrace_event_class___53 *class;
	char *name;
	struct trace_event___53 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___63 {
	struct cgroup_subsys_state___82 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___53 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___119 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___53)(struct trace_iterator___53 *, int, struct trace_event___53 *);

struct trace_event_functions___53 {
	trace_print_func___53 trace;
	trace_print_func___53 raw;
	trace_print_func___53 hex;
	trace_print_func___53 binary;
};

struct ftrace_event_class___53 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___53 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___53 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___53 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___53 *);
};

struct syscall_metadata___23 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___53 *enter_event;
	struct ftrace_event_call___53 *exit_event;
};

struct fd___11 {
	struct file___118 *file;
	unsigned int flags;
};

struct dev_pm_qos_request___11 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___95 *dev;
};

struct socket_wq___6 {
	wait_queue_head_t wait;
	struct fasync_struct___118 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___6;

struct socket___6 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___6 *wq;
	struct file___118 *file;
	struct sock___7 *sk;
	const struct proto_ops___6 *ops;
};

struct proto_ops___6 {
	int family;
	struct module *owner;
	int (*release)(struct socket___6 *);
	int (*bind)(struct socket___6 *, struct sockaddr *, int);
	int (*connect)(struct socket___6 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___6 *, struct socket___6 *);
	int (*accept)(struct socket___6 *, struct socket___6 *, int);
	int (*getname)(struct socket___6 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___118 *, struct socket___6 *, struct poll_table_struct___76 *);
	int (*ioctl)(struct socket___6 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___6 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___6 *, int);
	int (*shutdown)(struct socket___6 *, int);
	int (*setsockopt)(struct socket___6 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___6 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___6 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___6 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___10 *, struct socket___6 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___10 *, struct socket___6 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___118 *, struct socket___6 *, struct vm_area_struct___123 *);
	ssize_t (*sendpage)(struct socket___6 *, struct page___118 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___6 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___7 *, int);
		struct {
			void (*set_peek_off)(struct sock___7 *, int);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
};

struct nf_bridge_info___7 {
	atomic_t use;
	unsigned int mask;
	struct net_device___9 *physindev;
	struct net_device___9 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___7(struct sk_buff___11 **);

struct net_device_ops___7;

struct ethtool_ops___7;

struct header_ops___7;

struct inet6_dev___5;

struct netdev_rx_queue___7;

struct netdev_queue___7;

struct rtnl_link_ops___6;

struct dcbnl_rtnl_ops___7;

struct net_device___9 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___7 *netdev_ops;
	const struct ethtool_ops___7 *ethtool_ops;
	const struct header_ops___7 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___6 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___5 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___7 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___7 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___7 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___7 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___7 = 0,
		NETREG_REGISTERED___7 = 1,
		NETREG_UNREGISTERING___7 = 2,
		NETREG_UNREGISTERED___7 = 3,
		NETREG_RELEASED___7 = 4,
		NETREG_DUMMY___7 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___7 = 0,
		RTNL_LINK_INITIALIZING___7 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___9 *);
	struct netpoll_info *npinfo;
	struct net___15 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide22;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___95 dev;
	const struct attribute_group___88 *sysfs_groups[4];
	const struct rtnl_link_ops___6 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___7 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___11 {
	struct sk_buff___11 *next;
	struct sk_buff___11 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___7 *sk;
	struct net_device___9 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___11 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___7 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___7 {
	int (*get_settings)(struct net_device___9 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___9 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___9 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___9 *);
	void (*get_regs)(struct net_device___9 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___9 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___9 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___9 *);
	void (*set_msglevel)(struct net_device___9 *, u32);
	int (*nway_reset)(struct net_device___9 *);
	u32 (*get_link)(struct net_device___9 *);
	int (*get_eeprom_len)(struct net_device___9 *);
	int (*get_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___9 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___9 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___9 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___9 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___9 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___9 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___9 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___9 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___9 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___9 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___9 *);
	void (*complete)(struct net_device___9 *);
	u32 (*get_priv_flags)(struct net_device___9 *);
	int (*set_priv_flags)(struct net_device___9 *, u32);
	int (*get_sset_count)(struct net_device___9 *, int);
	int (*get_rxnfc)(struct net_device___9 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___9 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___9 *, struct ethtool_flash *);
	int (*reset)(struct net_device___9 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___9 *);
	int (*get_rxfh_indir)(struct net_device___9 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___9 *, const u32 *);
	void (*get_channels)(struct net_device___9 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___9 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___9 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___9 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___9 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___9 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___9 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___9 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___9 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___9 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___9 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___9 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___3;

struct dst_entry___6 {
	struct callback_head callback_head;
	struct dst_entry___6 *child;
	struct net_device___9 *dev;
	struct dst_ops___14 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___6 *path;
	struct dst_entry___6 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___11 *);
	union {
		int (*output)(struct sock___7 *, struct sk_buff___11 *);
		struct {
			int (*output)(struct sk_buff___11 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___6 *next;
		struct rtable___3 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___6;

struct neigh_parms___6;

struct neigh_ops___6;

struct neighbour___6 {
	struct neighbour___6 *next;
	struct neigh_table___6 *tbl;
	struct neigh_parms___6 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___8 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___6 *, struct sk_buff___11 *);
	const struct neigh_ops___6 *ops;
	struct callback_head rcu;
	struct net_device___9 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___14 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___11 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___11 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___15 *, struct dst_entry___6 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___11 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___11 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___7 {
	int (*ieee_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___9 *);
	u8 (*setstate)(struct net_device___9 *, u8);
	void (*getpermhwaddr)(struct net_device___9 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___9 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___9 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___9 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___9 *, int, u8 *);
	void (*setpfccfg)(struct net_device___9 *, int, u8);
	void (*getpfccfg)(struct net_device___9 *, int, u8 *);
	u8 (*setall)(struct net_device___9 *);
	u8 (*getcap)(struct net_device___9 *, int, u8 *);
	int (*getnumtcs)(struct net_device___9 *, int, u8 *);
	int (*setnumtcs)(struct net_device___9 *, int, u8);
	u8 (*getpfcstate)(struct net_device___9 *);
	void (*setpfcstate)(struct net_device___9 *, u8);
	void (*getbcncfg)(struct net_device___9 *, int, u32 *);
	void (*setbcncfg)(struct net_device___9 *, int, u32);
	void (*getbcnrp)(struct net_device___9 *, int, u8 *);
	void (*setbcnrp)(struct net_device___9 *, int, u8);
	u8 (*setapp)(struct net_device___9 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___9 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___9 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___9 *, int, u8);
	u8 (*getdcbx)(struct net_device___9 *);
	u8 (*setdcbx)(struct net_device___9 *, u8);
	int (*peer_getappinfo)(struct net_device___9 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___9 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___9 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___9 *, struct cee_pfc *);
};

struct request_sock_ops___6;

struct request_sock___5 {
	struct sock_common___6 __req_common;
	struct request_sock___5 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___6 *rsk_ops;
	struct sock___7 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___7 {
	struct sk_buff___11 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___11 *, struct netlink_callback___7 *);
	int (*done)(struct netlink_callback___7 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___7 {
	int (*create)(struct sk_buff___11 *, struct net_device___9 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___11 *, unsigned char *);
	int (*rebuild)(struct sk_buff___11 *);
	int (*cache)(const struct neighbour___6 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___9 *, const unsigned char *);
};

struct napi_struct___7 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___7 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___9 *dev;
	struct sk_buff___11 *gro_list;
	struct sk_buff___11 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___7 {
	struct net_device___9 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___6 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___7 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___6 kobj;
	struct net_device___9 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___7 {
	int (*ndo_init)(struct net_device___9 *);
	void (*ndo_uninit)(struct net_device___9 *);
	int (*ndo_open)(struct net_device___9 *);
	int (*ndo_stop)(struct net_device___9 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___11 *, struct net_device___9 *);
	u16 (*ndo_select_queue)(struct net_device___9 *, struct sk_buff___11 *);
	void (*ndo_change_rx_flags)(struct net_device___9 *, int);
	void (*ndo_set_rx_mode)(struct net_device___9 *);
	int (*ndo_set_mac_address)(struct net_device___9 *, void *);
	int (*ndo_validate_addr)(struct net_device___9 *);
	int (*ndo_do_ioctl)(struct net_device___9 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___9 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___9 *, int);
	int (*ndo_neigh_setup)(struct net_device___9 *, struct neigh_parms___6 *);
	void (*ndo_tx_timeout)(struct net_device___9 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___9 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___9 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___9 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___9 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___9 *);
	int (*ndo_netpoll_setup)(struct net_device___9 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___9 *);
	int (*ndo_busy_poll)(struct napi_struct___7 *);
	int (*ndo_set_vf_mac)(struct net_device___9 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___9 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___9 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___9 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___9 *, int, struct ifla_vf_info___2 *);
	int (*ndo_set_vf_link_state)(struct net_device___9 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___9 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___9 *, int, struct sk_buff___11 *);
	int (*ndo_setup_tc)(struct net_device___9 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___9 *);
	int (*ndo_fcoe_disable)(struct net_device___9 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___9 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___9 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___9 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___9 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___9 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___9 *, const struct sk_buff___11 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___9 *, struct net_device___9 *);
	int (*ndo_del_slave)(struct net_device___9 *, struct net_device___9 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___6 *);
	void (*ndo_neigh_destroy)(struct neighbour___6 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___11 *, struct netlink_callback___7 *, struct net_device___9 *, int);
	int (*ndo_bridge_setlink)(struct net_device___9 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___11 *, u32, u32, struct net_device___9 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___9 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___9 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___9 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___9 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___9 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___9 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___11 *, struct net_device___9 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___9 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___9 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___9 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___6 {
	struct net___15 *net;
	struct net_device___9 *dev;
	struct neigh_parms___6 *next;
	int (*neigh_setup)(struct neighbour___6 *);
	void (*neigh_cleanup)(struct neighbour___6 *);
	struct neigh_table___6 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___5;

struct ifacaddr6___5;

struct inet6_dev___5 {
	struct net_device___9 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___5 *mc_list;
	struct ifmcaddr6___5 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___5 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___6 *nd_parms;
	struct inet6_dev___5 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___6 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___9 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___15 *, struct net_device___9 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___9 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___9 *, struct list_head *);
	size_t (*get_size)(const struct net_device___9 *);
	int (*fill_info)(struct sk_buff___11 *, const struct net_device___9 *);
	size_t (*get_xstats_size)(const struct net_device___9 *);
	int (*fill_xstats)(struct sk_buff___11 *, const struct net_device___9 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___15 * (*get_link_net)(const struct net_device___9 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___9 *, struct net_device___9 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___9 *, const struct net_device___9 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___11 *, const struct net_device___9 *, const struct net_device___9 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___7 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___11 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___6;

struct neigh_hash_table___6;

struct neigh_table___6 {
	struct neigh_table___6 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___9 *, __u32 *);
	int (*constructor)(struct neighbour___6 *);
	int (*pconstructor)(struct pneigh_entry___6 *);
	void (*pdestructor)(struct pneigh_entry___6 *);
	void (*proxy_redo)(struct sk_buff___11 *);
	char *id;
	struct neigh_parms___6 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___8 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___6 *nht;
	struct pneigh_entry___6 **phash_buckets;
};

struct neigh_ops___6 {
	int family;
	void (*solicit)(struct neighbour___6 *, struct sk_buff___11 *);
	void (*error_report)(struct neighbour___6 *, struct sk_buff___11 *);
	int (*output)(struct neighbour___6 *, struct sk_buff___11 *);
	int (*connected_output)(struct neighbour___6 *, struct sk_buff___11 *);
};

struct pneigh_entry___6 {
	struct pneigh_entry___6 *next;
	struct net___15 *net;
	struct net_device___9 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___6 {
	struct neighbour___6 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___3 {
	struct dst_entry___6 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___6;

struct proto___6 {
	void (*close)(struct sock___7 *, long int);
	int (*connect)(struct sock___7 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___7 *, int);
	struct sock___7 * (*accept)(struct sock___7 *, int, int *);
	int (*ioctl)(struct sock___7 *, int, long unsigned int);
	int (*init)(struct sock___7 *);
	void (*destroy)(struct sock___7 *);
	void (*shutdown)(struct sock___7 *, int);
	int (*setsockopt)(struct sock___7 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___7 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___7 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___7 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___7 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___10 *, struct sock___7 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___10 *, struct sock___7 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___7 *, struct page___118 *, int, size_t, int);
	int (*bind)(struct sock___7 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___7 *, struct sk_buff___11 *);
	void (*release_cb)(struct sock___7 *);
	void (*mtu_reduced)(struct sock___7 *);
	void (*hash)(struct sock___7 *);
	void (*unhash)(struct sock___7 *);
	void (*rehash)(struct sock___7 *);
	int (*get_port)(struct sock___7 *, short unsigned int);
	void (*clear_sk)(struct sock___7 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___7 *);
	void (*enter_memory_pressure)(struct sock___7 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___105 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___6 *rsk_prot;
	struct timewait_sock_ops___6 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___35 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___6 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___6 {
	void (*enter_memory_pressure)(struct sock___7 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___6 {
	int family;
	int obj_size;
	struct kmem_cache___105 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___7 *, struct request_sock___5 *);
	void (*send_ack)(struct sock___7 *, struct sk_buff___11 *, struct request_sock___5 *);
	void (*send_reset)(struct sock___7 *, struct sk_buff___11 *);
	void (*destructor)(struct request_sock___5 *);
	void (*syn_ack_timeout)(struct sock___7 *, struct request_sock___5 *);
};

struct timewait_sock_ops___6 {
	struct kmem_cache___105 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___7 *, struct sock___7 *, void *);
	void (*twsk_destructor)(struct sock___7 *);
};

struct ifmcaddr6___5 {
	struct in6_addr mca_addr;
	struct inet6_dev___5 *idev;
	struct ifmcaddr6___5 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___5 {
	struct in6_addr aca_addr;
	struct inet6_dev___5 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___5 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct poll_list {
	struct poll_list *next;
	int len;
	struct pollfd entries[0];
};

struct page___119;

typedef struct page___119 *pgtable_t___119;

struct address_space___119;

struct kmem_cache___106;

struct page___119 {
	long unsigned int flags;
	struct address_space___119 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___119 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___119 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___106 *slab_cache;
		struct page___119 *first_page;
	};
	long: 64;
};

struct thread_struct___64;

struct task_struct___119;

struct pv_cpu_ops___119 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___64 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___64 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___119 *);
	void (*end_context_switch)(struct task_struct___119 *);
};

struct perf_event___64;

struct thread_struct___64 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___64 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___69;

struct pid_link___69 {
	struct hlist_node node;
	struct pid___69 *pid;
};

struct mutex___120 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___119 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___115 {
	struct page___119 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___124;

struct fs_struct___10;

struct nsproxy___71;

struct signal_struct___119;

struct css_set___82;

struct perf_event_context___64;

struct task_struct___119 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___119 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___124 *mm;
	struct mm_struct___124 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___119 *real_parent;
	struct task_struct___119 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___119 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___69 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___119 = 0,
		VTIME_USER___119 = 1,
		VTIME_SYS___119 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___64 thread;
	struct fs_struct___10 *fs;
	struct files_struct *files;
	struct nsproxy___71 *nsproxy;
	struct signal_struct___119 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___82 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___64 *perf_event_ctxp[2];
	struct mutex___120 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___115 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___124 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___124 *, struct mm_struct___124 *);
	void (*dup_mmap)(struct mm_struct___124 *, struct mm_struct___124 *);
	void (*exit_mmap)(struct mm_struct___124 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___124 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___124 *);
	void (*pgd_free)(struct mm_struct___124 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___124 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___124 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___124 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___124 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___124 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___124 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___124 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___124 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___124 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___124 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___124 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___120 lock;
	void *vdso;
} mm_context_t___120;

struct xol_area___119;

struct uprobes_state___119 {
	struct xol_area___119 *xol_area;
};

struct vm_area_struct___124;

struct file___119;

struct core_state___119;

struct mm_struct___124 {
	struct vm_area_struct___124 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___124 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___124 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___120 context;
	long unsigned int flags;
	struct core_state___119 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___119 *owner;
	struct file___119 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___119 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___64 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___119 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___119 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___119 *target;
};

typedef void (*perf_overflow_handler_t___64)(struct perf_event___64 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___64;

typedef void (*ftrace_func_t___64)(long unsigned int, long unsigned int, struct ftrace_ops___64 *, struct pt_regs *);

struct ftrace_ops___64 {
	ftrace_func_t___64 func;
	struct ftrace_ops___64 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___120 regex_lock;
};

struct pmu___64;

struct fasync_struct___119;

struct pid_namespace___69;

struct ftrace_event_call___54;

struct perf_cgroup___64;

struct perf_event___64 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___64 *group_leader;
	struct pmu___64 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___64 hw;
	struct perf_event_context___64 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___120 child_mutex;
	struct list_head child_list;
	struct perf_event___64 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___119 *owner;
	struct mutex___120 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___119 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___64 *);
	struct callback_head callback_head;
	struct pid_namespace___69 *ns;
	u64 id;
	perf_overflow_handler_t___64 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___54 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___64 ftrace_ops;
	struct perf_cgroup___64 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___63 {
	struct task_struct___119 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___89;

struct x86_io_apic_ops___89 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___89 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___89;

struct irq_data___89 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___89 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___96;

struct dev_pm_ops___96 {
	int (*prepare)(struct device___96 *);
	void (*complete)(struct device___96 *);
	int (*suspend)(struct device___96 *);
	int (*resume)(struct device___96 *);
	int (*freeze)(struct device___96 *);
	int (*thaw)(struct device___96 *);
	int (*poweroff)(struct device___96 *);
	int (*restore)(struct device___96 *);
	int (*suspend_late)(struct device___96 *);
	int (*resume_early)(struct device___96 *);
	int (*freeze_late)(struct device___96 *);
	int (*thaw_early)(struct device___96 *);
	int (*poweroff_late)(struct device___96 *);
	int (*restore_early)(struct device___96 *);
	int (*suspend_noirq)(struct device___96 *);
	int (*resume_noirq)(struct device___96 *);
	int (*freeze_noirq)(struct device___96 *);
	int (*thaw_noirq)(struct device___96 *);
	int (*poweroff_noirq)(struct device___96 *);
	int (*restore_noirq)(struct device___96 *);
	int (*runtime_suspend)(struct device___96 *);
	int (*runtime_resume)(struct device___96 *);
	int (*runtime_idle)(struct device___96 *);
};

struct device_type___96;

struct bus_type___96;

struct device_driver___96;

struct dev_pm_domain___96;

struct class___96;

struct attribute_group___89;

struct device_rh___96;

struct device___96 {
	struct device___96 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___96 *type;
	struct mutex___120 mutex;
	struct bus_type___96 *bus;
	struct device_driver___96 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___96 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___96 *class;
	const struct attribute_group___89 **groups;
	void (*release)(struct device___96 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___96 *device_rh;
};

struct dev_pm_info_rh___96 {
	void (*set_latency_tolerance)(struct device___96 *, s32);
};

struct dev_pm_domain___96 {
	struct dev_pm_ops___96 ops;
};

struct smp_ops___119 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___119 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___119;

struct lruvec___119 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___119 *zone;
};

struct pglist_data___119;

struct zone___119 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___119 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___119 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___119 {
	struct zone___119 *zone;
	int zone_idx;
};

struct zonelist___119 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___119 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___119 {
	struct zone___119 node_zones[4];
	struct zonelist___119 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___119 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___119;

struct dquot___119 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___120 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___119 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___119;

struct mem_dqinfo___119 {
	struct quota_format_type___119 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___119;

struct quota_format_ops___119;

struct quota_info___119 {
	unsigned int flags;
	struct mutex___120 dqio_mutex;
	struct mutex___120 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___119 *files[2];
	struct mem_dqinfo___119 info[2];
	const struct quota_format_ops___119 *ops[2];
};

struct file_system_type___119;

struct super_operations___119;

struct dquot_operations___119;

struct quotactl_ops___119;

struct dentry___119;

struct xattr_handler___82;

struct block_device___119;

struct dentry_operations___119;

struct super_block___119 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___119 *s_type;
	const struct super_operations___119 *s_op;
	const struct dquot_operations___119 *dq_op;
	const struct quotactl_ops___119 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___119 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___82 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___119 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___119 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___120 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___119 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___119 {
	int qf_fmt_id;
	const struct quota_format_ops___119 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___119 *qf_next;
};

struct quota_format_ops___119 {
	int (*check_quota_file)(struct super_block___119 *, int);
	int (*read_file_info)(struct super_block___119 *, int);
	int (*write_file_info)(struct super_block___119 *, int);
	int (*free_file_info)(struct super_block___119 *, int);
	int (*read_dqblk)(struct dquot___119 *);
	int (*commit_dqblk)(struct dquot___119 *);
	int (*release_dqblk)(struct dquot___119 *);
};

struct dquot_operations___119 {
	int (*write_dquot)(struct dquot___119 *);
	struct dquot___119 * (*alloc_dquot)(struct super_block___119 *, int);
	void (*destroy_dquot)(struct dquot___119 *);
	int (*acquire_dquot)(struct dquot___119 *);
	int (*release_dquot)(struct dquot___119 *);
	int (*mark_dirty)(struct dquot___119 *);
	int (*write_info)(struct super_block___119 *, int);
	qsize_t * (*get_reserved_space)(struct inode___119 *);
};

struct address_space_operations___119;

struct address_space___119 {
	struct inode___119 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___120 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___119 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___119;

struct file_operations___119;

struct file_lock___119;

struct inode___119 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___119 *i_op;
	struct super_block___119 *i_sb;
	struct address_space___119 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___120 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___119 *i_fop;
	struct file_lock___119 *i_flock;
	struct address_space___119 i_data;
	struct dquot___119 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___119 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___119;

struct quotactl_ops___119 {
	int (*quota_on)(struct super_block___119 *, int, int, struct path___119 *);
	int (*quota_on_meta)(struct super_block___119 *, int, int);
	int (*quota_off)(struct super_block___119 *, int);
	int (*quota_sync)(struct super_block___119 *, int);
	int (*get_info)(struct super_block___119 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___119 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___119 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___119 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___119 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___119 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___119 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___119 *, unsigned int);
};

struct vfsmount___20;

struct path___119 {
	struct vfsmount___20 *mnt;
	struct dentry___119 *dentry;
};

struct mnt_namespace___2;

struct nsproxy___71 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___2 *mnt_ns;
	struct pid_namespace___69 *pid_ns;
	struct net *net_ns;
};

struct xol_area___119 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___119 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___106;

struct memcg_cache_params___106;

struct kmem_cache___106 {
	struct kmem_cache_cpu___106 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___106 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___69 {
	rwlock_t lock;
	struct pid___69 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___119 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___119 f_path;
	struct inode___119 *f_inode;
	const struct file_operations___119 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___69 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___119 *f_mapping;
	struct mutex___120 f_pos_lock;
};

struct vm_operations_struct___106;

struct vm_area_struct___124 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___124 *vm_next;
	struct vm_area_struct___124 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___124 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___106 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___119 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___103;

struct vm_operations_struct___106 {
	void (*open)(struct vm_area_struct___124 *);
	void (*close)(struct vm_area_struct___124 *);
	int (*fault)(struct vm_area_struct___124 *, struct vm_fault___103 *);
	int (*page_mkwrite)(struct vm_area_struct___124 *, struct vm_fault___103 *);
	int (*access)(struct vm_area_struct___124 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___124 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___124 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___124 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___124 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___119 {
	struct task_struct___119 *task;
	struct core_thread___119 *next;
};

struct core_state___119 {
	atomic_t nr_threads;
	struct core_thread___119 dumper;
	struct completion startup;
};

struct vm_fault___103 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___119 *page;
};

struct seq_operations___90;

struct seq_file___91 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___120 lock;
	const struct seq_operations___90 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___90 {
	void * (*start)(struct seq_file___91 *, loff_t *);
	void (*stop)(struct seq_file___91 *, void *);
	void * (*next)(struct seq_file___91 *, void *, loff_t *);
	int (*show)(struct seq_file___91 *, void *);
};

struct dentry___119 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___119 *d_parent;
	struct qstr d_name;
	struct inode___119 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___119 *d_op;
	struct super_block___119 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___119 {
	int (*d_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_hash)(const struct dentry___119 *, struct qstr *);
	int (*d_compare)(const struct dentry___119 *, const struct dentry___119 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___119 *);
	void (*d_release)(struct dentry___119 *);
	void (*d_prune)(struct dentry___119 *);
	void (*d_iput)(struct dentry___119 *, struct inode___119 *);
	char * (*d_dname)(struct dentry___119 *, char *, int);
	struct vfsmount___20 * (*d_automount)(struct path___119 *);
	int (*d_manage)(struct dentry___119 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___20 {
	struct dentry___119 *mnt_root;
	struct super_block___119 *mnt_sb;
	int mnt_flags;
};

struct upid___69 {
	int nr;
	struct pid_namespace___69 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___69 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___119 *child_reaper;
	struct kmem_cache___106 *pid_cachep;
	unsigned int level;
	struct pid_namespace___69 *parent;
	struct vfsmount___20 *proc_mnt;
	struct dentry___119 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___69 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___69 numbers[1];
};

struct block_device___119 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___119 *bd_inode;
	struct super_block___119 *bd_super;
	struct mutex___120 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___119 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___120 bd_fsfreeze_mutex;
};

struct cgroup___82;

struct cgroup_subsys_state___83 {
	struct cgroup___82 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___119 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___119 *ia_file;
};

struct swap_info_struct___28;

struct address_space_operations___119 {
	int (*writepage)(struct page___119 *, struct writeback_control *);
	int (*readpage)(struct file___119 *, struct page___119 *);
	int (*writepages)(struct address_space___119 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___119 *);
	int (*readpages)(struct file___119 *, struct address_space___119 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___119 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___119 **, void **);
	int (*write_end)(struct file___119 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___119 *, void *);
	sector_t (*bmap)(struct address_space___119 *, sector_t);
	void (*invalidatepage)(struct page___119 *, long unsigned int);
	int (*releasepage)(struct page___119 *, gfp_t);
	void (*freepage)(struct page___119 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___119 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___119 *, struct page___119 *, struct page___119 *, enum migrate_mode);
	int (*launder_page)(struct page___119 *);
	int (*is_partially_uptodate)(struct page___119 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___119 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___119 *, struct page___119 *);
	int (*swap_activate)(struct swap_info_struct___28 *, struct file___119 *, sector_t *);
	void (*swap_deactivate)(struct file___119 *);
	void (*invalidatepage_range)(struct page___119 *, unsigned int, unsigned int);
};

struct swap_info_struct___28 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___119 *bdev;
	struct file___119 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___119 {
	struct dentry___119 * (*lookup)(struct inode___119 *, struct dentry___119 *, unsigned int);
	void * (*follow_link)(struct dentry___119 *, struct nameidata *);
	int (*permission)(struct inode___119 *, int);
	struct posix_acl * (*get_acl)(struct inode___119 *, int);
	int (*readlink)(struct dentry___119 *, char *, int);
	void (*put_link)(struct dentry___119 *, struct nameidata *, void *);
	int (*create)(struct inode___119 *, struct dentry___119 *, umode_t, bool);
	int (*link)(struct dentry___119 *, struct inode___119 *, struct dentry___119 *);
	int (*unlink)(struct inode___119 *, struct dentry___119 *);
	int (*symlink)(struct inode___119 *, struct dentry___119 *, const char *);
	int (*mkdir)(struct inode___119 *, struct dentry___119 *, umode_t);
	int (*rmdir)(struct inode___119 *, struct dentry___119 *);
	int (*mknod)(struct inode___119 *, struct dentry___119 *, umode_t, dev_t);
	int (*rename)(struct inode___119 *, struct dentry___119 *, struct inode___119 *, struct dentry___119 *);
	int (*setattr)(struct dentry___119 *, struct iattr___119 *);
	int (*getattr)(struct vfsmount___20 *, struct dentry___119 *, struct kstat *);
	int (*setxattr)(struct dentry___119 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___119 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___119 *, char *, size_t);
	int (*removexattr)(struct dentry___119 *, const char *);
	int (*fiemap)(struct inode___119 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___119 *, struct timespec *, int);
	int (*atomic_open)(struct inode___119 *, struct dentry___119 *, struct file___119 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___77;

struct file_operations___119 {
	struct module *owner;
	loff_t (*llseek)(struct file___119 *, loff_t, int);
	ssize_t (*read)(struct file___119 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___119 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___119 *, void *, filldir_t);
	unsigned int (*poll)(struct file___119 *, struct poll_table_struct___77 *);
	long int (*unlocked_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___119 *, struct vm_area_struct___124 *);
	int (*open)(struct inode___119 *, struct file___119 *);
	int (*flush)(struct file___119 *, fl_owner_t);
	int (*release)(struct inode___119 *, struct file___119 *);
	int (*fsync)(struct file___119 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___119 *, int);
	int (*lock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*sendpage)(struct file___119 *, struct page___119 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___119 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___119 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___119 *, long int, struct file_lock___119 **, void **);
		struct {
			int (*setlease)(struct file___119 *, long int, struct file_lock___119 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___119 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___91 *, struct file___119 *);
};

struct file_lock_operations___119;

struct lock_manager_operations___119;

struct file_lock___119 {
	struct file_lock___119 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___69 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___119 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___119 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___119 *fl_ops;
	const struct lock_manager_operations___119 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___119 {
	void (*fl_copy_lock)(struct file_lock___119 *, struct file_lock___119 *);
	void (*fl_release_private)(struct file_lock___119 *);
};

struct lock_manager_operations___119 {
	int (*lm_compare_owner)(struct file_lock___119 *, struct file_lock___119 *);
	long unsigned int (*lm_owner_key)(struct file_lock___119 *);
	void (*lm_notify)(struct file_lock___119 *);
	int (*lm_grant)(struct file_lock___119 *, struct file_lock___119 *, int);
	void (*lm_break)(struct file_lock___119 *);
	int (*lm_change)(struct file_lock___119 **, int);
};

struct fasync_struct___119 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___119 *fa_next;
	struct file___119 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___119 {
	const char *name;
	int fs_flags;
	struct dentry___119 * (*mount)(struct file_system_type___119 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___119 *);
	struct module *owner;
	struct file_system_type___119 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___119 {
	struct inode___119 * (*alloc_inode)(struct super_block___119 *);
	void (*destroy_inode)(struct inode___119 *);
	void (*dirty_inode)(struct inode___119 *, int);
	int (*write_inode)(struct inode___119 *, struct writeback_control *);
	int (*drop_inode)(struct inode___119 *);
	void (*evict_inode)(struct inode___119 *);
	void (*put_super)(struct super_block___119 *);
	int (*sync_fs)(struct super_block___119 *, int);
	int (*freeze_fs)(struct super_block___119 *);
	int (*unfreeze_fs)(struct super_block___119 *);
	int (*statfs)(struct dentry___119 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___119 *, int *, char *);
	void (*umount_begin)(struct super_block___119 *);
	int (*show_options)(struct seq_file___91 *, struct dentry___119 *);
	int (*show_devname)(struct seq_file___91 *, struct dentry___119 *);
	int (*show_path)(struct seq_file___91 *, struct dentry___119 *);
	int (*show_stats)(struct seq_file___91 *, struct dentry___119 *);
	ssize_t (*quota_read)(struct super_block___119 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___119 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___119 *);
	int (*bdev_try_to_free_page)(struct super_block___119 *, struct page___119 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___119 *);
	void (*free_cached_objects)(struct super_block___119 *, int);
};

struct xattr_handler___82 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___119 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___119 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___119 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___79)(struct file___119 *, wait_queue_head_t *, struct poll_table_struct___77 *);

struct poll_table_struct___77 {
	poll_queue_proc___79 _qproc;
	long unsigned int _key;
};

struct irq_chip___89 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___89 *);
	void (*irq_shutdown)(struct irq_data___89 *);
	void (*irq_enable)(struct irq_data___89 *);
	void (*irq_disable)(struct irq_data___89 *);
	void (*irq_ack)(struct irq_data___89 *);
	void (*irq_mask)(struct irq_data___89 *);
	void (*irq_mask_ack)(struct irq_data___89 *);
	void (*irq_unmask)(struct irq_data___89 *);
	void (*irq_eoi)(struct irq_data___89 *);
	int (*irq_set_affinity)(struct irq_data___89 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___89 *);
	int (*irq_set_type)(struct irq_data___89 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___89 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___89 *);
	void (*irq_bus_sync_unlock)(struct irq_data___89 *);
	void (*irq_cpu_online)(struct irq_data___89 *);
	void (*irq_cpu_offline)(struct irq_data___89 *);
	void (*irq_suspend)(struct irq_data___89 *);
	void (*irq_resume)(struct irq_data___89 *);
	void (*irq_pm_shutdown)(struct irq_data___89 *);
	void (*irq_print_chip)(struct irq_data___89 *, struct seq_file___91 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___89 *, void *);
	long unsigned int flags;
};

struct signal_struct___119 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___119 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___119 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___69 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___69 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___120 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___10 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___119 root;
	struct path___119 pwd;
};

struct css_set___82 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___83 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___64 {
	struct pmu___64 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___120 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___119 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___64 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct mount___2;

struct mnt_namespace___2 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___2 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct bin_attribute___89;

struct attribute_group___89 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___89 **bin_attrs;
};

struct bin_attribute___89 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___119 *, struct kobject___6 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___119 *, struct kobject___6 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	int (*mmap)(struct file___119 *, struct kobject___6 *, struct bin_attribute___89 *, struct vm_area_struct___124 *);
};

struct bus_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___96 *, char *);
	ssize_t (*store)(struct bus_type___96 *, const char *, size_t);
};

struct device_attribute___96;

struct driver_attribute___96;

struct bus_type___96 {
	const char *name;
	const char *dev_name;
	struct device___96 *dev_root;
	struct bus_attribute___96 *bus_attrs;
	struct device_attribute___96 *dev_attrs;
	struct driver_attribute___96 *drv_attrs;
	const struct attribute_group___89 **bus_groups;
	const struct attribute_group___89 **dev_groups;
	const struct attribute_group___89 **drv_groups;
	int (*match)(struct device___96 *, struct device_driver___96 *);
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	int (*probe)(struct device___96 *);
	int (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*online)(struct device___96 *);
	int (*offline)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct device___96 *, struct device_attribute___96 *, char *);
	ssize_t (*store)(struct device___96 *, struct device_attribute___96 *, const char *, size_t);
};

struct driver_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___96 *, char *);
	ssize_t (*store)(struct device_driver___96 *, const char *, size_t);
};

struct device_driver___96 {
	const char *name;
	struct bus_type___96 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___96 *);
	int (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	const struct attribute_group___89 **groups;
	const struct dev_pm_ops___96 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___96 {
	const char *name;
	const struct attribute_group___89 **groups;
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
};

struct class_attribute___96;

struct class___96 {
	const char *name;
	struct module *owner;
	struct class_attribute___96 *class_attrs;
	struct device_attribute___96 *dev_attrs;
	const struct attribute_group___89 **dev_groups;
	struct bin_attribute___89 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *);
	void (*class_release)(struct class___96 *);
	void (*dev_release)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
	struct subsys_private *p;
};

struct class_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct class___96 *, struct class_attribute___96 *, char *);
	ssize_t (*store)(struct class___96 *, struct class_attribute___96 *, const char *, size_t);
	const void * (*namespace)(struct class___96 *, const struct class_attribute___96 *);
};

struct device_rh___96 {
	struct dev_pm_info_rh___96 power;
};

struct kmem_cache_cpu___106 {
	void **freelist;
	long unsigned int tid;
	struct page___119 *page;
	struct page___119 *partial;
};

struct memcg_cache_params___106 {
	bool is_root_cache;
	union {
		struct kmem_cache___106 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___106 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___82;

struct cgroup___82 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___82 *parent;
	struct dentry___119 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___83 *subsys[11];
	struct cgroupfs_root___82 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___120 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___82 {
	struct super_block___119 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___82 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___38 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___119 *, struct file___119 *);
	ssize_t (*read)(struct cgroup___82 *, struct cftype___38 *, struct file___119 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___82 *, struct cftype___38 *);
	s64 (*read_s64)(struct cgroup___82 *, struct cftype___38 *);
	int (*read_map)(struct cgroup___82 *, struct cftype___38 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___82 *, struct cftype___38 *, struct seq_file___91 *);
	ssize_t (*write)(struct cgroup___82 *, struct cftype___38 *, struct file___119 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___82 *, struct cftype___38 *, u64);
	int (*write_s64)(struct cgroup___82 *, struct cftype___38 *, s64);
	int (*write_string)(struct cgroup___82 *, struct cftype___38 *, const char *);
	int (*trigger)(struct cgroup___82 *, unsigned int);
	int (*release)(struct inode___119 *, struct file___119 *);
	int (*register_event)(struct cgroup___82 *, struct cftype___38 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___82 *, struct cftype___38 *, struct eventfd_ctx *);
};

struct cftype_set___36 {
	struct list_head node;
	struct cftype___38 *cfts;
};

struct task_and_cgroup___36 {
	struct task_struct___119 *task;
	struct cgroup___82 *cgrp;
	struct css_set___82 *cg;
};

struct cgroup_taskset___36 {
	struct task_and_cgroup___36 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___82 *cur_cgrp;
};

struct cgroup_subsys___36 {
	struct cgroup_subsys_state___83 * (*css_alloc)(struct cgroup___82 *);
	int (*css_online)(struct cgroup___82 *);
	void (*css_offline)(struct cgroup___82 *);
	void (*css_free)(struct cgroup___82 *);
	int (*can_attach)(struct cgroup___82 *, struct cgroup_taskset___36 *);
	void (*cancel_attach)(struct cgroup___82 *, struct cgroup_taskset___36 *);
	void (*attach)(struct cgroup___82 *, struct cgroup_taskset___36 *);
	void (*fork)(struct task_struct___119 *);
	void (*exit)(struct cgroup___82 *, struct cgroup___82 *, struct task_struct___119 *);
	void (*bind)(struct cgroup___82 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___82 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___38 *base_cftypes;
	struct cftype_set___36 base_cftset;
	struct module *module;
};

struct perf_cpu_context___64;

struct pmu___64 {
	struct list_head entry;
	struct device___96 *dev;
	const struct attribute_group___89 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___64 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___64 *);
	void (*pmu_disable)(struct pmu___64 *);
	int (*event_init)(struct perf_event___64 *);
	int (*add)(struct perf_event___64 *, int);
	void (*del)(struct perf_event___64 *, int);
	void (*start)(struct perf_event___64 *, int);
	void (*stop)(struct perf_event___64 *, int);
	void (*read)(struct perf_event___64 *);
	void (*start_txn)(struct pmu___64 *);
	int (*commit_txn)(struct pmu___64 *);
	void (*cancel_txn)(struct pmu___64 *);
	int (*event_idx)(struct perf_event___64 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___64 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___64 *);
};

struct perf_cpu_context___64 {
	struct perf_event_context___64 ctx;
	struct perf_event_context___64 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___64 *unique_pmu;
	struct perf_cgroup___64 *cgrp;
};

struct trace_event_functions___54;

struct trace_event___54 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___54 *funcs;
};

struct ftrace_event_class___54;

struct ftrace_event_call___54 {
	struct list_head list;
	struct ftrace_event_class___54 *class;
	char *name;
	struct trace_event___54 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___64 {
	struct cgroup_subsys_state___83 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___54 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___120 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___54)(struct trace_iterator___54 *, int, struct trace_event___54 *);

struct trace_event_functions___54 {
	trace_print_func___54 trace;
	trace_print_func___54 raw;
	trace_print_func___54 hex;
	trace_print_func___54 binary;
};

struct ftrace_event_class___54 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___54 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___54 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___54 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___54 *);
};

struct syscall_metadata___24 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___54 *enter_event;
	struct ftrace_event_call___54 *exit_event;
};

struct mountpoint___2;

struct mount___2 {
	struct list_head mnt_hash;
	struct mount___2 *mnt_parent;
	struct dentry___119 *mnt_mountpoint;
	struct vfsmount___20 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___2 *mnt_master;
	struct mnt_namespace___2 *mnt_ns;
	struct mountpoint___2 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___2 {
	struct list_head m_hash;
	struct dentry___119 *m_dentry;
	int m_count;
};

enum d_walk_ret {
	D_WALK_CONTINUE = 0,
	D_WALK_QUIT = 1,
	D_WALK_NORETRY = 2,
	D_WALK_SKIP = 3,
};

struct select_data {
	struct dentry___119 *start;
	struct list_head dispose;
	int found;
};

enum slow_d_compare {
	D_COMP_OK = 0,
	D_COMP_NOMATCH = 1,
	D_COMP_SEQRETRY = 2,
};

struct page___120;

typedef struct page___120 *pgtable_t___120;

struct address_space___120;

struct kmem_cache___107;

struct page___120 {
	long unsigned int flags;
	struct address_space___120 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___120 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___120 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___107 *slab_cache;
		struct page___120 *first_page;
	};
	long: 64;
};

struct task_struct___120;

struct pv_cpu_ops___120 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___64 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___64 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___120 *);
	void (*end_context_switch)(struct task_struct___120 *);
};

struct mutex___121 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___120 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___116 {
	struct page___120 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___125;

struct signal_struct___120;

struct backing_dev_info___25;

struct css_set___83;

struct task_struct___120 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___120 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___125 *mm;
	struct mm_struct___125 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___120 *real_parent;
	struct task_struct___120 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___120 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___69 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___120 = 0,
		VTIME_USER___120 = 1,
		VTIME_SYS___120 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___64 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___120 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___25 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___83 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___121 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___116 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___125 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___125 *, struct mm_struct___125 *);
	void (*dup_mmap)(struct mm_struct___125 *, struct mm_struct___125 *);
	void (*exit_mmap)(struct mm_struct___125 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___125 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___125 *);
	void (*pgd_free)(struct mm_struct___125 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___125 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___125 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___125 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___125 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___125 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___125 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___125 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___125 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___125 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___125 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___125 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___121 lock;
	void *vdso;
} mm_context_t___121;

struct xol_area___120;

struct uprobes_state___120 {
	struct xol_area___120 *xol_area;
};

struct vm_area_struct___125;

struct file___120;

struct core_state___120;

struct mm_struct___125 {
	struct vm_area_struct___125 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___125 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___125 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___121 context;
	long unsigned int flags;
	struct core_state___120 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___120 *owner;
	struct file___120 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___120 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___120;

struct dentry_operations___120;

struct super_block___120;

struct dentry___120 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___120 *d_parent;
	struct qstr d_name;
	struct inode___120 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___120 *d_op;
	struct super_block___120 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___120;

struct address_space___120 {
	struct inode___120 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___121 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___120 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___25 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___120;

struct file_operations___120;

struct file_lock___120;

struct dquot___120;

struct block_device___120;

struct cdev___36;

struct inode___120 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___120 *i_op;
	struct super_block___120 *i_sb;
	struct address_space___120 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___121 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___120 *i_fop;
	struct file_lock___120 *i_flock;
	struct address_space___120 i_data;
	struct dquot___120 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___120 *i_bdev;
		struct cdev___36 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___21;

struct path___120;

struct dentry_operations___120 {
	int (*d_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_hash)(const struct dentry___120 *, struct qstr *);
	int (*d_compare)(const struct dentry___120 *, const struct dentry___120 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___120 *);
	void (*d_release)(struct dentry___120 *);
	void (*d_prune)(struct dentry___120 *);
	void (*d_iput)(struct dentry___120 *, struct inode___120 *);
	char * (*d_dname)(struct dentry___120 *, char *, int);
	struct vfsmount___21 * (*d_automount)(struct path___120 *);
	int (*d_manage)(struct dentry___120 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___120;

struct mem_dqinfo___120 {
	struct quota_format_type___120 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___120;

struct quota_info___120 {
	unsigned int flags;
	struct mutex___121 dqio_mutex;
	struct mutex___121 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___120 *files[2];
	struct mem_dqinfo___120 info[2];
	const struct quota_format_ops___120 *ops[2];
};

struct file_system_type___120;

struct super_operations___120;

struct dquot_operations___120;

struct quotactl_ops___120;

struct xattr_handler___83;

struct super_block___120 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___120 *s_type;
	const struct super_operations___120 *s_op;
	const struct dquot_operations___120 *dq_op;
	const struct quotactl_ops___120 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___120 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___83 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___120 *s_bdev;
	struct backing_dev_info___25 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___120 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___121 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___120 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___21 {
	struct dentry___120 *mnt_root;
	struct super_block___120 *mnt_sb;
	int mnt_flags;
};

struct path___120 {
	struct vfsmount___21 *mnt;
	struct dentry___120 *dentry;
};

struct device___97;

struct dev_pm_ops___97 {
	int (*prepare)(struct device___97 *);
	void (*complete)(struct device___97 *);
	int (*suspend)(struct device___97 *);
	int (*resume)(struct device___97 *);
	int (*freeze)(struct device___97 *);
	int (*thaw)(struct device___97 *);
	int (*poweroff)(struct device___97 *);
	int (*restore)(struct device___97 *);
	int (*suspend_late)(struct device___97 *);
	int (*resume_early)(struct device___97 *);
	int (*freeze_late)(struct device___97 *);
	int (*thaw_early)(struct device___97 *);
	int (*poweroff_late)(struct device___97 *);
	int (*restore_early)(struct device___97 *);
	int (*suspend_noirq)(struct device___97 *);
	int (*resume_noirq)(struct device___97 *);
	int (*freeze_noirq)(struct device___97 *);
	int (*thaw_noirq)(struct device___97 *);
	int (*poweroff_noirq)(struct device___97 *);
	int (*restore_noirq)(struct device___97 *);
	int (*runtime_suspend)(struct device___97 *);
	int (*runtime_resume)(struct device___97 *);
	int (*runtime_idle)(struct device___97 *);
};

struct device_type___97;

struct bus_type___97;

struct device_driver___97;

struct dev_pm_domain___97;

struct class___97;

struct attribute_group___90;

struct device_rh___97;

struct device___97 {
	struct device___97 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___97 *type;
	struct mutex___121 mutex;
	struct bus_type___97 *bus;
	struct device_driver___97 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___97 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___97 *class;
	const struct attribute_group___90 **groups;
	void (*release)(struct device___97 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___97 *device_rh;
};

struct dev_pm_info_rh___97 {
	void (*set_latency_tolerance)(struct device___97 *, s32);
};

struct dev_pm_domain___97 {
	struct dev_pm_ops___97 ops;
};

struct smp_ops___120 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___120 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___120 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___120 *bd_inode;
	struct super_block___120 *bd_super;
	struct mutex___121 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___120 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___121 bd_fsfreeze_mutex;
};

struct cgroup___83;

struct cgroup_subsys_state___84 {
	struct cgroup___83 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___120 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___120 *ia_file;
};

struct file___120 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___120 f_path;
	struct inode___120 *f_inode;
	const struct file_operations___120 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___69 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___120 *f_mapping;
	struct mutex___121 f_pos_lock;
};

struct zone___120;

struct lruvec___120 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___120 *zone;
};

struct pglist_data___120;

struct zone___120 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___120 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___120 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___120 {
	struct zone___120 *zone;
	int zone_idx;
};

struct zonelist___120 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___120 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___120 {
	struct zone___120 node_zones[4];
	struct zonelist___120 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___120 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___120 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___121 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___120 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___120 {
	int qf_fmt_id;
	const struct quota_format_ops___120 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___120 *qf_next;
};

struct quota_format_ops___120 {
	int (*check_quota_file)(struct super_block___120 *, int);
	int (*read_file_info)(struct super_block___120 *, int);
	int (*write_file_info)(struct super_block___120 *, int);
	int (*free_file_info)(struct super_block___120 *, int);
	int (*read_dqblk)(struct dquot___120 *);
	int (*commit_dqblk)(struct dquot___120 *);
	int (*release_dqblk)(struct dquot___120 *);
};

struct dquot_operations___120 {
	int (*write_dquot)(struct dquot___120 *);
	struct dquot___120 * (*alloc_dquot)(struct super_block___120 *, int);
	void (*destroy_dquot)(struct dquot___120 *);
	int (*acquire_dquot)(struct dquot___120 *);
	int (*release_dquot)(struct dquot___120 *);
	int (*mark_dirty)(struct dquot___120 *);
	int (*write_info)(struct super_block___120 *, int);
	qsize_t * (*get_reserved_space)(struct inode___120 *);
};

struct quotactl_ops___120 {
	int (*quota_on)(struct super_block___120 *, int, int, struct path___120 *);
	int (*quota_on_meta)(struct super_block___120 *, int, int);
	int (*quota_off)(struct super_block___120 *, int);
	int (*quota_sync)(struct super_block___120 *, int);
	int (*get_info)(struct super_block___120 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___120 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___120 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___120 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___120 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___120 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___120 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___120 *, unsigned int);
};

struct swap_info_struct___29;

struct address_space_operations___120 {
	int (*writepage)(struct page___120 *, struct writeback_control *);
	int (*readpage)(struct file___120 *, struct page___120 *);
	int (*writepages)(struct address_space___120 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___120 *);
	int (*readpages)(struct file___120 *, struct address_space___120 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___120 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___120 **, void **);
	int (*write_end)(struct file___120 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___120 *, void *);
	sector_t (*bmap)(struct address_space___120 *, sector_t);
	void (*invalidatepage)(struct page___120 *, long unsigned int);
	int (*releasepage)(struct page___120 *, gfp_t);
	void (*freepage)(struct page___120 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___120 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___120 *, struct page___120 *, struct page___120 *, enum migrate_mode);
	int (*launder_page)(struct page___120 *);
	int (*is_partially_uptodate)(struct page___120 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___120 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___120 *, struct page___120 *);
	int (*swap_activate)(struct swap_info_struct___29 *, struct file___120 *, sector_t *);
	void (*swap_deactivate)(struct file___120 *);
	void (*invalidatepage_range)(struct page___120 *, unsigned int, unsigned int);
};

struct swap_info_struct___29 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___120 *bdev;
	struct file___120 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___25 {
	struct backing_dev_info___25 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___25 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___25 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___97 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___120 *debug_dir;
	struct dentry___120 *debug_stats;
};

struct cdev___36 {
	struct kobject___6 kobj;
	struct module *owner;
	const struct file_operations___120 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___120 {
	struct dentry___120 * (*lookup)(struct inode___120 *, struct dentry___120 *, unsigned int);
	void * (*follow_link)(struct dentry___120 *, struct nameidata *);
	int (*permission)(struct inode___120 *, int);
	struct posix_acl * (*get_acl)(struct inode___120 *, int);
	int (*readlink)(struct dentry___120 *, char *, int);
	void (*put_link)(struct dentry___120 *, struct nameidata *, void *);
	int (*create)(struct inode___120 *, struct dentry___120 *, umode_t, bool);
	int (*link)(struct dentry___120 *, struct inode___120 *, struct dentry___120 *);
	int (*unlink)(struct inode___120 *, struct dentry___120 *);
	int (*symlink)(struct inode___120 *, struct dentry___120 *, const char *);
	int (*mkdir)(struct inode___120 *, struct dentry___120 *, umode_t);
	int (*rmdir)(struct inode___120 *, struct dentry___120 *);
	int (*mknod)(struct inode___120 *, struct dentry___120 *, umode_t, dev_t);
	int (*rename)(struct inode___120 *, struct dentry___120 *, struct inode___120 *, struct dentry___120 *);
	int (*setattr)(struct dentry___120 *, struct iattr___120 *);
	int (*getattr)(struct vfsmount___21 *, struct dentry___120 *, struct kstat *);
	int (*setxattr)(struct dentry___120 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___120 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___120 *, char *, size_t);
	int (*removexattr)(struct dentry___120 *, const char *);
	int (*fiemap)(struct inode___120 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___120 *, struct timespec *, int);
	int (*atomic_open)(struct inode___120 *, struct dentry___120 *, struct file___120 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___120 {
	struct module *owner;
	loff_t (*llseek)(struct file___120 *, loff_t, int);
	ssize_t (*read)(struct file___120 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___120 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___120 *, void *, filldir_t);
	unsigned int (*poll)(struct file___120 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___120 *, struct vm_area_struct___125 *);
	int (*open)(struct inode___120 *, struct file___120 *);
	int (*flush)(struct file___120 *, fl_owner_t);
	int (*release)(struct inode___120 *, struct file___120 *);
	int (*fsync)(struct file___120 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___120 *, int);
	int (*lock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*sendpage)(struct file___120 *, struct page___120 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___120 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___120 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___120 *, long int, struct file_lock___120 **, void **);
		struct {
			int (*setlease)(struct file___120 *, long int, struct file_lock___120 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___120 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___120 *);
};

struct fasync_struct___120;

struct file_lock_operations___120;

struct lock_manager_operations___120;

struct file_lock___120 {
	struct file_lock___120 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___69 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___120 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___120 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___120 *fl_ops;
	const struct lock_manager_operations___120 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___120 {
	void (*fl_copy_lock)(struct file_lock___120 *, struct file_lock___120 *);
	void (*fl_release_private)(struct file_lock___120 *);
};

struct lock_manager_operations___120 {
	int (*lm_compare_owner)(struct file_lock___120 *, struct file_lock___120 *);
	long unsigned int (*lm_owner_key)(struct file_lock___120 *);
	void (*lm_notify)(struct file_lock___120 *);
	int (*lm_grant)(struct file_lock___120 *, struct file_lock___120 *, int);
	void (*lm_break)(struct file_lock___120 *);
	int (*lm_change)(struct file_lock___120 **, int);
};

struct fasync_struct___120 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___120 *fa_next;
	struct file___120 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___120 {
	const char *name;
	int fs_flags;
	struct dentry___120 * (*mount)(struct file_system_type___120 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___120 *);
	struct module *owner;
	struct file_system_type___120 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___120 {
	struct inode___120 * (*alloc_inode)(struct super_block___120 *);
	void (*destroy_inode)(struct inode___120 *);
	void (*dirty_inode)(struct inode___120 *, int);
	int (*write_inode)(struct inode___120 *, struct writeback_control *);
	int (*drop_inode)(struct inode___120 *);
	void (*evict_inode)(struct inode___120 *);
	void (*put_super)(struct super_block___120 *);
	int (*sync_fs)(struct super_block___120 *, int);
	int (*freeze_fs)(struct super_block___120 *);
	int (*unfreeze_fs)(struct super_block___120 *);
	int (*statfs)(struct dentry___120 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___120 *, int *, char *);
	void (*umount_begin)(struct super_block___120 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___120 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___120 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___120 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___120 *);
	ssize_t (*quota_read)(struct super_block___120 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___120 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___120 *);
	int (*bdev_try_to_free_page)(struct super_block___120 *, struct page___120 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___120 *);
	void (*free_cached_objects)(struct super_block___120 *, int);
};

struct xattr_handler___83 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___120 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___120 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___120 *, const char *, const void *, size_t, int, int);
};

struct vm_operations_struct___107;

struct vm_area_struct___125 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___125 *vm_next;
	struct vm_area_struct___125 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___125 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___107 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___120 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum file_time_flags {
	S_ATIME = 1,
	S_MTIME = 2,
	S_CTIME = 4,
	S_VERSION = 8,
};

struct xol_area___120 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___120 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___107;

struct memcg_cache_params___107;

struct kmem_cache___107 {
	struct kmem_cache_cpu___107 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___107 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___104;

struct vm_operations_struct___107 {
	void (*open)(struct vm_area_struct___125 *);
	void (*close)(struct vm_area_struct___125 *);
	int (*fault)(struct vm_area_struct___125 *, struct vm_fault___104 *);
	int (*page_mkwrite)(struct vm_area_struct___125 *, struct vm_fault___104 *);
	int (*access)(struct vm_area_struct___125 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___125 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___125 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___125 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___125 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___120 {
	struct task_struct___120 *task;
	struct core_thread___120 *next;
};

struct core_state___120 {
	atomic_t nr_threads;
	struct core_thread___120 dumper;
	struct completion startup;
};

struct vm_fault___104 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___120 *page;
};

struct signal_struct___120 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___120 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___120 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___69 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___69 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___121 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___83 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___84 *subsys[11];
	struct callback_head callback_head;
};

struct bin_attribute___90;

struct attribute_group___90 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___90 **bin_attrs;
};

struct bin_attribute___90 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___120 *, struct kobject___6 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___120 *, struct kobject___6 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	int (*mmap)(struct file___120 *, struct kobject___6 *, struct bin_attribute___90 *, struct vm_area_struct___125 *);
};

struct kmem_cache_cpu___107 {
	void **freelist;
	long unsigned int tid;
	struct page___120 *page;
	struct page___120 *partial;
};

struct memcg_cache_params___107 {
	bool is_root_cache;
	union {
		struct kmem_cache___107 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___107 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___83;

struct cgroup___83 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___83 *parent;
	struct dentry___120 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___84 *subsys[11];
	struct cgroupfs_root___83 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___121 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___83 {
	struct super_block___120 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___83 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___39 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___120 *, struct file___120 *);
	ssize_t (*read)(struct cgroup___83 *, struct cftype___39 *, struct file___120 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___83 *, struct cftype___39 *);
	s64 (*read_s64)(struct cgroup___83 *, struct cftype___39 *);
	int (*read_map)(struct cgroup___83 *, struct cftype___39 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___83 *, struct cftype___39 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___83 *, struct cftype___39 *, struct file___120 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___83 *, struct cftype___39 *, u64);
	int (*write_s64)(struct cgroup___83 *, struct cftype___39 *, s64);
	int (*write_string)(struct cgroup___83 *, struct cftype___39 *, const char *);
	int (*trigger)(struct cgroup___83 *, unsigned int);
	int (*release)(struct inode___120 *, struct file___120 *);
	int (*register_event)(struct cgroup___83 *, struct cftype___39 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___83 *, struct cftype___39 *, struct eventfd_ctx *);
};

struct cftype_set___37 {
	struct list_head node;
	struct cftype___39 *cfts;
};

struct task_and_cgroup___37 {
	struct task_struct___120 *task;
	struct cgroup___83 *cgrp;
	struct css_set___83 *cg;
};

struct cgroup_taskset___37 {
	struct task_and_cgroup___37 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___83 *cur_cgrp;
};

struct cgroup_subsys___37 {
	struct cgroup_subsys_state___84 * (*css_alloc)(struct cgroup___83 *);
	int (*css_online)(struct cgroup___83 *);
	void (*css_offline)(struct cgroup___83 *);
	void (*css_free)(struct cgroup___83 *);
	int (*can_attach)(struct cgroup___83 *, struct cgroup_taskset___37 *);
	void (*cancel_attach)(struct cgroup___83 *, struct cgroup_taskset___37 *);
	void (*attach)(struct cgroup___83 *, struct cgroup_taskset___37 *);
	void (*fork)(struct task_struct___120 *);
	void (*exit)(struct cgroup___83 *, struct cgroup___83 *, struct task_struct___120 *);
	void (*bind)(struct cgroup___83 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___83 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___39 *base_cftypes;
	struct cftype_set___37 base_cftset;
	struct module *module;
};

struct bus_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___97 *, char *);
	ssize_t (*store)(struct bus_type___97 *, const char *, size_t);
};

struct device_attribute___97;

struct driver_attribute___97;

struct bus_type___97 {
	const char *name;
	const char *dev_name;
	struct device___97 *dev_root;
	struct bus_attribute___97 *bus_attrs;
	struct device_attribute___97 *dev_attrs;
	struct driver_attribute___97 *drv_attrs;
	const struct attribute_group___90 **bus_groups;
	const struct attribute_group___90 **dev_groups;
	const struct attribute_group___90 **drv_groups;
	int (*match)(struct device___97 *, struct device_driver___97 *);
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	int (*probe)(struct device___97 *);
	int (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*online)(struct device___97 *);
	int (*offline)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct device___97 *, struct device_attribute___97 *, char *);
	ssize_t (*store)(struct device___97 *, struct device_attribute___97 *, const char *, size_t);
};

struct driver_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___97 *, char *);
	ssize_t (*store)(struct device_driver___97 *, const char *, size_t);
};

struct device_driver___97 {
	const char *name;
	struct bus_type___97 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___97 *);
	int (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	const struct attribute_group___90 **groups;
	const struct dev_pm_ops___97 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___97 {
	const char *name;
	const struct attribute_group___90 **groups;
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
};

struct class_attribute___97;

struct class___97 {
	const char *name;
	struct module *owner;
	struct class_attribute___97 *class_attrs;
	struct device_attribute___97 *dev_attrs;
	const struct attribute_group___90 **dev_groups;
	struct bin_attribute___90 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *);
	void (*class_release)(struct class___97 *);
	void (*dev_release)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
	struct subsys_private *p;
};

struct class_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct class___97 *, struct class_attribute___97 *, char *);
	ssize_t (*store)(struct class___97 *, struct class_attribute___97 *, const char *, size_t);
	const void * (*namespace)(struct class___97 *, const struct class_attribute___97 *);
};

struct device_rh___97 {
	struct dev_pm_info_rh___97 power;
};

typedef struct poll_table_struct___73 poll_table___12;

struct page___121;

typedef struct page___121 *pgtable_t___121;

struct address_space___121;

struct kmem_cache___108;

struct page___121 {
	long unsigned int flags;
	struct address_space___121 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___121 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___121 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___108 *slab_cache;
		struct page___121 *first_page;
	};
	long: 64;
};

struct thread_struct___65;

struct task_struct___121;

struct pv_cpu_ops___121 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___65 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___65 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___121 *);
	void (*end_context_switch)(struct task_struct___121 *);
};

struct perf_event___65;

struct thread_struct___65 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___65 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___70;

struct pid_link___70 {
	struct hlist_node node;
	struct pid___70 *pid;
};

struct mutex___122 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___121 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___117 {
	struct page___121 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___126;

struct fs_struct___11;

struct nsproxy___72;

struct signal_struct___121;

struct css_set___84;

struct perf_event_context___65;

struct task_struct___121 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___121 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___126 *mm;
	struct mm_struct___126 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___121 *real_parent;
	struct task_struct___121 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___121 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___70 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___121 = 0,
		VTIME_USER___121 = 1,
		VTIME_SYS___121 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___65 thread;
	struct fs_struct___11 *fs;
	struct files_struct *files;
	struct nsproxy___72 *nsproxy;
	struct signal_struct___121 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___84 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___65 *perf_event_ctxp[2];
	struct mutex___122 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___117 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___126 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___126 *, struct mm_struct___126 *);
	void (*dup_mmap)(struct mm_struct___126 *, struct mm_struct___126 *);
	void (*exit_mmap)(struct mm_struct___126 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___126 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___126 *);
	void (*pgd_free)(struct mm_struct___126 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___126 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___126 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___126 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___126 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___126 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___126 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___126 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___126 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___126 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___126 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___126 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___122 lock;
	void *vdso;
} mm_context_t___122;

struct xol_area___121;

struct uprobes_state___121 {
	struct xol_area___121 *xol_area;
};

struct vm_area_struct___126;

struct file___121;

struct core_state___121;

struct mm_struct___126 {
	struct vm_area_struct___126 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___126 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___126 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___122 context;
	long unsigned int flags;
	struct core_state___121 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___121 *owner;
	struct file___121 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___121 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___65 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___121 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___121 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___121 *target;
};

typedef void (*perf_overflow_handler_t___65)(struct perf_event___65 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___65;

typedef void (*ftrace_func_t___65)(long unsigned int, long unsigned int, struct ftrace_ops___65 *, struct pt_regs *);

struct ftrace_ops___65 {
	ftrace_func_t___65 func;
	struct ftrace_ops___65 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___122 regex_lock;
};

struct pmu___65;

struct fasync_struct___121;

struct pid_namespace___70;

struct ftrace_event_call___55;

struct perf_cgroup___65;

struct perf_event___65 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___65 *group_leader;
	struct pmu___65 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___65 hw;
	struct perf_event_context___65 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___122 child_mutex;
	struct list_head child_list;
	struct perf_event___65 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___121 *owner;
	struct mutex___122 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___121 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___65 *);
	struct callback_head callback_head;
	struct pid_namespace___70 *ns;
	u64 id;
	perf_overflow_handler_t___65 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___55 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___65 ftrace_ops;
	struct perf_cgroup___65 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___64 {
	struct task_struct___121 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___90;

struct x86_io_apic_ops___90 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___90 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___90;

struct irq_data___90 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___90 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___98;

struct dev_pm_ops___98 {
	int (*prepare)(struct device___98 *);
	void (*complete)(struct device___98 *);
	int (*suspend)(struct device___98 *);
	int (*resume)(struct device___98 *);
	int (*freeze)(struct device___98 *);
	int (*thaw)(struct device___98 *);
	int (*poweroff)(struct device___98 *);
	int (*restore)(struct device___98 *);
	int (*suspend_late)(struct device___98 *);
	int (*resume_early)(struct device___98 *);
	int (*freeze_late)(struct device___98 *);
	int (*thaw_early)(struct device___98 *);
	int (*poweroff_late)(struct device___98 *);
	int (*restore_early)(struct device___98 *);
	int (*suspend_noirq)(struct device___98 *);
	int (*resume_noirq)(struct device___98 *);
	int (*freeze_noirq)(struct device___98 *);
	int (*thaw_noirq)(struct device___98 *);
	int (*poweroff_noirq)(struct device___98 *);
	int (*restore_noirq)(struct device___98 *);
	int (*runtime_suspend)(struct device___98 *);
	int (*runtime_resume)(struct device___98 *);
	int (*runtime_idle)(struct device___98 *);
};

struct device_type___98;

struct bus_type___98;

struct device_driver___98;

struct dev_pm_domain___98;

struct class___98;

struct attribute_group___91;

struct device_rh___98;

struct device___98 {
	struct device___98 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___98 *type;
	struct mutex___122 mutex;
	struct bus_type___98 *bus;
	struct device_driver___98 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___98 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___98 *class;
	const struct attribute_group___91 **groups;
	void (*release)(struct device___98 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___98 *device_rh;
};

struct dev_pm_info_rh___98 {
	void (*set_latency_tolerance)(struct device___98 *, s32);
};

struct dev_pm_domain___98 {
	struct dev_pm_ops___98 ops;
};

struct smp_ops___121 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___121 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___121;

struct lruvec___121 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___121 *zone;
};

struct pglist_data___121;

struct zone___121 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___121 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___121 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___121 {
	struct zone___121 *zone;
	int zone_idx;
};

struct zonelist___121 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___121 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___121 {
	struct zone___121 node_zones[4];
	struct zonelist___121 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___121 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___121;

struct dquot___121 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___122 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___121 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___121;

struct mem_dqinfo___121 {
	struct quota_format_type___121 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___121;

struct quota_format_ops___121;

struct quota_info___121 {
	unsigned int flags;
	struct mutex___122 dqio_mutex;
	struct mutex___122 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___121 *files[2];
	struct mem_dqinfo___121 info[2];
	const struct quota_format_ops___121 *ops[2];
};

struct file_system_type___121;

struct super_operations___121;

struct dquot_operations___121;

struct quotactl_ops___121;

struct dentry___121;

struct xattr_handler___84;

struct block_device___121;

struct dentry_operations___121;

struct super_block___121 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___121 *s_type;
	const struct super_operations___121 *s_op;
	const struct dquot_operations___121 *dq_op;
	const struct quotactl_ops___121 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___121 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___84 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___121 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___121 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___122 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___121 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___121 {
	int qf_fmt_id;
	const struct quota_format_ops___121 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___121 *qf_next;
};

struct quota_format_ops___121 {
	int (*check_quota_file)(struct super_block___121 *, int);
	int (*read_file_info)(struct super_block___121 *, int);
	int (*write_file_info)(struct super_block___121 *, int);
	int (*free_file_info)(struct super_block___121 *, int);
	int (*read_dqblk)(struct dquot___121 *);
	int (*commit_dqblk)(struct dquot___121 *);
	int (*release_dqblk)(struct dquot___121 *);
};

struct dquot_operations___121 {
	int (*write_dquot)(struct dquot___121 *);
	struct dquot___121 * (*alloc_dquot)(struct super_block___121 *, int);
	void (*destroy_dquot)(struct dquot___121 *);
	int (*acquire_dquot)(struct dquot___121 *);
	int (*release_dquot)(struct dquot___121 *);
	int (*mark_dirty)(struct dquot___121 *);
	int (*write_info)(struct super_block___121 *, int);
	qsize_t * (*get_reserved_space)(struct inode___121 *);
};

struct address_space_operations___121;

struct address_space___121 {
	struct inode___121 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___122 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___121 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___121;

struct file_operations___121;

struct file_lock___121;

struct inode___121 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___121 *i_op;
	struct super_block___121 *i_sb;
	struct address_space___121 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___122 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___121 *i_fop;
	struct file_lock___121 *i_flock;
	struct address_space___121 i_data;
	struct dquot___121 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___121 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___121;

struct quotactl_ops___121 {
	int (*quota_on)(struct super_block___121 *, int, int, struct path___121 *);
	int (*quota_on_meta)(struct super_block___121 *, int, int);
	int (*quota_off)(struct super_block___121 *, int);
	int (*quota_sync)(struct super_block___121 *, int);
	int (*get_info)(struct super_block___121 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___121 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___121 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___121 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___121 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___121 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___121 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___121 *, unsigned int);
};

struct vfsmount___22;

struct path___121 {
	struct vfsmount___22 *mnt;
	struct dentry___121 *dentry;
};

struct mnt_namespace___3;

struct nsproxy___72 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___3 *mnt_ns;
	struct pid_namespace___70 *pid_ns;
	struct net *net_ns;
};

struct xol_area___121 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___121 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___108;

struct memcg_cache_params___108;

struct kmem_cache___108 {
	struct kmem_cache_cpu___108 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___108 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___70 {
	rwlock_t lock;
	struct pid___70 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___121 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___121 f_path;
	struct inode___121 *f_inode;
	const struct file_operations___121 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___121 *f_mapping;
	struct mutex___122 f_pos_lock;
};

struct vm_operations_struct___108;

struct vm_area_struct___126 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___126 *vm_next;
	struct vm_area_struct___126 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___126 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___108 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___121 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___105;

struct vm_operations_struct___108 {
	void (*open)(struct vm_area_struct___126 *);
	void (*close)(struct vm_area_struct___126 *);
	int (*fault)(struct vm_area_struct___126 *, struct vm_fault___105 *);
	int (*page_mkwrite)(struct vm_area_struct___126 *, struct vm_fault___105 *);
	int (*access)(struct vm_area_struct___126 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___126 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___126 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___126 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___126 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___121 {
	struct task_struct___121 *task;
	struct core_thread___121 *next;
};

struct core_state___121 {
	atomic_t nr_threads;
	struct core_thread___121 dumper;
	struct completion startup;
};

struct vm_fault___105 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___121 *page;
};

struct seq_operations___91;

struct seq_file___92 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___122 lock;
	const struct seq_operations___91 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___91 {
	void * (*start)(struct seq_file___92 *, loff_t *);
	void (*stop)(struct seq_file___92 *, void *);
	void * (*next)(struct seq_file___92 *, void *, loff_t *);
	int (*show)(struct seq_file___92 *, void *);
};

struct dentry___121 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___121 *d_parent;
	struct qstr d_name;
	struct inode___121 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___121 *d_op;
	struct super_block___121 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___121 {
	int (*d_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_hash)(const struct dentry___121 *, struct qstr *);
	int (*d_compare)(const struct dentry___121 *, const struct dentry___121 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___121 *);
	void (*d_release)(struct dentry___121 *);
	void (*d_prune)(struct dentry___121 *);
	void (*d_iput)(struct dentry___121 *, struct inode___121 *);
	char * (*d_dname)(struct dentry___121 *, char *, int);
	struct vfsmount___22 * (*d_automount)(struct path___121 *);
	int (*d_manage)(struct dentry___121 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___22 {
	struct dentry___121 *mnt_root;
	struct super_block___121 *mnt_sb;
	int mnt_flags;
};

struct upid___70 {
	int nr;
	struct pid_namespace___70 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___70 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___121 *child_reaper;
	struct kmem_cache___108 *pid_cachep;
	unsigned int level;
	struct pid_namespace___70 *parent;
	struct vfsmount___22 *proc_mnt;
	struct dentry___121 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___70 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___70 numbers[1];
};

struct block_device___121 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___121 *bd_inode;
	struct super_block___121 *bd_super;
	struct mutex___122 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___121 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___122 bd_fsfreeze_mutex;
};

struct cgroup___84;

struct cgroup_subsys_state___85 {
	struct cgroup___84 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___121 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___121 *ia_file;
};

struct address_space_operations___121 {
	int (*writepage)(struct page___121 *, struct writeback_control *);
	int (*readpage)(struct file___121 *, struct page___121 *);
	int (*writepages)(struct address_space___121 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___121 *);
	int (*readpages)(struct file___121 *, struct address_space___121 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___121 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___121 **, void **);
	int (*write_end)(struct file___121 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___121 *, void *);
	sector_t (*bmap)(struct address_space___121 *, sector_t);
	void (*invalidatepage)(struct page___121 *, long unsigned int);
	int (*releasepage)(struct page___121 *, gfp_t);
	void (*freepage)(struct page___121 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___121 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___121 *, struct page___121 *, struct page___121 *, enum migrate_mode);
	int (*launder_page)(struct page___121 *);
	int (*is_partially_uptodate)(struct page___121 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___121 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___121 *, struct page___121 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___121 *, sector_t *);
	void (*swap_deactivate)(struct file___121 *);
	void (*invalidatepage_range)(struct page___121 *, unsigned int, unsigned int);
};

struct nameidata___10;

struct inode_operations___121 {
	struct dentry___121 * (*lookup)(struct inode___121 *, struct dentry___121 *, unsigned int);
	void * (*follow_link)(struct dentry___121 *, struct nameidata___10 *);
	int (*permission)(struct inode___121 *, int);
	struct posix_acl * (*get_acl)(struct inode___121 *, int);
	int (*readlink)(struct dentry___121 *, char *, int);
	void (*put_link)(struct dentry___121 *, struct nameidata___10 *, void *);
	int (*create)(struct inode___121 *, struct dentry___121 *, umode_t, bool);
	int (*link)(struct dentry___121 *, struct inode___121 *, struct dentry___121 *);
	int (*unlink)(struct inode___121 *, struct dentry___121 *);
	int (*symlink)(struct inode___121 *, struct dentry___121 *, const char *);
	int (*mkdir)(struct inode___121 *, struct dentry___121 *, umode_t);
	int (*rmdir)(struct inode___121 *, struct dentry___121 *);
	int (*mknod)(struct inode___121 *, struct dentry___121 *, umode_t, dev_t);
	int (*rename)(struct inode___121 *, struct dentry___121 *, struct inode___121 *, struct dentry___121 *);
	int (*setattr)(struct dentry___121 *, struct iattr___121 *);
	int (*getattr)(struct vfsmount___22 *, struct dentry___121 *, struct kstat *);
	int (*setxattr)(struct dentry___121 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___121 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___121 *, char *, size_t);
	int (*removexattr)(struct dentry___121 *, const char *);
	int (*fiemap)(struct inode___121 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___121 *, struct timespec *, int);
	int (*atomic_open)(struct inode___121 *, struct dentry___121 *, struct file___121 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___78;

struct file_operations___121 {
	struct module *owner;
	loff_t (*llseek)(struct file___121 *, loff_t, int);
	ssize_t (*read)(struct file___121 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___121 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___121 *, void *, filldir_t);
	unsigned int (*poll)(struct file___121 *, struct poll_table_struct___78 *);
	long int (*unlocked_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___121 *, struct vm_area_struct___126 *);
	int (*open)(struct inode___121 *, struct file___121 *);
	int (*flush)(struct file___121 *, fl_owner_t);
	int (*release)(struct inode___121 *, struct file___121 *);
	int (*fsync)(struct file___121 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___121 *, int);
	int (*lock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*sendpage)(struct file___121 *, struct page___121 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___121 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___121 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___121 *, long int, struct file_lock___121 **, void **);
		struct {
			int (*setlease)(struct file___121 *, long int, struct file_lock___121 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___121 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___92 *, struct file___121 *);
};

struct file_lock_operations___121;

struct lock_manager_operations___121;

struct file_lock___121 {
	struct file_lock___121 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___70 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___121 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___121 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___121 *fl_ops;
	const struct lock_manager_operations___121 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___121 {
	void (*fl_copy_lock)(struct file_lock___121 *, struct file_lock___121 *);
	void (*fl_release_private)(struct file_lock___121 *);
};

struct lock_manager_operations___121 {
	int (*lm_compare_owner)(struct file_lock___121 *, struct file_lock___121 *);
	long unsigned int (*lm_owner_key)(struct file_lock___121 *);
	void (*lm_notify)(struct file_lock___121 *);
	int (*lm_grant)(struct file_lock___121 *, struct file_lock___121 *, int);
	void (*lm_break)(struct file_lock___121 *);
	int (*lm_change)(struct file_lock___121 **, int);
};

struct fasync_struct___121 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___121 *fa_next;
	struct file___121 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___121 {
	const char *name;
	int fs_flags;
	struct dentry___121 * (*mount)(struct file_system_type___121 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___121 *);
	struct module *owner;
	struct file_system_type___121 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___121 {
	struct inode___121 * (*alloc_inode)(struct super_block___121 *);
	void (*destroy_inode)(struct inode___121 *);
	void (*dirty_inode)(struct inode___121 *, int);
	int (*write_inode)(struct inode___121 *, struct writeback_control *);
	int (*drop_inode)(struct inode___121 *);
	void (*evict_inode)(struct inode___121 *);
	void (*put_super)(struct super_block___121 *);
	int (*sync_fs)(struct super_block___121 *, int);
	int (*freeze_fs)(struct super_block___121 *);
	int (*unfreeze_fs)(struct super_block___121 *);
	int (*statfs)(struct dentry___121 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___121 *, int *, char *);
	void (*umount_begin)(struct super_block___121 *);
	int (*show_options)(struct seq_file___92 *, struct dentry___121 *);
	int (*show_devname)(struct seq_file___92 *, struct dentry___121 *);
	int (*show_path)(struct seq_file___92 *, struct dentry___121 *);
	int (*show_stats)(struct seq_file___92 *, struct dentry___121 *);
	ssize_t (*quota_read)(struct super_block___121 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___121 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___121 *);
	int (*bdev_try_to_free_page)(struct super_block___121 *, struct page___121 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___121 *);
	void (*free_cached_objects)(struct super_block___121 *, int);
};

struct xattr_handler___84 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___121 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___121 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___121 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___80)(struct file___121 *, wait_queue_head_t *, struct poll_table_struct___78 *);

struct poll_table_struct___78 {
	poll_queue_proc___80 _qproc;
	long unsigned int _key;
};

struct nameidata___10 {
	struct path___121 path;
	struct qstr last;
	struct path___121 root;
	struct inode___121 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct irq_chip___90 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___90 *);
	void (*irq_shutdown)(struct irq_data___90 *);
	void (*irq_enable)(struct irq_data___90 *);
	void (*irq_disable)(struct irq_data___90 *);
	void (*irq_ack)(struct irq_data___90 *);
	void (*irq_mask)(struct irq_data___90 *);
	void (*irq_mask_ack)(struct irq_data___90 *);
	void (*irq_unmask)(struct irq_data___90 *);
	void (*irq_eoi)(struct irq_data___90 *);
	int (*irq_set_affinity)(struct irq_data___90 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___90 *);
	int (*irq_set_type)(struct irq_data___90 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___90 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___90 *);
	void (*irq_bus_sync_unlock)(struct irq_data___90 *);
	void (*irq_cpu_online)(struct irq_data___90 *);
	void (*irq_cpu_offline)(struct irq_data___90 *);
	void (*irq_suspend)(struct irq_data___90 *);
	void (*irq_resume)(struct irq_data___90 *);
	void (*irq_pm_shutdown)(struct irq_data___90 *);
	void (*irq_print_chip)(struct irq_data___90 *, struct seq_file___92 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___90 *, void *);
	long unsigned int flags;
};

struct signal_struct___121 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___121 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___121 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___70 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___122 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___11 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___121 root;
	struct path___121 pwd;
};

struct css_set___84 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___85 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___65 {
	struct pmu___65 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___122 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___121 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___65 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct mount___3;

struct mnt_namespace___3 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___3 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct bin_attribute___91;

struct attribute_group___91 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___91 **bin_attrs;
};

struct bin_attribute___91 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___121 *, struct kobject___6 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___121 *, struct kobject___6 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	int (*mmap)(struct file___121 *, struct kobject___6 *, struct bin_attribute___91 *, struct vm_area_struct___126 *);
};

struct bus_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___98 *, char *);
	ssize_t (*store)(struct bus_type___98 *, const char *, size_t);
};

struct device_attribute___98;

struct driver_attribute___98;

struct bus_type___98 {
	const char *name;
	const char *dev_name;
	struct device___98 *dev_root;
	struct bus_attribute___98 *bus_attrs;
	struct device_attribute___98 *dev_attrs;
	struct driver_attribute___98 *drv_attrs;
	const struct attribute_group___91 **bus_groups;
	const struct attribute_group___91 **dev_groups;
	const struct attribute_group___91 **drv_groups;
	int (*match)(struct device___98 *, struct device_driver___98 *);
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	int (*probe)(struct device___98 *);
	int (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*online)(struct device___98 *);
	int (*offline)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct device___98 *, struct device_attribute___98 *, char *);
	ssize_t (*store)(struct device___98 *, struct device_attribute___98 *, const char *, size_t);
};

struct driver_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___98 *, char *);
	ssize_t (*store)(struct device_driver___98 *, const char *, size_t);
};

struct device_driver___98 {
	const char *name;
	struct bus_type___98 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___98 *);
	int (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	const struct attribute_group___91 **groups;
	const struct dev_pm_ops___98 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___98 {
	const char *name;
	const struct attribute_group___91 **groups;
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
};

struct class_attribute___98;

struct class___98 {
	const char *name;
	struct module *owner;
	struct class_attribute___98 *class_attrs;
	struct device_attribute___98 *dev_attrs;
	const struct attribute_group___91 **dev_groups;
	struct bin_attribute___91 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *);
	void (*class_release)(struct class___98 *);
	void (*dev_release)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
	struct subsys_private *p;
};

struct class_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct class___98 *, struct class_attribute___98 *, char *);
	ssize_t (*store)(struct class___98 *, struct class_attribute___98 *, const char *, size_t);
	const void * (*namespace)(struct class___98 *, const struct class_attribute___98 *);
};

struct device_rh___98 {
	struct dev_pm_info_rh___98 power;
};

struct kmem_cache_cpu___108 {
	void **freelist;
	long unsigned int tid;
	struct page___121 *page;
	struct page___121 *partial;
};

struct memcg_cache_params___108 {
	bool is_root_cache;
	union {
		struct kmem_cache___108 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___108 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___84;

struct cgroup___84 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___84 *parent;
	struct dentry___121 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___85 *subsys[11];
	struct cgroupfs_root___84 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___122 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___84 {
	struct super_block___121 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___84 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___65;

struct pmu___65 {
	struct list_head entry;
	struct device___98 *dev;
	const struct attribute_group___91 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___65 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___65 *);
	void (*pmu_disable)(struct pmu___65 *);
	int (*event_init)(struct perf_event___65 *);
	int (*add)(struct perf_event___65 *, int);
	void (*del)(struct perf_event___65 *, int);
	void (*start)(struct perf_event___65 *, int);
	void (*stop)(struct perf_event___65 *, int);
	void (*read)(struct perf_event___65 *);
	void (*start_txn)(struct pmu___65 *);
	int (*commit_txn)(struct pmu___65 *);
	void (*cancel_txn)(struct pmu___65 *);
	int (*event_idx)(struct perf_event___65 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___65 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___65 *);
};

struct perf_cpu_context___65 {
	struct perf_event_context___65 ctx;
	struct perf_event_context___65 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___65 *unique_pmu;
	struct perf_cgroup___65 *cgrp;
};

struct trace_event_functions___55;

struct trace_event___55 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___55 *funcs;
};

struct ftrace_event_class___55;

struct ftrace_event_call___55 {
	struct list_head list;
	struct ftrace_event_class___55 *class;
	char *name;
	struct trace_event___55 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___65 {
	struct cgroup_subsys_state___85 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___55 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___122 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___55)(struct trace_iterator___55 *, int, struct trace_event___55 *);

struct trace_event_functions___55 {
	trace_print_func___55 trace;
	trace_print_func___55 raw;
	trace_print_func___55 hex;
	trace_print_func___55 binary;
};

struct ftrace_event_class___55 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___55 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___55 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___55 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___55 *);
};

struct syscall_metadata___25 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___55 *enter_event;
	struct ftrace_event_call___55 *exit_event;
};

struct proc_ns_operations___5 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___121 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___72 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___2 {
	void *ns;
	const struct proc_ns_operations___5 *ns_ops;
};

struct mountpoint___3;

struct mount___3 {
	struct list_head mnt_hash;
	struct mount___3 *mnt_parent;
	struct dentry___121 *mnt_mountpoint;
	struct vfsmount___22 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___3 *mnt_master;
	struct mnt_namespace___3 *mnt_ns;
	struct mountpoint___3 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___3 {
	struct list_head m_hash;
	struct dentry___121 *m_dentry;
	int m_count;
};

struct proc_mounts {
	struct seq_file___92 m;
	struct mnt_namespace___3 *ns;
	struct path___121 root;
	int (*show)(struct seq_file___92 *, struct vfsmount___22 *);
	void *cached_mount;
	u64 cached_event;
	loff_t cached_index;
};

struct page___122;

typedef struct page___122 *pgtable_t___122;

struct address_space___122;

struct kmem_cache___109;

struct page___122 {
	long unsigned int flags;
	struct address_space___122 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___122 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___122 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___109 *slab_cache;
		struct page___122 *first_page;
	};
	long: 64;
};

struct task_struct___122;

struct pv_cpu_ops___122 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___65 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___65 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___122 *);
	void (*end_context_switch)(struct task_struct___122 *);
};

struct mutex___123 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___122 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___118 {
	struct page___122 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___127;

struct signal_struct___122;

struct task_struct___122 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___122 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___127 *mm;
	struct mm_struct___127 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___122 *real_parent;
	struct task_struct___122 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___122 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___70 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___122 = 0,
		VTIME_USER___122 = 1,
		VTIME_SYS___122 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___65 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___122 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___123 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___118 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___127 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___127 *, struct mm_struct___127 *);
	void (*dup_mmap)(struct mm_struct___127 *, struct mm_struct___127 *);
	void (*exit_mmap)(struct mm_struct___127 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___127 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___127 *);
	void (*pgd_free)(struct mm_struct___127 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___127 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___127 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___127 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___127 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___127 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___127 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___127 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___127 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___127 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___127 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___127 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___123 lock;
	void *vdso;
} mm_context_t___123;

struct xol_area___122;

struct uprobes_state___122 {
	struct xol_area___122 *xol_area;
};

struct vm_area_struct___127;

struct file___122;

struct core_state___122;

struct mm_struct___127 {
	struct vm_area_struct___127 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___127 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___127 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___123 context;
	long unsigned int flags;
	struct core_state___122 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___122 *owner;
	struct file___122 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___122 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___65 {
	struct task_struct___122 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___122;

struct lruvec___122 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___122 *zone;
};

struct pglist_data___122;

struct zone___122 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___122 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___122 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___122 {
	struct zone___122 *zone;
	int zone_idx;
};

struct zonelist___122 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___122 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___122 {
	struct zone___122 node_zones[4];
	struct zonelist___122 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___122 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___122 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___122 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___122 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___122 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___109;

struct memcg_cache_params___109;

struct kmem_cache___109 {
	struct kmem_cache_cpu___109 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___109 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___122;

struct address_space_operations___122;

struct address_space___122 {
	struct inode___122 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___123 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___122 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___23;

struct dentry___122;

struct path___122 {
	struct vfsmount___23 *mnt;
	struct dentry___122 *dentry;
};

struct file_operations___122;

struct file___122 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___122 f_path;
	struct inode___122 *f_inode;
	const struct file_operations___122 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___122 *f_mapping;
	struct mutex___123 f_pos_lock;
};

struct vm_operations_struct___109;

struct vm_area_struct___127 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___127 *vm_next;
	struct vm_area_struct___127 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___127 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___109 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___122 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___106;

struct vm_operations_struct___109 {
	void (*open)(struct vm_area_struct___127 *);
	void (*close)(struct vm_area_struct___127 *);
	int (*fault)(struct vm_area_struct___127 *, struct vm_fault___106 *);
	int (*page_mkwrite)(struct vm_area_struct___127 *, struct vm_fault___106 *);
	int (*access)(struct vm_area_struct___127 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___127 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___127 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___127 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___127 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___122 {
	struct task_struct___122 *task;
	struct core_thread___122 *next;
};

struct core_state___122 {
	atomic_t nr_threads;
	struct core_thread___122 dumper;
	struct completion startup;
};

struct vm_fault___106 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___122 *page;
};

struct dentry_operations___122;

struct super_block___122;

struct dentry___122 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___122 *d_parent;
	struct qstr d_name;
	struct inode___122 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___122 *d_op;
	struct super_block___122 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___122;

struct file_lock___122;

struct dquot___122;

struct block_device___122;

struct inode___122 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___122 *i_op;
	struct super_block___122 *i_sb;
	struct address_space___122 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___123 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___122 *i_fop;
	struct file_lock___122 *i_flock;
	struct address_space___122 i_data;
	struct dquot___122 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___122 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___122 {
	int (*d_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_hash)(const struct dentry___122 *, struct qstr *);
	int (*d_compare)(const struct dentry___122 *, const struct dentry___122 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___122 *);
	void (*d_release)(struct dentry___122 *);
	void (*d_prune)(struct dentry___122 *);
	void (*d_iput)(struct dentry___122 *, struct inode___122 *);
	char * (*d_dname)(struct dentry___122 *, char *, int);
	struct vfsmount___23 * (*d_automount)(struct path___122 *);
	int (*d_manage)(struct dentry___122 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___122;

struct mem_dqinfo___122 {
	struct quota_format_type___122 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___122;

struct quota_info___122 {
	unsigned int flags;
	struct mutex___123 dqio_mutex;
	struct mutex___123 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___122 *files[2];
	struct mem_dqinfo___122 info[2];
	const struct quota_format_ops___122 *ops[2];
};

struct file_system_type___122;

struct super_operations___122;

struct dquot_operations___122;

struct quotactl_ops___122;

struct export_operations___5;

struct super_block___122 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___122 *s_type;
	const struct super_operations___122 *s_op;
	const struct dquot_operations___122 *dq_op;
	const struct quotactl_ops___122 *s_qcop;
	const struct export_operations___5 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___122 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___122 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___122 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___123 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___122 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___23 {
	struct dentry___122 *mnt_root;
	struct super_block___122 *mnt_sb;
	int mnt_flags;
};

struct block_device___122 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___122 *bd_inode;
	struct super_block___122 *bd_super;
	struct mutex___123 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___122 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___123 bd_fsfreeze_mutex;
};

struct iattr___122 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___122 *ia_file;
};

struct dquot___122 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___123 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___122 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___122 {
	int qf_fmt_id;
	const struct quota_format_ops___122 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___122 *qf_next;
};

struct quota_format_ops___122 {
	int (*check_quota_file)(struct super_block___122 *, int);
	int (*read_file_info)(struct super_block___122 *, int);
	int (*write_file_info)(struct super_block___122 *, int);
	int (*free_file_info)(struct super_block___122 *, int);
	int (*read_dqblk)(struct dquot___122 *);
	int (*commit_dqblk)(struct dquot___122 *);
	int (*release_dqblk)(struct dquot___122 *);
};

struct dquot_operations___122 {
	int (*write_dquot)(struct dquot___122 *);
	struct dquot___122 * (*alloc_dquot)(struct super_block___122 *, int);
	void (*destroy_dquot)(struct dquot___122 *);
	int (*acquire_dquot)(struct dquot___122 *);
	int (*release_dquot)(struct dquot___122 *);
	int (*mark_dirty)(struct dquot___122 *);
	int (*write_info)(struct super_block___122 *, int);
	qsize_t * (*get_reserved_space)(struct inode___122 *);
};

struct quotactl_ops___122 {
	int (*quota_on)(struct super_block___122 *, int, int, struct path___122 *);
	int (*quota_on_meta)(struct super_block___122 *, int, int);
	int (*quota_off)(struct super_block___122 *, int);
	int (*quota_sync)(struct super_block___122 *, int);
	int (*get_info)(struct super_block___122 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___122 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___122 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___122 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___122 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___122 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___122 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___122 *, unsigned int);
};

struct address_space_operations___122 {
	int (*writepage)(struct page___122 *, struct writeback_control *);
	int (*readpage)(struct file___122 *, struct page___122 *);
	int (*writepages)(struct address_space___122 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___122 *);
	int (*readpages)(struct file___122 *, struct address_space___122 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___122 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___122 **, void **);
	int (*write_end)(struct file___122 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___122 *, void *);
	sector_t (*bmap)(struct address_space___122 *, sector_t);
	void (*invalidatepage)(struct page___122 *, long unsigned int);
	int (*releasepage)(struct page___122 *, gfp_t);
	void (*freepage)(struct page___122 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___122 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___122 *, struct page___122 *, struct page___122 *, enum migrate_mode);
	int (*launder_page)(struct page___122 *);
	int (*is_partially_uptodate)(struct page___122 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___122 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___122 *, struct page___122 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___122 *, sector_t *);
	void (*swap_deactivate)(struct file___122 *);
	void (*invalidatepage_range)(struct page___122 *, unsigned int, unsigned int);
};

struct nameidata___11;

struct inode_operations___122 {
	struct dentry___122 * (*lookup)(struct inode___122 *, struct dentry___122 *, unsigned int);
	void * (*follow_link)(struct dentry___122 *, struct nameidata___11 *);
	int (*permission)(struct inode___122 *, int);
	struct posix_acl * (*get_acl)(struct inode___122 *, int);
	int (*readlink)(struct dentry___122 *, char *, int);
	void (*put_link)(struct dentry___122 *, struct nameidata___11 *, void *);
	int (*create)(struct inode___122 *, struct dentry___122 *, umode_t, bool);
	int (*link)(struct dentry___122 *, struct inode___122 *, struct dentry___122 *);
	int (*unlink)(struct inode___122 *, struct dentry___122 *);
	int (*symlink)(struct inode___122 *, struct dentry___122 *, const char *);
	int (*mkdir)(struct inode___122 *, struct dentry___122 *, umode_t);
	int (*rmdir)(struct inode___122 *, struct dentry___122 *);
	int (*mknod)(struct inode___122 *, struct dentry___122 *, umode_t, dev_t);
	int (*rename)(struct inode___122 *, struct dentry___122 *, struct inode___122 *, struct dentry___122 *);
	int (*setattr)(struct dentry___122 *, struct iattr___122 *);
	int (*getattr)(struct vfsmount___23 *, struct dentry___122 *, struct kstat *);
	int (*setxattr)(struct dentry___122 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___122 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___122 *, char *, size_t);
	int (*removexattr)(struct dentry___122 *, const char *);
	int (*fiemap)(struct inode___122 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___122 *, struct timespec *, int);
	int (*atomic_open)(struct inode___122 *, struct dentry___122 *, struct file___122 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___122 {
	struct module *owner;
	loff_t (*llseek)(struct file___122 *, loff_t, int);
	ssize_t (*read)(struct file___122 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___122 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___122 *, void *, filldir_t);
	unsigned int (*poll)(struct file___122 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___122 *, struct vm_area_struct___127 *);
	int (*open)(struct inode___122 *, struct file___122 *);
	int (*flush)(struct file___122 *, fl_owner_t);
	int (*release)(struct inode___122 *, struct file___122 *);
	int (*fsync)(struct file___122 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___122 *, int);
	int (*lock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*sendpage)(struct file___122 *, struct page___122 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___122 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___122 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___122 *, long int, struct file_lock___122 **, void **);
		struct {
			int (*setlease)(struct file___122 *, long int, struct file_lock___122 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___122 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___122 *);
};

struct fasync_struct___122;

struct file_lock_operations___122;

struct lock_manager_operations___122;

struct file_lock___122 {
	struct file_lock___122 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___70 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___122 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___122 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___122 *fl_ops;
	const struct lock_manager_operations___122 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___122 {
	void (*fl_copy_lock)(struct file_lock___122 *, struct file_lock___122 *);
	void (*fl_release_private)(struct file_lock___122 *);
};

struct lock_manager_operations___122 {
	int (*lm_compare_owner)(struct file_lock___122 *, struct file_lock___122 *);
	long unsigned int (*lm_owner_key)(struct file_lock___122 *);
	void (*lm_notify)(struct file_lock___122 *);
	int (*lm_grant)(struct file_lock___122 *, struct file_lock___122 *, int);
	void (*lm_break)(struct file_lock___122 *);
	int (*lm_change)(struct file_lock___122 **, int);
};

struct fasync_struct___122 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___122 *fa_next;
	struct file___122 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___122 {
	const char *name;
	int fs_flags;
	struct dentry___122 * (*mount)(struct file_system_type___122 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___122 *);
	struct module *owner;
	struct file_system_type___122 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___122 {
	struct inode___122 * (*alloc_inode)(struct super_block___122 *);
	void (*destroy_inode)(struct inode___122 *);
	void (*dirty_inode)(struct inode___122 *, int);
	int (*write_inode)(struct inode___122 *, struct writeback_control *);
	int (*drop_inode)(struct inode___122 *);
	void (*evict_inode)(struct inode___122 *);
	void (*put_super)(struct super_block___122 *);
	int (*sync_fs)(struct super_block___122 *, int);
	int (*freeze_fs)(struct super_block___122 *);
	int (*unfreeze_fs)(struct super_block___122 *);
	int (*statfs)(struct dentry___122 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___122 *, int *, char *);
	void (*umount_begin)(struct super_block___122 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___122 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___122 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___122 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___122 *);
	ssize_t (*quota_read)(struct super_block___122 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___122 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___122 *);
	int (*bdev_try_to_free_page)(struct super_block___122 *, struct page___122 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___122 *);
	void (*free_cached_objects)(struct super_block___122 *, int);
};

struct export_operations___5 {
	int (*encode_fh)(struct inode___122 *, __u32 *, int *, struct inode___122 *);
	struct dentry___122 * (*fh_to_dentry)(struct super_block___122 *, struct fid *, int, int);
	struct dentry___122 * (*fh_to_parent)(struct super_block___122 *, struct fid *, int, int);
	int (*get_name)(struct dentry___122 *, char *, struct dentry___122 *);
	struct dentry___122 * (*get_parent)(struct dentry___122 *);
	int (*commit_metadata)(struct inode___122 *);
	int (*get_uuid)(struct super_block___122 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___122 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___122 *, struct iomap *, int, struct iattr___122 *);
};

struct nameidata___11 {
	struct path___122 path;
	struct qstr last;
	struct path___122 root;
	struct inode___122 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct tree_descr {
	char *name;
	const struct file_operations___122 *ops;
	int mode;
};

struct simple_transaction_argresp {
	ssize_t size;
	char data[0];
};

struct kmem_cache_cpu___109 {
	void **freelist;
	long unsigned int tid;
	struct page___122 *page;
	struct page___122 *partial;
};

struct memcg_cache_params___109 {
	bool is_root_cache;
	union {
		struct kmem_cache___109 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___109 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___122 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___122 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___122 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___70 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___123 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct simple_attr {
	int (*get)(void *, u64 *);
	int (*set)(void *, u64);
	char get_buf[24];
	char set_buf[24];
	void *data;
	const char *fmt;
	struct mutex___123 mutex;
};

struct wb_writeback_work {
	long int nr_pages;
	struct super_block___103 *sb;
	long unsigned int *older_than_this;
	enum writeback_sync_modes sync_mode;
	unsigned int tagged_writepages: 1;
	unsigned int for_kupdate: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_background: 1;
	unsigned int for_sync: 1;
	enum wb_reason reason;
	struct list_head list;
	struct completion *done;
};

struct ftrace_raw_writeback_dirty_page {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int index;
	char __data[0];
};

struct ftrace_raw_writeback_dirty_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int flags;
	char __data[0];
};

struct ftrace_raw_writeback_write_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	int sync_mode;
	char __data[0];
};

struct ftrace_raw_writeback_work_class {
	struct trace_entry ent;
	char name[32];
	long int nr_pages;
	dev_t sb_dev;
	int sync_mode;
	int for_kupdate;
	int range_cyclic;
	int for_background;
	int reason;
	char __data[0];
};

struct ftrace_raw_writeback_pages_written {
	struct trace_entry ent;
	long int pages;
	char __data[0];
};

struct ftrace_raw_writeback_class {
	struct trace_entry ent;
	char name[32];
	char __data[0];
};

struct ftrace_raw_wbc_class {
	struct trace_entry ent;
	char name[32];
	long int nr_to_write;
	long int pages_skipped;
	int sync_mode;
	int for_kupdate;
	int for_background;
	int for_reclaim;
	int range_cyclic;
	long int range_start;
	long int range_end;
	char __data[0];
};

struct ftrace_raw_writeback_queue_io {
	struct trace_entry ent;
	char name[32];
	long unsigned int older;
	long int age;
	int moved;
	int reason;
	char __data[0];
};

struct ftrace_raw_global_dirty_state {
	struct trace_entry ent;
	long unsigned int nr_dirty;
	long unsigned int nr_writeback;
	long unsigned int nr_unstable;
	long unsigned int background_thresh;
	long unsigned int dirty_thresh;
	long unsigned int dirty_limit;
	long unsigned int nr_dirtied;
	long unsigned int nr_written;
	char __data[0];
};

struct ftrace_raw_bdi_dirty_ratelimit {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int write_bw;
	long unsigned int avg_write_bw;
	long unsigned int dirty_rate;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	char __data[0];
};

struct ftrace_raw_balance_dirty_pages {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int limit;
	long unsigned int setpoint;
	long unsigned int dirty;
	long unsigned int bdi_setpoint;
	long unsigned int bdi_dirty;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	unsigned int dirtied;
	unsigned int dirtied_pause;
	long unsigned int paused;
	long int pause;
	long unsigned int period;
	long int think;
	char __data[0];
};

struct ftrace_raw_writeback_sb_inodes_requeue {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	char __data[0];
};

struct ftrace_raw_writeback_congest_waited_template {
	struct trace_entry ent;
	unsigned int usec_timeout;
	unsigned int usec_delayed;
	char __data[0];
};

struct ftrace_raw_writeback_single_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	long unsigned int writeback_index;
	long int nr_to_write;
	long unsigned int wrote;
	char __data[0];
};

struct ftrace_raw_writeback_lazytime_template {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int ino;
	long unsigned int state;
	__u16 mode;
	long unsigned int dirtied_when;
	char __data[0];
};

struct ftrace_data_offsets_writeback_dirty_page {};

struct ftrace_data_offsets_writeback_dirty_inode_template {};

struct ftrace_data_offsets_writeback_write_inode_template {};

struct ftrace_data_offsets_writeback_work_class {};

struct ftrace_data_offsets_writeback_pages_written {};

struct ftrace_data_offsets_writeback_class {};

struct ftrace_data_offsets_wbc_class {};

struct ftrace_data_offsets_writeback_queue_io {};

struct ftrace_data_offsets_global_dirty_state {};

struct ftrace_data_offsets_bdi_dirty_ratelimit {};

struct ftrace_data_offsets_balance_dirty_pages {};

struct ftrace_data_offsets_writeback_sb_inodes_requeue {};

struct ftrace_data_offsets_writeback_congest_waited_template {};

struct ftrace_data_offsets_writeback_single_inode_template {};

struct ftrace_data_offsets_writeback_lazytime_template {};

struct splice_desc {
	unsigned int len;
	unsigned int total_len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___115 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

typedef int splice_actor(struct pipe_inode_info___5 *, struct pipe_buffer___5 *, struct splice_desc *);

typedef int splice_direct_actor(struct pipe_inode_info___5 *, struct splice_desc *);

struct fd___12 {
	struct file___105 *file;
	unsigned int flags;
};

struct utimbuf {
	__kernel_time_t actime;
	__kernel_time_t modtime;
};

typedef int __kernel_daddr_t;

struct ustat {
	__kernel_daddr_t f_tfree;
	__kernel_ino_t f_tinode;
	char f_fname[6];
	char f_fpack[6];
};

enum {
	_DQUOT_USAGE_ENABLED = 0,
	_DQUOT_LIMITS_ENABLED = 1,
	_DQUOT_SUSPENDED = 2,
	_DQUOT_STATE_FLAGS = 3,
};

struct statfs {
	long int f_type;
	long int f_bsize;
	long int f_blocks;
	long int f_bfree;
	long int f_bavail;
	long int f_files;
	long int f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

struct statfs64 {
	long int f_type;
	long int f_bsize;
	__u64 f_blocks;
	__u64 f_bfree;
	__u64 f_bavail;
	__u64 f_files;
	__u64 f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

struct page___123;

typedef struct page___123 *pgtable_t___123;

struct address_space___123;

struct kmem_cache___110;

struct page___123 {
	long unsigned int flags;
	struct address_space___123 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___123 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___123 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___110 *slab_cache;
		struct page___123 *first_page;
	};
	long: 64;
};

struct thread_struct___66;

struct task_struct___123;

struct pv_cpu_ops___123 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___66 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___66 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___123 *);
	void (*end_context_switch)(struct task_struct___123 *);
};

struct perf_event___66;

struct thread_struct___66 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___66 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___71;

struct pid_link___71 {
	struct hlist_node node;
	struct pid___71 *pid;
};

struct mutex___124 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___123 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___119 {
	struct page___123 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___128;

struct nsproxy___73;

struct signal_struct___123;

struct bio_list___17;

struct backing_dev_info___26;

struct io_context___17;

struct css_set___85;

struct perf_event_context___66;

struct task_struct___123 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___123 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___128 *mm;
	struct mm_struct___128 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___123 *real_parent;
	struct task_struct___123 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___123 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___71 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___123 = 0,
		VTIME_USER___123 = 1,
		VTIME_SYS___123 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___66 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___73 *nsproxy;
	struct signal_struct___123 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___17 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___26 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___85 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___66 *perf_event_ctxp[2];
	struct mutex___124 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___119 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___128 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___128 *, struct mm_struct___128 *);
	void (*dup_mmap)(struct mm_struct___128 *, struct mm_struct___128 *);
	void (*exit_mmap)(struct mm_struct___128 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___128 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___128 *);
	void (*pgd_free)(struct mm_struct___128 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___128 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___128 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___128 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___128 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___128 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___128 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___128 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___128 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___128 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___128 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___128 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___124 lock;
	void *vdso;
} mm_context_t___124;

struct xol_area___123;

struct uprobes_state___123 {
	struct xol_area___123 *xol_area;
};

struct vm_area_struct___128;

struct file___123;

struct core_state___123;

struct mm_struct___128 {
	struct vm_area_struct___128 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___128 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___128 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___124 context;
	long unsigned int flags;
	struct core_state___123 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___123 *owner;
	struct file___123 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___123 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___66 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___123 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___123 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___123 *target;
};

typedef void (*perf_overflow_handler_t___66)(struct perf_event___66 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___66;

typedef void (*ftrace_func_t___66)(long unsigned int, long unsigned int, struct ftrace_ops___66 *, struct pt_regs *);

struct ftrace_ops___66 {
	ftrace_func_t___66 func;
	struct ftrace_ops___66 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___124 regex_lock;
};

struct pmu___66;

struct fasync_struct___123;

struct pid_namespace___71;

struct ftrace_event_call___56;

struct perf_cgroup___66;

struct perf_event___66 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___66 *group_leader;
	struct pmu___66 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___66 hw;
	struct perf_event_context___66 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___124 child_mutex;
	struct list_head child_list;
	struct perf_event___66 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___123 *owner;
	struct mutex___124 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___123 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___66 *);
	struct callback_head callback_head;
	struct pid_namespace___71 *ns;
	u64 id;
	perf_overflow_handler_t___66 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___56 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___66 ftrace_ops;
	struct perf_cgroup___66 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___66 {
	struct task_struct___123 *task;
	struct exec_domain___32 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___91;

struct x86_io_apic_ops___91 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___91 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___91;

struct irq_data___91 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___91 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___99;

struct dev_pm_ops___99 {
	int (*prepare)(struct device___99 *);
	void (*complete)(struct device___99 *);
	int (*suspend)(struct device___99 *);
	int (*resume)(struct device___99 *);
	int (*freeze)(struct device___99 *);
	int (*thaw)(struct device___99 *);
	int (*poweroff)(struct device___99 *);
	int (*restore)(struct device___99 *);
	int (*suspend_late)(struct device___99 *);
	int (*resume_early)(struct device___99 *);
	int (*freeze_late)(struct device___99 *);
	int (*thaw_early)(struct device___99 *);
	int (*poweroff_late)(struct device___99 *);
	int (*restore_early)(struct device___99 *);
	int (*suspend_noirq)(struct device___99 *);
	int (*resume_noirq)(struct device___99 *);
	int (*freeze_noirq)(struct device___99 *);
	int (*thaw_noirq)(struct device___99 *);
	int (*poweroff_noirq)(struct device___99 *);
	int (*restore_noirq)(struct device___99 *);
	int (*runtime_suspend)(struct device___99 *);
	int (*runtime_resume)(struct device___99 *);
	int (*runtime_idle)(struct device___99 *);
};

struct device_type___99;

struct bus_type___99;

struct device_driver___99;

struct dev_pm_domain___99;

struct class___99;

struct attribute_group___92;

struct device_rh___99;

struct device___99 {
	struct device___99 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___99 *type;
	struct mutex___124 mutex;
	struct bus_type___99 *bus;
	struct device_driver___99 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___99 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___99 *class;
	const struct attribute_group___92 **groups;
	void (*release)(struct device___99 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___99 *device_rh;
};

struct dev_pm_info_rh___99 {
	void (*set_latency_tolerance)(struct device___99 *, s32);
};

struct dev_pm_domain___99 {
	struct dev_pm_ops___99 ops;
};

struct smp_ops___123 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___123 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___123;

struct lruvec___123 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___123 *zone;
};

struct pglist_data___123;

struct zone___123 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___123 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___123 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___123 {
	struct zone___123 *zone;
	int zone_idx;
};

struct zonelist___123 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___123 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___123 {
	struct zone___123 node_zones[4];
	struct zonelist___123 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___123 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___123;

struct dquot___123 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___124 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___123 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___123;

struct mem_dqinfo___123 {
	struct quota_format_type___123 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___123;

struct quota_format_ops___123;

struct quota_info___123 {
	unsigned int flags;
	struct mutex___124 dqio_mutex;
	struct mutex___124 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___123 *files[2];
	struct mem_dqinfo___123 info[2];
	const struct quota_format_ops___123 *ops[2];
};

struct file_system_type___123;

struct super_operations___123;

struct dquot_operations___123;

struct quotactl_ops___123;

struct dentry___123;

struct xattr_handler___85;

struct block_device___123;

struct dentry_operations___123;

struct super_block___123 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___123 *s_type;
	const struct super_operations___123 *s_op;
	const struct dquot_operations___123 *dq_op;
	const struct quotactl_ops___123 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___123 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___85 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___123 *s_bdev;
	struct backing_dev_info___26 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___123 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___124 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___123 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___123 {
	int qf_fmt_id;
	const struct quota_format_ops___123 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___123 *qf_next;
};

struct quota_format_ops___123 {
	int (*check_quota_file)(struct super_block___123 *, int);
	int (*read_file_info)(struct super_block___123 *, int);
	int (*write_file_info)(struct super_block___123 *, int);
	int (*free_file_info)(struct super_block___123 *, int);
	int (*read_dqblk)(struct dquot___123 *);
	int (*commit_dqblk)(struct dquot___123 *);
	int (*release_dqblk)(struct dquot___123 *);
};

struct dquot_operations___123 {
	int (*write_dquot)(struct dquot___123 *);
	struct dquot___123 * (*alloc_dquot)(struct super_block___123 *, int);
	void (*destroy_dquot)(struct dquot___123 *);
	int (*acquire_dquot)(struct dquot___123 *);
	int (*release_dquot)(struct dquot___123 *);
	int (*mark_dirty)(struct dquot___123 *);
	int (*write_info)(struct super_block___123 *, int);
	qsize_t * (*get_reserved_space)(struct inode___123 *);
};

struct address_space_operations___123;

struct address_space___123 {
	struct inode___123 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___124 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___123 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___26 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___123;

struct file_operations___123;

struct file_lock___123;

struct inode___123 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___123 *i_op;
	struct super_block___123 *i_sb;
	struct address_space___123 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___124 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___123 *i_fop;
	struct file_lock___123 *i_flock;
	struct address_space___123 i_data;
	struct dquot___123 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___123 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___123;

struct quotactl_ops___123 {
	int (*quota_on)(struct super_block___123 *, int, int, struct path___123 *);
	int (*quota_on_meta)(struct super_block___123 *, int, int);
	int (*quota_off)(struct super_block___123 *, int);
	int (*quota_sync)(struct super_block___123 *, int);
	int (*get_info)(struct super_block___123 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___123 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___123 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___123 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___123 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___123 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___123 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___123 *, unsigned int);
};

struct path___123 {
	struct vfsmount *mnt;
	struct dentry___123 *dentry;
};

struct nsproxy___73 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___71 *pid_ns;
	struct net *net_ns;
};

struct xol_area___123 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___123 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___110;

struct memcg_cache_params___110;

struct kmem_cache___110 {
	struct kmem_cache_cpu___110 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___110 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___71 {
	rwlock_t lock;
	struct pid___71 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___123 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___123 f_path;
	struct inode___123 *f_inode;
	const struct file_operations___123 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___71 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___123 *f_mapping;
	struct mutex___124 f_pos_lock;
};

struct vm_operations_struct___110;

struct vm_area_struct___128 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___128 *vm_next;
	struct vm_area_struct___128 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___128 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___110 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___123 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___107;

struct vm_operations_struct___110 {
	void (*open)(struct vm_area_struct___128 *);
	void (*close)(struct vm_area_struct___128 *);
	int (*fault)(struct vm_area_struct___128 *, struct vm_fault___107 *);
	int (*page_mkwrite)(struct vm_area_struct___128 *, struct vm_fault___107 *);
	int (*access)(struct vm_area_struct___128 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___128 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___128 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___128 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___128 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___123 {
	struct task_struct___123 *task;
	struct core_thread___123 *next;
};

struct core_state___123 {
	atomic_t nr_threads;
	struct core_thread___123 dumper;
	struct completion startup;
};

struct vm_fault___107 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___123 *page;
};

struct seq_operations___92;

struct seq_file___93 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___124 lock;
	const struct seq_operations___92 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___92 {
	void * (*start)(struct seq_file___93 *, loff_t *);
	void (*stop)(struct seq_file___93 *, void *);
	void * (*next)(struct seq_file___93 *, void *, loff_t *);
	int (*show)(struct seq_file___93 *, void *);
};

struct dentry___123 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___123 *d_parent;
	struct qstr d_name;
	struct inode___123 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___123 *d_op;
	struct super_block___123 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___123 {
	int (*d_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_hash)(const struct dentry___123 *, struct qstr *);
	int (*d_compare)(const struct dentry___123 *, const struct dentry___123 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___123 *);
	void (*d_release)(struct dentry___123 *);
	void (*d_prune)(struct dentry___123 *);
	void (*d_iput)(struct dentry___123 *, struct inode___123 *);
	char * (*d_dname)(struct dentry___123 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___123 *);
	int (*d_manage)(struct dentry___123 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___71 {
	int nr;
	struct pid_namespace___71 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___71 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___123 *child_reaper;
	struct kmem_cache___110 *pid_cachep;
	unsigned int level;
	struct pid_namespace___71 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___123 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___71 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___71 numbers[1];
};

struct bio___18;

typedef void bio_end_io_t___18(struct bio___18 *, int);

struct bio_vec___18 {
	struct page___123 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___86;

struct bio_integrity_payload___18;

struct bio_set___18;

struct bio___18 {
	sector_t bi_sector;
	struct bio___18 *bi_next;
	struct block_device___123 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___18 *bi_end_io;
	void *bi_private;
	struct io_context___17 *bi_ioc;
	struct cgroup_subsys_state___86 *bi_css;
	struct bio_integrity_payload___18 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___18 *bi_io_vec;
	struct bio_set___18 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___18 bi_inline_vecs[0];
};

struct hd_struct___18;

struct gendisk___18;

struct request_queue___17;

struct block_device___123 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___123 *bd_inode;
	struct super_block___123 *bd_super;
	struct mutex___124 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___123 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___18 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___18 *bd_disk;
	struct request_queue___17 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___124 bd_fsfreeze_mutex;
};

struct io_cq___17;

struct io_context___17 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___17 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___85;

struct cgroup_subsys_state___86 {
	struct cgroup___85 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___18 {
	struct bio___18 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___18 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___18 *bip_vec;
	struct bio_vec___18 bip_inline_vecs[0];
};

struct bio_list___17 {
	struct bio___18 *head;
	struct bio___18 *tail;
};

struct bio_set___18 {
	struct kmem_cache___110 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___17 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct buffer_head___2;

typedef int get_block_t___2(struct inode___123 *, sector_t, struct buffer_head___2 *, int);

typedef void bh_end_io_t___2(struct buffer_head___2 *, int);

struct buffer_head___2 {
	long unsigned int b_state;
	struct buffer_head___2 *b_this_page;
	struct page___123 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___123 *b_bdev;
	bh_end_io_t___2 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___123 *b_assoc_map;
	atomic_t b_count;
};

struct iattr___123 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___123 *ia_file;
};

struct swap_info_struct___30;

struct address_space_operations___123 {
	int (*writepage)(struct page___123 *, struct writeback_control *);
	int (*readpage)(struct file___123 *, struct page___123 *);
	int (*writepages)(struct address_space___123 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___123 *);
	int (*readpages)(struct file___123 *, struct address_space___123 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___123 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___123 **, void **);
	int (*write_end)(struct file___123 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___123 *, void *);
	sector_t (*bmap)(struct address_space___123 *, sector_t);
	void (*invalidatepage)(struct page___123 *, long unsigned int);
	int (*releasepage)(struct page___123 *, gfp_t);
	void (*freepage)(struct page___123 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___123 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___123 *, struct page___123 *, struct page___123 *, enum migrate_mode);
	int (*launder_page)(struct page___123 *);
	int (*is_partially_uptodate)(struct page___123 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___123 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___123 *, struct page___123 *);
	int (*swap_activate)(struct swap_info_struct___30 *, struct file___123 *, sector_t *);
	void (*swap_deactivate)(struct file___123 *);
	void (*invalidatepage_range)(struct page___123 *, unsigned int, unsigned int);
};

struct swap_info_struct___30 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___123 *bdev;
	struct file___123 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___26 {
	struct backing_dev_info___26 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___26 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___26 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___99 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___123 *debug_dir;
	struct dentry___123 *debug_stats;
};

struct hd_struct___18 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___99 __dev;
	struct kobject___6 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___18;

struct block_device_operations___17;

struct gendisk___18 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___18 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___18 *part_tbl;
	struct hd_struct___18 part0;
	const struct block_device_operations___17 *fops;
	struct request_queue___17 *queue;
	void *private_data;
	int flags;
	struct device___99 *driverfs_dev;
	struct kobject___6 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct request_list___17 {
	struct request_queue___17 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___17(struct request_queue___17 *);

typedef void make_request_fn___17(struct request_queue___17 *, struct bio___18 *);

struct request___17;

typedef int prep_rq_fn___17(struct request_queue___17 *, struct request___17 *);

struct bvec_merge_data___17;

typedef int merge_bvec_fn___17(struct request_queue___17 *, struct bvec_merge_data___17 *, struct bio_vec___18 *);

typedef void softirq_done_fn___17(struct request___17 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___17(struct request___17 *);

typedef int dma_drain_needed_fn___17(struct request___17 *);

typedef int lld_busy_fn___17(struct request_queue___17 *);

struct bsg_class_device___17 {
	struct device___99 *class_dev;
	struct device___99 *parent;
	int minor;
	struct request_queue___17 *queue;
	struct kref ref;
	void (*release)(struct device___99 *);
};

typedef void unprep_rq_fn___17(struct request_queue___17 *, struct request___17 *);

struct elevator_queue___17;

struct blk_queue_tag___17;

struct blk_trace___3;

struct request_queue___17 {
	struct list_head queue_head;
	struct request___17 *last_merge;
	struct elevator_queue___17 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___17 root_rl;
	request_fn_proc___17 *request_fn;
	make_request_fn___17 *make_request_fn;
	prep_rq_fn___17 *prep_rq_fn;
	merge_bvec_fn___17 *merge_bvec_fn;
	softirq_done_fn___17 *softirq_done_fn;
	rq_timed_out_fn___17 *rq_timed_out_fn;
	dma_drain_needed_fn___17 *dma_drain_needed;
	lld_busy_fn___17 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___17 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___26 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___6 kobj;
	struct kobject___6 mq_kobj;
	struct device___99 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___17 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___3 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___17 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___124 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___17 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___17 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___18 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___123 {
	struct dentry___123 * (*lookup)(struct inode___123 *, struct dentry___123 *, unsigned int);
	void * (*follow_link)(struct dentry___123 *, struct nameidata *);
	int (*permission)(struct inode___123 *, int);
	struct posix_acl * (*get_acl)(struct inode___123 *, int);
	int (*readlink)(struct dentry___123 *, char *, int);
	void (*put_link)(struct dentry___123 *, struct nameidata *, void *);
	int (*create)(struct inode___123 *, struct dentry___123 *, umode_t, bool);
	int (*link)(struct dentry___123 *, struct inode___123 *, struct dentry___123 *);
	int (*unlink)(struct inode___123 *, struct dentry___123 *);
	int (*symlink)(struct inode___123 *, struct dentry___123 *, const char *);
	int (*mkdir)(struct inode___123 *, struct dentry___123 *, umode_t);
	int (*rmdir)(struct inode___123 *, struct dentry___123 *);
	int (*mknod)(struct inode___123 *, struct dentry___123 *, umode_t, dev_t);
	int (*rename)(struct inode___123 *, struct dentry___123 *, struct inode___123 *, struct dentry___123 *);
	int (*setattr)(struct dentry___123 *, struct iattr___123 *);
	int (*getattr)(struct vfsmount *, struct dentry___123 *, struct kstat *);
	int (*setxattr)(struct dentry___123 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___123 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___123 *, char *, size_t);
	int (*removexattr)(struct dentry___123 *, const char *);
	int (*fiemap)(struct inode___123 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___123 *, struct timespec *, int);
	int (*atomic_open)(struct inode___123 *, struct dentry___123 *, struct file___123 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___79;

struct file_operations___123 {
	struct module *owner;
	loff_t (*llseek)(struct file___123 *, loff_t, int);
	ssize_t (*read)(struct file___123 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___123 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___123 *, void *, filldir_t);
	unsigned int (*poll)(struct file___123 *, struct poll_table_struct___79 *);
	long int (*unlocked_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___123 *, struct vm_area_struct___128 *);
	int (*open)(struct inode___123 *, struct file___123 *);
	int (*flush)(struct file___123 *, fl_owner_t);
	int (*release)(struct inode___123 *, struct file___123 *);
	int (*fsync)(struct file___123 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___123 *, int);
	int (*lock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*sendpage)(struct file___123 *, struct page___123 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___123 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___123 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___123 *, long int, struct file_lock___123 **, void **);
		struct {
			int (*setlease)(struct file___123 *, long int, struct file_lock___123 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___123 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___93 *, struct file___123 *);
};

struct file_lock_operations___123;

struct lock_manager_operations___123;

struct file_lock___123 {
	struct file_lock___123 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___71 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___123 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___123 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___123 *fl_ops;
	const struct lock_manager_operations___123 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___123 {
	void (*fl_copy_lock)(struct file_lock___123 *, struct file_lock___123 *);
	void (*fl_release_private)(struct file_lock___123 *);
};

struct lock_manager_operations___123 {
	int (*lm_compare_owner)(struct file_lock___123 *, struct file_lock___123 *);
	long unsigned int (*lm_owner_key)(struct file_lock___123 *);
	void (*lm_notify)(struct file_lock___123 *);
	int (*lm_grant)(struct file_lock___123 *, struct file_lock___123 *, int);
	void (*lm_break)(struct file_lock___123 *);
	int (*lm_change)(struct file_lock___123 **, int);
};

struct fasync_struct___123 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___123 *fa_next;
	struct file___123 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___123 {
	const char *name;
	int fs_flags;
	struct dentry___123 * (*mount)(struct file_system_type___123 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___123 *);
	struct module *owner;
	struct file_system_type___123 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___123 {
	struct inode___123 * (*alloc_inode)(struct super_block___123 *);
	void (*destroy_inode)(struct inode___123 *);
	void (*dirty_inode)(struct inode___123 *, int);
	int (*write_inode)(struct inode___123 *, struct writeback_control *);
	int (*drop_inode)(struct inode___123 *);
	void (*evict_inode)(struct inode___123 *);
	void (*put_super)(struct super_block___123 *);
	int (*sync_fs)(struct super_block___123 *, int);
	int (*freeze_fs)(struct super_block___123 *);
	int (*unfreeze_fs)(struct super_block___123 *);
	int (*statfs)(struct dentry___123 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___123 *, int *, char *);
	void (*umount_begin)(struct super_block___123 *);
	int (*show_options)(struct seq_file___93 *, struct dentry___123 *);
	int (*show_devname)(struct seq_file___93 *, struct dentry___123 *);
	int (*show_path)(struct seq_file___93 *, struct dentry___123 *);
	int (*show_stats)(struct seq_file___93 *, struct dentry___123 *);
	ssize_t (*quota_read)(struct super_block___123 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___123 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___123 *);
	int (*bdev_try_to_free_page)(struct super_block___123 *, struct page___123 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___123 *);
	void (*free_cached_objects)(struct super_block___123 *, int);
};

struct xattr_handler___85 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___123 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___123 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___123 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___81)(struct file___123 *, wait_queue_head_t *, struct poll_table_struct___79 *);

struct poll_table_struct___79 {
	poll_queue_proc___81 _qproc;
	long unsigned int _key;
};

struct irq_chip___91 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___91 *);
	void (*irq_shutdown)(struct irq_data___91 *);
	void (*irq_enable)(struct irq_data___91 *);
	void (*irq_disable)(struct irq_data___91 *);
	void (*irq_ack)(struct irq_data___91 *);
	void (*irq_mask)(struct irq_data___91 *);
	void (*irq_mask_ack)(struct irq_data___91 *);
	void (*irq_unmask)(struct irq_data___91 *);
	void (*irq_eoi)(struct irq_data___91 *);
	int (*irq_set_affinity)(struct irq_data___91 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___91 *);
	int (*irq_set_type)(struct irq_data___91 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___91 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___91 *);
	void (*irq_bus_sync_unlock)(struct irq_data___91 *);
	void (*irq_cpu_online)(struct irq_data___91 *);
	void (*irq_cpu_offline)(struct irq_data___91 *);
	void (*irq_suspend)(struct irq_data___91 *);
	void (*irq_resume)(struct irq_data___91 *);
	void (*irq_pm_shutdown)(struct irq_data___91 *);
	void (*irq_print_chip)(struct irq_data___91 *, struct seq_file___93 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___91 *, void *);
	long unsigned int flags;
};

struct signal_struct___123 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___123 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___123 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___71 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___71 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___124 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___85 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___86 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___66 {
	struct pmu___66 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___124 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___123 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___66 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___92;

struct attribute_group___92 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___92 **bin_attrs;
};

struct bin_attribute___92 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___123 *, struct kobject___6 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___123 *, struct kobject___6 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	int (*mmap)(struct file___123 *, struct kobject___6 *, struct bin_attribute___92 *, struct vm_area_struct___128 *);
};

struct bus_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___99 *, char *);
	ssize_t (*store)(struct bus_type___99 *, const char *, size_t);
};

struct device_attribute___99;

struct driver_attribute___99;

struct bus_type___99 {
	const char *name;
	const char *dev_name;
	struct device___99 *dev_root;
	struct bus_attribute___99 *bus_attrs;
	struct device_attribute___99 *dev_attrs;
	struct driver_attribute___99 *drv_attrs;
	const struct attribute_group___92 **bus_groups;
	const struct attribute_group___92 **dev_groups;
	const struct attribute_group___92 **drv_groups;
	int (*match)(struct device___99 *, struct device_driver___99 *);
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	int (*probe)(struct device___99 *);
	int (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*online)(struct device___99 *);
	int (*offline)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct device___99 *, struct device_attribute___99 *, char *);
	ssize_t (*store)(struct device___99 *, struct device_attribute___99 *, const char *, size_t);
};

struct driver_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___99 *, char *);
	ssize_t (*store)(struct device_driver___99 *, const char *, size_t);
};

struct device_driver___99 {
	const char *name;
	struct bus_type___99 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___99 *);
	int (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	const struct attribute_group___92 **groups;
	const struct dev_pm_ops___99 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___99 {
	const char *name;
	const struct attribute_group___92 **groups;
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
};

struct class_attribute___99;

struct class___99 {
	const char *name;
	struct module *owner;
	struct class_attribute___99 *class_attrs;
	struct device_attribute___99 *dev_attrs;
	const struct attribute_group___92 **dev_groups;
	struct bin_attribute___92 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *);
	void (*class_release)(struct class___99 *);
	void (*dev_release)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
	struct subsys_private *p;
};

struct class_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct class___99 *, struct class_attribute___99 *, char *);
	ssize_t (*store)(struct class___99 *, struct class_attribute___99 *, const char *, size_t);
	const void * (*namespace)(struct class___99 *, const struct class_attribute___99 *);
};

struct device_rh___99 {
	struct dev_pm_info_rh___99 power;
};

struct kmem_cache_cpu___110 {
	void **freelist;
	long unsigned int tid;
	struct page___123 *page;
	struct page___123 *partial;
};

struct memcg_cache_params___110 {
	bool is_root_cache;
	union {
		struct kmem_cache___110 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___110 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___85;

struct cgroup___85 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___85 *parent;
	struct dentry___123 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___86 *subsys[11];
	struct cgroupfs_root___85 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___124 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___85 {
	struct super_block___123 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___85 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___40 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___123 *, struct file___123 *);
	ssize_t (*read)(struct cgroup___85 *, struct cftype___40 *, struct file___123 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___85 *, struct cftype___40 *);
	s64 (*read_s64)(struct cgroup___85 *, struct cftype___40 *);
	int (*read_map)(struct cgroup___85 *, struct cftype___40 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___85 *, struct cftype___40 *, struct seq_file___93 *);
	ssize_t (*write)(struct cgroup___85 *, struct cftype___40 *, struct file___123 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___85 *, struct cftype___40 *, u64);
	int (*write_s64)(struct cgroup___85 *, struct cftype___40 *, s64);
	int (*write_string)(struct cgroup___85 *, struct cftype___40 *, const char *);
	int (*trigger)(struct cgroup___85 *, unsigned int);
	int (*release)(struct inode___123 *, struct file___123 *);
	int (*register_event)(struct cgroup___85 *, struct cftype___40 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___85 *, struct cftype___40 *, struct eventfd_ctx *);
};

struct cftype_set___38 {
	struct list_head node;
	struct cftype___40 *cfts;
};

struct task_and_cgroup___38 {
	struct task_struct___123 *task;
	struct cgroup___85 *cgrp;
	struct css_set___85 *cg;
};

struct cgroup_taskset___38 {
	struct task_and_cgroup___38 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___85 *cur_cgrp;
};

struct cgroup_subsys___38 {
	struct cgroup_subsys_state___86 * (*css_alloc)(struct cgroup___85 *);
	int (*css_online)(struct cgroup___85 *);
	void (*css_offline)(struct cgroup___85 *);
	void (*css_free)(struct cgroup___85 *);
	int (*can_attach)(struct cgroup___85 *, struct cgroup_taskset___38 *);
	void (*cancel_attach)(struct cgroup___85 *, struct cgroup_taskset___38 *);
	void (*attach)(struct cgroup___85 *, struct cgroup_taskset___38 *);
	void (*fork)(struct task_struct___123 *);
	void (*exit)(struct cgroup___85 *, struct cgroup___85 *, struct task_struct___123 *);
	void (*bind)(struct cgroup___85 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___85 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___40 *base_cftypes;
	struct cftype_set___38 base_cftset;
	struct module *module;
};

struct perf_cpu_context___66;

struct pmu___66 {
	struct list_head entry;
	struct device___99 *dev;
	const struct attribute_group___92 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___66 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___66 *);
	void (*pmu_disable)(struct pmu___66 *);
	int (*event_init)(struct perf_event___66 *);
	int (*add)(struct perf_event___66 *, int);
	void (*del)(struct perf_event___66 *, int);
	void (*start)(struct perf_event___66 *, int);
	void (*stop)(struct perf_event___66 *, int);
	void (*read)(struct perf_event___66 *);
	void (*start_txn)(struct pmu___66 *);
	int (*commit_txn)(struct pmu___66 *);
	void (*cancel_txn)(struct pmu___66 *);
	int (*event_idx)(struct perf_event___66 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___66 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___66 *);
};

struct perf_cpu_context___66 {
	struct perf_event_context___66 ctx;
	struct perf_event_context___66 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___66 *unique_pmu;
	struct perf_cgroup___66 *cgrp;
};

struct trace_event_functions___56;

struct trace_event___56 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___56 *funcs;
};

struct ftrace_event_class___56;

struct ftrace_event_call___56 {
	struct list_head list;
	struct ftrace_event_class___56 *class;
	char *name;
	struct trace_event___56 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___66 {
	struct cgroup_subsys_state___86 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___56 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___124 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___56)(struct trace_iterator___56 *, int, struct trace_event___56 *);

struct trace_event_functions___56 {
	trace_print_func___56 trace;
	trace_print_func___56 raw;
	trace_print_func___56 hex;
	trace_print_func___56 binary;
};

struct ftrace_event_class___56 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___56 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___56 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___56 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___56 *);
};

struct syscall_metadata___26 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___56 *enter_event;
	struct ftrace_event_call___56 *exit_event;
};

struct disk_part_tbl___18 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___18 *last_lookup;
	struct hd_struct___18 *part[0];
};

struct block_device_operations___17 {
	int (*open)(struct block_device___123 *, fmode_t);
	void (*release)(struct gendisk___18 *, fmode_t);
	int (*ioctl)(struct block_device___123 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___123 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___123 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___18 *, unsigned int);
	int (*media_changed)(struct gendisk___18 *);
	void (*unlock_native_capacity)(struct gendisk___18 *);
	int (*revalidate_disk)(struct gendisk___18 *);
	int (*getgeo)(struct block_device___123 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___123 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___17 {
	struct request_queue___17 *q;
	struct io_context___17 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___110 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___17(struct request___17 *, int);

struct request___17 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide11;
			union {			};
		};
	};
	struct request_queue___17 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___18 *bio;
	struct bio___18 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___17 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___17 *saved_end_io;
		} flush;
	};
	struct gendisk___18 *rq_disk;
	struct hd_struct___18 *part;
	long unsigned int start_time;
	struct request_list___17 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___17 *end_io;
	void *end_io_data;
	struct request___17 *next_rq;
};

typedef int elevator_merge_fn___17(struct request_queue___17 *, struct request___17 **, struct bio___18 *);

typedef void elevator_merge_req_fn___17(struct request_queue___17 *, struct request___17 *, struct request___17 *);

typedef void elevator_merged_fn___17(struct request_queue___17 *, struct request___17 *, int);

typedef int elevator_allow_merge_fn___17(struct request_queue___17 *, struct request___17 *, struct bio___18 *);

typedef void elevator_bio_merged_fn___17(struct request_queue___17 *, struct request___17 *, struct bio___18 *);

typedef int elevator_dispatch_fn___17(struct request_queue___17 *, int);

typedef void elevator_add_req_fn___17(struct request_queue___17 *, struct request___17 *);

typedef struct request___17 *elevator_request_list_fn___17(struct request_queue___17 *, struct request___17 *);

typedef void elevator_completed_req_fn___17(struct request_queue___17 *, struct request___17 *);

typedef int elevator_may_queue_fn___17(struct request_queue___17 *, int);

typedef void elevator_init_icq_fn___17(struct io_cq___17 *);

typedef void elevator_exit_icq_fn___17(struct io_cq___17 *);

typedef int elevator_set_req_fn___17(struct request_queue___17 *, struct request___17 *, struct bio___18 *, gfp_t);

typedef void elevator_put_req_fn___17(struct request___17 *);

typedef void elevator_activate_req_fn___17(struct request_queue___17 *, struct request___17 *);

typedef void elevator_deactivate_req_fn___17(struct request_queue___17 *, struct request___17 *);

struct elevator_type___17;

typedef int elevator_init_fn___17(struct request_queue___17 *, struct elevator_type___17 *);

typedef void elevator_exit_fn___17(struct elevator_queue___17 *);

struct elevator_ops___17 {
	elevator_merge_fn___17 *elevator_merge_fn;
	elevator_merged_fn___17 *elevator_merged_fn;
	elevator_merge_req_fn___17 *elevator_merge_req_fn;
	elevator_allow_merge_fn___17 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___17 *elevator_bio_merged_fn;
	elevator_dispatch_fn___17 *elevator_dispatch_fn;
	elevator_add_req_fn___17 *elevator_add_req_fn;
	elevator_activate_req_fn___17 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___17 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___17 *elevator_completed_req_fn;
	elevator_request_list_fn___17 *elevator_former_req_fn;
	elevator_request_list_fn___17 *elevator_latter_req_fn;
	elevator_init_icq_fn___17 *elevator_init_icq_fn;
	elevator_exit_icq_fn___17 *elevator_exit_icq_fn;
	elevator_set_req_fn___17 *elevator_set_req_fn;
	elevator_put_req_fn___17 *elevator_put_req_fn;
	elevator_may_queue_fn___17 *elevator_may_queue_fn;
	elevator_init_fn___17 *elevator_init_fn;
	elevator_exit_fn___17 *elevator_exit_fn;
};

struct elv_fs_entry___17;

struct elevator_type___17 {
	struct kmem_cache___110 *icq_cache;
	struct elevator_ops___17 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___17 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___17 {
	struct elevator_type___17 *type;
	void *elevator_data;
	struct kobject___6 kobj;
	struct mutex___124 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___17 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___17 *, char *);
	ssize_t (*store)(struct elevator_queue___17 *, const char *, size_t);
};

struct bvec_merge_data___17 {
	struct block_device___123 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___17 {
	struct request___17 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct rchan___4;

struct blk_trace___3 {
	int trace_state;
	struct rchan___4 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___123 *dir;
	struct dentry___123 *dropped_file;
	struct dentry___123 *msg_file;
	atomic_t dropped;
};

struct rchan_buf___4 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___4 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___123 *dentry;
	struct kref kref;
	struct page___123 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___4;

struct rchan___4 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___4 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___4 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___123 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___4 {
	int (*subbuf_start)(struct rchan_buf___4 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___4 *, struct file___123 *);
	void (*buf_unmapped)(struct rchan_buf___4 *, struct file___123 *);
	struct dentry___123 * (*create_buf_file)(const char *, struct dentry___123 *, umode_t, struct rchan_buf___4 *, int *);
	int (*remove_buf_file)(struct dentry___123 *);
};

struct bh_lru {
	struct buffer_head___2 *bhs[16];
};

struct bh_accounting {
	int nr;
	int ratelimit;
};

struct bio_pair {
	struct bio___12 bio1;
	struct bio___12 bio2;
	struct bio_vec___12 bv1;
	struct bio_vec___12 bv2;
	struct bio_integrity_payload___12 bip1;
	struct bio_integrity_payload___12 bip2;
	struct bio_vec___12 iv1;
	struct bio_vec___12 iv2;
	atomic_t cnt;
	int error;
};

struct biovec_slab {
	int nr_vecs;
	char *name;
	struct kmem_cache___91 *slab;
};

struct rq_map_data {
	struct page___103 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct sg_iovec {
	void *iov_base;
	size_t iov_len;
};

struct bio_slab {
	struct kmem_cache___91 *slab;
	unsigned int slab_ref;
	unsigned int slab_size;
	char name[8];
};

struct submit_bio_ret {
	struct completion event;
	int error;
};

struct bio_map_data {
	struct bio_vec___12 *iovecs;
	struct sg_iovec *sgvecs;
	int nr_sgvecs;
	int is_our_pages;
};

struct page___124;

typedef struct page___124 *pgtable_t___124;

struct address_space___124;

struct kmem_cache___111;

struct page___124 {
	long unsigned int flags;
	struct address_space___124 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___124 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___124 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___111 *slab_cache;
		struct page___124 *first_page;
	};
	long: 64;
};

struct task_struct___124;

struct pv_cpu_ops___124 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___66 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___66 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___124 *);
	void (*end_context_switch)(struct task_struct___124 *);
};

struct mutex___125 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___124 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___120 {
	struct page___124 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___129;

struct signal_struct___124;

struct bio_list___18;

struct backing_dev_info___27;

struct io_context___18;

struct css_set___86;

struct task_struct___124 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___124 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___129 *mm;
	struct mm_struct___129 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___124 *real_parent;
	struct task_struct___124 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___124 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___71 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___124 = 0,
		VTIME_USER___124 = 1,
		VTIME_SYS___124 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___66 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___124 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___18 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___27 *backing_dev_info;
	struct io_context___18 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___86 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___125 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___120 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___129 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___129 *, struct mm_struct___129 *);
	void (*dup_mmap)(struct mm_struct___129 *, struct mm_struct___129 *);
	void (*exit_mmap)(struct mm_struct___129 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___129 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___129 *);
	void (*pgd_free)(struct mm_struct___129 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___129 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___129 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___129 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___129 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___129 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___129 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___129 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___129 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___129 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___129 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___129 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___125 lock;
	void *vdso;
} mm_context_t___125;

struct xol_area___124;

struct uprobes_state___124 {
	struct xol_area___124 *xol_area;
};

struct vm_area_struct___129;

struct file___124;

struct core_state___124;

struct mm_struct___129 {
	struct vm_area_struct___129 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___129 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___129 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___125 context;
	long unsigned int flags;
	struct core_state___124 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___124 *owner;
	struct file___124 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___124 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___64;

struct exec_domain___33 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___64 *module;
	struct exec_domain___33 *next;
};

struct module_kobject___63 {
	struct kobject___6 kobj;
	struct module___64 *mod;
	struct kobject___6 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___63;

struct module___64 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___63 mkobj;
	struct module_attribute___63 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___6 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___124 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___67 {
	struct task_struct___124 *task;
	struct exec_domain___33 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___124;

struct lruvec___124 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___124 *zone;
};

struct pglist_data___124;

struct zone___124 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___124 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___124 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___124 {
	struct zone___124 *zone;
	int zone_idx;
};

struct zonelist___124 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___124 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___124 {
	struct zone___124 node_zones[4];
	struct zonelist___124 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___124 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___100;

struct dev_pm_ops___100 {
	int (*prepare)(struct device___100 *);
	void (*complete)(struct device___100 *);
	int (*suspend)(struct device___100 *);
	int (*resume)(struct device___100 *);
	int (*freeze)(struct device___100 *);
	int (*thaw)(struct device___100 *);
	int (*poweroff)(struct device___100 *);
	int (*restore)(struct device___100 *);
	int (*suspend_late)(struct device___100 *);
	int (*resume_early)(struct device___100 *);
	int (*freeze_late)(struct device___100 *);
	int (*thaw_early)(struct device___100 *);
	int (*poweroff_late)(struct device___100 *);
	int (*restore_early)(struct device___100 *);
	int (*suspend_noirq)(struct device___100 *);
	int (*resume_noirq)(struct device___100 *);
	int (*freeze_noirq)(struct device___100 *);
	int (*thaw_noirq)(struct device___100 *);
	int (*poweroff_noirq)(struct device___100 *);
	int (*restore_noirq)(struct device___100 *);
	int (*runtime_suspend)(struct device___100 *);
	int (*runtime_resume)(struct device___100 *);
	int (*runtime_idle)(struct device___100 *);
};

struct device_type___100;

struct bus_type___100;

struct device_driver___100;

struct dev_pm_domain___100;

struct class___100;

struct attribute_group___93;

struct device_rh___100;

struct device___100 {
	struct device___100 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___100 *type;
	struct mutex___125 mutex;
	struct bus_type___100 *bus;
	struct device_driver___100 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___100 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___100 *class;
	const struct attribute_group___93 **groups;
	void (*release)(struct device___100 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___100 *device_rh;
};

struct dev_pm_info_rh___100 {
	void (*set_latency_tolerance)(struct device___100 *, s32);
};

struct dev_pm_domain___100 {
	struct dev_pm_ops___100 ops;
};

struct smp_ops___124 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___124 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___124 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___124 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___111;

struct memcg_cache_params___111;

struct kmem_cache___111 {
	struct kmem_cache_cpu___111 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___111 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___124;

struct address_space_operations___124;

struct address_space___124 {
	struct inode___124 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___125 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___124 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___27 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___24;

struct dentry___124;

struct path___124 {
	struct vfsmount___24 *mnt;
	struct dentry___124 *dentry;
};

struct file_operations___124;

struct file___124 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___124 f_path;
	struct inode___124 *f_inode;
	const struct file_operations___124 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___71 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___124 *f_mapping;
	struct mutex___125 f_pos_lock;
};

struct vm_operations_struct___111;

struct vm_area_struct___129 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___129 *vm_next;
	struct vm_area_struct___129 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___129 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___111 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___124 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___108;

struct vm_operations_struct___111 {
	void (*open)(struct vm_area_struct___129 *);
	void (*close)(struct vm_area_struct___129 *);
	int (*fault)(struct vm_area_struct___129 *, struct vm_fault___108 *);
	int (*page_mkwrite)(struct vm_area_struct___129 *, struct vm_fault___108 *);
	int (*access)(struct vm_area_struct___129 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___129 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___129 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___129 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___129 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___124 {
	struct task_struct___124 *task;
	struct core_thread___124 *next;
};

struct core_state___124 {
	atomic_t nr_threads;
	struct core_thread___124 dumper;
	struct completion startup;
};

struct vm_fault___108 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___124 *page;
};

struct bin_attribute___93;

struct attribute_group___93 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___93 **bin_attrs;
};

struct bin_attribute___93 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___124 *, struct kobject___6 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___124 *, struct kobject___6 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	int (*mmap)(struct file___124 *, struct kobject___6 *, struct bin_attribute___93 *, struct vm_area_struct___129 *);
};

struct kmem_cache_cpu___111 {
	void **freelist;
	long unsigned int tid;
	struct page___124 *page;
	struct page___124 *partial;
};

struct memcg_cache_params___111 {
	bool is_root_cache;
	union {
		struct kmem_cache___111 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___111 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___124;

struct super_block___124;

struct dentry___124 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___124 *d_parent;
	struct qstr d_name;
	struct inode___124 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___124 *d_op;
	struct super_block___124 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___124;

struct file_lock___124;

struct dquot___124;

struct block_device___124;

struct inode___124 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___124 *i_op;
	struct super_block___124 *i_sb;
	struct address_space___124 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___125 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___124 *i_fop;
	struct file_lock___124 *i_flock;
	struct address_space___124 i_data;
	struct dquot___124 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___124 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___124 {
	int (*d_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_hash)(const struct dentry___124 *, struct qstr *);
	int (*d_compare)(const struct dentry___124 *, const struct dentry___124 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___124 *);
	void (*d_release)(struct dentry___124 *);
	void (*d_prune)(struct dentry___124 *);
	void (*d_iput)(struct dentry___124 *, struct inode___124 *);
	char * (*d_dname)(struct dentry___124 *, char *, int);
	struct vfsmount___24 * (*d_automount)(struct path___124 *);
	int (*d_manage)(struct dentry___124 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___124;

struct mem_dqinfo___124 {
	struct quota_format_type___124 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___124;

struct quota_info___124 {
	unsigned int flags;
	struct mutex___125 dqio_mutex;
	struct mutex___125 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___124 *files[2];
	struct mem_dqinfo___124 info[2];
	const struct quota_format_ops___124 *ops[2];
};

struct file_system_type___124;

struct super_operations___124;

struct dquot_operations___124;

struct quotactl_ops___124;

struct export_operations___6;

struct xattr_handler___86;

struct super_block___124 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___124 *s_type;
	const struct super_operations___124 *s_op;
	const struct dquot_operations___124 *dq_op;
	const struct quotactl_ops___124 *s_qcop;
	const struct export_operations___6 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___124 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___86 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___124 *s_bdev;
	struct backing_dev_info___27 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___124 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___125 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___124 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___24 {
	struct dentry___124 *mnt_root;
	struct super_block___124 *mnt_sb;
	int mnt_flags;
};

struct bio___19;

typedef void bio_end_io_t___19(struct bio___19 *, int);

struct bio_vec___19 {
	struct page___124 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___19;

struct bio_set___19;

struct bio___19 {
	sector_t bi_sector;
	struct bio___19 *bi_next;
	struct block_device___124 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___19 *bi_end_io;
	void *bi_private;
	struct io_context___18 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___19 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___19 *bi_io_vec;
	struct bio_set___19 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___19 bi_inline_vecs[0];
};

struct hd_struct___19;

struct gendisk___19;

struct request_queue___18;

struct block_device___124 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___124 *bd_inode;
	struct super_block___124 *bd_super;
	struct mutex___125 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___124 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___19 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___19 *bd_disk;
	struct request_queue___18 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___125 bd_fsfreeze_mutex;
};

struct io_cq___18;

struct io_context___18 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___18 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___86;

struct cgroup_subsys_state___69 {
	struct cgroup___86 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___19 {
	struct bio___19 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___19 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___19 *bip_vec;
	struct bio_vec___19 bip_inline_vecs[0];
};

struct bio_list___18 {
	struct bio___19 *head;
	struct bio___19 *tail;
};

struct bio_set___19 {
	struct kmem_cache___111 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___18 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct buffer_head___3;

typedef int get_block_t___3(struct inode___124 *, sector_t, struct buffer_head___3 *, int);

typedef void bh_end_io_t___3(struct buffer_head___3 *, int);

struct buffer_head___3 {
	long unsigned int b_state;
	struct buffer_head___3 *b_this_page;
	struct page___124 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___124 *b_bdev;
	bh_end_io_t___3 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___124 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___11;

typedef void dio_iodone_t(struct kiocb___11 *, loff_t, ssize_t, void *, int, bool);

typedef int kiocb_cancel_fn___11(struct kiocb___11 *, struct io_event *);

struct kiocb___11 {
	atomic_t ki_users;
	struct file___124 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___11 *ki_cancel;
	void (*ki_dtor)(struct kiocb___11 *);
	union {
		void *user;
		struct task_struct___124 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___124 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___124 *ia_file;
};

struct dquot___124 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___125 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___124 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___124 {
	int qf_fmt_id;
	const struct quota_format_ops___124 *qf_ops;
	struct module___64 *qf_owner;
	struct quota_format_type___124 *qf_next;
};

struct quota_format_ops___124 {
	int (*check_quota_file)(struct super_block___124 *, int);
	int (*read_file_info)(struct super_block___124 *, int);
	int (*write_file_info)(struct super_block___124 *, int);
	int (*free_file_info)(struct super_block___124 *, int);
	int (*read_dqblk)(struct dquot___124 *);
	int (*commit_dqblk)(struct dquot___124 *);
	int (*release_dqblk)(struct dquot___124 *);
};

struct dquot_operations___124 {
	int (*write_dquot)(struct dquot___124 *);
	struct dquot___124 * (*alloc_dquot)(struct super_block___124 *, int);
	void (*destroy_dquot)(struct dquot___124 *);
	int (*acquire_dquot)(struct dquot___124 *);
	int (*release_dquot)(struct dquot___124 *);
	int (*mark_dirty)(struct dquot___124 *);
	int (*write_info)(struct super_block___124 *, int);
	qsize_t * (*get_reserved_space)(struct inode___124 *);
};

struct quotactl_ops___124 {
	int (*quota_on)(struct super_block___124 *, int, int, struct path___124 *);
	int (*quota_on_meta)(struct super_block___124 *, int, int);
	int (*quota_off)(struct super_block___124 *, int);
	int (*quota_sync)(struct super_block___124 *, int);
	int (*get_info)(struct super_block___124 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___124 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___124 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___124 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___124 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___124 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___124 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___124 *, unsigned int);
};

struct swap_info_struct___31;

struct address_space_operations___124 {
	int (*writepage)(struct page___124 *, struct writeback_control *);
	int (*readpage)(struct file___124 *, struct page___124 *);
	int (*writepages)(struct address_space___124 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___124 *);
	int (*readpages)(struct file___124 *, struct address_space___124 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___124 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___124 **, void **);
	int (*write_end)(struct file___124 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___124 *, void *);
	sector_t (*bmap)(struct address_space___124 *, sector_t);
	void (*invalidatepage)(struct page___124 *, long unsigned int);
	int (*releasepage)(struct page___124 *, gfp_t);
	void (*freepage)(struct page___124 *);
	ssize_t (*direct_IO)(int, struct kiocb___11 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___124 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___124 *, struct page___124 *, struct page___124 *, enum migrate_mode);
	int (*launder_page)(struct page___124 *);
	int (*is_partially_uptodate)(struct page___124 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___124 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___124 *, struct page___124 *);
	int (*swap_activate)(struct swap_info_struct___31 *, struct file___124 *, sector_t *);
	void (*swap_deactivate)(struct file___124 *);
	void (*invalidatepage_range)(struct page___124 *, unsigned int, unsigned int);
};

struct swap_info_struct___31 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___124 *bdev;
	struct file___124 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___27 {
	struct backing_dev_info___27 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___27 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___27 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___100 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___124 *debug_dir;
	struct dentry___124 *debug_stats;
};

struct hd_struct___19 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___100 __dev;
	struct kobject___6 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___19;

struct block_device_operations___18;

struct gendisk___19 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___19 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___19 *part_tbl;
	struct hd_struct___19 part0;
	const struct block_device_operations___18 *fops;
	struct request_queue___18 *queue;
	void *private_data;
	int flags;
	struct device___100 *driverfs_dev;
	struct kobject___6 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct request_list___18 {
	struct request_queue___18 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___18(struct request_queue___18 *);

typedef void make_request_fn___18(struct request_queue___18 *, struct bio___19 *);

struct request___18;

typedef int prep_rq_fn___18(struct request_queue___18 *, struct request___18 *);

struct bvec_merge_data___18;

typedef int merge_bvec_fn___18(struct request_queue___18 *, struct bvec_merge_data___18 *, struct bio_vec___19 *);

typedef void softirq_done_fn___18(struct request___18 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___18(struct request___18 *);

typedef int dma_drain_needed_fn___18(struct request___18 *);

typedef int lld_busy_fn___18(struct request_queue___18 *);

struct bsg_class_device___18 {
	struct device___100 *class_dev;
	struct device___100 *parent;
	int minor;
	struct request_queue___18 *queue;
	struct kref ref;
	void (*release)(struct device___100 *);
};

typedef void unprep_rq_fn___18(struct request_queue___18 *, struct request___18 *);

struct elevator_queue___18;

struct blk_queue_tag___18;

struct request_queue___18 {
	struct list_head queue_head;
	struct request___18 *last_merge;
	struct elevator_queue___18 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___18 root_rl;
	request_fn_proc___18 *request_fn;
	make_request_fn___18 *make_request_fn;
	prep_rq_fn___18 *prep_rq_fn;
	merge_bvec_fn___18 *merge_bvec_fn;
	softirq_done_fn___18 *softirq_done_fn;
	rq_timed_out_fn___18 *rq_timed_out_fn;
	dma_drain_needed_fn___18 *dma_drain_needed;
	lld_busy_fn___18 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___18 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___27 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___6 kobj;
	struct kobject___6 mq_kobj;
	struct device___100 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___18 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___18 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___125 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___18 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___18 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___19 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct nameidata___12;

struct inode_operations___124 {
	struct dentry___124 * (*lookup)(struct inode___124 *, struct dentry___124 *, unsigned int);
	void * (*follow_link)(struct dentry___124 *, struct nameidata___12 *);
	int (*permission)(struct inode___124 *, int);
	struct posix_acl * (*get_acl)(struct inode___124 *, int);
	int (*readlink)(struct dentry___124 *, char *, int);
	void (*put_link)(struct dentry___124 *, struct nameidata___12 *, void *);
	int (*create)(struct inode___124 *, struct dentry___124 *, umode_t, bool);
	int (*link)(struct dentry___124 *, struct inode___124 *, struct dentry___124 *);
	int (*unlink)(struct inode___124 *, struct dentry___124 *);
	int (*symlink)(struct inode___124 *, struct dentry___124 *, const char *);
	int (*mkdir)(struct inode___124 *, struct dentry___124 *, umode_t);
	int (*rmdir)(struct inode___124 *, struct dentry___124 *);
	int (*mknod)(struct inode___124 *, struct dentry___124 *, umode_t, dev_t);
	int (*rename)(struct inode___124 *, struct dentry___124 *, struct inode___124 *, struct dentry___124 *);
	int (*setattr)(struct dentry___124 *, struct iattr___124 *);
	int (*getattr)(struct vfsmount___24 *, struct dentry___124 *, struct kstat *);
	int (*setxattr)(struct dentry___124 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___124 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___124 *, char *, size_t);
	int (*removexattr)(struct dentry___124 *, const char *);
	int (*fiemap)(struct inode___124 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___124 *, struct timespec *, int);
	int (*atomic_open)(struct inode___124 *, struct dentry___124 *, struct file___124 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___124 {
	struct module___64 *owner;
	loff_t (*llseek)(struct file___124 *, loff_t, int);
	ssize_t (*read)(struct file___124 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___124 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___11 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___11 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___124 *, void *, filldir_t);
	unsigned int (*poll)(struct file___124 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___124 *, struct vm_area_struct___129 *);
	int (*open)(struct inode___124 *, struct file___124 *);
	int (*flush)(struct file___124 *, fl_owner_t);
	int (*release)(struct inode___124 *, struct file___124 *);
	int (*fsync)(struct file___124 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___11 *, int);
	int (*fasync)(int, struct file___124 *, int);
	int (*lock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*sendpage)(struct file___124 *, struct page___124 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___124 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___124 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___124 *, long int, struct file_lock___124 **, void **);
		struct {
			int (*setlease)(struct file___124 *, long int, struct file_lock___124 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___124 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___124 *);
};

struct fasync_struct___124;

struct file_lock_operations___124;

struct lock_manager_operations___124;

struct file_lock___124 {
	struct file_lock___124 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___71 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___124 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___124 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___124 *fl_ops;
	const struct lock_manager_operations___124 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___124 {
	void (*fl_copy_lock)(struct file_lock___124 *, struct file_lock___124 *);
	void (*fl_release_private)(struct file_lock___124 *);
};

struct lock_manager_operations___124 {
	int (*lm_compare_owner)(struct file_lock___124 *, struct file_lock___124 *);
	long unsigned int (*lm_owner_key)(struct file_lock___124 *);
	void (*lm_notify)(struct file_lock___124 *);
	int (*lm_grant)(struct file_lock___124 *, struct file_lock___124 *, int);
	void (*lm_break)(struct file_lock___124 *);
	int (*lm_change)(struct file_lock___124 **, int);
};

struct fasync_struct___124 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___124 *fa_next;
	struct file___124 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___124 {
	const char *name;
	int fs_flags;
	struct dentry___124 * (*mount)(struct file_system_type___124 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___124 *);
	struct module___64 *owner;
	struct file_system_type___124 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___124 {
	struct inode___124 * (*alloc_inode)(struct super_block___124 *);
	void (*destroy_inode)(struct inode___124 *);
	void (*dirty_inode)(struct inode___124 *, int);
	int (*write_inode)(struct inode___124 *, struct writeback_control *);
	int (*drop_inode)(struct inode___124 *);
	void (*evict_inode)(struct inode___124 *);
	void (*put_super)(struct super_block___124 *);
	int (*sync_fs)(struct super_block___124 *, int);
	int (*freeze_fs)(struct super_block___124 *);
	int (*unfreeze_fs)(struct super_block___124 *);
	int (*statfs)(struct dentry___124 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___124 *, int *, char *);
	void (*umount_begin)(struct super_block___124 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___124 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___124 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___124 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___124 *);
	ssize_t (*quota_read)(struct super_block___124 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___124 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___124 *);
	int (*bdev_try_to_free_page)(struct super_block___124 *, struct page___124 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___124 *);
	void (*free_cached_objects)(struct super_block___124 *, int);
};

struct export_operations___6 {
	int (*encode_fh)(struct inode___124 *, __u32 *, int *, struct inode___124 *);
	struct dentry___124 * (*fh_to_dentry)(struct super_block___124 *, struct fid *, int, int);
	struct dentry___124 * (*fh_to_parent)(struct super_block___124 *, struct fid *, int, int);
	int (*get_name)(struct dentry___124 *, char *, struct dentry___124 *);
	struct dentry___124 * (*get_parent)(struct dentry___124 *);
	int (*commit_metadata)(struct inode___124 *);
	int (*get_uuid)(struct super_block___124 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___124 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___124 *, struct iomap *, int, struct iattr___124 *);
};

struct xattr_handler___86 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___124 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___124 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___124 *, const char *, const void *, size_t, int, int);
};

struct nameidata___12 {
	struct path___124 path;
	struct qstr last;
	struct path___124 root;
	struct inode___124 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

typedef void dio_submit_t(int, struct bio___19 *, struct inode___124 *, loff_t);

enum {
	DIO_LOCKING = 1,
	DIO_SKIP_HOLES = 2,
	DIO_IGNORE_TRUNCATE = 4,
	DIO_ASYNC_EXTEND = 8,
};

struct signal_struct___124 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___124 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___124 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___71 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___71 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___125 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___86 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___69 *subsys[11];
	struct callback_head callback_head;
};

struct bus_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___100 *, char *);
	ssize_t (*store)(struct bus_type___100 *, const char *, size_t);
};

struct device_attribute___100;

struct driver_attribute___100;

struct bus_type___100 {
	const char *name;
	const char *dev_name;
	struct device___100 *dev_root;
	struct bus_attribute___100 *bus_attrs;
	struct device_attribute___100 *dev_attrs;
	struct driver_attribute___100 *drv_attrs;
	const struct attribute_group___93 **bus_groups;
	const struct attribute_group___93 **dev_groups;
	const struct attribute_group___93 **drv_groups;
	int (*match)(struct device___100 *, struct device_driver___100 *);
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	int (*probe)(struct device___100 *);
	int (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*online)(struct device___100 *);
	int (*offline)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct device___100 *, struct device_attribute___100 *, char *);
	ssize_t (*store)(struct device___100 *, struct device_attribute___100 *, const char *, size_t);
};

struct driver_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___100 *, char *);
	ssize_t (*store)(struct device_driver___100 *, const char *, size_t);
};

struct device_driver___100 {
	const char *name;
	struct bus_type___100 *bus;
	struct module___64 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___100 *);
	int (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	const struct attribute_group___93 **groups;
	const struct dev_pm_ops___100 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___100 {
	const char *name;
	const struct attribute_group___93 **groups;
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
};

struct class_attribute___100;

struct class___100 {
	const char *name;
	struct module___64 *owner;
	struct class_attribute___100 *class_attrs;
	struct device_attribute___100 *dev_attrs;
	const struct attribute_group___93 **dev_groups;
	struct bin_attribute___93 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *);
	void (*class_release)(struct class___100 *);
	void (*dev_release)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
	struct subsys_private *p;
};

struct class_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct class___100 *, struct class_attribute___100 *, char *);
	ssize_t (*store)(struct class___100 *, struct class_attribute___100 *, const char *, size_t);
	const void * (*namespace)(struct class___100 *, const struct class_attribute___100 *);
};

struct device_rh___100 {
	struct dev_pm_info_rh___100 power;
};

enum {
	DISK_EVENT_MEDIA_CHANGE = 1,
	DISK_EVENT_EJECT_REQUEST = 2,
};

struct disk_part_tbl___19 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___19 *last_lookup;
	struct hd_struct___19 *part[0];
};

struct block_device_operations___18 {
	int (*open)(struct block_device___124 *, fmode_t);
	void (*release)(struct gendisk___19 *, fmode_t);
	int (*ioctl)(struct block_device___124 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___124 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___124 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___19 *, unsigned int);
	int (*media_changed)(struct gendisk___19 *);
	void (*unlock_native_capacity)(struct gendisk___19 *);
	int (*revalidate_disk)(struct gendisk___19 *);
	int (*getgeo)(struct block_device___124 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___124 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___64 *owner;
};

struct io_cq___18 {
	struct request_queue___18 *q;
	struct io_context___18 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___111 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___18(struct request___18 *, int);

struct request___18 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___18 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___19 *bio;
	struct bio___19 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___18 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___18 *saved_end_io;
		} flush;
	};
	struct gendisk___19 *rq_disk;
	struct hd_struct___19 *part;
	long unsigned int start_time;
	struct request_list___18 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___18 *end_io;
	void *end_io_data;
	struct request___18 *next_rq;
};

typedef int elevator_merge_fn___18(struct request_queue___18 *, struct request___18 **, struct bio___19 *);

typedef void elevator_merge_req_fn___18(struct request_queue___18 *, struct request___18 *, struct request___18 *);

typedef void elevator_merged_fn___18(struct request_queue___18 *, struct request___18 *, int);

typedef int elevator_allow_merge_fn___18(struct request_queue___18 *, struct request___18 *, struct bio___19 *);

typedef void elevator_bio_merged_fn___18(struct request_queue___18 *, struct request___18 *, struct bio___19 *);

typedef int elevator_dispatch_fn___18(struct request_queue___18 *, int);

typedef void elevator_add_req_fn___18(struct request_queue___18 *, struct request___18 *);

typedef struct request___18 *elevator_request_list_fn___18(struct request_queue___18 *, struct request___18 *);

typedef void elevator_completed_req_fn___18(struct request_queue___18 *, struct request___18 *);

typedef int elevator_may_queue_fn___18(struct request_queue___18 *, int);

typedef void elevator_init_icq_fn___18(struct io_cq___18 *);

typedef void elevator_exit_icq_fn___18(struct io_cq___18 *);

typedef int elevator_set_req_fn___18(struct request_queue___18 *, struct request___18 *, struct bio___19 *, gfp_t);

typedef void elevator_put_req_fn___18(struct request___18 *);

typedef void elevator_activate_req_fn___18(struct request_queue___18 *, struct request___18 *);

typedef void elevator_deactivate_req_fn___18(struct request_queue___18 *, struct request___18 *);

struct elevator_type___18;

typedef int elevator_init_fn___18(struct request_queue___18 *, struct elevator_type___18 *);

typedef void elevator_exit_fn___18(struct elevator_queue___18 *);

struct elevator_ops___18 {
	elevator_merge_fn___18 *elevator_merge_fn;
	elevator_merged_fn___18 *elevator_merged_fn;
	elevator_merge_req_fn___18 *elevator_merge_req_fn;
	elevator_allow_merge_fn___18 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___18 *elevator_bio_merged_fn;
	elevator_dispatch_fn___18 *elevator_dispatch_fn;
	elevator_add_req_fn___18 *elevator_add_req_fn;
	elevator_activate_req_fn___18 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___18 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___18 *elevator_completed_req_fn;
	elevator_request_list_fn___18 *elevator_former_req_fn;
	elevator_request_list_fn___18 *elevator_latter_req_fn;
	elevator_init_icq_fn___18 *elevator_init_icq_fn;
	elevator_exit_icq_fn___18 *elevator_exit_icq_fn;
	elevator_set_req_fn___18 *elevator_set_req_fn;
	elevator_put_req_fn___18 *elevator_put_req_fn;
	elevator_may_queue_fn___18 *elevator_may_queue_fn;
	elevator_init_fn___18 *elevator_init_fn;
	elevator_exit_fn___18 *elevator_exit_fn;
};

struct elv_fs_entry___18;

struct elevator_type___18 {
	struct kmem_cache___111 *icq_cache;
	struct elevator_ops___18 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___18 *elevator_attrs;
	char elevator_name[16];
	struct module___64 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___18 {
	struct elevator_type___18 *type;
	void *elevator_data;
	struct kobject___6 kobj;
	struct mutex___125 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___18 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___18 *, char *);
	ssize_t (*store)(struct elevator_queue___18 *, const char *, size_t);
};

struct bvec_merge_data___18 {
	struct block_device___124 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___18 {
	struct request___18 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct module_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___63 *, struct module_kobject___63 *, char *);
	ssize_t (*store)(struct module_attribute___63 *, struct module_kobject___63 *, const char *, size_t);
	void (*setup)(struct module___64 *, const char *);
	int (*test)(struct module___64 *);
	void (*free)(struct module___64 *);
};

struct cgroupfs_root___86;

struct cgroup___86 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___86 *parent;
	struct dentry___124 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___69 *subsys[11];
	struct cgroupfs_root___86 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___125 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___86 {
	struct super_block___124 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___86 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___41 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___124 *, struct file___124 *);
	ssize_t (*read)(struct cgroup___86 *, struct cftype___41 *, struct file___124 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___86 *, struct cftype___41 *);
	s64 (*read_s64)(struct cgroup___86 *, struct cftype___41 *);
	int (*read_map)(struct cgroup___86 *, struct cftype___41 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___86 *, struct cftype___41 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___86 *, struct cftype___41 *, struct file___124 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___86 *, struct cftype___41 *, u64);
	int (*write_s64)(struct cgroup___86 *, struct cftype___41 *, s64);
	int (*write_string)(struct cgroup___86 *, struct cftype___41 *, const char *);
	int (*trigger)(struct cgroup___86 *, unsigned int);
	int (*release)(struct inode___124 *, struct file___124 *);
	int (*register_event)(struct cgroup___86 *, struct cftype___41 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___86 *, struct cftype___41 *, struct eventfd_ctx *);
};

struct cftype_set___39 {
	struct list_head node;
	struct cftype___41 *cfts;
};

struct task_and_cgroup___39 {
	struct task_struct___124 *task;
	struct cgroup___86 *cgrp;
	struct css_set___86 *cg;
};

struct cgroup_taskset___39 {
	struct task_and_cgroup___39 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___86 *cur_cgrp;
};

struct cgroup_subsys___39 {
	struct cgroup_subsys_state___69 * (*css_alloc)(struct cgroup___86 *);
	int (*css_online)(struct cgroup___86 *);
	void (*css_offline)(struct cgroup___86 *);
	void (*css_free)(struct cgroup___86 *);
	int (*can_attach)(struct cgroup___86 *, struct cgroup_taskset___39 *);
	void (*cancel_attach)(struct cgroup___86 *, struct cgroup_taskset___39 *);
	void (*attach)(struct cgroup___86 *, struct cgroup_taskset___39 *);
	void (*fork)(struct task_struct___124 *);
	void (*exit)(struct cgroup___86 *, struct cgroup___86 *, struct task_struct___124 *);
	void (*bind)(struct cgroup___86 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___86 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___41 *base_cftypes;
	struct cftype_set___39 base_cftset;
	struct module___64 *module;
};

struct bdev_inode {
	struct block_device___124 bdev;
	struct inode___124 vfs_inode;
};

struct bd_holder_disk {
	struct list_head list;
	struct gendisk___19 *disk;
	int refcnt;
};

struct page___125;

typedef struct page___125 *pgtable_t___125;

struct address_space___125;

struct kmem_cache___112;

struct page___125 {
	long unsigned int flags;
	struct address_space___125 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___125 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___125 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___112 *slab_cache;
		struct page___125 *first_page;
	};
	long: 64;
};

struct task_struct___125;

struct pv_cpu_ops___125 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___66 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___66 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___125 *);
	void (*end_context_switch)(struct task_struct___125 *);
};

struct mutex___126 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___125 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___121 {
	struct page___125 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___130;

struct signal_struct___125;

struct bio_list___19;

struct backing_dev_info___28;

struct io_context___19;

struct task_struct___125 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___125 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___130 *mm;
	struct mm_struct___130 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___125 *real_parent;
	struct task_struct___125 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___125 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___71 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___125 = 0,
		VTIME_USER___125 = 1,
		VTIME_SYS___125 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___66 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___125 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___19 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___28 *backing_dev_info;
	struct io_context___19 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___126 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___121 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___130 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___130 *, struct mm_struct___130 *);
	void (*dup_mmap)(struct mm_struct___130 *, struct mm_struct___130 *);
	void (*exit_mmap)(struct mm_struct___130 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___130 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___130 *);
	void (*pgd_free)(struct mm_struct___130 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___130 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___130 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___130 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___130 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___130 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___130 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___130 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___130 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___130 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___130 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___130 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___126 lock;
	void *vdso;
} mm_context_t___126;

struct xol_area___125;

struct uprobes_state___125 {
	struct xol_area___125 *xol_area;
};

struct vm_area_struct___130;

struct file___125;

struct core_state___125;

struct mm_struct___130 {
	struct vm_area_struct___130 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___130 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___130 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___126 context;
	long unsigned int flags;
	struct core_state___125 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___125 *owner;
	struct file___125 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___125 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___65;

struct exec_domain___34 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___65 *module;
	struct exec_domain___34 *next;
};

struct module_kobject___64 {
	struct kobject___6 kobj;
	struct module___65 *mod;
	struct kobject___6 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___64;

struct module___65 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___64 mkobj;
	struct module_attribute___64 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___6 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___125 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___68 {
	struct task_struct___125 *task;
	struct exec_domain___34 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___125;

struct lruvec___125 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___125 *zone;
};

struct pglist_data___125;

struct zone___125 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___125 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___125 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___125 {
	struct zone___125 *zone;
	int zone_idx;
};

struct zonelist___125 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___125 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___125 {
	struct zone___125 node_zones[4];
	struct zonelist___125 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___125 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___101;

struct dev_pm_ops___101 {
	int (*prepare)(struct device___101 *);
	void (*complete)(struct device___101 *);
	int (*suspend)(struct device___101 *);
	int (*resume)(struct device___101 *);
	int (*freeze)(struct device___101 *);
	int (*thaw)(struct device___101 *);
	int (*poweroff)(struct device___101 *);
	int (*restore)(struct device___101 *);
	int (*suspend_late)(struct device___101 *);
	int (*resume_early)(struct device___101 *);
	int (*freeze_late)(struct device___101 *);
	int (*thaw_early)(struct device___101 *);
	int (*poweroff_late)(struct device___101 *);
	int (*restore_early)(struct device___101 *);
	int (*suspend_noirq)(struct device___101 *);
	int (*resume_noirq)(struct device___101 *);
	int (*freeze_noirq)(struct device___101 *);
	int (*thaw_noirq)(struct device___101 *);
	int (*poweroff_noirq)(struct device___101 *);
	int (*restore_noirq)(struct device___101 *);
	int (*runtime_suspend)(struct device___101 *);
	int (*runtime_resume)(struct device___101 *);
	int (*runtime_idle)(struct device___101 *);
};

struct device_type___101;

struct bus_type___101;

struct device_driver___101;

struct dev_pm_domain___101;

struct class___101;

struct attribute_group___94;

struct device_rh___101;

struct device___101 {
	struct device___101 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___101 *type;
	struct mutex___126 mutex;
	struct bus_type___101 *bus;
	struct device_driver___101 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___101 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___101 *class;
	const struct attribute_group___94 **groups;
	void (*release)(struct device___101 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___101 *device_rh;
};

struct dev_pm_info_rh___101 {
	void (*set_latency_tolerance)(struct device___101 *, s32);
};

struct dev_pm_domain___101 {
	struct dev_pm_ops___101 ops;
};

struct smp_ops___125 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___125 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___94;

struct attribute_group___94 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___94 **bin_attrs;
};

struct bin_attribute___94 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___125 *, struct kobject___6 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___125 *, struct kobject___6 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	int (*mmap)(struct file___125 *, struct kobject___6 *, struct bin_attribute___94 *, struct vm_area_struct___130 *);
};

struct dentry___125;

struct path___125 {
	struct vfsmount *mnt;
	struct dentry___125 *dentry;
};

struct inode___125;

struct file_operations___125;

struct file___125 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___125 f_path;
	struct inode___125 *f_inode;
	const struct file_operations___125 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___71 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___125 *f_mapping;
	struct mutex___126 f_pos_lock;
};

struct vm_operations_struct___112;

struct vm_area_struct___130 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___130 *vm_next;
	struct vm_area_struct___130 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___130 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___112 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___125 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___64 *, struct module_kobject___64 *, char *);
	ssize_t (*store)(struct module_attribute___64 *, struct module_kobject___64 *, const char *, size_t);
	void (*setup)(struct module___65 *, const char *);
	int (*test)(struct module___65 *);
	void (*free)(struct module___65 *);
};

struct dentry_operations___125;

struct super_block___125;

struct dentry___125 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___125 *d_parent;
	struct qstr d_name;
	struct inode___125 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___125 *d_op;
	struct super_block___125 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___125;

struct address_space___125 {
	struct inode___125 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___126 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___125 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___28 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___125;

struct file_lock___125;

struct dquot___125;

struct block_device___125;

struct inode___125 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___125 *i_op;
	struct super_block___125 *i_sb;
	struct address_space___125 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___126 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___125 *i_fop;
	struct file_lock___125 *i_flock;
	struct address_space___125 i_data;
	struct dquot___125 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___125 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___125 {
	int (*d_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_hash)(const struct dentry___125 *, struct qstr *);
	int (*d_compare)(const struct dentry___125 *, const struct dentry___125 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___125 *);
	void (*d_release)(struct dentry___125 *);
	void (*d_prune)(struct dentry___125 *);
	void (*d_iput)(struct dentry___125 *, struct inode___125 *);
	char * (*d_dname)(struct dentry___125 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___125 *);
	int (*d_manage)(struct dentry___125 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___125;

struct mem_dqinfo___125 {
	struct quota_format_type___125 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___125;

struct quota_info___125 {
	unsigned int flags;
	struct mutex___126 dqio_mutex;
	struct mutex___126 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___125 *files[2];
	struct mem_dqinfo___125 info[2];
	const struct quota_format_ops___125 *ops[2];
};

struct file_system_type___125;

struct super_operations___125;

struct dquot_operations___125;

struct quotactl_ops___125;

struct super_block___125 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___125 *s_type;
	const struct super_operations___125 *s_op;
	const struct dquot_operations___125 *dq_op;
	const struct quotactl_ops___125 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___125 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___125 *s_bdev;
	struct backing_dev_info___28 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___125 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___126 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___125 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___20;

typedef void bio_end_io_t___20(struct bio___20 *, int);

struct bio_vec___20 {
	struct page___125 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___20;

struct bio_set___20;

struct bio___20 {
	sector_t bi_sector;
	struct bio___20 *bi_next;
	struct block_device___125 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___20 *bi_end_io;
	void *bi_private;
	struct io_context___19 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___20 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___20 *bi_io_vec;
	struct bio_set___20 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___20 bi_inline_vecs[0];
};

struct hd_struct___20;

struct gendisk___20;

struct request_queue___19;

struct block_device___125 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___125 *bd_inode;
	struct super_block___125 *bd_super;
	struct mutex___126 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___125 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___20 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___20 *bd_disk;
	struct request_queue___19 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___126 bd_fsfreeze_mutex;
};

struct io_cq___19;

struct io_context___19 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___19 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___20 {
	struct bio___20 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___20 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___20 *bip_vec;
	struct bio_vec___20 bip_inline_vecs[0];
};

struct bio_list___19 {
	struct bio___20 *head;
	struct bio___20 *tail;
};

struct bio_set___20 {
	struct kmem_cache___112 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___19 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct buffer_head___4;

typedef int get_block_t___4(struct inode___125 *, sector_t, struct buffer_head___4 *, int);

typedef void bh_end_io_t___4(struct buffer_head___4 *, int);

struct buffer_head___4 {
	long unsigned int b_state;
	struct buffer_head___4 *b_this_page;
	struct page___125 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___125 *b_bdev;
	bh_end_io_t___4 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___125 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___12;

typedef void dio_iodone_t___2(struct kiocb___12 *, loff_t, ssize_t, void *, int, bool);

typedef int kiocb_cancel_fn___12(struct kiocb___12 *, struct io_event *);

struct kiocb___12 {
	atomic_t ki_users;
	struct file___125 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___12 *ki_cancel;
	void (*ki_dtor)(struct kiocb___12 *);
	union {
		void *user;
		struct task_struct___125 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___125 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___125 *ia_file;
};

struct dquot___125 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___126 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___125 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___125 {
	int qf_fmt_id;
	const struct quota_format_ops___125 *qf_ops;
	struct module___65 *qf_owner;
	struct quota_format_type___125 *qf_next;
};

struct quota_format_ops___125 {
	int (*check_quota_file)(struct super_block___125 *, int);
	int (*read_file_info)(struct super_block___125 *, int);
	int (*write_file_info)(struct super_block___125 *, int);
	int (*free_file_info)(struct super_block___125 *, int);
	int (*read_dqblk)(struct dquot___125 *);
	int (*commit_dqblk)(struct dquot___125 *);
	int (*release_dqblk)(struct dquot___125 *);
};

struct dquot_operations___125 {
	int (*write_dquot)(struct dquot___125 *);
	struct dquot___125 * (*alloc_dquot)(struct super_block___125 *, int);
	void (*destroy_dquot)(struct dquot___125 *);
	int (*acquire_dquot)(struct dquot___125 *);
	int (*release_dquot)(struct dquot___125 *);
	int (*mark_dirty)(struct dquot___125 *);
	int (*write_info)(struct super_block___125 *, int);
	qsize_t * (*get_reserved_space)(struct inode___125 *);
};

struct quotactl_ops___125 {
	int (*quota_on)(struct super_block___125 *, int, int, struct path___125 *);
	int (*quota_on_meta)(struct super_block___125 *, int, int);
	int (*quota_off)(struct super_block___125 *, int);
	int (*quota_sync)(struct super_block___125 *, int);
	int (*get_info)(struct super_block___125 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___125 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___125 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___125 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___125 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___125 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___125 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___125 *, unsigned int);
};

struct address_space_operations___125 {
	int (*writepage)(struct page___125 *, struct writeback_control *);
	int (*readpage)(struct file___125 *, struct page___125 *);
	int (*writepages)(struct address_space___125 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___125 *);
	int (*readpages)(struct file___125 *, struct address_space___125 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___125 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___125 **, void **);
	int (*write_end)(struct file___125 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___125 *, void *);
	sector_t (*bmap)(struct address_space___125 *, sector_t);
	void (*invalidatepage)(struct page___125 *, long unsigned int);
	int (*releasepage)(struct page___125 *, gfp_t);
	void (*freepage)(struct page___125 *);
	ssize_t (*direct_IO)(int, struct kiocb___12 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___125 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___125 *, struct page___125 *, struct page___125 *, enum migrate_mode);
	int (*launder_page)(struct page___125 *);
	int (*is_partially_uptodate)(struct page___125 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___125 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___125 *, struct page___125 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___125 *, sector_t *);
	void (*swap_deactivate)(struct file___125 *);
	void (*invalidatepage_range)(struct page___125 *, unsigned int, unsigned int);
};

struct bdi_writeback___28 {
	struct backing_dev_info___28 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___28 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___28 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___101 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___125 *debug_dir;
	struct dentry___125 *debug_stats;
};

struct hd_struct___20 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___101 __dev;
	struct kobject___6 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___20;

struct block_device_operations___19;

struct gendisk___20 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___20 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___20 *part_tbl;
	struct hd_struct___20 part0;
	const struct block_device_operations___19 *fops;
	struct request_queue___19 *queue;
	void *private_data;
	int flags;
	struct device___101 *driverfs_dev;
	struct kobject___6 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct request_list___19 {
	struct request_queue___19 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___19(struct request_queue___19 *);

typedef void make_request_fn___19(struct request_queue___19 *, struct bio___20 *);

struct request___19;

typedef int prep_rq_fn___19(struct request_queue___19 *, struct request___19 *);

struct bvec_merge_data___19;

typedef int merge_bvec_fn___19(struct request_queue___19 *, struct bvec_merge_data___19 *, struct bio_vec___20 *);

typedef void softirq_done_fn___19(struct request___19 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___19(struct request___19 *);

typedef int dma_drain_needed_fn___19(struct request___19 *);

typedef int lld_busy_fn___19(struct request_queue___19 *);

struct bsg_class_device___19 {
	struct device___101 *class_dev;
	struct device___101 *parent;
	int minor;
	struct request_queue___19 *queue;
	struct kref ref;
	void (*release)(struct device___101 *);
};

typedef void unprep_rq_fn___19(struct request_queue___19 *, struct request___19 *);

struct elevator_queue___19;

struct blk_queue_tag___19;

struct request_queue___19 {
	struct list_head queue_head;
	struct request___19 *last_merge;
	struct elevator_queue___19 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___19 root_rl;
	request_fn_proc___19 *request_fn;
	make_request_fn___19 *make_request_fn;
	prep_rq_fn___19 *prep_rq_fn;
	merge_bvec_fn___19 *merge_bvec_fn;
	softirq_done_fn___19 *softirq_done_fn;
	rq_timed_out_fn___19 *rq_timed_out_fn;
	dma_drain_needed_fn___19 *dma_drain_needed;
	lld_busy_fn___19 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___19 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___28 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___6 kobj;
	struct kobject___6 mq_kobj;
	struct device___101 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___19 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___19 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___126 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___19 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___19 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___20 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___125 {
	struct dentry___125 * (*lookup)(struct inode___125 *, struct dentry___125 *, unsigned int);
	void * (*follow_link)(struct dentry___125 *, struct nameidata *);
	int (*permission)(struct inode___125 *, int);
	struct posix_acl * (*get_acl)(struct inode___125 *, int);
	int (*readlink)(struct dentry___125 *, char *, int);
	void (*put_link)(struct dentry___125 *, struct nameidata *, void *);
	int (*create)(struct inode___125 *, struct dentry___125 *, umode_t, bool);
	int (*link)(struct dentry___125 *, struct inode___125 *, struct dentry___125 *);
	int (*unlink)(struct inode___125 *, struct dentry___125 *);
	int (*symlink)(struct inode___125 *, struct dentry___125 *, const char *);
	int (*mkdir)(struct inode___125 *, struct dentry___125 *, umode_t);
	int (*rmdir)(struct inode___125 *, struct dentry___125 *);
	int (*mknod)(struct inode___125 *, struct dentry___125 *, umode_t, dev_t);
	int (*rename)(struct inode___125 *, struct dentry___125 *, struct inode___125 *, struct dentry___125 *);
	int (*setattr)(struct dentry___125 *, struct iattr___125 *);
	int (*getattr)(struct vfsmount *, struct dentry___125 *, struct kstat *);
	int (*setxattr)(struct dentry___125 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___125 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___125 *, char *, size_t);
	int (*removexattr)(struct dentry___125 *, const char *);
	int (*fiemap)(struct inode___125 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___125 *, struct timespec *, int);
	int (*atomic_open)(struct inode___125 *, struct dentry___125 *, struct file___125 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___125 {
	struct module___65 *owner;
	loff_t (*llseek)(struct file___125 *, loff_t, int);
	ssize_t (*read)(struct file___125 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___125 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___12 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___12 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___125 *, void *, filldir_t);
	unsigned int (*poll)(struct file___125 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___125 *, struct vm_area_struct___130 *);
	int (*open)(struct inode___125 *, struct file___125 *);
	int (*flush)(struct file___125 *, fl_owner_t);
	int (*release)(struct inode___125 *, struct file___125 *);
	int (*fsync)(struct file___125 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___12 *, int);
	int (*fasync)(int, struct file___125 *, int);
	int (*lock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*sendpage)(struct file___125 *, struct page___125 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___125 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___125 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___125 *, long int, struct file_lock___125 **, void **);
		struct {
			int (*setlease)(struct file___125 *, long int, struct file_lock___125 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___125 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___125 *);
};

struct fasync_struct___125;

struct file_lock_operations___125;

struct lock_manager_operations___125;

struct file_lock___125 {
	struct file_lock___125 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___71 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___125 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___125 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___125 *fl_ops;
	const struct lock_manager_operations___125 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___125 {
	void (*fl_copy_lock)(struct file_lock___125 *, struct file_lock___125 *);
	void (*fl_release_private)(struct file_lock___125 *);
};

struct lock_manager_operations___125 {
	int (*lm_compare_owner)(struct file_lock___125 *, struct file_lock___125 *);
	long unsigned int (*lm_owner_key)(struct file_lock___125 *);
	void (*lm_notify)(struct file_lock___125 *);
	int (*lm_grant)(struct file_lock___125 *, struct file_lock___125 *, int);
	void (*lm_break)(struct file_lock___125 *);
	int (*lm_change)(struct file_lock___125 **, int);
};

struct fasync_struct___125 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___125 *fa_next;
	struct file___125 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___125 {
	const char *name;
	int fs_flags;
	struct dentry___125 * (*mount)(struct file_system_type___125 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___125 *);
	struct module___65 *owner;
	struct file_system_type___125 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___125 {
	struct inode___125 * (*alloc_inode)(struct super_block___125 *);
	void (*destroy_inode)(struct inode___125 *);
	void (*dirty_inode)(struct inode___125 *, int);
	int (*write_inode)(struct inode___125 *, struct writeback_control *);
	int (*drop_inode)(struct inode___125 *);
	void (*evict_inode)(struct inode___125 *);
	void (*put_super)(struct super_block___125 *);
	int (*sync_fs)(struct super_block___125 *, int);
	int (*freeze_fs)(struct super_block___125 *);
	int (*unfreeze_fs)(struct super_block___125 *);
	int (*statfs)(struct dentry___125 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___125 *, int *, char *);
	void (*umount_begin)(struct super_block___125 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___125 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___125 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___125 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___125 *);
	ssize_t (*quota_read)(struct super_block___125 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___125 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___125 *);
	int (*bdev_try_to_free_page)(struct super_block___125 *, struct page___125 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___125 *);
	void (*free_cached_objects)(struct super_block___125 *, int);
};

typedef void dio_submit_t___2(int, struct bio___20 *, struct inode___125 *, loff_t);

struct xol_area___125 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___125 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___112;

struct memcg_cache_params___112;

struct kmem_cache___112 {
	struct kmem_cache_cpu___112 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___112 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___109;

struct vm_operations_struct___112 {
	void (*open)(struct vm_area_struct___130 *);
	void (*close)(struct vm_area_struct___130 *);
	int (*fault)(struct vm_area_struct___130 *, struct vm_fault___109 *);
	int (*page_mkwrite)(struct vm_area_struct___130 *, struct vm_fault___109 *);
	int (*access)(struct vm_area_struct___130 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___130 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___130 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___130 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___130 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___125 {
	struct task_struct___125 *task;
	struct core_thread___125 *next;
};

struct core_state___125 {
	atomic_t nr_threads;
	struct core_thread___125 dumper;
	struct completion startup;
};

struct vm_fault___109 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___125 *page;
};

struct kmem_cache_cpu___112 {
	void **freelist;
	long unsigned int tid;
	struct page___125 *page;
	struct page___125 *partial;
};

struct memcg_cache_params___112 {
	bool is_root_cache;
	union {
		struct kmem_cache___112 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___112 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___125 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___125 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___125 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___71 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___71 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___126 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___19 {
	struct request_queue___19 *q;
	struct io_context___19 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___112 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct bus_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___101 *, char *);
	ssize_t (*store)(struct bus_type___101 *, const char *, size_t);
};

struct device_attribute___101;

struct driver_attribute___101;

struct bus_type___101 {
	const char *name;
	const char *dev_name;
	struct device___101 *dev_root;
	struct bus_attribute___101 *bus_attrs;
	struct device_attribute___101 *dev_attrs;
	struct driver_attribute___101 *drv_attrs;
	const struct attribute_group___94 **bus_groups;
	const struct attribute_group___94 **dev_groups;
	const struct attribute_group___94 **drv_groups;
	int (*match)(struct device___101 *, struct device_driver___101 *);
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	int (*probe)(struct device___101 *);
	int (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*online)(struct device___101 *);
	int (*offline)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct device___101 *, struct device_attribute___101 *, char *);
	ssize_t (*store)(struct device___101 *, struct device_attribute___101 *, const char *, size_t);
};

struct driver_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___101 *, char *);
	ssize_t (*store)(struct device_driver___101 *, const char *, size_t);
};

struct device_driver___101 {
	const char *name;
	struct bus_type___101 *bus;
	struct module___65 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___101 *);
	int (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	const struct attribute_group___94 **groups;
	const struct dev_pm_ops___101 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___101 {
	const char *name;
	const struct attribute_group___94 **groups;
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
};

struct class_attribute___101;

struct class___101 {
	const char *name;
	struct module___65 *owner;
	struct class_attribute___101 *class_attrs;
	struct device_attribute___101 *dev_attrs;
	const struct attribute_group___94 **dev_groups;
	struct bin_attribute___94 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *);
	void (*class_release)(struct class___101 *);
	void (*dev_release)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
	struct subsys_private *p;
};

struct class_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct class___101 *, struct class_attribute___101 *, char *);
	ssize_t (*store)(struct class___101 *, struct class_attribute___101 *, const char *, size_t);
	const void * (*namespace)(struct class___101 *, const struct class_attribute___101 *);
};

struct device_rh___101 {
	struct dev_pm_info_rh___101 power;
};

struct disk_part_tbl___20 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___20 *last_lookup;
	struct hd_struct___20 *part[0];
};

struct block_device_operations___19 {
	int (*open)(struct block_device___125 *, fmode_t);
	void (*release)(struct gendisk___20 *, fmode_t);
	int (*ioctl)(struct block_device___125 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___125 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___125 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___20 *, unsigned int);
	int (*media_changed)(struct gendisk___20 *);
	void (*unlock_native_capacity)(struct gendisk___20 *);
	int (*revalidate_disk)(struct gendisk___20 *);
	int (*getgeo)(struct block_device___125 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___125 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___65 *owner;
};

typedef void rq_end_io_fn___19(struct request___19 *, int);

struct request___19 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___19 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___20 *bio;
	struct bio___20 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___19 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___19 *saved_end_io;
		} flush;
	};
	struct gendisk___20 *rq_disk;
	struct hd_struct___20 *part;
	long unsigned int start_time;
	struct request_list___19 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___19 *end_io;
	void *end_io_data;
	struct request___19 *next_rq;
};

typedef int elevator_merge_fn___19(struct request_queue___19 *, struct request___19 **, struct bio___20 *);

typedef void elevator_merge_req_fn___19(struct request_queue___19 *, struct request___19 *, struct request___19 *);

typedef void elevator_merged_fn___19(struct request_queue___19 *, struct request___19 *, int);

typedef int elevator_allow_merge_fn___19(struct request_queue___19 *, struct request___19 *, struct bio___20 *);

typedef void elevator_bio_merged_fn___19(struct request_queue___19 *, struct request___19 *, struct bio___20 *);

typedef int elevator_dispatch_fn___19(struct request_queue___19 *, int);

typedef void elevator_add_req_fn___19(struct request_queue___19 *, struct request___19 *);

typedef struct request___19 *elevator_request_list_fn___19(struct request_queue___19 *, struct request___19 *);

typedef void elevator_completed_req_fn___19(struct request_queue___19 *, struct request___19 *);

typedef int elevator_may_queue_fn___19(struct request_queue___19 *, int);

typedef void elevator_init_icq_fn___19(struct io_cq___19 *);

typedef void elevator_exit_icq_fn___19(struct io_cq___19 *);

typedef int elevator_set_req_fn___19(struct request_queue___19 *, struct request___19 *, struct bio___20 *, gfp_t);

typedef void elevator_put_req_fn___19(struct request___19 *);

typedef void elevator_activate_req_fn___19(struct request_queue___19 *, struct request___19 *);

typedef void elevator_deactivate_req_fn___19(struct request_queue___19 *, struct request___19 *);

struct elevator_type___19;

typedef int elevator_init_fn___19(struct request_queue___19 *, struct elevator_type___19 *);

typedef void elevator_exit_fn___19(struct elevator_queue___19 *);

struct elevator_ops___19 {
	elevator_merge_fn___19 *elevator_merge_fn;
	elevator_merged_fn___19 *elevator_merged_fn;
	elevator_merge_req_fn___19 *elevator_merge_req_fn;
	elevator_allow_merge_fn___19 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___19 *elevator_bio_merged_fn;
	elevator_dispatch_fn___19 *elevator_dispatch_fn;
	elevator_add_req_fn___19 *elevator_add_req_fn;
	elevator_activate_req_fn___19 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___19 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___19 *elevator_completed_req_fn;
	elevator_request_list_fn___19 *elevator_former_req_fn;
	elevator_request_list_fn___19 *elevator_latter_req_fn;
	elevator_init_icq_fn___19 *elevator_init_icq_fn;
	elevator_exit_icq_fn___19 *elevator_exit_icq_fn;
	elevator_set_req_fn___19 *elevator_set_req_fn;
	elevator_put_req_fn___19 *elevator_put_req_fn;
	elevator_may_queue_fn___19 *elevator_may_queue_fn;
	elevator_init_fn___19 *elevator_init_fn;
	elevator_exit_fn___19 *elevator_exit_fn;
};

struct elv_fs_entry___19;

struct elevator_type___19 {
	struct kmem_cache___112 *icq_cache;
	struct elevator_ops___19 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___19 *elevator_attrs;
	char elevator_name[16];
	struct module___65 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___19 {
	struct elevator_type___19 *type;
	void *elevator_data;
	struct kobject___6 kobj;
	struct mutex___126 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___19 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___19 *, char *);
	ssize_t (*store)(struct elevator_queue___19 *, const char *, size_t);
};

struct bvec_merge_data___19 {
	struct block_device___125 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___19 {
	struct request___19 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct dio_submit {
	struct bio___20 *bio;
	unsigned int blkbits;
	unsigned int blkfactor;
	unsigned int start_zero_done;
	int pages_in_io;
	size_t size;
	sector_t block_in_file;
	unsigned int blocks_available;
	int reap_counter;
	sector_t final_block_in_request;
	unsigned int first_block_in_page;
	int boundary;
	get_block_t___4 *get_block;
	dio_submit_t___2 *submit_io;
	loff_t logical_offset_in_bio;
	sector_t final_block_in_bio;
	sector_t next_block_for_io;
	struct page___125 *cur_page;
	unsigned int cur_page_offset;
	unsigned int cur_page_len;
	sector_t cur_page_block;
	loff_t cur_page_fs_offset;
	int curr_page;
	int total_pages;
	long unsigned int curr_user_address;
	unsigned int head;
	unsigned int tail;
};

struct dio {
	int flags;
	int rw;
	struct inode___125 *inode;
	loff_t i_size;
	dio_iodone_t___2 *end_io;
	void *private;
	spinlock_t bio_lock;
	int page_errors;
	int is_async;
	int io_error;
	long unsigned int refcount;
	struct bio___20 *bio_list;
	struct task_struct___125 *waiter;
	struct kiocb___12 *iocb;
	ssize_t result;
	struct page___125 *pages[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*writepage_t___2)(struct page___124 *, struct writeback_control *, void *);

struct mpage_data {
	struct bio___19 *bio;
	sector_t last_block_in_bio;
	get_block_t___3 *get_block;
	unsigned int use_writepage;
};

struct page___126;

typedef struct page___126 *pgtable_t___126;

struct address_space___126;

struct kmem_cache___113;

struct page___126 {
	long unsigned int flags;
	struct address_space___126 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___126 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___126 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___113 *slab_cache;
		struct page___126 *first_page;
	};
	long: 64;
};

struct thread_struct___67;

struct task_struct___126;

struct pv_cpu_ops___126 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___67 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___67 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___126 *);
	void (*end_context_switch)(struct task_struct___126 *);
};

struct perf_event___67;

struct thread_struct___67 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___67 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___72;

struct pid_link___72 {
	struct hlist_node node;
	struct pid___72 *pid;
};

struct mutex___127 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___126 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___122 {
	struct page___126 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___131;

struct nsproxy___74;

struct signal_struct___126;

struct bio_list___20;

struct backing_dev_info___29;

struct io_context___20;

struct css_set___87;

struct perf_event_context___67;

struct task_struct___126 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___126 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___131 *mm;
	struct mm_struct___131 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___126 *real_parent;
	struct task_struct___126 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___126 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___72 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___126 = 0,
		VTIME_USER___126 = 1,
		VTIME_SYS___126 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___67 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___74 *nsproxy;
	struct signal_struct___126 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___20 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___29 *backing_dev_info;
	struct io_context___20 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___87 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___67 *perf_event_ctxp[2];
	struct mutex___127 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___122 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___131 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___131 *, struct mm_struct___131 *);
	void (*dup_mmap)(struct mm_struct___131 *, struct mm_struct___131 *);
	void (*exit_mmap)(struct mm_struct___131 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___131 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___131 *);
	void (*pgd_free)(struct mm_struct___131 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___131 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___131 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___131 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___131 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___131 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___131 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___131 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___131 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___131 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___131 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___131 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___127 lock;
	void *vdso;
} mm_context_t___127;

struct xol_area___126;

struct uprobes_state___126 {
	struct xol_area___126 *xol_area;
};

struct vm_area_struct___131;

struct file___126;

struct core_state___126;

struct mm_struct___131 {
	struct vm_area_struct___131 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___131 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___131 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___127 context;
	long unsigned int flags;
	struct core_state___126 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___126 *owner;
	struct file___126 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___126 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___67 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___126 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___126 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___126 *target;
};

typedef void (*perf_overflow_handler_t___67)(struct perf_event___67 *, struct perf_sample_data___3 *, struct pt_regs *);

struct ftrace_ops___67;

typedef void (*ftrace_func_t___67)(long unsigned int, long unsigned int, struct ftrace_ops___67 *, struct pt_regs *);

struct ftrace_ops___67 {
	ftrace_func_t___67 func;
	struct ftrace_ops___67 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___127 regex_lock;
};

struct pmu___67;

struct fasync_struct___126;

struct pid_namespace___72;

struct ftrace_event_call___57;

struct perf_cgroup___67;

struct perf_event___67 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___67 *group_leader;
	struct pmu___67 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___67 hw;
	struct perf_event_context___67 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___127 child_mutex;
	struct list_head child_list;
	struct perf_event___67 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___126 *owner;
	struct mutex___127 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___126 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___67 *);
	struct callback_head callback_head;
	struct pid_namespace___72 *ns;
	u64 id;
	perf_overflow_handler_t___67 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___57 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___67 ftrace_ops;
	struct perf_cgroup___67 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___126;

struct lruvec___126 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___126 *zone;
};

struct pglist_data___126;

struct zone___126 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___126 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___126 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___126 {
	struct zone___126 *zone;
	int zone_idx;
};

struct zonelist___126 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___126 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___126 {
	struct zone___126 node_zones[4];
	struct zonelist___126 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___126 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___92;

struct x86_io_apic_ops___92 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___92 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___92;

struct irq_data___92 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___92 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___102;

struct dev_pm_ops___102 {
	int (*prepare)(struct device___102 *);
	void (*complete)(struct device___102 *);
	int (*suspend)(struct device___102 *);
	int (*resume)(struct device___102 *);
	int (*freeze)(struct device___102 *);
	int (*thaw)(struct device___102 *);
	int (*poweroff)(struct device___102 *);
	int (*restore)(struct device___102 *);
	int (*suspend_late)(struct device___102 *);
	int (*resume_early)(struct device___102 *);
	int (*freeze_late)(struct device___102 *);
	int (*thaw_early)(struct device___102 *);
	int (*poweroff_late)(struct device___102 *);
	int (*restore_early)(struct device___102 *);
	int (*suspend_noirq)(struct device___102 *);
	int (*resume_noirq)(struct device___102 *);
	int (*freeze_noirq)(struct device___102 *);
	int (*thaw_noirq)(struct device___102 *);
	int (*poweroff_noirq)(struct device___102 *);
	int (*restore_noirq)(struct device___102 *);
	int (*runtime_suspend)(struct device___102 *);
	int (*runtime_resume)(struct device___102 *);
	int (*runtime_idle)(struct device___102 *);
};

struct device_type___102;

struct bus_type___102;

struct device_driver___102;

struct dev_pm_domain___102;

struct class___102;

struct attribute_group___95;

struct device_rh___102;

struct device___102 {
	struct device___102 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___102 *type;
	struct mutex___127 mutex;
	struct bus_type___102 *bus;
	struct device_driver___102 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___102 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___102 *class;
	const struct attribute_group___95 **groups;
	void (*release)(struct device___102 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___102 *device_rh;
};

struct dev_pm_info_rh___102 {
	void (*set_latency_tolerance)(struct device___102 *, s32);
};

struct dev_pm_domain___102 {
	struct dev_pm_ops___102 ops;
};

struct smp_ops___126 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___126 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___126 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___126 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___113;

struct memcg_cache_params___113;

struct kmem_cache___113 {
	struct kmem_cache_cpu___113 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___113 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___126;

struct address_space_operations___126;

struct address_space___126 {
	struct inode___126 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___127 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___126 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___29 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___126;

struct path___126 {
	struct vfsmount *mnt;
	struct dentry___126 *dentry;
};

struct fown_struct___72 {
	rwlock_t lock;
	struct pid___72 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___126;

struct file___126 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___126 f_path;
	struct inode___126 *f_inode;
	const struct file_operations___126 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___72 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___126 *f_mapping;
	struct mutex___127 f_pos_lock;
};

struct vm_operations_struct___113;

struct vm_area_struct___131 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___131 *vm_next;
	struct vm_area_struct___131 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___131 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___113 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___126 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___110;

struct vm_operations_struct___113 {
	void (*open)(struct vm_area_struct___131 *);
	void (*close)(struct vm_area_struct___131 *);
	int (*fault)(struct vm_area_struct___131 *, struct vm_fault___110 *);
	int (*page_mkwrite)(struct vm_area_struct___131 *, struct vm_fault___110 *);
	int (*access)(struct vm_area_struct___131 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___131 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___131 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___131 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___131 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___126 {
	struct task_struct___126 *task;
	struct core_thread___126 *next;
};

struct core_state___126 {
	atomic_t nr_threads;
	struct core_thread___126 dumper;
	struct completion startup;
};

struct upid___72 {
	int nr;
	struct pid_namespace___72 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___72 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___126 *child_reaper;
	struct kmem_cache___113 *pid_cachep;
	unsigned int level;
	struct pid_namespace___72 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___126 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___72 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___72 numbers[1];
};

struct nsproxy___74 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___72 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___126 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___126 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___126 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___72 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___72 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___127 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___21;

struct bio_list___20 {
	struct bio___21 *head;
	struct bio___21 *tail;
};

struct bdi_writeback___29 {
	struct backing_dev_info___29 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___29 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___29 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___102 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___126 *debug_dir;
	struct dentry___126 *debug_stats;
};

struct io_cq___20;

struct io_context___20 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___20 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___87;

struct css_set___87 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___87 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___67 {
	struct pmu___67 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___127 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___126 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___67 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct request_queue___20;

struct io_cq___20 {
	struct request_queue___20 *q;
	struct io_context___20 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___113 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct request_list___20 {
	struct request_queue___20 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___20(struct request_queue___20 *);

typedef void make_request_fn___20(struct request_queue___20 *, struct bio___21 *);

struct request___20;

typedef int prep_rq_fn___20(struct request_queue___20 *, struct request___20 *);

struct bvec_merge_data___20;

struct bio_vec___21;

typedef int merge_bvec_fn___20(struct request_queue___20 *, struct bvec_merge_data___20 *, struct bio_vec___21 *);

typedef void softirq_done_fn___20(struct request___20 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___20(struct request___20 *);

typedef int dma_drain_needed_fn___20(struct request___20 *);

typedef int lld_busy_fn___20(struct request_queue___20 *);

struct bsg_class_device___20 {
	struct device___102 *class_dev;
	struct device___102 *parent;
	int minor;
	struct request_queue___20 *queue;
	struct kref ref;
	void (*release)(struct device___102 *);
};

typedef void unprep_rq_fn___20(struct request_queue___20 *, struct request___20 *);

struct elevator_queue___20;

struct blk_queue_tag___20;

struct bio_set___21;

struct request_queue___20 {
	struct list_head queue_head;
	struct request___20 *last_merge;
	struct elevator_queue___20 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___20 root_rl;
	request_fn_proc___20 *request_fn;
	make_request_fn___20 *make_request_fn;
	prep_rq_fn___20 *prep_rq_fn;
	merge_bvec_fn___20 *merge_bvec_fn;
	softirq_done_fn___20 *softirq_done_fn;
	rq_timed_out_fn___20 *rq_timed_out_fn;
	dma_drain_needed_fn___20 *dma_drain_needed;
	lld_busy_fn___20 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___20 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___29 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___6 kobj;
	struct kobject___6 mq_kobj;
	struct device___102 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___20 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___20 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___127 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___20 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___20 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___21 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

enum {
	IOPRIO_WHO_PROCESS = 1,
	IOPRIO_WHO_PGRP = 2,
	IOPRIO_WHO_USER = 3,
};

struct bin_attribute___95;

struct attribute_group___95 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___95 **bin_attrs;
};

struct bin_attribute___95 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___126 *, struct kobject___6 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___126 *, struct kobject___6 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	int (*mmap)(struct file___126 *, struct kobject___6 *, struct bin_attribute___95 *, struct vm_area_struct___131 *);
};

struct kmem_cache_cpu___113 {
	void **freelist;
	long unsigned int tid;
	struct page___126 *page;
	struct page___126 *partial;
};

struct memcg_cache_params___113 {
	bool is_root_cache;
	union {
		struct kmem_cache___113 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___113 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___102 *, char *);
	ssize_t (*store)(struct bus_type___102 *, const char *, size_t);
};

struct device_attribute___102;

struct driver_attribute___102;

struct bus_type___102 {
	const char *name;
	const char *dev_name;
	struct device___102 *dev_root;
	struct bus_attribute___102 *bus_attrs;
	struct device_attribute___102 *dev_attrs;
	struct driver_attribute___102 *drv_attrs;
	const struct attribute_group___95 **bus_groups;
	const struct attribute_group___95 **dev_groups;
	const struct attribute_group___95 **drv_groups;
	int (*match)(struct device___102 *, struct device_driver___102 *);
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	int (*probe)(struct device___102 *);
	int (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*online)(struct device___102 *);
	int (*offline)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct device___102 *, struct device_attribute___102 *, char *);
	ssize_t (*store)(struct device___102 *, struct device_attribute___102 *, const char *, size_t);
};

struct driver_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___102 *, char *);
	ssize_t (*store)(struct device_driver___102 *, const char *, size_t);
};

struct device_driver___102 {
	const char *name;
	struct bus_type___102 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___102 *);
	int (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	const struct attribute_group___95 **groups;
	const struct dev_pm_ops___102 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___102 {
	const char *name;
	const struct attribute_group___95 **groups;
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
};

struct class_attribute___102;

struct class___102 {
	const char *name;
	struct module *owner;
	struct class_attribute___102 *class_attrs;
	struct device_attribute___102 *dev_attrs;
	const struct attribute_group___95 **dev_groups;
	struct bin_attribute___95 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *);
	void (*class_release)(struct class___102 *);
	void (*dev_release)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
	struct subsys_private *p;
};

struct class_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct class___102 *, struct class_attribute___102 *, char *);
	ssize_t (*store)(struct class___102 *, struct class_attribute___102 *, const char *, size_t);
	const void * (*namespace)(struct class___102 *, const struct class_attribute___102 *);
};

struct device_rh___102 {
	struct dev_pm_info_rh___102 power;
};

struct dentry_operations___126;

struct super_block___126;

struct dentry___126 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___126 *d_parent;
	struct qstr d_name;
	struct inode___126 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___126 *d_op;
	struct super_block___126 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___126;

struct file_lock___126;

struct dquot___126;

struct block_device___126;

struct inode___126 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___126 *i_op;
	struct super_block___126 *i_sb;
	struct address_space___126 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___127 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___126 *i_fop;
	struct file_lock___126 *i_flock;
	struct address_space___126 i_data;
	struct dquot___126 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___126 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___126 {
	int (*d_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_hash)(const struct dentry___126 *, struct qstr *);
	int (*d_compare)(const struct dentry___126 *, const struct dentry___126 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___126 *);
	void (*d_release)(struct dentry___126 *);
	void (*d_prune)(struct dentry___126 *);
	void (*d_iput)(struct dentry___126 *, struct inode___126 *);
	char * (*d_dname)(struct dentry___126 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___126 *);
	int (*d_manage)(struct dentry___126 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___126;

struct mem_dqinfo___126 {
	struct quota_format_type___126 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___126;

struct quota_info___126 {
	unsigned int flags;
	struct mutex___127 dqio_mutex;
	struct mutex___127 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___126 *files[2];
	struct mem_dqinfo___126 info[2];
	const struct quota_format_ops___126 *ops[2];
};

struct file_system_type___126;

struct super_operations___126;

struct dquot_operations___126;

struct quotactl_ops___126;

struct xattr_handler___87;

struct super_block___126 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___126 *s_type;
	const struct super_operations___126 *s_op;
	const struct dquot_operations___126 *dq_op;
	const struct quotactl_ops___126 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___126 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___87 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___126 *s_bdev;
	struct backing_dev_info___29 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___126 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___127 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___126 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___21(struct bio___21 *, int);

struct bio_vec___21 {
	struct page___126 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___21;

struct bio___21 {
	sector_t bi_sector;
	struct bio___21 *bi_next;
	struct block_device___126 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___21 *bi_end_io;
	void *bi_private;
	struct io_context___20 *bi_ioc;
	struct cgroup_subsys_state___87 *bi_css;
	struct bio_integrity_payload___21 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___21 *bi_io_vec;
	struct bio_set___21 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___21 bi_inline_vecs[0];
};

struct hd_struct___21;

struct gendisk___21;

struct block_device___126 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___126 *bd_inode;
	struct super_block___126 *bd_super;
	struct mutex___127 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___126 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___21 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___21 *bd_disk;
	struct request_queue___20 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___127 bd_fsfreeze_mutex;
};

struct cgroup___87;

struct cgroup_subsys_state___87 {
	struct cgroup___87 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___21 {
	struct bio___21 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___21 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___21 *bip_vec;
	struct bio_vec___21 bip_inline_vecs[0];
};

struct bio_set___21 {
	struct kmem_cache___113 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___20 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___126 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___126 *ia_file;
};

struct dquot___126 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___127 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___126 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___126 {
	int qf_fmt_id;
	const struct quota_format_ops___126 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___126 *qf_next;
};

struct quota_format_ops___126 {
	int (*check_quota_file)(struct super_block___126 *, int);
	int (*read_file_info)(struct super_block___126 *, int);
	int (*write_file_info)(struct super_block___126 *, int);
	int (*free_file_info)(struct super_block___126 *, int);
	int (*read_dqblk)(struct dquot___126 *);
	int (*commit_dqblk)(struct dquot___126 *);
	int (*release_dqblk)(struct dquot___126 *);
};

struct dquot_operations___126 {
	int (*write_dquot)(struct dquot___126 *);
	struct dquot___126 * (*alloc_dquot)(struct super_block___126 *, int);
	void (*destroy_dquot)(struct dquot___126 *);
	int (*acquire_dquot)(struct dquot___126 *);
	int (*release_dquot)(struct dquot___126 *);
	int (*mark_dirty)(struct dquot___126 *);
	int (*write_info)(struct super_block___126 *, int);
	qsize_t * (*get_reserved_space)(struct inode___126 *);
};

struct quotactl_ops___126 {
	int (*quota_on)(struct super_block___126 *, int, int, struct path___126 *);
	int (*quota_on_meta)(struct super_block___126 *, int, int);
	int (*quota_off)(struct super_block___126 *, int);
	int (*quota_sync)(struct super_block___126 *, int);
	int (*get_info)(struct super_block___126 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___126 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___126 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___126 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___126 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___126 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___126 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___126 *, unsigned int);
};

struct address_space_operations___126 {
	int (*writepage)(struct page___126 *, struct writeback_control *);
	int (*readpage)(struct file___126 *, struct page___126 *);
	int (*writepages)(struct address_space___126 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___126 *);
	int (*readpages)(struct file___126 *, struct address_space___126 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___126 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___126 **, void **);
	int (*write_end)(struct file___126 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___126 *, void *);
	sector_t (*bmap)(struct address_space___126 *, sector_t);
	void (*invalidatepage)(struct page___126 *, long unsigned int);
	int (*releasepage)(struct page___126 *, gfp_t);
	void (*freepage)(struct page___126 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___126 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___126 *, struct page___126 *, struct page___126 *, enum migrate_mode);
	int (*launder_page)(struct page___126 *);
	int (*is_partially_uptodate)(struct page___126 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___126 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___126 *, struct page___126 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___126 *, sector_t *);
	void (*swap_deactivate)(struct file___126 *);
	void (*invalidatepage_range)(struct page___126 *, unsigned int, unsigned int);
};

struct hd_struct___21 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___102 __dev;
	struct kobject___6 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___21;

struct block_device_operations___20;

struct gendisk___21 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___21 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___21 *part_tbl;
	struct hd_struct___21 part0;
	const struct block_device_operations___20 *fops;
	struct request_queue___20 *queue;
	void *private_data;
	int flags;
	struct device___102 *driverfs_dev;
	struct kobject___6 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___2 *integrity;
	int node_id;
};

struct inode_operations___126 {
	struct dentry___126 * (*lookup)(struct inode___126 *, struct dentry___126 *, unsigned int);
	void * (*follow_link)(struct dentry___126 *, struct nameidata *);
	int (*permission)(struct inode___126 *, int);
	struct posix_acl * (*get_acl)(struct inode___126 *, int);
	int (*readlink)(struct dentry___126 *, char *, int);
	void (*put_link)(struct dentry___126 *, struct nameidata *, void *);
	int (*create)(struct inode___126 *, struct dentry___126 *, umode_t, bool);
	int (*link)(struct dentry___126 *, struct inode___126 *, struct dentry___126 *);
	int (*unlink)(struct inode___126 *, struct dentry___126 *);
	int (*symlink)(struct inode___126 *, struct dentry___126 *, const char *);
	int (*mkdir)(struct inode___126 *, struct dentry___126 *, umode_t);
	int (*rmdir)(struct inode___126 *, struct dentry___126 *);
	int (*mknod)(struct inode___126 *, struct dentry___126 *, umode_t, dev_t);
	int (*rename)(struct inode___126 *, struct dentry___126 *, struct inode___126 *, struct dentry___126 *);
	int (*setattr)(struct dentry___126 *, struct iattr___126 *);
	int (*getattr)(struct vfsmount *, struct dentry___126 *, struct kstat *);
	int (*setxattr)(struct dentry___126 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___126 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___126 *, char *, size_t);
	int (*removexattr)(struct dentry___126 *, const char *);
	int (*fiemap)(struct inode___126 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___126 *, struct timespec *, int);
	int (*atomic_open)(struct inode___126 *, struct dentry___126 *, struct file___126 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___80;

struct seq_file___94;

struct file_operations___126 {
	struct module *owner;
	loff_t (*llseek)(struct file___126 *, loff_t, int);
	ssize_t (*read)(struct file___126 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___126 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___126 *, void *, filldir_t);
	unsigned int (*poll)(struct file___126 *, struct poll_table_struct___80 *);
	long int (*unlocked_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___126 *, struct vm_area_struct___131 *);
	int (*open)(struct inode___126 *, struct file___126 *);
	int (*flush)(struct file___126 *, fl_owner_t);
	int (*release)(struct inode___126 *, struct file___126 *);
	int (*fsync)(struct file___126 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___126 *, int);
	int (*lock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*sendpage)(struct file___126 *, struct page___126 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___126 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___126 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___126 *, long int, struct file_lock___126 **, void **);
		struct {
			int (*setlease)(struct file___126 *, long int, struct file_lock___126 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___126 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___94 *, struct file___126 *);
};

struct file_lock_operations___126;

struct lock_manager_operations___126;

struct file_lock___126 {
	struct file_lock___126 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___72 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___126 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___126 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___126 *fl_ops;
	const struct lock_manager_operations___126 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___126 {
	void (*fl_copy_lock)(struct file_lock___126 *, struct file_lock___126 *);
	void (*fl_release_private)(struct file_lock___126 *);
};

struct lock_manager_operations___126 {
	int (*lm_compare_owner)(struct file_lock___126 *, struct file_lock___126 *);
	long unsigned int (*lm_owner_key)(struct file_lock___126 *);
	void (*lm_notify)(struct file_lock___126 *);
	int (*lm_grant)(struct file_lock___126 *, struct file_lock___126 *, int);
	void (*lm_break)(struct file_lock___126 *);
	int (*lm_change)(struct file_lock___126 **, int);
};

struct fasync_struct___126 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___126 *fa_next;
	struct file___126 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___126 {
	const char *name;
	int fs_flags;
	struct dentry___126 * (*mount)(struct file_system_type___126 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___126 *);
	struct module *owner;
	struct file_system_type___126 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___126 {
	struct inode___126 * (*alloc_inode)(struct super_block___126 *);
	void (*destroy_inode)(struct inode___126 *);
	void (*dirty_inode)(struct inode___126 *, int);
	int (*write_inode)(struct inode___126 *, struct writeback_control *);
	int (*drop_inode)(struct inode___126 *);
	void (*evict_inode)(struct inode___126 *);
	void (*put_super)(struct super_block___126 *);
	int (*sync_fs)(struct super_block___126 *, int);
	int (*freeze_fs)(struct super_block___126 *);
	int (*unfreeze_fs)(struct super_block___126 *);
	int (*statfs)(struct dentry___126 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___126 *, int *, char *);
	void (*umount_begin)(struct super_block___126 *);
	int (*show_options)(struct seq_file___94 *, struct dentry___126 *);
	int (*show_devname)(struct seq_file___94 *, struct dentry___126 *);
	int (*show_path)(struct seq_file___94 *, struct dentry___126 *);
	int (*show_stats)(struct seq_file___94 *, struct dentry___126 *);
	ssize_t (*quota_read)(struct super_block___126 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___126 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___126 *);
	int (*bdev_try_to_free_page)(struct super_block___126 *, struct page___126 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___126 *);
	void (*free_cached_objects)(struct super_block___126 *, int);
};

struct xattr_handler___87 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___126 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___126 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___126 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___82)(struct file___126 *, wait_queue_head_t *, struct poll_table_struct___80 *);

struct poll_table_struct___80 {
	poll_queue_proc___82 _qproc;
	long unsigned int _key;
};

struct seq_operations___93;

struct seq_file___94 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___127 lock;
	const struct seq_operations___93 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___21 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___21 *last_lookup;
	struct hd_struct___21 *part[0];
};

struct block_device_operations___20 {
	int (*open)(struct block_device___126 *, fmode_t);
	void (*release)(struct gendisk___21 *, fmode_t);
	int (*ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___126 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___21 *, unsigned int);
	int (*media_changed)(struct gendisk___21 *);
	void (*unlock_native_capacity)(struct gendisk___21 *);
	int (*revalidate_disk)(struct gendisk___21 *);
	int (*getgeo)(struct block_device___126 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___126 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___110 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___126 *page;
};

struct irq_chip___92 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___92 *);
	void (*irq_shutdown)(struct irq_data___92 *);
	void (*irq_enable)(struct irq_data___92 *);
	void (*irq_disable)(struct irq_data___92 *);
	void (*irq_ack)(struct irq_data___92 *);
	void (*irq_mask)(struct irq_data___92 *);
	void (*irq_mask_ack)(struct irq_data___92 *);
	void (*irq_unmask)(struct irq_data___92 *);
	void (*irq_eoi)(struct irq_data___92 *);
	int (*irq_set_affinity)(struct irq_data___92 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___92 *);
	int (*irq_set_type)(struct irq_data___92 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___92 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___92 *);
	void (*irq_bus_sync_unlock)(struct irq_data___92 *);
	void (*irq_cpu_online)(struct irq_data___92 *);
	void (*irq_cpu_offline)(struct irq_data___92 *);
	void (*irq_suspend)(struct irq_data___92 *);
	void (*irq_resume)(struct irq_data___92 *);
	void (*irq_pm_shutdown)(struct irq_data___92 *);
	void (*irq_print_chip)(struct irq_data___92 *, struct seq_file___94 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___92 *, void *);
	long unsigned int flags;
};

typedef void rq_end_io_fn___20(struct request___20 *, int);

struct request___20 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___20 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___21 *bio;
	struct bio___21 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___20 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___20 *saved_end_io;
		} flush;
	};
	struct gendisk___21 *rq_disk;
	struct hd_struct___21 *part;
	long unsigned int start_time;
	struct request_list___20 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___20 *end_io;
	void *end_io_data;
	struct request___20 *next_rq;
};

typedef int elevator_merge_fn___20(struct request_queue___20 *, struct request___20 **, struct bio___21 *);

typedef void elevator_merge_req_fn___20(struct request_queue___20 *, struct request___20 *, struct request___20 *);

typedef void elevator_merged_fn___20(struct request_queue___20 *, struct request___20 *, int);

typedef int elevator_allow_merge_fn___20(struct request_queue___20 *, struct request___20 *, struct bio___21 *);

typedef void elevator_bio_merged_fn___20(struct request_queue___20 *, struct request___20 *, struct bio___21 *);

typedef int elevator_dispatch_fn___20(struct request_queue___20 *, int);

typedef void elevator_add_req_fn___20(struct request_queue___20 *, struct request___20 *);

typedef struct request___20 *elevator_request_list_fn___20(struct request_queue___20 *, struct request___20 *);

typedef void elevator_completed_req_fn___20(struct request_queue___20 *, struct request___20 *);

typedef int elevator_may_queue_fn___20(struct request_queue___20 *, int);

typedef void elevator_init_icq_fn___20(struct io_cq___20 *);

typedef void elevator_exit_icq_fn___20(struct io_cq___20 *);

typedef int elevator_set_req_fn___20(struct request_queue___20 *, struct request___20 *, struct bio___21 *, gfp_t);

typedef void elevator_put_req_fn___20(struct request___20 *);

typedef void elevator_activate_req_fn___20(struct request_queue___20 *, struct request___20 *);

typedef void elevator_deactivate_req_fn___20(struct request_queue___20 *, struct request___20 *);

struct elevator_type___20;

typedef int elevator_init_fn___20(struct request_queue___20 *, struct elevator_type___20 *);

typedef void elevator_exit_fn___20(struct elevator_queue___20 *);

struct elevator_ops___20 {
	elevator_merge_fn___20 *elevator_merge_fn;
	elevator_merged_fn___20 *elevator_merged_fn;
	elevator_merge_req_fn___20 *elevator_merge_req_fn;
	elevator_allow_merge_fn___20 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___20 *elevator_bio_merged_fn;
	elevator_dispatch_fn___20 *elevator_dispatch_fn;
	elevator_add_req_fn___20 *elevator_add_req_fn;
	elevator_activate_req_fn___20 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___20 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___20 *elevator_completed_req_fn;
	elevator_request_list_fn___20 *elevator_former_req_fn;
	elevator_request_list_fn___20 *elevator_latter_req_fn;
	elevator_init_icq_fn___20 *elevator_init_icq_fn;
	elevator_exit_icq_fn___20 *elevator_exit_icq_fn;
	elevator_set_req_fn___20 *elevator_set_req_fn;
	elevator_put_req_fn___20 *elevator_put_req_fn;
	elevator_may_queue_fn___20 *elevator_may_queue_fn;
	elevator_init_fn___20 *elevator_init_fn;
	elevator_exit_fn___20 *elevator_exit_fn;
};

struct elv_fs_entry___20;

struct elevator_type___20 {
	struct kmem_cache___113 *icq_cache;
	struct elevator_ops___20 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___20 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___20 {
	struct elevator_type___20 *type;
	void *elevator_data;
	struct kobject___6 kobj;
	struct mutex___127 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___20 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___20 *, char *);
	ssize_t (*store)(struct elevator_queue___20 *, const char *, size_t);
};

struct bvec_merge_data___20 {
	struct block_device___126 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___20 {
	struct request___20 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___93 {
	void * (*start)(struct seq_file___94 *, loff_t *);
	void (*stop)(struct seq_file___94 *, void *);
	void * (*next)(struct seq_file___94 *, void *, loff_t *);
	int (*show)(struct seq_file___94 *, void *);
};

struct cgroupfs_root___87;

struct cgroup___87 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___87 *parent;
	struct dentry___126 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___87 *subsys[11];
	struct cgroupfs_root___87 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___127 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___87 {
	struct super_block___126 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___87 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___67;

struct pmu___67 {
	struct list_head entry;
	struct device___102 *dev;
	const struct attribute_group___95 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___67 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___67 *);
	void (*pmu_disable)(struct pmu___67 *);
	int (*event_init)(struct perf_event___67 *);
	int (*add)(struct perf_event___67 *, int);
	void (*del)(struct perf_event___67 *, int);
	void (*start)(struct perf_event___67 *, int);
	void (*stop)(struct perf_event___67 *, int);
	void (*read)(struct perf_event___67 *);
	void (*start_txn)(struct pmu___67 *);
	int (*commit_txn)(struct pmu___67 *);
	void (*cancel_txn)(struct pmu___67 *);
	int (*event_idx)(struct perf_event___67 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___67 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___67 *);
};

struct perf_cpu_context___67 {
	struct perf_event_context___67 ctx;
	struct perf_event_context___67 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___67 *unique_pmu;
	struct perf_cgroup___67 *cgrp;
};

struct trace_event_functions___57;

struct trace_event___57 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___57 *funcs;
};

struct ftrace_event_class___57;

struct ftrace_event_call___57 {
	struct list_head list;
	struct ftrace_event_class___57 *class;
	char *name;
	struct trace_event___57 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___67 {
	struct cgroup_subsys_state___87 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___57 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___127 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___57)(struct trace_iterator___57 *, int, struct trace_event___57 *);

struct trace_event_functions___57 {
	trace_print_func___57 trace;
	trace_print_func___57 raw;
	trace_print_func___57 hex;
	trace_print_func___57 binary;
};

struct ftrace_event_class___57 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___57 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___57 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___57 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___57 *);
};

struct syscall_metadata___27 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___57 *enter_event;
	struct ftrace_event_call___57 *exit_event;
};

typedef __u32 nlink_t;

struct page___127;

typedef struct page___127 *pgtable_t___127;

struct address_space___127;

struct kmem_cache___114;

struct page___127 {
	long unsigned int flags;
	struct address_space___127 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___127 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___127 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___114 *slab_cache;
		struct page___127 *first_page;
	};
	long: 64;
};

struct task_struct___127;

struct pv_cpu_ops___127 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___67 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___67 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___127 *);
	void (*end_context_switch)(struct task_struct___127 *);
};

struct mutex___128 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___127 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___123 {
	struct page___127 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___132;

struct fs_struct___12;

struct nsproxy___75;

struct signal_struct___127;

struct task_struct___127 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___127 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___132 *mm;
	struct mm_struct___132 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___127 *real_parent;
	struct task_struct___127 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___127 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___72 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___127 = 0,
		VTIME_USER___127 = 1,
		VTIME_SYS___127 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___67 thread;
	struct fs_struct___12 *fs;
	struct files_struct *files;
	struct nsproxy___75 *nsproxy;
	struct signal_struct___127 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___128 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___123 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___132 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___132 *, struct mm_struct___132 *);
	void (*dup_mmap)(struct mm_struct___132 *, struct mm_struct___132 *);
	void (*exit_mmap)(struct mm_struct___132 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___132 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___132 *);
	void (*pgd_free)(struct mm_struct___132 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___132 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___132 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___132 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___132 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___132 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___132 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___132 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___132 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___132 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___132 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___132 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___128 lock;
	void *vdso;
} mm_context_t___128;

struct xol_area___127;

struct uprobes_state___127 {
	struct xol_area___127 *xol_area;
};

struct vm_area_struct___132;

struct file___127;

struct linux_binfmt___15;

struct core_state___127;

struct mm_struct___132 {
	struct vm_area_struct___132 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___132 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___132 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___15 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___128 context;
	long unsigned int flags;
	struct core_state___127 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___127 *owner;
	struct file___127 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___127 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___127 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___127 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___114;

struct memcg_cache_params___114;

struct kmem_cache___114 {
	struct kmem_cache_cpu___114 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___114 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___127;

struct address_space_operations___127;

struct address_space___127 {
	struct inode___127 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___128 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___127 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___25;

struct dentry___127;

struct path___127 {
	struct vfsmount___25 *mnt;
	struct dentry___127 *dentry;
};

struct file_operations___127;

struct file___127 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___127 f_path;
	struct inode___127 *f_inode;
	const struct file_operations___127 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___72 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___127 *f_mapping;
	struct mutex___128 f_pos_lock;
};

struct vm_area_struct___132 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___132 *vm_next;
	struct vm_area_struct___132 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___132 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___127 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___127 {
	struct task_struct___127 *task;
	struct core_thread___127 *next;
};

struct core_state___127 {
	atomic_t nr_threads;
	struct core_thread___127 dumper;
	struct completion startup;
};

struct linux_binprm___16;

struct coredump_params___15;

struct linux_binfmt___15 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___16 *);
	int (*load_shlib)(struct file___127 *);
	int (*core_dump)(struct coredump_params___15 *);
	long unsigned int min_coredump;
};

struct smp_ops___127 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___127 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___127;

struct lruvec___127 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___127 *zone;
};

struct pglist_data___127;

struct zone___127 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___127 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___127 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___127 {
	struct zone___127 *zone;
	int zone_idx;
};

struct zonelist___127 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___127 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___127 {
	struct zone___127 node_zones[4];
	struct zonelist___127 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___127 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___15;

struct ctl_node___15 {
	struct rb_node node;
	struct ctl_table_header___15 *header;
};

struct ctl_table_root___15;

struct ctl_table_set___15;

struct ctl_dir___15;

struct ctl_table_header___15 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___15 *root;
	struct ctl_table_set___15 *set;
	struct ctl_dir___15 *parent;
	struct ctl_node___15 *node;
};

struct ctl_dir___15 {
	struct ctl_table_header___15 header;
	struct rb_root root;
};

struct ctl_table_set___15 {
	int (*is_seen)(struct ctl_table_set___15 *);
	struct ctl_dir___15 dir;
};

struct ctl_table_root___15 {
	struct ctl_table_set___15 default_set;
	struct ctl_table_set___15 * (*lookup)(struct ctl_table_root___15 *, struct nsproxy___75 *);
	int (*permissions)(struct ctl_table_header___15 *, struct ctl_table *);
};

struct mnt_namespace___4;

struct nsproxy___75 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___4 *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net *net_ns;
};

struct signal_struct___127 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___127 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___127 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___72 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___72 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___128 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___12 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___127 root;
	struct path___127 pwd;
};

struct mount___4;

struct mnt_namespace___4 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___4 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct kmem_cache_cpu___114 {
	void **freelist;
	long unsigned int tid;
	struct page___127 *page;
	struct page___127 *partial;
};

struct memcg_cache_params___114 {
	bool is_root_cache;
	union {
		struct kmem_cache___114 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___114 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct inode_operations___127;

struct super_block___127;

struct file_lock___127;

struct dquot___127;

struct block_device___127;

struct inode___127 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___127 *i_op;
	struct super_block___127 *i_sb;
	struct address_space___127 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___128 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___127 *i_fop;
	struct file_lock___127 *i_flock;
	struct address_space___127 i_data;
	struct dquot___127 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___127 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___127;

struct mem_dqinfo___127 {
	struct quota_format_type___127 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___127;

struct quota_info___127 {
	unsigned int flags;
	struct mutex___128 dqio_mutex;
	struct mutex___128 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___127 *files[2];
	struct mem_dqinfo___127 info[2];
	const struct quota_format_ops___127 *ops[2];
};

struct file_system_type___127;

struct super_operations___127;

struct dquot_operations___127;

struct quotactl_ops___127;

struct dentry_operations___127;

struct super_block___127 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___127 *s_type;
	const struct super_operations___127 *s_op;
	const struct dquot_operations___127 *dq_op;
	const struct quotactl_ops___127 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___127 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___127 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___127 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___128 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___127 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___127 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___127 *d_parent;
	struct qstr d_name;
	struct inode___127 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___127 *d_op;
	struct super_block___127 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct linux_binprm___16 {
	char buf[128];
	struct vm_area_struct___132 *vma;
	long unsigned int vma_pages;
	struct mm_struct___132 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___127 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct seq_operations___94;

struct seq_file___95 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___128 lock;
	const struct seq_operations___94 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vfsmount___25 {
	struct dentry___127 *mnt_root;
	struct super_block___127 *mnt_sb;
	int mnt_flags;
};

struct iattr___127 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___127 *ia_file;
};

struct dentry_operations___127 {
	int (*d_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_hash)(const struct dentry___127 *, struct qstr *);
	int (*d_compare)(const struct dentry___127 *, const struct dentry___127 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___127 *);
	void (*d_release)(struct dentry___127 *);
	void (*d_prune)(struct dentry___127 *);
	void (*d_iput)(struct dentry___127 *, struct inode___127 *);
	char * (*d_dname)(struct dentry___127 *, char *, int);
	struct vfsmount___25 * (*d_automount)(struct path___127 *);
	int (*d_manage)(struct dentry___127 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___127 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___127 *bd_inode;
	struct super_block___127 *bd_super;
	struct mutex___128 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___127 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___128 bd_fsfreeze_mutex;
};

struct dquot___127 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___128 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___127 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___127 {
	int qf_fmt_id;
	const struct quota_format_ops___127 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___127 *qf_next;
};

struct quota_format_ops___127 {
	int (*check_quota_file)(struct super_block___127 *, int);
	int (*read_file_info)(struct super_block___127 *, int);
	int (*write_file_info)(struct super_block___127 *, int);
	int (*free_file_info)(struct super_block___127 *, int);
	int (*read_dqblk)(struct dquot___127 *);
	int (*commit_dqblk)(struct dquot___127 *);
	int (*release_dqblk)(struct dquot___127 *);
};

struct dquot_operations___127 {
	int (*write_dquot)(struct dquot___127 *);
	struct dquot___127 * (*alloc_dquot)(struct super_block___127 *, int);
	void (*destroy_dquot)(struct dquot___127 *);
	int (*acquire_dquot)(struct dquot___127 *);
	int (*release_dquot)(struct dquot___127 *);
	int (*mark_dirty)(struct dquot___127 *);
	int (*write_info)(struct super_block___127 *, int);
	qsize_t * (*get_reserved_space)(struct inode___127 *);
};

struct quotactl_ops___127 {
	int (*quota_on)(struct super_block___127 *, int, int, struct path___127 *);
	int (*quota_on_meta)(struct super_block___127 *, int, int);
	int (*quota_off)(struct super_block___127 *, int);
	int (*quota_sync)(struct super_block___127 *, int);
	int (*get_info)(struct super_block___127 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___127 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___127 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___127 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___127 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___127 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___127 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___127 *, unsigned int);
};

struct address_space_operations___127 {
	int (*writepage)(struct page___127 *, struct writeback_control *);
	int (*readpage)(struct file___127 *, struct page___127 *);
	int (*writepages)(struct address_space___127 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___127 *);
	int (*readpages)(struct file___127 *, struct address_space___127 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___127 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___127 **, void **);
	int (*write_end)(struct file___127 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___127 *, void *);
	sector_t (*bmap)(struct address_space___127 *, sector_t);
	void (*invalidatepage)(struct page___127 *, long unsigned int);
	int (*releasepage)(struct page___127 *, gfp_t);
	void (*freepage)(struct page___127 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___127 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___127 *, struct page___127 *, struct page___127 *, enum migrate_mode);
	int (*launder_page)(struct page___127 *);
	int (*is_partially_uptodate)(struct page___127 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___127 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___127 *, struct page___127 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___127 *, sector_t *);
	void (*swap_deactivate)(struct file___127 *);
	void (*invalidatepage_range)(struct page___127 *, unsigned int, unsigned int);
};

struct inode_operations___127 {
	struct dentry___127 * (*lookup)(struct inode___127 *, struct dentry___127 *, unsigned int);
	void * (*follow_link)(struct dentry___127 *, struct nameidata *);
	int (*permission)(struct inode___127 *, int);
	struct posix_acl * (*get_acl)(struct inode___127 *, int);
	int (*readlink)(struct dentry___127 *, char *, int);
	void (*put_link)(struct dentry___127 *, struct nameidata *, void *);
	int (*create)(struct inode___127 *, struct dentry___127 *, umode_t, bool);
	int (*link)(struct dentry___127 *, struct inode___127 *, struct dentry___127 *);
	int (*unlink)(struct inode___127 *, struct dentry___127 *);
	int (*symlink)(struct inode___127 *, struct dentry___127 *, const char *);
	int (*mkdir)(struct inode___127 *, struct dentry___127 *, umode_t);
	int (*rmdir)(struct inode___127 *, struct dentry___127 *);
	int (*mknod)(struct inode___127 *, struct dentry___127 *, umode_t, dev_t);
	int (*rename)(struct inode___127 *, struct dentry___127 *, struct inode___127 *, struct dentry___127 *);
	int (*setattr)(struct dentry___127 *, struct iattr___127 *);
	int (*getattr)(struct vfsmount___25 *, struct dentry___127 *, struct kstat *);
	int (*setxattr)(struct dentry___127 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___127 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___127 *, char *, size_t);
	int (*removexattr)(struct dentry___127 *, const char *);
	int (*fiemap)(struct inode___127 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___127 *, struct timespec *, int);
	int (*atomic_open)(struct inode___127 *, struct dentry___127 *, struct file___127 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___81;

struct file_operations___127 {
	struct module *owner;
	loff_t (*llseek)(struct file___127 *, loff_t, int);
	ssize_t (*read)(struct file___127 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___127 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___127 *, void *, filldir_t);
	unsigned int (*poll)(struct file___127 *, struct poll_table_struct___81 *);
	long int (*unlocked_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___127 *, struct vm_area_struct___132 *);
	int (*open)(struct inode___127 *, struct file___127 *);
	int (*flush)(struct file___127 *, fl_owner_t);
	int (*release)(struct inode___127 *, struct file___127 *);
	int (*fsync)(struct file___127 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___127 *, int);
	int (*lock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*sendpage)(struct file___127 *, struct page___127 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___127 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___127 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___127 *, long int, struct file_lock___127 **, void **);
		struct {
			int (*setlease)(struct file___127 *, long int, struct file_lock___127 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___127 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___95 *, struct file___127 *);
};

struct fasync_struct___127;

struct file_lock_operations___127;

struct lock_manager_operations___127;

struct file_lock___127 {
	struct file_lock___127 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___72 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___127 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___127 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___127 *fl_ops;
	const struct lock_manager_operations___127 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___127 {
	void (*fl_copy_lock)(struct file_lock___127 *, struct file_lock___127 *);
	void (*fl_release_private)(struct file_lock___127 *);
};

struct lock_manager_operations___127 {
	int (*lm_compare_owner)(struct file_lock___127 *, struct file_lock___127 *);
	long unsigned int (*lm_owner_key)(struct file_lock___127 *);
	void (*lm_notify)(struct file_lock___127 *);
	int (*lm_grant)(struct file_lock___127 *, struct file_lock___127 *, int);
	void (*lm_break)(struct file_lock___127 *);
	int (*lm_change)(struct file_lock___127 **, int);
};

struct fasync_struct___127 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___127 *fa_next;
	struct file___127 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___127 {
	const char *name;
	int fs_flags;
	struct dentry___127 * (*mount)(struct file_system_type___127 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___127 *);
	struct module *owner;
	struct file_system_type___127 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___127 {
	struct inode___127 * (*alloc_inode)(struct super_block___127 *);
	void (*destroy_inode)(struct inode___127 *);
	void (*dirty_inode)(struct inode___127 *, int);
	int (*write_inode)(struct inode___127 *, struct writeback_control *);
	int (*drop_inode)(struct inode___127 *);
	void (*evict_inode)(struct inode___127 *);
	void (*put_super)(struct super_block___127 *);
	int (*sync_fs)(struct super_block___127 *, int);
	int (*freeze_fs)(struct super_block___127 *);
	int (*unfreeze_fs)(struct super_block___127 *);
	int (*statfs)(struct dentry___127 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___127 *, int *, char *);
	void (*umount_begin)(struct super_block___127 *);
	int (*show_options)(struct seq_file___95 *, struct dentry___127 *);
	int (*show_devname)(struct seq_file___95 *, struct dentry___127 *);
	int (*show_path)(struct seq_file___95 *, struct dentry___127 *);
	int (*show_stats)(struct seq_file___95 *, struct dentry___127 *);
	ssize_t (*quota_read)(struct super_block___127 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___127 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___127 *);
	int (*bdev_try_to_free_page)(struct super_block___127 *, struct page___127 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___127 *);
	void (*free_cached_objects)(struct super_block___127 *, int);
};

typedef void (*poll_queue_proc___83)(struct file___127 *, wait_queue_head_t *, struct poll_table_struct___81 *);

struct poll_table_struct___81 {
	poll_queue_proc___83 _qproc;
	long unsigned int _key;
};

struct proc_ns_operations___6 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___127 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___75 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___3 {
	void *ns;
	const struct proc_ns_operations___6 *ns_ops;
};

struct coredump_params___15 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___127 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct proc_dir_entry___2 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___127 *proc_iops;
	const struct file_operations___127 *proc_fops;
	struct proc_dir_entry___2 *next;
	struct proc_dir_entry___2 *parent;
	struct proc_dir_entry___2 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

union proc_op {
	int (*proc_get_link)(struct dentry___127 *, struct path___127 *);
	int (*proc_read)(struct task_struct___127 *, char *);
	int (*proc_show)(struct seq_file___95 *, struct pid_namespace *, struct pid___72 *, struct task_struct___127 *);
};

struct proc_inode {
	struct pid___72 *pid;
	int fd;
	union proc_op op;
	struct proc_dir_entry___2 *pde;
	struct ctl_table_header___15 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___3 ns;
	struct inode___127 vfs_inode;
};

struct seq_operations___94 {
	void * (*start)(struct seq_file___95 *, loff_t *);
	void (*stop)(struct seq_file___95 *, void *);
	void * (*next)(struct seq_file___95 *, void *, loff_t *);
	int (*show)(struct seq_file___95 *, void *);
};

typedef struct poll_table_struct___81 poll_table___13;

struct mountpoint___4;

struct mount___4 {
	struct list_head mnt_hash;
	struct mount___4 *mnt_parent;
	struct dentry___127 *mnt_mountpoint;
	struct vfsmount___25 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___4 *mnt_master;
	struct mnt_namespace___4 *mnt_ns;
	struct mountpoint___4 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___4 {
	struct list_head m_hash;
	struct dentry___127 *m_dentry;
	int m_count;
};

struct proc_mounts___2 {
	struct seq_file___95 m;
	struct mnt_namespace___4 *ns;
	struct path___127 root;
	int (*show)(struct seq_file___95 *, struct vfsmount___25 *);
	void *cached_mount;
	u64 cached_event;
	loff_t cached_index;
};

struct proc_fs_info {
	int flag;
	const char *str;
};

struct bio_pair___2 {
	struct bio___9 bio1;
	struct bio___9 bio2;
	struct bio_vec___9 bv1;
	struct bio_vec___9 bv2;
	struct bio_integrity_payload___9 bip1;
	struct bio_integrity_payload___9 bip2;
	struct bio_vec___9 iv1;
	struct bio_vec___9 iv2;
	atomic_t cnt;
	int error;
};

struct fsnotify_group___3;

struct fsnotify_mark___3;

struct fsnotify_event___3;

struct fsnotify_event_private_data___3;

struct fsnotify_ops___3 {
	bool (*should_send_event)(struct fsnotify_group___3 *, struct inode___115 *, struct fsnotify_mark___3 *, struct fsnotify_mark___3 *, __u32, void *, int);
	int (*handle_event)(struct fsnotify_group___3 *, struct fsnotify_mark___3 *, struct fsnotify_mark___3 *, struct fsnotify_event___3 *);
	void (*free_group_priv)(struct fsnotify_group___3 *);
	void (*freeing_mark)(struct fsnotify_mark___3 *, struct fsnotify_group___3 *);
	void (*free_event_priv)(struct fsnotify_event_private_data___3 *);
};

struct fanotify_group_private_data___3 {
	struct mutex___116 access_mutex;
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	atomic_t bypass_perm;
	int f_flags;
	unsigned int max_marks;
	struct user_struct *user;
};

struct fsnotify_group___3 {
	atomic_t refcnt;
	const struct fsnotify_ops___3 *ops;
	struct mutex___116 notification_mutex;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	struct mutex___116 mark_mutex;
	atomic_t num_marks;
	struct list_head marks_list;
	struct fasync_struct___115 *fsn_fa;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data___3 fanotify_data;
	};
};

struct fsnotify_inode_mark___3 {
	struct inode___115 *inode;
	struct hlist_node i_list;
	struct list_head free_i_list;
};

struct fsnotify_vfsmount_mark___3 {
	struct vfsmount___18 *mnt;
	struct hlist_node m_list;
	struct list_head free_m_list;
};

struct fsnotify_mark___3 {
	__u32 mask;
	atomic_t refcnt;
	struct fsnotify_group___3 *group;
	struct list_head g_list;
	spinlock_t lock;
	union {
		struct fsnotify_inode_mark___3 i;
		struct fsnotify_vfsmount_mark___3 m;
	};
	__u32 ignored_mask;
	unsigned int flags;
	struct list_head destroy_list;
	void (*free_mark)(struct fsnotify_mark___3 *);
};

struct fsnotify_event_holder___3 {
	struct fsnotify_event___3 *event;
	struct list_head event_list;
};

struct fsnotify_event___3 {
	struct fsnotify_event_holder___3 holder;
	spinlock_t lock;
	struct inode___115 *to_tell;
	union {
		struct path___115 path;
		struct inode___115 *inode;
	};
	int data_type;
	atomic_t refcnt;
	__u32 mask;
	u32 sync_cookie;
	const unsigned char *file_name;
	size_t name_len;
	struct pid___65 *tgid;
	__u32 response;
	struct list_head private_data_list;
};

struct fsnotify_event_private_data___3 {
	struct fsnotify_group___3 *group;
	struct list_head event_list;
};

struct file_handle {
	__u32 handle_bytes;
	int handle_type;
	unsigned char f_handle[0];
};

struct fsnotify_group___4;

struct fsnotify_mark___4;

struct fsnotify_event___4;

struct fsnotify_event_private_data___4;

struct fsnotify_ops___4 {
	bool (*should_send_event)(struct fsnotify_group___4 *, struct inode___105 *, struct fsnotify_mark___4 *, struct fsnotify_mark___4 *, __u32, void *, int);
	int (*handle_event)(struct fsnotify_group___4 *, struct fsnotify_mark___4 *, struct fsnotify_mark___4 *, struct fsnotify_event___4 *);
	void (*free_group_priv)(struct fsnotify_group___4 *);
	void (*freeing_mark)(struct fsnotify_mark___4 *, struct fsnotify_group___4 *);
	void (*free_event_priv)(struct fsnotify_event_private_data___4 *);
};

struct fanotify_group_private_data___4 {
	struct mutex___107 access_mutex;
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	atomic_t bypass_perm;
	int f_flags;
	unsigned int max_marks;
	struct user_struct *user;
};

struct fsnotify_group___4 {
	atomic_t refcnt;
	const struct fsnotify_ops___4 *ops;
	struct mutex___107 notification_mutex;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	struct mutex___107 mark_mutex;
	atomic_t num_marks;
	struct list_head marks_list;
	struct fasync_struct___105 *fsn_fa;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data___4 fanotify_data;
	};
};

struct fsnotify_inode_mark___4 {
	struct inode___105 *inode;
	struct hlist_node i_list;
	struct list_head free_i_list;
};

struct fsnotify_vfsmount_mark___4 {
	struct vfsmount___14 *mnt;
	struct hlist_node m_list;
	struct list_head free_m_list;
};

struct fsnotify_mark___4 {
	__u32 mask;
	atomic_t refcnt;
	struct fsnotify_group___4 *group;
	struct list_head g_list;
	spinlock_t lock;
	union {
		struct fsnotify_inode_mark___4 i;
		struct fsnotify_vfsmount_mark___4 m;
	};
	__u32 ignored_mask;
	unsigned int flags;
	struct list_head destroy_list;
	void (*free_mark)(struct fsnotify_mark___4 *);
};

struct fsnotify_event_holder___4 {
	struct fsnotify_event___4 *event;
	struct list_head event_list;
};

struct fsnotify_event___4 {
	struct fsnotify_event_holder___4 holder;
	spinlock_t lock;
	struct inode___105 *to_tell;
	union {
		struct path___105 path;
		struct inode___105 *inode;
	};
	int data_type;
	atomic_t refcnt;
	__u32 mask;
	u32 sync_cookie;
	const unsigned char *file_name;
	size_t name_len;
	struct pid___60 *tgid;
	__u32 response;
	struct list_head private_data_list;
};

struct fsnotify_event_private_data___4 {
	struct fsnotify_group___4 *group;
	struct list_head event_list;
};

struct inotify_inode_mark {
	struct fsnotify_mark___4 fsn_mark;
	int wd;
};

struct mount___5;

struct mnt_namespace___5 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___5 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct mountpoint___5;

struct mount___5 {
	struct list_head mnt_hash;
	struct mount___5 *mnt_parent;
	struct dentry___105 *mnt_mountpoint;
	struct vfsmount___14 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___5 *mnt_master;
	struct mnt_namespace___5 *mnt_ns;
	struct mountpoint___5 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___5 {
	struct list_head m_hash;
	struct dentry___105 *m_dentry;
	int m_count;
};

struct dnotify_struct {
	struct dnotify_struct *dn_next;
	__u32 dn_mask;
	int dn_fd;
	struct file___115 *dn_filp;
	fl_owner_t___6 dn_owner;
};

struct dnotify_mark {
	struct fsnotify_mark___3 fsn_mark;
	struct dnotify_struct *dn;
};

struct inotify_event_private_data {
	struct fsnotify_event_private_data___4 fsnotify_event_priv_data;
	int wd;
};

struct inotify_event {
	__s32 wd;
	__u32 mask;
	__u32 cookie;
	__u32 len;
	char name[0];
};

typedef int (*inotify_path_proc)(struct path___115 *, struct path___115 *);

struct inotify_stackfs {
	struct list_head list;
	struct file_system_type___115 *fs_type;
	inotify_path_proc func;
};

struct inotify_event_private_data___2 {
	struct fsnotify_event_private_data___3 fsnotify_event_priv_data;
	int wd;
};

struct inotify_inode_mark___2 {
	struct fsnotify_mark___3 fsn_mark;
	int wd;
};

struct fanotify_event_metadata {
	__u32 event_len;
	__u8 vers;
	__u8 reserved;
	__u16 metadata_len;
	__u64 mask;
	__s32 fd;
	__s32 pid;
};

struct fanotify_response {
	__s32 fd;
	__u32 response;
};

struct fanotify_response_event {
	struct list_head list;
	__s32 fd;
	struct fsnotify_event___3 *event;
};

struct fd___13 {
	struct file___74 *file;
	unsigned int flags;
};

typedef struct poll_table_struct___44 poll_table___14;

struct syscall_metadata___28 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___27 *enter_event;
	struct ftrace_event_call___27 *exit_event;
};

struct epoll_event {
	__u32 events;
	__u64 data;
} __attribute__((packed));

struct epoll_filefd {
	struct file___74 *file;
	int fd;
} __attribute__((packed));

struct nested_call_node {
	struct list_head llink;
	void *cookie;
	void *ctx;
};

struct nested_calls {
	struct list_head tasks_call_list;
	spinlock_t lock;
};

struct eventpoll;

struct epitem {
	union {
		struct rb_node rbn;
		struct callback_head rcu;
	};
	struct list_head rdllink;
	struct epitem *next;
	struct epoll_filefd ffd;
	int nwait;
	struct list_head pwqlist;
	struct eventpoll *ep;
	struct list_head fllink;
	struct wakeup_source *ws;
	struct epoll_event event;
};

struct eventpoll {
	spinlock_t lock;
	struct mutex___75 mtx;
	wait_queue_head_t wq;
	wait_queue_head_t poll_wait;
	struct list_head rdllist;
	struct rb_root rbr;
	struct epitem *ovflist;
	struct wakeup_source *ws;
	struct user_struct *user;
	struct file___74 *file;
	int visited;
	struct list_head visited_list_link;
};

struct eppoll_entry {
	struct list_head llink;
	struct epitem *base;
	wait_queue_t wait;
	wait_queue_head_t *whead;
};

struct ep_pqueue {
	poll_table___14 pt;
	struct epitem *epi;
};

struct ep_send_events_data {
	int maxevents;
	struct epoll_event *events;
};

struct readyevents_arg {
	struct eventpoll *ep;
	bool locked;
};

typedef struct poll_table_struct___67 poll_table___15;

struct signalfd_siginfo {
	__u32 ssi_signo;
	__s32 ssi_errno;
	__s32 ssi_code;
	__u32 ssi_pid;
	__u32 ssi_uid;
	__s32 ssi_fd;
	__u32 ssi_tid;
	__u32 ssi_band;
	__u32 ssi_overrun;
	__u32 ssi_trapno;
	__s32 ssi_status;
	__s32 ssi_int;
	__u64 ssi_ptr;
	__u64 ssi_utime;
	__u64 ssi_stime;
	__u64 ssi_addr;
	__u16 ssi_addr_lsb;
	__u8 __pad[46];
};

struct signalfd_ctx {
	sigset_t sigmask;
};

struct timerfd_ctx {
	struct hrtimer tmr;
	ktime_t tintv;
	ktime_t moffs;
	wait_queue_head_t wqh;
	u64 ticks;
	int clockid;
	short unsigned int expired;
	short unsigned int settime_flags;
	struct callback_head rcu;
	struct list_head clist;
	bool might_cancel;
};

struct eventfd_ctx___2 {
	struct kref kref;
	wait_queue_head_t wqh;
	__u64 count;
	unsigned int flags;
};

enum userfaultfd_state {
	UFFD_STATE_WAIT_API = 0,
	UFFD_STATE_RUNNING = 1,
};

struct userfaultfd_ctx {
	wait_queue_head_t fault_pending_wqh;
	wait_queue_head_t fault_wqh;
	wait_queue_head_t fd_wqh;
	struct seqcount refile_seq;
	atomic_t refcount;
	unsigned int flags;
	enum userfaultfd_state state;
	bool released;
	struct mm_struct___123 *mm;
};

struct uffd_msg {
	__u8 event;
	__u8 reserved1;
	__u16 reserved2;
	__u32 reserved3;
	union {
		struct {
			__u64 flags;
			__u64 address;
		} pagefault;
		struct {
			__u64 reserved1;
			__u64 reserved2;
			__u64 reserved3;
		} reserved;
	} arg;
};

struct uffdio_api {
	__u64 api;
	__u64 features;
	__u64 ioctls;
};

struct uffdio_range {
	__u64 start;
	__u64 len;
};

struct uffdio_register {
	struct uffdio_range range;
	__u64 mode;
	__u64 ioctls;
};

struct uffdio_copy {
	__u64 dst;
	__u64 src;
	__u64 len;
	__u64 mode;
	__s64 copy;
};

struct uffdio_zeropage {
	struct uffdio_range range;
	__u64 mode;
	__s64 zeropage;
};

struct userfaultfd_wait_queue {
	struct uffd_msg msg;
	wait_queue_t wq;
	struct userfaultfd_ctx *ctx;
};

struct userfaultfd_wake_range {
	long unsigned int start;
	long unsigned int len;
};

typedef __kernel_ulong_t aio_context_t;

enum {
	IOCB_CMD_PREAD = 0,
	IOCB_CMD_PWRITE = 1,
	IOCB_CMD_FSYNC = 2,
	IOCB_CMD_FDSYNC = 3,
	IOCB_CMD_NOOP = 6,
	IOCB_CMD_PREADV = 7,
	IOCB_CMD_PWRITEV = 8,
};

struct iocb {
	__u64 aio_data;
	__u32 aio_key;
	__u32 aio_reserved1;
	__u16 aio_lio_opcode;
	__s16 aio_reqprio;
	__u32 aio_fildes;
	__u64 aio_buf;
	__u64 aio_nbytes;
	__s64 aio_offset;
	__u64 aio_reserved2;
	__u32 aio_flags;
	__u32 aio_resfd;
};

struct buffer_head___5;

struct hrtimer_sleeper___4 {
	struct hrtimer timer;
	struct task_struct___51 *task;
};

struct kioctx {
	atomic_t users;
	atomic_t dead;
	long unsigned int user_id;
	struct hlist_node list;
	unsigned int max_reqs;
	unsigned int nr_events;
	long unsigned int mmap_base;
	long unsigned int mmap_size;
	struct page___50 **ring_pages;
	long int nr_pages;
	struct callback_head callback_head;
	struct work_struct rcu_work;
	long: 64;
	struct {
		atomic_t reqs_active;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		spinlock_t ctx_lock;
		struct list_head active_reqs;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		struct mutex___51 ring_lock;
		wait_queue_head_t wait;
	};
	struct completion *requests_done;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct {
		unsigned int tail;
		unsigned int completed_events;
		spinlock_t completion_lock;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct page___50 *internal_pages[8];
	struct file___50 *aio_ring_file;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct aio_ring {
	unsigned int id;
	unsigned int nr;
	unsigned int head;
	unsigned int tail;
	unsigned int magic;
	unsigned int compat_features;
	unsigned int incompat_features;
	unsigned int header_length;
	struct io_event io_events[0];
};

typedef ssize_t aio_rw_op(struct kiocb___2 *, const struct iovec *, long unsigned int, loff_t);

struct fd___14 {
	struct file___115 *file;
	unsigned int flags;
};

struct ftrace_event_file___21 {
	struct list_head list;
	struct ftrace_event_call___50 *event_call;
	struct dentry___115 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_filelock_lease {
	struct trace_entry ent;
	struct file_lock___115 *fl;
	long unsigned int i_ino;
	dev_t s_dev;
	struct file_lock___115 *fl_next;
	fl_owner_t___6 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	char __data[0];
};

struct ftrace_data_offsets_filelock_lease {};

struct locks_iterator {
	int li_cpu;
	loff_t li_pos;
};

typedef unsigned int __kernel_mode_t;

typedef unsigned int __kernel_uid_t;

typedef unsigned int __kernel_gid_t;

struct page___128;

typedef struct page___128 *pgtable_t___128;

struct address_space___128;

struct kmem_cache___115;

struct page___128 {
	long unsigned int flags;
	struct address_space___128 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___128 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___128 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___115 *slab_cache;
		struct page___128 *first_page;
	};
	long: 64;
};

struct thread_struct___68;

struct task_struct___128;

struct pv_cpu_ops___128 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___68 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___68 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___128 *);
	void (*end_context_switch)(struct task_struct___128 *);
};

struct perf_event___68;

struct thread_struct___68 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___68 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___73;

struct pid_link___73 {
	struct hlist_node node;
	struct pid___73 *pid;
};

struct mutex___129 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___128 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___124 {
	struct page___128 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___133;

struct fs_struct___13;

struct files_struct___9;

struct nsproxy___76;

struct signal_struct___128;

struct css_set___88;

struct perf_event_context___68;

struct task_struct___128 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___128 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___133 *mm;
	struct mm_struct___133 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___128 *real_parent;
	struct task_struct___128 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___128 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___73 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___128 = 0,
		VTIME_USER___128 = 1,
		VTIME_SYS___128 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___68 thread;
	struct fs_struct___13 *fs;
	struct files_struct___9 *files;
	struct nsproxy___76 *nsproxy;
	struct signal_struct___128 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___88 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___68 *perf_event_ctxp[2];
	struct mutex___129 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___124 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___133 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___133 *, struct mm_struct___133 *);
	void (*dup_mmap)(struct mm_struct___133 *, struct mm_struct___133 *);
	void (*exit_mmap)(struct mm_struct___133 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___133 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___133 *);
	void (*pgd_free)(struct mm_struct___133 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___133 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___133 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___133 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___133 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___133 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___133 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___133 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___133 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___133 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___133 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___133 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___129 lock;
	void *vdso;
} mm_context_t___129;

struct xol_area___128;

struct uprobes_state___128 {
	struct xol_area___128 *xol_area;
};

struct vm_area_struct___133;

struct file___128;

struct core_state___128;

struct mm_struct___133 {
	struct vm_area_struct___133 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___133 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___133 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___129 context;
	long unsigned int flags;
	struct core_state___128 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___128 *owner;
	struct file___128 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___128 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___68 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___128 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___128 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___128 *target;
};

typedef void (*perf_overflow_handler_t___68)(struct perf_event___68 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___68;

typedef void (*ftrace_func_t___68)(long unsigned int, long unsigned int, struct ftrace_ops___68 *, struct pt_regs *);

struct ftrace_ops___68 {
	ftrace_func_t___68 func;
	struct ftrace_ops___68 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___129 regex_lock;
};

struct pmu___68;

struct fasync_struct___128;

struct pid_namespace___73;

struct ftrace_event_call___58;

struct perf_cgroup___68;

struct perf_event___68 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___68 *group_leader;
	struct pmu___68 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___68 hw;
	struct perf_event_context___68 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___129 child_mutex;
	struct list_head child_list;
	struct perf_event___68 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___128 *owner;
	struct mutex___129 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___128 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___68 *);
	struct callback_head callback_head;
	struct pid_namespace___73 *ns;
	u64 id;
	perf_overflow_handler_t___68 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___58 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___68 ftrace_ops;
	struct perf_cgroup___68 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___69 {
	struct task_struct___128 *task;
	struct exec_domain___34 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___128;

struct dentry_operations___128;

struct super_block___128;

struct dentry___128 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___128 *d_parent;
	struct qstr d_name;
	struct inode___128 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___128 *d_op;
	struct super_block___128 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___128;

struct address_space___128 {
	struct inode___128 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___129 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___128 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___128;

struct file_operations___128;

struct file_lock___128;

struct dquot___128;

struct block_device___128;

struct inode___128 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___128 *i_op;
	struct super_block___128 *i_sb;
	struct address_space___128 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___129 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___128 *i_fop;
	struct file_lock___128 *i_flock;
	struct address_space___128 i_data;
	struct dquot___128 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___128 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___128;

struct dentry_operations___128 {
	int (*d_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_hash)(const struct dentry___128 *, struct qstr *);
	int (*d_compare)(const struct dentry___128 *, const struct dentry___128 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___128 *);
	void (*d_release)(struct dentry___128 *);
	void (*d_prune)(struct dentry___128 *);
	void (*d_iput)(struct dentry___128 *, struct inode___128 *);
	char * (*d_dname)(struct dentry___128 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___128 *);
	int (*d_manage)(struct dentry___128 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___128;

struct mem_dqinfo___128 {
	struct quota_format_type___128 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___128;

struct quota_info___128 {
	unsigned int flags;
	struct mutex___129 dqio_mutex;
	struct mutex___129 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___128 *files[2];
	struct mem_dqinfo___128 info[2];
	const struct quota_format_ops___128 *ops[2];
};

struct file_system_type___128;

struct super_operations___128;

struct dquot_operations___128;

struct quotactl_ops___128;

struct xattr_handler___88;

struct super_block___128 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___128 *s_type;
	const struct super_operations___128 *s_op;
	const struct dquot_operations___128 *dq_op;
	const struct quotactl_ops___128 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___128 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___88 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___128 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___128 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___129 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___128 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___128 {
	struct vfsmount *mnt;
	struct dentry___128 *dentry;
};

struct upid___73 {
	int nr;
	struct pid_namespace___73 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___73 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___128 *child_reaper;
	struct kmem_cache___115 *pid_cachep;
	unsigned int level;
	struct pid_namespace___73 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___128 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___73 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___73 numbers[1];
};

struct irq_data___93;

struct x86_io_apic_ops___93 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___93 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___93;

struct irq_data___93 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___93 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___103;

struct dev_pm_ops___103 {
	int (*prepare)(struct device___103 *);
	void (*complete)(struct device___103 *);
	int (*suspend)(struct device___103 *);
	int (*resume)(struct device___103 *);
	int (*freeze)(struct device___103 *);
	int (*thaw)(struct device___103 *);
	int (*poweroff)(struct device___103 *);
	int (*restore)(struct device___103 *);
	int (*suspend_late)(struct device___103 *);
	int (*resume_early)(struct device___103 *);
	int (*freeze_late)(struct device___103 *);
	int (*thaw_early)(struct device___103 *);
	int (*poweroff_late)(struct device___103 *);
	int (*restore_early)(struct device___103 *);
	int (*suspend_noirq)(struct device___103 *);
	int (*resume_noirq)(struct device___103 *);
	int (*freeze_noirq)(struct device___103 *);
	int (*thaw_noirq)(struct device___103 *);
	int (*poweroff_noirq)(struct device___103 *);
	int (*restore_noirq)(struct device___103 *);
	int (*runtime_suspend)(struct device___103 *);
	int (*runtime_resume)(struct device___103 *);
	int (*runtime_idle)(struct device___103 *);
};

struct device_type___103;

struct bus_type___103;

struct device_driver___103;

struct dev_pm_domain___103;

struct class___103;

struct attribute_group___96;

struct device_rh___103;

struct device___103 {
	struct device___103 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___103 *type;
	struct mutex___129 mutex;
	struct bus_type___103 *bus;
	struct device_driver___103 *driver;
	void *platform_data;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___103 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___33 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___103 *class;
	const struct attribute_group___96 **groups;
	void (*release)(struct device___103 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___103 *device_rh;
};

struct dev_pm_info_rh___103 {
	void (*set_latency_tolerance)(struct device___103 *, s32);
};

struct dev_pm_domain___103 {
	struct dev_pm_ops___103 ops;
};

struct smp_ops___128 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___128 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___128 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___128 *bd_inode;
	struct super_block___128 *bd_super;
	struct mutex___129 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___128 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___129 bd_fsfreeze_mutex;
};

struct cgroup___88;

struct cgroup_subsys_state___88 {
	struct cgroup___88 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___13;

typedef int kiocb_cancel_fn___13(struct kiocb___13 *, struct io_event *);

struct kiocb___13 {
	atomic_t ki_users;
	struct file___128 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___13 *ki_cancel;
	void (*ki_dtor)(struct kiocb___13 *);
	union {
		void *user;
		struct task_struct___128 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___128 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___128 *ia_file;
};

struct fown_struct___73 {
	rwlock_t lock;
	struct pid___73 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___128 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___128 f_path;
	struct inode___128 *f_inode;
	const struct file_operations___128 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___73 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___128 *f_mapping;
	struct mutex___129 f_pos_lock;
};

struct zone___128;

struct lruvec___128 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___128 *zone;
};

struct pglist_data___128;

struct zone___128 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___128 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___128 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___128 {
	struct zone___128 *zone;
	int zone_idx;
};

struct zonelist___128 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___128 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___128 {
	struct zone___128 node_zones[4];
	struct zonelist___128 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___128 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___128 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___129 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___128 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___128 {
	int qf_fmt_id;
	const struct quota_format_ops___128 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___128 *qf_next;
};

struct quota_format_ops___128 {
	int (*check_quota_file)(struct super_block___128 *, int);
	int (*read_file_info)(struct super_block___128 *, int);
	int (*write_file_info)(struct super_block___128 *, int);
	int (*free_file_info)(struct super_block___128 *, int);
	int (*read_dqblk)(struct dquot___128 *);
	int (*commit_dqblk)(struct dquot___128 *);
	int (*release_dqblk)(struct dquot___128 *);
};

struct dquot_operations___128 {
	int (*write_dquot)(struct dquot___128 *);
	struct dquot___128 * (*alloc_dquot)(struct super_block___128 *, int);
	void (*destroy_dquot)(struct dquot___128 *);
	int (*acquire_dquot)(struct dquot___128 *);
	int (*release_dquot)(struct dquot___128 *);
	int (*mark_dirty)(struct dquot___128 *);
	int (*write_info)(struct super_block___128 *, int);
	qsize_t * (*get_reserved_space)(struct inode___128 *);
};

struct quotactl_ops___128 {
	int (*quota_on)(struct super_block___128 *, int, int, struct path___128 *);
	int (*quota_on_meta)(struct super_block___128 *, int, int);
	int (*quota_off)(struct super_block___128 *, int);
	int (*quota_sync)(struct super_block___128 *, int);
	int (*get_info)(struct super_block___128 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___128 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___128 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___128 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___128 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___128 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___128 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___128 *, unsigned int);
};

struct address_space_operations___128 {
	int (*writepage)(struct page___128 *, struct writeback_control *);
	int (*readpage)(struct file___128 *, struct page___128 *);
	int (*writepages)(struct address_space___128 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___128 *);
	int (*readpages)(struct file___128 *, struct address_space___128 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___128 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___128 **, void **);
	int (*write_end)(struct file___128 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___128 *, void *);
	sector_t (*bmap)(struct address_space___128 *, sector_t);
	void (*invalidatepage)(struct page___128 *, long unsigned int);
	int (*releasepage)(struct page___128 *, gfp_t);
	void (*freepage)(struct page___128 *);
	ssize_t (*direct_IO)(int, struct kiocb___13 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___128 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___128 *, struct page___128 *, struct page___128 *, enum migrate_mode);
	int (*launder_page)(struct page___128 *);
	int (*is_partially_uptodate)(struct page___128 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___128 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___128 *, struct page___128 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___128 *, sector_t *);
	void (*swap_deactivate)(struct file___128 *);
	void (*invalidatepage_range)(struct page___128 *, unsigned int, unsigned int);
};

struct nameidata___13;

struct inode_operations___128 {
	struct dentry___128 * (*lookup)(struct inode___128 *, struct dentry___128 *, unsigned int);
	void * (*follow_link)(struct dentry___128 *, struct nameidata___13 *);
	int (*permission)(struct inode___128 *, int);
	struct posix_acl * (*get_acl)(struct inode___128 *, int);
	int (*readlink)(struct dentry___128 *, char *, int);
	void (*put_link)(struct dentry___128 *, struct nameidata___13 *, void *);
	int (*create)(struct inode___128 *, struct dentry___128 *, umode_t, bool);
	int (*link)(struct dentry___128 *, struct inode___128 *, struct dentry___128 *);
	int (*unlink)(struct inode___128 *, struct dentry___128 *);
	int (*symlink)(struct inode___128 *, struct dentry___128 *, const char *);
	int (*mkdir)(struct inode___128 *, struct dentry___128 *, umode_t);
	int (*rmdir)(struct inode___128 *, struct dentry___128 *);
	int (*mknod)(struct inode___128 *, struct dentry___128 *, umode_t, dev_t);
	int (*rename)(struct inode___128 *, struct dentry___128 *, struct inode___128 *, struct dentry___128 *);
	int (*setattr)(struct dentry___128 *, struct iattr___128 *);
	int (*getattr)(struct vfsmount *, struct dentry___128 *, struct kstat *);
	int (*setxattr)(struct dentry___128 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___128 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___128 *, char *, size_t);
	int (*removexattr)(struct dentry___128 *, const char *);
	int (*fiemap)(struct inode___128 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___128 *, struct timespec *, int);
	int (*atomic_open)(struct inode___128 *, struct dentry___128 *, struct file___128 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___9 *fl_owner_t___9;

struct poll_table_struct___82;

struct seq_file___96;

struct file_operations___128 {
	struct module *owner;
	loff_t (*llseek)(struct file___128 *, loff_t, int);
	ssize_t (*read)(struct file___128 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___128 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___13 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___13 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___128 *, void *, filldir_t);
	unsigned int (*poll)(struct file___128 *, struct poll_table_struct___82 *);
	long int (*unlocked_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___128 *, struct vm_area_struct___133 *);
	int (*open)(struct inode___128 *, struct file___128 *);
	int (*flush)(struct file___128 *, fl_owner_t___9);
	int (*release)(struct inode___128 *, struct file___128 *);
	int (*fsync)(struct file___128 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___13 *, int);
	int (*fasync)(int, struct file___128 *, int);
	int (*lock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*sendpage)(struct file___128 *, struct page___128 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___128 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___128 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___128 *, long int, struct file_lock___128 **, void **);
		struct {
			int (*setlease)(struct file___128 *, long int, struct file_lock___128 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___128 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___96 *, struct file___128 *);
};

struct file_lock_operations___128;

struct lock_manager_operations___128;

struct file_lock___128 {
	struct file_lock___128 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___9 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___73 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___128 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___128 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___128 *fl_ops;
	const struct lock_manager_operations___128 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___9 {
	unsigned int max_fds;
	struct file___128 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___9 {
	atomic_t count;
	struct fdtable___9 *fdt;
	struct fdtable___9 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___128 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___128 {
	void (*fl_copy_lock)(struct file_lock___128 *, struct file_lock___128 *);
	void (*fl_release_private)(struct file_lock___128 *);
};

struct lock_manager_operations___128 {
	int (*lm_compare_owner)(struct file_lock___128 *, struct file_lock___128 *);
	long unsigned int (*lm_owner_key)(struct file_lock___128 *);
	void (*lm_notify)(struct file_lock___128 *);
	int (*lm_grant)(struct file_lock___128 *, struct file_lock___128 *, int);
	void (*lm_break)(struct file_lock___128 *);
	int (*lm_change)(struct file_lock___128 **, int);
};

struct fasync_struct___128 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___128 *fa_next;
	struct file___128 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___128 {
	const char *name;
	int fs_flags;
	struct dentry___128 * (*mount)(struct file_system_type___128 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___128 *);
	struct module *owner;
	struct file_system_type___128 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___128 {
	struct inode___128 * (*alloc_inode)(struct super_block___128 *);
	void (*destroy_inode)(struct inode___128 *);
	void (*dirty_inode)(struct inode___128 *, int);
	int (*write_inode)(struct inode___128 *, struct writeback_control *);
	int (*drop_inode)(struct inode___128 *);
	void (*evict_inode)(struct inode___128 *);
	void (*put_super)(struct super_block___128 *);
	int (*sync_fs)(struct super_block___128 *, int);
	int (*freeze_fs)(struct super_block___128 *);
	int (*unfreeze_fs)(struct super_block___128 *);
	int (*statfs)(struct dentry___128 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___128 *, int *, char *);
	void (*umount_begin)(struct super_block___128 *);
	int (*show_options)(struct seq_file___96 *, struct dentry___128 *);
	int (*show_devname)(struct seq_file___96 *, struct dentry___128 *);
	int (*show_path)(struct seq_file___96 *, struct dentry___128 *);
	int (*show_stats)(struct seq_file___96 *, struct dentry___128 *);
	ssize_t (*quota_read)(struct super_block___128 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___128 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___128 *);
	int (*bdev_try_to_free_page)(struct super_block___128 *, struct page___128 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___128 *);
	void (*free_cached_objects)(struct super_block___128 *, int);
};

struct xattr_handler___88 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___128 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___128 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___128 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___84)(struct file___128 *, wait_queue_head_t *, struct poll_table_struct___82 *);

struct poll_table_struct___82 {
	poll_queue_proc___84 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___114;

struct vm_area_struct___133 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___133 *vm_next;
	struct vm_area_struct___133 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___133 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___114 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___128 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___95;

struct seq_file___96 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___129 lock;
	const struct seq_operations___95 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___13 {
	struct path___128 path;
	struct qstr last;
	struct path___128 root;
	struct inode___128 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___128 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___128 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___115;

struct memcg_cache_params___115;

struct kmem_cache___115 {
	struct kmem_cache_cpu___115 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___6 kobj;
	struct memcg_cache_params___115 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___111;

struct vm_operations_struct___114 {
	void (*open)(struct vm_area_struct___133 *);
	void (*close)(struct vm_area_struct___133 *);
	int (*fault)(struct vm_area_struct___133 *, struct vm_fault___111 *);
	int (*page_mkwrite)(struct vm_area_struct___133 *, struct vm_fault___111 *);
	int (*access)(struct vm_area_struct___133 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___133 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___133 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___133 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___133 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___128 {
	struct task_struct___128 *task;
	struct core_thread___128 *next;
};

struct core_state___128 {
	atomic_t nr_threads;
	struct core_thread___128 dumper;
	struct completion startup;
};

struct nsproxy___76 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___73 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___128 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___128 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___128 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___73 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___73 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___129 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___13 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___128 root;
	struct path___128 pwd;
};

struct css_set___88 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___88 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___68 {
	struct pmu___68 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___129 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___128 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___68 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

typedef u16 __compat_uid_t;

typedef u16 __compat_gid_t;

typedef u16 compat_mode_t;

typedef u32 compat_ino_t;

typedef u16 compat_dev_t;

typedef u16 compat_nlink_t;

typedef s32 compat_daddr_t;

typedef __kernel_fsid_t compat_fsid_t;

struct compat_stat {
	compat_dev_t st_dev;
	u16 __pad1;
	compat_ino_t st_ino;
	compat_mode_t st_mode;
	compat_nlink_t st_nlink;
	__compat_uid_t st_uid;
	__compat_gid_t st_gid;
	compat_dev_t st_rdev;
	u16 __pad2;
	u32 st_size;
	u32 st_blksize;
	u32 st_blocks;
	u32 st_atime;
	u32 st_atime_nsec;
	u32 st_mtime;
	u32 st_mtime_nsec;
	u32 st_ctime;
	u32 st_ctime_nsec;
	u32 __unused4;
	u32 __unused5;
};

struct compat_flock {
	short int l_type;
	short int l_whence;
	compat_off_t l_start;
	compat_off_t l_len;
	compat_pid_t l_pid;
};

struct compat_flock64 {
	short int l_type;
	short int l_whence;
	compat_loff_t l_start;
	compat_loff_t l_len;
	compat_pid_t l_pid;
} __attribute__((packed));

struct compat_statfs {
	int f_type;
	int f_bsize;
	int f_blocks;
	int f_bfree;
	int f_bavail;
	int f_files;
	int f_ffree;
	compat_fsid_t f_fsid;
	int f_namelen;
	int f_frsize;
	int f_flags;
	int f_spare[4];
};

struct compat_utimbuf {
	compat_time_t actime;
	compat_time_t modtime;
};

struct compat_ustat {
	compat_daddr_t f_tfree;
	compat_ino_t f_tinode;
	char f_fname[6];
	char f_fpack[6];
};

struct fd___15 {
	struct file___128 *file;
	unsigned int flags;
};

struct compat_statfs64 {
	__u32 f_type;
	__u32 f_bsize;
	__u64 f_blocks;
	__u64 f_bfree;
	__u64 f_bavail;
	__u64 f_files;
	__u64 f_ffree;
	__kernel_fsid_t f_fsid;
	__u32 f_namelen;
	__u32 f_frsize;
	__u32 f_flags;
	__u32 f_spare[4];
} __attribute__((packed));

struct ncp_mount_data {
	int version;
	unsigned int ncp_fd;
	__kernel_uid_t mounted_uid;
	__kernel_pid_t wdog_pid;
	unsigned char mounted_vol[17];
	unsigned int time_out;
	unsigned int retry_count;
	unsigned int flags;
	__kernel_uid_t uid;
	__kernel_gid_t gid;
	__kernel_mode_t file_mode;
	__kernel_mode_t dir_mode;
};

struct ncp_mount_data_v4 {
	int version;
	long unsigned int flags;
	long unsigned int mounted_uid;
	long int wdog_pid;
	unsigned int ncp_fd;
	unsigned int time_out;
	unsigned int retry_count;
	long unsigned int uid;
	long unsigned int gid;
	long unsigned int file_mode;
	long unsigned int dir_mode;
};

struct nfs_string {
	unsigned int len;
	const char *data;
};

struct nfs4_mount_data {
	int version;
	int flags;
	int rsize;
	int wsize;
	int timeo;
	int retrans;
	int acregmin;
	int acregmax;
	int acdirmin;
	int acdirmax;
	struct nfs_string client_addr;
	struct nfs_string mnt_path;
	struct nfs_string hostname;
	unsigned int host_addrlen;
	struct sockaddr *host_addr;
	int proto;
	int auth_flavourlen;
	int *auth_flavours;
};

struct vm_fault___111 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___128 *page;
};

struct seq_operations___95 {
	void * (*start)(struct seq_file___96 *, loff_t *);
	void (*stop)(struct seq_file___96 *, void *);
	void * (*next)(struct seq_file___96 *, void *, loff_t *);
	int (*show)(struct seq_file___96 *, void *);
};

struct irq_chip___93 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___93 *);
	void (*irq_shutdown)(struct irq_data___93 *);
	void (*irq_enable)(struct irq_data___93 *);
	void (*irq_disable)(struct irq_data___93 *);
	void (*irq_ack)(struct irq_data___93 *);
	void (*irq_mask)(struct irq_data___93 *);
	void (*irq_mask_ack)(struct irq_data___93 *);
	void (*irq_unmask)(struct irq_data___93 *);
	void (*irq_eoi)(struct irq_data___93 *);
	int (*irq_set_affinity)(struct irq_data___93 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___93 *);
	int (*irq_set_type)(struct irq_data___93 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___93 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___93 *);
	void (*irq_bus_sync_unlock)(struct irq_data___93 *);
	void (*irq_cpu_online)(struct irq_data___93 *);
	void (*irq_cpu_offline)(struct irq_data___93 *);
	void (*irq_suspend)(struct irq_data___93 *);
	void (*irq_resume)(struct irq_data___93 *);
	void (*irq_pm_shutdown)(struct irq_data___93 *);
	void (*irq_print_chip)(struct irq_data___93 *, struct seq_file___96 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___93 *, void *);
	long unsigned int flags;
};

struct bin_attribute___96;

struct attribute_group___96 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___96 **bin_attrs;
};

struct bin_attribute___96 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___128 *, struct kobject___6 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___128 *, struct kobject___6 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	int (*mmap)(struct file___128 *, struct kobject___6 *, struct bin_attribute___96 *, struct vm_area_struct___133 *);
};

struct bus_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___103 *, char *);
	ssize_t (*store)(struct bus_type___103 *, const char *, size_t);
};

struct device_attribute___103;

struct driver_attribute___103;

struct bus_type___103 {
	const char *name;
	const char *dev_name;
	struct device___103 *dev_root;
	struct bus_attribute___103 *bus_attrs;
	struct device_attribute___103 *dev_attrs;
	struct driver_attribute___103 *drv_attrs;
	const struct attribute_group___96 **bus_groups;
	const struct attribute_group___96 **dev_groups;
	const struct attribute_group___96 **drv_groups;
	int (*match)(struct device___103 *, struct device_driver___103 *);
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	int (*probe)(struct device___103 *);
	int (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*online)(struct device___103 *);
	int (*offline)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct device___103 *, struct device_attribute___103 *, char *);
	ssize_t (*store)(struct device___103 *, struct device_attribute___103 *, const char *, size_t);
};

struct driver_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___103 *, char *);
	ssize_t (*store)(struct device_driver___103 *, const char *, size_t);
};

struct device_driver___103 {
	const char *name;
	struct bus_type___103 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___103 *);
	int (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	const struct attribute_group___96 **groups;
	const struct dev_pm_ops___103 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___103 {
	const char *name;
	const struct attribute_group___96 **groups;
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
};

struct class_attribute___103;

struct class___103 {
	const char *name;
	struct module *owner;
	struct class_attribute___103 *class_attrs;
	struct device_attribute___103 *dev_attrs;
	const struct attribute_group___96 **dev_groups;
	struct bin_attribute___96 *dev_bin_attrs;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *);
	void (*class_release)(struct class___103 *);
	void (*dev_release)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
	struct subsys_private *p;
};

struct class_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct class___103 *, struct class_attribute___103 *, char *);
	ssize_t (*store)(struct class___103 *, struct class_attribute___103 *, const char *, size_t);
	const void * (*namespace)(struct class___103 *, const struct class_attribute___103 *);
};

struct device_rh___103 {
	struct dev_pm_info_rh___103 power;
};

struct kmem_cache_cpu___115 {
	void **freelist;
	long unsigned int tid;
	struct page___128 *page;
	struct page___128 *partial;
};

struct memcg_cache_params___115 {
	bool is_root_cache;
	union {
		struct kmem_cache___115 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___115 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___88;

struct cgroup___88 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___88 *parent;
	struct dentry___128 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___88 *subsys[11];
	struct cgroupfs_root___88 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___129 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___88 {
	struct super_block___128 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___88 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___68;

struct pmu___68 {
	struct list_head entry;
	struct device___103 *dev;
	const struct attribute_group___96 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___68 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___68 *);
	void (*pmu_disable)(struct pmu___68 *);
	int (*event_init)(struct perf_event___68 *);
	int (*add)(struct perf_event___68 *, int);
	void (*del)(struct perf_event___68 *, int);
	void (*start)(struct perf_event___68 *, int);
	void (*stop)(struct perf_event___68 *, int);
	void (*read)(struct perf_event___68 *);
	void (*start_txn)(struct pmu___68 *);
	int (*commit_txn)(struct pmu___68 *);
	void (*cancel_txn)(struct pmu___68 *);
	int (*event_idx)(struct perf_event___68 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___68 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___68 *);
};

struct perf_cpu_context___68 {
	struct perf_event_context___68 ctx;
	struct perf_event_context___68 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___68 *unique_pmu;
	struct perf_cgroup___68 *cgrp;
};

struct trace_event_functions___58;

struct trace_event___58 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___58 *funcs;
};

struct ftrace_event_class___58;

struct ftrace_event_call___58 {
	struct list_head list;
	struct ftrace_event_class___58 *class;
	char *name;
	struct trace_event___58 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___68 {
	struct cgroup_subsys_state___88 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___58 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___129 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___58)(struct trace_iterator___58 *, int, struct trace_event___58 *);

struct trace_event_functions___58 {
	trace_print_func___58 trace;
	trace_print_func___58 raw;
	trace_print_func___58 hex;
	trace_print_func___58 binary;
};

struct ftrace_event_class___58 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___58 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___58 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___58 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___58 *);
};

struct tlb_state___34 {
	struct mm_struct___133 *active_mm;
	int state;
};

struct compat_ncp_mount_data {
	compat_int_t version;
	compat_uint_t ncp_fd;
	__compat_uid_t mounted_uid;
	compat_pid_t wdog_pid;
	unsigned char mounted_vol[17];
	compat_uint_t time_out;
	compat_uint_t retry_count;
	compat_uint_t flags;
	__compat_uid_t uid;
	__compat_gid_t gid;
	compat_mode_t file_mode;
	compat_mode_t dir_mode;
};

struct compat_ncp_mount_data_v4 {
	compat_int_t version;
	compat_ulong_t flags;
	compat_ulong_t mounted_uid;
	compat_long_t wdog_pid;
	compat_uint_t ncp_fd;
	compat_uint_t time_out;
	compat_uint_t retry_count;
	compat_ulong_t uid;
	compat_ulong_t gid;
	compat_ulong_t file_mode;
	compat_ulong_t dir_mode;
};

struct compat_nfs_string {
	compat_uint_t len;
	compat_uptr_t data;
};

struct compat_nfs4_mount_data_v1 {
	compat_int_t version;
	compat_int_t flags;
	compat_int_t rsize;
	compat_int_t wsize;
	compat_int_t timeo;
	compat_int_t retrans;
	compat_int_t acregmin;
	compat_int_t acregmax;
	compat_int_t acdirmin;
	compat_int_t acdirmax;
	struct compat_nfs_string client_addr;
	struct compat_nfs_string mnt_path;
	struct compat_nfs_string hostname;
	compat_uint_t host_addrlen;
	compat_uptr_t host_addr;
	compat_int_t proto;
	compat_int_t auth_flavourlen;
	compat_uptr_t auth_flavours;
};

struct compat_old_linux_dirent {
	compat_ulong_t d_ino;
	compat_ulong_t d_offset;
	short unsigned int d_namlen;
	char d_name[1];
};

struct compat_readdir_callback {
	struct compat_old_linux_dirent *dirent;
	int result;
};

struct compat_linux_dirent {
	compat_ulong_t d_ino;
	compat_ulong_t d_off;
	short unsigned int d_reclen;
	char d_name[1];
};

struct compat_getdents_callback {
	struct compat_linux_dirent *current_dir;
	struct compat_linux_dirent *previous;
	int count;
	int error;
};

struct compat_getdents_callback64 {
	struct linux_dirent64 *current_dir;
	struct linux_dirent64 *previous;
	int count;
	int error;
};

struct compat_sel_arg_struct {
	compat_ulong_t n;
	compat_uptr_t inp;
	compat_uptr_t outp;
	compat_uptr_t exp;
	compat_uptr_t tvp;
};

struct page___129;

typedef struct page___129 *pgtable_t___129;

struct address_space___129;

struct kmem_cache___116;

struct page___129 {
	long unsigned int flags;
	struct address_space___129 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___129 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___129 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___116 *slab_cache;
		struct page___129 *first_page;
	};
	long: 64;
};

struct thread_struct___69;

struct task_struct___129;

struct pv_cpu_ops___129 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___69 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___69 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___129 *);
	void (*end_context_switch)(struct task_struct___129 *);
};

struct perf_event___69;

struct thread_struct___69 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___69 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___74;

struct pid_link___74 {
	struct hlist_node node;
	struct pid___74 *pid;
};

struct mutex___130 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___129 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___125 {
	struct page___129 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___134;

struct nsproxy___77;

struct signal_struct___129;

struct bio_list___21;

struct backing_dev_info___30;

struct io_context___21;

struct css_set___89;

struct perf_event_context___69;

struct task_struct___129 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___129 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___134 *mm;
	struct mm_struct___134 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___129 *real_parent;
	struct task_struct___129 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___129 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___74 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___129 = 0,
		VTIME_USER___129 = 1,
		VTIME_SYS___129 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___69 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___77 *nsproxy;
	struct signal_struct___129 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___21 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___30 *backing_dev_info;
	struct io_context___21 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___89 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___69 *perf_event_ctxp[2];
	struct mutex___130 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___125 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___134 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___134 *, struct mm_struct___134 *);
	void (*dup_mmap)(struct mm_struct___134 *, struct mm_struct___134 *);
	void (*exit_mmap)(struct mm_struct___134 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___134 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___134 *);
	void (*pgd_free)(struct mm_struct___134 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___134 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___134 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___134 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___134 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___134 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___134 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___134 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___134 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___134 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___134 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___134 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___130 lock;
	void *vdso;
} mm_context_t___130;

struct xol_area___129;

struct uprobes_state___129 {
	struct xol_area___129 *xol_area;
};

struct vm_area_struct___134;

struct file___129;

struct core_state___129;

struct mm_struct___134 {
	struct vm_area_struct___134 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___134 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___134 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___130 context;
	long unsigned int flags;
	struct core_state___129 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___129 *owner;
	struct file___129 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___129 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___69 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___129 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___129 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___129 *target;
};

typedef void (*perf_overflow_handler_t___69)(struct perf_event___69 *, struct perf_sample_data___2 *, struct pt_regs *);

struct ftrace_ops___69;

typedef void (*ftrace_func_t___69)(long unsigned int, long unsigned int, struct ftrace_ops___69 *, struct pt_regs *);

struct ftrace_ops___69 {
	ftrace_func_t___69 func;
	struct ftrace_ops___69 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___130 regex_lock;
};

struct pmu___69;

struct fasync_struct___129;

struct pid_namespace___74;

struct ftrace_event_call___59;

struct perf_cgroup___69;

struct perf_event___69 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___69 *group_leader;
	struct pmu___69 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___69 hw;
	struct perf_event_context___69 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___130 child_mutex;
	struct list_head child_list;
	struct perf_event___69 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___129 *owner;
	struct mutex___130 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___129 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___69 *);
	struct callback_head callback_head;
	struct pid_namespace___74 *ns;
	u64 id;
	perf_overflow_handler_t___69 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___59 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___69 ftrace_ops;
	struct perf_cgroup___69 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___70 {
	struct task_struct___129 *task;
	struct exec_domain___34 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct sock___8;

struct kobj_ns_type_operations___7 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___8 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___7;

struct net___16;

struct sock_common___7 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___7 *skc_prot;
	struct net___16 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___12;

struct sk_buff_head___9 {
	struct sk_buff___12 *next;
	struct sk_buff___12 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___8;

struct socket_wq___7;

struct dst_entry___7;

struct socket___7;

struct cg_proto___7;

struct sock___8 {
	struct sock_common___7 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___9 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___12 *head;
		struct sk_buff___12 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___8 *sk_filter;
	struct socket_wq___7 *sk_wq;
	struct sk_buff_head___9 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___7 *sk_rx_dst;
	struct dst_entry___7 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___9 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___9 sk_error_queue;
	struct proto___7 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___74 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___7 *sk_socket;
	void *sk_user_data;
	struct page_frag___125 sk_frag;
	struct sk_buff___12 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___7 *sk_cgrp;
	void (*sk_state_change)(struct sock___8 *);
	void (*sk_data_ready)(struct sock___8 *, int);
	void (*sk_write_space)(struct sock___8 *);
	void (*sk_error_report)(struct sock___8 *);
	int (*sk_backlog_rcv)(struct sock___8 *, struct sk_buff___12 *);
	void (*sk_destruct)(struct sock___8 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct kobject___7;

struct bin_attribute___97;

struct attribute_group___97 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___97 **bin_attrs;
};

struct kset___7;

struct kobj_type___7;

struct kobject___7 {
	const char *name;
	struct list_head entry;
	struct kobject___7 *parent;
	struct kset___7 *kset;
	struct kobj_type___7 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct bin_attribute___97 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___129 *, struct kobject___7 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___129 *, struct kobject___7 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	int (*mmap)(struct file___129 *, struct kobject___7 *, struct bin_attribute___97 *, struct vm_area_struct___134 *);
};

struct dentry___129;

struct path___129 {
	struct vfsmount *mnt;
	struct dentry___129 *dentry;
};

struct fown_struct___74 {
	rwlock_t lock;
	struct pid___74 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___129;

struct file_operations___129;

struct file___129 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___129 f_path;
	struct inode___129 *f_inode;
	const struct file_operations___129 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___74 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___129 *f_mapping;
	struct mutex___130 f_pos_lock;
};

struct vm_operations_struct___115;

struct vm_area_struct___134 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___134 *vm_next;
	struct vm_area_struct___134 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___134 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___115 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___129 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___7 {
	ssize_t (*show)(struct kobject___7 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___7 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___7 *, const struct attribute *);
};

struct kset_uevent_ops___7;

struct kset___7 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___7 kobj;
	const struct kset_uevent_ops___7 *uevent_ops;
};

struct kobj_type___7 {
	void (*release)(struct kobject___7 *);
	const struct sysfs_ops___7 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___7 *);
	const void * (*namespace)(struct kobject___7 *);
};

struct kset_uevent_ops___7 {
	int (* const filter)(struct kset___7 *, struct kobject___7 *);
	const char * (* const name)(struct kset___7 *, struct kobject___7 *);
	int (* const uevent)(struct kset___7 *, struct kobject___7 *, struct kobj_uevent_env *);
};

struct device___104;

struct dev_pm_ops___104 {
	int (*prepare)(struct device___104 *);
	void (*complete)(struct device___104 *);
	int (*suspend)(struct device___104 *);
	int (*resume)(struct device___104 *);
	int (*freeze)(struct device___104 *);
	int (*thaw)(struct device___104 *);
	int (*poweroff)(struct device___104 *);
	int (*restore)(struct device___104 *);
	int (*suspend_late)(struct device___104 *);
	int (*resume_early)(struct device___104 *);
	int (*freeze_late)(struct device___104 *);
	int (*thaw_early)(struct device___104 *);
	int (*poweroff_late)(struct device___104 *);
	int (*restore_early)(struct device___104 *);
	int (*suspend_noirq)(struct device___104 *);
	int (*resume_noirq)(struct device___104 *);
	int (*freeze_noirq)(struct device___104 *);
	int (*thaw_noirq)(struct device___104 *);
	int (*poweroff_noirq)(struct device___104 *);
	int (*restore_noirq)(struct device___104 *);
	int (*runtime_suspend)(struct device___104 *);
	int (*runtime_resume)(struct device___104 *);
	int (*runtime_idle)(struct device___104 *);
};

struct dev_pm_qos___12;

struct dev_pm_info___12 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___12 *qos;
};

struct dma_map_ops___34;

struct dev_archdata___34 {
	struct dma_map_ops___34 *dma_ops;
	void *iommu;
};

struct device_type___104;

struct bus_type___104;

struct device_driver___104;

struct dev_pm_domain___104;

struct device_node___6;

struct class___104;

struct device_rh___104;

struct device___104 {
	struct device___104 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___104 *type;
	struct mutex___130 mutex;
	struct bus_type___104 *bus;
	struct device_driver___104 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___104 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___34 archdata;
	struct device_node___6 *of_node;
	struct acpi_dev_node___9 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___104 *class;
	const struct attribute_group___97 **groups;
	void (*release)(struct device___104 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___104 *device_rh;
};

struct dev_pm_qos_request___12;

struct dev_pm_qos___12 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___12 *latency_req;
	struct dev_pm_qos_request___12 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___12 *latency_tolerance_req;
};

struct dev_pm_info_rh___104 {
	void (*set_latency_tolerance)(struct device___104 *, s32);
};

struct dev_pm_domain___104 {
	struct dev_pm_ops___104 ops;
};

struct zone___129;

struct lruvec___129 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___129 *zone;
};

struct pglist_data___129;

struct zone___129 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___129 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___129 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___129 {
	struct zone___129 *zone;
	int zone_idx;
};

struct zonelist___129 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___129 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___129 {
	struct zone___129 node_zones[4];
	struct zonelist___129 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___129 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___94;

struct x86_io_apic_ops___94 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___94 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___94;

struct irq_data___94 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___94 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct property___6;

struct device_node___6 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___6 *properties;
	struct property___6 *deadprops;
	struct device_node___6 *parent;
	struct device_node___6 *child;
	struct device_node___6 *sibling;
	struct device_node___6 *next;
	struct device_node___6 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___7 kobj;
};

struct smp_ops___129 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___129 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___34 {
	void * (*alloc)(struct device___104 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___104 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___104 *, struct vm_area_struct___134 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___104 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___104 *, struct page___129 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___104 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___104 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___104 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___104 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___104 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___104 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___104 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___104 *, dma_addr_t);
	int (*dma_supported)(struct device___104 *, u64);
	int (*set_dma_mask)(struct device___104 *, u64);
	int is_phys;
};

struct bus_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___104 *, char *);
	ssize_t (*store)(struct bus_type___104 *, const char *, size_t);
};

struct device_attribute___104;

struct driver_attribute___104;

struct bus_type___104 {
	const char *name;
	const char *dev_name;
	struct device___104 *dev_root;
	struct bus_attribute___104 *bus_attrs;
	struct device_attribute___104 *dev_attrs;
	struct driver_attribute___104 *drv_attrs;
	const struct attribute_group___97 **bus_groups;
	const struct attribute_group___97 **dev_groups;
	const struct attribute_group___97 **drv_groups;
	int (*match)(struct device___104 *, struct device_driver___104 *);
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	int (*probe)(struct device___104 *);
	int (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*online)(struct device___104 *);
	int (*offline)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct device___104 *, struct device_attribute___104 *, char *);
	ssize_t (*store)(struct device___104 *, struct device_attribute___104 *, const char *, size_t);
};

struct driver_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___104 *, char *);
	ssize_t (*store)(struct device_driver___104 *, const char *, size_t);
};

struct device_driver___104 {
	const char *name;
	struct bus_type___104 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___104 *);
	int (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	const struct attribute_group___97 **groups;
	const struct dev_pm_ops___104 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___104 {
	const char *name;
	const struct attribute_group___97 **groups;
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
};

struct class_attribute___104;

struct class___104 {
	const char *name;
	struct module *owner;
	struct class_attribute___104 *class_attrs;
	struct device_attribute___104 *dev_attrs;
	const struct attribute_group___97 **dev_groups;
	struct bin_attribute___97 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *);
	void (*class_release)(struct class___104 *);
	void (*dev_release)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
	struct subsys_private *p;
};

struct class_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct class___104 *, struct class_attribute___104 *, char *);
	ssize_t (*store)(struct class___104 *, struct class_attribute___104 *, const char *, size_t);
	const void * (*namespace)(struct class___104 *, const struct class_attribute___104 *);
};

struct device_rh___104 {
	struct dev_pm_info_rh___104 power;
};

struct dentry_operations___129;

struct super_block___129;

struct dentry___129 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___129 *d_parent;
	struct qstr d_name;
	struct inode___129 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___129 *d_op;
	struct super_block___129 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___129;

struct address_space___129 {
	struct inode___129 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___130 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___129 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___30 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___129;

struct file_lock___129;

struct dquot___129;

struct block_device___129;

struct cdev___37;

struct inode___129 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___129 *i_op;
	struct super_block___129 *i_sb;
	struct address_space___129 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___130 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___129 *i_fop;
	struct file_lock___129 *i_flock;
	struct address_space___129 i_data;
	struct dquot___129 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___129 *i_bdev;
		struct cdev___37 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___129 {
	int (*d_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_hash)(const struct dentry___129 *, struct qstr *);
	int (*d_compare)(const struct dentry___129 *, const struct dentry___129 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___129 *);
	void (*d_release)(struct dentry___129 *);
	void (*d_prune)(struct dentry___129 *);
	void (*d_iput)(struct dentry___129 *, struct inode___129 *);
	char * (*d_dname)(struct dentry___129 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___129 *);
	int (*d_manage)(struct dentry___129 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___129;

struct mem_dqinfo___129 {
	struct quota_format_type___129 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___129;

struct quota_info___129 {
	unsigned int flags;
	struct mutex___130 dqio_mutex;
	struct mutex___130 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___129 *files[2];
	struct mem_dqinfo___129 info[2];
	const struct quota_format_ops___129 *ops[2];
};

struct file_system_type___129;

struct super_operations___129;

struct dquot_operations___129;

struct quotactl_ops___129;

struct xattr_handler___89;

struct super_block___129 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___129 *s_type;
	const struct super_operations___129 *s_op;
	const struct dquot_operations___129 *dq_op;
	const struct quotactl_ops___129 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___129 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___89 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___129 *s_bdev;
	struct backing_dev_info___30 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___129 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___130 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___129 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___74 {
	int nr;
	struct pid_namespace___74 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___74 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___129 *child_reaper;
	struct kmem_cache___116 *pid_cachep;
	unsigned int level;
	struct pid_namespace___74 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___129 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___74 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___74 numbers[1];
};

struct bio___22;

typedef void bio_end_io_t___22(struct bio___22 *, int);

struct bio_vec___22 {
	struct page___129 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___89;

struct bio_integrity_payload___22;

struct bio_set___22;

struct bio___22 {
	sector_t bi_sector;
	struct bio___22 *bi_next;
	struct block_device___129 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___22 *bi_end_io;
	void *bi_private;
	struct io_context___21 *bi_ioc;
	struct cgroup_subsys_state___89 *bi_css;
	struct bio_integrity_payload___22 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___22 *bi_io_vec;
	struct bio_set___22 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	struct bio_vec___22 bi_inline_vecs[0];
};

struct hd_struct___22;

struct gendisk___22;

struct request_queue___21;

struct block_device___129 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___129 *bd_inode;
	struct super_block___129 *bd_super;
	struct mutex___130 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___129 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___22 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___22 *bd_disk;
	struct request_queue___21 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___130 bd_fsfreeze_mutex;
};

struct io_cq___21;

struct io_context___21 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___21 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___89;

struct cgroup_subsys_state___89 {
	struct cgroup___89 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___22 {
	struct bio___22 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___22 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___22 *bip_vec;
	struct bio_vec___22 bip_inline_vecs[0];
};

struct bio_list___21 {
	struct bio___22 *head;
	struct bio___22 *tail;
};

struct bio_set___22 {
	struct kmem_cache___116 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___21 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct kiocb___14;

typedef int kiocb_cancel_fn___14(struct kiocb___14 *, struct io_event *);

struct kiocb___14 {
	atomic_t ki_users;
	struct file___129 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___14 *ki_cancel;
	void (*ki_dtor)(struct kiocb___14 *);
	union {
		void *user;
		struct task_struct___129 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___129 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___129 *ia_file;
};

struct dquot___129 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___130 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___129 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___129 {
	int qf_fmt_id;
	const struct quota_format_ops___129 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___129 *qf_next;
};

struct quota_format_ops___129 {
	int (*check_quota_file)(struct super_block___129 *, int);
	int (*read_file_info)(struct super_block___129 *, int);
	int (*write_file_info)(struct super_block___129 *, int);
	int (*free_file_info)(struct super_block___129 *, int);
	int (*read_dqblk)(struct dquot___129 *);
	int (*commit_dqblk)(struct dquot___129 *);
	int (*release_dqblk)(struct dquot___129 *);
};

struct dquot_operations___129 {
	int (*write_dquot)(struct dquot___129 *);
	struct dquot___129 * (*alloc_dquot)(struct super_block___129 *, int);
	void (*destroy_dquot)(struct dquot___129 *);
	int (*acquire_dquot)(struct dquot___129 *);
	int (*release_dquot)(struct dquot___129 *);
	int (*mark_dirty)(struct dquot___129 *);
	int (*write_info)(struct super_block___129 *, int);
	qsize_t * (*get_reserved_space)(struct inode___129 *);
};

struct quotactl_ops___129 {
	int (*quota_on)(struct super_block___129 *, int, int, struct path___129 *);
	int (*quota_on_meta)(struct super_block___129 *, int, int);
	int (*quota_off)(struct super_block___129 *, int);
	int (*quota_sync)(struct super_block___129 *, int);
	int (*get_info)(struct super_block___129 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___129 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___129 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___129 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___129 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___129 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___129 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___129 *, unsigned int);
};

struct address_space_operations___129 {
	int (*writepage)(struct page___129 *, struct writeback_control *);
	int (*readpage)(struct file___129 *, struct page___129 *);
	int (*writepages)(struct address_space___129 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___129 *);
	int (*readpages)(struct file___129 *, struct address_space___129 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___129 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___129 **, void **);
	int (*write_end)(struct file___129 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___129 *, void *);
	sector_t (*bmap)(struct address_space___129 *, sector_t);
	void (*invalidatepage)(struct page___129 *, long unsigned int);
	int (*releasepage)(struct page___129 *, gfp_t);
	void (*freepage)(struct page___129 *);
	ssize_t (*direct_IO)(int, struct kiocb___14 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___129 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___129 *, struct page___129 *, struct page___129 *, enum migrate_mode);
	int (*launder_page)(struct page___129 *);
	int (*is_partially_uptodate)(struct page___129 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___129 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___129 *, struct page___129 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___129 *, sector_t *);
	void (*swap_deactivate)(struct file___129 *);
	void (*invalidatepage_range)(struct page___129 *, unsigned int, unsigned int);
};

struct bdi_writeback___30 {
	struct backing_dev_info___30 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___30 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___30 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___104 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___129 *debug_dir;
	struct dentry___129 *debug_stats;
};

struct hd_struct___22 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___104 __dev;
	struct kobject___7 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___22;

struct block_device_operations___21;

struct blk_integrity___3;

struct gendisk___22 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___22 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___22 *part_tbl;
	struct hd_struct___22 part0;
	const struct block_device_operations___21 *fops;
	struct request_queue___21 *queue;
	void *private_data;
	int flags;
	struct device___104 *driverfs_dev;
	struct kobject___7 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___21 {
	struct request_queue___21 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___21(struct request_queue___21 *);

typedef void make_request_fn___21(struct request_queue___21 *, struct bio___22 *);

struct request___21;

typedef int prep_rq_fn___21(struct request_queue___21 *, struct request___21 *);

struct bvec_merge_data___21;

typedef int merge_bvec_fn___21(struct request_queue___21 *, struct bvec_merge_data___21 *, struct bio_vec___22 *);

typedef void softirq_done_fn___21(struct request___21 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___21(struct request___21 *);

typedef int dma_drain_needed_fn___21(struct request___21 *);

typedef int lld_busy_fn___21(struct request_queue___21 *);

struct bsg_class_device___21 {
	struct device___104 *class_dev;
	struct device___104 *parent;
	int minor;
	struct request_queue___21 *queue;
	struct kref ref;
	void (*release)(struct device___104 *);
};

typedef void unprep_rq_fn___21(struct request_queue___21 *, struct request___21 *);

struct elevator_queue___21;

struct blk_queue_tag___21;

struct request_queue___21 {
	struct list_head queue_head;
	struct request___21 *last_merge;
	struct elevator_queue___21 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___21 root_rl;
	request_fn_proc___21 *request_fn;
	make_request_fn___21 *make_request_fn;
	prep_rq_fn___21 *prep_rq_fn;
	merge_bvec_fn___21 *merge_bvec_fn;
	softirq_done_fn___21 *softirq_done_fn;
	rq_timed_out_fn___21 *rq_timed_out_fn;
	dma_drain_needed_fn___21 *dma_drain_needed;
	lld_busy_fn___21 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___21 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___30 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___7 kobj;
	struct kobject___7 mq_kobj;
	struct device___104 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___21 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___2 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___21 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___130 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___21 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___21 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___22 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___37 {
	struct kobject___7 kobj;
	struct module *owner;
	const struct file_operations___129 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___129 {
	struct dentry___129 * (*lookup)(struct inode___129 *, struct dentry___129 *, unsigned int);
	void * (*follow_link)(struct dentry___129 *, struct nameidata *);
	int (*permission)(struct inode___129 *, int);
	struct posix_acl * (*get_acl)(struct inode___129 *, int);
	int (*readlink)(struct dentry___129 *, char *, int);
	void (*put_link)(struct dentry___129 *, struct nameidata *, void *);
	int (*create)(struct inode___129 *, struct dentry___129 *, umode_t, bool);
	int (*link)(struct dentry___129 *, struct inode___129 *, struct dentry___129 *);
	int (*unlink)(struct inode___129 *, struct dentry___129 *);
	int (*symlink)(struct inode___129 *, struct dentry___129 *, const char *);
	int (*mkdir)(struct inode___129 *, struct dentry___129 *, umode_t);
	int (*rmdir)(struct inode___129 *, struct dentry___129 *);
	int (*mknod)(struct inode___129 *, struct dentry___129 *, umode_t, dev_t);
	int (*rename)(struct inode___129 *, struct dentry___129 *, struct inode___129 *, struct dentry___129 *);
	int (*setattr)(struct dentry___129 *, struct iattr___129 *);
	int (*getattr)(struct vfsmount *, struct dentry___129 *, struct kstat *);
	int (*setxattr)(struct dentry___129 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___129 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___129 *, char *, size_t);
	int (*removexattr)(struct dentry___129 *, const char *);
	int (*fiemap)(struct inode___129 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___129 *, struct timespec *, int);
	int (*atomic_open)(struct inode___129 *, struct dentry___129 *, struct file___129 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___83;

struct seq_file___97;

struct file_operations___129 {
	struct module *owner;
	loff_t (*llseek)(struct file___129 *, loff_t, int);
	ssize_t (*read)(struct file___129 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___129 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___14 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___14 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___129 *, void *, filldir_t);
	unsigned int (*poll)(struct file___129 *, struct poll_table_struct___83 *);
	long int (*unlocked_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___129 *, struct vm_area_struct___134 *);
	int (*open)(struct inode___129 *, struct file___129 *);
	int (*flush)(struct file___129 *, fl_owner_t);
	int (*release)(struct inode___129 *, struct file___129 *);
	int (*fsync)(struct file___129 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___14 *, int);
	int (*fasync)(int, struct file___129 *, int);
	int (*lock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*sendpage)(struct file___129 *, struct page___129 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___129 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___129 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___129 *, long int, struct file_lock___129 **, void **);
		struct {
			int (*setlease)(struct file___129 *, long int, struct file_lock___129 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___129 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___97 *, struct file___129 *);
};

struct file_lock_operations___129;

struct lock_manager_operations___129;

struct file_lock___129 {
	struct file_lock___129 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___74 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___129 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___129 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___129 *fl_ops;
	const struct lock_manager_operations___129 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___129 {
	void (*fl_copy_lock)(struct file_lock___129 *, struct file_lock___129 *);
	void (*fl_release_private)(struct file_lock___129 *);
};

struct lock_manager_operations___129 {
	int (*lm_compare_owner)(struct file_lock___129 *, struct file_lock___129 *);
	long unsigned int (*lm_owner_key)(struct file_lock___129 *);
	void (*lm_notify)(struct file_lock___129 *);
	int (*lm_grant)(struct file_lock___129 *, struct file_lock___129 *, int);
	void (*lm_break)(struct file_lock___129 *);
	int (*lm_change)(struct file_lock___129 **, int);
};

struct fasync_struct___129 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___129 *fa_next;
	struct file___129 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___129 {
	const char *name;
	int fs_flags;
	struct dentry___129 * (*mount)(struct file_system_type___129 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___129 *);
	struct module *owner;
	struct file_system_type___129 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___129 {
	struct inode___129 * (*alloc_inode)(struct super_block___129 *);
	void (*destroy_inode)(struct inode___129 *);
	void (*dirty_inode)(struct inode___129 *, int);
	int (*write_inode)(struct inode___129 *, struct writeback_control *);
	int (*drop_inode)(struct inode___129 *);
	void (*evict_inode)(struct inode___129 *);
	void (*put_super)(struct super_block___129 *);
	int (*sync_fs)(struct super_block___129 *, int);
	int (*freeze_fs)(struct super_block___129 *);
	int (*unfreeze_fs)(struct super_block___129 *);
	int (*statfs)(struct dentry___129 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___129 *, int *, char *);
	void (*umount_begin)(struct super_block___129 *);
	int (*show_options)(struct seq_file___97 *, struct dentry___129 *);
	int (*show_devname)(struct seq_file___97 *, struct dentry___129 *);
	int (*show_path)(struct seq_file___97 *, struct dentry___129 *);
	int (*show_stats)(struct seq_file___97 *, struct dentry___129 *);
	ssize_t (*quota_read)(struct super_block___129 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___129 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___129 *);
	int (*bdev_try_to_free_page)(struct super_block___129 *, struct page___129 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___129 *);
	void (*free_cached_objects)(struct super_block___129 *, int);
};

struct xattr_handler___89 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___129 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___129 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___129 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___85)(struct file___129 *, wait_queue_head_t *, struct poll_table_struct___83 *);

struct poll_table_struct___83 {
	poll_queue_proc___85 _qproc;
	long unsigned int _key;
};

struct seq_operations___96;

struct seq_file___97 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___130 lock;
	const struct seq_operations___96 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___129 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___129 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___116;

struct memcg_cache_params___116;

struct kmem_cache___116 {
	struct kmem_cache_cpu___116 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___116 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___112;

struct vm_operations_struct___115 {
	void (*open)(struct vm_area_struct___134 *);
	void (*close)(struct vm_area_struct___134 *);
	int (*fault)(struct vm_area_struct___134 *, struct vm_fault___112 *);
	int (*page_mkwrite)(struct vm_area_struct___134 *, struct vm_fault___112 *);
	int (*access)(struct vm_area_struct___134 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___134 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___134 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___134 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___134 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___129 {
	struct task_struct___129 *task;
	struct core_thread___129 *next;
};

struct core_state___129 {
	atomic_t nr_threads;
	struct core_thread___129 dumper;
	struct completion startup;
};

struct ctl_table_header___16;

struct ctl_node___16 {
	struct rb_node node;
	struct ctl_table_header___16 *header;
};

struct ctl_table_root___16;

struct ctl_table_set___16;

struct ctl_dir___16;

struct ctl_table_header___16 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___16 *root;
	struct ctl_table_set___16 *set;
	struct ctl_dir___16 *parent;
	struct ctl_node___16 *node;
};

struct ctl_dir___16 {
	struct ctl_table_header___16 header;
	struct rb_root root;
};

struct ctl_table_set___16 {
	int (*is_seen)(struct ctl_table_set___16 *);
	struct ctl_dir___16 dir;
};

struct ctl_table_root___16 {
	struct ctl_table_set___16 default_set;
	struct ctl_table_set___16 * (*lookup)(struct ctl_table_root___16 *, struct nsproxy___77 *);
	int (*permissions)(struct ctl_table_header___16 *, struct ctl_table *);
};

struct nsproxy___77 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___74 *pid_ns;
	struct net___16 *net_ns;
};

struct tty_struct___11;

struct signal_struct___129 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___129 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___129 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___74 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___74 *tty_old_pgrp;
	int leader;
	struct tty_struct___11 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___130 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___11;

struct tty_operations___11;

struct tty_ldisc___11;

struct tty_port___11;

struct tty_struct___11 {
	int magic;
	struct kref kref;
	struct device___104 *dev;
	struct tty_driver___11 *driver;
	const struct tty_operations___11 *ops;
	int index;
	struct mutex___130 ldisc_mutex;
	struct tty_ldisc___11 *ldisc;
	struct mutex___130 atomic_write_lock;
	struct mutex___130 legacy_mutex;
	struct mutex___130 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___74 *pgrp;
	struct pid___74 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___11 *link;
	struct fasync_struct___129 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___11 *port;
	struct ld_semaphore ldisc_sem;
};

struct css_set___89 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___89 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___69 {
	struct pmu___69 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___130 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___129 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___69 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

typedef u32 compat_caddr_t;

struct dev_pm_qos_request___12 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___104 *dev;
};

struct vm_fault___112 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___129 *page;
};

struct socket_wq___7 {
	wait_queue_head_t wait;
	struct fasync_struct___129 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___7;

struct socket___7 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___7 *wq;
	struct file___129 *file;
	struct sock___8 *sk;
	const struct proto_ops___7 *ops;
};

struct proto_ops___7 {
	int family;
	struct module *owner;
	int (*release)(struct socket___7 *);
	int (*bind)(struct socket___7 *, struct sockaddr *, int);
	int (*connect)(struct socket___7 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___7 *, struct socket___7 *);
	int (*accept)(struct socket___7 *, struct socket___7 *, int);
	int (*getname)(struct socket___7 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___129 *, struct socket___7 *, struct poll_table_struct___83 *);
	int (*ioctl)(struct socket___7 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___7 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___7 *, int);
	int (*shutdown)(struct socket___7 *, int);
	int (*setsockopt)(struct socket___7 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___7 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___7 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___7 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___14 *, struct socket___7 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___14 *, struct socket___7 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___129 *, struct socket___7 *, struct vm_area_struct___134 *);
	ssize_t (*sendpage)(struct socket___7 *, struct page___129 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___7 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___8 *, int);
		struct {
			void (*set_peek_off)(struct sock___8 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___15 {
	struct ctl_table_header___16 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___15 {
	struct mutex___130 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___15 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___16 *ctl;
};

struct netns_ipv4___15 {
	struct ctl_table_header___16 *forw_hdr;
	struct ctl_table_header___16 *frags_hdr;
	struct ctl_table_header___16 *ipv4_hdr;
	struct ctl_table_header___16 *route_hdr;
	struct ctl_table_header___16 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___8 *fibnl;
	struct sock___8 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___15 {
	struct ctl_table_header___16 *hdr;
	struct ctl_table_header___16 *route_hdr;
	struct ctl_table_header___16 *icmp_hdr;
	struct ctl_table_header___16 *frags_hdr;
	struct ctl_table_header___16 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___10;

struct neighbour___7;

struct dst_ops___15 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___15 *);
	struct dst_entry___7 * (*check)(struct dst_entry___7 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___7 *);
	unsigned int (*mtu)(const struct dst_entry___7 *);
	u32 * (*cow_metrics)(struct dst_entry___7 *, long unsigned int);
	void (*destroy)(struct dst_entry___7 *);
	void (*ifdown)(struct dst_entry___7 *, struct net_device___10 *, int);
	struct dst_entry___7 * (*negative_advice)(struct dst_entry___7 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___7 *, struct sock___8 *, struct sk_buff___12 *, u32);
	void (*redirect)(struct dst_entry___7 *, struct sock___8 *, struct sk_buff___12 *);
	int (*local_out)(struct sk_buff___12 *);
	struct neighbour___7 * (*neigh_lookup)(const struct dst_entry___7 *, struct sk_buff___12 *, const void *);
	struct kmem_cache___116 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___15 {
	struct netns_sysctl_ipv6___15 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___15 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___8 **icmp_sk;
	struct sock___8 *ndisc_sk;
	struct sock___8 *tcp_sk;
	struct sock___8 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___15 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___16 *sysctl_header;
	struct sock___8 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___7 {
	struct sock___8 *v4_ctl_sk;
	struct sock___8 *v6_ctl_sk;
};

struct netns_nf___15 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___16 *nf_log_dir_header;
};

struct nf_proto_net___15 {
	struct ctl_table_header___16 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___15 {
	struct nf_proto_net___15 pn;
	unsigned int timeout;
};

struct nf_tcp_net___15 {
	struct nf_proto_net___15 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___15 {
	struct nf_proto_net___15 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___15 {
	struct nf_proto_net___15 pn;
	unsigned int timeout;
};

struct nf_ip_net___15 {
	struct nf_generic_net___15 generic;
	struct nf_tcp_net___15 tcp;
	struct nf_udp_net___15 udp;
	struct nf_icmp_net___15 icmp;
	struct nf_icmp_net___15 icmpv6;
};

struct netns_ct___15 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___16 *sysctl_header;
	struct ctl_table_header___16 *acct_sysctl_header;
	struct ctl_table_header___16 *tstamp_sysctl_header;
	struct ctl_table_header___16 *event_sysctl_header;
	struct ctl_table_header___16 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___116 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___15 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___15 {
	struct netns_sysctl_ipv6___15 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___15 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___8 *nlsk;
	struct sock___8 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___16 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___15 xfrm4_dst_ops;
	struct dst_ops___15 xfrm6_dst_ops;
};

struct net___16 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___16 sysctls;
	struct sock___8 *rtnl;
	struct sock___8 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___10 *loopback_dev;
	struct netns_core___15 core;
	struct netns_mib mib;
	struct netns_packet___15 packet;
	struct netns_unix___15 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___15 ipv4;
	struct netns_ipv6___15 ipv6;
	struct netns_sctp___15 sctp;
	struct netns_dccp___7 dccp;
	struct netns_nf___15 nf;
	struct netns_xt xt;
	struct netns_ct___15 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___15 nf_frag;
	struct sock___8 *nfnl;
	struct sock___8 *nfnl_stash;
	struct sk_buff_head___9 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___15 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___8 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___8 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___130 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___130 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___116 {
	void **freelist;
	long unsigned int tid;
	struct page___129 *page;
	struct page___129 *partial;
};

struct memcg_cache_params___116 {
	bool is_root_cache;
	union {
		struct kmem_cache___116 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___116 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___8 {
	atomic_t use;
	unsigned int mask;
	struct net_device___10 *physindev;
	struct net_device___10 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___8(struct sk_buff___12 **);

struct net_device_ops___8;

struct ethtool_ops___8;

struct header_ops___8;

struct netdev_rx_queue___8;

struct netdev_queue___8;

struct rtnl_link_ops___7;

struct dcbnl_rtnl_ops___8;

struct net_device___10 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___8 *netdev_ops;
	const struct ethtool_ops___8 *ethtool_ops;
	const struct header_ops___8 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___7 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___8 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___8 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___8 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___8 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___8 = 0,
		NETREG_REGISTERED___8 = 1,
		NETREG_UNREGISTERING___8 = 2,
		NETREG_UNREGISTERED___8 = 3,
		NETREG_RELEASED___8 = 4,
		NETREG_DUMMY___8 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___8 = 0,
		RTNL_LINK_INITIALIZING___8 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___10 *);
	struct netpoll_info *npinfo;
	struct net___16 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___104 dev;
	const struct attribute_group___97 *sysfs_groups[4];
	const struct rtnl_link_ops___7 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___8 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___12 {
	struct sk_buff___12 *next;
	struct sk_buff___12 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___8 *sk;
	struct net_device___10 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___12 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___8 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___8 {
	int (*get_settings)(struct net_device___10 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___10 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___10 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___10 *);
	void (*get_regs)(struct net_device___10 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___10 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___10 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___10 *);
	void (*set_msglevel)(struct net_device___10 *, u32);
	int (*nway_reset)(struct net_device___10 *);
	u32 (*get_link)(struct net_device___10 *);
	int (*get_eeprom_len)(struct net_device___10 *);
	int (*get_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___10 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___10 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___10 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___10 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___10 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___10 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___10 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___10 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___10 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___10 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___10 *);
	void (*complete)(struct net_device___10 *);
	u32 (*get_priv_flags)(struct net_device___10 *);
	int (*set_priv_flags)(struct net_device___10 *, u32);
	int (*get_sset_count)(struct net_device___10 *, int);
	int (*get_rxnfc)(struct net_device___10 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___10 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___10 *, struct ethtool_flash *);
	int (*reset)(struct net_device___10 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___10 *);
	int (*get_rxfh_indir)(struct net_device___10 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___10 *, const u32 *);
	void (*get_channels)(struct net_device___10 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___10 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___10 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___10 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___10 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___10 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___10 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___10 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___10 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___10 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___10 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___10 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___7 {
	struct callback_head callback_head;
	struct dst_entry___7 *child;
	struct net_device___10 *dev;
	struct dst_ops___15 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___7 *path;
	struct dst_entry___7 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___12 *);
	union {
		int (*output)(struct sock___8 *, struct sk_buff___12 *);
		struct {
			int (*output)(struct sk_buff___12 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___7 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___7;

struct neigh_parms___7;

struct neigh_ops___7;

struct neighbour___7 {
	struct neighbour___7 *next;
	struct neigh_table___7 *tbl;
	struct neigh_parms___7 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___9 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___7 *, struct sk_buff___12 *);
	const struct neigh_ops___7 *ops;
	struct callback_head rcu;
	struct net_device___10 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___15 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___12 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___12 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___16 *, struct dst_entry___7 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___12 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___12 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___94 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___94 *);
	void (*irq_shutdown)(struct irq_data___94 *);
	void (*irq_enable)(struct irq_data___94 *);
	void (*irq_disable)(struct irq_data___94 *);
	void (*irq_ack)(struct irq_data___94 *);
	void (*irq_mask)(struct irq_data___94 *);
	void (*irq_mask_ack)(struct irq_data___94 *);
	void (*irq_unmask)(struct irq_data___94 *);
	void (*irq_eoi)(struct irq_data___94 *);
	int (*irq_set_affinity)(struct irq_data___94 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___94 *);
	int (*irq_set_type)(struct irq_data___94 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___94 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___94 *);
	void (*irq_bus_sync_unlock)(struct irq_data___94 *);
	void (*irq_cpu_online)(struct irq_data___94 *);
	void (*irq_cpu_offline)(struct irq_data___94 *);
	void (*irq_suspend)(struct irq_data___94 *);
	void (*irq_resume)(struct irq_data___94 *);
	void (*irq_pm_shutdown)(struct irq_data___94 *);
	void (*irq_print_chip)(struct irq_data___94 *, struct seq_file___97 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___94 *, void *);
	long unsigned int flags;
};

struct seq_operations___96 {
	void * (*start)(struct seq_file___97 *, loff_t *);
	void (*stop)(struct seq_file___97 *, void *);
	void * (*next)(struct seq_file___97 *, void *, loff_t *);
	int (*show)(struct seq_file___97 *, void *);
};

struct dcbnl_rtnl_ops___8 {
	int (*ieee_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___10 *);
	u8 (*setstate)(struct net_device___10 *, u8);
	void (*getpermhwaddr)(struct net_device___10 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___10 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___10 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___10 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___10 *, int, u8 *);
	void (*setpfccfg)(struct net_device___10 *, int, u8);
	void (*getpfccfg)(struct net_device___10 *, int, u8 *);
	u8 (*setall)(struct net_device___10 *);
	u8 (*getcap)(struct net_device___10 *, int, u8 *);
	int (*getnumtcs)(struct net_device___10 *, int, u8 *);
	int (*setnumtcs)(struct net_device___10 *, int, u8);
	u8 (*getpfcstate)(struct net_device___10 *);
	void (*setpfcstate)(struct net_device___10 *, u8);
	void (*getbcncfg)(struct net_device___10 *, int, u32 *);
	void (*setbcncfg)(struct net_device___10 *, int, u32);
	void (*getbcnrp)(struct net_device___10 *, int, u8 *);
	void (*setbcnrp)(struct net_device___10 *, int, u8);
	u8 (*setapp)(struct net_device___10 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___10 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___10 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___10 *, int, u8);
	u8 (*getdcbx)(struct net_device___10 *);
	u8 (*setdcbx)(struct net_device___10 *, u8);
	int (*peer_getappinfo)(struct net_device___10 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___10 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___10 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___10 *, struct cee_pfc *);
};

struct cgroupfs_root___89;

struct cgroup___89 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___89 *parent;
	struct dentry___129 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___89 *subsys[11];
	struct cgroupfs_root___89 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___130 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___89 {
	struct super_block___129 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___89 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___42 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___129 *, struct file___129 *);
	ssize_t (*read)(struct cgroup___89 *, struct cftype___42 *, struct file___129 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___89 *, struct cftype___42 *);
	s64 (*read_s64)(struct cgroup___89 *, struct cftype___42 *);
	int (*read_map)(struct cgroup___89 *, struct cftype___42 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___89 *, struct cftype___42 *, struct seq_file___97 *);
	ssize_t (*write)(struct cgroup___89 *, struct cftype___42 *, struct file___129 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___89 *, struct cftype___42 *, u64);
	int (*write_s64)(struct cgroup___89 *, struct cftype___42 *, s64);
	int (*write_string)(struct cgroup___89 *, struct cftype___42 *, const char *);
	int (*trigger)(struct cgroup___89 *, unsigned int);
	int (*release)(struct inode___129 *, struct file___129 *);
	int (*register_event)(struct cgroup___89 *, struct cftype___42 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___89 *, struct cftype___42 *, struct eventfd_ctx *);
};

struct cftype_set___40 {
	struct list_head node;
	struct cftype___42 *cfts;
};

struct task_and_cgroup___40 {
	struct task_struct___129 *task;
	struct cgroup___89 *cgrp;
	struct css_set___89 *cg;
};

struct cgroup_taskset___40 {
	struct task_and_cgroup___40 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___89 *cur_cgrp;
};

struct cgroup_subsys___40 {
	struct cgroup_subsys_state___89 * (*css_alloc)(struct cgroup___89 *);
	int (*css_online)(struct cgroup___89 *);
	void (*css_offline)(struct cgroup___89 *);
	void (*css_free)(struct cgroup___89 *);
	int (*can_attach)(struct cgroup___89 *, struct cgroup_taskset___40 *);
	void (*cancel_attach)(struct cgroup___89 *, struct cgroup_taskset___40 *);
	void (*attach)(struct cgroup___89 *, struct cgroup_taskset___40 *);
	void (*fork)(struct task_struct___129 *);
	void (*exit)(struct cgroup___89 *, struct cgroup___89 *, struct task_struct___129 *);
	void (*bind)(struct cgroup___89 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___89 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___42 *base_cftypes;
	struct cftype_set___40 base_cftset;
	struct module *module;
};

struct netlink_callback___8 {
	struct sk_buff___12 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___12 *, struct netlink_callback___8 *);
	int (*done)(struct netlink_callback___8 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___8 {
	int (*create)(struct sk_buff___12 *, struct net_device___10 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___12 *, unsigned char *);
	int (*rebuild)(struct sk_buff___12 *);
	int (*cache)(const struct neighbour___7 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___10 *, const unsigned char *);
};

struct napi_struct___8 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___8 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___10 *dev;
	struct sk_buff___12 *gro_list;
	struct sk_buff___12 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___8 {
	struct net_device___10 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___7 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___8 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___7 kobj;
	struct net_device___10 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___8 {
	int (*ndo_init)(struct net_device___10 *);
	void (*ndo_uninit)(struct net_device___10 *);
	int (*ndo_open)(struct net_device___10 *);
	int (*ndo_stop)(struct net_device___10 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___12 *, struct net_device___10 *);
	u16 (*ndo_select_queue)(struct net_device___10 *, struct sk_buff___12 *);
	void (*ndo_change_rx_flags)(struct net_device___10 *, int);
	void (*ndo_set_rx_mode)(struct net_device___10 *);
	int (*ndo_set_mac_address)(struct net_device___10 *, void *);
	int (*ndo_validate_addr)(struct net_device___10 *);
	int (*ndo_do_ioctl)(struct net_device___10 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___10 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___10 *, int);
	int (*ndo_neigh_setup)(struct net_device___10 *, struct neigh_parms___7 *);
	void (*ndo_tx_timeout)(struct net_device___10 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___10 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___10 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___10 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___10 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___10 *);
	int (*ndo_netpoll_setup)(struct net_device___10 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___10 *);
	int (*ndo_busy_poll)(struct napi_struct___8 *);
	int (*ndo_set_vf_mac)(struct net_device___10 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___10 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___10 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___10 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___10 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___10 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___10 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___10 *, int, struct sk_buff___12 *);
	int (*ndo_setup_tc)(struct net_device___10 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___10 *);
	int (*ndo_fcoe_disable)(struct net_device___10 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___10 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___10 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___10 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___10 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___10 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___10 *, const struct sk_buff___12 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___10 *, struct net_device___10 *);
	int (*ndo_del_slave)(struct net_device___10 *, struct net_device___10 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___7 *);
	void (*ndo_neigh_destroy)(struct neighbour___7 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___12 *, struct netlink_callback___8 *, struct net_device___10 *, int);
	int (*ndo_bridge_setlink)(struct net_device___10 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___12 *, u32, u32, struct net_device___10 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___10 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___10 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___10 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___10 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___10 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___10 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___12 *, struct net_device___10 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___10 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___10 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___10 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___7 {
	struct net___16 *net;
	struct net_device___10 *dev;
	struct neigh_parms___7 *next;
	int (*neigh_setup)(struct neighbour___7 *);
	void (*neigh_cleanup)(struct neighbour___7 *);
	struct neigh_table___7 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___7 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___10 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___16 *, struct net_device___10 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___10 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___10 *, struct list_head *);
	size_t (*get_size)(const struct net_device___10 *);
	int (*fill_info)(struct sk_buff___12 *, const struct net_device___10 *);
	size_t (*get_xstats_size)(const struct net_device___10 *);
	int (*fill_xstats)(struct sk_buff___12 *, const struct net_device___10 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___16 * (*get_link_net)(const struct net_device___10 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___10 *, struct net_device___10 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___10 *, const struct net_device___10 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___12 *, const struct net_device___10 *, const struct net_device___10 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fd___16 {
	struct file___129 *file;
	unsigned int flags;
};

struct ppp_idle {
	__kernel_time_t xmit_idle;
	__kernel_time_t recv_idle;
};

struct ppp_option_data {
	__u8 *ptr;
	__u32 length;
	int transmit;
};

struct sk_filter___8 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___12 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___7;

struct neigh_hash_table___7;

struct neigh_table___7 {
	struct neigh_table___7 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___10 *, __u32 *);
	int (*constructor)(struct neighbour___7 *);
	int (*pconstructor)(struct pneigh_entry___7 *);
	void (*pdestructor)(struct pneigh_entry___7 *);
	void (*proxy_redo)(struct sk_buff___12 *);
	char *id;
	struct neigh_parms___7 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___9 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___7 *nht;
	struct pneigh_entry___7 **phash_buckets;
};

struct neigh_ops___7 {
	int family;
	void (*solicit)(struct neighbour___7 *, struct sk_buff___12 *);
	void (*error_report)(struct neighbour___7 *, struct sk_buff___12 *);
	int (*output)(struct neighbour___7 *, struct sk_buff___12 *);
	int (*connected_output)(struct neighbour___7 *, struct sk_buff___12 *);
};

struct pneigh_entry___7 {
	struct pneigh_entry___7 *next;
	struct net___16 *net;
	struct net_device___10 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___7 {
	struct neighbour___7 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___7 {
	void (*close)(struct sock___8 *, long int);
	int (*connect)(struct sock___8 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___8 *, int);
	struct sock___8 * (*accept)(struct sock___8 *, int, int *);
	int (*ioctl)(struct sock___8 *, int, long unsigned int);
	int (*init)(struct sock___8 *);
	void (*destroy)(struct sock___8 *);
	void (*shutdown)(struct sock___8 *, int);
	int (*setsockopt)(struct sock___8 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___8 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___8 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___8 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___8 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___14 *, struct sock___8 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___14 *, struct sock___8 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___8 *, struct page___129 *, int, size_t, int);
	int (*bind)(struct sock___8 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___8 *, struct sk_buff___12 *);
	void (*release_cb)(struct sock___8 *);
	void (*mtu_reduced)(struct sock___8 *);
	void (*hash)(struct sock___8 *);
	void (*unhash)(struct sock___8 *);
	void (*rehash)(struct sock___8 *);
	int (*get_port)(struct sock___8 *, short unsigned int);
	void (*clear_sk)(struct sock___8 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___8 *);
	void (*enter_memory_pressure)(struct sock___8 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___116 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___40 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___7 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___7 {
	void (*enter_memory_pressure)(struct sock___8 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct mtget {
	long int mt_type;
	long int mt_resid;
	long int mt_dsreg;
	long int mt_gstat;
	long int mt_erreg;
	__kernel_daddr_t mt_fileno;
	__kernel_daddr_t mt_blkno;
};

struct mtpos {
	long int mt_blkno;
};

struct tty_operations___11 {
	struct tty_struct___11 * (*lookup)(struct tty_driver___11 *, struct inode___129 *, int);
	int (*install)(struct tty_driver___11 *, struct tty_struct___11 *);
	void (*remove)(struct tty_driver___11 *, struct tty_struct___11 *);
	int (*open)(struct tty_struct___11 *, struct file___129 *);
	void (*close)(struct tty_struct___11 *, struct file___129 *);
	void (*shutdown)(struct tty_struct___11 *);
	void (*cleanup)(struct tty_struct___11 *);
	int (*write)(struct tty_struct___11 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___11 *, unsigned char);
	void (*flush_chars)(struct tty_struct___11 *);
	int (*write_room)(struct tty_struct___11 *);
	int (*chars_in_buffer)(struct tty_struct___11 *);
	int (*ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	void (*throttle)(struct tty_struct___11 *);
	void (*unthrottle)(struct tty_struct___11 *);
	void (*stop)(struct tty_struct___11 *);
	void (*start)(struct tty_struct___11 *);
	void (*hangup)(struct tty_struct___11 *);
	int (*break_ctl)(struct tty_struct___11 *, int);
	void (*flush_buffer)(struct tty_struct___11 *);
	void (*set_ldisc)(struct tty_struct___11 *);
	void (*wait_until_sent)(struct tty_struct___11 *, int);
	void (*send_xchar)(struct tty_struct___11 *, char);
	int (*tiocmget)(struct tty_struct___11 *);
	int (*tiocmset)(struct tty_struct___11 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___11 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___11 *, struct termiox *);
	int (*get_icount)(struct tty_struct___11 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___11 *, int, char *);
	int (*poll_get_char)(struct tty_driver___11 *, int);
	void (*poll_put_char)(struct tty_driver___11 *, int, char);
	const struct file_operations___129 *proc_fops;
};

struct tty_driver___11 {
	int magic;
	struct kref kref;
	struct cdev___37 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___11 *other;
	struct tty_struct___11 **ttys;
	struct tty_port___11 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___11 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___11;

struct tty_port___11 {
	struct tty_bufhead buf;
	struct tty_struct___11 *tty;
	struct tty_struct___11 *itty;
	const struct tty_port_operations___11 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___130 mutex;
	struct mutex___130 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___11 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___11 *);
	void (*close)(struct tty_struct___11 *);
	void (*flush_buffer)(struct tty_struct___11 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___11 *);
	ssize_t (*read)(struct tty_struct___11 *, struct file___129 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___11 *, struct file___129 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___11 *, struct file___129 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___11 *, struct file___129 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___11 *, struct file___129 *, struct poll_table_struct___83 *);
	int (*hangup)(struct tty_struct___11 *);
	void (*receive_buf)(struct tty_struct___11 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___11 *);
	void (*dcd_change)(struct tty_struct___11 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___11 *, int);
};

struct tty_ldisc___11 {
	struct tty_ldisc_ops___11 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___11 *tty;
};

struct tty_port_operations___11 {
	int (*carrier_raised)(struct tty_port___11 *);
	void (*dtr_rts)(struct tty_port___11 *, int);
	void (*shutdown)(struct tty_port___11 *);
	void (*drop)(struct tty_port___11 *);
	int (*activate)(struct tty_port___11 *, struct tty_struct___11 *);
	void (*destruct)(struct tty_port___11 *);
};

struct property___6 {
	char *name;
	int length;
	void *value;
	struct property___6 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___97 attr;
};

struct i2c_msg {
	__u16 addr;
	__u16 flags;
	__u16 len;
	__u8 *buf;
};

union i2c_smbus_data {
	__u8 byte;
	__u16 word;
	__u8 block[34];
};

enum v4l2_preemphasis {
	V4L2_PREEMPHASIS_DISABLED = 0,
	V4L2_PREEMPHASIS_50_uS = 1,
	V4L2_PREEMPHASIS_75_uS = 2,
};

struct disk_part_tbl___22 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___22 *last_lookup;
	struct hd_struct___22 *part[0];
};

struct block_device_operations___21 {
	int (*open)(struct block_device___129 *, fmode_t);
	void (*release)(struct gendisk___22 *, fmode_t);
	int (*ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___129 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___22 *, unsigned int);
	int (*media_changed)(struct gendisk___22 *);
	void (*unlock_native_capacity)(struct gendisk___22 *);
	int (*revalidate_disk)(struct gendisk___22 *);
	int (*getgeo)(struct block_device___129 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___129 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct blk_integrity___3 {
	integrity_gen_fn *generate_fn;
	integrity_vrfy_fn *verify_fn;
	integrity_set_tag_fn *set_tag_fn;
	integrity_get_tag_fn *get_tag_fn;
	short unsigned int flags;
	short unsigned int tuple_size;
	short unsigned int sector_size;
	short unsigned int tag_size;
	const char *name;
	struct kobject___7 kobj;
};

struct io_cq___21 {
	struct request_queue___21 *q;
	struct io_context___21 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___116 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___21(struct request___21 *, int);

struct request___21 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide32;
			union {			};
		};
	};
	struct request_queue___21 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___22 *bio;
	struct bio___22 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___21 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___21 *saved_end_io;
		} flush;
	};
	struct gendisk___22 *rq_disk;
	struct hd_struct___22 *part;
	long unsigned int start_time;
	struct request_list___21 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___21 *end_io;
	void *end_io_data;
	struct request___21 *next_rq;
};

typedef int elevator_merge_fn___21(struct request_queue___21 *, struct request___21 **, struct bio___22 *);

typedef void elevator_merge_req_fn___21(struct request_queue___21 *, struct request___21 *, struct request___21 *);

typedef void elevator_merged_fn___21(struct request_queue___21 *, struct request___21 *, int);

typedef int elevator_allow_merge_fn___21(struct request_queue___21 *, struct request___21 *, struct bio___22 *);

typedef void elevator_bio_merged_fn___21(struct request_queue___21 *, struct request___21 *, struct bio___22 *);

typedef int elevator_dispatch_fn___21(struct request_queue___21 *, int);

typedef void elevator_add_req_fn___21(struct request_queue___21 *, struct request___21 *);

typedef struct request___21 *elevator_request_list_fn___21(struct request_queue___21 *, struct request___21 *);

typedef void elevator_completed_req_fn___21(struct request_queue___21 *, struct request___21 *);

typedef int elevator_may_queue_fn___21(struct request_queue___21 *, int);

typedef void elevator_init_icq_fn___21(struct io_cq___21 *);

typedef void elevator_exit_icq_fn___21(struct io_cq___21 *);

typedef int elevator_set_req_fn___21(struct request_queue___21 *, struct request___21 *, struct bio___22 *, gfp_t);

typedef void elevator_put_req_fn___21(struct request___21 *);

typedef void elevator_activate_req_fn___21(struct request_queue___21 *, struct request___21 *);

typedef void elevator_deactivate_req_fn___21(struct request_queue___21 *, struct request___21 *);

struct elevator_type___21;

typedef int elevator_init_fn___21(struct request_queue___21 *, struct elevator_type___21 *);

typedef void elevator_exit_fn___21(struct elevator_queue___21 *);

struct elevator_ops___21 {
	elevator_merge_fn___21 *elevator_merge_fn;
	elevator_merged_fn___21 *elevator_merged_fn;
	elevator_merge_req_fn___21 *elevator_merge_req_fn;
	elevator_allow_merge_fn___21 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___21 *elevator_bio_merged_fn;
	elevator_dispatch_fn___21 *elevator_dispatch_fn;
	elevator_add_req_fn___21 *elevator_add_req_fn;
	elevator_activate_req_fn___21 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___21 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___21 *elevator_completed_req_fn;
	elevator_request_list_fn___21 *elevator_former_req_fn;
	elevator_request_list_fn___21 *elevator_latter_req_fn;
	elevator_init_icq_fn___21 *elevator_init_icq_fn;
	elevator_exit_icq_fn___21 *elevator_exit_icq_fn;
	elevator_set_req_fn___21 *elevator_set_req_fn;
	elevator_put_req_fn___21 *elevator_put_req_fn;
	elevator_may_queue_fn___21 *elevator_may_queue_fn;
	elevator_init_fn___21 *elevator_init_fn;
	elevator_exit_fn___21 *elevator_exit_fn;
};

struct elv_fs_entry___21;

struct elevator_type___21 {
	struct kmem_cache___116 *icq_cache;
	struct elevator_ops___21 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___21 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___21 {
	struct elevator_type___21 *type;
	void *elevator_data;
	struct kobject___7 kobj;
	struct mutex___130 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___21 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___21 *, char *);
	ssize_t (*store)(struct elevator_queue___21 *, const char *, size_t);
};

struct bvec_merge_data___21 {
	struct block_device___129 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___21 {
	struct request___21 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct serial_struct {
	int type;
	int line;
	unsigned int port;
	int irq;
	int flags;
	int xmit_fifo_size;
	int custom_divisor;
	int baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char[1];
	int hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	long unsigned int iomap_base;
};

struct perf_cpu_context___69;

struct pmu___69 {
	struct list_head entry;
	struct device___104 *dev;
	const struct attribute_group___97 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___69 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___69 *);
	void (*pmu_disable)(struct pmu___69 *);
	int (*event_init)(struct perf_event___69 *);
	int (*add)(struct perf_event___69 *, int);
	void (*del)(struct perf_event___69 *, int);
	void (*start)(struct perf_event___69 *, int);
	void (*stop)(struct perf_event___69 *, int);
	void (*read)(struct perf_event___69 *);
	void (*start_txn)(struct pmu___69 *);
	int (*commit_txn)(struct pmu___69 *);
	void (*cancel_txn)(struct pmu___69 *);
	int (*event_idx)(struct perf_event___69 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___69 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___69 *);
};

struct perf_cpu_context___69 {
	struct perf_event_context___69 ctx;
	struct perf_event_context___69 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___69 *unique_pmu;
	struct perf_cgroup___69 *cgrp;
};

struct trace_event_functions___59;

struct trace_event___59 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___59 *funcs;
};

struct ftrace_event_class___59;

struct ftrace_event_call___59 {
	struct list_head list;
	struct ftrace_event_class___59 *class;
	char *name;
	struct trace_event___59 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___69 {
	struct cgroup_subsys_state___89 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___59 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___130 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___59)(struct trace_iterator___59 *, int, struct trace_event___59 *);

struct trace_event_functions___59 {
	trace_print_func___59 trace;
	trace_print_func___59 raw;
	trace_print_func___59 hex;
	trace_print_func___59 binary;
};

struct ftrace_event_class___59 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___59 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___59 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___59 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___59 *);
};

struct i2c_smbus_ioctl_data {
	__u8 read_write;
	__u8 command;
	__u32 size;
	union i2c_smbus_data *data;
};

struct i2c_rdwr_ioctl_data {
	struct i2c_msg *msgs;
	__u32 nmsgs;
};

typedef struct sg_iovec sg_iovec_t;

struct sg_io_hdr {
	int interface_id;
	int dxfer_direction;
	unsigned char cmd_len;
	unsigned char mx_sb_len;
	short unsigned int iovec_count;
	unsigned int dxfer_len;
	void *dxferp;
	unsigned char *cmdp;
	void *sbp;
	unsigned int timeout;
	unsigned int flags;
	int pack_id;
	void *usr_ptr;
	unsigned char status;
	unsigned char masked_status;
	unsigned char msg_status;
	unsigned char sb_len_wr;
	short unsigned int host_status;
	short unsigned int driver_status;
	int resid;
	unsigned int duration;
	unsigned int info;
};

typedef struct sg_io_hdr sg_io_hdr_t;

struct sg_req_info {
	char req_state;
	char orphan;
	char sg_io_owned;
	char problem;
	int pack_id;
	void *usr_ptr;
	unsigned int duration;
	int unused;
};

typedef struct sg_req_info sg_req_info_t;

typedef enum {
	VIDEO_FORMAT_4_3 = 0,
	VIDEO_FORMAT_16_9 = 1,
	VIDEO_FORMAT_221_1 = 2,
} video_format_t;

typedef struct {
	int w;
	int h;
	video_format_t aspect_ratio;
} video_size_t;

struct video_event {
	__s32 type;
	__kernel_time_t timestamp;
	union {
		video_size_t size;
		unsigned int frame_rate;
		unsigned char vsync_field;
	} u;
};

struct video_still_picture {
	char *iFrame;
	__s32 size;
};

struct video_spu_palette {
	int length;
	__u8 *palette;
};

struct compat_video_event {
	int32_t type;
	compat_time_t timestamp;
	union {
		video_size_t size;
		unsigned int frame_rate;
	} u;
};

struct compat_video_still_picture {
	compat_uptr_t iFrame;
	int32_t size;
};

struct compat_video_spu_palette {
	int length;
	compat_uptr_t palette;
};

struct sg_io_hdr32 {
	compat_int_t interface_id;
	compat_int_t dxfer_direction;
	unsigned char cmd_len;
	unsigned char mx_sb_len;
	short unsigned int iovec_count;
	compat_uint_t dxfer_len;
	compat_uint_t dxferp;
	compat_uptr_t cmdp;
	compat_uptr_t sbp;
	compat_uint_t timeout;
	compat_uint_t flags;
	compat_int_t pack_id;
	compat_uptr_t usr_ptr;
	unsigned char status;
	unsigned char masked_status;
	unsigned char msg_status;
	unsigned char sb_len_wr;
	short unsigned int host_status;
	short unsigned int driver_status;
	compat_int_t resid;
	compat_uint_t duration;
	compat_uint_t info;
};

typedef struct sg_io_hdr32 sg_io_hdr32_t;

struct sg_iovec32 {
	compat_uint_t iov_base;
	compat_uint_t iov_len;
};

typedef struct sg_iovec32 sg_iovec32_t;

struct compat_sg_req_info {
	char req_state;
	char orphan;
	char sg_io_owned;
	char problem;
	int pack_id;
	compat_uptr_t usr_ptr;
	unsigned int duration;
	int unused;
};

struct sock_fprog32 {
	short unsigned int len;
	compat_caddr_t filter;
};

struct ppp_option_data32 {
	compat_caddr_t ptr;
	u32 length;
	compat_int_t transmit;
};

struct ppp_idle32 {
	compat_time_t xmit_idle;
	compat_time_t recv_idle;
};

struct mtget32 {
	compat_long_t mt_type;
	compat_long_t mt_resid;
	compat_long_t mt_dsreg;
	compat_long_t mt_gstat;
	compat_long_t mt_erreg;
	compat_daddr_t mt_fileno;
	compat_daddr_t mt_blkno;
};

struct mtpos32 {
	compat_long_t mt_blkno;
};

struct serial_struct32 {
	compat_int_t type;
	compat_int_t line;
	compat_uint_t port;
	compat_int_t irq;
	compat_int_t flags;
	compat_int_t xmit_fifo_size;
	compat_int_t custom_divisor;
	compat_int_t baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char[1];
	compat_int_t hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	compat_uint_t iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	compat_int_t reserved[1];
};

struct i2c_msg32 {
	u16 addr;
	u16 flags;
	u16 len;
	compat_caddr_t buf;
};

struct i2c_rdwr_ioctl_data32 {
	compat_caddr_t msgs;
	u32 nmsgs;
};

struct i2c_smbus_ioctl_data32 {
	u8 read_write;
	u8 command;
	u32 size;
	compat_caddr_t data;
};

struct i2c_rdwr_aligned {
	struct i2c_rdwr_ioctl_data cmd;
	struct i2c_msg msgs[0];
};

struct space_resv_32 {
	__s16 l_type;
	__s16 l_whence;
	__s64 l_start;
	__s64 l_len;
	__s32 l_sysid;
	__u32 l_pid;
	__s32 l_pad[4];
} __attribute__((packed));

struct elf_prpsinfo {
	char pr_state;
	char pr_sname;
	char pr_zomb;
	char pr_nice;
	long unsigned int pr_flag;
	__kernel_uid_t pr_uid;
	__kernel_gid_t pr_gid;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	char pr_fname[16];
	char pr_psargs[80];
};

struct memelfnote {
	const char *name;
	int type;
	unsigned int datasz;
	void *data;
};

struct user_regset___3;

typedef int user_regset_active_fn___4(struct task_struct___115 *, const struct user_regset___3 *);

typedef int user_regset_get_fn___4(struct task_struct___115 *, const struct user_regset___3 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___4(struct task_struct___115 *, const struct user_regset___3 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___4(struct task_struct___115 *, const struct user_regset___3 *, int);

struct user_regset___3 {
	user_regset_get_fn___4 *get;
	user_regset_set_fn___4 *set;
	user_regset_active_fn___4 *active;
	user_regset_writeback_fn___4 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___2 {
	const char *name;
	const struct user_regset___3 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct elf_thread_core_info {
	struct elf_thread_core_info *next;
	struct task_struct___115 *task;
	struct elf_prstatus prstatus;
	struct memelfnote notes[0];
};

struct elf_note_info {
	struct elf_thread_core_info *thread;
	struct memelfnote psinfo;
	struct memelfnote signote;
	struct memelfnote auxv;
	struct memelfnote files;
	siginfo_t csigdata;
	size_t size;
	int thread_notes;
};

struct page___130;

typedef struct page___130 *pgtable_t___130;

struct address_space___130;

struct kmem_cache___117;

struct page___130 {
	long unsigned int flags;
	struct address_space___130 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___130 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___130 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___117 *slab_cache;
		struct page___130 *first_page;
	};
	long: 64;
};

struct task_struct___130;

struct pv_cpu_ops___130 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___69 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___69 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___130 *);
	void (*end_context_switch)(struct task_struct___130 *);
};

struct mutex___131 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___130 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___126 {
	struct page___130 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___135;

struct signal_struct___130;

struct task_struct___130 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___130 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___135 *mm;
	struct mm_struct___135 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___130 *real_parent;
	struct task_struct___130 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___130 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___74 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___130 = 0,
		VTIME_USER___130 = 1,
		VTIME_SYS___130 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___69 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___77 *nsproxy;
	struct signal_struct___130 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___131 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___126 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___135 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___135 *, struct mm_struct___135 *);
	void (*dup_mmap)(struct mm_struct___135 *, struct mm_struct___135 *);
	void (*exit_mmap)(struct mm_struct___135 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___135 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___135 *);
	void (*pgd_free)(struct mm_struct___135 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___135 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___135 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___135 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___135 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___135 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___135 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___135 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___135 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___135 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___135 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___135 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___131 lock;
	void *vdso;
} mm_context_t___131;

struct xol_area___130;

struct uprobes_state___130 {
	struct xol_area___130 *xol_area;
};

struct vm_area_struct___135;

struct file___130;

struct linux_binfmt___16;

struct core_state___130;

struct mm_struct___135 {
	struct vm_area_struct___135 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___135 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___135 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___16 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___131 context;
	long unsigned int flags;
	struct core_state___130 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___130 *owner;
	struct file___130 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___130 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___66;

struct exec_domain___35 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___66 *module;
	struct exec_domain___35 *next;
};

struct module_kobject___65 {
	struct kobject___7 kobj;
	struct module___66 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___65;

struct module___66 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___65 mkobj;
	struct module_attribute___65 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___130 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___71 {
	struct task_struct___130 *task;
	struct exec_domain___35 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct elf32_note {
	Elf32_Word n_namesz;
	Elf32_Word n_descsz;
	Elf32_Word n_type;
};

struct xol_area___130 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___130 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___117;

struct memcg_cache_params___117;

struct kmem_cache___117 {
	struct kmem_cache_cpu___117 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___117 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___130;

struct address_space_operations___130;

struct address_space___130 {
	struct inode___130 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___131 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___130 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___130;

struct path___130 {
	struct vfsmount *mnt;
	struct dentry___130 *dentry;
};

struct file_operations___130;

struct file___130 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___130 f_path;
	struct inode___130 *f_inode;
	const struct file_operations___130 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___74 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___130 *f_mapping;
	struct mutex___131 f_pos_lock;
};

struct vm_operations_struct___116;

struct vm_area_struct___135 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___135 *vm_next;
	struct vm_area_struct___135 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___135 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___116 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___130 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___113;

struct vm_operations_struct___116 {
	void (*open)(struct vm_area_struct___135 *);
	void (*close)(struct vm_area_struct___135 *);
	int (*fault)(struct vm_area_struct___135 *, struct vm_fault___113 *);
	int (*page_mkwrite)(struct vm_area_struct___135 *, struct vm_fault___113 *);
	int (*access)(struct vm_area_struct___135 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___135 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___135 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___135 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___135 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___130 {
	struct task_struct___130 *task;
	struct core_thread___130 *next;
};

struct core_state___130 {
	atomic_t nr_threads;
	struct core_thread___130 dumper;
	struct completion startup;
};

struct linux_binprm___17;

struct coredump_params___16;

struct linux_binfmt___16 {
	struct list_head lh;
	struct module___66 *module;
	int (*load_binary)(struct linux_binprm___17 *);
	int (*load_shlib)(struct file___130 *);
	int (*core_dump)(struct coredump_params___16 *);
	long unsigned int min_coredump;
};

struct smp_ops___130 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___130 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___130;

struct lruvec___130 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___130 *zone;
};

struct pglist_data___130;

struct zone___130 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___130 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___130 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___130 {
	struct zone___130 *zone;
	int zone_idx;
};

struct zonelist___130 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___130 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___130 {
	struct zone___130 node_zones[4];
	struct zonelist___130 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___130 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___130 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___130 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___130 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___74 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___74 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___131 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___130;

struct super_block___130;

struct dentry___130 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___130 *d_parent;
	struct qstr d_name;
	struct inode___130 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___130 *d_op;
	struct super_block___130 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___130;

struct file_lock___130;

struct dquot___130;

struct block_device___130;

struct inode___130 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___130 *i_op;
	struct super_block___130 *i_sb;
	struct address_space___130 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___131 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___130 *i_fop;
	struct file_lock___130 *i_flock;
	struct address_space___130 i_data;
	struct dquot___130 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___130 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___130 {
	int (*d_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_hash)(const struct dentry___130 *, struct qstr *);
	int (*d_compare)(const struct dentry___130 *, const struct dentry___130 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___130 *);
	void (*d_release)(struct dentry___130 *);
	void (*d_prune)(struct dentry___130 *);
	void (*d_iput)(struct dentry___130 *, struct inode___130 *);
	char * (*d_dname)(struct dentry___130 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___130 *);
	int (*d_manage)(struct dentry___130 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___130;

struct mem_dqinfo___130 {
	struct quota_format_type___130 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___130;

struct quota_info___130 {
	unsigned int flags;
	struct mutex___131 dqio_mutex;
	struct mutex___131 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___130 *files[2];
	struct mem_dqinfo___130 info[2];
	const struct quota_format_ops___130 *ops[2];
};

struct file_system_type___130;

struct super_operations___130;

struct dquot_operations___130;

struct quotactl_ops___130;

struct super_block___130 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___130 *s_type;
	const struct super_operations___130 *s_op;
	const struct dquot_operations___130 *dq_op;
	const struct quotactl_ops___130 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___130 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___130 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___130 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___131 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___130 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___130 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___130 *bd_inode;
	struct super_block___130 *bd_super;
	struct mutex___131 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___130 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___131 bd_fsfreeze_mutex;
};

struct iattr___130 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___130 *ia_file;
};

struct dquot___130 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___131 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___130 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___130 {
	int qf_fmt_id;
	const struct quota_format_ops___130 *qf_ops;
	struct module___66 *qf_owner;
	struct quota_format_type___130 *qf_next;
};

struct quota_format_ops___130 {
	int (*check_quota_file)(struct super_block___130 *, int);
	int (*read_file_info)(struct super_block___130 *, int);
	int (*write_file_info)(struct super_block___130 *, int);
	int (*free_file_info)(struct super_block___130 *, int);
	int (*read_dqblk)(struct dquot___130 *);
	int (*commit_dqblk)(struct dquot___130 *);
	int (*release_dqblk)(struct dquot___130 *);
};

struct dquot_operations___130 {
	int (*write_dquot)(struct dquot___130 *);
	struct dquot___130 * (*alloc_dquot)(struct super_block___130 *, int);
	void (*destroy_dquot)(struct dquot___130 *);
	int (*acquire_dquot)(struct dquot___130 *);
	int (*release_dquot)(struct dquot___130 *);
	int (*mark_dirty)(struct dquot___130 *);
	int (*write_info)(struct super_block___130 *, int);
	qsize_t * (*get_reserved_space)(struct inode___130 *);
};

struct quotactl_ops___130 {
	int (*quota_on)(struct super_block___130 *, int, int, struct path___130 *);
	int (*quota_on_meta)(struct super_block___130 *, int, int);
	int (*quota_off)(struct super_block___130 *, int);
	int (*quota_sync)(struct super_block___130 *, int);
	int (*get_info)(struct super_block___130 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___130 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___130 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___130 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___130 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___130 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___130 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___130 *, unsigned int);
};

struct address_space_operations___130 {
	int (*writepage)(struct page___130 *, struct writeback_control *);
	int (*readpage)(struct file___130 *, struct page___130 *);
	int (*writepages)(struct address_space___130 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___130 *);
	int (*readpages)(struct file___130 *, struct address_space___130 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___130 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___130 **, void **);
	int (*write_end)(struct file___130 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___130 *, void *);
	sector_t (*bmap)(struct address_space___130 *, sector_t);
	void (*invalidatepage)(struct page___130 *, long unsigned int);
	int (*releasepage)(struct page___130 *, gfp_t);
	void (*freepage)(struct page___130 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___130 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___130 *, struct page___130 *, struct page___130 *, enum migrate_mode);
	int (*launder_page)(struct page___130 *);
	int (*is_partially_uptodate)(struct page___130 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___130 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___130 *, struct page___130 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___130 *, sector_t *);
	void (*swap_deactivate)(struct file___130 *);
	void (*invalidatepage_range)(struct page___130 *, unsigned int, unsigned int);
};

struct inode_operations___130 {
	struct dentry___130 * (*lookup)(struct inode___130 *, struct dentry___130 *, unsigned int);
	void * (*follow_link)(struct dentry___130 *, struct nameidata *);
	int (*permission)(struct inode___130 *, int);
	struct posix_acl * (*get_acl)(struct inode___130 *, int);
	int (*readlink)(struct dentry___130 *, char *, int);
	void (*put_link)(struct dentry___130 *, struct nameidata *, void *);
	int (*create)(struct inode___130 *, struct dentry___130 *, umode_t, bool);
	int (*link)(struct dentry___130 *, struct inode___130 *, struct dentry___130 *);
	int (*unlink)(struct inode___130 *, struct dentry___130 *);
	int (*symlink)(struct inode___130 *, struct dentry___130 *, const char *);
	int (*mkdir)(struct inode___130 *, struct dentry___130 *, umode_t);
	int (*rmdir)(struct inode___130 *, struct dentry___130 *);
	int (*mknod)(struct inode___130 *, struct dentry___130 *, umode_t, dev_t);
	int (*rename)(struct inode___130 *, struct dentry___130 *, struct inode___130 *, struct dentry___130 *);
	int (*setattr)(struct dentry___130 *, struct iattr___130 *);
	int (*getattr)(struct vfsmount *, struct dentry___130 *, struct kstat *);
	int (*setxattr)(struct dentry___130 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___130 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___130 *, char *, size_t);
	int (*removexattr)(struct dentry___130 *, const char *);
	int (*fiemap)(struct inode___130 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___130 *, struct timespec *, int);
	int (*atomic_open)(struct inode___130 *, struct dentry___130 *, struct file___130 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___130 {
	struct module___66 *owner;
	loff_t (*llseek)(struct file___130 *, loff_t, int);
	ssize_t (*read)(struct file___130 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___130 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___130 *, void *, filldir_t);
	unsigned int (*poll)(struct file___130 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___130 *, struct vm_area_struct___135 *);
	int (*open)(struct inode___130 *, struct file___130 *);
	int (*flush)(struct file___130 *, fl_owner_t);
	int (*release)(struct inode___130 *, struct file___130 *);
	int (*fsync)(struct file___130 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___130 *, int);
	int (*lock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*sendpage)(struct file___130 *, struct page___130 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___130 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___130 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___130 *, long int, struct file_lock___130 **, void **);
		struct {
			int (*setlease)(struct file___130 *, long int, struct file_lock___130 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___130 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___130 *);
};

struct fasync_struct___130;

struct file_lock_operations___130;

struct lock_manager_operations___130;

struct file_lock___130 {
	struct file_lock___130 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___74 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___130 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___130 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___130 *fl_ops;
	const struct lock_manager_operations___130 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___130 {
	void (*fl_copy_lock)(struct file_lock___130 *, struct file_lock___130 *);
	void (*fl_release_private)(struct file_lock___130 *);
};

struct lock_manager_operations___130 {
	int (*lm_compare_owner)(struct file_lock___130 *, struct file_lock___130 *);
	long unsigned int (*lm_owner_key)(struct file_lock___130 *);
	void (*lm_notify)(struct file_lock___130 *);
	int (*lm_grant)(struct file_lock___130 *, struct file_lock___130 *, int);
	void (*lm_break)(struct file_lock___130 *);
	int (*lm_change)(struct file_lock___130 **, int);
};

struct fasync_struct___130 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___130 *fa_next;
	struct file___130 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___130 {
	const char *name;
	int fs_flags;
	struct dentry___130 * (*mount)(struct file_system_type___130 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___130 *);
	struct module___66 *owner;
	struct file_system_type___130 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___130 {
	struct inode___130 * (*alloc_inode)(struct super_block___130 *);
	void (*destroy_inode)(struct inode___130 *);
	void (*dirty_inode)(struct inode___130 *, int);
	int (*write_inode)(struct inode___130 *, struct writeback_control *);
	int (*drop_inode)(struct inode___130 *);
	void (*evict_inode)(struct inode___130 *);
	void (*put_super)(struct super_block___130 *);
	int (*sync_fs)(struct super_block___130 *, int);
	int (*freeze_fs)(struct super_block___130 *);
	int (*unfreeze_fs)(struct super_block___130 *);
	int (*statfs)(struct dentry___130 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___130 *, int *, char *);
	void (*umount_begin)(struct super_block___130 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___130 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___130 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___130 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___130 *);
	ssize_t (*quota_read)(struct super_block___130 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___130 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___130 *);
	int (*bdev_try_to_free_page)(struct super_block___130 *, struct page___130 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___130 *);
	void (*free_cached_objects)(struct super_block___130 *, int);
};

struct user_regs_struct32 {
	__u32 ebx;
	__u32 ecx;
	__u32 edx;
	__u32 esi;
	__u32 edi;
	__u32 ebp;
	__u32 eax;
	short unsigned int ds;
	short unsigned int __ds;
	short unsigned int es;
	short unsigned int __es;
	short unsigned int fs;
	short unsigned int __fs;
	short unsigned int gs;
	short unsigned int __gs;
	__u32 orig_eax;
	__u32 eip;
	short unsigned int cs;
	short unsigned int __cs;
	__u32 eflags;
	__u32 esp;
	short unsigned int ss;
	short unsigned int __ss;
};

typedef struct user_regs_struct32 compat_elf_gregset_t;

struct compat_elf_siginfo {
	compat_int_t si_signo;
	compat_int_t si_code;
	compat_int_t si_errno;
};

struct compat_elf_prstatus {
	struct compat_elf_siginfo pr_info;
	short int pr_cursig;
	compat_ulong_t pr_sigpend;
	compat_ulong_t pr_sighold;
	compat_pid_t pr_pid;
	compat_pid_t pr_ppid;
	compat_pid_t pr_pgrp;
	compat_pid_t pr_sid;
	struct compat_timeval pr_utime;
	struct compat_timeval pr_stime;
	struct compat_timeval pr_cutime;
	struct compat_timeval pr_cstime;
	compat_elf_gregset_t pr_reg;
	compat_int_t pr_fpvalid;
};

struct compat_elf_prpsinfo {
	char pr_state;
	char pr_sname;
	char pr_zomb;
	char pr_nice;
	compat_ulong_t pr_flag;
	__compat_uid_t pr_uid;
	__compat_gid_t pr_gid;
	compat_pid_t pr_pid;
	compat_pid_t pr_ppid;
	compat_pid_t pr_pgrp;
	compat_pid_t pr_sid;
	char pr_fname[16];
	char pr_psargs[80];
};

struct module_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___65 *, struct module_kobject___65 *, char *);
	ssize_t (*store)(struct module_attribute___65 *, struct module_kobject___65 *, const char *, size_t);
	void (*setup)(struct module___66 *, const char *);
	int (*test)(struct module___66 *);
	void (*free)(struct module___66 *);
};

struct vm_fault___113 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___130 *page;
};

struct linux_binprm___17 {
	char buf[128];
	struct vm_area_struct___135 *vma;
	long unsigned int vma_pages;
	struct mm_struct___135 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___130 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___16 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___130 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct kmem_cache_cpu___117 {
	void **freelist;
	long unsigned int tid;
	struct page___130 *page;
	struct page___130 *partial;
};

struct memcg_cache_params___117 {
	bool is_root_cache;
	union {
		struct kmem_cache___117 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___117 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct user_regset___4;

typedef int user_regset_active_fn___5(struct task_struct___130 *, const struct user_regset___4 *);

typedef int user_regset_get_fn___5(struct task_struct___130 *, const struct user_regset___4 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___5(struct task_struct___130 *, const struct user_regset___4 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___5(struct task_struct___130 *, const struct user_regset___4 *, int);

struct user_regset___4 {
	user_regset_get_fn___5 *get;
	user_regset_set_fn___5 *set;
	user_regset_active_fn___5 *active;
	user_regset_writeback_fn___5 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___3 {
	const char *name;
	const struct user_regset___4 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct elf_thread_core_info___2 {
	struct elf_thread_core_info___2 *next;
	struct task_struct___130 *task;
	struct compat_elf_prstatus prstatus;
	struct memelfnote notes[0];
};

struct elf_note_info___2 {
	struct elf_thread_core_info___2 *thread;
	struct memelfnote psinfo;
	struct memelfnote signote;
	struct memelfnote auxv;
	struct memelfnote files;
	compat_siginfo_t csigdata;
	size_t size;
	int thread_notes;
};

typedef __u32 __le32;

typedef struct {
	__le16 e_tag;
	__le16 e_perm;
	__le32 e_id;
} posix_acl_xattr_entry;

typedef struct {
	__le32 a_version;
	posix_acl_xattr_entry a_entries[0];
} posix_acl_xattr_header;

struct core_name {
	char *corename;
	int used;
	int size;
};

struct page___131;

typedef struct page___131 *pgtable_t___131;

struct address_space___131;

struct kmem_cache___118;

struct page___131 {
	long unsigned int flags;
	struct address_space___131 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___131 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___131 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___118 *slab_cache;
		struct page___131 *first_page;
	};
	long: 64;
};

struct thread_struct___70;

struct task_struct___131;

struct pv_cpu_ops___131 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___131 *);
	void (*end_context_switch)(struct task_struct___131 *);
};

struct perf_event___70;

struct thread_struct___70 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___70 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___75;

struct pid_link___75 {
	struct hlist_node node;
	struct pid___75 *pid;
};

struct mutex___132 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___131 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___127 {
	struct page___131 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___136;

struct fs_struct___14;

struct nsproxy___78;

struct signal_struct___131;

struct css_set___90;

struct perf_event_context___70;

struct task_struct___131 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___131 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___136 *mm;
	struct mm_struct___136 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___131 *real_parent;
	struct task_struct___131 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___131 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___75 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___131 = 0,
		VTIME_USER___131 = 1,
		VTIME_SYS___131 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct___14 *fs;
	struct files_struct *files;
	struct nsproxy___78 *nsproxy;
	struct signal_struct___131 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___90 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___70 *perf_event_ctxp[2];
	struct mutex___132 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___127 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___136 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___136 *, struct mm_struct___136 *);
	void (*dup_mmap)(struct mm_struct___136 *, struct mm_struct___136 *);
	void (*exit_mmap)(struct mm_struct___136 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___136 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___136 *);
	void (*pgd_free)(struct mm_struct___136 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___136 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___136 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___136 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___136 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___136 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___136 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___136 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___136 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___136 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___136 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___136 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___132 lock;
	void *vdso;
} mm_context_t___132;

struct xol_area___131;

struct uprobes_state___131 {
	struct xol_area___131 *xol_area;
};

struct vm_area_struct___136;

struct file___131;

struct core_state___131;

struct mm_struct___136 {
	struct vm_area_struct___136 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___136 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___136 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___132 context;
	long unsigned int flags;
	struct core_state___131 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___131 *owner;
	struct file___131 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___131 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___70 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___131 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___131 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___131 *target;
};

typedef void (*perf_overflow_handler_t___70)(struct perf_event___70 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___70;

typedef void (*ftrace_func_t___70)(long unsigned int, long unsigned int, struct ftrace_ops___70 *, struct pt_regs *);

struct ftrace_ops___70 {
	ftrace_func_t___70 func;
	struct ftrace_ops___70 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___132 regex_lock;
};

struct pmu___70;

struct fasync_struct___131;

struct pid_namespace___75;

struct ftrace_event_call___60;

struct perf_cgroup___70;

struct perf_event___70 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___70 *group_leader;
	struct pmu___70 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___70 hw;
	struct perf_event_context___70 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___132 child_mutex;
	struct list_head child_list;
	struct perf_event___70 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___131 *owner;
	struct mutex___132 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___131 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___70 *);
	struct callback_head callback_head;
	struct pid_namespace___75 *ns;
	u64 id;
	perf_overflow_handler_t___70 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___60 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___70 ftrace_ops;
	struct perf_cgroup___70 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct irq_data___95;

struct x86_io_apic_ops___95 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___95 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___95;

struct irq_data___95 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___95 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___105;

struct dev_pm_ops___105 {
	int (*prepare)(struct device___105 *);
	void (*complete)(struct device___105 *);
	int (*suspend)(struct device___105 *);
	int (*resume)(struct device___105 *);
	int (*freeze)(struct device___105 *);
	int (*thaw)(struct device___105 *);
	int (*poweroff)(struct device___105 *);
	int (*restore)(struct device___105 *);
	int (*suspend_late)(struct device___105 *);
	int (*resume_early)(struct device___105 *);
	int (*freeze_late)(struct device___105 *);
	int (*thaw_early)(struct device___105 *);
	int (*poweroff_late)(struct device___105 *);
	int (*restore_early)(struct device___105 *);
	int (*suspend_noirq)(struct device___105 *);
	int (*resume_noirq)(struct device___105 *);
	int (*freeze_noirq)(struct device___105 *);
	int (*thaw_noirq)(struct device___105 *);
	int (*poweroff_noirq)(struct device___105 *);
	int (*restore_noirq)(struct device___105 *);
	int (*runtime_suspend)(struct device___105 *);
	int (*runtime_resume)(struct device___105 *);
	int (*runtime_idle)(struct device___105 *);
};

struct device_type___105;

struct bus_type___105;

struct device_driver___105;

struct dev_pm_domain___105;

struct class___105;

struct attribute_group___98;

struct device_rh___105;

struct device___105 {
	struct device___105 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___105 *type;
	struct mutex___132 mutex;
	struct bus_type___105 *bus;
	struct device_driver___105 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___105 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___34 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___105 *class;
	const struct attribute_group___98 **groups;
	void (*release)(struct device___105 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___105 *device_rh;
};

struct dev_pm_info_rh___105 {
	void (*set_latency_tolerance)(struct device___105 *, s32);
};

struct dev_pm_domain___105 {
	struct dev_pm_ops___105 ops;
};

struct smp_ops___131 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___131 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___131;

struct lruvec___131 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___131 *zone;
};

struct pglist_data___131;

struct zone___131 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___131 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___131 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___131 {
	struct zone___131 *zone;
	int zone_idx;
};

struct zonelist___131 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___131 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___131 {
	struct zone___131 node_zones[4];
	struct zonelist___131 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___131 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___131;

struct dquot___131 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___132 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___131 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___131;

struct mem_dqinfo___131 {
	struct quota_format_type___131 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___131;

struct quota_format_ops___131;

struct quota_info___131 {
	unsigned int flags;
	struct mutex___132 dqio_mutex;
	struct mutex___132 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___131 *files[2];
	struct mem_dqinfo___131 info[2];
	const struct quota_format_ops___131 *ops[2];
};

struct file_system_type___131;

struct super_operations___131;

struct dquot_operations___131;

struct quotactl_ops___131;

struct export_operations___7;

struct dentry___131;

struct xattr_handler___90;

struct block_device___131;

struct dentry_operations___131;

struct super_block___131 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___131 *s_type;
	const struct super_operations___131 *s_op;
	const struct dquot_operations___131 *dq_op;
	const struct quotactl_ops___131 *s_qcop;
	const struct export_operations___7 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___131 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___90 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___131 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___131 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___132 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___131 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___131 {
	int qf_fmt_id;
	const struct quota_format_ops___131 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___131 *qf_next;
};

struct quota_format_ops___131 {
	int (*check_quota_file)(struct super_block___131 *, int);
	int (*read_file_info)(struct super_block___131 *, int);
	int (*write_file_info)(struct super_block___131 *, int);
	int (*free_file_info)(struct super_block___131 *, int);
	int (*read_dqblk)(struct dquot___131 *);
	int (*commit_dqblk)(struct dquot___131 *);
	int (*release_dqblk)(struct dquot___131 *);
};

struct dquot_operations___131 {
	int (*write_dquot)(struct dquot___131 *);
	struct dquot___131 * (*alloc_dquot)(struct super_block___131 *, int);
	void (*destroy_dquot)(struct dquot___131 *);
	int (*acquire_dquot)(struct dquot___131 *);
	int (*release_dquot)(struct dquot___131 *);
	int (*mark_dirty)(struct dquot___131 *);
	int (*write_info)(struct super_block___131 *, int);
	qsize_t * (*get_reserved_space)(struct inode___131 *);
};

struct address_space_operations___131;

struct address_space___131 {
	struct inode___131 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___132 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___131 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___131;

struct file_operations___131;

struct file_lock___131;

struct inode___131 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___131 *i_op;
	struct super_block___131 *i_sb;
	struct address_space___131 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___132 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___131 *i_fop;
	struct file_lock___131 *i_flock;
	struct address_space___131 i_data;
	struct dquot___131 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___131 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___131;

struct quotactl_ops___131 {
	int (*quota_on)(struct super_block___131 *, int, int, struct path___131 *);
	int (*quota_on_meta)(struct super_block___131 *, int, int);
	int (*quota_off)(struct super_block___131 *, int);
	int (*quota_sync)(struct super_block___131 *, int);
	int (*get_info)(struct super_block___131 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___131 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___131 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___131 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___131 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___131 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___131 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___131 *, unsigned int);
};

struct vfsmount___26;

struct path___131 {
	struct vfsmount___26 *mnt;
	struct dentry___131 *dentry;
};

struct mnt_namespace___6;

struct nsproxy___78 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___6 *mnt_ns;
	struct pid_namespace___75 *pid_ns;
	struct net *net_ns;
};

struct xol_area___131 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___131 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___118;

struct memcg_cache_params___118;

struct kmem_cache___118 {
	struct kmem_cache_cpu___118 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___118 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___75 {
	rwlock_t lock;
	struct pid___75 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___131 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___131 f_path;
	struct inode___131 *f_inode;
	const struct file_operations___131 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___131 *f_mapping;
	struct mutex___132 f_pos_lock;
};

struct vm_operations_struct___117;

struct vm_area_struct___136 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___136 *vm_next;
	struct vm_area_struct___136 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___136 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___117 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___131 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___114;

struct vm_operations_struct___117 {
	void (*open)(struct vm_area_struct___136 *);
	void (*close)(struct vm_area_struct___136 *);
	int (*fault)(struct vm_area_struct___136 *, struct vm_fault___114 *);
	int (*page_mkwrite)(struct vm_area_struct___136 *, struct vm_fault___114 *);
	int (*access)(struct vm_area_struct___136 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___136 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___136 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___136 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___136 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___131 {
	struct task_struct___131 *task;
	struct core_thread___131 *next;
};

struct core_state___131 {
	atomic_t nr_threads;
	struct core_thread___131 dumper;
	struct completion startup;
};

struct vm_fault___114 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___131 *page;
};

struct seq_operations___97;

struct seq_file___98 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___132 lock;
	const struct seq_operations___97 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___97 {
	void * (*start)(struct seq_file___98 *, loff_t *);
	void (*stop)(struct seq_file___98 *, void *);
	void * (*next)(struct seq_file___98 *, void *, loff_t *);
	int (*show)(struct seq_file___98 *, void *);
};

struct dentry___131 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___131 *d_parent;
	struct qstr d_name;
	struct inode___131 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___131 *d_op;
	struct super_block___131 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___131 {
	int (*d_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_hash)(const struct dentry___131 *, struct qstr *);
	int (*d_compare)(const struct dentry___131 *, const struct dentry___131 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___131 *);
	void (*d_release)(struct dentry___131 *);
	void (*d_prune)(struct dentry___131 *);
	void (*d_iput)(struct dentry___131 *, struct inode___131 *);
	char * (*d_dname)(struct dentry___131 *, char *, int);
	struct vfsmount___26 * (*d_automount)(struct path___131 *);
	int (*d_manage)(struct dentry___131 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___26 {
	struct dentry___131 *mnt_root;
	struct super_block___131 *mnt_sb;
	int mnt_flags;
};

struct upid___75 {
	int nr;
	struct pid_namespace___75 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___75 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___131 *child_reaper;
	struct kmem_cache___118 *pid_cachep;
	unsigned int level;
	struct pid_namespace___75 *parent;
	struct vfsmount___26 *proc_mnt;
	struct dentry___131 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___75 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___75 numbers[1];
};

struct block_device___131 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___131 *bd_inode;
	struct super_block___131 *bd_super;
	struct mutex___132 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___131 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___132 bd_fsfreeze_mutex;
};

struct cgroup___90;

struct cgroup_subsys_state___90 {
	struct cgroup___90 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___131 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___131 *ia_file;
};

struct address_space_operations___131 {
	int (*writepage)(struct page___131 *, struct writeback_control *);
	int (*readpage)(struct file___131 *, struct page___131 *);
	int (*writepages)(struct address_space___131 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___131 *);
	int (*readpages)(struct file___131 *, struct address_space___131 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___131 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___131 **, void **);
	int (*write_end)(struct file___131 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___131 *, void *);
	sector_t (*bmap)(struct address_space___131 *, sector_t);
	void (*invalidatepage)(struct page___131 *, long unsigned int);
	int (*releasepage)(struct page___131 *, gfp_t);
	void (*freepage)(struct page___131 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___131 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___131 *, struct page___131 *, struct page___131 *, enum migrate_mode);
	int (*launder_page)(struct page___131 *);
	int (*is_partially_uptodate)(struct page___131 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___131 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___131 *, struct page___131 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___131 *, sector_t *);
	void (*swap_deactivate)(struct file___131 *);
	void (*invalidatepage_range)(struct page___131 *, unsigned int, unsigned int);
};

struct nameidata___14;

struct inode_operations___131 {
	struct dentry___131 * (*lookup)(struct inode___131 *, struct dentry___131 *, unsigned int);
	void * (*follow_link)(struct dentry___131 *, struct nameidata___14 *);
	int (*permission)(struct inode___131 *, int);
	struct posix_acl * (*get_acl)(struct inode___131 *, int);
	int (*readlink)(struct dentry___131 *, char *, int);
	void (*put_link)(struct dentry___131 *, struct nameidata___14 *, void *);
	int (*create)(struct inode___131 *, struct dentry___131 *, umode_t, bool);
	int (*link)(struct dentry___131 *, struct inode___131 *, struct dentry___131 *);
	int (*unlink)(struct inode___131 *, struct dentry___131 *);
	int (*symlink)(struct inode___131 *, struct dentry___131 *, const char *);
	int (*mkdir)(struct inode___131 *, struct dentry___131 *, umode_t);
	int (*rmdir)(struct inode___131 *, struct dentry___131 *);
	int (*mknod)(struct inode___131 *, struct dentry___131 *, umode_t, dev_t);
	int (*rename)(struct inode___131 *, struct dentry___131 *, struct inode___131 *, struct dentry___131 *);
	int (*setattr)(struct dentry___131 *, struct iattr___131 *);
	int (*getattr)(struct vfsmount___26 *, struct dentry___131 *, struct kstat *);
	int (*setxattr)(struct dentry___131 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___131 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___131 *, char *, size_t);
	int (*removexattr)(struct dentry___131 *, const char *);
	int (*fiemap)(struct inode___131 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___131 *, struct timespec *, int);
	int (*atomic_open)(struct inode___131 *, struct dentry___131 *, struct file___131 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___84;

struct file_operations___131 {
	struct module *owner;
	loff_t (*llseek)(struct file___131 *, loff_t, int);
	ssize_t (*read)(struct file___131 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___131 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___131 *, void *, filldir_t);
	unsigned int (*poll)(struct file___131 *, struct poll_table_struct___84 *);
	long int (*unlocked_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___131 *, struct vm_area_struct___136 *);
	int (*open)(struct inode___131 *, struct file___131 *);
	int (*flush)(struct file___131 *, fl_owner_t);
	int (*release)(struct inode___131 *, struct file___131 *);
	int (*fsync)(struct file___131 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___131 *, int);
	int (*lock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*sendpage)(struct file___131 *, struct page___131 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___131 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___131 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___131 *, long int, struct file_lock___131 **, void **);
		struct {
			int (*setlease)(struct file___131 *, long int, struct file_lock___131 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___131 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___98 *, struct file___131 *);
};

struct file_lock_operations___131;

struct lock_manager_operations___131;

struct file_lock___131 {
	struct file_lock___131 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___75 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___131 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___131 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___131 *fl_ops;
	const struct lock_manager_operations___131 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___131 {
	void (*fl_copy_lock)(struct file_lock___131 *, struct file_lock___131 *);
	void (*fl_release_private)(struct file_lock___131 *);
};

struct lock_manager_operations___131 {
	int (*lm_compare_owner)(struct file_lock___131 *, struct file_lock___131 *);
	long unsigned int (*lm_owner_key)(struct file_lock___131 *);
	void (*lm_notify)(struct file_lock___131 *);
	int (*lm_grant)(struct file_lock___131 *, struct file_lock___131 *, int);
	void (*lm_break)(struct file_lock___131 *);
	int (*lm_change)(struct file_lock___131 **, int);
};

struct fasync_struct___131 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___131 *fa_next;
	struct file___131 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___131 {
	const char *name;
	int fs_flags;
	struct dentry___131 * (*mount)(struct file_system_type___131 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___131 *);
	struct module *owner;
	struct file_system_type___131 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___131 {
	struct inode___131 * (*alloc_inode)(struct super_block___131 *);
	void (*destroy_inode)(struct inode___131 *);
	void (*dirty_inode)(struct inode___131 *, int);
	int (*write_inode)(struct inode___131 *, struct writeback_control *);
	int (*drop_inode)(struct inode___131 *);
	void (*evict_inode)(struct inode___131 *);
	void (*put_super)(struct super_block___131 *);
	int (*sync_fs)(struct super_block___131 *, int);
	int (*freeze_fs)(struct super_block___131 *);
	int (*unfreeze_fs)(struct super_block___131 *);
	int (*statfs)(struct dentry___131 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___131 *, int *, char *);
	void (*umount_begin)(struct super_block___131 *);
	int (*show_options)(struct seq_file___98 *, struct dentry___131 *);
	int (*show_devname)(struct seq_file___98 *, struct dentry___131 *);
	int (*show_path)(struct seq_file___98 *, struct dentry___131 *);
	int (*show_stats)(struct seq_file___98 *, struct dentry___131 *);
	ssize_t (*quota_read)(struct super_block___131 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___131 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___131 *);
	int (*bdev_try_to_free_page)(struct super_block___131 *, struct page___131 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___131 *);
	void (*free_cached_objects)(struct super_block___131 *, int);
};

struct export_operations___7 {
	int (*encode_fh)(struct inode___131 *, __u32 *, int *, struct inode___131 *);
	struct dentry___131 * (*fh_to_dentry)(struct super_block___131 *, struct fid *, int, int);
	struct dentry___131 * (*fh_to_parent)(struct super_block___131 *, struct fid *, int, int);
	int (*get_name)(struct dentry___131 *, char *, struct dentry___131 *);
	struct dentry___131 * (*get_parent)(struct dentry___131 *);
	int (*commit_metadata)(struct inode___131 *);
	int (*get_uuid)(struct super_block___131 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___131 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___131 *, struct iomap *, int, struct iattr___131 *);
};

struct xattr_handler___90 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___131 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___131 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___131 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___86)(struct file___131 *, wait_queue_head_t *, struct poll_table_struct___84 *);

struct poll_table_struct___84 {
	poll_queue_proc___86 _qproc;
	long unsigned int _key;
};

struct nameidata___14 {
	struct path___131 path;
	struct qstr last;
	struct path___131 root;
	struct inode___131 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct irq_chip___95 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___95 *);
	void (*irq_shutdown)(struct irq_data___95 *);
	void (*irq_enable)(struct irq_data___95 *);
	void (*irq_disable)(struct irq_data___95 *);
	void (*irq_ack)(struct irq_data___95 *);
	void (*irq_mask)(struct irq_data___95 *);
	void (*irq_mask_ack)(struct irq_data___95 *);
	void (*irq_unmask)(struct irq_data___95 *);
	void (*irq_eoi)(struct irq_data___95 *);
	int (*irq_set_affinity)(struct irq_data___95 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___95 *);
	int (*irq_set_type)(struct irq_data___95 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___95 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___95 *);
	void (*irq_bus_sync_unlock)(struct irq_data___95 *);
	void (*irq_cpu_online)(struct irq_data___95 *);
	void (*irq_cpu_offline)(struct irq_data___95 *);
	void (*irq_suspend)(struct irq_data___95 *);
	void (*irq_resume)(struct irq_data___95 *);
	void (*irq_pm_shutdown)(struct irq_data___95 *);
	void (*irq_print_chip)(struct irq_data___95 *, struct seq_file___98 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___95 *, void *);
	long unsigned int flags;
};

struct signal_struct___131 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___131 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___131 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___75 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___132 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___14 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___131 root;
	struct path___131 pwd;
};

struct css_set___90 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___90 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___70 {
	struct pmu___70 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___132 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___131 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___70 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct mount___6;

struct mnt_namespace___6 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___6 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct bin_attribute___98;

struct attribute_group___98 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___98 **bin_attrs;
};

struct bin_attribute___98 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___131 *, struct kobject___7 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___131 *, struct kobject___7 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	int (*mmap)(struct file___131 *, struct kobject___7 *, struct bin_attribute___98 *, struct vm_area_struct___136 *);
};

struct bus_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___105 *, char *);
	ssize_t (*store)(struct bus_type___105 *, const char *, size_t);
};

struct device_attribute___105;

struct driver_attribute___105;

struct bus_type___105 {
	const char *name;
	const char *dev_name;
	struct device___105 *dev_root;
	struct bus_attribute___105 *bus_attrs;
	struct device_attribute___105 *dev_attrs;
	struct driver_attribute___105 *drv_attrs;
	const struct attribute_group___98 **bus_groups;
	const struct attribute_group___98 **dev_groups;
	const struct attribute_group___98 **drv_groups;
	int (*match)(struct device___105 *, struct device_driver___105 *);
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	int (*probe)(struct device___105 *);
	int (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*online)(struct device___105 *);
	int (*offline)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct device___105 *, struct device_attribute___105 *, char *);
	ssize_t (*store)(struct device___105 *, struct device_attribute___105 *, const char *, size_t);
};

struct driver_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___105 *, char *);
	ssize_t (*store)(struct device_driver___105 *, const char *, size_t);
};

struct device_driver___105 {
	const char *name;
	struct bus_type___105 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___105 *);
	int (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	const struct attribute_group___98 **groups;
	const struct dev_pm_ops___105 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___105 {
	const char *name;
	const struct attribute_group___98 **groups;
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
};

struct class_attribute___105;

struct class___105 {
	const char *name;
	struct module *owner;
	struct class_attribute___105 *class_attrs;
	struct device_attribute___105 *dev_attrs;
	const struct attribute_group___98 **dev_groups;
	struct bin_attribute___98 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *);
	void (*class_release)(struct class___105 *);
	void (*dev_release)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
	struct subsys_private *p;
};

struct class_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct class___105 *, struct class_attribute___105 *, char *);
	ssize_t (*store)(struct class___105 *, struct class_attribute___105 *, const char *, size_t);
	const void * (*namespace)(struct class___105 *, const struct class_attribute___105 *);
};

struct device_rh___105 {
	struct dev_pm_info_rh___105 power;
};

struct kmem_cache_cpu___118 {
	void **freelist;
	long unsigned int tid;
	struct page___131 *page;
	struct page___131 *partial;
};

struct memcg_cache_params___118 {
	bool is_root_cache;
	union {
		struct kmem_cache___118 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___118 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___90;

struct cgroup___90 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___90 *parent;
	struct dentry___131 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___90 *subsys[11];
	struct cgroupfs_root___90 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___132 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___90 {
	struct super_block___131 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___90 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___70;

struct pmu___70 {
	struct list_head entry;
	struct device___105 *dev;
	const struct attribute_group___98 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___70 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___70 *);
	void (*pmu_disable)(struct pmu___70 *);
	int (*event_init)(struct perf_event___70 *);
	int (*add)(struct perf_event___70 *, int);
	void (*del)(struct perf_event___70 *, int);
	void (*start)(struct perf_event___70 *, int);
	void (*stop)(struct perf_event___70 *, int);
	void (*read)(struct perf_event___70 *);
	void (*start_txn)(struct pmu___70 *);
	int (*commit_txn)(struct pmu___70 *);
	void (*cancel_txn)(struct pmu___70 *);
	int (*event_idx)(struct perf_event___70 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___70 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___70 *);
};

struct perf_cpu_context___70 {
	struct perf_event_context___70 ctx;
	struct perf_event_context___70 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___70 *unique_pmu;
	struct perf_cgroup___70 *cgrp;
};

struct trace_event_functions___60;

struct trace_event___60 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___60 *funcs;
};

struct ftrace_event_class___60;

struct ftrace_event_call___60 {
	struct list_head list;
	struct ftrace_event_class___60 *class;
	char *name;
	struct trace_event___60 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___70 {
	struct cgroup_subsys_state___90 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___60 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___132 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___60)(struct trace_iterator___60 *, int, struct trace_event___60 *);

struct trace_event_functions___60 {
	trace_print_func___60 trace;
	trace_print_func___60 raw;
	trace_print_func___60 hex;
	trace_print_func___60 binary;
};

struct ftrace_event_class___60 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___60 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___60 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___60 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___60 *);
};

struct syscall_metadata___29 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___60 *enter_event;
	struct ftrace_event_call___60 *exit_event;
};

struct fd___17 {
	struct file___131 *file;
	unsigned int flags;
};

struct mountpoint___6;

struct mount___6 {
	struct list_head mnt_hash;
	struct mount___6 *mnt_parent;
	struct dentry___131 *mnt_mountpoint;
	struct vfsmount___26 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___6 *mnt_master;
	struct mnt_namespace___6 *mnt_ns;
	struct mountpoint___6 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___6 {
	struct list_head m_hash;
	struct dentry___131 *m_dentry;
	int m_count;
};

struct page___132;

typedef struct page___132 *pgtable_t___132;

struct address_space___132;

struct kmem_cache___119;

struct page___132 {
	long unsigned int flags;
	struct address_space___132 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___132 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___132 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___119 *slab_cache;
		struct page___132 *first_page;
	};
	long: 64;
};

struct task_struct___132;

struct pv_cpu_ops___132 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___132 *);
	void (*end_context_switch)(struct task_struct___132 *);
};

struct mutex___133 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___132 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___128 {
	struct page___132 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___137;

struct signal_struct___132;

struct task_struct___132 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___132 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___137 *mm;
	struct mm_struct___137 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___132 *real_parent;
	struct task_struct___132 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___132 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___75 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___132 = 0,
		VTIME_USER___132 = 1,
		VTIME_SYS___132 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___132 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___133 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___128 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___137 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___137 *, struct mm_struct___137 *);
	void (*dup_mmap)(struct mm_struct___137 *, struct mm_struct___137 *);
	void (*exit_mmap)(struct mm_struct___137 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___137 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___137 *);
	void (*pgd_free)(struct mm_struct___137 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___137 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___137 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___137 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___137 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___137 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___137 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___137 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___137 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___137 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___137 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___137 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___133 lock;
	void *vdso;
} mm_context_t___133;

struct xol_area___132;

struct uprobes_state___132 {
	struct xol_area___132 *xol_area;
};

struct vm_area_struct___137;

struct file___132;

struct core_state___132;

struct mm_struct___137 {
	struct vm_area_struct___137 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___137 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___137 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___133 context;
	long unsigned int flags;
	struct core_state___132 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___132 *owner;
	struct file___132 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___132 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___67;

struct module_kobject___66 {
	struct kobject___7 kobj;
	struct module___67 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___66;

struct module___67 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___66 mkobj;
	struct module_attribute___66 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___132 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___132;

struct dentry_operations___132;

struct super_block___132;

struct dentry___132 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___132 *d_parent;
	struct qstr d_name;
	struct inode___132 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___132 *d_op;
	struct super_block___132 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___132;

struct address_space___132 {
	struct inode___132 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___133 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___132 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___132;

struct file_operations___132;

struct file_lock___132;

struct dquot___132;

struct block_device___132;

struct cdev___38;

struct inode___132 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___132 *i_op;
	struct super_block___132 *i_sb;
	struct address_space___132 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___133 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___132 *i_fop;
	struct file_lock___132 *i_flock;
	struct address_space___132 i_data;
	struct dquot___132 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___132 *i_bdev;
		struct cdev___38 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___27;

struct path___132;

struct dentry_operations___132 {
	int (*d_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_hash)(const struct dentry___132 *, struct qstr *);
	int (*d_compare)(const struct dentry___132 *, const struct dentry___132 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___132 *);
	void (*d_release)(struct dentry___132 *);
	void (*d_prune)(struct dentry___132 *);
	void (*d_iput)(struct dentry___132 *, struct inode___132 *);
	char * (*d_dname)(struct dentry___132 *, char *, int);
	struct vfsmount___27 * (*d_automount)(struct path___132 *);
	int (*d_manage)(struct dentry___132 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___132;

struct mem_dqinfo___132 {
	struct quota_format_type___132 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___132;

struct quota_info___132 {
	unsigned int flags;
	struct mutex___133 dqio_mutex;
	struct mutex___133 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___132 *files[2];
	struct mem_dqinfo___132 info[2];
	const struct quota_format_ops___132 *ops[2];
};

struct file_system_type___132;

struct super_operations___132;

struct dquot_operations___132;

struct quotactl_ops___132;

struct super_block___132 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___132 *s_type;
	const struct super_operations___132 *s_op;
	const struct dquot_operations___132 *dq_op;
	const struct quotactl_ops___132 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___132 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___132 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___132 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___133 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___132 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___27 {
	struct dentry___132 *mnt_root;
	struct super_block___132 *mnt_sb;
	int mnt_flags;
};

struct path___132 {
	struct vfsmount___27 *mnt;
	struct dentry___132 *dentry;
};

struct device___106;

struct dev_pm_ops___106 {
	int (*prepare)(struct device___106 *);
	void (*complete)(struct device___106 *);
	int (*suspend)(struct device___106 *);
	int (*resume)(struct device___106 *);
	int (*freeze)(struct device___106 *);
	int (*thaw)(struct device___106 *);
	int (*poweroff)(struct device___106 *);
	int (*restore)(struct device___106 *);
	int (*suspend_late)(struct device___106 *);
	int (*resume_early)(struct device___106 *);
	int (*freeze_late)(struct device___106 *);
	int (*thaw_early)(struct device___106 *);
	int (*poweroff_late)(struct device___106 *);
	int (*restore_early)(struct device___106 *);
	int (*suspend_noirq)(struct device___106 *);
	int (*resume_noirq)(struct device___106 *);
	int (*freeze_noirq)(struct device___106 *);
	int (*thaw_noirq)(struct device___106 *);
	int (*poweroff_noirq)(struct device___106 *);
	int (*restore_noirq)(struct device___106 *);
	int (*runtime_suspend)(struct device___106 *);
	int (*runtime_resume)(struct device___106 *);
	int (*runtime_idle)(struct device___106 *);
};

struct device_type___106;

struct bus_type___106;

struct device_driver___106;

struct dev_pm_domain___106;

struct class___106;

struct attribute_group___99;

struct device_rh___106;

struct device___106 {
	struct device___106 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___106 *type;
	struct mutex___133 mutex;
	struct bus_type___106 *bus;
	struct device_driver___106 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___106 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___34 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___106 *class;
	const struct attribute_group___99 **groups;
	void (*release)(struct device___106 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___106 *device_rh;
};

struct dev_pm_info_rh___106 {
	void (*set_latency_tolerance)(struct device___106 *, s32);
};

struct dev_pm_domain___106 {
	struct dev_pm_ops___106 ops;
};

struct smp_ops___132 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___132 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___132 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___132 *bd_inode;
	struct super_block___132 *bd_super;
	struct mutex___133 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___132 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___133 bd_fsfreeze_mutex;
};

struct iattr___132 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___132 *ia_file;
};

struct file___132 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___132 f_path;
	struct inode___132 *f_inode;
	const struct file_operations___132 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___132 *f_mapping;
	struct mutex___133 f_pos_lock;
};

struct zone___132;

struct lruvec___132 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___132 *zone;
};

struct pglist_data___132;

struct zone___132 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___132 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___132 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___132 {
	struct zone___132 *zone;
	int zone_idx;
};

struct zonelist___132 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___132 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___132 {
	struct zone___132 node_zones[4];
	struct zonelist___132 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___132 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___132 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___133 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___132 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

enum {
	QIF_BLIMITS_B = 0,
	QIF_SPACE_B = 1,
	QIF_ILIMITS_B = 2,
	QIF_INODES_B = 3,
	QIF_BTIME_B = 4,
	QIF_ITIME_B = 5,
};

typedef __kernel_uid32_t qid_t;

struct quota_format_type___132 {
	int qf_fmt_id;
	const struct quota_format_ops___132 *qf_ops;
	struct module___67 *qf_owner;
	struct quota_format_type___132 *qf_next;
};

struct quota_format_ops___132 {
	int (*check_quota_file)(struct super_block___132 *, int);
	int (*read_file_info)(struct super_block___132 *, int);
	int (*write_file_info)(struct super_block___132 *, int);
	int (*free_file_info)(struct super_block___132 *, int);
	int (*read_dqblk)(struct dquot___132 *);
	int (*commit_dqblk)(struct dquot___132 *);
	int (*release_dqblk)(struct dquot___132 *);
};

struct dquot_operations___132 {
	int (*write_dquot)(struct dquot___132 *);
	struct dquot___132 * (*alloc_dquot)(struct super_block___132 *, int);
	void (*destroy_dquot)(struct dquot___132 *);
	int (*acquire_dquot)(struct dquot___132 *);
	int (*release_dquot)(struct dquot___132 *);
	int (*mark_dirty)(struct dquot___132 *);
	int (*write_info)(struct super_block___132 *, int);
	qsize_t * (*get_reserved_space)(struct inode___132 *);
};

struct quotactl_ops___132 {
	int (*quota_on)(struct super_block___132 *, int, int, struct path___132 *);
	int (*quota_on_meta)(struct super_block___132 *, int, int);
	int (*quota_off)(struct super_block___132 *, int);
	int (*quota_sync)(struct super_block___132 *, int);
	int (*get_info)(struct super_block___132 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___132 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___132 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___132 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___132 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___132 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___132 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___132 *, unsigned int);
};

struct quota_module_name {
	int qm_fmt_id;
	char *qm_mod_name;
};

struct address_space_operations___132 {
	int (*writepage)(struct page___132 *, struct writeback_control *);
	int (*readpage)(struct file___132 *, struct page___132 *);
	int (*writepages)(struct address_space___132 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___132 *);
	int (*readpages)(struct file___132 *, struct address_space___132 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___132 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___132 **, void **);
	int (*write_end)(struct file___132 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___132 *, void *);
	sector_t (*bmap)(struct address_space___132 *, sector_t);
	void (*invalidatepage)(struct page___132 *, long unsigned int);
	int (*releasepage)(struct page___132 *, gfp_t);
	void (*freepage)(struct page___132 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___132 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___132 *, struct page___132 *, struct page___132 *, enum migrate_mode);
	int (*launder_page)(struct page___132 *);
	int (*is_partially_uptodate)(struct page___132 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___132 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___132 *, struct page___132 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___132 *, sector_t *);
	void (*swap_deactivate)(struct file___132 *);
	void (*invalidatepage_range)(struct page___132 *, unsigned int, unsigned int);
};

struct cdev___38 {
	struct kobject___7 kobj;
	struct module___67 *owner;
	const struct file_operations___132 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct nameidata___15;

struct inode_operations___132 {
	struct dentry___132 * (*lookup)(struct inode___132 *, struct dentry___132 *, unsigned int);
	void * (*follow_link)(struct dentry___132 *, struct nameidata___15 *);
	int (*permission)(struct inode___132 *, int);
	struct posix_acl * (*get_acl)(struct inode___132 *, int);
	int (*readlink)(struct dentry___132 *, char *, int);
	void (*put_link)(struct dentry___132 *, struct nameidata___15 *, void *);
	int (*create)(struct inode___132 *, struct dentry___132 *, umode_t, bool);
	int (*link)(struct dentry___132 *, struct inode___132 *, struct dentry___132 *);
	int (*unlink)(struct inode___132 *, struct dentry___132 *);
	int (*symlink)(struct inode___132 *, struct dentry___132 *, const char *);
	int (*mkdir)(struct inode___132 *, struct dentry___132 *, umode_t);
	int (*rmdir)(struct inode___132 *, struct dentry___132 *);
	int (*mknod)(struct inode___132 *, struct dentry___132 *, umode_t, dev_t);
	int (*rename)(struct inode___132 *, struct dentry___132 *, struct inode___132 *, struct dentry___132 *);
	int (*setattr)(struct dentry___132 *, struct iattr___132 *);
	int (*getattr)(struct vfsmount___27 *, struct dentry___132 *, struct kstat *);
	int (*setxattr)(struct dentry___132 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___132 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___132 *, char *, size_t);
	int (*removexattr)(struct dentry___132 *, const char *);
	int (*fiemap)(struct inode___132 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___132 *, struct timespec *, int);
	int (*atomic_open)(struct inode___132 *, struct dentry___132 *, struct file___132 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___99;

struct file_operations___132 {
	struct module___67 *owner;
	loff_t (*llseek)(struct file___132 *, loff_t, int);
	ssize_t (*read)(struct file___132 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___132 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___132 *, void *, filldir_t);
	unsigned int (*poll)(struct file___132 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___132 *, struct vm_area_struct___137 *);
	int (*open)(struct inode___132 *, struct file___132 *);
	int (*flush)(struct file___132 *, fl_owner_t);
	int (*release)(struct inode___132 *, struct file___132 *);
	int (*fsync)(struct file___132 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___132 *, int);
	int (*lock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*sendpage)(struct file___132 *, struct page___132 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___132 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___132 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___132 *, long int, struct file_lock___132 **, void **);
		struct {
			int (*setlease)(struct file___132 *, long int, struct file_lock___132 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___132 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___99 *, struct file___132 *);
};

struct fasync_struct___132;

struct file_lock_operations___132;

struct lock_manager_operations___132;

struct file_lock___132 {
	struct file_lock___132 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___75 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___132 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___132 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___132 *fl_ops;
	const struct lock_manager_operations___132 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___132 {
	void (*fl_copy_lock)(struct file_lock___132 *, struct file_lock___132 *);
	void (*fl_release_private)(struct file_lock___132 *);
};

struct lock_manager_operations___132 {
	int (*lm_compare_owner)(struct file_lock___132 *, struct file_lock___132 *);
	long unsigned int (*lm_owner_key)(struct file_lock___132 *);
	void (*lm_notify)(struct file_lock___132 *);
	int (*lm_grant)(struct file_lock___132 *, struct file_lock___132 *, int);
	void (*lm_break)(struct file_lock___132 *);
	int (*lm_change)(struct file_lock___132 **, int);
};

struct fasync_struct___132 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___132 *fa_next;
	struct file___132 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___132 {
	const char *name;
	int fs_flags;
	struct dentry___132 * (*mount)(struct file_system_type___132 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___132 *);
	struct module___67 *owner;
	struct file_system_type___132 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___132 {
	struct inode___132 * (*alloc_inode)(struct super_block___132 *);
	void (*destroy_inode)(struct inode___132 *);
	void (*dirty_inode)(struct inode___132 *, int);
	int (*write_inode)(struct inode___132 *, struct writeback_control *);
	int (*drop_inode)(struct inode___132 *);
	void (*evict_inode)(struct inode___132 *);
	void (*put_super)(struct super_block___132 *);
	int (*sync_fs)(struct super_block___132 *, int);
	int (*freeze_fs)(struct super_block___132 *);
	int (*unfreeze_fs)(struct super_block___132 *);
	int (*statfs)(struct dentry___132 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___132 *, int *, char *);
	void (*umount_begin)(struct super_block___132 *);
	int (*show_options)(struct seq_file___99 *, struct dentry___132 *);
	int (*show_devname)(struct seq_file___99 *, struct dentry___132 *);
	int (*show_path)(struct seq_file___99 *, struct dentry___132 *);
	int (*show_stats)(struct seq_file___99 *, struct dentry___132 *);
	ssize_t (*quota_read)(struct super_block___132 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___132 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___132 *);
	int (*bdev_try_to_free_page)(struct super_block___132 *, struct page___132 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___132 *);
	void (*free_cached_objects)(struct super_block___132 *, int);
};

struct vm_operations_struct___118;

struct vm_area_struct___137 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___137 *vm_next;
	struct vm_area_struct___137 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___137 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___118 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___132 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___98;

struct seq_file___99 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___133 lock;
	const struct seq_operations___98 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___15 {
	struct path___132 path;
	struct qstr last;
	struct path___132 root;
	struct inode___132 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___132 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___132 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___119;

struct memcg_cache_params___119;

struct kmem_cache___119 {
	struct kmem_cache_cpu___119 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___119 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___115;

struct vm_operations_struct___118 {
	void (*open)(struct vm_area_struct___137 *);
	void (*close)(struct vm_area_struct___137 *);
	int (*fault)(struct vm_area_struct___137 *, struct vm_fault___115 *);
	int (*page_mkwrite)(struct vm_area_struct___137 *, struct vm_fault___115 *);
	int (*access)(struct vm_area_struct___137 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___137 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___137 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___137 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___137 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___132 {
	struct task_struct___132 *task;
	struct core_thread___132 *next;
};

struct core_state___132 {
	atomic_t nr_threads;
	struct core_thread___132 dumper;
	struct completion startup;
};

struct vm_fault___115 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___132 *page;
};

struct bin_attribute___99;

struct attribute_group___99 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___99 **bin_attrs;
};

struct bin_attribute___99 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___132 *, struct kobject___7 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___132 *, struct kobject___7 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	int (*mmap)(struct file___132 *, struct kobject___7 *, struct bin_attribute___99 *, struct vm_area_struct___137 *);
};

struct tty_struct___12;

struct tty_driver___12;

struct tty_operations___12 {
	struct tty_struct___12 * (*lookup)(struct tty_driver___12 *, struct inode___132 *, int);
	int (*install)(struct tty_driver___12 *, struct tty_struct___12 *);
	void (*remove)(struct tty_driver___12 *, struct tty_struct___12 *);
	int (*open)(struct tty_struct___12 *, struct file___132 *);
	void (*close)(struct tty_struct___12 *, struct file___132 *);
	void (*shutdown)(struct tty_struct___12 *);
	void (*cleanup)(struct tty_struct___12 *);
	int (*write)(struct tty_struct___12 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___12 *, unsigned char);
	void (*flush_chars)(struct tty_struct___12 *);
	int (*write_room)(struct tty_struct___12 *);
	int (*chars_in_buffer)(struct tty_struct___12 *);
	int (*ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	void (*throttle)(struct tty_struct___12 *);
	void (*unthrottle)(struct tty_struct___12 *);
	void (*stop)(struct tty_struct___12 *);
	void (*start)(struct tty_struct___12 *);
	void (*hangup)(struct tty_struct___12 *);
	int (*break_ctl)(struct tty_struct___12 *, int);
	void (*flush_buffer)(struct tty_struct___12 *);
	void (*set_ldisc)(struct tty_struct___12 *);
	void (*wait_until_sent)(struct tty_struct___12 *, int);
	void (*send_xchar)(struct tty_struct___12 *, char);
	int (*tiocmget)(struct tty_struct___12 *);
	int (*tiocmset)(struct tty_struct___12 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___12 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___12 *, struct termiox *);
	int (*get_icount)(struct tty_struct___12 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___12 *, int, char *);
	int (*poll_get_char)(struct tty_driver___12 *, int);
	void (*poll_put_char)(struct tty_driver___12 *, int, char);
	const struct file_operations___132 *proc_fops;
};

struct tty_ldisc___12;

struct tty_port___12;

struct tty_struct___12 {
	int magic;
	struct kref kref;
	struct device___106 *dev;
	struct tty_driver___12 *driver;
	const struct tty_operations___12 *ops;
	int index;
	struct mutex___133 ldisc_mutex;
	struct tty_ldisc___12 *ldisc;
	struct mutex___133 atomic_write_lock;
	struct mutex___133 legacy_mutex;
	struct mutex___133 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___75 *pgrp;
	struct pid___75 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___12 *link;
	struct fasync_struct___132 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___12 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___12 {
	int magic;
	struct kref kref;
	struct cdev___38 *cdevs;
	struct module___67 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___12 *other;
	struct tty_struct___12 **ttys;
	struct tty_port___12 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___12 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___12;

struct tty_port___12 {
	struct tty_bufhead buf;
	struct tty_struct___12 *tty;
	struct tty_struct___12 *itty;
	const struct tty_port_operations___12 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___133 mutex;
	struct mutex___133 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___12 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___12 *);
	void (*close)(struct tty_struct___12 *);
	void (*flush_buffer)(struct tty_struct___12 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___12 *);
	ssize_t (*read)(struct tty_struct___12 *, struct file___132 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___12 *, struct file___132 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___12 *, struct file___132 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___12 *, struct file___132 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___12 *, struct file___132 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___12 *);
	void (*receive_buf)(struct tty_struct___12 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___12 *);
	void (*dcd_change)(struct tty_struct___12 *, unsigned int);
	struct module___67 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___12 *, int);
};

struct tty_ldisc___12 {
	struct tty_ldisc_ops___12 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___12 *tty;
};

struct tty_port_operations___12 {
	int (*carrier_raised)(struct tty_port___12 *);
	void (*dtr_rts)(struct tty_port___12 *, int);
	void (*shutdown)(struct tty_port___12 *);
	void (*drop)(struct tty_port___12 *);
	int (*activate)(struct tty_port___12 *, struct tty_struct___12 *);
	void (*destruct)(struct tty_port___12 *);
};

struct kmem_cache_cpu___119 {
	void **freelist;
	long unsigned int tid;
	struct page___132 *page;
	struct page___132 *partial;
};

struct memcg_cache_params___119 {
	bool is_root_cache;
	union {
		struct kmem_cache___119 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___119 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct module_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___66 *, struct module_kobject___66 *, char *);
	ssize_t (*store)(struct module_attribute___66 *, struct module_kobject___66 *, const char *, size_t);
	void (*setup)(struct module___67 *, const char *);
	int (*test)(struct module___67 *);
	void (*free)(struct module___67 *);
};

struct signal_struct___132 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___132 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___132 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___75 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct___12 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___133 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___106 *, char *);
	ssize_t (*store)(struct bus_type___106 *, const char *, size_t);
};

struct device_attribute___106;

struct driver_attribute___106;

struct bus_type___106 {
	const char *name;
	const char *dev_name;
	struct device___106 *dev_root;
	struct bus_attribute___106 *bus_attrs;
	struct device_attribute___106 *dev_attrs;
	struct driver_attribute___106 *drv_attrs;
	const struct attribute_group___99 **bus_groups;
	const struct attribute_group___99 **dev_groups;
	const struct attribute_group___99 **drv_groups;
	int (*match)(struct device___106 *, struct device_driver___106 *);
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	int (*probe)(struct device___106 *);
	int (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*online)(struct device___106 *);
	int (*offline)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct device___106 *, struct device_attribute___106 *, char *);
	ssize_t (*store)(struct device___106 *, struct device_attribute___106 *, const char *, size_t);
};

struct driver_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___106 *, char *);
	ssize_t (*store)(struct device_driver___106 *, const char *, size_t);
};

struct device_driver___106 {
	const char *name;
	struct bus_type___106 *bus;
	struct module___67 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___106 *);
	int (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	const struct attribute_group___99 **groups;
	const struct dev_pm_ops___106 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___106 {
	const char *name;
	const struct attribute_group___99 **groups;
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
};

struct class_attribute___106;

struct class___106 {
	const char *name;
	struct module___67 *owner;
	struct class_attribute___106 *class_attrs;
	struct device_attribute___106 *dev_attrs;
	const struct attribute_group___99 **dev_groups;
	struct bin_attribute___99 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *);
	void (*class_release)(struct class___106 *);
	void (*dev_release)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
	struct subsys_private *p;
};

struct class_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct class___106 *, struct class_attribute___106 *, char *);
	ssize_t (*store)(struct class___106 *, struct class_attribute___106 *, const char *, size_t);
	const void * (*namespace)(struct class___106 *, const struct class_attribute___106 *);
};

struct device_rh___106 {
	struct dev_pm_info_rh___106 power;
};

struct seq_operations___98 {
	void * (*start)(struct seq_file___99 *, loff_t *);
	void (*stop)(struct seq_file___99 *, void *);
	void * (*next)(struct seq_file___99 *, void *, loff_t *);
	int (*show)(struct seq_file___99 *, void *);
};

struct dquot_warn {
	struct super_block___132 *w_sb;
	struct kqid w_dq_id;
	short int w_type;
};

typedef __u64 __le64;

struct qtree_fmt_operations {
	void (*mem2disk_dqblk)(void *, struct dquot___132 *);
	void (*disk2mem_dqblk)(struct dquot___132 *, void *);
	int (*is_id)(void *, struct dquot___132 *);
};

struct qtree_mem_dqinfo {
	struct super_block___132 *dqi_sb;
	int dqi_type;
	unsigned int dqi_blocks;
	unsigned int dqi_free_blk;
	unsigned int dqi_free_entry;
	unsigned int dqi_blocksize_bits;
	unsigned int dqi_entry_size;
	unsigned int dqi_usable_bs;
	unsigned int dqi_qtree_depth;
	struct qtree_fmt_operations *dqi_ops;
};

struct v2_disk_dqheader {
	__le32 dqh_magic;
	__le32 dqh_version;
};

struct v2r0_disk_dqblk {
	__le32 dqb_id;
	__le32 dqb_ihardlimit;
	__le32 dqb_isoftlimit;
	__le32 dqb_curinodes;
	__le32 dqb_bhardlimit;
	__le32 dqb_bsoftlimit;
	__le64 dqb_curspace;
	__le64 dqb_btime;
	__le64 dqb_itime;
};

struct v2r1_disk_dqblk {
	__le32 dqb_id;
	__le32 dqb_pad;
	__le64 dqb_ihardlimit;
	__le64 dqb_isoftlimit;
	__le64 dqb_curinodes;
	__le64 dqb_bhardlimit;
	__le64 dqb_bsoftlimit;
	__le64 dqb_curspace;
	__le64 dqb_btime;
	__le64 dqb_itime;
};

struct v2_disk_dqinfo {
	__le32 dqi_bgrace;
	__le32 dqi_igrace;
	__le32 dqi_flags;
	__le32 dqi_blocks;
	__le32 dqi_free_blk;
	__le32 dqi_free_entry;
};

struct qt_disk_dqdbheader {
	__le32 dqdh_next_free;
	__le32 dqdh_prev_free;
	__le16 dqdh_entries;
	__le16 dqdh_pad1;
	__le32 dqdh_pad2;
};

struct if_dqblk {
	__u64 dqb_bhardlimit;
	__u64 dqb_bsoftlimit;
	__u64 dqb_curspace;
	__u64 dqb_ihardlimit;
	__u64 dqb_isoftlimit;
	__u64 dqb_curinodes;
	__u64 dqb_btime;
	__u64 dqb_itime;
	__u32 dqb_valid;
};

struct compat_if_dqblk {
	compat_u64 dqb_bhardlimit;
	compat_u64 dqb_bsoftlimit;
	compat_u64 dqb_curspace;
	compat_u64 dqb_ihardlimit;
	compat_u64 dqb_isoftlimit;
	compat_u64 dqb_curinodes;
	compat_u64 dqb_btime;
	compat_u64 dqb_itime;
	compat_uint_t dqb_valid;
} __attribute__((packed));

struct compat_fs_qfilestat {
	compat_u64 dqb_bhardlimit;
	compat_u64 qfs_nblks;
	compat_uint_t qfs_nextents;
} __attribute__((packed));

struct compat_fs_quota_stat {
	__s8 qs_version;
	char: 8;
	__u16 qs_flags;
	__s8 qs_pad;
	int: 24;
	struct compat_fs_qfilestat qs_uquota;
	struct compat_fs_qfilestat qs_gquota;
	compat_uint_t qs_incoredqs;
	compat_int_t qs_btimelimit;
	compat_int_t qs_itimelimit;
	compat_int_t qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
} __attribute__((packed));

struct page___133;

typedef struct page___133 *pgtable_t___133;

struct address_space___133;

struct kmem_cache___120;

struct page___133 {
	long unsigned int flags;
	struct address_space___133 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___133 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___133 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___120 *slab_cache;
		struct page___133 *first_page;
	};
	long: 64;
};

struct task_struct___133;

struct pv_cpu_ops___133 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___133 *);
	void (*end_context_switch)(struct task_struct___133 *);
};

struct mutex___134 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___133 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___129 {
	struct page___133 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___138;

struct nsproxy___79;

struct signal_struct___133;

struct task_struct___133 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___133 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___138 *mm;
	struct mm_struct___138 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___133 *real_parent;
	struct task_struct___133 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___133 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___75 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___133 = 0,
		VTIME_USER___133 = 1,
		VTIME_SYS___133 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___79 *nsproxy;
	struct signal_struct___133 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___134 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___129 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___138 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___138 *, struct mm_struct___138 *);
	void (*dup_mmap)(struct mm_struct___138 *, struct mm_struct___138 *);
	void (*exit_mmap)(struct mm_struct___138 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___138 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___138 *);
	void (*pgd_free)(struct mm_struct___138 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___138 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___138 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___138 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___138 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___138 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___138 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___138 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___138 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___138 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___138 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___138 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___134 lock;
	void *vdso;
} mm_context_t___134;

struct xol_area___133;

struct uprobes_state___133 {
	struct xol_area___133 *xol_area;
};

struct vm_area_struct___138;

struct file___133;

struct core_state___133;

struct mm_struct___138 {
	struct vm_area_struct___138 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___138 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___138 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___134 context;
	long unsigned int flags;
	struct core_state___133 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___133 *owner;
	struct file___133 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___133 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___68;

struct module_kobject___67 {
	struct kobject___7 kobj;
	struct module___68 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___67;

struct module___68 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___67 mkobj;
	struct module_attribute___67 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___133 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct ctl_table_header___17;

struct ctl_node___17 {
	struct rb_node node;
	struct ctl_table_header___17 *header;
};

struct ctl_table_root___17;

struct ctl_table_set___17;

struct ctl_dir___17;

struct ctl_table_header___17 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___17 *root;
	struct ctl_table_set___17 *set;
	struct ctl_dir___17 *parent;
	struct ctl_node___17 *node;
};

struct ctl_dir___17 {
	struct ctl_table_header___17 header;
	struct rb_root root;
};

struct ctl_table_set___17 {
	int (*is_seen)(struct ctl_table_set___17 *);
	struct ctl_dir___17 dir;
};

struct ctl_table_root___17 {
	struct ctl_table_set___17 default_set;
	struct ctl_table_set___17 * (*lookup)(struct ctl_table_root___17 *, struct nsproxy___79 *);
	int (*permissions)(struct ctl_table_header___17 *, struct ctl_table *);
};

struct net___17;

struct nsproxy___79 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___17 *net_ns;
};

struct zone___133;

struct lruvec___133 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___133 *zone;
};

struct pglist_data___133;

struct zone___133 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___133 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___133 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___133 {
	struct zone___133 *zone;
	int zone_idx;
};

struct zonelist___133 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___133 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___133 {
	struct zone___133 node_zones[4];
	struct zonelist___133 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___133 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___96;

struct x86_io_apic_ops___96 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___96 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___96;

struct irq_data___96 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___96 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___107;

struct dev_pm_ops___107 {
	int (*prepare)(struct device___107 *);
	void (*complete)(struct device___107 *);
	int (*suspend)(struct device___107 *);
	int (*resume)(struct device___107 *);
	int (*freeze)(struct device___107 *);
	int (*thaw)(struct device___107 *);
	int (*poweroff)(struct device___107 *);
	int (*restore)(struct device___107 *);
	int (*suspend_late)(struct device___107 *);
	int (*resume_early)(struct device___107 *);
	int (*freeze_late)(struct device___107 *);
	int (*thaw_early)(struct device___107 *);
	int (*poweroff_late)(struct device___107 *);
	int (*restore_early)(struct device___107 *);
	int (*suspend_noirq)(struct device___107 *);
	int (*resume_noirq)(struct device___107 *);
	int (*freeze_noirq)(struct device___107 *);
	int (*thaw_noirq)(struct device___107 *);
	int (*poweroff_noirq)(struct device___107 *);
	int (*restore_noirq)(struct device___107 *);
	int (*runtime_suspend)(struct device___107 *);
	int (*runtime_resume)(struct device___107 *);
	int (*runtime_idle)(struct device___107 *);
};

struct dma_map_ops___35;

struct dev_archdata___35 {
	struct dma_map_ops___35 *dma_ops;
	void *iommu;
};

struct device_type___107;

struct bus_type___107;

struct device_driver___107;

struct dev_pm_domain___107;

struct class___107;

struct attribute_group___100;

struct device_rh___107;

struct device___107 {
	struct device___107 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___107 *type;
	struct mutex___134 mutex;
	struct bus_type___107 *bus;
	struct device_driver___107 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___107 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___35 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___107 *class;
	const struct attribute_group___100 **groups;
	void (*release)(struct device___107 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___107 *device_rh;
};

struct dev_pm_info_rh___107 {
	void (*set_latency_tolerance)(struct device___107 *, s32);
};

struct dev_pm_domain___107 {
	struct dev_pm_ops___107 ops;
};

struct smp_ops___133 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___133 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___100;

struct attribute_group___100 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___100 **bin_attrs;
};

struct bin_attribute___100 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___133 *, struct kobject___7 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___133 *, struct kobject___7 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	int (*mmap)(struct file___133 *, struct kobject___7 *, struct bin_attribute___100 *, struct vm_area_struct___138 *);
};

struct dentry___133;

struct path___133 {
	struct vfsmount *mnt;
	struct dentry___133 *dentry;
};

struct inode___133;

struct file_operations___133;

struct file___133 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___133 f_path;
	struct inode___133 *f_inode;
	const struct file_operations___133 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___133 *f_mapping;
	struct mutex___134 f_pos_lock;
};

struct vm_operations_struct___119;

struct vm_area_struct___138 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___138 *vm_next;
	struct vm_area_struct___138 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___138 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___119 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___133 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___67 *, struct module_kobject___67 *, char *);
	ssize_t (*store)(struct module_attribute___67 *, struct module_kobject___67 *, const char *, size_t);
	void (*setup)(struct module___68 *, const char *);
	int (*test)(struct module___68 *);
	void (*free)(struct module___68 *);
};

struct dentry_operations___133;

struct super_block___133;

struct dentry___133 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___133 *d_parent;
	struct qstr d_name;
	struct inode___133 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___133 *d_op;
	struct super_block___133 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___133;

struct address_space___133 {
	struct inode___133 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___134 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___133 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___133;

struct file_lock___133;

struct dquot___133;

struct block_device___133;

struct inode___133 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___133 *i_op;
	struct super_block___133 *i_sb;
	struct address_space___133 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___134 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___133 *i_fop;
	struct file_lock___133 *i_flock;
	struct address_space___133 i_data;
	struct dquot___133 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___133 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___133 {
	int (*d_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_hash)(const struct dentry___133 *, struct qstr *);
	int (*d_compare)(const struct dentry___133 *, const struct dentry___133 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___133 *);
	void (*d_release)(struct dentry___133 *);
	void (*d_prune)(struct dentry___133 *);
	void (*d_iput)(struct dentry___133 *, struct inode___133 *);
	char * (*d_dname)(struct dentry___133 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___133 *);
	int (*d_manage)(struct dentry___133 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___133;

struct mem_dqinfo___133 {
	struct quota_format_type___133 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___133;

struct quota_info___133 {
	unsigned int flags;
	struct mutex___134 dqio_mutex;
	struct mutex___134 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___133 *files[2];
	struct mem_dqinfo___133 info[2];
	const struct quota_format_ops___133 *ops[2];
};

struct file_system_type___133;

struct super_operations___133;

struct dquot_operations___133;

struct quotactl_ops___133;

struct super_block___133 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___133 *s_type;
	const struct super_operations___133 *s_op;
	const struct dquot_operations___133 *dq_op;
	const struct quotactl_ops___133 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___133 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___133 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___133 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___134 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___133 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___133 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___133 *bd_inode;
	struct super_block___133 *bd_super;
	struct mutex___134 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___133 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___134 bd_fsfreeze_mutex;
};

struct iattr___133 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___133 *ia_file;
};

struct dquot___133 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___134 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___133 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

enum {
	QUOTA_NL_C_UNSPEC = 0,
	QUOTA_NL_C_WARNING = 1,
	__QUOTA_NL_C_MAX = 2,
};

enum {
	QUOTA_NL_A_UNSPEC = 0,
	QUOTA_NL_A_QTYPE = 1,
	QUOTA_NL_A_EXCESS_ID = 2,
	QUOTA_NL_A_WARNING = 3,
	QUOTA_NL_A_DEV_MAJOR = 4,
	QUOTA_NL_A_DEV_MINOR = 5,
	QUOTA_NL_A_CAUSED_ID = 6,
	__QUOTA_NL_A_MAX = 7,
};

struct quota_format_type___133 {
	int qf_fmt_id;
	const struct quota_format_ops___133 *qf_ops;
	struct module___68 *qf_owner;
	struct quota_format_type___133 *qf_next;
};

struct quota_format_ops___133 {
	int (*check_quota_file)(struct super_block___133 *, int);
	int (*read_file_info)(struct super_block___133 *, int);
	int (*write_file_info)(struct super_block___133 *, int);
	int (*free_file_info)(struct super_block___133 *, int);
	int (*read_dqblk)(struct dquot___133 *);
	int (*commit_dqblk)(struct dquot___133 *);
	int (*release_dqblk)(struct dquot___133 *);
};

struct dquot_operations___133 {
	int (*write_dquot)(struct dquot___133 *);
	struct dquot___133 * (*alloc_dquot)(struct super_block___133 *, int);
	void (*destroy_dquot)(struct dquot___133 *);
	int (*acquire_dquot)(struct dquot___133 *);
	int (*release_dquot)(struct dquot___133 *);
	int (*mark_dirty)(struct dquot___133 *);
	int (*write_info)(struct super_block___133 *, int);
	qsize_t * (*get_reserved_space)(struct inode___133 *);
};

struct quotactl_ops___133 {
	int (*quota_on)(struct super_block___133 *, int, int, struct path___133 *);
	int (*quota_on_meta)(struct super_block___133 *, int, int);
	int (*quota_off)(struct super_block___133 *, int);
	int (*quota_sync)(struct super_block___133 *, int);
	int (*get_info)(struct super_block___133 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___133 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___133 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___133 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___133 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___133 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___133 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___133 *, unsigned int);
};

struct address_space_operations___133 {
	int (*writepage)(struct page___133 *, struct writeback_control *);
	int (*readpage)(struct file___133 *, struct page___133 *);
	int (*writepages)(struct address_space___133 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___133 *);
	int (*readpages)(struct file___133 *, struct address_space___133 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___133 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___133 **, void **);
	int (*write_end)(struct file___133 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___133 *, void *);
	sector_t (*bmap)(struct address_space___133 *, sector_t);
	void (*invalidatepage)(struct page___133 *, long unsigned int);
	int (*releasepage)(struct page___133 *, gfp_t);
	void (*freepage)(struct page___133 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___133 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___133 *, struct page___133 *, struct page___133 *, enum migrate_mode);
	int (*launder_page)(struct page___133 *);
	int (*is_partially_uptodate)(struct page___133 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___133 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___133 *, struct page___133 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___133 *, sector_t *);
	void (*swap_deactivate)(struct file___133 *);
	void (*invalidatepage_range)(struct page___133 *, unsigned int, unsigned int);
};

struct inode_operations___133 {
	struct dentry___133 * (*lookup)(struct inode___133 *, struct dentry___133 *, unsigned int);
	void * (*follow_link)(struct dentry___133 *, struct nameidata *);
	int (*permission)(struct inode___133 *, int);
	struct posix_acl * (*get_acl)(struct inode___133 *, int);
	int (*readlink)(struct dentry___133 *, char *, int);
	void (*put_link)(struct dentry___133 *, struct nameidata *, void *);
	int (*create)(struct inode___133 *, struct dentry___133 *, umode_t, bool);
	int (*link)(struct dentry___133 *, struct inode___133 *, struct dentry___133 *);
	int (*unlink)(struct inode___133 *, struct dentry___133 *);
	int (*symlink)(struct inode___133 *, struct dentry___133 *, const char *);
	int (*mkdir)(struct inode___133 *, struct dentry___133 *, umode_t);
	int (*rmdir)(struct inode___133 *, struct dentry___133 *);
	int (*mknod)(struct inode___133 *, struct dentry___133 *, umode_t, dev_t);
	int (*rename)(struct inode___133 *, struct dentry___133 *, struct inode___133 *, struct dentry___133 *);
	int (*setattr)(struct dentry___133 *, struct iattr___133 *);
	int (*getattr)(struct vfsmount *, struct dentry___133 *, struct kstat *);
	int (*setxattr)(struct dentry___133 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___133 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___133 *, char *, size_t);
	int (*removexattr)(struct dentry___133 *, const char *);
	int (*fiemap)(struct inode___133 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___133 *, struct timespec *, int);
	int (*atomic_open)(struct inode___133 *, struct dentry___133 *, struct file___133 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___100;

struct file_operations___133 {
	struct module___68 *owner;
	loff_t (*llseek)(struct file___133 *, loff_t, int);
	ssize_t (*read)(struct file___133 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___133 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___133 *, void *, filldir_t);
	unsigned int (*poll)(struct file___133 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___133 *, struct vm_area_struct___138 *);
	int (*open)(struct inode___133 *, struct file___133 *);
	int (*flush)(struct file___133 *, fl_owner_t);
	int (*release)(struct inode___133 *, struct file___133 *);
	int (*fsync)(struct file___133 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___133 *, int);
	int (*lock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*sendpage)(struct file___133 *, struct page___133 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___133 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___133 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___133 *, long int, struct file_lock___133 **, void **);
		struct {
			int (*setlease)(struct file___133 *, long int, struct file_lock___133 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___133 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___100 *, struct file___133 *);
};

struct fasync_struct___133;

struct file_lock_operations___133;

struct lock_manager_operations___133;

struct file_lock___133 {
	struct file_lock___133 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___75 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___133 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___133 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___133 *fl_ops;
	const struct lock_manager_operations___133 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___133 {
	void (*fl_copy_lock)(struct file_lock___133 *, struct file_lock___133 *);
	void (*fl_release_private)(struct file_lock___133 *);
};

struct lock_manager_operations___133 {
	int (*lm_compare_owner)(struct file_lock___133 *, struct file_lock___133 *);
	long unsigned int (*lm_owner_key)(struct file_lock___133 *);
	void (*lm_notify)(struct file_lock___133 *);
	int (*lm_grant)(struct file_lock___133 *, struct file_lock___133 *, int);
	void (*lm_break)(struct file_lock___133 *);
	int (*lm_change)(struct file_lock___133 **, int);
};

struct fasync_struct___133 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___133 *fa_next;
	struct file___133 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___133 {
	const char *name;
	int fs_flags;
	struct dentry___133 * (*mount)(struct file_system_type___133 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___133 *);
	struct module___68 *owner;
	struct file_system_type___133 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___133 {
	struct inode___133 * (*alloc_inode)(struct super_block___133 *);
	void (*destroy_inode)(struct inode___133 *);
	void (*dirty_inode)(struct inode___133 *, int);
	int (*write_inode)(struct inode___133 *, struct writeback_control *);
	int (*drop_inode)(struct inode___133 *);
	void (*evict_inode)(struct inode___133 *);
	void (*put_super)(struct super_block___133 *);
	int (*sync_fs)(struct super_block___133 *, int);
	int (*freeze_fs)(struct super_block___133 *);
	int (*unfreeze_fs)(struct super_block___133 *);
	int (*statfs)(struct dentry___133 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___133 *, int *, char *);
	void (*umount_begin)(struct super_block___133 *);
	int (*show_options)(struct seq_file___100 *, struct dentry___133 *);
	int (*show_devname)(struct seq_file___100 *, struct dentry___133 *);
	int (*show_path)(struct seq_file___100 *, struct dentry___133 *);
	int (*show_stats)(struct seq_file___100 *, struct dentry___133 *);
	ssize_t (*quota_read)(struct super_block___133 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___133 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___133 *);
	int (*bdev_try_to_free_page)(struct super_block___133 *, struct page___133 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___133 *);
	void (*free_cached_objects)(struct super_block___133 *, int);
};

struct seq_operations___99;

struct seq_file___100 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___134 lock;
	const struct seq_operations___99 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___133 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___133 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___120;

struct memcg_cache_params___120;

struct kmem_cache___120 {
	struct kmem_cache_cpu___120 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___120 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___116;

struct vm_operations_struct___119 {
	void (*open)(struct vm_area_struct___138 *);
	void (*close)(struct vm_area_struct___138 *);
	int (*fault)(struct vm_area_struct___138 *, struct vm_fault___116 *);
	int (*page_mkwrite)(struct vm_area_struct___138 *, struct vm_fault___116 *);
	int (*access)(struct vm_area_struct___138 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___138 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___138 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___138 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___138 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___133 {
	struct task_struct___133 *task;
	struct core_thread___133 *next;
};

struct core_state___133 {
	atomic_t nr_threads;
	struct core_thread___133 dumper;
	struct completion startup;
};

struct signal_struct___133 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___133 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___133 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___75 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___134 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___120 {
	void **freelist;
	long unsigned int tid;
	struct page___133 *page;
	struct page___133 *partial;
};

struct memcg_cache_params___120 {
	bool is_root_cache;
	union {
		struct kmem_cache___120 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___120 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct netns_core___16 {
	struct ctl_table_header___17 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___16 {
	struct mutex___134 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___16 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___17 *ctl;
};

struct netns_ipv4___16 {
	struct ctl_table_header___17 *forw_hdr;
	struct ctl_table_header___17 *frags_hdr;
	struct ctl_table_header___17 *ipv4_hdr;
	struct ctl_table_header___17 *route_hdr;
	struct ctl_table_header___17 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___16 {
	struct ctl_table_header___17 *hdr;
	struct ctl_table_header___17 *route_hdr;
	struct ctl_table_header___17 *icmp_hdr;
	struct ctl_table_header___17 *frags_hdr;
	struct ctl_table_header___17 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___16 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___16 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *);
	int (*local_out)(struct sk_buff___12 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___12 *, const void *);
	struct kmem_cache___120 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___16 {
	struct netns_sysctl_ipv6___16 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___16 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___16 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___17 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___16 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___17 *nf_log_dir_header;
};

struct nf_proto_net___16 {
	struct ctl_table_header___17 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___16 {
	struct nf_proto_net___16 pn;
	unsigned int timeout;
};

struct nf_tcp_net___16 {
	struct nf_proto_net___16 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___16 {
	struct nf_proto_net___16 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___16 {
	struct nf_proto_net___16 pn;
	unsigned int timeout;
};

struct nf_ip_net___16 {
	struct nf_generic_net___16 generic;
	struct nf_tcp_net___16 tcp;
	struct nf_udp_net___16 udp;
	struct nf_icmp_net___16 icmp;
	struct nf_icmp_net___16 icmpv6;
};

struct netns_ct___16 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___17 *sysctl_header;
	struct ctl_table_header___17 *acct_sysctl_header;
	struct ctl_table_header___17 *tstamp_sysctl_header;
	struct ctl_table_header___17 *event_sysctl_header;
	struct ctl_table_header___17 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___120 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___16 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___16 {
	struct netns_sysctl_ipv6___16 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___16 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___17 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___16 xfrm4_dst_ops;
	struct dst_ops___16 xfrm6_dst_ops;
};

struct net___17 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___17 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___16 core;
	struct netns_mib mib;
	struct netns_packet___16 packet;
	struct netns_unix___16 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___16 ipv4;
	struct netns_ipv6___16 ipv6;
	struct netns_sctp___16 sctp;
	struct netns_dccp___7 dccp;
	struct netns_nf___16 nf;
	struct netns_xt xt;
	struct netns_ct___16 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___16 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___9 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___16 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___134 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___134 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___35 {
	void * (*alloc)(struct device___107 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___107 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___107 *, struct vm_area_struct___138 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___107 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___107 *, struct page___133 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___107 *, dma_addr_t);
	int (*dma_supported)(struct device___107 *, u64);
	int (*set_dma_mask)(struct device___107 *, u64);
	int is_phys;
};

struct bus_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___107 *, char *);
	ssize_t (*store)(struct bus_type___107 *, const char *, size_t);
};

struct device_attribute___107;

struct driver_attribute___107;

struct bus_type___107 {
	const char *name;
	const char *dev_name;
	struct device___107 *dev_root;
	struct bus_attribute___107 *bus_attrs;
	struct device_attribute___107 *dev_attrs;
	struct driver_attribute___107 *drv_attrs;
	const struct attribute_group___100 **bus_groups;
	const struct attribute_group___100 **dev_groups;
	const struct attribute_group___100 **drv_groups;
	int (*match)(struct device___107 *, struct device_driver___107 *);
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	int (*probe)(struct device___107 *);
	int (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*online)(struct device___107 *);
	int (*offline)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct device___107 *, struct device_attribute___107 *, char *);
	ssize_t (*store)(struct device___107 *, struct device_attribute___107 *, const char *, size_t);
};

struct driver_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___107 *, char *);
	ssize_t (*store)(struct device_driver___107 *, const char *, size_t);
};

struct device_driver___107 {
	const char *name;
	struct bus_type___107 *bus;
	struct module___68 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___107 *);
	int (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	const struct attribute_group___100 **groups;
	const struct dev_pm_ops___107 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___107 {
	const char *name;
	const struct attribute_group___100 **groups;
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
};

struct class_attribute___107;

struct class___107 {
	const char *name;
	struct module___68 *owner;
	struct class_attribute___107 *class_attrs;
	struct device_attribute___107 *dev_attrs;
	const struct attribute_group___100 **dev_groups;
	struct bin_attribute___100 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *);
	void (*class_release)(struct class___107 *);
	void (*dev_release)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
	struct subsys_private *p;
};

struct class_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct class___107 *, struct class_attribute___107 *, char *);
	ssize_t (*store)(struct class___107 *, struct class_attribute___107 *, const char *, size_t);
	const void * (*namespace)(struct class___107 *, const struct class_attribute___107 *);
};

struct device_rh___107 {
	struct dev_pm_info_rh___107 power;
};

struct vm_fault___116 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___133 *page;
};

struct netlink_callback___9 {
	struct sk_buff___12 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___12 *, struct netlink_callback___9 *);
	int (*done)(struct netlink_callback___9 *);
	void *data;
	struct module___68 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct nf_afinfo___16 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___12 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___12 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___17 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___12 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___12 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___96 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___96 *);
	void (*irq_shutdown)(struct irq_data___96 *);
	void (*irq_enable)(struct irq_data___96 *);
	void (*irq_disable)(struct irq_data___96 *);
	void (*irq_ack)(struct irq_data___96 *);
	void (*irq_mask)(struct irq_data___96 *);
	void (*irq_mask_ack)(struct irq_data___96 *);
	void (*irq_unmask)(struct irq_data___96 *);
	void (*irq_eoi)(struct irq_data___96 *);
	int (*irq_set_affinity)(struct irq_data___96 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___96 *);
	int (*irq_set_type)(struct irq_data___96 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___96 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___96 *);
	void (*irq_bus_sync_unlock)(struct irq_data___96 *);
	void (*irq_cpu_online)(struct irq_data___96 *);
	void (*irq_cpu_offline)(struct irq_data___96 *);
	void (*irq_suspend)(struct irq_data___96 *);
	void (*irq_resume)(struct irq_data___96 *);
	void (*irq_pm_shutdown)(struct irq_data___96 *);
	void (*irq_print_chip)(struct irq_data___96 *, struct seq_file___100 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___96 *, void *);
	long unsigned int flags;
};

struct seq_operations___99 {
	void * (*start)(struct seq_file___100 *, loff_t *);
	void (*stop)(struct seq_file___100 *, void *);
	void * (*next)(struct seq_file___100 *, void *, loff_t *);
	int (*show)(struct seq_file___100 *, void *);
};

struct genl_ops___2;

struct genl_info___2;

struct genl_family___2 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___2 *, struct sk_buff___12 *, struct genl_info___2 *);
	void (*post_doit)(const struct genl_ops___2 *, struct sk_buff___12 *, struct genl_info___2 *);
	struct nlattr **attrbuf;
	const struct genl_ops___2 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module___68 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___2 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___12 *, struct genl_info___2 *);
	int (*dumpit)(struct sk_buff___12 *, struct netlink_callback___9 *);
	int (*done)(struct netlink_callback___9 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___2 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___17 *_net;
	void *user_ptr[2];
	struct sock *dst_sk;
};

struct proc_dir_entry___3 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___50 *proc_iops;
	const struct file_operations___50 *proc_fops;
	struct proc_dir_entry___3 *next;
	struct proc_dir_entry___3 *parent;
	struct proc_dir_entry___3 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct proc_ns_operations___7 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___51 *);
	void (*put)(void *);
	int (*install)(struct nsproxy *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___4 {
	void *ns;
	const struct proc_ns_operations___7 *ns_ops;
};

union proc_op___2 {
	int (*proc_get_link)(struct dentry___51 *, struct path___50 *);
	int (*proc_read)(struct task_struct___51 *, char *);
	int (*proc_show)(struct seq_file___34 *, struct pid_namespace *, struct pid___20 *, struct task_struct___51 *);
};

struct proc_inode___2 {
	struct pid___20 *pid;
	int fd;
	union proc_op___2 op;
	struct proc_dir_entry___3 *pde;
	struct ctl_table_header___17 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___4 ns;
	struct inode___51 vfs_inode;
};

struct proc_maps_private {
	struct pid___20 *pid;
	struct task_struct___51 *task;
	struct vm_area_struct___54 *tail_vma;
	struct mempolicy *task_mempolicy;
};

struct mem_size_stats {
	struct vm_area_struct___54 *vma;
	long unsigned int resident;
	long unsigned int shared_clean;
	long unsigned int shared_dirty;
	long unsigned int private_clean;
	long unsigned int private_dirty;
	long unsigned int referenced;
	long unsigned int anonymous;
	long unsigned int anonymous_thp;
	long unsigned int swap;
	long unsigned int nonlinear;
	u64 pss;
};

typedef struct {
	u64 pme;
} pagemap_entry_t;

struct pagemapread {
	int pos;
	int len;
	pagemap_entry_t *buffer;
};

struct numa_maps {
	struct vm_area_struct___54 *vma;
	long unsigned int pages;
	long unsigned int anon;
	long unsigned int active;
	long unsigned int writeback;
	long unsigned int mapcount_max;
	long unsigned int dirty;
	long unsigned int swapcache;
	long unsigned int node[1024];
};

struct numa_maps_private {
	struct proc_maps_private proc_maps;
	struct numa_maps md;
};

struct ctl_table_header___18;

struct ctl_node___18 {
	struct rb_node node;
	struct ctl_table_header___18 *header;
};

struct ctl_table_root___18;

struct ctl_table_set___18;

struct ctl_dir___18;

struct ctl_table_header___18 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___18 *root;
	struct ctl_table_set___18 *set;
	struct ctl_dir___18 *parent;
	struct ctl_node___18 *node;
};

struct ctl_dir___18 {
	struct ctl_table_header___18 header;
	struct rb_root root;
};

struct ctl_table_set___18 {
	int (*is_seen)(struct ctl_table_set___18 *);
	struct ctl_dir___18 dir;
};

struct ctl_table_root___18 {
	struct ctl_table_set___18 default_set;
	struct ctl_table_set___18 * (*lookup)(struct ctl_table_root___18 *, struct nsproxy___67 *);
	int (*permissions)(struct ctl_table_header___18 *, struct ctl_table *);
};

struct proc_ns_operations___8 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___115 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___67 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___5 {
	void *ns;
	const struct proc_ns_operations___8 *ns_ops;
};

struct proc_dir_entry___4 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___115 *proc_iops;
	const struct file_operations___115 *proc_fops;
	struct proc_dir_entry___4 *next;
	struct proc_dir_entry___4 *parent;
	struct proc_dir_entry___4 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

union proc_op___3 {
	int (*proc_get_link)(struct dentry___115 *, struct path___115 *);
	int (*proc_read)(struct task_struct___115 *, char *);
	int (*proc_show)(struct seq_file___87 *, struct pid_namespace___65 *, struct pid___65 *, struct task_struct___115 *);
};

struct proc_inode___3 {
	struct pid___65 *pid;
	int fd;
	union proc_op___3 op;
	struct proc_dir_entry___4 *pde;
	struct ctl_table_header___18 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___5 ns;
	struct inode___115 vfs_inode;
};

struct pde_opener {
	struct file___115 *file;
	struct list_head lh;
	int closing;
	struct completion *c;
};

enum {
	BIAS = 2147483648,
};

struct match_token {
	int token;
	const char *pattern;
};

enum {
	MAX_OPT_ARGS = 3,
};

typedef struct {
	char *from;
	char *to;
} substring_t;

enum {
	Opt_gid = 0,
	Opt_hidepid = 1,
	Opt_err = 2,
};

struct page___134;

typedef struct page___134 *pgtable_t___134;

struct address_space___134;

struct kmem_cache___121;

struct page___134 {
	long unsigned int flags;
	struct address_space___134 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___134 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___134 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___121 *slab_cache;
		struct page___134 *first_page;
	};
	long: 64;
};

struct task_struct___134;

struct pv_cpu_ops___134 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___134 *);
	void (*end_context_switch)(struct task_struct___134 *);
};

struct pid___76;

struct pid_link___76 {
	struct hlist_node node;
	struct pid___76 *pid;
};

struct mutex___135 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___134 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___130 {
	struct page___134 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___139;

struct fs_struct___15;

struct files_struct___10;

struct nsproxy___80;

struct signal_struct___134;

struct css_set___91;

struct task_struct___134 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___134 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___139 *mm;
	struct mm_struct___139 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___134 *real_parent;
	struct task_struct___134 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___134 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___76 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___134 = 0,
		VTIME_USER___134 = 1,
		VTIME_SYS___134 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct___15 *fs;
	struct files_struct___10 *files;
	struct nsproxy___80 *nsproxy;
	struct signal_struct___134 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___91 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___135 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___130 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___139 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___139 *, struct mm_struct___139 *);
	void (*dup_mmap)(struct mm_struct___139 *, struct mm_struct___139 *);
	void (*exit_mmap)(struct mm_struct___139 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___139 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___139 *);
	void (*pgd_free)(struct mm_struct___139 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___139 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___139 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___139 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___139 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___139 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___139 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___139 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___139 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___139 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___139 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___139 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___135 lock;
	void *vdso;
} mm_context_t___135;

struct xol_area___134;

struct uprobes_state___134 {
	struct xol_area___134 *xol_area;
};

struct vm_area_struct___139;

struct file___134;

struct linux_binfmt___17;

struct core_state___134;

struct mm_struct___139 {
	struct vm_area_struct___139 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___139 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___139 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___17 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___135 context;
	long unsigned int flags;
	struct core_state___134 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___134 *owner;
	struct file___134 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___134 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___69;

struct module_kobject___68 {
	struct kobject___7 kobj;
	struct module___69 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___68;

struct module___69 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___68 mkobj;
	struct module_attribute___68 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___134 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___134;

struct dentry_operations___134;

struct super_block___134;

struct dentry___134 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___134 *d_parent;
	struct qstr d_name;
	struct inode___134 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___134 *d_op;
	struct super_block___134 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___134;

struct address_space___134 {
	struct inode___134 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___135 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___134 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___134;

struct file_operations___134;

struct file_lock___134;

struct dquot___134;

struct block_device___134;

struct cdev___39;

struct inode___134 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___134 *i_op;
	struct super_block___134 *i_sb;
	struct address_space___134 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___135 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___134 *i_fop;
	struct file_lock___134 *i_flock;
	struct address_space___134 i_data;
	struct dquot___134 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___134 *i_bdev;
		struct cdev___39 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___28;

struct path___134;

struct dentry_operations___134 {
	int (*d_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_hash)(const struct dentry___134 *, struct qstr *);
	int (*d_compare)(const struct dentry___134 *, const struct dentry___134 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___134 *);
	void (*d_release)(struct dentry___134 *);
	void (*d_prune)(struct dentry___134 *);
	void (*d_iput)(struct dentry___134 *, struct inode___134 *);
	char * (*d_dname)(struct dentry___134 *, char *, int);
	struct vfsmount___28 * (*d_automount)(struct path___134 *);
	int (*d_manage)(struct dentry___134 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___134;

struct mem_dqinfo___134 {
	struct quota_format_type___134 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___134;

struct quota_info___134 {
	unsigned int flags;
	struct mutex___135 dqio_mutex;
	struct mutex___135 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___134 *files[2];
	struct mem_dqinfo___134 info[2];
	const struct quota_format_ops___134 *ops[2];
};

struct file_system_type___134;

struct super_operations___134;

struct dquot_operations___134;

struct quotactl_ops___134;

struct xattr_handler___91;

struct super_block___134 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___134 *s_type;
	const struct super_operations___134 *s_op;
	const struct dquot_operations___134 *dq_op;
	const struct quotactl_ops___134 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___134 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___91 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___134 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___134 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___135 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___134 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___28 {
	struct dentry___134 *mnt_root;
	struct super_block___134 *mnt_sb;
	int mnt_flags;
};

struct path___134 {
	struct vfsmount___28 *mnt;
	struct dentry___134 *dentry;
};

struct pid_namespace___76;

struct upid___76 {
	int nr;
	struct pid_namespace___76 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___76 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___134 *child_reaper;
	struct kmem_cache___121 *pid_cachep;
	unsigned int level;
	struct pid_namespace___76 *parent;
	struct vfsmount___28 *proc_mnt;
	struct dentry___134 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___76 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___76 numbers[1];
};

struct irq_data___97;

struct x86_io_apic_ops___97 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___97 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___97;

struct irq_data___97 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___97 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___134 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___134 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___134 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___134 *bd_inode;
	struct super_block___134 *bd_super;
	struct mutex___135 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___134 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___135 bd_fsfreeze_mutex;
};

struct cgroup___91;

struct cgroup_subsys_state___91 {
	struct cgroup___91 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___134 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___134 *ia_file;
};

struct fown_struct___76 {
	rwlock_t lock;
	struct pid___76 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___134 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___134 f_path;
	struct inode___134 *f_inode;
	const struct file_operations___134 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___76 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___134 *f_mapping;
	struct mutex___135 f_pos_lock;
};

struct zone___134;

struct lruvec___134 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___134 *zone;
};

struct pglist_data___134;

struct zone___134 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___134 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___134 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___134 {
	struct zone___134 *zone;
	int zone_idx;
};

struct zonelist___134 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___134 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___134 {
	struct zone___134 node_zones[4];
	struct zonelist___134 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___134 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___134 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___135 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___134 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___134 {
	int qf_fmt_id;
	const struct quota_format_ops___134 *qf_ops;
	struct module___69 *qf_owner;
	struct quota_format_type___134 *qf_next;
};

struct quota_format_ops___134 {
	int (*check_quota_file)(struct super_block___134 *, int);
	int (*read_file_info)(struct super_block___134 *, int);
	int (*write_file_info)(struct super_block___134 *, int);
	int (*free_file_info)(struct super_block___134 *, int);
	int (*read_dqblk)(struct dquot___134 *);
	int (*commit_dqblk)(struct dquot___134 *);
	int (*release_dqblk)(struct dquot___134 *);
};

struct dquot_operations___134 {
	int (*write_dquot)(struct dquot___134 *);
	struct dquot___134 * (*alloc_dquot)(struct super_block___134 *, int);
	void (*destroy_dquot)(struct dquot___134 *);
	int (*acquire_dquot)(struct dquot___134 *);
	int (*release_dquot)(struct dquot___134 *);
	int (*mark_dirty)(struct dquot___134 *);
	int (*write_info)(struct super_block___134 *, int);
	qsize_t * (*get_reserved_space)(struct inode___134 *);
};

struct quotactl_ops___134 {
	int (*quota_on)(struct super_block___134 *, int, int, struct path___134 *);
	int (*quota_on_meta)(struct super_block___134 *, int, int);
	int (*quota_off)(struct super_block___134 *, int);
	int (*quota_sync)(struct super_block___134 *, int);
	int (*get_info)(struct super_block___134 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___134 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___134 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___134 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___134 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___134 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___134 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___134 *, unsigned int);
};

struct swap_info_struct___32;

struct address_space_operations___134 {
	int (*writepage)(struct page___134 *, struct writeback_control *);
	int (*readpage)(struct file___134 *, struct page___134 *);
	int (*writepages)(struct address_space___134 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___134 *);
	int (*readpages)(struct file___134 *, struct address_space___134 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___134 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___134 **, void **);
	int (*write_end)(struct file___134 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___134 *, void *);
	sector_t (*bmap)(struct address_space___134 *, sector_t);
	void (*invalidatepage)(struct page___134 *, long unsigned int);
	int (*releasepage)(struct page___134 *, gfp_t);
	void (*freepage)(struct page___134 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___134 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___134 *, struct page___134 *, struct page___134 *, enum migrate_mode);
	int (*launder_page)(struct page___134 *);
	int (*is_partially_uptodate)(struct page___134 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___134 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___134 *, struct page___134 *);
	int (*swap_activate)(struct swap_info_struct___32 *, struct file___134 *, sector_t *);
	void (*swap_deactivate)(struct file___134 *);
	void (*invalidatepage_range)(struct page___134 *, unsigned int, unsigned int);
};

struct swap_info_struct___32 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___134 *bdev;
	struct file___134 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___39 {
	struct kobject___7 kobj;
	struct module___69 *owner;
	const struct file_operations___134 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct nameidata___16;

struct inode_operations___134 {
	struct dentry___134 * (*lookup)(struct inode___134 *, struct dentry___134 *, unsigned int);
	void * (*follow_link)(struct dentry___134 *, struct nameidata___16 *);
	int (*permission)(struct inode___134 *, int);
	struct posix_acl * (*get_acl)(struct inode___134 *, int);
	int (*readlink)(struct dentry___134 *, char *, int);
	void (*put_link)(struct dentry___134 *, struct nameidata___16 *, void *);
	int (*create)(struct inode___134 *, struct dentry___134 *, umode_t, bool);
	int (*link)(struct dentry___134 *, struct inode___134 *, struct dentry___134 *);
	int (*unlink)(struct inode___134 *, struct dentry___134 *);
	int (*symlink)(struct inode___134 *, struct dentry___134 *, const char *);
	int (*mkdir)(struct inode___134 *, struct dentry___134 *, umode_t);
	int (*rmdir)(struct inode___134 *, struct dentry___134 *);
	int (*mknod)(struct inode___134 *, struct dentry___134 *, umode_t, dev_t);
	int (*rename)(struct inode___134 *, struct dentry___134 *, struct inode___134 *, struct dentry___134 *);
	int (*setattr)(struct dentry___134 *, struct iattr___134 *);
	int (*getattr)(struct vfsmount___28 *, struct dentry___134 *, struct kstat *);
	int (*setxattr)(struct dentry___134 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___134 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___134 *, char *, size_t);
	int (*removexattr)(struct dentry___134 *, const char *);
	int (*fiemap)(struct inode___134 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___134 *, struct timespec *, int);
	int (*atomic_open)(struct inode___134 *, struct dentry___134 *, struct file___134 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___10 *fl_owner_t___10;

struct poll_table_struct___85;

struct seq_file___101;

struct file_operations___134 {
	struct module___69 *owner;
	loff_t (*llseek)(struct file___134 *, loff_t, int);
	ssize_t (*read)(struct file___134 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___134 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___134 *, void *, filldir_t);
	unsigned int (*poll)(struct file___134 *, struct poll_table_struct___85 *);
	long int (*unlocked_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___134 *, struct vm_area_struct___139 *);
	int (*open)(struct inode___134 *, struct file___134 *);
	int (*flush)(struct file___134 *, fl_owner_t___10);
	int (*release)(struct inode___134 *, struct file___134 *);
	int (*fsync)(struct file___134 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___134 *, int);
	int (*lock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*sendpage)(struct file___134 *, struct page___134 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___134 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___134 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___134 *, long int, struct file_lock___134 **, void **);
		struct {
			int (*setlease)(struct file___134 *, long int, struct file_lock___134 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___134 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___101 *, struct file___134 *);
};

struct fasync_struct___134;

struct file_lock_operations___134;

struct lock_manager_operations___134;

struct file_lock___134 {
	struct file_lock___134 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___10 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___76 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___134 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___134 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___134 *fl_ops;
	const struct lock_manager_operations___134 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct fdtable___10 {
	unsigned int max_fds;
	struct file___134 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___10 {
	atomic_t count;
	struct fdtable___10 *fdt;
	struct fdtable___10 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___134 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___134 {
	void (*fl_copy_lock)(struct file_lock___134 *, struct file_lock___134 *);
	void (*fl_release_private)(struct file_lock___134 *);
};

struct lock_manager_operations___134 {
	int (*lm_compare_owner)(struct file_lock___134 *, struct file_lock___134 *);
	long unsigned int (*lm_owner_key)(struct file_lock___134 *);
	void (*lm_notify)(struct file_lock___134 *);
	int (*lm_grant)(struct file_lock___134 *, struct file_lock___134 *, int);
	void (*lm_break)(struct file_lock___134 *);
	int (*lm_change)(struct file_lock___134 **, int);
};

struct fasync_struct___134 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___134 *fa_next;
	struct file___134 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___134 {
	const char *name;
	int fs_flags;
	struct dentry___134 * (*mount)(struct file_system_type___134 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___134 *);
	struct module___69 *owner;
	struct file_system_type___134 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___134 {
	struct inode___134 * (*alloc_inode)(struct super_block___134 *);
	void (*destroy_inode)(struct inode___134 *);
	void (*dirty_inode)(struct inode___134 *, int);
	int (*write_inode)(struct inode___134 *, struct writeback_control *);
	int (*drop_inode)(struct inode___134 *);
	void (*evict_inode)(struct inode___134 *);
	void (*put_super)(struct super_block___134 *);
	int (*sync_fs)(struct super_block___134 *, int);
	int (*freeze_fs)(struct super_block___134 *);
	int (*unfreeze_fs)(struct super_block___134 *);
	int (*statfs)(struct dentry___134 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___134 *, int *, char *);
	void (*umount_begin)(struct super_block___134 *);
	int (*show_options)(struct seq_file___101 *, struct dentry___134 *);
	int (*show_devname)(struct seq_file___101 *, struct dentry___134 *);
	int (*show_path)(struct seq_file___101 *, struct dentry___134 *);
	int (*show_stats)(struct seq_file___101 *, struct dentry___134 *);
	ssize_t (*quota_read)(struct super_block___134 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___134 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___134 *);
	int (*bdev_try_to_free_page)(struct super_block___134 *, struct page___134 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___134 *);
	void (*free_cached_objects)(struct super_block___134 *, int);
};

struct xattr_handler___91 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___134 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___134 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___134 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___87)(struct file___134 *, wait_queue_head_t *, struct poll_table_struct___85 *);

struct poll_table_struct___85 {
	poll_queue_proc___87 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___120;

struct vm_area_struct___139 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___139 *vm_next;
	struct vm_area_struct___139 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___139 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___120 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___134 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___100;

struct seq_file___101 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___135 lock;
	const struct seq_operations___100 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___16 {
	struct path___134 path;
	struct qstr last;
	struct path___134 root;
	struct inode___134 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___134 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___134 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___121;

struct memcg_cache_params___121;

struct kmem_cache___121 {
	struct kmem_cache_cpu___121 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___121 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___117;

struct vm_operations_struct___120 {
	void (*open)(struct vm_area_struct___139 *);
	void (*close)(struct vm_area_struct___139 *);
	int (*fault)(struct vm_area_struct___139 *, struct vm_fault___117 *);
	int (*page_mkwrite)(struct vm_area_struct___139 *, struct vm_fault___117 *);
	int (*access)(struct vm_area_struct___139 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___139 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___139 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___139 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___139 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___134 {
	struct task_struct___134 *task;
	struct core_thread___134 *next;
};

struct core_state___134 {
	atomic_t nr_threads;
	struct core_thread___134 dumper;
	struct completion startup;
};

struct linux_binprm___18;

struct coredump_params___17;

struct linux_binfmt___17 {
	struct list_head lh;
	struct module___69 *module;
	int (*load_binary)(struct linux_binprm___18 *);
	int (*load_shlib)(struct file___134 *);
	int (*core_dump)(struct coredump_params___17 *);
	long unsigned int min_coredump;
};

struct ctl_table_header___19;

struct ctl_node___19 {
	struct rb_node node;
	struct ctl_table_header___19 *header;
};

struct ctl_table_root___19;

struct ctl_table_set___19;

struct ctl_dir___19;

struct ctl_table_header___19 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___19 *root;
	struct ctl_table_set___19 *set;
	struct ctl_dir___19 *parent;
	struct ctl_node___19 *node;
};

struct ctl_dir___19 {
	struct ctl_table_header___19 header;
	struct rb_root root;
};

struct ctl_table_set___19 {
	int (*is_seen)(struct ctl_table_set___19 *);
	struct ctl_dir___19 dir;
};

struct ctl_table_root___19 {
	struct ctl_table_set___19 default_set;
	struct ctl_table_set___19 * (*lookup)(struct ctl_table_root___19 *, struct nsproxy___80 *);
	int (*permissions)(struct ctl_table_header___19 *, struct ctl_table *);
};

struct nsproxy___80 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___76 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___134 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___134 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___134 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___76 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___76 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___135 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___15 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___134 root;
	struct path___134 pwd;
};

struct css_set___91 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___91 *subsys[11];
	struct callback_head callback_head;
};

struct seq_operations___100 {
	void * (*start)(struct seq_file___101 *, loff_t *);
	void (*stop)(struct seq_file___101 *, void *);
	void * (*next)(struct seq_file___101 *, void *, loff_t *);
	int (*show)(struct seq_file___101 *, void *);
};

struct vm_fault___117 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___134 *page;
};

struct kmem_cache_cpu___121 {
	void **freelist;
	long unsigned int tid;
	struct page___134 *page;
	struct page___134 *partial;
};

struct memcg_cache_params___121 {
	bool is_root_cache;
	union {
		struct kmem_cache___121 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___121 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___91;

struct cgroup___91 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___91 *parent;
	struct dentry___134 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___91 *subsys[11];
	struct cgroupfs_root___91 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___135 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___91 {
	struct super_block___134 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___91 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___43 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___134 *, struct file___134 *);
	ssize_t (*read)(struct cgroup___91 *, struct cftype___43 *, struct file___134 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___91 *, struct cftype___43 *);
	s64 (*read_s64)(struct cgroup___91 *, struct cftype___43 *);
	int (*read_map)(struct cgroup___91 *, struct cftype___43 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___91 *, struct cftype___43 *, struct seq_file___101 *);
	ssize_t (*write)(struct cgroup___91 *, struct cftype___43 *, struct file___134 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___91 *, struct cftype___43 *, u64);
	int (*write_s64)(struct cgroup___91 *, struct cftype___43 *, s64);
	int (*write_string)(struct cgroup___91 *, struct cftype___43 *, const char *);
	int (*trigger)(struct cgroup___91 *, unsigned int);
	int (*release)(struct inode___134 *, struct file___134 *);
	int (*register_event)(struct cgroup___91 *, struct cftype___43 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___91 *, struct cftype___43 *, struct eventfd_ctx *);
};

struct cftype_set___41 {
	struct list_head node;
	struct cftype___43 *cfts;
};

struct task_and_cgroup___41 {
	struct task_struct___134 *task;
	struct cgroup___91 *cgrp;
	struct css_set___91 *cg;
};

struct cgroup_taskset___41 {
	struct task_and_cgroup___41 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___91 *cur_cgrp;
};

struct cgroup_subsys___41 {
	struct cgroup_subsys_state___91 * (*css_alloc)(struct cgroup___91 *);
	int (*css_online)(struct cgroup___91 *);
	void (*css_offline)(struct cgroup___91 *);
	void (*css_free)(struct cgroup___91 *);
	int (*can_attach)(struct cgroup___91 *, struct cgroup_taskset___41 *);
	void (*cancel_attach)(struct cgroup___91 *, struct cgroup_taskset___41 *);
	void (*attach)(struct cgroup___91 *, struct cgroup_taskset___41 *);
	void (*fork)(struct task_struct___134 *);
	void (*exit)(struct cgroup___91 *, struct cgroup___91 *, struct task_struct___134 *);
	void (*bind)(struct cgroup___91 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___91 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___43 *base_cftypes;
	struct cftype_set___41 base_cftset;
	struct module___69 *module;
};

struct irq_chip___97 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___97 *);
	void (*irq_shutdown)(struct irq_data___97 *);
	void (*irq_enable)(struct irq_data___97 *);
	void (*irq_disable)(struct irq_data___97 *);
	void (*irq_ack)(struct irq_data___97 *);
	void (*irq_mask)(struct irq_data___97 *);
	void (*irq_mask_ack)(struct irq_data___97 *);
	void (*irq_unmask)(struct irq_data___97 *);
	void (*irq_eoi)(struct irq_data___97 *);
	int (*irq_set_affinity)(struct irq_data___97 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___97 *);
	int (*irq_set_type)(struct irq_data___97 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___97 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___97 *);
	void (*irq_bus_sync_unlock)(struct irq_data___97 *);
	void (*irq_cpu_online)(struct irq_data___97 *);
	void (*irq_cpu_offline)(struct irq_data___97 *);
	void (*irq_suspend)(struct irq_data___97 *);
	void (*irq_resume)(struct irq_data___97 *);
	void (*irq_pm_shutdown)(struct irq_data___97 *);
	void (*irq_print_chip)(struct irq_data___97 *, struct seq_file___101 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___97 *, void *);
	long unsigned int flags;
};

struct proc_dir_entry___5 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___134 *proc_iops;
	const struct file_operations___134 *proc_fops;
	struct proc_dir_entry___5 *next;
	struct proc_dir_entry___5 *parent;
	struct proc_dir_entry___5 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct module_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___68 *, struct module_kobject___68 *, char *);
	ssize_t (*store)(struct module_attribute___68 *, struct module_kobject___68 *, const char *, size_t);
	void (*setup)(struct module___69 *, const char *);
	int (*test)(struct module___69 *);
	void (*free)(struct module___69 *);
};

struct linux_binprm___18 {
	char buf[128];
	struct vm_area_struct___139 *vma;
	long unsigned int vma_pages;
	struct mm_struct___139 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___134 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct proc_ns_operations___9 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___134 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___80 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___6 {
	void *ns;
	const struct proc_ns_operations___9 *ns_ops;
};

struct coredump_params___17 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___134 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

union proc_op___4 {
	int (*proc_get_link)(struct dentry___134 *, struct path___134 *);
	int (*proc_read)(struct task_struct___134 *, char *);
	int (*proc_show)(struct seq_file___101 *, struct pid_namespace___76 *, struct pid___76 *, struct task_struct___134 *);
};

struct proc_inode___4 {
	struct pid___76 *pid;
	int fd;
	union proc_op___4 op;
	struct proc_dir_entry___5 *pde;
	struct ctl_table_header___19 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___6 ns;
	struct inode___134 vfs_inode;
};

typedef struct dentry___134 *instantiate_t(struct inode___134 *, struct dentry___134 *, struct task_struct___134 *, const void *);

struct pid_entry {
	char *name;
	int len;
	umode_t mode;
	const struct inode_operations___134 *iop;
	const struct file_operations___134 *fop;
	union proc_op___4 op;
};

struct limit_names {
	char *name;
	char *unit;
};

struct tgid_iter {
	unsigned int tgid;
	struct task_struct___134 *task;
};

struct page___135;

typedef struct page___135 *pgtable_t___135;

struct address_space___135;

struct kmem_cache___122;

struct page___135 {
	long unsigned int flags;
	struct address_space___135 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___135 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___135 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___122 *slab_cache;
		struct page___135 *first_page;
	};
	long: 64;
};

struct task_struct___135;

struct pv_cpu_ops___135 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___135 *);
	void (*end_context_switch)(struct task_struct___135 *);
};

struct pid___77;

struct pid_link___77 {
	struct hlist_node node;
	struct pid___77 *pid;
};

struct mutex___136 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___135 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___131 {
	struct page___135 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___140;

struct files_struct___11;

struct nsproxy___81;

struct signal_struct___135;

struct css_set___92;

struct task_struct___135 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___135 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___140 *mm;
	struct mm_struct___140 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___135 *real_parent;
	struct task_struct___135 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___135 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___77 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___135 = 0,
		VTIME_USER___135 = 1,
		VTIME_SYS___135 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct___11 *files;
	struct nsproxy___81 *nsproxy;
	struct signal_struct___135 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___92 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___136 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___131 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___140 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___140 *, struct mm_struct___140 *);
	void (*dup_mmap)(struct mm_struct___140 *, struct mm_struct___140 *);
	void (*exit_mmap)(struct mm_struct___140 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___140 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___140 *);
	void (*pgd_free)(struct mm_struct___140 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___140 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___140 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___140 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___140 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___140 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___140 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___140 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___140 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___140 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___140 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___140 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___136 lock;
	void *vdso;
} mm_context_t___136;

struct xol_area___135;

struct uprobes_state___135 {
	struct xol_area___135 *xol_area;
};

struct vm_area_struct___140;

struct file___135;

struct linux_binfmt___18;

struct core_state___135;

struct mm_struct___140 {
	struct vm_area_struct___140 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___140 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___140 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___18 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___136 context;
	long unsigned int flags;
	struct core_state___135 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___135 *owner;
	struct file___135 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___135 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___72 {
	struct task_struct___135 *task;
	struct exec_domain___35 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___98;

struct x86_io_apic_ops___98 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___98 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___98;

struct irq_data___98 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___98 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___108;

struct dev_pm_ops___108 {
	int (*prepare)(struct device___108 *);
	void (*complete)(struct device___108 *);
	int (*suspend)(struct device___108 *);
	int (*resume)(struct device___108 *);
	int (*freeze)(struct device___108 *);
	int (*thaw)(struct device___108 *);
	int (*poweroff)(struct device___108 *);
	int (*restore)(struct device___108 *);
	int (*suspend_late)(struct device___108 *);
	int (*resume_early)(struct device___108 *);
	int (*freeze_late)(struct device___108 *);
	int (*thaw_early)(struct device___108 *);
	int (*poweroff_late)(struct device___108 *);
	int (*restore_early)(struct device___108 *);
	int (*suspend_noirq)(struct device___108 *);
	int (*resume_noirq)(struct device___108 *);
	int (*freeze_noirq)(struct device___108 *);
	int (*thaw_noirq)(struct device___108 *);
	int (*poweroff_noirq)(struct device___108 *);
	int (*restore_noirq)(struct device___108 *);
	int (*runtime_suspend)(struct device___108 *);
	int (*runtime_resume)(struct device___108 *);
	int (*runtime_idle)(struct device___108 *);
};

struct device_type___108;

struct bus_type___108;

struct device_driver___108;

struct dev_pm_domain___108;

struct class___108;

struct attribute_group___101;

struct device_rh___108;

struct device___108 {
	struct device___108 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___108 *type;
	struct mutex___136 mutex;
	struct bus_type___108 *bus;
	struct device_driver___108 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___108 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___35 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___108 *class;
	const struct attribute_group___101 **groups;
	void (*release)(struct device___108 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___108 *device_rh;
};

struct dev_pm_info_rh___108 {
	void (*set_latency_tolerance)(struct device___108 *, s32);
};

struct dev_pm_domain___108 {
	struct dev_pm_ops___108 ops;
};

struct smp_ops___135 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___135 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___135;

struct lruvec___135 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___135 *zone;
};

struct pglist_data___135;

struct zone___135 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___135 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___135 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___135 {
	struct zone___135 *zone;
	int zone_idx;
};

struct zonelist___135 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___135 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___135 {
	struct zone___135 node_zones[4];
	struct zonelist___135 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___135 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___102;

struct irq_chip___98 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___98 *);
	void (*irq_shutdown)(struct irq_data___98 *);
	void (*irq_enable)(struct irq_data___98 *);
	void (*irq_disable)(struct irq_data___98 *);
	void (*irq_ack)(struct irq_data___98 *);
	void (*irq_mask)(struct irq_data___98 *);
	void (*irq_mask_ack)(struct irq_data___98 *);
	void (*irq_unmask)(struct irq_data___98 *);
	void (*irq_eoi)(struct irq_data___98 *);
	int (*irq_set_affinity)(struct irq_data___98 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___98 *);
	int (*irq_set_type)(struct irq_data___98 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___98 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___98 *);
	void (*irq_bus_sync_unlock)(struct irq_data___98 *);
	void (*irq_cpu_online)(struct irq_data___98 *);
	void (*irq_cpu_offline)(struct irq_data___98 *);
	void (*irq_suspend)(struct irq_data___98 *);
	void (*irq_resume)(struct irq_data___98 *);
	void (*irq_pm_shutdown)(struct irq_data___98 *);
	void (*irq_print_chip)(struct irq_data___98 *, struct seq_file___102 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___98 *, void *);
	long unsigned int flags;
};

struct seq_operations___101;

struct seq_file___102 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___136 lock;
	const struct seq_operations___101 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct inode_operations___135;

struct file_operations___135;

struct proc_dir_entry___6 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___135 *proc_iops;
	const struct file_operations___135 *proc_fops;
	struct proc_dir_entry___6 *next;
	struct proc_dir_entry___6 *parent;
	struct proc_dir_entry___6 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct xol_area___135 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___135 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___122;

struct memcg_cache_params___122;

struct kmem_cache___122 {
	struct kmem_cache_cpu___122 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___122 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___135;

struct address_space_operations___135;

struct address_space___135 {
	struct inode___135 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___136 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___135 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___135;

struct path___135 {
	struct vfsmount *mnt;
	struct dentry___135 *dentry;
};

struct fown_struct___77 {
	rwlock_t lock;
	struct pid___77 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___135 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___135 f_path;
	struct inode___135 *f_inode;
	const struct file_operations___135 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___77 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___135 *f_mapping;
	struct mutex___136 f_pos_lock;
};

struct vm_operations_struct___121;

struct vm_area_struct___140 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___140 *vm_next;
	struct vm_area_struct___140 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___140 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___121 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___135 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___118;

struct vm_operations_struct___121 {
	void (*open)(struct vm_area_struct___140 *);
	void (*close)(struct vm_area_struct___140 *);
	int (*fault)(struct vm_area_struct___140 *, struct vm_fault___118 *);
	int (*page_mkwrite)(struct vm_area_struct___140 *, struct vm_fault___118 *);
	int (*access)(struct vm_area_struct___140 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___140 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___140 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___140 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___140 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___135 {
	struct task_struct___135 *task;
	struct core_thread___135 *next;
};

struct core_state___135 {
	atomic_t nr_threads;
	struct core_thread___135 dumper;
	struct completion startup;
};

struct linux_binprm___19;

struct coredump_params___18;

struct linux_binfmt___18 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___19 *);
	int (*load_shlib)(struct file___135 *);
	int (*core_dump)(struct coredump_params___18 *);
	long unsigned int min_coredump;
};

struct pid_namespace___77;

struct upid___77 {
	int nr;
	struct pid_namespace___77 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___77 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___135 *child_reaper;
	struct kmem_cache___122 *pid_cachep;
	unsigned int level;
	struct pid_namespace___77 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___135 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___77 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___77 numbers[1];
};

struct nsproxy___81 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___77 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___13;

struct signal_struct___135 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___135 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___135 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___77 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___77 *tty_old_pgrp;
	int leader;
	struct tty_struct___13 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___136 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___13;

struct tty_operations___13;

struct tty_ldisc___13;

struct fasync_struct___135;

struct tty_port___13;

struct tty_struct___13 {
	int magic;
	struct kref kref;
	struct device___108 *dev;
	struct tty_driver___13 *driver;
	const struct tty_operations___13 *ops;
	int index;
	struct mutex___136 ldisc_mutex;
	struct tty_ldisc___13 *ldisc;
	struct mutex___136 atomic_write_lock;
	struct mutex___136 legacy_mutex;
	struct mutex___136 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___77 *pgrp;
	struct pid___77 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___13 *link;
	struct fasync_struct___135 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___13 *port;
	struct ld_semaphore ldisc_sem;
};

struct fdtable___11 {
	unsigned int max_fds;
	struct file___135 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___11 {
	atomic_t count;
	struct fdtable___11 *fdt;
	struct fdtable___11 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___135 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_subsys_state___92;

struct css_set___92 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___92 *subsys[11];
	struct callback_head callback_head;
};

struct dentry_operations___135;

struct super_block___135;

struct dentry___135 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___135 *d_parent;
	struct qstr d_name;
	struct inode___135 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___135 *d_op;
	struct super_block___135 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct file_lock___135;

struct dquot___135;

struct block_device___135;

struct cdev___40;

struct inode___135 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___135 *i_op;
	struct super_block___135 *i_sb;
	struct address_space___135 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___136 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___135 *i_fop;
	struct file_lock___135 *i_flock;
	struct address_space___135 i_data;
	struct dquot___135 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___135 *i_bdev;
		struct cdev___40 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___135 {
	int (*d_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_hash)(const struct dentry___135 *, struct qstr *);
	int (*d_compare)(const struct dentry___135 *, const struct dentry___135 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___135 *);
	void (*d_release)(struct dentry___135 *);
	void (*d_prune)(struct dentry___135 *);
	void (*d_iput)(struct dentry___135 *, struct inode___135 *);
	char * (*d_dname)(struct dentry___135 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___135 *);
	int (*d_manage)(struct dentry___135 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___135;

struct mem_dqinfo___135 {
	struct quota_format_type___135 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___135;

struct quota_info___135 {
	unsigned int flags;
	struct mutex___136 dqio_mutex;
	struct mutex___136 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___135 *files[2];
	struct mem_dqinfo___135 info[2];
	const struct quota_format_ops___135 *ops[2];
};

struct file_system_type___135;

struct super_operations___135;

struct dquot_operations___135;

struct quotactl_ops___135;

struct xattr_handler___92;

struct super_block___135 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___135 *s_type;
	const struct super_operations___135 *s_op;
	const struct dquot_operations___135 *dq_op;
	const struct quotactl_ops___135 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___135 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___92 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___135 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___135 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___136 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___135 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___135 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___135 *bd_inode;
	struct super_block___135 *bd_super;
	struct mutex___136 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___135 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___136 bd_fsfreeze_mutex;
};

struct cgroup___92;

struct cgroup_subsys_state___92 {
	struct cgroup___92 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___135 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___135 *ia_file;
};

struct dquot___135 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___136 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___135 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___135 {
	int qf_fmt_id;
	const struct quota_format_ops___135 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___135 *qf_next;
};

struct quota_format_ops___135 {
	int (*check_quota_file)(struct super_block___135 *, int);
	int (*read_file_info)(struct super_block___135 *, int);
	int (*write_file_info)(struct super_block___135 *, int);
	int (*free_file_info)(struct super_block___135 *, int);
	int (*read_dqblk)(struct dquot___135 *);
	int (*commit_dqblk)(struct dquot___135 *);
	int (*release_dqblk)(struct dquot___135 *);
};

struct dquot_operations___135 {
	int (*write_dquot)(struct dquot___135 *);
	struct dquot___135 * (*alloc_dquot)(struct super_block___135 *, int);
	void (*destroy_dquot)(struct dquot___135 *);
	int (*acquire_dquot)(struct dquot___135 *);
	int (*release_dquot)(struct dquot___135 *);
	int (*mark_dirty)(struct dquot___135 *);
	int (*write_info)(struct super_block___135 *, int);
	qsize_t * (*get_reserved_space)(struct inode___135 *);
};

struct quotactl_ops___135 {
	int (*quota_on)(struct super_block___135 *, int, int, struct path___135 *);
	int (*quota_on_meta)(struct super_block___135 *, int, int);
	int (*quota_off)(struct super_block___135 *, int);
	int (*quota_sync)(struct super_block___135 *, int);
	int (*get_info)(struct super_block___135 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___135 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___135 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___135 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___135 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___135 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___135 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___135 *, unsigned int);
};

struct swap_info_struct___33;

struct address_space_operations___135 {
	int (*writepage)(struct page___135 *, struct writeback_control *);
	int (*readpage)(struct file___135 *, struct page___135 *);
	int (*writepages)(struct address_space___135 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___135 *);
	int (*readpages)(struct file___135 *, struct address_space___135 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___135 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___135 **, void **);
	int (*write_end)(struct file___135 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___135 *, void *);
	sector_t (*bmap)(struct address_space___135 *, sector_t);
	void (*invalidatepage)(struct page___135 *, long unsigned int);
	int (*releasepage)(struct page___135 *, gfp_t);
	void (*freepage)(struct page___135 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___135 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___135 *, struct page___135 *, struct page___135 *, enum migrate_mode);
	int (*launder_page)(struct page___135 *);
	int (*is_partially_uptodate)(struct page___135 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___135 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___135 *, struct page___135 *);
	int (*swap_activate)(struct swap_info_struct___33 *, struct file___135 *, sector_t *);
	void (*swap_deactivate)(struct file___135 *);
	void (*invalidatepage_range)(struct page___135 *, unsigned int, unsigned int);
};

struct swap_info_struct___33 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___135 *bdev;
	struct file___135 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___40 {
	struct kobject___7 kobj;
	struct module *owner;
	const struct file_operations___135 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___135 {
	struct dentry___135 * (*lookup)(struct inode___135 *, struct dentry___135 *, unsigned int);
	void * (*follow_link)(struct dentry___135 *, struct nameidata *);
	int (*permission)(struct inode___135 *, int);
	struct posix_acl * (*get_acl)(struct inode___135 *, int);
	int (*readlink)(struct dentry___135 *, char *, int);
	void (*put_link)(struct dentry___135 *, struct nameidata *, void *);
	int (*create)(struct inode___135 *, struct dentry___135 *, umode_t, bool);
	int (*link)(struct dentry___135 *, struct inode___135 *, struct dentry___135 *);
	int (*unlink)(struct inode___135 *, struct dentry___135 *);
	int (*symlink)(struct inode___135 *, struct dentry___135 *, const char *);
	int (*mkdir)(struct inode___135 *, struct dentry___135 *, umode_t);
	int (*rmdir)(struct inode___135 *, struct dentry___135 *);
	int (*mknod)(struct inode___135 *, struct dentry___135 *, umode_t, dev_t);
	int (*rename)(struct inode___135 *, struct dentry___135 *, struct inode___135 *, struct dentry___135 *);
	int (*setattr)(struct dentry___135 *, struct iattr___135 *);
	int (*getattr)(struct vfsmount *, struct dentry___135 *, struct kstat *);
	int (*setxattr)(struct dentry___135 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___135 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___135 *, char *, size_t);
	int (*removexattr)(struct dentry___135 *, const char *);
	int (*fiemap)(struct inode___135 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___135 *, struct timespec *, int);
	int (*atomic_open)(struct inode___135 *, struct dentry___135 *, struct file___135 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___11 *fl_owner_t___11;

struct file_operations___135 {
	struct module *owner;
	loff_t (*llseek)(struct file___135 *, loff_t, int);
	ssize_t (*read)(struct file___135 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___135 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___135 *, void *, filldir_t);
	unsigned int (*poll)(struct file___135 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___135 *, struct vm_area_struct___140 *);
	int (*open)(struct inode___135 *, struct file___135 *);
	int (*flush)(struct file___135 *, fl_owner_t___11);
	int (*release)(struct inode___135 *, struct file___135 *);
	int (*fsync)(struct file___135 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___135 *, int);
	int (*lock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*sendpage)(struct file___135 *, struct page___135 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___135 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___135 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___135 *, long int, struct file_lock___135 **, void **);
		struct {
			int (*setlease)(struct file___135 *, long int, struct file_lock___135 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___135 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___102 *, struct file___135 *);
};

struct file_lock_operations___135;

struct lock_manager_operations___135;

struct file_lock___135 {
	struct file_lock___135 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___11 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___77 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___135 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___135 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___135 *fl_ops;
	const struct lock_manager_operations___135 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___135 {
	void (*fl_copy_lock)(struct file_lock___135 *, struct file_lock___135 *);
	void (*fl_release_private)(struct file_lock___135 *);
};

struct lock_manager_operations___135 {
	int (*lm_compare_owner)(struct file_lock___135 *, struct file_lock___135 *);
	long unsigned int (*lm_owner_key)(struct file_lock___135 *);
	void (*lm_notify)(struct file_lock___135 *);
	int (*lm_grant)(struct file_lock___135 *, struct file_lock___135 *, int);
	void (*lm_break)(struct file_lock___135 *);
	int (*lm_change)(struct file_lock___135 **, int);
};

struct fasync_struct___135 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___135 *fa_next;
	struct file___135 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___135 {
	const char *name;
	int fs_flags;
	struct dentry___135 * (*mount)(struct file_system_type___135 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___135 *);
	struct module *owner;
	struct file_system_type___135 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___135 {
	struct inode___135 * (*alloc_inode)(struct super_block___135 *);
	void (*destroy_inode)(struct inode___135 *);
	void (*dirty_inode)(struct inode___135 *, int);
	int (*write_inode)(struct inode___135 *, struct writeback_control *);
	int (*drop_inode)(struct inode___135 *);
	void (*evict_inode)(struct inode___135 *);
	void (*put_super)(struct super_block___135 *);
	int (*sync_fs)(struct super_block___135 *, int);
	int (*freeze_fs)(struct super_block___135 *);
	int (*unfreeze_fs)(struct super_block___135 *);
	int (*statfs)(struct dentry___135 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___135 *, int *, char *);
	void (*umount_begin)(struct super_block___135 *);
	int (*show_options)(struct seq_file___102 *, struct dentry___135 *);
	int (*show_devname)(struct seq_file___102 *, struct dentry___135 *);
	int (*show_path)(struct seq_file___102 *, struct dentry___135 *);
	int (*show_stats)(struct seq_file___102 *, struct dentry___135 *);
	ssize_t (*quota_read)(struct super_block___135 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___135 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___135 *);
	int (*bdev_try_to_free_page)(struct super_block___135 *, struct page___135 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___135 *);
	void (*free_cached_objects)(struct super_block___135 *, int);
};

struct xattr_handler___92 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___135 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___135 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___135 *, const char *, const void *, size_t, int, int);
};

struct bin_attribute___101;

struct attribute_group___101 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___101 **bin_attrs;
};

struct bin_attribute___101 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___135 *, struct kobject___7 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___135 *, struct kobject___7 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	int (*mmap)(struct file___135 *, struct kobject___7 *, struct bin_attribute___101 *, struct vm_area_struct___140 *);
};

struct tty_operations___13 {
	struct tty_struct___13 * (*lookup)(struct tty_driver___13 *, struct inode___135 *, int);
	int (*install)(struct tty_driver___13 *, struct tty_struct___13 *);
	void (*remove)(struct tty_driver___13 *, struct tty_struct___13 *);
	int (*open)(struct tty_struct___13 *, struct file___135 *);
	void (*close)(struct tty_struct___13 *, struct file___135 *);
	void (*shutdown)(struct tty_struct___13 *);
	void (*cleanup)(struct tty_struct___13 *);
	int (*write)(struct tty_struct___13 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___13 *, unsigned char);
	void (*flush_chars)(struct tty_struct___13 *);
	int (*write_room)(struct tty_struct___13 *);
	int (*chars_in_buffer)(struct tty_struct___13 *);
	int (*ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	void (*throttle)(struct tty_struct___13 *);
	void (*unthrottle)(struct tty_struct___13 *);
	void (*stop)(struct tty_struct___13 *);
	void (*start)(struct tty_struct___13 *);
	void (*hangup)(struct tty_struct___13 *);
	int (*break_ctl)(struct tty_struct___13 *, int);
	void (*flush_buffer)(struct tty_struct___13 *);
	void (*set_ldisc)(struct tty_struct___13 *);
	void (*wait_until_sent)(struct tty_struct___13 *, int);
	void (*send_xchar)(struct tty_struct___13 *, char);
	int (*tiocmget)(struct tty_struct___13 *);
	int (*tiocmset)(struct tty_struct___13 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___13 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___13 *, struct termiox *);
	int (*get_icount)(struct tty_struct___13 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___13 *, int, char *);
	int (*poll_get_char)(struct tty_driver___13 *, int);
	void (*poll_put_char)(struct tty_driver___13 *, int, char);
	const struct file_operations___135 *proc_fops;
};

struct tty_driver___13 {
	int magic;
	struct kref kref;
	struct cdev___40 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry___6 *proc_entry;
	struct tty_driver___13 *other;
	struct tty_struct___13 **ttys;
	struct tty_port___13 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___13 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___13;

struct tty_port___13 {
	struct tty_bufhead buf;
	struct tty_struct___13 *tty;
	struct tty_struct___13 *itty;
	const struct tty_port_operations___13 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___136 mutex;
	struct mutex___136 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___13 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___13 *);
	void (*close)(struct tty_struct___13 *);
	void (*flush_buffer)(struct tty_struct___13 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___13 *);
	ssize_t (*read)(struct tty_struct___13 *, struct file___135 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___13 *, struct file___135 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___13 *, struct file___135 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___13 *, struct file___135 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___13 *, struct file___135 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___13 *);
	void (*receive_buf)(struct tty_struct___13 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___13 *);
	void (*dcd_change)(struct tty_struct___13 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___13 *, int);
};

struct tty_ldisc___13 {
	struct tty_ldisc_ops___13 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___13 *tty;
};

struct tty_port_operations___13 {
	int (*carrier_raised)(struct tty_port___13 *);
	void (*dtr_rts)(struct tty_port___13 *, int);
	void (*shutdown)(struct tty_port___13 *);
	void (*drop)(struct tty_port___13 *);
	int (*activate)(struct tty_port___13 *, struct tty_struct___13 *);
	void (*destruct)(struct tty_port___13 *);
};

struct vm_fault___118 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___135 *page;
};

struct kmem_cache_cpu___122 {
	void **freelist;
	long unsigned int tid;
	struct page___135 *page;
	struct page___135 *partial;
};

struct memcg_cache_params___122 {
	bool is_root_cache;
	union {
		struct kmem_cache___122 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___122 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___92;

struct cgroup___92 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___92 *parent;
	struct dentry___135 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___92 *subsys[11];
	struct cgroupfs_root___92 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___136 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___92 {
	struct super_block___135 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___92 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___44 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___135 *, struct file___135 *);
	ssize_t (*read)(struct cgroup___92 *, struct cftype___44 *, struct file___135 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___92 *, struct cftype___44 *);
	s64 (*read_s64)(struct cgroup___92 *, struct cftype___44 *);
	int (*read_map)(struct cgroup___92 *, struct cftype___44 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___92 *, struct cftype___44 *, struct seq_file___102 *);
	ssize_t (*write)(struct cgroup___92 *, struct cftype___44 *, struct file___135 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___92 *, struct cftype___44 *, u64);
	int (*write_s64)(struct cgroup___92 *, struct cftype___44 *, s64);
	int (*write_string)(struct cgroup___92 *, struct cftype___44 *, const char *);
	int (*trigger)(struct cgroup___92 *, unsigned int);
	int (*release)(struct inode___135 *, struct file___135 *);
	int (*register_event)(struct cgroup___92 *, struct cftype___44 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___92 *, struct cftype___44 *, struct eventfd_ctx *);
};

struct cftype_set___42 {
	struct list_head node;
	struct cftype___44 *cfts;
};

struct task_and_cgroup___42 {
	struct task_struct___135 *task;
	struct cgroup___92 *cgrp;
	struct css_set___92 *cg;
};

struct cgroup_taskset___42 {
	struct task_and_cgroup___42 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___92 *cur_cgrp;
};

struct cgroup_subsys___42 {
	struct cgroup_subsys_state___92 * (*css_alloc)(struct cgroup___92 *);
	int (*css_online)(struct cgroup___92 *);
	void (*css_offline)(struct cgroup___92 *);
	void (*css_free)(struct cgroup___92 *);
	int (*can_attach)(struct cgroup___92 *, struct cgroup_taskset___42 *);
	void (*cancel_attach)(struct cgroup___92 *, struct cgroup_taskset___42 *);
	void (*attach)(struct cgroup___92 *, struct cgroup_taskset___42 *);
	void (*fork)(struct task_struct___135 *);
	void (*exit)(struct cgroup___92 *, struct cgroup___92 *, struct task_struct___135 *);
	void (*bind)(struct cgroup___92 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___92 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___44 *base_cftypes;
	struct cftype_set___42 base_cftset;
	struct module *module;
};

struct tlb_state___35 {
	struct mm_struct___140 *active_mm;
	int state;
};

struct hstate___12 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___44 cgroup_files[5];
	char name[32];
};

struct bus_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___108 *, char *);
	ssize_t (*store)(struct bus_type___108 *, const char *, size_t);
};

struct device_attribute___108;

struct driver_attribute___108;

struct bus_type___108 {
	const char *name;
	const char *dev_name;
	struct device___108 *dev_root;
	struct bus_attribute___108 *bus_attrs;
	struct device_attribute___108 *dev_attrs;
	struct driver_attribute___108 *drv_attrs;
	const struct attribute_group___101 **bus_groups;
	const struct attribute_group___101 **dev_groups;
	const struct attribute_group___101 **drv_groups;
	int (*match)(struct device___108 *, struct device_driver___108 *);
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	int (*probe)(struct device___108 *);
	int (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*online)(struct device___108 *);
	int (*offline)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct device___108 *, struct device_attribute___108 *, char *);
	ssize_t (*store)(struct device___108 *, struct device_attribute___108 *, const char *, size_t);
};

struct driver_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___108 *, char *);
	ssize_t (*store)(struct device_driver___108 *, const char *, size_t);
};

struct device_driver___108 {
	const char *name;
	struct bus_type___108 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___108 *);
	int (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	const struct attribute_group___101 **groups;
	const struct dev_pm_ops___108 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___108 {
	const char *name;
	const struct attribute_group___101 **groups;
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
};

struct class_attribute___108;

struct class___108 {
	const char *name;
	struct module *owner;
	struct class_attribute___108 *class_attrs;
	struct device_attribute___108 *dev_attrs;
	const struct attribute_group___101 **dev_groups;
	struct bin_attribute___101 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *);
	void (*class_release)(struct class___108 *);
	void (*dev_release)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
	struct subsys_private *p;
};

struct class_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct class___108 *, struct class_attribute___108 *, char *);
	ssize_t (*store)(struct class___108 *, struct class_attribute___108 *, const char *, size_t);
	const void * (*namespace)(struct class___108 *, const struct class_attribute___108 *);
};

struct device_rh___108 {
	struct dev_pm_info_rh___108 power;
};

struct seq_operations___101 {
	void * (*start)(struct seq_file___102 *, loff_t *);
	void (*stop)(struct seq_file___102 *, void *);
	void * (*next)(struct seq_file___102 *, void *, loff_t *);
	int (*show)(struct seq_file___102 *, void *);
};

struct linux_binprm___19 {
	char buf[128];
	struct vm_area_struct___140 *vma;
	long unsigned int vma_pages;
	struct mm_struct___140 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___135 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___18 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___135 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct page___136;

typedef struct page___136 *pgtable_t___136;

struct address_space___136;

struct kmem_cache___123;

struct page___136 {
	long unsigned int flags;
	struct address_space___136 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___136 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___136 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___123 *slab_cache;
		struct page___136 *first_page;
	};
	long: 64;
};

struct task_struct___136;

struct pv_cpu_ops___136 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___136 *);
	void (*end_context_switch)(struct task_struct___136 *);
};

struct mutex___137 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___136 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___132 {
	struct page___136 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___141;

struct files_struct___12;

struct signal_struct___136;

struct task_struct___136 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___136 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___141 *mm;
	struct mm_struct___141 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___136 *real_parent;
	struct task_struct___136 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___136 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___77 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___136 = 0,
		VTIME_USER___136 = 1,
		VTIME_SYS___136 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct___12 *files;
	struct nsproxy *nsproxy;
	struct signal_struct___136 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___137 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___132 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___141 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___141 *, struct mm_struct___141 *);
	void (*dup_mmap)(struct mm_struct___141 *, struct mm_struct___141 *);
	void (*exit_mmap)(struct mm_struct___141 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___141 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___141 *);
	void (*pgd_free)(struct mm_struct___141 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___141 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___141 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___141 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___141 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___141 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___141 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___141 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___141 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___141 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___141 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___141 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___137 lock;
	void *vdso;
} mm_context_t___137;

struct xol_area___136;

struct uprobes_state___136 {
	struct xol_area___136 *xol_area;
};

struct vm_area_struct___141;

struct file___136;

struct linux_binfmt___19;

struct core_state___136;

struct mm_struct___141 {
	struct vm_area_struct___141 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___141 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___141 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___19 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___137 context;
	long unsigned int flags;
	struct core_state___136 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___136 *owner;
	struct file___136 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___136 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___136 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___136 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___123;

struct memcg_cache_params___123;

struct kmem_cache___123 {
	struct kmem_cache_cpu___123 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___123 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___136;

struct address_space_operations___136;

struct address_space___136 {
	struct inode___136 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___137 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___136 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___29;

struct dentry___136;

struct path___136 {
	struct vfsmount___29 *mnt;
	struct dentry___136 *dentry;
};

struct file_operations___136;

struct file___136 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___136 f_path;
	struct inode___136 *f_inode;
	const struct file_operations___136 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___77 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___136 *f_mapping;
	struct mutex___137 f_pos_lock;
};

struct vm_area_struct___141 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___141 *vm_next;
	struct vm_area_struct___141 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___141 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___136 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___136 {
	struct task_struct___136 *task;
	struct core_thread___136 *next;
};

struct core_state___136 {
	atomic_t nr_threads;
	struct core_thread___136 dumper;
	struct completion startup;
};

struct linux_binprm___20;

struct coredump_params___19;

struct linux_binfmt___19 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___20 *);
	int (*load_shlib)(struct file___136 *);
	int (*core_dump)(struct coredump_params___19 *);
	long unsigned int min_coredump;
};

struct smp_ops___136 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___136 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___136;

struct lruvec___136 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___136 *zone;
};

struct pglist_data___136;

struct zone___136 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___136 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___136 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___136 {
	struct zone___136 *zone;
	int zone_idx;
};

struct zonelist___136 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___136 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___136 {
	struct zone___136 node_zones[4];
	struct zonelist___136 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___136 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___136 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___136 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___136 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___77 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___77 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___137 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fdtable___12 {
	unsigned int max_fds;
	struct file___136 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___12 {
	atomic_t count;
	struct fdtable___12 *fdt;
	struct fdtable___12 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___136 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___136;

struct super_block___136;

struct dentry___136 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___136 *d_parent;
	struct qstr d_name;
	struct inode___136 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___136 *d_op;
	struct super_block___136 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___136;

struct file_lock___136;

struct dquot___136;

struct block_device___136;

struct inode___136 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___136 *i_op;
	struct super_block___136 *i_sb;
	struct address_space___136 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___137 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___136 *i_fop;
	struct file_lock___136 *i_flock;
	struct address_space___136 i_data;
	struct dquot___136 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___136 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___136 {
	int (*d_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_hash)(const struct dentry___136 *, struct qstr *);
	int (*d_compare)(const struct dentry___136 *, const struct dentry___136 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___136 *);
	void (*d_release)(struct dentry___136 *);
	void (*d_prune)(struct dentry___136 *);
	void (*d_iput)(struct dentry___136 *, struct inode___136 *);
	char * (*d_dname)(struct dentry___136 *, char *, int);
	struct vfsmount___29 * (*d_automount)(struct path___136 *);
	int (*d_manage)(struct dentry___136 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___136;

struct mem_dqinfo___136 {
	struct quota_format_type___136 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___136;

struct quota_info___136 {
	unsigned int flags;
	struct mutex___137 dqio_mutex;
	struct mutex___137 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___136 *files[2];
	struct mem_dqinfo___136 info[2];
	const struct quota_format_ops___136 *ops[2];
};

struct file_system_type___136;

struct super_operations___136;

struct dquot_operations___136;

struct quotactl_ops___136;

struct super_block___136 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___136 *s_type;
	const struct super_operations___136 *s_op;
	const struct dquot_operations___136 *dq_op;
	const struct quotactl_ops___136 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___136 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___136 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___136 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___137 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___136 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___29 {
	struct dentry___136 *mnt_root;
	struct super_block___136 *mnt_sb;
	int mnt_flags;
};

struct block_device___136 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___136 *bd_inode;
	struct super_block___136 *bd_super;
	struct mutex___137 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___136 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___137 bd_fsfreeze_mutex;
};

struct iattr___136 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___136 *ia_file;
};

struct dquot___136 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___137 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___136 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___136 {
	int qf_fmt_id;
	const struct quota_format_ops___136 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___136 *qf_next;
};

struct quota_format_ops___136 {
	int (*check_quota_file)(struct super_block___136 *, int);
	int (*read_file_info)(struct super_block___136 *, int);
	int (*write_file_info)(struct super_block___136 *, int);
	int (*free_file_info)(struct super_block___136 *, int);
	int (*read_dqblk)(struct dquot___136 *);
	int (*commit_dqblk)(struct dquot___136 *);
	int (*release_dqblk)(struct dquot___136 *);
};

struct dquot_operations___136 {
	int (*write_dquot)(struct dquot___136 *);
	struct dquot___136 * (*alloc_dquot)(struct super_block___136 *, int);
	void (*destroy_dquot)(struct dquot___136 *);
	int (*acquire_dquot)(struct dquot___136 *);
	int (*release_dquot)(struct dquot___136 *);
	int (*mark_dirty)(struct dquot___136 *);
	int (*write_info)(struct super_block___136 *, int);
	qsize_t * (*get_reserved_space)(struct inode___136 *);
};

struct quotactl_ops___136 {
	int (*quota_on)(struct super_block___136 *, int, int, struct path___136 *);
	int (*quota_on_meta)(struct super_block___136 *, int, int);
	int (*quota_off)(struct super_block___136 *, int);
	int (*quota_sync)(struct super_block___136 *, int);
	int (*get_info)(struct super_block___136 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___136 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___136 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___136 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___136 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___136 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___136 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___136 *, unsigned int);
};

struct address_space_operations___136 {
	int (*writepage)(struct page___136 *, struct writeback_control *);
	int (*readpage)(struct file___136 *, struct page___136 *);
	int (*writepages)(struct address_space___136 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___136 *);
	int (*readpages)(struct file___136 *, struct address_space___136 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___136 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___136 **, void **);
	int (*write_end)(struct file___136 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___136 *, void *);
	sector_t (*bmap)(struct address_space___136 *, sector_t);
	void (*invalidatepage)(struct page___136 *, long unsigned int);
	int (*releasepage)(struct page___136 *, gfp_t);
	void (*freepage)(struct page___136 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___136 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___136 *, struct page___136 *, struct page___136 *, enum migrate_mode);
	int (*launder_page)(struct page___136 *);
	int (*is_partially_uptodate)(struct page___136 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___136 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___136 *, struct page___136 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___136 *, sector_t *);
	void (*swap_deactivate)(struct file___136 *);
	void (*invalidatepage_range)(struct page___136 *, unsigned int, unsigned int);
};

struct nameidata___17;

struct inode_operations___136 {
	struct dentry___136 * (*lookup)(struct inode___136 *, struct dentry___136 *, unsigned int);
	void * (*follow_link)(struct dentry___136 *, struct nameidata___17 *);
	int (*permission)(struct inode___136 *, int);
	struct posix_acl * (*get_acl)(struct inode___136 *, int);
	int (*readlink)(struct dentry___136 *, char *, int);
	void (*put_link)(struct dentry___136 *, struct nameidata___17 *, void *);
	int (*create)(struct inode___136 *, struct dentry___136 *, umode_t, bool);
	int (*link)(struct dentry___136 *, struct inode___136 *, struct dentry___136 *);
	int (*unlink)(struct inode___136 *, struct dentry___136 *);
	int (*symlink)(struct inode___136 *, struct dentry___136 *, const char *);
	int (*mkdir)(struct inode___136 *, struct dentry___136 *, umode_t);
	int (*rmdir)(struct inode___136 *, struct dentry___136 *);
	int (*mknod)(struct inode___136 *, struct dentry___136 *, umode_t, dev_t);
	int (*rename)(struct inode___136 *, struct dentry___136 *, struct inode___136 *, struct dentry___136 *);
	int (*setattr)(struct dentry___136 *, struct iattr___136 *);
	int (*getattr)(struct vfsmount___29 *, struct dentry___136 *, struct kstat *);
	int (*setxattr)(struct dentry___136 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___136 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___136 *, char *, size_t);
	int (*removexattr)(struct dentry___136 *, const char *);
	int (*fiemap)(struct inode___136 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___136 *, struct timespec *, int);
	int (*atomic_open)(struct inode___136 *, struct dentry___136 *, struct file___136 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___12 *fl_owner_t___12;

struct poll_table_struct___86;

struct seq_file___103;

struct file_operations___136 {
	struct module *owner;
	loff_t (*llseek)(struct file___136 *, loff_t, int);
	ssize_t (*read)(struct file___136 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___136 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___136 *, void *, filldir_t);
	unsigned int (*poll)(struct file___136 *, struct poll_table_struct___86 *);
	long int (*unlocked_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___136 *, struct vm_area_struct___141 *);
	int (*open)(struct inode___136 *, struct file___136 *);
	int (*flush)(struct file___136 *, fl_owner_t___12);
	int (*release)(struct inode___136 *, struct file___136 *);
	int (*fsync)(struct file___136 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___136 *, int);
	int (*lock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*sendpage)(struct file___136 *, struct page___136 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___136 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___136 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___136 *, long int, struct file_lock___136 **, void **);
		struct {
			int (*setlease)(struct file___136 *, long int, struct file_lock___136 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___136 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___103 *, struct file___136 *);
};

struct fasync_struct___136;

struct file_lock_operations___136;

struct lock_manager_operations___136;

struct file_lock___136 {
	struct file_lock___136 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___12 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___77 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___136 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___136 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___136 *fl_ops;
	const struct lock_manager_operations___136 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___136 {
	void (*fl_copy_lock)(struct file_lock___136 *, struct file_lock___136 *);
	void (*fl_release_private)(struct file_lock___136 *);
};

struct lock_manager_operations___136 {
	int (*lm_compare_owner)(struct file_lock___136 *, struct file_lock___136 *);
	long unsigned int (*lm_owner_key)(struct file_lock___136 *);
	void (*lm_notify)(struct file_lock___136 *);
	int (*lm_grant)(struct file_lock___136 *, struct file_lock___136 *, int);
	void (*lm_break)(struct file_lock___136 *);
	int (*lm_change)(struct file_lock___136 **, int);
};

struct fasync_struct___136 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___136 *fa_next;
	struct file___136 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___136 {
	const char *name;
	int fs_flags;
	struct dentry___136 * (*mount)(struct file_system_type___136 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___136 *);
	struct module *owner;
	struct file_system_type___136 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___136 {
	struct inode___136 * (*alloc_inode)(struct super_block___136 *);
	void (*destroy_inode)(struct inode___136 *);
	void (*dirty_inode)(struct inode___136 *, int);
	int (*write_inode)(struct inode___136 *, struct writeback_control *);
	int (*drop_inode)(struct inode___136 *);
	void (*evict_inode)(struct inode___136 *);
	void (*put_super)(struct super_block___136 *);
	int (*sync_fs)(struct super_block___136 *, int);
	int (*freeze_fs)(struct super_block___136 *);
	int (*unfreeze_fs)(struct super_block___136 *);
	int (*statfs)(struct dentry___136 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___136 *, int *, char *);
	void (*umount_begin)(struct super_block___136 *);
	int (*show_options)(struct seq_file___103 *, struct dentry___136 *);
	int (*show_devname)(struct seq_file___103 *, struct dentry___136 *);
	int (*show_path)(struct seq_file___103 *, struct dentry___136 *);
	int (*show_stats)(struct seq_file___103 *, struct dentry___136 *);
	ssize_t (*quota_read)(struct super_block___136 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___136 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___136 *);
	int (*bdev_try_to_free_page)(struct super_block___136 *, struct page___136 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___136 *);
	void (*free_cached_objects)(struct super_block___136 *, int);
};

typedef void (*poll_queue_proc___88)(struct file___136 *, wait_queue_head_t *, struct poll_table_struct___86 *);

struct poll_table_struct___86 {
	poll_queue_proc___88 _qproc;
	long unsigned int _key;
};

struct seq_operations___102;

struct seq_file___103 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___137 lock;
	const struct seq_operations___102 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___17 {
	struct path___136 path;
	struct qstr last;
	struct path___136 root;
	struct inode___136 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct kmem_cache_cpu___123 {
	void **freelist;
	long unsigned int tid;
	struct page___136 *page;
	struct page___136 *partial;
};

struct memcg_cache_params___123 {
	bool is_root_cache;
	union {
		struct kmem_cache___123 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___123 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct linux_binprm___20 {
	char buf[128];
	struct vm_area_struct___141 *vma;
	long unsigned int vma_pages;
	struct mm_struct___141 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___136 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct seq_operations___102 {
	void * (*start)(struct seq_file___103 *, loff_t *);
	void (*stop)(struct seq_file___103 *, void *);
	void * (*next)(struct seq_file___103 *, void *, loff_t *);
	int (*show)(struct seq_file___103 *, void *);
};

struct mount___7;

struct mnt_namespace___7 {
	atomic_t count;
	unsigned int proc_inum;
	struct mount___7 *root;
	struct list_head list;
	struct user_namespace *user_ns;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
};

struct mountpoint___7;

struct mount___7 {
	struct list_head mnt_hash;
	struct mount___7 *mnt_parent;
	struct dentry___136 *mnt_mountpoint;
	struct vfsmount___29 mnt;
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___7 *mnt_master;
	struct mnt_namespace___7 *mnt_ns;
	struct mountpoint___7 *mnt_mp;
	struct hlist_head mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	int mnt_pinned;
	int mnt_ghosts;
};

struct mountpoint___7 {
	struct list_head m_hash;
	struct dentry___136 *m_dentry;
	int m_count;
};

struct proc_ns_operations___10 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___136 *);
	void (*put)(void *);
	int (*install)(struct nsproxy *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___7 {
	void *ns;
	const struct proc_ns_operations___10 *ns_ops;
};

struct coredump_params___19 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___136 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct proc_dir_entry___7 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___136 *proc_iops;
	const struct file_operations___136 *proc_fops;
	struct proc_dir_entry___7 *next;
	struct proc_dir_entry___7 *parent;
	struct proc_dir_entry___7 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

union proc_op___5 {
	int (*proc_get_link)(struct dentry___136 *, struct path___136 *);
	int (*proc_read)(struct task_struct___136 *, char *);
	int (*proc_show)(struct seq_file___103 *, struct pid_namespace *, struct pid___77 *, struct task_struct___136 *);
};

struct proc_inode___5 {
	struct pid___77 *pid;
	int fd;
	union proc_op___5 op;
	struct proc_dir_entry___7 *pde;
	struct ctl_table_header___19 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___7 ns;
	struct inode___136 vfs_inode;
};

typedef struct dentry___136 *instantiate_t___2(struct inode___136 *, struct dentry___136 *, struct task_struct___136 *, const void *);

struct console___3 {
	char name[16];
	void (*write)(struct console___3 *, const char *, unsigned int);
	int (*read)(struct console___3 *, char *, unsigned int);
	struct tty_driver___12 * (*device)(struct console___3 *, int *);
	void (*unblank)();
	int (*setup)(struct console___3 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___3 *next;
};

struct hstate___13 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___43 cgroup_files[5];
	char name[32];
};

typedef u64 cputime64_t;

struct page___137;

typedef struct page___137 *pgtable_t___137;

struct address_space___137;

struct kmem_cache___124;

struct page___137 {
	long unsigned int flags;
	struct address_space___137 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___137 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___137 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___124 *slab_cache;
		struct page___137 *first_page;
	};
	long: 64;
};

struct task_struct___137;

struct pv_cpu_ops___137 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___137 *);
	void (*end_context_switch)(struct task_struct___137 *);
};

struct pid___78;

struct pid_link___78 {
	struct hlist_node node;
	struct pid___78 *pid;
};

struct mutex___138 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___137 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___133 {
	struct page___137 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___142;

struct fs_struct___16;

struct nsproxy___82;

struct signal_struct___137;

struct task_struct___137 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___137 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___142 *mm;
	struct mm_struct___142 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___137 *real_parent;
	struct task_struct___137 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___137 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___78 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___137 = 0,
		VTIME_USER___137 = 1,
		VTIME_SYS___137 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct___16 *fs;
	struct files_struct *files;
	struct nsproxy___82 *nsproxy;
	struct signal_struct___137 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___138 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___133 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___142 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___142 *, struct mm_struct___142 *);
	void (*dup_mmap)(struct mm_struct___142 *, struct mm_struct___142 *);
	void (*exit_mmap)(struct mm_struct___142 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___142 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___142 *);
	void (*pgd_free)(struct mm_struct___142 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___142 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___142 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___142 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___142 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___142 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___142 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___142 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___142 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___142 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___142 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___142 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___138 lock;
	void *vdso;
} mm_context_t___138;

struct xol_area___137;

struct uprobes_state___137 {
	struct xol_area___137 *xol_area;
};

struct vm_area_struct___142;

struct file___137;

struct linux_binfmt___20;

struct core_state___137;

struct mm_struct___142 {
	struct vm_area_struct___142 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___142 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___142 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___20 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___138 context;
	long unsigned int flags;
	struct core_state___137 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___137 *owner;
	struct file___137 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___137 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___137;

struct dentry_operations___137;

struct super_block___137;

struct dentry___137 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___137 *d_parent;
	struct qstr d_name;
	struct inode___137 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___137 *d_op;
	struct super_block___137 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___137;

struct address_space___137 {
	struct inode___137 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___138 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___137 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___137;

struct file_operations___137;

struct file_lock___137;

struct dquot___137;

struct block_device___137;

struct inode___137 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___137 *i_op;
	struct super_block___137 *i_sb;
	struct address_space___137 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___138 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___137 *i_fop;
	struct file_lock___137 *i_flock;
	struct address_space___137 i_data;
	struct dquot___137 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___137 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___30;

struct path___137;

struct dentry_operations___137 {
	int (*d_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_hash)(const struct dentry___137 *, struct qstr *);
	int (*d_compare)(const struct dentry___137 *, const struct dentry___137 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___137 *);
	void (*d_release)(struct dentry___137 *);
	void (*d_prune)(struct dentry___137 *);
	void (*d_iput)(struct dentry___137 *, struct inode___137 *);
	char * (*d_dname)(struct dentry___137 *, char *, int);
	struct vfsmount___30 * (*d_automount)(struct path___137 *);
	int (*d_manage)(struct dentry___137 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___137;

struct mem_dqinfo___137 {
	struct quota_format_type___137 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___137;

struct quota_info___137 {
	unsigned int flags;
	struct mutex___138 dqio_mutex;
	struct mutex___138 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___137 *files[2];
	struct mem_dqinfo___137 info[2];
	const struct quota_format_ops___137 *ops[2];
};

struct file_system_type___137;

struct super_operations___137;

struct dquot_operations___137;

struct quotactl_ops___137;

struct super_block___137 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___137 *s_type;
	const struct super_operations___137 *s_op;
	const struct dquot_operations___137 *dq_op;
	const struct quotactl_ops___137 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___137 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___137 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___137 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___138 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___137 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___30 {
	struct dentry___137 *mnt_root;
	struct super_block___137 *mnt_sb;
	int mnt_flags;
};

struct path___137 {
	struct vfsmount___30 *mnt;
	struct dentry___137 *dentry;
};

struct pid_namespace___78;

struct upid___78 {
	int nr;
	struct pid_namespace___78 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___78 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___137 *child_reaper;
	struct kmem_cache___124 *pid_cachep;
	unsigned int level;
	struct pid_namespace___78 *parent;
	struct vfsmount___30 *proc_mnt;
	struct dentry___137 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___78 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___78 numbers[1];
};

struct irq_data___99;

struct x86_io_apic_ops___99 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___99 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___99;

struct irq_data___99 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___99 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___109;

struct dev_pm_ops___109 {
	int (*prepare)(struct device___109 *);
	void (*complete)(struct device___109 *);
	int (*suspend)(struct device___109 *);
	int (*resume)(struct device___109 *);
	int (*freeze)(struct device___109 *);
	int (*thaw)(struct device___109 *);
	int (*poweroff)(struct device___109 *);
	int (*restore)(struct device___109 *);
	int (*suspend_late)(struct device___109 *);
	int (*resume_early)(struct device___109 *);
	int (*freeze_late)(struct device___109 *);
	int (*thaw_early)(struct device___109 *);
	int (*poweroff_late)(struct device___109 *);
	int (*restore_early)(struct device___109 *);
	int (*suspend_noirq)(struct device___109 *);
	int (*resume_noirq)(struct device___109 *);
	int (*freeze_noirq)(struct device___109 *);
	int (*thaw_noirq)(struct device___109 *);
	int (*poweroff_noirq)(struct device___109 *);
	int (*restore_noirq)(struct device___109 *);
	int (*runtime_suspend)(struct device___109 *);
	int (*runtime_resume)(struct device___109 *);
	int (*runtime_idle)(struct device___109 *);
};

struct dma_map_ops___36;

struct dev_archdata___36 {
	struct dma_map_ops___36 *dma_ops;
	void *iommu;
};

struct device_type___109;

struct bus_type___109;

struct device_driver___109;

struct dev_pm_domain___109;

struct class___109;

struct attribute_group___102;

struct device_rh___109;

struct device___109 {
	struct device___109 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___109 *type;
	struct mutex___138 mutex;
	struct bus_type___109 *bus;
	struct device_driver___109 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___109 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___36 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___109 *class;
	const struct attribute_group___102 **groups;
	void (*release)(struct device___109 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___109 *device_rh;
};

struct dev_pm_info_rh___109 {
	void (*set_latency_tolerance)(struct device___109 *, s32);
};

struct dev_pm_domain___109 {
	struct dev_pm_ops___109 ops;
};

struct smp_ops___137 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___137 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___137 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___137 *bd_inode;
	struct super_block___137 *bd_super;
	struct mutex___138 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___137 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___138 bd_fsfreeze_mutex;
};

struct iattr___137 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___137 *ia_file;
};

struct fown_struct___78 {
	rwlock_t lock;
	struct pid___78 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___137 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___137 f_path;
	struct inode___137 *f_inode;
	const struct file_operations___137 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___78 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___137 *f_mapping;
	struct mutex___138 f_pos_lock;
};

struct zone___137;

struct lruvec___137 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___137 *zone;
};

struct pglist_data___137;

struct zone___137 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___137 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___137 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___137 {
	struct zone___137 *zone;
	int zone_idx;
};

struct zonelist___137 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___137 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___137 {
	struct zone___137 node_zones[4];
	struct zonelist___137 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___137 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___137 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___138 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___137 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___137 {
	int qf_fmt_id;
	const struct quota_format_ops___137 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___137 *qf_next;
};

struct quota_format_ops___137 {
	int (*check_quota_file)(struct super_block___137 *, int);
	int (*read_file_info)(struct super_block___137 *, int);
	int (*write_file_info)(struct super_block___137 *, int);
	int (*free_file_info)(struct super_block___137 *, int);
	int (*read_dqblk)(struct dquot___137 *);
	int (*commit_dqblk)(struct dquot___137 *);
	int (*release_dqblk)(struct dquot___137 *);
};

struct dquot_operations___137 {
	int (*write_dquot)(struct dquot___137 *);
	struct dquot___137 * (*alloc_dquot)(struct super_block___137 *, int);
	void (*destroy_dquot)(struct dquot___137 *);
	int (*acquire_dquot)(struct dquot___137 *);
	int (*release_dquot)(struct dquot___137 *);
	int (*mark_dirty)(struct dquot___137 *);
	int (*write_info)(struct super_block___137 *, int);
	qsize_t * (*get_reserved_space)(struct inode___137 *);
};

struct quotactl_ops___137 {
	int (*quota_on)(struct super_block___137 *, int, int, struct path___137 *);
	int (*quota_on_meta)(struct super_block___137 *, int, int);
	int (*quota_off)(struct super_block___137 *, int);
	int (*quota_sync)(struct super_block___137 *, int);
	int (*get_info)(struct super_block___137 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___137 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___137 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___137 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___137 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___137 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___137 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___137 *, unsigned int);
};

struct address_space_operations___137 {
	int (*writepage)(struct page___137 *, struct writeback_control *);
	int (*readpage)(struct file___137 *, struct page___137 *);
	int (*writepages)(struct address_space___137 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___137 *);
	int (*readpages)(struct file___137 *, struct address_space___137 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___137 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___137 **, void **);
	int (*write_end)(struct file___137 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___137 *, void *);
	sector_t (*bmap)(struct address_space___137 *, sector_t);
	void (*invalidatepage)(struct page___137 *, long unsigned int);
	int (*releasepage)(struct page___137 *, gfp_t);
	void (*freepage)(struct page___137 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___137 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___137 *, struct page___137 *, struct page___137 *, enum migrate_mode);
	int (*launder_page)(struct page___137 *);
	int (*is_partially_uptodate)(struct page___137 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___137 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___137 *, struct page___137 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___137 *, sector_t *);
	void (*swap_deactivate)(struct file___137 *);
	void (*invalidatepage_range)(struct page___137 *, unsigned int, unsigned int);
};

struct nameidata___18;

struct inode_operations___137 {
	struct dentry___137 * (*lookup)(struct inode___137 *, struct dentry___137 *, unsigned int);
	void * (*follow_link)(struct dentry___137 *, struct nameidata___18 *);
	int (*permission)(struct inode___137 *, int);
	struct posix_acl * (*get_acl)(struct inode___137 *, int);
	int (*readlink)(struct dentry___137 *, char *, int);
	void (*put_link)(struct dentry___137 *, struct nameidata___18 *, void *);
	int (*create)(struct inode___137 *, struct dentry___137 *, umode_t, bool);
	int (*link)(struct dentry___137 *, struct inode___137 *, struct dentry___137 *);
	int (*unlink)(struct inode___137 *, struct dentry___137 *);
	int (*symlink)(struct inode___137 *, struct dentry___137 *, const char *);
	int (*mkdir)(struct inode___137 *, struct dentry___137 *, umode_t);
	int (*rmdir)(struct inode___137 *, struct dentry___137 *);
	int (*mknod)(struct inode___137 *, struct dentry___137 *, umode_t, dev_t);
	int (*rename)(struct inode___137 *, struct dentry___137 *, struct inode___137 *, struct dentry___137 *);
	int (*setattr)(struct dentry___137 *, struct iattr___137 *);
	int (*getattr)(struct vfsmount___30 *, struct dentry___137 *, struct kstat *);
	int (*setxattr)(struct dentry___137 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___137 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___137 *, char *, size_t);
	int (*removexattr)(struct dentry___137 *, const char *);
	int (*fiemap)(struct inode___137 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___137 *, struct timespec *, int);
	int (*atomic_open)(struct inode___137 *, struct dentry___137 *, struct file___137 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___104;

struct file_operations___137 {
	struct module *owner;
	loff_t (*llseek)(struct file___137 *, loff_t, int);
	ssize_t (*read)(struct file___137 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___137 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___137 *, void *, filldir_t);
	unsigned int (*poll)(struct file___137 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___137 *, struct vm_area_struct___142 *);
	int (*open)(struct inode___137 *, struct file___137 *);
	int (*flush)(struct file___137 *, fl_owner_t);
	int (*release)(struct inode___137 *, struct file___137 *);
	int (*fsync)(struct file___137 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___137 *, int);
	int (*lock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*sendpage)(struct file___137 *, struct page___137 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___137 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___137 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___137 *, long int, struct file_lock___137 **, void **);
		struct {
			int (*setlease)(struct file___137 *, long int, struct file_lock___137 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___137 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___104 *, struct file___137 *);
};

struct fasync_struct___137;

struct file_lock_operations___137;

struct lock_manager_operations___137;

struct file_lock___137 {
	struct file_lock___137 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___78 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___137 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___137 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___137 *fl_ops;
	const struct lock_manager_operations___137 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___137 {
	void (*fl_copy_lock)(struct file_lock___137 *, struct file_lock___137 *);
	void (*fl_release_private)(struct file_lock___137 *);
};

struct lock_manager_operations___137 {
	int (*lm_compare_owner)(struct file_lock___137 *, struct file_lock___137 *);
	long unsigned int (*lm_owner_key)(struct file_lock___137 *);
	void (*lm_notify)(struct file_lock___137 *);
	int (*lm_grant)(struct file_lock___137 *, struct file_lock___137 *, int);
	void (*lm_break)(struct file_lock___137 *);
	int (*lm_change)(struct file_lock___137 **, int);
};

struct fasync_struct___137 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___137 *fa_next;
	struct file___137 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___137 {
	const char *name;
	int fs_flags;
	struct dentry___137 * (*mount)(struct file_system_type___137 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___137 *);
	struct module *owner;
	struct file_system_type___137 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___137 {
	struct inode___137 * (*alloc_inode)(struct super_block___137 *);
	void (*destroy_inode)(struct inode___137 *);
	void (*dirty_inode)(struct inode___137 *, int);
	int (*write_inode)(struct inode___137 *, struct writeback_control *);
	int (*drop_inode)(struct inode___137 *);
	void (*evict_inode)(struct inode___137 *);
	void (*put_super)(struct super_block___137 *);
	int (*sync_fs)(struct super_block___137 *, int);
	int (*freeze_fs)(struct super_block___137 *);
	int (*unfreeze_fs)(struct super_block___137 *);
	int (*statfs)(struct dentry___137 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___137 *, int *, char *);
	void (*umount_begin)(struct super_block___137 *);
	int (*show_options)(struct seq_file___104 *, struct dentry___137 *);
	int (*show_devname)(struct seq_file___104 *, struct dentry___137 *);
	int (*show_path)(struct seq_file___104 *, struct dentry___137 *);
	int (*show_stats)(struct seq_file___104 *, struct dentry___137 *);
	ssize_t (*quota_read)(struct super_block___137 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___137 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___137 *);
	int (*bdev_try_to_free_page)(struct super_block___137 *, struct page___137 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___137 *);
	void (*free_cached_objects)(struct super_block___137 *, int);
};

struct vm_operations_struct___122;

struct vm_area_struct___142 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___142 *vm_next;
	struct vm_area_struct___142 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___142 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___122 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___137 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___103;

struct seq_file___104 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___138 lock;
	const struct seq_operations___103 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___18 {
	struct path___137 path;
	struct qstr last;
	struct path___137 root;
	struct inode___137 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___137 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___137 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___124;

struct memcg_cache_params___124;

struct kmem_cache___124 {
	struct kmem_cache_cpu___124 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___124 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___119;

struct vm_operations_struct___122 {
	void (*open)(struct vm_area_struct___142 *);
	void (*close)(struct vm_area_struct___142 *);
	int (*fault)(struct vm_area_struct___142 *, struct vm_fault___119 *);
	int (*page_mkwrite)(struct vm_area_struct___142 *, struct vm_fault___119 *);
	int (*access)(struct vm_area_struct___142 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___142 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___142 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___142 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___142 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___137 {
	struct task_struct___137 *task;
	struct core_thread___137 *next;
};

struct core_state___137 {
	atomic_t nr_threads;
	struct core_thread___137 dumper;
	struct completion startup;
};

struct linux_binprm___21;

struct coredump_params___20;

struct linux_binfmt___20 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___21 *);
	int (*load_shlib)(struct file___137 *);
	int (*core_dump)(struct coredump_params___20 *);
	long unsigned int min_coredump;
};

struct ctl_table_header___20;

struct ctl_node___20 {
	struct rb_node node;
	struct ctl_table_header___20 *header;
};

struct ctl_table_root___20;

struct ctl_table_set___20;

struct ctl_dir___20;

struct ctl_table_header___20 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___20 *root;
	struct ctl_table_set___20 *set;
	struct ctl_dir___20 *parent;
	struct ctl_node___20 *node;
};

struct ctl_dir___20 {
	struct ctl_table_header___20 header;
	struct rb_root root;
};

struct ctl_table_set___20 {
	int (*is_seen)(struct ctl_table_set___20 *);
	struct ctl_dir___20 dir;
};

struct ctl_table_root___20 {
	struct ctl_table_set___20 default_set;
	struct ctl_table_set___20 * (*lookup)(struct ctl_table_root___20 *, struct nsproxy___82 *);
	int (*permissions)(struct ctl_table_header___20 *, struct ctl_table *);
};

struct ipc_namespace___2;

struct net___18;

struct nsproxy___82 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace___2 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___78 *pid_ns;
	struct net___18 *net_ns;
};

struct signal_struct___137 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___137 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___137 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___78 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___78 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___138 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fs_struct___16 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___137 root;
	struct path___137 pwd;
};

struct ipc_namespace___2 {
	atomic_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	int auto_msgmni;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___30 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

struct netns_core___17 {
	struct ctl_table_header___20 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___17 {
	struct mutex___138 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___17 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___20 *ctl;
};

struct netns_ipv4___17 {
	struct ctl_table_header___20 *forw_hdr;
	struct ctl_table_header___20 *frags_hdr;
	struct ctl_table_header___20 *ipv4_hdr;
	struct ctl_table_header___20 *route_hdr;
	struct ctl_table_header___20 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___17 {
	struct ctl_table_header___20 *hdr;
	struct ctl_table_header___20 *route_hdr;
	struct ctl_table_header___20 *icmp_hdr;
	struct ctl_table_header___20 *frags_hdr;
	struct ctl_table_header___20 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___17 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___17 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *);
	int (*local_out)(struct sk_buff___12 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___12 *, const void *);
	struct kmem_cache___124 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___17 {
	struct netns_sysctl_ipv6___17 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___17 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___17 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___20 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___17 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___20 *nf_log_dir_header;
};

struct nf_proto_net___17 {
	struct ctl_table_header___20 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___17 {
	struct nf_proto_net___17 pn;
	unsigned int timeout;
};

struct nf_tcp_net___17 {
	struct nf_proto_net___17 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___17 {
	struct nf_proto_net___17 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___17 {
	struct nf_proto_net___17 pn;
	unsigned int timeout;
};

struct nf_ip_net___17 {
	struct nf_generic_net___17 generic;
	struct nf_tcp_net___17 tcp;
	struct nf_udp_net___17 udp;
	struct nf_icmp_net___17 icmp;
	struct nf_icmp_net___17 icmpv6;
};

struct netns_ct___17 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___20 *sysctl_header;
	struct ctl_table_header___20 *acct_sysctl_header;
	struct ctl_table_header___20 *tstamp_sysctl_header;
	struct ctl_table_header___20 *event_sysctl_header;
	struct ctl_table_header___20 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___124 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___17 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___17 {
	struct netns_sysctl_ipv6___17 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___17 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___20 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___17 xfrm4_dst_ops;
	struct dst_ops___17 xfrm6_dst_ops;
};

struct net___18 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___20 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___17 core;
	struct netns_mib mib;
	struct netns_packet___17 packet;
	struct netns_unix___17 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___17 ipv4;
	struct netns_ipv6___17 ipv6;
	struct netns_sctp___17 sctp;
	struct netns_dccp___7 dccp;
	struct netns_nf___17 nf;
	struct netns_xt xt;
	struct netns_ct___17 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___17 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___9 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___17 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___138 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___138 flow_flush_sem;
	long: 64;
	long: 64;
};

struct proc_dir_entry {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___137 *proc_iops;
	const struct file_operations___137 *proc_fops;
	struct proc_dir_entry *next;
	struct proc_dir_entry *parent;
	struct proc_dir_entry *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct bin_attribute___102;

struct attribute_group___102 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___102 **bin_attrs;
};

struct bin_attribute___102 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___137 *, struct kobject___7 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___137 *, struct kobject___7 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	int (*mmap)(struct file___137 *, struct kobject___7 *, struct bin_attribute___102 *, struct vm_area_struct___142 *);
};

struct kmem_cache_cpu___124 {
	void **freelist;
	long unsigned int tid;
	struct page___137 *page;
	struct page___137 *partial;
};

struct memcg_cache_params___124 {
	bool is_root_cache;
	union {
		struct kmem_cache___124 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___124 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___36 {
	void * (*alloc)(struct device___109 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___109 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___109 *, struct vm_area_struct___142 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___109 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___109 *, struct page___137 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___109 *, dma_addr_t);
	int (*dma_supported)(struct device___109 *, u64);
	int (*set_dma_mask)(struct device___109 *, u64);
	int is_phys;
};

struct bus_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___109 *, char *);
	ssize_t (*store)(struct bus_type___109 *, const char *, size_t);
};

struct device_attribute___109;

struct driver_attribute___109;

struct bus_type___109 {
	const char *name;
	const char *dev_name;
	struct device___109 *dev_root;
	struct bus_attribute___109 *bus_attrs;
	struct device_attribute___109 *dev_attrs;
	struct driver_attribute___109 *drv_attrs;
	const struct attribute_group___102 **bus_groups;
	const struct attribute_group___102 **dev_groups;
	const struct attribute_group___102 **drv_groups;
	int (*match)(struct device___109 *, struct device_driver___109 *);
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	int (*probe)(struct device___109 *);
	int (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*online)(struct device___109 *);
	int (*offline)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct device___109 *, struct device_attribute___109 *, char *);
	ssize_t (*store)(struct device___109 *, struct device_attribute___109 *, const char *, size_t);
};

struct driver_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___109 *, char *);
	ssize_t (*store)(struct device_driver___109 *, const char *, size_t);
};

struct device_driver___109 {
	const char *name;
	struct bus_type___109 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___109 *);
	int (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	const struct attribute_group___102 **groups;
	const struct dev_pm_ops___109 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___109 {
	const char *name;
	const struct attribute_group___102 **groups;
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
};

struct class_attribute___109;

struct class___109 {
	const char *name;
	struct module *owner;
	struct class_attribute___109 *class_attrs;
	struct device_attribute___109 *dev_attrs;
	const struct attribute_group___102 **dev_groups;
	struct bin_attribute___102 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *);
	void (*class_release)(struct class___109 *);
	void (*dev_release)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
	struct subsys_private *p;
};

struct class_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct class___109 *, struct class_attribute___109 *, char *);
	ssize_t (*store)(struct class___109 *, struct class_attribute___109 *, const char *, size_t);
	const void * (*namespace)(struct class___109 *, const struct class_attribute___109 *);
};

struct device_rh___109 {
	struct dev_pm_info_rh___109 power;
};

struct vm_fault___119 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___137 *page;
};

struct nf_afinfo___17 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___12 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___12 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___18 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___12 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___12 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___99 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___99 *);
	void (*irq_shutdown)(struct irq_data___99 *);
	void (*irq_enable)(struct irq_data___99 *);
	void (*irq_disable)(struct irq_data___99 *);
	void (*irq_ack)(struct irq_data___99 *);
	void (*irq_mask)(struct irq_data___99 *);
	void (*irq_mask_ack)(struct irq_data___99 *);
	void (*irq_unmask)(struct irq_data___99 *);
	void (*irq_eoi)(struct irq_data___99 *);
	int (*irq_set_affinity)(struct irq_data___99 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___99 *);
	int (*irq_set_type)(struct irq_data___99 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___99 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___99 *);
	void (*irq_bus_sync_unlock)(struct irq_data___99 *);
	void (*irq_cpu_online)(struct irq_data___99 *);
	void (*irq_cpu_offline)(struct irq_data___99 *);
	void (*irq_suspend)(struct irq_data___99 *);
	void (*irq_resume)(struct irq_data___99 *);
	void (*irq_pm_shutdown)(struct irq_data___99 *);
	void (*irq_print_chip)(struct irq_data___99 *, struct seq_file___104 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___99 *, void *);
	long unsigned int flags;
};

struct seq_operations___103 {
	void * (*start)(struct seq_file___104 *, loff_t *);
	void (*stop)(struct seq_file___104 *, void *);
	void * (*next)(struct seq_file___104 *, void *, loff_t *);
	int (*show)(struct seq_file___104 *, void *);
};

struct proc_ns_operations___11 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___137 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___82 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___8 {
	void *ns;
	const struct proc_ns_operations___11 *ns_ops;
};

struct linux_binprm___21 {
	char buf[128];
	struct vm_area_struct___142 *vma;
	long unsigned int vma_pages;
	struct mm_struct___142 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___137 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___20 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___137 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

union proc_op___6 {
	int (*proc_get_link)(struct dentry___137 *, struct path___137 *);
	int (*proc_read)(struct task_struct___137 *, char *);
	int (*proc_show)(struct seq_file___104 *, struct pid_namespace___78 *, struct pid___78 *, struct task_struct___137 *);
};

struct proc_inode___6 {
	struct pid___78 *pid;
	int fd;
	union proc_op___6 op;
	struct proc_dir_entry *pde;
	struct ctl_table_header___20 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___8 ns;
	struct inode___137 vfs_inode;
};

typedef struct dentry___137 *instantiate_t___3(struct inode___137 *, struct dentry___137 *, struct task_struct___137 *, const void *);

struct page___138;

typedef struct page___138 *pgtable_t___138;

struct address_space___138;

struct kmem_cache___125;

struct page___138 {
	long unsigned int flags;
	struct address_space___138 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___138 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___138 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___125 *slab_cache;
		struct page___138 *first_page;
	};
	long: 64;
};

struct task_struct___138;

struct pv_cpu_ops___138 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___138 *);
	void (*end_context_switch)(struct task_struct___138 *);
};

struct pid___79;

struct pid_link___79 {
	struct hlist_node node;
	struct pid___79 *pid;
};

struct mutex___139 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___138 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___134 {
	struct page___138 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___143;

struct nsproxy___83;

struct signal_struct___138;

struct task_struct___138 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___138 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___143 *mm;
	struct mm_struct___143 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___138 *real_parent;
	struct task_struct___138 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___138 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___79 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___138 = 0,
		VTIME_USER___138 = 1,
		VTIME_SYS___138 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___83 *nsproxy;
	struct signal_struct___138 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___139 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___134 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___143 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___143 *, struct mm_struct___143 *);
	void (*dup_mmap)(struct mm_struct___143 *, struct mm_struct___143 *);
	void (*exit_mmap)(struct mm_struct___143 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___143 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___143 *);
	void (*pgd_free)(struct mm_struct___143 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___143 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___143 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___143 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___143 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___143 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___143 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___143 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___143 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___143 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___143 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___143 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___139 lock;
	void *vdso;
} mm_context_t___139;

struct xol_area___138;

struct uprobes_state___138 {
	struct xol_area___138 *xol_area;
};

struct vm_area_struct___143;

struct file___138;

struct linux_binfmt___21;

struct core_state___138;

struct mm_struct___143 {
	struct vm_area_struct___143 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___143 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___143 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___21 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___139 context;
	long unsigned int flags;
	struct core_state___138 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___138 *owner;
	struct file___138 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___138 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___138 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___138 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___125;

struct memcg_cache_params___125;

struct kmem_cache___125 {
	struct kmem_cache_cpu___125 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___125 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___138;

struct address_space_operations___138;

struct address_space___138 {
	struct inode___138 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___139 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___138 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___138;

struct path___138 {
	struct vfsmount *mnt;
	struct dentry___138 *dentry;
};

struct fown_struct___79 {
	rwlock_t lock;
	struct pid___79 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___138;

struct file___138 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___138 f_path;
	struct inode___138 *f_inode;
	const struct file_operations___138 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___138 *f_mapping;
	struct mutex___139 f_pos_lock;
};

struct vm_operations_struct___123;

struct vm_area_struct___143 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___143 *vm_next;
	struct vm_area_struct___143 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___143 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___123 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___138 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___120;

struct vm_operations_struct___123 {
	void (*open)(struct vm_area_struct___143 *);
	void (*close)(struct vm_area_struct___143 *);
	int (*fault)(struct vm_area_struct___143 *, struct vm_fault___120 *);
	int (*page_mkwrite)(struct vm_area_struct___143 *, struct vm_fault___120 *);
	int (*access)(struct vm_area_struct___143 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___143 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___143 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___143 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___143 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___138 {
	struct task_struct___138 *task;
	struct core_thread___138 *next;
};

struct core_state___138 {
	atomic_t nr_threads;
	struct core_thread___138 dumper;
	struct completion startup;
};

struct linux_binprm___22;

struct coredump_params___21;

struct linux_binfmt___21 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___22 *);
	int (*load_shlib)(struct file___138 *);
	int (*core_dump)(struct coredump_params___21 *);
	long unsigned int min_coredump;
};

struct smp_ops___138 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___138 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___79;

struct upid___79 {
	int nr;
	struct pid_namespace___79 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___79 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___138 *child_reaper;
	struct kmem_cache___125 *pid_cachep;
	unsigned int level;
	struct pid_namespace___79 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___138 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___79 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___79 numbers[1];
};

struct zone___138;

struct lruvec___138 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___138 *zone;
};

struct pglist_data___138;

struct zone___138 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___138 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___138 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___138 {
	struct zone___138 *zone;
	int zone_idx;
};

struct zonelist___138 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___138 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___138 {
	struct zone___138 node_zones[4];
	struct zonelist___138 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___138 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___83 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___79 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___138 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___138 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___138 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___79 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___139 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___138;

struct super_block___138;

struct dentry___138 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___138 *d_parent;
	struct qstr d_name;
	struct inode___138 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___138 *d_op;
	struct super_block___138 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___138;

struct file_lock___138;

struct dquot___138;

struct block_device___138;

struct inode___138 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___138 *i_op;
	struct super_block___138 *i_sb;
	struct address_space___138 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___139 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___138 *i_fop;
	struct file_lock___138 *i_flock;
	struct address_space___138 i_data;
	struct dquot___138 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___138 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___138 {
	int (*d_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_hash)(const struct dentry___138 *, struct qstr *);
	int (*d_compare)(const struct dentry___138 *, const struct dentry___138 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___138 *);
	void (*d_release)(struct dentry___138 *);
	void (*d_prune)(struct dentry___138 *);
	void (*d_iput)(struct dentry___138 *, struct inode___138 *);
	char * (*d_dname)(struct dentry___138 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___138 *);
	int (*d_manage)(struct dentry___138 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___138;

struct mem_dqinfo___138 {
	struct quota_format_type___138 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___138;

struct quota_info___138 {
	unsigned int flags;
	struct mutex___139 dqio_mutex;
	struct mutex___139 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___138 *files[2];
	struct mem_dqinfo___138 info[2];
	const struct quota_format_ops___138 *ops[2];
};

struct file_system_type___138;

struct super_operations___138;

struct dquot_operations___138;

struct quotactl_ops___138;

struct super_block___138 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___138 *s_type;
	const struct super_operations___138 *s_op;
	const struct dquot_operations___138 *dq_op;
	const struct quotactl_ops___138 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___138 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___138 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___138 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___139 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___138 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct nameidata___19 {
	struct path___138 path;
	struct qstr last;
	struct path___138 root;
	struct inode___138 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct kmem_cache_cpu___125 {
	void **freelist;
	long unsigned int tid;
	struct page___138 *page;
	struct page___138 *partial;
};

struct memcg_cache_params___125 {
	bool is_root_cache;
	union {
		struct kmem_cache___125 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___125 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___120 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___138 *page;
};

struct block_device___138 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___138 *bd_inode;
	struct super_block___138 *bd_super;
	struct mutex___139 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___138 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___139 bd_fsfreeze_mutex;
};

struct iattr___138 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___138 *ia_file;
};

struct dquot___138 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___139 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___138 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___138 {
	int qf_fmt_id;
	const struct quota_format_ops___138 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___138 *qf_next;
};

struct quota_format_ops___138 {
	int (*check_quota_file)(struct super_block___138 *, int);
	int (*read_file_info)(struct super_block___138 *, int);
	int (*write_file_info)(struct super_block___138 *, int);
	int (*free_file_info)(struct super_block___138 *, int);
	int (*read_dqblk)(struct dquot___138 *);
	int (*commit_dqblk)(struct dquot___138 *);
	int (*release_dqblk)(struct dquot___138 *);
};

struct dquot_operations___138 {
	int (*write_dquot)(struct dquot___138 *);
	struct dquot___138 * (*alloc_dquot)(struct super_block___138 *, int);
	void (*destroy_dquot)(struct dquot___138 *);
	int (*acquire_dquot)(struct dquot___138 *);
	int (*release_dquot)(struct dquot___138 *);
	int (*mark_dirty)(struct dquot___138 *);
	int (*write_info)(struct super_block___138 *, int);
	qsize_t * (*get_reserved_space)(struct inode___138 *);
};

struct quotactl_ops___138 {
	int (*quota_on)(struct super_block___138 *, int, int, struct path___138 *);
	int (*quota_on_meta)(struct super_block___138 *, int, int);
	int (*quota_off)(struct super_block___138 *, int);
	int (*quota_sync)(struct super_block___138 *, int);
	int (*get_info)(struct super_block___138 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___138 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___138 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___138 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___138 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___138 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___138 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___138 *, unsigned int);
};

struct address_space_operations___138 {
	int (*writepage)(struct page___138 *, struct writeback_control *);
	int (*readpage)(struct file___138 *, struct page___138 *);
	int (*writepages)(struct address_space___138 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___138 *);
	int (*readpages)(struct file___138 *, struct address_space___138 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___138 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___138 **, void **);
	int (*write_end)(struct file___138 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___138 *, void *);
	sector_t (*bmap)(struct address_space___138 *, sector_t);
	void (*invalidatepage)(struct page___138 *, long unsigned int);
	int (*releasepage)(struct page___138 *, gfp_t);
	void (*freepage)(struct page___138 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___138 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___138 *, struct page___138 *, struct page___138 *, enum migrate_mode);
	int (*launder_page)(struct page___138 *);
	int (*is_partially_uptodate)(struct page___138 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___138 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___138 *, struct page___138 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___138 *, sector_t *);
	void (*swap_deactivate)(struct file___138 *);
	void (*invalidatepage_range)(struct page___138 *, unsigned int, unsigned int);
};

struct inode_operations___138 {
	struct dentry___138 * (*lookup)(struct inode___138 *, struct dentry___138 *, unsigned int);
	void * (*follow_link)(struct dentry___138 *, struct nameidata___19 *);
	int (*permission)(struct inode___138 *, int);
	struct posix_acl * (*get_acl)(struct inode___138 *, int);
	int (*readlink)(struct dentry___138 *, char *, int);
	void (*put_link)(struct dentry___138 *, struct nameidata___19 *, void *);
	int (*create)(struct inode___138 *, struct dentry___138 *, umode_t, bool);
	int (*link)(struct dentry___138 *, struct inode___138 *, struct dentry___138 *);
	int (*unlink)(struct inode___138 *, struct dentry___138 *);
	int (*symlink)(struct inode___138 *, struct dentry___138 *, const char *);
	int (*mkdir)(struct inode___138 *, struct dentry___138 *, umode_t);
	int (*rmdir)(struct inode___138 *, struct dentry___138 *);
	int (*mknod)(struct inode___138 *, struct dentry___138 *, umode_t, dev_t);
	int (*rename)(struct inode___138 *, struct dentry___138 *, struct inode___138 *, struct dentry___138 *);
	int (*setattr)(struct dentry___138 *, struct iattr___138 *);
	int (*getattr)(struct vfsmount *, struct dentry___138 *, struct kstat *);
	int (*setxattr)(struct dentry___138 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___138 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___138 *, char *, size_t);
	int (*removexattr)(struct dentry___138 *, const char *);
	int (*fiemap)(struct inode___138 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___138 *, struct timespec *, int);
	int (*atomic_open)(struct inode___138 *, struct dentry___138 *, struct file___138 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___138 {
	struct module *owner;
	loff_t (*llseek)(struct file___138 *, loff_t, int);
	ssize_t (*read)(struct file___138 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___138 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___138 *, void *, filldir_t);
	unsigned int (*poll)(struct file___138 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___138 *, struct vm_area_struct___143 *);
	int (*open)(struct inode___138 *, struct file___138 *);
	int (*flush)(struct file___138 *, fl_owner_t);
	int (*release)(struct inode___138 *, struct file___138 *);
	int (*fsync)(struct file___138 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___138 *, int);
	int (*lock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*sendpage)(struct file___138 *, struct page___138 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___138 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___138 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___138 *, long int, struct file_lock___138 **, void **);
		struct {
			int (*setlease)(struct file___138 *, long int, struct file_lock___138 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___138 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___138 *);
};

struct fasync_struct___138;

struct file_lock_operations___138;

struct lock_manager_operations___138;

struct file_lock___138 {
	struct file_lock___138 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___138 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___138 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___138 *fl_ops;
	const struct lock_manager_operations___138 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___138 {
	void (*fl_copy_lock)(struct file_lock___138 *, struct file_lock___138 *);
	void (*fl_release_private)(struct file_lock___138 *);
};

struct lock_manager_operations___138 {
	int (*lm_compare_owner)(struct file_lock___138 *, struct file_lock___138 *);
	long unsigned int (*lm_owner_key)(struct file_lock___138 *);
	void (*lm_notify)(struct file_lock___138 *);
	int (*lm_grant)(struct file_lock___138 *, struct file_lock___138 *, int);
	void (*lm_break)(struct file_lock___138 *);
	int (*lm_change)(struct file_lock___138 **, int);
};

struct fasync_struct___138 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___138 *fa_next;
	struct file___138 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___138 {
	const char *name;
	int fs_flags;
	struct dentry___138 * (*mount)(struct file_system_type___138 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___138 *);
	struct module *owner;
	struct file_system_type___138 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___138 {
	struct inode___138 * (*alloc_inode)(struct super_block___138 *);
	void (*destroy_inode)(struct inode___138 *);
	void (*dirty_inode)(struct inode___138 *, int);
	int (*write_inode)(struct inode___138 *, struct writeback_control *);
	int (*drop_inode)(struct inode___138 *);
	void (*evict_inode)(struct inode___138 *);
	void (*put_super)(struct super_block___138 *);
	int (*sync_fs)(struct super_block___138 *, int);
	int (*freeze_fs)(struct super_block___138 *);
	int (*unfreeze_fs)(struct super_block___138 *);
	int (*statfs)(struct dentry___138 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___138 *, int *, char *);
	void (*umount_begin)(struct super_block___138 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___138 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___138 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___138 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___138 *);
	ssize_t (*quota_read)(struct super_block___138 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___138 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___138 *);
	int (*bdev_try_to_free_page)(struct super_block___138 *, struct page___138 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___138 *);
	void (*free_cached_objects)(struct super_block___138 *, int);
};

struct linux_binprm___22 {
	char buf[128];
	struct vm_area_struct___143 *vma;
	long unsigned int vma_pages;
	struct mm_struct___143 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___138 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___21 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___138 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct ctl_path {
	const char *procname;
};

typedef struct poll_table_struct___85 poll_table___16;

struct page___139;

typedef struct page___139 *pgtable_t___139;

struct address_space___139;

struct kmem_cache___126;

struct page___139 {
	long unsigned int flags;
	struct address_space___139 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___139 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___139 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___126 *slab_cache;
		struct page___139 *first_page;
	};
	long: 64;
};

struct task_struct___139;

struct pv_cpu_ops___139 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___139 *);
	void (*end_context_switch)(struct task_struct___139 *);
};

struct mutex___140 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___139 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___135 {
	struct page___139 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___144;

struct nsproxy___84;

struct signal_struct___139;

struct task_struct___139 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___139 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___144 *mm;
	struct mm_struct___144 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___139 *real_parent;
	struct task_struct___139 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___139 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___79 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___139 = 0,
		VTIME_USER___139 = 1,
		VTIME_SYS___139 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___84 *nsproxy;
	struct signal_struct___139 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___140 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___135 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___144 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___144 *, struct mm_struct___144 *);
	void (*dup_mmap)(struct mm_struct___144 *, struct mm_struct___144 *);
	void (*exit_mmap)(struct mm_struct___144 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___144 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___144 *);
	void (*pgd_free)(struct mm_struct___144 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___144 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___144 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___144 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___144 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___144 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___144 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___144 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___144 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___144 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___144 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___144 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___140 lock;
	void *vdso;
} mm_context_t___140;

struct xol_area___139;

struct uprobes_state___139 {
	struct xol_area___139 *xol_area;
};

struct vm_area_struct___144;

struct file___139;

struct linux_binfmt___22;

struct core_state___139;

struct mm_struct___144 {
	struct vm_area_struct___144 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___144 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___144 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___22 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___140 context;
	long unsigned int flags;
	struct core_state___139 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___139 *owner;
	struct file___139 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___139 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___70;

struct module_kobject___69 {
	struct kobject___7 kobj;
	struct module___70 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___69;

struct module___70 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___69 mkobj;
	struct module_attribute___69 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___139 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___139;

struct dentry_operations___139;

struct super_block___139;

struct dentry___139 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___139 *d_parent;
	struct qstr d_name;
	struct inode___139 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___139 *d_op;
	struct super_block___139 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___139;

struct address_space___139 {
	struct inode___139 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___140 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___139 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___139;

struct file_operations___139;

struct file_lock___139;

struct dquot___139;

struct block_device___139;

struct inode___139 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___139 *i_op;
	struct super_block___139 *i_sb;
	struct address_space___139 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___140 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___139 *i_fop;
	struct file_lock___139 *i_flock;
	struct address_space___139 i_data;
	struct dquot___139 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___139 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___31;

struct path___139;

struct dentry_operations___139 {
	int (*d_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_hash)(const struct dentry___139 *, struct qstr *);
	int (*d_compare)(const struct dentry___139 *, const struct dentry___139 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___139 *);
	void (*d_release)(struct dentry___139 *);
	void (*d_prune)(struct dentry___139 *);
	void (*d_iput)(struct dentry___139 *, struct inode___139 *);
	char * (*d_dname)(struct dentry___139 *, char *, int);
	struct vfsmount___31 * (*d_automount)(struct path___139 *);
	int (*d_manage)(struct dentry___139 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___139;

struct mem_dqinfo___139 {
	struct quota_format_type___139 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___139;

struct quota_info___139 {
	unsigned int flags;
	struct mutex___140 dqio_mutex;
	struct mutex___140 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___139 *files[2];
	struct mem_dqinfo___139 info[2];
	const struct quota_format_ops___139 *ops[2];
};

struct file_system_type___139;

struct super_operations___139;

struct dquot_operations___139;

struct quotactl_ops___139;

struct super_block___139 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___139 *s_type;
	const struct super_operations___139 *s_op;
	const struct dquot_operations___139 *dq_op;
	const struct quotactl_ops___139 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___139 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___139 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___139 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___140 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___139 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___31 {
	struct dentry___139 *mnt_root;
	struct super_block___139 *mnt_sb;
	int mnt_flags;
};

struct path___139 {
	struct vfsmount___31 *mnt;
	struct dentry___139 *dentry;
};

struct irq_data___100;

struct x86_io_apic_ops___100 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___100 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___100;

struct irq_data___100 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___100 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___110;

struct dev_pm_ops___110 {
	int (*prepare)(struct device___110 *);
	void (*complete)(struct device___110 *);
	int (*suspend)(struct device___110 *);
	int (*resume)(struct device___110 *);
	int (*freeze)(struct device___110 *);
	int (*thaw)(struct device___110 *);
	int (*poweroff)(struct device___110 *);
	int (*restore)(struct device___110 *);
	int (*suspend_late)(struct device___110 *);
	int (*resume_early)(struct device___110 *);
	int (*freeze_late)(struct device___110 *);
	int (*thaw_early)(struct device___110 *);
	int (*poweroff_late)(struct device___110 *);
	int (*restore_early)(struct device___110 *);
	int (*suspend_noirq)(struct device___110 *);
	int (*resume_noirq)(struct device___110 *);
	int (*freeze_noirq)(struct device___110 *);
	int (*thaw_noirq)(struct device___110 *);
	int (*poweroff_noirq)(struct device___110 *);
	int (*restore_noirq)(struct device___110 *);
	int (*runtime_suspend)(struct device___110 *);
	int (*runtime_resume)(struct device___110 *);
	int (*runtime_idle)(struct device___110 *);
};

struct dma_map_ops___37;

struct dev_archdata___37 {
	struct dma_map_ops___37 *dma_ops;
	void *iommu;
};

struct device_type___110;

struct bus_type___110;

struct device_driver___110;

struct dev_pm_domain___110;

struct class___110;

struct attribute_group___103;

struct device_rh___110;

struct device___110 {
	struct device___110 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___110 *type;
	struct mutex___140 mutex;
	struct bus_type___110 *bus;
	struct device_driver___110 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___110 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___37 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___110 *class;
	const struct attribute_group___103 **groups;
	void (*release)(struct device___110 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___110 *device_rh;
};

struct dev_pm_info_rh___110 {
	void (*set_latency_tolerance)(struct device___110 *, s32);
};

struct dev_pm_domain___110 {
	struct dev_pm_ops___110 ops;
};

struct smp_ops___139 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___139 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___139 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___139 *bd_inode;
	struct super_block___139 *bd_super;
	struct mutex___140 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___139 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___140 bd_fsfreeze_mutex;
};

struct iattr___139 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___139 *ia_file;
};

struct file___139 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___139 f_path;
	struct inode___139 *f_inode;
	const struct file_operations___139 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___139 *f_mapping;
	struct mutex___140 f_pos_lock;
};

struct zone___139;

struct lruvec___139 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___139 *zone;
};

struct pglist_data___139;

struct zone___139 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___139 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___139 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___139 {
	struct zone___139 *zone;
	int zone_idx;
};

struct zonelist___139 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___139 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___139 {
	struct zone___139 node_zones[4];
	struct zonelist___139 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___139 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___139 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___140 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___139 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___139 {
	int qf_fmt_id;
	const struct quota_format_ops___139 *qf_ops;
	struct module___70 *qf_owner;
	struct quota_format_type___139 *qf_next;
};

struct quota_format_ops___139 {
	int (*check_quota_file)(struct super_block___139 *, int);
	int (*read_file_info)(struct super_block___139 *, int);
	int (*write_file_info)(struct super_block___139 *, int);
	int (*free_file_info)(struct super_block___139 *, int);
	int (*read_dqblk)(struct dquot___139 *);
	int (*commit_dqblk)(struct dquot___139 *);
	int (*release_dqblk)(struct dquot___139 *);
};

struct dquot_operations___139 {
	int (*write_dquot)(struct dquot___139 *);
	struct dquot___139 * (*alloc_dquot)(struct super_block___139 *, int);
	void (*destroy_dquot)(struct dquot___139 *);
	int (*acquire_dquot)(struct dquot___139 *);
	int (*release_dquot)(struct dquot___139 *);
	int (*mark_dirty)(struct dquot___139 *);
	int (*write_info)(struct super_block___139 *, int);
	qsize_t * (*get_reserved_space)(struct inode___139 *);
};

struct quotactl_ops___139 {
	int (*quota_on)(struct super_block___139 *, int, int, struct path___139 *);
	int (*quota_on_meta)(struct super_block___139 *, int, int);
	int (*quota_off)(struct super_block___139 *, int);
	int (*quota_sync)(struct super_block___139 *, int);
	int (*get_info)(struct super_block___139 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___139 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___139 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___139 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___139 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___139 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___139 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___139 *, unsigned int);
};

struct address_space_operations___139 {
	int (*writepage)(struct page___139 *, struct writeback_control *);
	int (*readpage)(struct file___139 *, struct page___139 *);
	int (*writepages)(struct address_space___139 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___139 *);
	int (*readpages)(struct file___139 *, struct address_space___139 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___139 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___139 **, void **);
	int (*write_end)(struct file___139 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___139 *, void *);
	sector_t (*bmap)(struct address_space___139 *, sector_t);
	void (*invalidatepage)(struct page___139 *, long unsigned int);
	int (*releasepage)(struct page___139 *, gfp_t);
	void (*freepage)(struct page___139 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___139 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___139 *, struct page___139 *, struct page___139 *, enum migrate_mode);
	int (*launder_page)(struct page___139 *);
	int (*is_partially_uptodate)(struct page___139 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___139 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___139 *, struct page___139 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___139 *, sector_t *);
	void (*swap_deactivate)(struct file___139 *);
	void (*invalidatepage_range)(struct page___139 *, unsigned int, unsigned int);
};

struct inode_operations___139 {
	struct dentry___139 * (*lookup)(struct inode___139 *, struct dentry___139 *, unsigned int);
	void * (*follow_link)(struct dentry___139 *, struct nameidata *);
	int (*permission)(struct inode___139 *, int);
	struct posix_acl * (*get_acl)(struct inode___139 *, int);
	int (*readlink)(struct dentry___139 *, char *, int);
	void (*put_link)(struct dentry___139 *, struct nameidata *, void *);
	int (*create)(struct inode___139 *, struct dentry___139 *, umode_t, bool);
	int (*link)(struct dentry___139 *, struct inode___139 *, struct dentry___139 *);
	int (*unlink)(struct inode___139 *, struct dentry___139 *);
	int (*symlink)(struct inode___139 *, struct dentry___139 *, const char *);
	int (*mkdir)(struct inode___139 *, struct dentry___139 *, umode_t);
	int (*rmdir)(struct inode___139 *, struct dentry___139 *);
	int (*mknod)(struct inode___139 *, struct dentry___139 *, umode_t, dev_t);
	int (*rename)(struct inode___139 *, struct dentry___139 *, struct inode___139 *, struct dentry___139 *);
	int (*setattr)(struct dentry___139 *, struct iattr___139 *);
	int (*getattr)(struct vfsmount___31 *, struct dentry___139 *, struct kstat *);
	int (*setxattr)(struct dentry___139 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___139 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___139 *, char *, size_t);
	int (*removexattr)(struct dentry___139 *, const char *);
	int (*fiemap)(struct inode___139 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___139 *, struct timespec *, int);
	int (*atomic_open)(struct inode___139 *, struct dentry___139 *, struct file___139 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___105;

struct file_operations___139 {
	struct module___70 *owner;
	loff_t (*llseek)(struct file___139 *, loff_t, int);
	ssize_t (*read)(struct file___139 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___139 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___139 *, void *, filldir_t);
	unsigned int (*poll)(struct file___139 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___139 *, struct vm_area_struct___144 *);
	int (*open)(struct inode___139 *, struct file___139 *);
	int (*flush)(struct file___139 *, fl_owner_t);
	int (*release)(struct inode___139 *, struct file___139 *);
	int (*fsync)(struct file___139 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___139 *, int);
	int (*lock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*sendpage)(struct file___139 *, struct page___139 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___139 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___139 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___139 *, long int, struct file_lock___139 **, void **);
		struct {
			int (*setlease)(struct file___139 *, long int, struct file_lock___139 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___139 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___105 *, struct file___139 *);
};

struct fasync_struct___139;

struct file_lock_operations___139;

struct lock_manager_operations___139;

struct file_lock___139 {
	struct file_lock___139 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___139 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___139 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___139 *fl_ops;
	const struct lock_manager_operations___139 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___139 {
	void (*fl_copy_lock)(struct file_lock___139 *, struct file_lock___139 *);
	void (*fl_release_private)(struct file_lock___139 *);
};

struct lock_manager_operations___139 {
	int (*lm_compare_owner)(struct file_lock___139 *, struct file_lock___139 *);
	long unsigned int (*lm_owner_key)(struct file_lock___139 *);
	void (*lm_notify)(struct file_lock___139 *);
	int (*lm_grant)(struct file_lock___139 *, struct file_lock___139 *, int);
	void (*lm_break)(struct file_lock___139 *);
	int (*lm_change)(struct file_lock___139 **, int);
};

struct fasync_struct___139 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___139 *fa_next;
	struct file___139 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___139 {
	const char *name;
	int fs_flags;
	struct dentry___139 * (*mount)(struct file_system_type___139 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___139 *);
	struct module___70 *owner;
	struct file_system_type___139 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___139 {
	struct inode___139 * (*alloc_inode)(struct super_block___139 *);
	void (*destroy_inode)(struct inode___139 *);
	void (*dirty_inode)(struct inode___139 *, int);
	int (*write_inode)(struct inode___139 *, struct writeback_control *);
	int (*drop_inode)(struct inode___139 *);
	void (*evict_inode)(struct inode___139 *);
	void (*put_super)(struct super_block___139 *);
	int (*sync_fs)(struct super_block___139 *, int);
	int (*freeze_fs)(struct super_block___139 *);
	int (*unfreeze_fs)(struct super_block___139 *);
	int (*statfs)(struct dentry___139 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___139 *, int *, char *);
	void (*umount_begin)(struct super_block___139 *);
	int (*show_options)(struct seq_file___105 *, struct dentry___139 *);
	int (*show_devname)(struct seq_file___105 *, struct dentry___139 *);
	int (*show_path)(struct seq_file___105 *, struct dentry___139 *);
	int (*show_stats)(struct seq_file___105 *, struct dentry___139 *);
	ssize_t (*quota_read)(struct super_block___139 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___139 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___139 *);
	int (*bdev_try_to_free_page)(struct super_block___139 *, struct page___139 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___139 *);
	void (*free_cached_objects)(struct super_block___139 *, int);
};

struct vm_operations_struct___124;

struct vm_area_struct___144 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___144 *vm_next;
	struct vm_area_struct___144 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___144 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___124 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___139 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___104;

struct seq_file___105 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___140 lock;
	const struct seq_operations___104 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___103;

struct attribute_group___103 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___103 **bin_attrs;
};

struct bin_attribute___103 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___139 *, struct kobject___7 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___139 *, struct kobject___7 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	int (*mmap)(struct file___139 *, struct kobject___7 *, struct bin_attribute___103 *, struct vm_area_struct___144 *);
};

struct kmem_cache_cpu___126 {
	void **freelist;
	long unsigned int tid;
	struct page___139 *page;
	struct page___139 *partial;
};

struct memcg_cache_params___126;

struct kmem_cache___126 {
	struct kmem_cache_cpu___126 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___7 kobj;
	struct memcg_cache_params___126 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___126 {
	bool is_root_cache;
	union {
		struct kmem_cache___126 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___126 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___139 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___139 *page;
	long unsigned int vaddr;
};

struct vm_fault___121;

struct vm_operations_struct___124 {
	void (*open)(struct vm_area_struct___144 *);
	void (*close)(struct vm_area_struct___144 *);
	int (*fault)(struct vm_area_struct___144 *, struct vm_fault___121 *);
	int (*page_mkwrite)(struct vm_area_struct___144 *, struct vm_fault___121 *);
	int (*access)(struct vm_area_struct___144 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___144 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___144 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___144 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___144 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___139 {
	struct task_struct___139 *task;
	struct core_thread___139 *next;
};

struct core_state___139 {
	atomic_t nr_threads;
	struct core_thread___139 dumper;
	struct completion startup;
};

struct linux_binprm___23;

struct coredump_params___22;

struct linux_binfmt___22 {
	struct list_head lh;
	struct module___70 *module;
	int (*load_binary)(struct linux_binprm___23 *);
	int (*load_shlib)(struct file___139 *);
	int (*core_dump)(struct coredump_params___22 *);
	long unsigned int min_coredump;
};

struct ctl_table_header___21;

struct ctl_node___21 {
	struct rb_node node;
	struct ctl_table_header___21 *header;
};

struct ctl_table_root___21;

struct ctl_table_set___21;

struct ctl_dir___21;

struct ctl_table_header___21 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___21 *root;
	struct ctl_table_set___21 *set;
	struct ctl_dir___21 *parent;
	struct ctl_node___21 *node;
};

struct ctl_dir___21 {
	struct ctl_table_header___21 header;
	struct rb_root root;
};

struct ctl_table_set___21 {
	int (*is_seen)(struct ctl_table_set___21 *);
	struct ctl_dir___21 dir;
};

struct ctl_table_root___21 {
	struct ctl_table_set___21 default_set;
	struct ctl_table_set___21 * (*lookup)(struct ctl_table_root___21 *, struct nsproxy___84 *);
	int (*permissions)(struct ctl_table_header___21 *, struct ctl_table *);
};

struct net___19;

struct nsproxy___84 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___19 *net_ns;
};

struct signal_struct___139 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___139 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___139 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___79 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___140 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___69 *, struct module_kobject___69 *, char *);
	ssize_t (*store)(struct module_attribute___69 *, struct module_kobject___69 *, const char *, size_t);
	void (*setup)(struct module___70 *, const char *);
	int (*test)(struct module___70 *);
	void (*free)(struct module___70 *);
};

struct netns_core___18 {
	struct ctl_table_header___21 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct proc_dir_entry___8;

struct netns_mib___2 {
	struct tcp_mib *tcp_statistics[1];
	struct ipstats_mib *ip_statistics[1];
	struct linux_mib *net_statistics[1];
	struct udp_mib *udp_statistics[1];
	struct udp_mib *udplite_statistics[1];
	struct icmp_mib *icmp_statistics[1];
	struct icmpmsg_mib *icmpmsg_statistics;
	struct proc_dir_entry___8 *proc_net_devsnmp6;
	struct udp_mib *udp_stats_in6[1];
	struct udp_mib *udplite_stats_in6[1];
	struct ipstats_mib *ipv6_statistics[1];
	struct icmpv6_mib *icmpv6_statistics[1];
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct linux_xfrm_mib *xfrm_statistics[1];
};

struct netns_packet___18 {
	struct mutex___140 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___18 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___21 *ctl;
};

struct netns_ipv4___18 {
	struct ctl_table_header___21 *forw_hdr;
	struct ctl_table_header___21 *frags_hdr;
	struct ctl_table_header___21 *ipv4_hdr;
	struct ctl_table_header___21 *route_hdr;
	struct ctl_table_header___21 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___18 {
	struct ctl_table_header___21 *hdr;
	struct ctl_table_header___21 *route_hdr;
	struct ctl_table_header___21 *icmp_hdr;
	struct ctl_table_header___21 *frags_hdr;
	struct ctl_table_header___21 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___18 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___18 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___12 *);
	int (*local_out)(struct sk_buff___12 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___12 *, const void *);
	struct kmem_cache___126 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___18 {
	struct netns_sysctl_ipv6___18 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___18 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___18 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry___8 *proc_net_sctp;
	struct ctl_table_header___21 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___18 {
	struct proc_dir_entry___8 *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___21 *nf_log_dir_header;
};

struct nf_proto_net___18 {
	struct ctl_table_header___21 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___18 {
	struct nf_proto_net___18 pn;
	unsigned int timeout;
};

struct nf_tcp_net___18 {
	struct nf_proto_net___18 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___18 {
	struct nf_proto_net___18 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___18 {
	struct nf_proto_net___18 pn;
	unsigned int timeout;
};

struct nf_ip_net___18 {
	struct nf_generic_net___18 generic;
	struct nf_tcp_net___18 tcp;
	struct nf_udp_net___18 udp;
	struct nf_icmp_net___18 icmp;
	struct nf_icmp_net___18 icmpv6;
};

struct netns_ct___18 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___21 *sysctl_header;
	struct ctl_table_header___21 *acct_sysctl_header;
	struct ctl_table_header___21 *tstamp_sysctl_header;
	struct ctl_table_header___21 *event_sysctl_header;
	struct ctl_table_header___21 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___126 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___18 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___18 {
	struct netns_sysctl_ipv6___18 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___18 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___21 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___18 xfrm4_dst_ops;
	struct dst_ops___18 xfrm6_dst_ops;
};

struct net___19 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry___8 *proc_net;
	struct proc_dir_entry___8 *proc_net_stat;
	struct ctl_table_set___21 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___18 core;
	struct netns_mib___2 mib;
	struct netns_packet___18 packet;
	struct netns_unix___18 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___18 ipv4;
	struct netns_ipv6___18 ipv6;
	struct netns_sctp___18 sctp;
	struct netns_dccp___7 dccp;
	struct netns_nf___18 nf;
	struct netns_xt xt;
	struct netns_ct___18 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___18 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___9 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___18 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___140 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___140 flow_flush_sem;
	long: 64;
	long: 64;
};

struct proc_dir_entry___8 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___139 *proc_iops;
	const struct file_operations___139 *proc_fops;
	struct proc_dir_entry___8 *next;
	struct proc_dir_entry___8 *parent;
	struct proc_dir_entry___8 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct dma_map_ops___37 {
	void * (*alloc)(struct device___110 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___110 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___110 *, struct vm_area_struct___144 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___110 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___110 *, struct page___139 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___110 *, dma_addr_t);
	int (*dma_supported)(struct device___110 *, u64);
	int (*set_dma_mask)(struct device___110 *, u64);
	int is_phys;
};

struct bus_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___110 *, char *);
	ssize_t (*store)(struct bus_type___110 *, const char *, size_t);
};

struct device_attribute___110;

struct driver_attribute___110;

struct bus_type___110 {
	const char *name;
	const char *dev_name;
	struct device___110 *dev_root;
	struct bus_attribute___110 *bus_attrs;
	struct device_attribute___110 *dev_attrs;
	struct driver_attribute___110 *drv_attrs;
	const struct attribute_group___103 **bus_groups;
	const struct attribute_group___103 **dev_groups;
	const struct attribute_group___103 **drv_groups;
	int (*match)(struct device___110 *, struct device_driver___110 *);
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	int (*probe)(struct device___110 *);
	int (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*online)(struct device___110 *);
	int (*offline)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct device___110 *, struct device_attribute___110 *, char *);
	ssize_t (*store)(struct device___110 *, struct device_attribute___110 *, const char *, size_t);
};

struct driver_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___110 *, char *);
	ssize_t (*store)(struct device_driver___110 *, const char *, size_t);
};

struct device_driver___110 {
	const char *name;
	struct bus_type___110 *bus;
	struct module___70 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___110 *);
	int (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	const struct attribute_group___103 **groups;
	const struct dev_pm_ops___110 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___110 {
	const char *name;
	const struct attribute_group___103 **groups;
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
};

struct class_attribute___110;

struct class___110 {
	const char *name;
	struct module___70 *owner;
	struct class_attribute___110 *class_attrs;
	struct device_attribute___110 *dev_attrs;
	const struct attribute_group___103 **dev_groups;
	struct bin_attribute___103 *dev_bin_attrs;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *);
	void (*class_release)(struct class___110 *);
	void (*dev_release)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
	struct subsys_private *p;
};

struct class_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct class___110 *, struct class_attribute___110 *, char *);
	ssize_t (*store)(struct class___110 *, struct class_attribute___110 *, const char *, size_t);
	const void * (*namespace)(struct class___110 *, const struct class_attribute___110 *);
};

struct device_rh___110 {
	struct dev_pm_info_rh___110 power;
};

struct vm_fault___121 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___139 *page;
};

struct nf_afinfo___18 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___12 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___12 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___19 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___12 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___12 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___100 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___100 *);
	void (*irq_shutdown)(struct irq_data___100 *);
	void (*irq_enable)(struct irq_data___100 *);
	void (*irq_disable)(struct irq_data___100 *);
	void (*irq_ack)(struct irq_data___100 *);
	void (*irq_mask)(struct irq_data___100 *);
	void (*irq_mask_ack)(struct irq_data___100 *);
	void (*irq_unmask)(struct irq_data___100 *);
	void (*irq_eoi)(struct irq_data___100 *);
	int (*irq_set_affinity)(struct irq_data___100 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___100 *);
	int (*irq_set_type)(struct irq_data___100 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___100 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___100 *);
	void (*irq_bus_sync_unlock)(struct irq_data___100 *);
	void (*irq_cpu_online)(struct irq_data___100 *);
	void (*irq_cpu_offline)(struct irq_data___100 *);
	void (*irq_suspend)(struct irq_data___100 *);
	void (*irq_resume)(struct irq_data___100 *);
	void (*irq_pm_shutdown)(struct irq_data___100 *);
	void (*irq_print_chip)(struct irq_data___100 *, struct seq_file___105 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___100 *, void *);
	long unsigned int flags;
};

struct seq_operations___104 {
	void * (*start)(struct seq_file___105 *, loff_t *);
	void (*stop)(struct seq_file___105 *, void *);
	void * (*next)(struct seq_file___105 *, void *, loff_t *);
	int (*show)(struct seq_file___105 *, void *);
};

struct seq_net_private {
	struct net___19 *net;
};

struct pernet_operations {
	struct list_head list;
	int (*init)(struct net___19 *);
	void (*exit)(struct net___19 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct proc_ns_operations___12 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___139 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___84 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___9 {
	void *ns;
	const struct proc_ns_operations___12 *ns_ops;
};

struct linux_binprm___23 {
	char buf[128];
	struct vm_area_struct___144 *vma;
	long unsigned int vma_pages;
	struct mm_struct___144 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___139 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct coredump_params___22 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___139 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

union proc_op___7 {
	int (*proc_get_link)(struct dentry___139 *, struct path___139 *);
	int (*proc_read)(struct task_struct___139 *, char *);
	int (*proc_show)(struct seq_file___105 *, struct pid_namespace *, struct pid___79 *, struct task_struct___139 *);
};

struct proc_inode___7 {
	struct pid___79 *pid;
	int fd;
	union proc_op___7 op;
	struct proc_dir_entry___8 *pde;
	struct ctl_table_header___21 *sysctl;
	struct ctl_table *sysctl_entry;
	struct proc_ns___9 ns;
	struct inode___139 vfs_inode;
};

struct vmcore {
	struct list_head list;
	long long unsigned int paddr;
	long long unsigned int size;
	loff_t offset;
};

typedef struct elf32_note Elf32_Nhdr;

typedef struct elf64_note Elf64_Nhdr;

struct proc_dir_entry___9 {
	unsigned int low_ino;
	umode_t mode;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	const struct inode_operations___54 *proc_iops;
	const struct file_operations___54 *proc_fops;
	struct proc_dir_entry___9 *next;
	struct proc_dir_entry___9 *parent;
	struct proc_dir_entry___9 *subdir;
	void *data;
	atomic_t count;
	atomic_t in_use;
	struct completion *pde_unload_completion;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	u8 namelen;
	char name[0];
};

struct sysfs_elem_dir {
	struct kobject___6 *kobj;
	long unsigned int subdirs;
	struct rb_root children;
};

struct sysfs_elem_symlink {
	struct sysfs_dirent *target_sd;
};

struct sysfs_open_dirent;

struct sysfs_elem_attr {
	struct attribute *attr;
	struct sysfs_open_dirent *open;
};

struct sysfs_elem_bin_attr {
	struct bin_attribute___93 *bin_attr;
	struct hlist_head buffers;
};

struct sysfs_inode_attrs;

struct sysfs_dirent {
	atomic_t s_count;
	atomic_t s_active;
	struct sysfs_dirent *s_parent;
	const char *s_name;
	struct rb_node s_rb;
	union {
		struct completion *completion;
		struct sysfs_dirent *removed_list;
	} u;
	const void *s_ns;
	unsigned int s_hash;
	union {
		struct sysfs_elem_dir s_dir;
		struct sysfs_elem_symlink s_symlink;
		struct sysfs_elem_attr s_attr;
		struct sysfs_elem_bin_attr s_bin_attr;
	};
	short unsigned int s_flags;
	umode_t s_mode;
	unsigned int s_ino;
	struct sysfs_inode_attrs *s_iattr;
};

struct sysfs_inode_attrs {
	struct iattr___124 ia_iattr;
	void *ia_secdata;
	u32 ia_secdata_len;
};

struct sysfs_addrm_cxt {
	struct sysfs_dirent *parent_sd;
	struct sysfs_dirent *removed;
};

struct page___140;

typedef struct page___140 *pgtable_t___140;

struct address_space___140;

struct kmem_cache___127;

struct page___140 {
	long unsigned int flags;
	struct address_space___140 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___140 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___140 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___127 *slab_cache;
		struct page___140 *first_page;
	};
	long: 64;
};

struct task_struct___140;

struct pv_cpu_ops___140 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___140 *);
	void (*end_context_switch)(struct task_struct___140 *);
};

struct mutex___141 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___140 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___136 {
	struct page___140 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___145;

struct signal_struct___140;

struct task_struct___140 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___140 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___145 *mm;
	struct mm_struct___145 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___140 *real_parent;
	struct task_struct___140 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___140 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___79 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___140 = 0,
		VTIME_USER___140 = 1,
		VTIME_SYS___140 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___140 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___141 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___136 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___145 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___145 *, struct mm_struct___145 *);
	void (*dup_mmap)(struct mm_struct___145 *, struct mm_struct___145 *);
	void (*exit_mmap)(struct mm_struct___145 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___145 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___145 *);
	void (*pgd_free)(struct mm_struct___145 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___145 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___145 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___145 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___145 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___145 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___145 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___145 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___145 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___145 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___145 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___145 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___141 lock;
	void *vdso;
} mm_context_t___141;

struct xol_area___140;

struct uprobes_state___140 {
	struct xol_area___140 *xol_area;
};

struct vm_area_struct___145;

struct file___140;

struct core_state___140;

struct mm_struct___145 {
	struct vm_area_struct___145 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___145 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___145 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___141 context;
	long unsigned int flags;
	struct core_state___140 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___140 *owner;
	struct file___140 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___140 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___8;

struct kobj_type___8;

struct sysfs_dirent___2;

struct kobject___8 {
	const char *name;
	struct list_head entry;
	struct kobject___8 *parent;
	struct kset___8 *kset;
	struct kobj_type___8 *ktype;
	struct sysfs_dirent___2 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___71;

struct module_kobject___70 {
	struct kobject___8 kobj;
	struct module___71 *mod;
	struct kobject___8 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___70;

struct module___71 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___70 mkobj;
	struct module_attribute___70 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___8 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___140 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___140;

struct lruvec___140 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___140 *zone;
};

struct pglist_data___140;

struct zone___140 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___140 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___140 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___140 {
	struct zone___140 *zone;
	int zone_idx;
};

struct zonelist___140 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___140 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___140 {
	struct zone___140 node_zones[4];
	struct zonelist___140 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___140 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___140 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___140 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___104 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___140 *, struct kobject___8 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___140 *, struct kobject___8 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	int (*mmap)(struct file___140 *, struct kobject___8 *, struct bin_attribute___104 *, struct vm_area_struct___145 *);
};

struct dentry___140;

struct path___140 {
	struct vfsmount *mnt;
	struct dentry___140 *dentry;
};

struct inode___140;

struct file_operations___140;

struct file___140 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___140 f_path;
	struct inode___140 *f_inode;
	const struct file_operations___140 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___140 *f_mapping;
	struct mutex___141 f_pos_lock;
};

struct vm_area_struct___145 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___145 *vm_next;
	struct vm_area_struct___145 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___145 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___140 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___8 {
	ssize_t (*show)(struct kobject___8 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___8 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___8 *, const struct attribute *);
};

struct kset_uevent_ops___8;

struct kset___8 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___8 kobj;
	const struct kset_uevent_ops___8 *uevent_ops;
};

struct kobj_type___8 {
	void (*release)(struct kobject___8 *);
	const struct sysfs_ops___8 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___8 *);
	const void * (*namespace)(struct kobject___8 *);
};

struct sysfs_elem_dir___2 {
	struct kobject___8 *kobj;
	long unsigned int subdirs;
	struct rb_root children;
};

struct sysfs_elem_symlink___2 {
	struct sysfs_dirent___2 *target_sd;
};

struct sysfs_elem_bin_attr___2 {
	struct bin_attribute___104 *bin_attr;
	struct hlist_head buffers;
};

struct sysfs_inode_attrs___2;

struct sysfs_dirent___2 {
	atomic_t s_count;
	atomic_t s_active;
	struct sysfs_dirent___2 *s_parent;
	const char *s_name;
	struct rb_node s_rb;
	union {
		struct completion *completion;
		struct sysfs_dirent___2 *removed_list;
	} u;
	const void *s_ns;
	unsigned int s_hash;
	union {
		struct sysfs_elem_dir___2 s_dir;
		struct sysfs_elem_symlink___2 s_symlink;
		struct sysfs_elem_attr s_attr;
		struct sysfs_elem_bin_attr___2 s_bin_attr;
	};
	short unsigned int s_flags;
	umode_t s_mode;
	unsigned int s_ino;
	struct sysfs_inode_attrs___2 *s_iattr;
};

struct kset_uevent_ops___8 {
	int (* const filter)(struct kset___8 *, struct kobject___8 *);
	const char * (* const name)(struct kset___8 *, struct kobject___8 *);
	int (* const uevent)(struct kset___8 *, struct kobject___8 *, struct kobj_uevent_env *);
};

struct module_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___70 *, struct module_kobject___70 *, char *);
	ssize_t (*store)(struct module_attribute___70 *, struct module_kobject___70 *, const char *, size_t);
	void (*setup)(struct module___71 *, const char *);
	int (*test)(struct module___71 *);
	void (*free)(struct module___71 *);
};

struct kmem_cache_cpu___127 {
	void **freelist;
	long unsigned int tid;
	struct page___140 *page;
	struct page___140 *partial;
};

struct memcg_cache_params___127;

struct kmem_cache___127 {
	struct kmem_cache_cpu___127 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___8 kobj;
	struct memcg_cache_params___127 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___127 {
	bool is_root_cache;
	union {
		struct kmem_cache___127 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___127 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___140;

struct super_block___140;

struct dentry___140 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___140 *d_parent;
	struct qstr d_name;
	struct inode___140 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___140 *d_op;
	struct super_block___140 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___140;

struct address_space___140 {
	struct inode___140 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___141 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___140 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___140;

struct file_lock___140;

struct dquot___140;

struct block_device___140;

struct inode___140 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___140 *i_op;
	struct super_block___140 *i_sb;
	struct address_space___140 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___141 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___140 *i_fop;
	struct file_lock___140 *i_flock;
	struct address_space___140 i_data;
	struct dquot___140 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___140 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___140 {
	int (*d_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_hash)(const struct dentry___140 *, struct qstr *);
	int (*d_compare)(const struct dentry___140 *, const struct dentry___140 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___140 *);
	void (*d_release)(struct dentry___140 *);
	void (*d_prune)(struct dentry___140 *);
	void (*d_iput)(struct dentry___140 *, struct inode___140 *);
	char * (*d_dname)(struct dentry___140 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___140 *);
	int (*d_manage)(struct dentry___140 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___140;

struct mem_dqinfo___140 {
	struct quota_format_type___140 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___140;

struct quota_info___140 {
	unsigned int flags;
	struct mutex___141 dqio_mutex;
	struct mutex___141 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___140 *files[2];
	struct mem_dqinfo___140 info[2];
	const struct quota_format_ops___140 *ops[2];
};

struct file_system_type___140;

struct super_operations___140;

struct dquot_operations___140;

struct quotactl_ops___140;

struct super_block___140 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___140 *s_type;
	const struct super_operations___140 *s_op;
	const struct dquot_operations___140 *dq_op;
	const struct quotactl_ops___140 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___140 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___140 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___140 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___141 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___140 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___140 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___140 *bd_inode;
	struct super_block___140 *bd_super;
	struct mutex___141 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___140 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___141 bd_fsfreeze_mutex;
};

struct iattr___140 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___140 *ia_file;
};

struct dquot___140 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___141 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___140 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___140 {
	int qf_fmt_id;
	const struct quota_format_ops___140 *qf_ops;
	struct module___71 *qf_owner;
	struct quota_format_type___140 *qf_next;
};

struct quota_format_ops___140 {
	int (*check_quota_file)(struct super_block___140 *, int);
	int (*read_file_info)(struct super_block___140 *, int);
	int (*write_file_info)(struct super_block___140 *, int);
	int (*free_file_info)(struct super_block___140 *, int);
	int (*read_dqblk)(struct dquot___140 *);
	int (*commit_dqblk)(struct dquot___140 *);
	int (*release_dqblk)(struct dquot___140 *);
};

struct dquot_operations___140 {
	int (*write_dquot)(struct dquot___140 *);
	struct dquot___140 * (*alloc_dquot)(struct super_block___140 *, int);
	void (*destroy_dquot)(struct dquot___140 *);
	int (*acquire_dquot)(struct dquot___140 *);
	int (*release_dquot)(struct dquot___140 *);
	int (*mark_dirty)(struct dquot___140 *);
	int (*write_info)(struct super_block___140 *, int);
	qsize_t * (*get_reserved_space)(struct inode___140 *);
};

struct quotactl_ops___140 {
	int (*quota_on)(struct super_block___140 *, int, int, struct path___140 *);
	int (*quota_on_meta)(struct super_block___140 *, int, int);
	int (*quota_off)(struct super_block___140 *, int);
	int (*quota_sync)(struct super_block___140 *, int);
	int (*get_info)(struct super_block___140 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___140 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___140 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___140 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___140 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___140 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___140 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___140 *, unsigned int);
};

struct address_space_operations___140 {
	int (*writepage)(struct page___140 *, struct writeback_control *);
	int (*readpage)(struct file___140 *, struct page___140 *);
	int (*writepages)(struct address_space___140 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___140 *);
	int (*readpages)(struct file___140 *, struct address_space___140 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___140 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___140 **, void **);
	int (*write_end)(struct file___140 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___140 *, void *);
	sector_t (*bmap)(struct address_space___140 *, sector_t);
	void (*invalidatepage)(struct page___140 *, long unsigned int);
	int (*releasepage)(struct page___140 *, gfp_t);
	void (*freepage)(struct page___140 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___140 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___140 *, struct page___140 *, struct page___140 *, enum migrate_mode);
	int (*launder_page)(struct page___140 *);
	int (*is_partially_uptodate)(struct page___140 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___140 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___140 *, struct page___140 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___140 *, sector_t *);
	void (*swap_deactivate)(struct file___140 *);
	void (*invalidatepage_range)(struct page___140 *, unsigned int, unsigned int);
};

struct nameidata___20;

struct inode_operations___140 {
	struct dentry___140 * (*lookup)(struct inode___140 *, struct dentry___140 *, unsigned int);
	void * (*follow_link)(struct dentry___140 *, struct nameidata___20 *);
	int (*permission)(struct inode___140 *, int);
	struct posix_acl * (*get_acl)(struct inode___140 *, int);
	int (*readlink)(struct dentry___140 *, char *, int);
	void (*put_link)(struct dentry___140 *, struct nameidata___20 *, void *);
	int (*create)(struct inode___140 *, struct dentry___140 *, umode_t, bool);
	int (*link)(struct dentry___140 *, struct inode___140 *, struct dentry___140 *);
	int (*unlink)(struct inode___140 *, struct dentry___140 *);
	int (*symlink)(struct inode___140 *, struct dentry___140 *, const char *);
	int (*mkdir)(struct inode___140 *, struct dentry___140 *, umode_t);
	int (*rmdir)(struct inode___140 *, struct dentry___140 *);
	int (*mknod)(struct inode___140 *, struct dentry___140 *, umode_t, dev_t);
	int (*rename)(struct inode___140 *, struct dentry___140 *, struct inode___140 *, struct dentry___140 *);
	int (*setattr)(struct dentry___140 *, struct iattr___140 *);
	int (*getattr)(struct vfsmount *, struct dentry___140 *, struct kstat *);
	int (*setxattr)(struct dentry___140 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___140 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___140 *, char *, size_t);
	int (*removexattr)(struct dentry___140 *, const char *);
	int (*fiemap)(struct inode___140 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___140 *, struct timespec *, int);
	int (*atomic_open)(struct inode___140 *, struct dentry___140 *, struct file___140 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___87;

struct file_operations___140 {
	struct module___71 *owner;
	loff_t (*llseek)(struct file___140 *, loff_t, int);
	ssize_t (*read)(struct file___140 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___140 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___140 *, void *, filldir_t);
	unsigned int (*poll)(struct file___140 *, struct poll_table_struct___87 *);
	long int (*unlocked_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___140 *, struct vm_area_struct___145 *);
	int (*open)(struct inode___140 *, struct file___140 *);
	int (*flush)(struct file___140 *, fl_owner_t);
	int (*release)(struct inode___140 *, struct file___140 *);
	int (*fsync)(struct file___140 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___140 *, int);
	int (*lock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*sendpage)(struct file___140 *, struct page___140 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___140 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___140 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___140 *, long int, struct file_lock___140 **, void **);
		struct {
			int (*setlease)(struct file___140 *, long int, struct file_lock___140 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___140 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___140 *);
};

struct fasync_struct___140;

struct file_lock_operations___140;

struct lock_manager_operations___140;

struct file_lock___140 {
	struct file_lock___140 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___140 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___140 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___140 *fl_ops;
	const struct lock_manager_operations___140 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___140 {
	void (*fl_copy_lock)(struct file_lock___140 *, struct file_lock___140 *);
	void (*fl_release_private)(struct file_lock___140 *);
};

struct lock_manager_operations___140 {
	int (*lm_compare_owner)(struct file_lock___140 *, struct file_lock___140 *);
	long unsigned int (*lm_owner_key)(struct file_lock___140 *);
	void (*lm_notify)(struct file_lock___140 *);
	int (*lm_grant)(struct file_lock___140 *, struct file_lock___140 *, int);
	void (*lm_break)(struct file_lock___140 *);
	int (*lm_change)(struct file_lock___140 **, int);
};

struct fasync_struct___140 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___140 *fa_next;
	struct file___140 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___140 {
	const char *name;
	int fs_flags;
	struct dentry___140 * (*mount)(struct file_system_type___140 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___140 *);
	struct module___71 *owner;
	struct file_system_type___140 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___140 {
	struct inode___140 * (*alloc_inode)(struct super_block___140 *);
	void (*destroy_inode)(struct inode___140 *);
	void (*dirty_inode)(struct inode___140 *, int);
	int (*write_inode)(struct inode___140 *, struct writeback_control *);
	int (*drop_inode)(struct inode___140 *);
	void (*evict_inode)(struct inode___140 *);
	void (*put_super)(struct super_block___140 *);
	int (*sync_fs)(struct super_block___140 *, int);
	int (*freeze_fs)(struct super_block___140 *);
	int (*unfreeze_fs)(struct super_block___140 *);
	int (*statfs)(struct dentry___140 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___140 *, int *, char *);
	void (*umount_begin)(struct super_block___140 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___140 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___140 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___140 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___140 *);
	ssize_t (*quota_read)(struct super_block___140 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___140 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___140 *);
	int (*bdev_try_to_free_page)(struct super_block___140 *, struct page___140 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___140 *);
	void (*free_cached_objects)(struct super_block___140 *, int);
};

typedef void (*poll_queue_proc___89)(struct file___140 *, wait_queue_head_t *, struct poll_table_struct___87 *);

struct poll_table_struct___87 {
	poll_queue_proc___89 _qproc;
	long unsigned int _key;
};

struct nameidata___20 {
	struct path___140 path;
	struct qstr last;
	struct path___140 root;
	struct inode___140 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct xol_area___140 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___140 *page;
	long unsigned int vaddr;
};

struct core_thread___140 {
	struct task_struct___140 *task;
	struct core_thread___140 *next;
};

struct core_state___140 {
	atomic_t nr_threads;
	struct core_thread___140 dumper;
	struct completion startup;
};

struct signal_struct___140 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___140 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___140 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___79 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___141 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct poll_table_struct___87 poll_table___17;

struct sysfs_open_dirent {
	atomic_t refcnt;
	atomic_t event;
	wait_queue_head_t poll;
	struct list_head buffers;
};

struct sysfs_inode_attrs___2 {
	struct iattr___140 ia_iattr;
	void *ia_secdata;
	u32 ia_secdata_len;
};

struct sysfs_addrm_cxt___2 {
	struct sysfs_dirent___2 *parent_sd;
	struct sysfs_dirent___2 *removed;
};

struct sysfs_buffer {
	size_t count;
	loff_t pos;
	char *page;
	const struct sysfs_ops___8 *ops;
	struct mutex___141 mutex;
	int needs_read_fill;
	int event;
	struct list_head list;
};

struct sysfs_schedule_callback_struct {
	struct list_head workq_list;
	struct kobject___8 *kobj;
	void (*func)(void *);
	void *data;
	struct module___71 *owner;
	struct work_struct work;
};

struct kset___9;

struct kobj_type___9;

struct sysfs_dirent___3;

struct kobject___9 {
	const char *name;
	struct list_head entry;
	struct kobject___9 *parent;
	struct kset___9 *kset;
	struct kobj_type___9 *ktype;
	struct sysfs_dirent___3 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___72;

struct module_kobject___71 {
	struct kobject___9 kobj;
	struct module___72 *mod;
	struct kobject___9 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___71;

struct module___72 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___71 mkobj;
	struct module_attribute___71 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___9 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___141;

struct dentry_operations___141;

struct super_block___141;

struct dentry___141 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___141 *d_parent;
	struct qstr d_name;
	struct inode___141 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___141 *d_op;
	struct super_block___141 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___141;

struct address_space___141 {
	struct inode___141 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___141 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___141 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___141;

struct file_operations___141;

struct file_lock___141;

struct dquot___141;

struct block_device___141;

struct inode___141 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___141 *i_op;
	struct super_block___141 *i_sb;
	struct address_space___141 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___141 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___141 *i_fop;
	struct file_lock___141 *i_flock;
	struct address_space___141 i_data;
	struct dquot___141 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___141 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___32;

struct path___141;

struct dentry_operations___141 {
	int (*d_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_hash)(const struct dentry___141 *, struct qstr *);
	int (*d_compare)(const struct dentry___141 *, const struct dentry___141 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___141 *);
	void (*d_release)(struct dentry___141 *);
	void (*d_prune)(struct dentry___141 *);
	void (*d_iput)(struct dentry___141 *, struct inode___141 *);
	char * (*d_dname)(struct dentry___141 *, char *, int);
	struct vfsmount___32 * (*d_automount)(struct path___141 *);
	int (*d_manage)(struct dentry___141 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___141;

struct mem_dqinfo___141 {
	struct quota_format_type___141 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___141;

struct quota_info___141 {
	unsigned int flags;
	struct mutex___141 dqio_mutex;
	struct mutex___141 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___141 *files[2];
	struct mem_dqinfo___141 info[2];
	const struct quota_format_ops___141 *ops[2];
};

struct file_system_type___141;

struct super_operations___141;

struct dquot_operations___141;

struct quotactl_ops___141;

struct super_block___141 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___141 *s_type;
	const struct super_operations___141 *s_op;
	const struct dquot_operations___141 *dq_op;
	const struct quotactl_ops___141 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___141 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___141 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___141 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___141 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___141 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___32 {
	struct dentry___141 *mnt_root;
	struct super_block___141 *mnt_sb;
	int mnt_flags;
};

struct path___141 {
	struct vfsmount___32 *mnt;
	struct dentry___141 *dentry;
};

struct block_device___141 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___141 *bd_inode;
	struct super_block___141 *bd_super;
	struct mutex___141 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___141 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___141 bd_fsfreeze_mutex;
};

struct file___141;

struct iattr___141 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___141 *ia_file;
};

struct file___141 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___141 f_path;
	struct inode___141 *f_inode;
	const struct file_operations___141 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___141 *f_mapping;
	struct mutex___141 f_pos_lock;
};

struct dquot___141 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___141 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___141 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___141 {
	int qf_fmt_id;
	const struct quota_format_ops___141 *qf_ops;
	struct module___72 *qf_owner;
	struct quota_format_type___141 *qf_next;
};

struct quota_format_ops___141 {
	int (*check_quota_file)(struct super_block___141 *, int);
	int (*read_file_info)(struct super_block___141 *, int);
	int (*write_file_info)(struct super_block___141 *, int);
	int (*free_file_info)(struct super_block___141 *, int);
	int (*read_dqblk)(struct dquot___141 *);
	int (*commit_dqblk)(struct dquot___141 *);
	int (*release_dqblk)(struct dquot___141 *);
};

struct dquot_operations___141 {
	int (*write_dquot)(struct dquot___141 *);
	struct dquot___141 * (*alloc_dquot)(struct super_block___141 *, int);
	void (*destroy_dquot)(struct dquot___141 *);
	int (*acquire_dquot)(struct dquot___141 *);
	int (*release_dquot)(struct dquot___141 *);
	int (*mark_dirty)(struct dquot___141 *);
	int (*write_info)(struct super_block___141 *, int);
	qsize_t * (*get_reserved_space)(struct inode___141 *);
};

struct quotactl_ops___141 {
	int (*quota_on)(struct super_block___141 *, int, int, struct path___141 *);
	int (*quota_on_meta)(struct super_block___141 *, int, int);
	int (*quota_off)(struct super_block___141 *, int);
	int (*quota_sync)(struct super_block___141 *, int);
	int (*get_info)(struct super_block___141 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___141 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___141 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___141 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___141 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___141 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___141 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___141 *, unsigned int);
};

struct address_space_operations___141 {
	int (*writepage)(struct page___20 *, struct writeback_control *);
	int (*readpage)(struct file___141 *, struct page___20 *);
	int (*writepages)(struct address_space___141 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___20 *);
	int (*readpages)(struct file___141 *, struct address_space___141 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___141 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___20 **, void **);
	int (*write_end)(struct file___141 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___20 *, void *);
	sector_t (*bmap)(struct address_space___141 *, sector_t);
	void (*invalidatepage)(struct page___20 *, long unsigned int);
	int (*releasepage)(struct page___20 *, gfp_t);
	void (*freepage)(struct page___20 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___141 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___141 *, struct page___20 *, struct page___20 *, enum migrate_mode);
	int (*launder_page)(struct page___20 *);
	int (*is_partially_uptodate)(struct page___20 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___20 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___141 *, struct page___20 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___141 *, sector_t *);
	void (*swap_deactivate)(struct file___141 *);
	void (*invalidatepage_range)(struct page___20 *, unsigned int, unsigned int);
};

struct nameidata___21;

struct inode_operations___141 {
	struct dentry___141 * (*lookup)(struct inode___141 *, struct dentry___141 *, unsigned int);
	void * (*follow_link)(struct dentry___141 *, struct nameidata___21 *);
	int (*permission)(struct inode___141 *, int);
	struct posix_acl * (*get_acl)(struct inode___141 *, int);
	int (*readlink)(struct dentry___141 *, char *, int);
	void (*put_link)(struct dentry___141 *, struct nameidata___21 *, void *);
	int (*create)(struct inode___141 *, struct dentry___141 *, umode_t, bool);
	int (*link)(struct dentry___141 *, struct inode___141 *, struct dentry___141 *);
	int (*unlink)(struct inode___141 *, struct dentry___141 *);
	int (*symlink)(struct inode___141 *, struct dentry___141 *, const char *);
	int (*mkdir)(struct inode___141 *, struct dentry___141 *, umode_t);
	int (*rmdir)(struct inode___141 *, struct dentry___141 *);
	int (*mknod)(struct inode___141 *, struct dentry___141 *, umode_t, dev_t);
	int (*rename)(struct inode___141 *, struct dentry___141 *, struct inode___141 *, struct dentry___141 *);
	int (*setattr)(struct dentry___141 *, struct iattr___141 *);
	int (*getattr)(struct vfsmount___32 *, struct dentry___141 *, struct kstat *);
	int (*setxattr)(struct dentry___141 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___141 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___141 *, char *, size_t);
	int (*removexattr)(struct dentry___141 *, const char *);
	int (*fiemap)(struct inode___141 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___141 *, struct timespec *, int);
	int (*atomic_open)(struct inode___141 *, struct dentry___141 *, struct file___141 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___141 {
	struct module___72 *owner;
	loff_t (*llseek)(struct file___141 *, loff_t, int);
	ssize_t (*read)(struct file___141 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___141 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___141 *, void *, filldir_t);
	unsigned int (*poll)(struct file___141 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___141 *, struct vm_area_struct___19 *);
	int (*open)(struct inode___141 *, struct file___141 *);
	int (*flush)(struct file___141 *, fl_owner_t);
	int (*release)(struct inode___141 *, struct file___141 *);
	int (*fsync)(struct file___141 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___141 *, int);
	int (*lock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*sendpage)(struct file___141 *, struct page___20 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___141 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___141 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___141 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___141 *, long int, struct file_lock___141 **, void **);
		struct {
			int (*setlease)(struct file___141 *, long int, struct file_lock___141 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___141 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___141 *);
};

struct fasync_struct___141;

struct file_lock_operations___141;

struct lock_manager_operations___141;

struct file_lock___141 {
	struct file_lock___141 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___141 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___141 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___141 *fl_ops;
	const struct lock_manager_operations___141 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___141 {
	void (*fl_copy_lock)(struct file_lock___141 *, struct file_lock___141 *);
	void (*fl_release_private)(struct file_lock___141 *);
};

struct lock_manager_operations___141 {
	int (*lm_compare_owner)(struct file_lock___141 *, struct file_lock___141 *);
	long unsigned int (*lm_owner_key)(struct file_lock___141 *);
	void (*lm_notify)(struct file_lock___141 *);
	int (*lm_grant)(struct file_lock___141 *, struct file_lock___141 *, int);
	void (*lm_break)(struct file_lock___141 *);
	int (*lm_change)(struct file_lock___141 **, int);
};

struct fasync_struct___141 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___141 *fa_next;
	struct file___141 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___141 {
	const char *name;
	int fs_flags;
	struct dentry___141 * (*mount)(struct file_system_type___141 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___141 *);
	struct module___72 *owner;
	struct file_system_type___141 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___141 {
	struct inode___141 * (*alloc_inode)(struct super_block___141 *);
	void (*destroy_inode)(struct inode___141 *);
	void (*dirty_inode)(struct inode___141 *, int);
	int (*write_inode)(struct inode___141 *, struct writeback_control *);
	int (*drop_inode)(struct inode___141 *);
	void (*evict_inode)(struct inode___141 *);
	void (*put_super)(struct super_block___141 *);
	int (*sync_fs)(struct super_block___141 *, int);
	int (*freeze_fs)(struct super_block___141 *);
	int (*unfreeze_fs)(struct super_block___141 *);
	int (*statfs)(struct dentry___141 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___141 *, int *, char *);
	void (*umount_begin)(struct super_block___141 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___141 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___141 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___141 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___141 *);
	ssize_t (*quota_read)(struct super_block___141 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___141 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___141 *);
	int (*bdev_try_to_free_page)(struct super_block___141 *, struct page___20 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___141 *);
	void (*free_cached_objects)(struct super_block___141 *, int);
};

struct nameidata___21 {
	struct path___141 path;
	struct qstr last;
	struct path___141 root;
	struct inode___141 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct bin_attribute___105 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___141 *, struct kobject___9 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___141 *, struct kobject___9 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	int (*mmap)(struct file___141 *, struct kobject___9 *, struct bin_attribute___105 *, struct vm_area_struct___19 *);
};

struct sysfs_ops___9 {
	ssize_t (*show)(struct kobject___9 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___9 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___9 *, const struct attribute *);
};

struct kset_uevent_ops___9;

struct kset___9 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___9 kobj;
	const struct kset_uevent_ops___9 *uevent_ops;
};

struct kobj_type___9 {
	void (*release)(struct kobject___9 *);
	const struct sysfs_ops___9 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___9 *);
	const void * (*namespace)(struct kobject___9 *);
};

struct sysfs_elem_dir___3 {
	struct kobject___9 *kobj;
	long unsigned int subdirs;
	struct rb_root children;
};

struct sysfs_elem_symlink___3 {
	struct sysfs_dirent___3 *target_sd;
};

struct sysfs_elem_bin_attr___3 {
	struct bin_attribute___105 *bin_attr;
	struct hlist_head buffers;
};

struct sysfs_inode_attrs___3;

struct sysfs_dirent___3 {
	atomic_t s_count;
	atomic_t s_active;
	struct sysfs_dirent___3 *s_parent;
	const char *s_name;
	struct rb_node s_rb;
	union {
		struct completion *completion;
		struct sysfs_dirent___3 *removed_list;
	} u;
	const void *s_ns;
	unsigned int s_hash;
	union {
		struct sysfs_elem_dir___3 s_dir;
		struct sysfs_elem_symlink___3 s_symlink;
		struct sysfs_elem_attr s_attr;
		struct sysfs_elem_bin_attr___3 s_bin_attr;
	};
	short unsigned int s_flags;
	umode_t s_mode;
	unsigned int s_ino;
	struct sysfs_inode_attrs___3 *s_iattr;
};

struct kset_uevent_ops___9 {
	int (* const filter)(struct kset___9 *, struct kobject___9 *);
	const char * (* const name)(struct kset___9 *, struct kobject___9 *);
	int (* const uevent)(struct kset___9 *, struct kobject___9 *, struct kobj_uevent_env *);
};

struct module_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___71 *, struct module_kobject___71 *, char *);
	ssize_t (*store)(struct module_attribute___71 *, struct module_kobject___71 *, const char *, size_t);
	void (*setup)(struct module___72 *, const char *);
	int (*test)(struct module___72 *);
	void (*free)(struct module___72 *);
};

struct memcg_cache_params___128;

struct kmem_cache___128 {
	struct kmem_cache_cpu___127 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___9 kobj;
	struct memcg_cache_params___128 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___128 {
	bool is_root_cache;
	union {
		struct kmem_cache___128 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___128 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct sysfs_inode_attrs___3 {
	struct iattr___141 ia_iattr;
	void *ia_secdata;
	u32 ia_secdata_len;
};

struct sysfs_addrm_cxt___3 {
	struct sysfs_dirent___3 *parent_sd;
	struct sysfs_dirent___3 *removed;
};

struct sysfs_super_info {
	void *ns[2];
};

struct page___141;

typedef struct page___141 *pgtable_t___141;

struct address_space___142;

struct kmem_cache___129;

struct page___141 {
	long unsigned int flags;
	struct address_space___142 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___141 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___141 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___129 *slab_cache;
		struct page___141 *first_page;
	};
	long: 64;
};

struct task_struct___141;

struct pv_cpu_ops___141 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___141 *);
	void (*end_context_switch)(struct task_struct___141 *);
};

struct mutex___142 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___141 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___137 {
	struct page___141 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___146;

struct signal_struct___141;

struct task_struct___141 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___141 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___146 *mm;
	struct mm_struct___146 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___141 *real_parent;
	struct task_struct___141 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___141 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___79 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___141 = 0,
		VTIME_USER___141 = 1,
		VTIME_SYS___141 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___84 *nsproxy;
	struct signal_struct___141 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___142 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___137 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___146 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___146 *, struct mm_struct___146 *);
	void (*dup_mmap)(struct mm_struct___146 *, struct mm_struct___146 *);
	void (*exit_mmap)(struct mm_struct___146 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___146 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___146 *);
	void (*pgd_free)(struct mm_struct___146 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___146 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___146 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___146 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___146 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___146 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___146 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___146 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___146 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___146 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___146 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___146 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___142 lock;
	void *vdso;
} mm_context_t___142;

struct xol_area___141;

struct uprobes_state___141 {
	struct xol_area___141 *xol_area;
};

struct vm_area_struct___146;

struct file___142;

struct core_state___141;

struct mm_struct___146 {
	struct vm_area_struct___146 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___146 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___146 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___142 context;
	long unsigned int flags;
	struct core_state___141 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___141 *owner;
	struct file___142 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___141 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___10;

struct kobj_type___10;

struct sysfs_dirent___4;

struct kobject___10 {
	const char *name;
	struct list_head entry;
	struct kobject___10 *parent;
	struct kset___10 *kset;
	struct kobj_type___10 *ktype;
	struct sysfs_dirent___4 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___73;

struct module_kobject___72 {
	struct kobject___10 kobj;
	struct module___73 *mod;
	struct kobject___10 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___72;

struct module___73 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___72 mkobj;
	struct module_attribute___72 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___10 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___141 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___142;

struct dentry_operations___142;

struct super_block___142;

struct dentry___142 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___142 *d_parent;
	struct qstr d_name;
	struct inode___142 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___142 *d_op;
	struct super_block___142 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___142;

struct address_space___142 {
	struct inode___142 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___142 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___142 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___142;

struct file_operations___142;

struct file_lock___142;

struct dquot___142;

struct block_device___142;

struct inode___142 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___142 *i_op;
	struct super_block___142 *i_sb;
	struct address_space___142 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___142 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___142 *i_fop;
	struct file_lock___142 *i_flock;
	struct address_space___142 i_data;
	struct dquot___142 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___142 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___33;

struct path___142;

struct dentry_operations___142 {
	int (*d_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_hash)(const struct dentry___142 *, struct qstr *);
	int (*d_compare)(const struct dentry___142 *, const struct dentry___142 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___142 *);
	void (*d_release)(struct dentry___142 *);
	void (*d_prune)(struct dentry___142 *);
	void (*d_iput)(struct dentry___142 *, struct inode___142 *);
	char * (*d_dname)(struct dentry___142 *, char *, int);
	struct vfsmount___33 * (*d_automount)(struct path___142 *);
	int (*d_manage)(struct dentry___142 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___142;

struct mem_dqinfo___142 {
	struct quota_format_type___142 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___142;

struct quota_info___142 {
	unsigned int flags;
	struct mutex___142 dqio_mutex;
	struct mutex___142 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___142 *files[2];
	struct mem_dqinfo___142 info[2];
	const struct quota_format_ops___142 *ops[2];
};

struct file_system_type___142;

struct super_operations___142;

struct dquot_operations___142;

struct quotactl_ops___142;

struct super_block___142 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___142 *s_type;
	const struct super_operations___142 *s_op;
	const struct dquot_operations___142 *dq_op;
	const struct quotactl_ops___142 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___142 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___142 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___142 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___142 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___142 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___33 {
	struct dentry___142 *mnt_root;
	struct super_block___142 *mnt_sb;
	int mnt_flags;
};

struct path___142 {
	struct vfsmount___33 *mnt;
	struct dentry___142 *dentry;
};

struct smp_ops___141 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___141 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___142 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___142 *bd_inode;
	struct super_block___142 *bd_super;
	struct mutex___142 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___142 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___142 bd_fsfreeze_mutex;
};

struct iattr___142 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___142 *ia_file;
};

struct file___142 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___142 f_path;
	struct inode___142 *f_inode;
	const struct file_operations___142 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___142 *f_mapping;
	struct mutex___142 f_pos_lock;
};

struct zone___141;

struct lruvec___141 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___141 *zone;
};

struct pglist_data___141;

struct zone___141 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___141 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___141 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___141 {
	struct zone___141 *zone;
	int zone_idx;
};

struct zonelist___141 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___141 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___141 {
	struct zone___141 node_zones[4];
	struct zonelist___141 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___141 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___142 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___142 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___142 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___142 {
	int qf_fmt_id;
	const struct quota_format_ops___142 *qf_ops;
	struct module___73 *qf_owner;
	struct quota_format_type___142 *qf_next;
};

struct quota_format_ops___142 {
	int (*check_quota_file)(struct super_block___142 *, int);
	int (*read_file_info)(struct super_block___142 *, int);
	int (*write_file_info)(struct super_block___142 *, int);
	int (*free_file_info)(struct super_block___142 *, int);
	int (*read_dqblk)(struct dquot___142 *);
	int (*commit_dqblk)(struct dquot___142 *);
	int (*release_dqblk)(struct dquot___142 *);
};

struct dquot_operations___142 {
	int (*write_dquot)(struct dquot___142 *);
	struct dquot___142 * (*alloc_dquot)(struct super_block___142 *, int);
	void (*destroy_dquot)(struct dquot___142 *);
	int (*acquire_dquot)(struct dquot___142 *);
	int (*release_dquot)(struct dquot___142 *);
	int (*mark_dirty)(struct dquot___142 *);
	int (*write_info)(struct super_block___142 *, int);
	qsize_t * (*get_reserved_space)(struct inode___142 *);
};

struct quotactl_ops___142 {
	int (*quota_on)(struct super_block___142 *, int, int, struct path___142 *);
	int (*quota_on_meta)(struct super_block___142 *, int, int);
	int (*quota_off)(struct super_block___142 *, int);
	int (*quota_sync)(struct super_block___142 *, int);
	int (*get_info)(struct super_block___142 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___142 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___142 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___142 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___142 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___142 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___142 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___142 *, unsigned int);
};

struct address_space_operations___142 {
	int (*writepage)(struct page___141 *, struct writeback_control *);
	int (*readpage)(struct file___142 *, struct page___141 *);
	int (*writepages)(struct address_space___142 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___141 *);
	int (*readpages)(struct file___142 *, struct address_space___142 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___142 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___141 **, void **);
	int (*write_end)(struct file___142 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___141 *, void *);
	sector_t (*bmap)(struct address_space___142 *, sector_t);
	void (*invalidatepage)(struct page___141 *, long unsigned int);
	int (*releasepage)(struct page___141 *, gfp_t);
	void (*freepage)(struct page___141 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___142 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___142 *, struct page___141 *, struct page___141 *, enum migrate_mode);
	int (*launder_page)(struct page___141 *);
	int (*is_partially_uptodate)(struct page___141 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___141 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___142 *, struct page___141 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___142 *, sector_t *);
	void (*swap_deactivate)(struct file___142 *);
	void (*invalidatepage_range)(struct page___141 *, unsigned int, unsigned int);
};

struct inode_operations___142 {
	struct dentry___142 * (*lookup)(struct inode___142 *, struct dentry___142 *, unsigned int);
	void * (*follow_link)(struct dentry___142 *, struct nameidata *);
	int (*permission)(struct inode___142 *, int);
	struct posix_acl * (*get_acl)(struct inode___142 *, int);
	int (*readlink)(struct dentry___142 *, char *, int);
	void (*put_link)(struct dentry___142 *, struct nameidata *, void *);
	int (*create)(struct inode___142 *, struct dentry___142 *, umode_t, bool);
	int (*link)(struct dentry___142 *, struct inode___142 *, struct dentry___142 *);
	int (*unlink)(struct inode___142 *, struct dentry___142 *);
	int (*symlink)(struct inode___142 *, struct dentry___142 *, const char *);
	int (*mkdir)(struct inode___142 *, struct dentry___142 *, umode_t);
	int (*rmdir)(struct inode___142 *, struct dentry___142 *);
	int (*mknod)(struct inode___142 *, struct dentry___142 *, umode_t, dev_t);
	int (*rename)(struct inode___142 *, struct dentry___142 *, struct inode___142 *, struct dentry___142 *);
	int (*setattr)(struct dentry___142 *, struct iattr___142 *);
	int (*getattr)(struct vfsmount___33 *, struct dentry___142 *, struct kstat *);
	int (*setxattr)(struct dentry___142 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___142 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___142 *, char *, size_t);
	int (*removexattr)(struct dentry___142 *, const char *);
	int (*fiemap)(struct inode___142 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___142 *, struct timespec *, int);
	int (*atomic_open)(struct inode___142 *, struct dentry___142 *, struct file___142 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___142 {
	struct module___73 *owner;
	loff_t (*llseek)(struct file___142 *, loff_t, int);
	ssize_t (*read)(struct file___142 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___142 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___142 *, void *, filldir_t);
	unsigned int (*poll)(struct file___142 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___142 *, struct vm_area_struct___146 *);
	int (*open)(struct inode___142 *, struct file___142 *);
	int (*flush)(struct file___142 *, fl_owner_t);
	int (*release)(struct inode___142 *, struct file___142 *);
	int (*fsync)(struct file___142 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___142 *, int);
	int (*lock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*sendpage)(struct file___142 *, struct page___141 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___142 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___142 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___142 *, long int, struct file_lock___142 **, void **);
		struct {
			int (*setlease)(struct file___142 *, long int, struct file_lock___142 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___142 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___142 *);
};

struct fasync_struct___142;

struct file_lock_operations___142;

struct lock_manager_operations___142;

struct file_lock___142 {
	struct file_lock___142 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___142 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___142 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___142 *fl_ops;
	const struct lock_manager_operations___142 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___142 {
	void (*fl_copy_lock)(struct file_lock___142 *, struct file_lock___142 *);
	void (*fl_release_private)(struct file_lock___142 *);
};

struct lock_manager_operations___142 {
	int (*lm_compare_owner)(struct file_lock___142 *, struct file_lock___142 *);
	long unsigned int (*lm_owner_key)(struct file_lock___142 *);
	void (*lm_notify)(struct file_lock___142 *);
	int (*lm_grant)(struct file_lock___142 *, struct file_lock___142 *, int);
	void (*lm_break)(struct file_lock___142 *);
	int (*lm_change)(struct file_lock___142 **, int);
};

struct fasync_struct___142 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___142 *fa_next;
	struct file___142 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___142 {
	const char *name;
	int fs_flags;
	struct dentry___142 * (*mount)(struct file_system_type___142 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___142 *);
	struct module___73 *owner;
	struct file_system_type___142 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___142 {
	struct inode___142 * (*alloc_inode)(struct super_block___142 *);
	void (*destroy_inode)(struct inode___142 *);
	void (*dirty_inode)(struct inode___142 *, int);
	int (*write_inode)(struct inode___142 *, struct writeback_control *);
	int (*drop_inode)(struct inode___142 *);
	void (*evict_inode)(struct inode___142 *);
	void (*put_super)(struct super_block___142 *);
	int (*sync_fs)(struct super_block___142 *, int);
	int (*freeze_fs)(struct super_block___142 *);
	int (*unfreeze_fs)(struct super_block___142 *);
	int (*statfs)(struct dentry___142 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___142 *, int *, char *);
	void (*umount_begin)(struct super_block___142 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___142 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___142 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___142 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___142 *);
	ssize_t (*quota_read)(struct super_block___142 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___142 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___142 *);
	int (*bdev_try_to_free_page)(struct super_block___142 *, struct page___141 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___142 *);
	void (*free_cached_objects)(struct super_block___142 *, int);
};

struct vm_operations_struct___125;

struct vm_area_struct___146 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___146 *vm_next;
	struct vm_area_struct___146 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___146 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___125 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___142 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xol_area___141 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___141 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___128;

struct memcg_cache_params___129;

struct kmem_cache___129 {
	struct kmem_cache_cpu___128 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___10 kobj;
	struct memcg_cache_params___129 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___122;

struct vm_operations_struct___125 {
	void (*open)(struct vm_area_struct___146 *);
	void (*close)(struct vm_area_struct___146 *);
	int (*fault)(struct vm_area_struct___146 *, struct vm_fault___122 *);
	int (*page_mkwrite)(struct vm_area_struct___146 *, struct vm_fault___122 *);
	int (*access)(struct vm_area_struct___146 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___146 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___146 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___146 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___146 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___141 {
	struct task_struct___141 *task;
	struct core_thread___141 *next;
};

struct core_state___141 {
	atomic_t nr_threads;
	struct core_thread___141 dumper;
	struct completion startup;
};

struct vm_fault___122 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___141 *page;
};

struct bin_attribute___106 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___142 *, struct kobject___10 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___142 *, struct kobject___10 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	int (*mmap)(struct file___142 *, struct kobject___10 *, struct bin_attribute___106 *, struct vm_area_struct___146 *);
};

struct sysfs_ops___10 {
	ssize_t (*show)(struct kobject___10 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___10 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___10 *, const struct attribute *);
};

struct kset_uevent_ops___10;

struct kset___10 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___10 kobj;
	const struct kset_uevent_ops___10 *uevent_ops;
};

struct kobj_type___10 {
	void (*release)(struct kobject___10 *);
	const struct sysfs_ops___10 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___10 *);
	const void * (*namespace)(struct kobject___10 *);
};

struct sysfs_elem_dir___4 {
	struct kobject___10 *kobj;
	long unsigned int subdirs;
	struct rb_root children;
};

struct sysfs_elem_symlink___4 {
	struct sysfs_dirent___4 *target_sd;
};

struct sysfs_elem_bin_attr___4 {
	struct bin_attribute___106 *bin_attr;
	struct hlist_head buffers;
};

struct sysfs_inode_attrs___4;

struct sysfs_dirent___4 {
	atomic_t s_count;
	atomic_t s_active;
	struct sysfs_dirent___4 *s_parent;
	const char *s_name;
	struct rb_node s_rb;
	union {
		struct completion *completion;
		struct sysfs_dirent___4 *removed_list;
	} u;
	const void *s_ns;
	unsigned int s_hash;
	union {
		struct sysfs_elem_dir___4 s_dir;
		struct sysfs_elem_symlink___4 s_symlink;
		struct sysfs_elem_attr s_attr;
		struct sysfs_elem_bin_attr___4 s_bin_attr;
	};
	short unsigned int s_flags;
	umode_t s_mode;
	unsigned int s_ino;
	struct sysfs_inode_attrs___4 *s_iattr;
};

struct kset_uevent_ops___10 {
	int (* const filter)(struct kset___10 *, struct kobject___10 *);
	const char * (* const name)(struct kset___10 *, struct kobject___10 *);
	int (* const uevent)(struct kset___10 *, struct kobject___10 *, struct kobj_uevent_env *);
};

struct module_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___72 *, struct module_kobject___72 *, char *);
	ssize_t (*store)(struct module_attribute___72 *, struct module_kobject___72 *, const char *, size_t);
	void (*setup)(struct module___73 *, const char *);
	int (*test)(struct module___73 *);
	void (*free)(struct module___73 *);
};

struct kmem_cache_cpu___128 {
	void **freelist;
	long unsigned int tid;
	struct page___141 *page;
	struct page___141 *partial;
};

struct memcg_cache_params___129 {
	bool is_root_cache;
	union {
		struct kmem_cache___129 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___129 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___141 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___141 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___141 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___79 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___142 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_inode_attrs___4 {
	struct iattr___142 ia_iattr;
	void *ia_secdata;
	u32 ia_secdata_len;
};

struct bin_buffer {
	struct mutex___142 mutex;
	void *buffer;
	int mmapped;
	const struct vm_operations_struct___125 *vm_ops;
	struct file___142 *file;
	struct hlist_node list;
};

struct attribute_group___104 {
	const char *name;
	umode_t (*is_visible)(struct kobject___9 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___105 **bin_attrs;
};

struct configfs_attribute {
	const char *ca_name;
	struct module *ca_owner;
	umode_t ca_mode;
};

struct configfs_dirent {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	struct list_head s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___124 *s_dentry;
	struct iattr___124 *s_iattr;
};

struct config_group;

struct config_item_type;

struct config_item {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item *ci_parent;
	struct config_group *ci_group;
	struct config_item_type *ci_type;
	struct dentry___142 *ci_dentry;
};

struct configfs_subsystem;

struct config_group {
	struct config_item cg_item;
	struct list_head cg_children;
	struct configfs_subsystem *cg_subsys;
	struct config_group **default_groups;
};

struct configfs_item_operations;

struct configfs_group_operations;

struct config_item_type {
	struct module___73 *ct_owner;
	struct configfs_item_operations *ct_item_ops;
	struct configfs_group_operations *ct_group_ops;
	struct configfs_attribute **ct_attrs;
};

struct configfs_item_operations {
	void (*release)(struct config_item *);
	ssize_t (*show_attribute)(struct config_item *, struct configfs_attribute *, char *);
	ssize_t (*store_attribute)(struct config_item *, struct configfs_attribute *, const char *, size_t);
	int (*allow_link)(struct config_item *, struct config_item *);
	int (*drop_link)(struct config_item *, struct config_item *);
};

struct configfs_group_operations {
	struct config_item * (*make_item)(struct config_group *, const char *);
	struct config_group * (*make_group)(struct config_group *, const char *);
	int (*commit_item)(struct config_item *);
	void (*disconnect_notify)(struct config_group *, struct config_item *);
	void (*drop_item)(struct config_group *, struct config_item *);
};

struct configfs_subsystem {
	struct config_group su_group;
	struct mutex___142 su_mutex;
};

struct configfs_dirent___2 {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	struct list_head s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___142 *s_dentry;
	struct iattr___142 *s_iattr;
};

struct configfs_symlink {
	struct list_head sl_list;
	struct config_item *sl_target;
};

struct configfs_buffer {
	size_t count;
	loff_t pos;
	char *page;
	struct configfs_item_operations *ops;
	struct mutex___142 mutex;
	int needs_read_fill;
};

struct config_group___2;

struct config_item_type___2;

struct config_item___2 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___2 *ci_parent;
	struct config_group___2 *ci_group;
	struct config_item_type___2 *ci_type;
	struct dentry___141 *ci_dentry;
};

struct configfs_subsystem___2;

struct config_group___2 {
	struct config_item___2 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___2 *cg_subsys;
	struct config_group___2 **default_groups;
};

struct configfs_item_operations___2;

struct configfs_group_operations___2;

struct config_item_type___2 {
	struct module___73 *ct_owner;
	struct configfs_item_operations___2 *ct_item_ops;
	struct configfs_group_operations___2 *ct_group_ops;
	struct configfs_attribute **ct_attrs;
};

struct configfs_item_operations___2 {
	void (*release)(struct config_item___2 *);
	ssize_t (*show_attribute)(struct config_item___2 *, struct configfs_attribute *, char *);
	ssize_t (*store_attribute)(struct config_item___2 *, struct configfs_attribute *, const char *, size_t);
	int (*allow_link)(struct config_item___2 *, struct config_item___2 *);
	int (*drop_link)(struct config_item___2 *, struct config_item___2 *);
};

struct configfs_group_operations___2 {
	struct config_item___2 * (*make_item)(struct config_group___2 *, const char *);
	struct config_group___2 * (*make_group)(struct config_group___2 *, const char *);
	int (*commit_item)(struct config_item___2 *);
	void (*disconnect_notify)(struct config_group___2 *, struct config_item___2 *);
	void (*drop_item)(struct config_group___2 *, struct config_item___2 *);
};

struct configfs_subsystem___2 {
	struct config_group___2 su_group;
	struct mutex___141 su_mutex;
};

struct configfs_dirent___3 {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	struct list_head s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___141 *s_dentry;
	struct iattr___141 *s_iattr;
};

struct configfs_symlink___2 {
	struct list_head sl_list;
	struct config_item___2 *sl_target;
};

struct pts_mount_opts {
	int setuid;
	int setgid;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	umode_t ptmxmode;
	int newinstance;
	int max;
};

enum {
	Opt_uid = 0,
	Opt_gid___2 = 1,
	Opt_mode = 2,
	Opt_ptmxmode = 3,
	Opt_newinstance = 4,
	Opt_max = 5,
	Opt_err___2 = 6,
};

struct pts_fs_info {
	struct ida allocated_ptys;
	struct pts_mount_opts mount_opts;
	struct dentry___132 *ptmx_dentry;
};

struct dcookie_struct {
	struct path___131 path;
	struct list_head hash_list;
};

struct dcookie_user {
	struct list_head next;
};

struct ramfs_mount_opts {
	umode_t mode;
};

enum {
	Opt_mode___2 = 0,
	Opt_err___3 = 1,
};

struct ramfs_fs_info {
	struct ramfs_mount_opts mount_opts;
};

struct hugetlbfs_sb_info___4 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___6 *hstate;
	struct hugepage_subpool *spool;
};

struct pagevec___5 {
	long unsigned int nr;
	long unsigned int cold;
	struct page___103 *pages[14];
};

struct hugetlbfs_config {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	long int nr_blocks;
	long int nr_inodes;
	struct hstate___6 *hstate;
};

struct hugetlbfs_inode_info {
	struct shared_policy policy;
	struct inode___103 vfs_inode;
};

enum {
	Opt_size = 0,
	Opt_nr_inodes = 1,
	Opt_mode___3 = 2,
	Opt_uid___2 = 3,
	Opt_gid___3 = 4,
	Opt_pagesize = 5,
	Opt_err___4 = 6,
};

enum {
	NO_SIZE = 0,
	SIZE_STD = 1,
	SIZE_PERCENT = 2,
};

struct inode___143;

struct dentry___143;

struct super_block___143;

struct iattr___143;

struct export_operations___8 {
	int (*encode_fh)(struct inode___143 *, __u32 *, int *, struct inode___143 *);
	struct dentry___143 * (*fh_to_dentry)(struct super_block___143 *, struct fid *, int, int);
	struct dentry___143 * (*fh_to_parent)(struct super_block___143 *, struct fid *, int, int);
	int (*get_name)(struct dentry___143 *, char *, struct dentry___143 *);
	struct dentry___143 * (*get_parent)(struct dentry___143 *);
	int (*commit_metadata)(struct inode___143 *);
	int (*get_uuid)(struct super_block___143 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___143 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___143 *, struct iomap *, int, struct iattr___143 *);
};

struct task_struct___142;

struct mutex___143 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___142 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct address_space_operations___143;

struct address_space___143 {
	struct inode___143 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___143 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___143 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___143;

struct file_operations___143;

struct file_lock___143;

struct dquot___143;

struct block_device___143;

struct inode___143 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___143 *i_op;
	struct super_block___143 *i_sb;
	struct address_space___143 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___143 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___143 *i_fop;
	struct file_lock___143 *i_flock;
	struct address_space___143 i_data;
	struct dquot___143 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___143 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___143;

struct dentry___143 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___143 *d_parent;
	struct qstr d_name;
	struct inode___143 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___143 *d_op;
	struct super_block___143 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct quota_format_type___143;

struct mem_dqinfo___143 {
	struct quota_format_type___143 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___143;

struct quota_info___143 {
	unsigned int flags;
	struct mutex___143 dqio_mutex;
	struct mutex___143 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___143 *files[2];
	struct mem_dqinfo___143 info[2];
	const struct quota_format_ops___143 *ops[2];
};

struct file_system_type___143;

struct super_operations___143;

struct dquot_operations___143;

struct quotactl_ops___143;

struct super_block___143 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___143 *s_type;
	const struct super_operations___143 *s_op;
	const struct dquot_operations___143 *dq_op;
	const struct quotactl_ops___143 *s_qcop;
	const struct export_operations___8 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___143 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___143 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___143 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___143 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___143 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct file___143;

struct iattr___143 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___143 *ia_file;
};

struct page___142;

typedef struct page___142 *pgtable_t___142;

struct page___142 {
	long unsigned int flags;
	struct address_space___143 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___142 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___142 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___142 *first_page;
	};
	long: 64;
};

struct pv_cpu_ops___142 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___70 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___70 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___142 *);
	void (*end_context_switch)(struct task_struct___142 *);
};

struct page_frag___138 {
	struct page___142 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___147;

struct signal_struct___142;

struct task_struct___142 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___142 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___147 *mm;
	struct mm_struct___147 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___142 *real_parent;
	struct task_struct___142 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___142 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___79 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___142 = 0,
		VTIME_USER___142 = 1,
		VTIME_SYS___142 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___70 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___142 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___143 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___138 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___147 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___147 *, struct mm_struct___147 *);
	void (*dup_mmap)(struct mm_struct___147 *, struct mm_struct___147 *);
	void (*exit_mmap)(struct mm_struct___147 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___147 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___147 *);
	void (*pgd_free)(struct mm_struct___147 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___147 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___147 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___147 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___147 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___147 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___147 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___147 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___147 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___147 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___147 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___147 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___143 lock;
	void *vdso;
} mm_context_t___143;

struct xol_area___142;

struct uprobes_state___142 {
	struct xol_area___142 *xol_area;
};

struct vm_area_struct___147;

struct core_state___142;

struct mm_struct___147 {
	struct vm_area_struct___147 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___147 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___147 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___143 context;
	long unsigned int flags;
	struct core_state___142 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___142 *owner;
	struct file___143 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___142 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___74;

struct module_kobject___73 {
	struct kobject___10 kobj;
	struct module___74 *mod;
	struct kobject___10 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___73;

struct module___74 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___73 mkobj;
	struct module_attribute___73 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___10 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___142 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct vfsmount___34;

struct path___143;

struct dentry_operations___143 {
	int (*d_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_hash)(const struct dentry___143 *, struct qstr *);
	int (*d_compare)(const struct dentry___143 *, const struct dentry___143 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___143 *);
	void (*d_release)(struct dentry___143 *);
	void (*d_prune)(struct dentry___143 *);
	void (*d_iput)(struct dentry___143 *, struct inode___143 *);
	char * (*d_dname)(struct dentry___143 *, char *, int);
	struct vfsmount___34 * (*d_automount)(struct path___143 *);
	int (*d_manage)(struct dentry___143 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___34 {
	struct dentry___143 *mnt_root;
	struct super_block___143 *mnt_sb;
	int mnt_flags;
};

struct path___143 {
	struct vfsmount___34 *mnt;
	struct dentry___143 *dentry;
};

struct smp_ops___142 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___142 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___143 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___143 *bd_inode;
	struct super_block___143 *bd_super;
	struct mutex___143 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___143 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___143 bd_fsfreeze_mutex;
};

struct file___143 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___143 f_path;
	struct inode___143 *f_inode;
	const struct file_operations___143 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___143 *f_mapping;
	struct mutex___143 f_pos_lock;
};

struct zone___142;

struct lruvec___142 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___142 *zone;
};

struct pglist_data___142;

struct zone___142 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___142 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___142 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___142 {
	struct zone___142 *zone;
	int zone_idx;
};

struct zonelist___142 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___142 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___142 {
	struct zone___142 node_zones[4];
	struct zonelist___142 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___142 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___143 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___143 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___143 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___143 {
	int qf_fmt_id;
	const struct quota_format_ops___143 *qf_ops;
	struct module___74 *qf_owner;
	struct quota_format_type___143 *qf_next;
};

struct quota_format_ops___143 {
	int (*check_quota_file)(struct super_block___143 *, int);
	int (*read_file_info)(struct super_block___143 *, int);
	int (*write_file_info)(struct super_block___143 *, int);
	int (*free_file_info)(struct super_block___143 *, int);
	int (*read_dqblk)(struct dquot___143 *);
	int (*commit_dqblk)(struct dquot___143 *);
	int (*release_dqblk)(struct dquot___143 *);
};

struct dquot_operations___143 {
	int (*write_dquot)(struct dquot___143 *);
	struct dquot___143 * (*alloc_dquot)(struct super_block___143 *, int);
	void (*destroy_dquot)(struct dquot___143 *);
	int (*acquire_dquot)(struct dquot___143 *);
	int (*release_dquot)(struct dquot___143 *);
	int (*mark_dirty)(struct dquot___143 *);
	int (*write_info)(struct super_block___143 *, int);
	qsize_t * (*get_reserved_space)(struct inode___143 *);
};

struct quotactl_ops___143 {
	int (*quota_on)(struct super_block___143 *, int, int, struct path___143 *);
	int (*quota_on_meta)(struct super_block___143 *, int, int);
	int (*quota_off)(struct super_block___143 *, int);
	int (*quota_sync)(struct super_block___143 *, int);
	int (*get_info)(struct super_block___143 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___143 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___143 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___143 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___143 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___143 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___143 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___143 *, unsigned int);
};

struct address_space_operations___143 {
	int (*writepage)(struct page___142 *, struct writeback_control *);
	int (*readpage)(struct file___143 *, struct page___142 *);
	int (*writepages)(struct address_space___143 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___142 *);
	int (*readpages)(struct file___143 *, struct address_space___143 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___143 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___142 **, void **);
	int (*write_end)(struct file___143 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___142 *, void *);
	sector_t (*bmap)(struct address_space___143 *, sector_t);
	void (*invalidatepage)(struct page___142 *, long unsigned int);
	int (*releasepage)(struct page___142 *, gfp_t);
	void (*freepage)(struct page___142 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___143 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___143 *, struct page___142 *, struct page___142 *, enum migrate_mode);
	int (*launder_page)(struct page___142 *);
	int (*is_partially_uptodate)(struct page___142 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___142 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___143 *, struct page___142 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___143 *, sector_t *);
	void (*swap_deactivate)(struct file___143 *);
	void (*invalidatepage_range)(struct page___142 *, unsigned int, unsigned int);
};

struct nameidata___22;

struct inode_operations___143 {
	struct dentry___143 * (*lookup)(struct inode___143 *, struct dentry___143 *, unsigned int);
	void * (*follow_link)(struct dentry___143 *, struct nameidata___22 *);
	int (*permission)(struct inode___143 *, int);
	struct posix_acl * (*get_acl)(struct inode___143 *, int);
	int (*readlink)(struct dentry___143 *, char *, int);
	void (*put_link)(struct dentry___143 *, struct nameidata___22 *, void *);
	int (*create)(struct inode___143 *, struct dentry___143 *, umode_t, bool);
	int (*link)(struct dentry___143 *, struct inode___143 *, struct dentry___143 *);
	int (*unlink)(struct inode___143 *, struct dentry___143 *);
	int (*symlink)(struct inode___143 *, struct dentry___143 *, const char *);
	int (*mkdir)(struct inode___143 *, struct dentry___143 *, umode_t);
	int (*rmdir)(struct inode___143 *, struct dentry___143 *);
	int (*mknod)(struct inode___143 *, struct dentry___143 *, umode_t, dev_t);
	int (*rename)(struct inode___143 *, struct dentry___143 *, struct inode___143 *, struct dentry___143 *);
	int (*setattr)(struct dentry___143 *, struct iattr___143 *);
	int (*getattr)(struct vfsmount___34 *, struct dentry___143 *, struct kstat *);
	int (*setxattr)(struct dentry___143 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___143 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___143 *, char *, size_t);
	int (*removexattr)(struct dentry___143 *, const char *);
	int (*fiemap)(struct inode___143 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___143 *, struct timespec *, int);
	int (*atomic_open)(struct inode___143 *, struct dentry___143 *, struct file___143 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___143 {
	struct module___74 *owner;
	loff_t (*llseek)(struct file___143 *, loff_t, int);
	ssize_t (*read)(struct file___143 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___143 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___143 *, void *, filldir_t);
	unsigned int (*poll)(struct file___143 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___143 *, struct vm_area_struct___147 *);
	int (*open)(struct inode___143 *, struct file___143 *);
	int (*flush)(struct file___143 *, fl_owner_t);
	int (*release)(struct inode___143 *, struct file___143 *);
	int (*fsync)(struct file___143 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___143 *, int);
	int (*lock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*sendpage)(struct file___143 *, struct page___142 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___143 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___143 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___143 *, long int, struct file_lock___143 **, void **);
		struct {
			int (*setlease)(struct file___143 *, long int, struct file_lock___143 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___143 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___143 *);
};

struct fasync_struct___143;

struct file_lock_operations___143;

struct lock_manager_operations___143;

struct file_lock___143 {
	struct file_lock___143 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___79 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___143 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___143 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___143 *fl_ops;
	const struct lock_manager_operations___143 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___143 {
	void (*fl_copy_lock)(struct file_lock___143 *, struct file_lock___143 *);
	void (*fl_release_private)(struct file_lock___143 *);
};

struct lock_manager_operations___143 {
	int (*lm_compare_owner)(struct file_lock___143 *, struct file_lock___143 *);
	long unsigned int (*lm_owner_key)(struct file_lock___143 *);
	void (*lm_notify)(struct file_lock___143 *);
	int (*lm_grant)(struct file_lock___143 *, struct file_lock___143 *, int);
	void (*lm_break)(struct file_lock___143 *);
	int (*lm_change)(struct file_lock___143 **, int);
};

struct fasync_struct___143 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___143 *fa_next;
	struct file___143 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___143 {
	const char *name;
	int fs_flags;
	struct dentry___143 * (*mount)(struct file_system_type___143 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___143 *);
	struct module___74 *owner;
	struct file_system_type___143 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___143 {
	struct inode___143 * (*alloc_inode)(struct super_block___143 *);
	void (*destroy_inode)(struct inode___143 *);
	void (*dirty_inode)(struct inode___143 *, int);
	int (*write_inode)(struct inode___143 *, struct writeback_control *);
	int (*drop_inode)(struct inode___143 *);
	void (*evict_inode)(struct inode___143 *);
	void (*put_super)(struct super_block___143 *);
	int (*sync_fs)(struct super_block___143 *, int);
	int (*freeze_fs)(struct super_block___143 *);
	int (*unfreeze_fs)(struct super_block___143 *);
	int (*statfs)(struct dentry___143 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___143 *, int *, char *);
	void (*umount_begin)(struct super_block___143 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___143 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___143 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___143 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___143 *);
	ssize_t (*quota_read)(struct super_block___143 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___143 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___143 *);
	int (*bdev_try_to_free_page)(struct super_block___143 *, struct page___142 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___143 *);
	void (*free_cached_objects)(struct super_block___143 *, int);
};

struct vm_area_struct___147 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___147 *vm_next;
	struct vm_area_struct___147 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___147 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___143 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct nameidata___22 {
	struct path___143 path;
	struct qstr last;
	struct path___143 root;
	struct inode___143 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct module_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___73 *, struct module_kobject___73 *, char *);
	ssize_t (*store)(struct module_attribute___73 *, struct module_kobject___73 *, const char *, size_t);
	void (*setup)(struct module___74 *, const char *);
	int (*test)(struct module___74 *);
	void (*free)(struct module___74 *);
};

struct xol_area___142 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___142 *page;
	long unsigned int vaddr;
};

struct core_thread___142 {
	struct task_struct___142 *task;
	struct core_thread___142 *next;
};

struct core_state___142 {
	atomic_t nr_threads;
	struct core_thread___142 dumper;
	struct completion startup;
};

struct signal_struct___142 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___142 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___142 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___79 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___143 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct getdents_callback___2 {
	char *name;
	long unsigned int ino;
	int found;
	int sequence;
};

typedef u16 wchar_t;

typedef u32 unicode_t;

struct nls_table {
	const char *charset;
	const char *alias;
	int (*uni2char)(wchar_t, unsigned char *, int);
	int (*char2uni)(const unsigned char *, int, wchar_t *);
	const unsigned char *charset2lower;
	const unsigned char *charset2upper;
	struct module___74 *owner;
	struct nls_table *next;
};

enum utf16_endian {
	UTF16_HOST_ENDIAN = 0,
	UTF16_LITTLE_ENDIAN = 1,
	UTF16_BIG_ENDIAN = 2,
};

struct utf8_table {
	int cmask;
	int cval;
	int shift;
	long int lmask;
	long int lval;
};

typedef unsigned int autofs_wqt_t;

struct autofs_sb_info;

struct autofs_info {
	struct dentry___112 *dentry;
	struct inode___112 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_wait_queue;

struct autofs_sb_info {
	u32 magic;
	int pipefd;
	struct file___112 *pipe;
	struct pid___64 *oz_pgrp;
	int catatonic;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	long unsigned int exp_timeout;
	unsigned int type;
	int reghost_enabled;
	int needs_reghost;
	struct super_block___112 *sb;
	struct mutex___113 wq_mutex;
	struct mutex___113 pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

struct autofs_wait_queue {
	wait_queue_head_t queue;
	struct autofs_wait_queue *next;
	autofs_wqt_t wait_queue_token;
	struct qstr name;
	u32 dev;
	u64 ino;
	kuid_t uid;
	kgid_t gid;
	pid_t pid;
	pid_t tgid;
	int status;
	unsigned int wait_ctr;
};

enum {
	Opt_err___5 = 0,
	Opt_fd = 1,
	Opt_uid___3 = 2,
	Opt_gid___4 = 3,
	Opt_pgrp = 4,
	Opt_minproto = 5,
	Opt_maxproto = 6,
	Opt_indirect = 7,
	Opt_direct = 8,
	Opt_offset = 9,
};

struct autofs_packet_hdr {
	int proto_version;
	int type;
};

struct autofs_packet_expire {
	struct autofs_packet_hdr hdr;
	int len;
	char name[256];
};

enum autofs_notify {
	NFY_NONE = 0,
	NFY_MOUNT = 1,
	NFY_EXPIRE = 2,
};

struct autofs_sb_info___2;

struct autofs_info___2 {
	struct dentry___137 *dentry;
	struct inode___137 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info___2 *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_sb_info___2 {
	u32 magic;
	int pipefd;
	struct file___137 *pipe;
	struct pid___78 *oz_pgrp;
	int catatonic;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	long unsigned int exp_timeout;
	unsigned int type;
	int reghost_enabled;
	int needs_reghost;
	struct super_block___137 *sb;
	struct mutex___138 wq_mutex;
	struct mutex___138 pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

struct autofs_packet_missing {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	int len;
	char name[256];
};

struct autofs_packet_expire_multi {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	int len;
	char name[256];
};

union autofs_packet_union {
	struct autofs_packet_hdr hdr;
	struct autofs_packet_missing missing;
	struct autofs_packet_expire expire;
	struct autofs_packet_expire_multi expire_multi;
};

struct autofs_v5_packet {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	__u32 dev;
	__u64 ino;
	__u32 uid;
	__u32 gid;
	__u32 pid;
	__u32 tgid;
	__u32 len;
	char name[256];
};

typedef struct autofs_v5_packet autofs_packet_missing_indirect_t;

typedef struct autofs_v5_packet autofs_packet_expire_indirect_t;

typedef struct autofs_v5_packet autofs_packet_missing_direct_t;

typedef struct autofs_v5_packet autofs_packet_expire_direct_t;

union autofs_v5_packet_union {
	struct autofs_packet_hdr hdr;
	struct autofs_v5_packet v5_packet;
	autofs_packet_missing_indirect_t missing_indirect;
	autofs_packet_expire_indirect_t expire_indirect;
	autofs_packet_missing_direct_t missing_direct;
	autofs_packet_expire_direct_t expire_direct;
};

struct miscdevice___5 {
	int minor;
	const char *name;
	const struct file_operations___115 *fops;
	struct list_head list;
	struct device___92 *parent;
	struct device___92 *this_device;
	const char *nodename;
	umode_t mode;
};

struct args_protover {
	__u32 version;
};

struct args_protosubver {
	__u32 sub_version;
};

struct args_openmount {
	__u32 devid;
};

struct args_ready {
	__u32 token;
};

struct args_fail {
	__u32 token;
	__s32 status;
};

struct args_setpipefd {
	__s32 pipefd;
};

struct args_timeout {
	__u64 timeout;
};

struct args_requester {
	__u32 uid;
	__u32 gid;
};

struct args_expire {
	__u32 how;
};

struct args_askumount {
	__u32 may_umount;
};

struct args_in {
	__u32 type;
};

struct args_out {
	__u32 devid;
	__u32 magic;
};

struct args_ismountpoint {
	union {
		struct args_in in;
		struct args_out out;
	};
};

struct autofs_dev_ioctl {
	__u32 ver_major;
	__u32 ver_minor;
	__u32 size;
	__s32 ioctlfd;
	union {
		struct args_protover protover;
		struct args_protosubver protosubver;
		struct args_openmount openmount;
		struct args_ready ready;
		struct args_fail fail;
		struct args_setpipefd setpipefd;
		struct args_timeout timeout;
		struct args_requester requester;
		struct args_expire expire;
		struct args_askumount askumount;
		struct args_ismountpoint ismountpoint;
	};
	char path[0];
};

enum {
	AUTOFS_DEV_IOCTL_VERSION_CMD = 113,
	AUTOFS_DEV_IOCTL_PROTOVER_CMD = 114,
	AUTOFS_DEV_IOCTL_PROTOSUBVER_CMD = 115,
	AUTOFS_DEV_IOCTL_OPENMOUNT_CMD = 116,
	AUTOFS_DEV_IOCTL_CLOSEMOUNT_CMD = 117,
	AUTOFS_DEV_IOCTL_READY_CMD = 118,
	AUTOFS_DEV_IOCTL_FAIL_CMD = 119,
	AUTOFS_DEV_IOCTL_SETPIPEFD_CMD = 120,
	AUTOFS_DEV_IOCTL_CATATONIC_CMD = 121,
	AUTOFS_DEV_IOCTL_TIMEOUT_CMD = 122,
	AUTOFS_DEV_IOCTL_REQUESTER_CMD = 123,
	AUTOFS_DEV_IOCTL_EXPIRE_CMD = 124,
	AUTOFS_DEV_IOCTL_ASKUMOUNT_CMD = 125,
	AUTOFS_DEV_IOCTL_ISMOUNTPOINT_CMD = 126,
};

struct autofs_sb_info___3;

struct autofs_info___3 {
	struct dentry___115 *dentry;
	struct inode___115 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info___3 *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_sb_info___3 {
	u32 magic;
	int pipefd;
	struct file___115 *pipe;
	struct pid___65 *oz_pgrp;
	int catatonic;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	long unsigned int exp_timeout;
	unsigned int type;
	int reghost_enabled;
	int needs_reghost;
	struct super_block___115 *sb;
	struct mutex___116 wq_mutex;
	struct mutex___116 pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

typedef int (*ioctl_fn)(struct file___115 *, struct autofs_sb_info___3 *, struct autofs_dev_ioctl *);

struct tree_descr___2 {
	char *name;
	const struct file_operations___134 *ops;
	int mode;
};

struct debugfs_mount_opts {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum {
	Opt_uid___4 = 0,
	Opt_gid___5 = 1,
	Opt_mode___4 = 2,
	Opt_err___6 = 3,
};

struct debugfs_fs_info {
	struct debugfs_mount_opts mount_opts;
};

struct device___111;

struct dev_pm_ops___111 {
	int (*prepare)(struct device___111 *);
	void (*complete)(struct device___111 *);
	int (*suspend)(struct device___111 *);
	int (*resume)(struct device___111 *);
	int (*freeze)(struct device___111 *);
	int (*thaw)(struct device___111 *);
	int (*poweroff)(struct device___111 *);
	int (*restore)(struct device___111 *);
	int (*suspend_late)(struct device___111 *);
	int (*resume_early)(struct device___111 *);
	int (*freeze_late)(struct device___111 *);
	int (*thaw_early)(struct device___111 *);
	int (*poweroff_late)(struct device___111 *);
	int (*restore_early)(struct device___111 *);
	int (*suspend_noirq)(struct device___111 *);
	int (*resume_noirq)(struct device___111 *);
	int (*freeze_noirq)(struct device___111 *);
	int (*thaw_noirq)(struct device___111 *);
	int (*poweroff_noirq)(struct device___111 *);
	int (*restore_noirq)(struct device___111 *);
	int (*runtime_suspend)(struct device___111 *);
	int (*runtime_resume)(struct device___111 *);
	int (*runtime_idle)(struct device___111 *);
};

struct device_type___111;

struct bus_type___111;

struct device_driver___111;

struct dev_pm_domain___111;

struct class___111;

struct device_rh___111;

struct device___111 {
	struct device___111 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___111 *type;
	struct mutex___138 mutex;
	struct bus_type___111 *bus;
	struct device_driver___111 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___111 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___37 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___14 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___111 *class;
	const struct attribute_group___102 **groups;
	void (*release)(struct device___111 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___111 *device_rh;
};

struct dev_pm_info_rh___111 {
	void (*set_latency_tolerance)(struct device___111 *, s32);
};

struct dev_pm_domain___111 {
	struct dev_pm_ops___111 ops;
};

struct debugfs_reg32 {
	char *name;
	long unsigned int offset;
};

struct debugfs_regset32 {
	const struct debugfs_reg32 *regs;
	int nregs;
	void *base;
};

struct bus_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___111 *, char *);
	ssize_t (*store)(struct bus_type___111 *, const char *, size_t);
};

struct device_attribute___111;

struct driver_attribute___111;

struct bus_type___111 {
	const char *name;
	const char *dev_name;
	struct device___111 *dev_root;
	struct bus_attribute___111 *bus_attrs;
	struct device_attribute___111 *dev_attrs;
	struct driver_attribute___111 *drv_attrs;
	const struct attribute_group___102 **bus_groups;
	const struct attribute_group___102 **dev_groups;
	const struct attribute_group___102 **drv_groups;
	int (*match)(struct device___111 *, struct device_driver___111 *);
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	int (*probe)(struct device___111 *);
	int (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*online)(struct device___111 *);
	int (*offline)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct device___111 *, struct device_attribute___111 *, char *);
	ssize_t (*store)(struct device___111 *, struct device_attribute___111 *, const char *, size_t);
};

struct driver_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___111 *, char *);
	ssize_t (*store)(struct device_driver___111 *, const char *, size_t);
};

struct device_driver___111 {
	const char *name;
	struct bus_type___111 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___111 *);
	int (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	const struct attribute_group___102 **groups;
	const struct dev_pm_ops___111 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___111 {
	const char *name;
	const struct attribute_group___102 **groups;
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
};

struct class_attribute___111;

struct class___111 {
	const char *name;
	struct module *owner;
	struct class_attribute___111 *class_attrs;
	struct device_attribute___111 *dev_attrs;
	const struct attribute_group___102 **dev_groups;
	struct bin_attribute___102 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *);
	void (*class_release)(struct class___111 *);
	void (*dev_release)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
	struct subsys_private *p;
};

struct class_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct class___111 *, struct class_attribute___111 *, char *);
	ssize_t (*store)(struct class___111 *, struct class_attribute___111 *, const char *, size_t);
	const void * (*namespace)(struct class___111 *, const struct class_attribute___111 *);
};

struct device_rh___111 {
	struct dev_pm_info_rh___111 power;
};

struct array_data {
	void *array;
	u32 elements;
};

struct debugfs_devm_entry {
	int (*read)(struct seq_file___104 *, void *);
	struct device___111 *dev;
};

enum pstore_type_id {
	PSTORE_TYPE_DMESG = 0,
	PSTORE_TYPE_MCE = 1,
	PSTORE_TYPE_CONSOLE = 2,
	PSTORE_TYPE_FTRACE = 3,
	PSTORE_TYPE_PPC_RTAS = 4,
	PSTORE_TYPE_PPC_OF = 5,
	PSTORE_TYPE_PPC_COMMON = 6,
	PSTORE_TYPE_PPC_OPAL = 7,
	PSTORE_TYPE_UNKNOWN = 255,
};

struct pstore_info {
	struct module___70 *owner;
	char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex___140 read_mutex;
	int (*open)(struct pstore_info *);
	int (*close)(struct pstore_info *);
	ssize_t (*read)(u64 *, enum pstore_type_id *, int *, struct timespec *, char **, bool *, struct pstore_info *);
	int (*write)(enum pstore_type_id, enum kmsg_dump_reason, u64 *, unsigned int, int, bool, size_t, struct pstore_info *);
	int (*write_buf)(enum pstore_type_id, enum kmsg_dump_reason, u64 *, unsigned int, const char *, bool, size_t, struct pstore_info *);
	int (*erase)(enum pstore_type_id, u64, int, struct timespec, struct pstore_info *);
	void *data;
};

struct pstore_ftrace_record {
	long unsigned int ip;
	long unsigned int parent_ip;
	unsigned int cpu;
};

struct pstore_private {
	struct list_head list;
	struct pstore_info *psi;
	enum pstore_type_id type;
	u64 id;
	int count;
	ssize_t size;
	char data[0];
};

struct pstore_ftrace_seq_data {
	const void *ptr;
	size_t off;
	size_t size;
};

enum {
	Opt_kmsg_bytes = 0,
	Opt_err___7 = 1,
};

struct efi_variable {
	efi_char16_t VariableName[512];
	efi_guid_t VendorGuid;
	long unsigned int DataSize;
	__u8 Data[1024];
	efi_status_t Status;
	__u32 Attributes;
} __attribute__((packed));

struct efivar_entry {
	struct efi_variable var;
	struct list_head list;
	struct kobject kobj;
	bool scanning;
	bool deleting;
};

typedef u16 ucs2_char_t;

typedef int __kernel_ipc_pid_t;

struct ipc_perm {
	__kernel_key_t key;
	__kernel_uid_t uid;
	__kernel_gid_t gid;
	__kernel_uid_t cuid;
	__kernel_gid_t cgid;
	__kernel_mode_t mode;
	short unsigned int seq;
};

struct ipc64_perm {
	__kernel_key_t key;
	__kernel_uid32_t uid;
	__kernel_gid32_t gid;
	__kernel_uid32_t cuid;
	__kernel_gid32_t cgid;
	__kernel_mode_t mode;
	unsigned char __pad1[0];
	short unsigned int seq;
	short unsigned int __pad2;
	long unsigned int __unused1;
	long unsigned int __unused2;
};

struct semid64_ds {
	struct ipc64_perm sem_perm;
	__kernel_time_t sem_otime;
	long unsigned int __unused1;
	__kernel_time_t sem_ctime;
	long unsigned int __unused2;
	long unsigned int sem_nsems;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct sembuf {
	short unsigned int sem_num;
	short int sem_op;
	short int sem_flg;
};

typedef u32 __compat_uid32_t;

typedef u32 __compat_gid32_t;

typedef u16 compat_ipc_pid_t;

typedef s32 compat_key_t;

struct compat_ipc64_perm {
	compat_key_t key;
	__compat_uid32_t uid;
	__compat_gid32_t gid;
	__compat_uid32_t cuid;
	__compat_gid32_t cgid;
	short unsigned int mode;
	short unsigned int __pad1;
	short unsigned int seq;
	short unsigned int __pad2;
	compat_ulong_t unused1;
	compat_ulong_t unused2;
};

struct compat_semid64_ds {
	struct compat_ipc64_perm sem_perm;
	compat_time_t sem_otime;
	compat_ulong_t __unused1;
	compat_time_t sem_ctime;
	compat_ulong_t __unused2;
	compat_ulong_t sem_nsems;
	compat_ulong_t __unused3;
	compat_ulong_t __unused4;
};

struct compat_msqid64_ds {
	struct compat_ipc64_perm msg_perm;
	compat_time_t msg_stime;
	compat_ulong_t __unused1;
	compat_time_t msg_rtime;
	compat_ulong_t __unused2;
	compat_time_t msg_ctime;
	compat_ulong_t __unused3;
	compat_ulong_t msg_cbytes;
	compat_ulong_t msg_qnum;
	compat_ulong_t msg_qbytes;
	compat_pid_t msg_lspid;
	compat_pid_t msg_lrpid;
	compat_ulong_t __unused4;
	compat_ulong_t __unused5;
};

struct compat_shmid64_ds {
	struct compat_ipc64_perm shm_perm;
	compat_size_t shm_segsz;
	compat_time_t shm_atime;
	compat_ulong_t __unused1;
	compat_time_t shm_dtime;
	compat_ulong_t __unused2;
	compat_time_t shm_ctime;
	compat_ulong_t __unused3;
	compat_pid_t shm_cpid;
	compat_pid_t shm_lpid;
	compat_ulong_t shm_nattch;
	compat_ulong_t __unused4;
	compat_ulong_t __unused5;
};

struct msg;

struct msqid_ds {
	struct ipc_perm msg_perm;
	struct msg *msg_first;
	struct msg *msg_last;
	__kernel_time_t msg_stime;
	__kernel_time_t msg_rtime;
	__kernel_time_t msg_ctime;
	long unsigned int msg_lcbytes;
	long unsigned int msg_lqbytes;
	short unsigned int msg_cbytes;
	short unsigned int msg_qnum;
	short unsigned int msg_qbytes;
	__kernel_ipc_pid_t msg_lspid;
	__kernel_ipc_pid_t msg_lrpid;
};

struct msqid64_ds {
	struct ipc64_perm msg_perm;
	__kernel_time_t msg_stime;
	__kernel_time_t msg_rtime;
	__kernel_time_t msg_ctime;
	long unsigned int msg_cbytes;
	long unsigned int msg_qnum;
	long unsigned int msg_qbytes;
	__kernel_pid_t msg_lspid;
	__kernel_pid_t msg_lrpid;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct msg_msgseg;

struct msg_msg {
	struct list_head m_list;
	long int m_type;
	size_t m_ts;
	struct msg_msgseg *next;
	void *security;
};

struct shmid_ds {
	struct ipc_perm shm_perm;
	int shm_segsz;
	__kernel_time_t shm_atime;
	__kernel_time_t shm_dtime;
	__kernel_time_t shm_ctime;
	__kernel_ipc_pid_t shm_cpid;
	__kernel_ipc_pid_t shm_lpid;
	short unsigned int shm_nattch;
	short unsigned int shm_unused;
	void *shm_unused2;
	void *shm_unused3;
};

struct shmid64_ds {
	struct ipc64_perm shm_perm;
	size_t shm_segsz;
	__kernel_time_t shm_atime;
	__kernel_time_t shm_dtime;
	__kernel_time_t shm_ctime;
	__kernel_pid_t shm_cpid;
	__kernel_pid_t shm_lpid;
	long unsigned int shm_nattch;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct shminfo64 {
	long unsigned int shmmax;
	long unsigned int shmmin;
	long unsigned int shmmni;
	long unsigned int shmseg;
	long unsigned int shmall;
	long unsigned int __unused1;
	long unsigned int __unused2;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct shminfo {
	int shmmax;
	int shmmin;
	int shmmni;
	int shmseg;
	int shmall;
};

struct shm_info {
	int used_ids;
	long unsigned int shm_tot;
	long unsigned int shm_rss;
	long unsigned int shm_swp;
	long unsigned int swap_attempts;
	long unsigned int swap_successes;
};

struct compat_msgbuf {
	compat_long_t mtype;
	char mtext[1];
};

struct compat_ipc_perm {
	key_t key;
	__compat_uid_t uid;
	__compat_gid_t gid;
	__compat_uid_t cuid;
	__compat_gid_t cgid;
	compat_mode_t mode;
	short unsigned int seq;
};

struct compat_semid_ds {
	struct compat_ipc_perm sem_perm;
	compat_time_t sem_otime;
	compat_time_t sem_ctime;
	compat_uptr_t sem_base;
	compat_uptr_t sem_pending;
	compat_uptr_t sem_pending_last;
	compat_uptr_t undo;
	short unsigned int sem_nsems;
};

struct compat_msqid_ds {
	struct compat_ipc_perm msg_perm;
	compat_uptr_t msg_first;
	compat_uptr_t msg_last;
	compat_time_t msg_stime;
	compat_time_t msg_rtime;
	compat_time_t msg_ctime;
	compat_ulong_t msg_lcbytes;
	compat_ulong_t msg_lqbytes;
	short unsigned int msg_cbytes;
	short unsigned int msg_qnum;
	short unsigned int msg_qbytes;
	compat_ipc_pid_t msg_lspid;
	compat_ipc_pid_t msg_lrpid;
};

struct compat_shmid_ds {
	struct compat_ipc_perm shm_perm;
	int shm_segsz;
	compat_time_t shm_atime;
	compat_time_t shm_dtime;
	compat_time_t shm_ctime;
	compat_ipc_pid_t shm_cpid;
	compat_ipc_pid_t shm_lpid;
	short unsigned int shm_nattch;
	short unsigned int shm_unused;
	compat_uptr_t shm_unused2;
	compat_uptr_t shm_unused3;
};

struct compat_ipc_kludge {
	compat_uptr_t msgp;
	compat_long_t msgtyp;
};

struct compat_shminfo64 {
	compat_ulong_t shmmax;
	compat_ulong_t shmmin;
	compat_ulong_t shmmni;
	compat_ulong_t shmseg;
	compat_ulong_t shmall;
	compat_ulong_t __unused1;
	compat_ulong_t __unused2;
	compat_ulong_t __unused3;
	compat_ulong_t __unused4;
};

struct compat_shm_info {
	compat_int_t used_ids;
	compat_ulong_t shm_tot;
	compat_ulong_t shm_rss;
	compat_ulong_t shm_swp;
	compat_ulong_t swap_attempts;
	compat_ulong_t swap_successes;
};

struct ipc_rcu {
	struct callback_head rcu;
	atomic_t refcount;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ipc_params {
	key_t key;
	int flg;
	union {
		size_t size;
		int nsems;
	} u;
};

struct ipc_ops {
	int (*getnew)(struct ipc_namespace *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct ipc_proc_iface {
	const char *path;
	const char *header;
	int ids;
	int (*show)(struct seq_file___98 *, void *);
};

struct ipc_proc_iter {
	struct ipc_namespace *ns;
	struct ipc_proc_iface *iface;
};

struct msg_msgseg {
	struct msg_msgseg *next;
};

struct msgbuf {
	long int mtype;
	char mtext[1];
};

struct msginfo {
	int msgpool;
	int msgmap;
	int msgmax;
	int msgmnb;
	int msgmni;
	int msgssz;
	int msgtql;
	short unsigned int msgseg;
};

struct msg_queue {
	struct kern_ipc_perm q_perm;
	time_t q_stime;
	time_t q_rtime;
	time_t q_ctime;
	long unsigned int q_cbytes;
	long unsigned int q_qnum;
	long unsigned int q_qbytes;
	pid_t q_lspid;
	pid_t q_lrpid;
	struct list_head q_messages;
	struct list_head q_receivers;
	struct list_head q_senders;
};

struct msg_receiver {
	struct list_head r_list;
	struct task_struct___131 *r_tsk;
	int r_mode;
	long int r_msgtype;
	long int r_maxsize;
	struct msg_msg * volatile r_msg;
};

struct msg_sender {
	struct list_head list;
	struct task_struct___131 *tsk;
};

typedef short unsigned int ushort;

struct sem;

struct sem_array {
	struct kern_ipc_perm sem_perm;
	time_t sem_ctime;
	struct sem *sem_base;
	struct list_head pending_alter;
	struct list_head pending_const;
	struct list_head list_id;
	int sem_nsems;
	int complex_count;
};

struct sem_queue;

struct sem_undo;

struct semid_ds {
	struct ipc_perm sem_perm;
	__kernel_time_t sem_otime;
	__kernel_time_t sem_ctime;
	struct sem *sem_base;
	struct sem_queue *sem_pending;
	struct sem_queue **sem_pending_last;
	struct sem_undo *undo;
	short unsigned int sem_nsems;
};

struct sem {
	int semval;
	int sempid;
	spinlock_t lock;
	struct list_head pending_alter;
	struct list_head pending_const;
	time_t sem_otime;
	long: 64;
};

struct sem_queue {
	struct list_head list;
	struct task_struct___128 *sleeper;
	struct sem_undo *undo;
	int pid;
	int status;
	struct sembuf *sops;
	int nsops;
	int alter;
};

struct sem_undo {
	struct list_head list_proc;
	struct callback_head rcu;
	struct sem_undo_list *ulp;
	struct list_head list_id;
	int semid;
	short int *semadj;
};

struct seminfo {
	int semmap;
	int semmni;
	int semmns;
	int semmnu;
	int semmsl;
	int semopm;
	int semume;
	int semusz;
	int semvmx;
	int semaem;
};

struct sem_undo_list {
	atomic_t refcnt;
	spinlock_t lock;
	struct list_head list_proc;
};

struct page___143;

typedef struct page___143 *pgtable_t___143;

struct address_space___144;

struct kmem_cache___130;

struct page___143 {
	long unsigned int flags;
	struct address_space___144 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___143 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___143 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___130 *slab_cache;
		struct page___143 *first_page;
	};
	long: 64;
};

struct thread_struct___71;

struct task_struct___143;

struct pv_cpu_ops___143 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___71 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___71 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___143 *);
	void (*end_context_switch)(struct task_struct___143 *);
};

struct perf_event___71;

struct thread_struct___71 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___71 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___80;

struct pid_link___80 {
	struct hlist_node node;
	struct pid___80 *pid;
};

struct mutex___144 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___143 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___139 {
	struct page___143 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___148;

struct nsproxy___85;

struct signal_struct___143;

struct css_set___93;

struct perf_event_context___71;

struct task_struct___143 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___143 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___148 *mm;
	struct mm_struct___148 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___143 *real_parent;
	struct task_struct___143 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___143 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___80 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___143 = 0,
		VTIME_USER___143 = 1,
		VTIME_SYS___143 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___71 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___85 *nsproxy;
	struct signal_struct___143 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___93 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___71 *perf_event_ctxp[2];
	struct mutex___144 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___139 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___148 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___148 *, struct mm_struct___148 *);
	void (*dup_mmap)(struct mm_struct___148 *, struct mm_struct___148 *);
	void (*exit_mmap)(struct mm_struct___148 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___148 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___148 *);
	void (*pgd_free)(struct mm_struct___148 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___148 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___148 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___148 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___148 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___148 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___148 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___148 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___148 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___148 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___148 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___148 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___144 lock;
	void *vdso;
} mm_context_t___144;

struct xol_area___143;

struct uprobes_state___143 {
	struct xol_area___143 *xol_area;
};

struct vm_area_struct___148;

struct file___144;

struct core_state___143;

struct mm_struct___148 {
	struct vm_area_struct___148 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___148 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___148 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___144 context;
	long unsigned int flags;
	struct core_state___143 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___143 *owner;
	struct file___144 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___143 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___71 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___143 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___143 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___143 *target;
};

typedef void (*perf_overflow_handler_t___71)(struct perf_event___71 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___71;

typedef void (*ftrace_func_t___71)(long unsigned int, long unsigned int, struct ftrace_ops___71 *, struct pt_regs *);

struct ftrace_ops___71 {
	ftrace_func_t___71 func;
	struct ftrace_ops___71 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___144 regex_lock;
};

struct pmu___71;

struct fasync_struct___144;

struct pid_namespace___80;

struct ftrace_event_call___61;

struct perf_cgroup___71;

struct perf_event___71 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___71 *group_leader;
	struct pmu___71 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___71 hw;
	struct perf_event_context___71 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___144 child_mutex;
	struct list_head child_list;
	struct perf_event___71 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___143 *owner;
	struct mutex___144 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___144 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___71 *);
	struct callback_head callback_head;
	struct pid_namespace___80 *ns;
	u64 id;
	perf_overflow_handler_t___71 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___61 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___71 ftrace_ops;
	struct perf_cgroup___71 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___143;

struct lruvec___143 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___143 *zone;
};

struct pglist_data___143;

struct zone___143 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___143 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___143 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___143 {
	struct zone___143 *zone;
	int zone_idx;
};

struct zonelist___143 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___143 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___143 {
	struct zone___143 node_zones[4];
	struct zonelist___143 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___143 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___101;

struct x86_io_apic_ops___101 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___101 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___101;

struct irq_data___101 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___101 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___112;

struct dev_pm_ops___112 {
	int (*prepare)(struct device___112 *);
	void (*complete)(struct device___112 *);
	int (*suspend)(struct device___112 *);
	int (*resume)(struct device___112 *);
	int (*freeze)(struct device___112 *);
	int (*thaw)(struct device___112 *);
	int (*poweroff)(struct device___112 *);
	int (*restore)(struct device___112 *);
	int (*suspend_late)(struct device___112 *);
	int (*resume_early)(struct device___112 *);
	int (*freeze_late)(struct device___112 *);
	int (*thaw_early)(struct device___112 *);
	int (*poweroff_late)(struct device___112 *);
	int (*restore_early)(struct device___112 *);
	int (*suspend_noirq)(struct device___112 *);
	int (*resume_noirq)(struct device___112 *);
	int (*freeze_noirq)(struct device___112 *);
	int (*thaw_noirq)(struct device___112 *);
	int (*poweroff_noirq)(struct device___112 *);
	int (*restore_noirq)(struct device___112 *);
	int (*runtime_suspend)(struct device___112 *);
	int (*runtime_resume)(struct device___112 *);
	int (*runtime_idle)(struct device___112 *);
};

struct device_type___112;

struct bus_type___112;

struct device_driver___112;

struct dev_pm_domain___112;

struct class___112;

struct attribute_group___105;

struct device_rh___112;

struct device___112 {
	struct device___112 *parent;
	struct device_private *p;
	struct kobject___10 kobj;
	const char *init_name;
	const struct device_type___112 *type;
	struct mutex___144 mutex;
	struct bus_type___112 *bus;
	struct device_driver___112 *driver;
	void *platform_data;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___112 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___37 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___112 *class;
	const struct attribute_group___105 **groups;
	void (*release)(struct device___112 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___112 *device_rh;
};

struct dev_pm_info_rh___112 {
	void (*set_latency_tolerance)(struct device___112 *, s32);
};

struct dev_pm_domain___112 {
	struct dev_pm_ops___112 ops;
};

struct smp_ops___143 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___143 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___107;

struct attribute_group___105 {
	const char *name;
	umode_t (*is_visible)(struct kobject___10 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___107 **bin_attrs;
};

struct bin_attribute___107 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___144 *, struct kobject___10 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___144 *, struct kobject___10 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	int (*mmap)(struct file___144 *, struct kobject___10 *, struct bin_attribute___107 *, struct vm_area_struct___148 *);
};

struct vfsmount___35;

struct dentry___144;

struct path___144 {
	struct vfsmount___35 *mnt;
	struct dentry___144 *dentry;
};

struct fown_struct___80 {
	rwlock_t lock;
	struct pid___80 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___144;

struct file_operations___144;

struct file___144 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___144 f_path;
	struct inode___144 *f_inode;
	const struct file_operations___144 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___80 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___144 *f_mapping;
	struct mutex___144 f_pos_lock;
};

struct vm_operations_struct___126;

struct vm_area_struct___148 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___148 *vm_next;
	struct vm_area_struct___148 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___148 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___126 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___144 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___129 {
	void **freelist;
	long unsigned int tid;
	struct page___143 *page;
	struct page___143 *partial;
};

struct memcg_cache_params___130;

struct kmem_cache___130 {
	struct kmem_cache_cpu___129 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___10 kobj;
	struct memcg_cache_params___130 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___130 {
	bool is_root_cache;
	union {
		struct kmem_cache___130 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___130 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___143 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___143 *page;
	long unsigned int vaddr;
};

struct address_space_operations___144;

struct address_space___144 {
	struct inode___144 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___144 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___144 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___123;

struct vm_operations_struct___126 {
	void (*open)(struct vm_area_struct___148 *);
	void (*close)(struct vm_area_struct___148 *);
	int (*fault)(struct vm_area_struct___148 *, struct vm_fault___123 *);
	int (*page_mkwrite)(struct vm_area_struct___148 *, struct vm_fault___123 *);
	int (*access)(struct vm_area_struct___148 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___148 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___148 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___148 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___148 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___143 {
	struct task_struct___143 *task;
	struct core_thread___143 *next;
};

struct core_state___143 {
	atomic_t nr_threads;
	struct core_thread___143 dumper;
	struct completion startup;
};

struct vm_fault___123 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___143 *page;
};

struct dentry_operations___144;

struct super_block___144;

struct dentry___144 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___144 *d_parent;
	struct qstr d_name;
	struct inode___144 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___144 *d_op;
	struct super_block___144 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___144;

struct file_lock___144;

struct dquot___144;

struct block_device___144;

struct inode___144 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___144 *i_op;
	struct super_block___144 *i_sb;
	struct address_space___144 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___144 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___144 *i_fop;
	struct file_lock___144 *i_flock;
	struct address_space___144 i_data;
	struct dquot___144 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___144 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___144 {
	int (*d_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_hash)(const struct dentry___144 *, struct qstr *);
	int (*d_compare)(const struct dentry___144 *, const struct dentry___144 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___144 *);
	void (*d_release)(struct dentry___144 *);
	void (*d_prune)(struct dentry___144 *);
	void (*d_iput)(struct dentry___144 *, struct inode___144 *);
	char * (*d_dname)(struct dentry___144 *, char *, int);
	struct vfsmount___35 * (*d_automount)(struct path___144 *);
	int (*d_manage)(struct dentry___144 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___144;

struct mem_dqinfo___144 {
	struct quota_format_type___144 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___144;

struct quota_info___144 {
	unsigned int flags;
	struct mutex___144 dqio_mutex;
	struct mutex___144 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___144 *files[2];
	struct mem_dqinfo___144 info[2];
	const struct quota_format_ops___144 *ops[2];
};

struct file_system_type___144;

struct super_operations___144;

struct dquot_operations___144;

struct quotactl_ops___144;

struct xattr_handler___93;

struct super_block___144 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___144 *s_type;
	const struct super_operations___144 *s_op;
	const struct dquot_operations___144 *dq_op;
	const struct quotactl_ops___144 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___144 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___93 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___144 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___144 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___144 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___144 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___35 {
	struct dentry___144 *mnt_root;
	struct super_block___144 *mnt_sb;
	int mnt_flags;
};

struct upid___80 {
	int nr;
	struct pid_namespace___80 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___80 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___143 *child_reaper;
	struct kmem_cache___130 *pid_cachep;
	unsigned int level;
	struct pid_namespace___80 *parent;
	struct vfsmount___35 *proc_mnt;
	struct dentry___144 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___80 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___80 numbers[1];
};

struct block_device___144 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___144 *bd_inode;
	struct super_block___144 *bd_super;
	struct mutex___144 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___144 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___144 bd_fsfreeze_mutex;
};

struct cgroup___93;

struct cgroup_subsys_state___93 {
	struct cgroup___93 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___144 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___144 *ia_file;
};

struct dquot___144 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___144 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___144 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___144 {
	int qf_fmt_id;
	const struct quota_format_ops___144 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___144 *qf_next;
};

struct quota_format_ops___144 {
	int (*check_quota_file)(struct super_block___144 *, int);
	int (*read_file_info)(struct super_block___144 *, int);
	int (*write_file_info)(struct super_block___144 *, int);
	int (*free_file_info)(struct super_block___144 *, int);
	int (*read_dqblk)(struct dquot___144 *);
	int (*commit_dqblk)(struct dquot___144 *);
	int (*release_dqblk)(struct dquot___144 *);
};

struct dquot_operations___144 {
	int (*write_dquot)(struct dquot___144 *);
	struct dquot___144 * (*alloc_dquot)(struct super_block___144 *, int);
	void (*destroy_dquot)(struct dquot___144 *);
	int (*acquire_dquot)(struct dquot___144 *);
	int (*release_dquot)(struct dquot___144 *);
	int (*mark_dirty)(struct dquot___144 *);
	int (*write_info)(struct super_block___144 *, int);
	qsize_t * (*get_reserved_space)(struct inode___144 *);
};

struct quotactl_ops___144 {
	int (*quota_on)(struct super_block___144 *, int, int, struct path___144 *);
	int (*quota_on_meta)(struct super_block___144 *, int, int);
	int (*quota_off)(struct super_block___144 *, int);
	int (*quota_sync)(struct super_block___144 *, int);
	int (*get_info)(struct super_block___144 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___144 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___144 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___144 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___144 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___144 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___144 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___144 *, unsigned int);
};

struct swap_info_struct___34;

struct address_space_operations___144 {
	int (*writepage)(struct page___143 *, struct writeback_control *);
	int (*readpage)(struct file___144 *, struct page___143 *);
	int (*writepages)(struct address_space___144 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___143 *);
	int (*readpages)(struct file___144 *, struct address_space___144 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___144 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___143 **, void **);
	int (*write_end)(struct file___144 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___143 *, void *);
	sector_t (*bmap)(struct address_space___144 *, sector_t);
	void (*invalidatepage)(struct page___143 *, long unsigned int);
	int (*releasepage)(struct page___143 *, gfp_t);
	void (*freepage)(struct page___143 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___144 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___144 *, struct page___143 *, struct page___143 *, enum migrate_mode);
	int (*launder_page)(struct page___143 *);
	int (*is_partially_uptodate)(struct page___143 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___143 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___144 *, struct page___143 *);
	int (*swap_activate)(struct swap_info_struct___34 *, struct file___144 *, sector_t *);
	void (*swap_deactivate)(struct file___144 *);
	void (*invalidatepage_range)(struct page___143 *, unsigned int, unsigned int);
};

struct swap_info_struct___34 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___144 *bdev;
	struct file___144 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___144 {
	struct dentry___144 * (*lookup)(struct inode___144 *, struct dentry___144 *, unsigned int);
	void * (*follow_link)(struct dentry___144 *, struct nameidata *);
	int (*permission)(struct inode___144 *, int);
	struct posix_acl * (*get_acl)(struct inode___144 *, int);
	int (*readlink)(struct dentry___144 *, char *, int);
	void (*put_link)(struct dentry___144 *, struct nameidata *, void *);
	int (*create)(struct inode___144 *, struct dentry___144 *, umode_t, bool);
	int (*link)(struct dentry___144 *, struct inode___144 *, struct dentry___144 *);
	int (*unlink)(struct inode___144 *, struct dentry___144 *);
	int (*symlink)(struct inode___144 *, struct dentry___144 *, const char *);
	int (*mkdir)(struct inode___144 *, struct dentry___144 *, umode_t);
	int (*rmdir)(struct inode___144 *, struct dentry___144 *);
	int (*mknod)(struct inode___144 *, struct dentry___144 *, umode_t, dev_t);
	int (*rename)(struct inode___144 *, struct dentry___144 *, struct inode___144 *, struct dentry___144 *);
	int (*setattr)(struct dentry___144 *, struct iattr___144 *);
	int (*getattr)(struct vfsmount___35 *, struct dentry___144 *, struct kstat *);
	int (*setxattr)(struct dentry___144 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___144 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___144 *, char *, size_t);
	int (*removexattr)(struct dentry___144 *, const char *);
	int (*fiemap)(struct inode___144 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___144 *, struct timespec *, int);
	int (*atomic_open)(struct inode___144 *, struct dentry___144 *, struct file___144 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___88;

struct seq_file___106;

struct file_operations___144 {
	struct module *owner;
	loff_t (*llseek)(struct file___144 *, loff_t, int);
	ssize_t (*read)(struct file___144 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___144 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___144 *, void *, filldir_t);
	unsigned int (*poll)(struct file___144 *, struct poll_table_struct___88 *);
	long int (*unlocked_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___144 *, struct vm_area_struct___148 *);
	int (*open)(struct inode___144 *, struct file___144 *);
	int (*flush)(struct file___144 *, fl_owner_t);
	int (*release)(struct inode___144 *, struct file___144 *);
	int (*fsync)(struct file___144 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___144 *, int);
	int (*lock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*sendpage)(struct file___144 *, struct page___143 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___144 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___144 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___144 *, long int, struct file_lock___144 **, void **);
		struct {
			int (*setlease)(struct file___144 *, long int, struct file_lock___144 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___144 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___106 *, struct file___144 *);
};

struct file_lock_operations___144;

struct lock_manager_operations___144;

struct file_lock___144 {
	struct file_lock___144 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___80 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___144 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___144 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___144 *fl_ops;
	const struct lock_manager_operations___144 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___144 {
	void (*fl_copy_lock)(struct file_lock___144 *, struct file_lock___144 *);
	void (*fl_release_private)(struct file_lock___144 *);
};

struct lock_manager_operations___144 {
	int (*lm_compare_owner)(struct file_lock___144 *, struct file_lock___144 *);
	long unsigned int (*lm_owner_key)(struct file_lock___144 *);
	void (*lm_notify)(struct file_lock___144 *);
	int (*lm_grant)(struct file_lock___144 *, struct file_lock___144 *, int);
	void (*lm_break)(struct file_lock___144 *);
	int (*lm_change)(struct file_lock___144 **, int);
};

struct fasync_struct___144 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___144 *fa_next;
	struct file___144 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___144 {
	const char *name;
	int fs_flags;
	struct dentry___144 * (*mount)(struct file_system_type___144 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___144 *);
	struct module *owner;
	struct file_system_type___144 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___144 {
	struct inode___144 * (*alloc_inode)(struct super_block___144 *);
	void (*destroy_inode)(struct inode___144 *);
	void (*dirty_inode)(struct inode___144 *, int);
	int (*write_inode)(struct inode___144 *, struct writeback_control *);
	int (*drop_inode)(struct inode___144 *);
	void (*evict_inode)(struct inode___144 *);
	void (*put_super)(struct super_block___144 *);
	int (*sync_fs)(struct super_block___144 *, int);
	int (*freeze_fs)(struct super_block___144 *);
	int (*unfreeze_fs)(struct super_block___144 *);
	int (*statfs)(struct dentry___144 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___144 *, int *, char *);
	void (*umount_begin)(struct super_block___144 *);
	int (*show_options)(struct seq_file___106 *, struct dentry___144 *);
	int (*show_devname)(struct seq_file___106 *, struct dentry___144 *);
	int (*show_path)(struct seq_file___106 *, struct dentry___144 *);
	int (*show_stats)(struct seq_file___106 *, struct dentry___144 *);
	ssize_t (*quota_read)(struct super_block___144 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___144 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___144 *);
	int (*bdev_try_to_free_page)(struct super_block___144 *, struct page___143 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___144 *);
	void (*free_cached_objects)(struct super_block___144 *, int);
};

struct xattr_handler___93 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___144 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___144 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___144 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___90)(struct file___144 *, wait_queue_head_t *, struct poll_table_struct___88 *);

struct poll_table_struct___88 {
	poll_queue_proc___90 _qproc;
	long unsigned int _key;
};

struct seq_operations___105;

struct seq_file___106 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___144 lock;
	const struct seq_operations___105 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ipc_namespace___3;

struct nsproxy___85 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace___3 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___80 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___143 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___143 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___143 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___80 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___80 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___144 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___93 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___93 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___71 {
	struct pmu___71 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___144 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___143 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___71 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct cgroupfs_root___93;

struct cgroup___93 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___93 *parent;
	struct dentry___144 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___93 *subsys[11];
	struct cgroupfs_root___93 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___144 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___93 {
	struct super_block___144 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___93 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___45 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___144 *, struct file___144 *);
	ssize_t (*read)(struct cgroup___93 *, struct cftype___45 *, struct file___144 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___93 *, struct cftype___45 *);
	s64 (*read_s64)(struct cgroup___93 *, struct cftype___45 *);
	int (*read_map)(struct cgroup___93 *, struct cftype___45 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___93 *, struct cftype___45 *, struct seq_file___106 *);
	ssize_t (*write)(struct cgroup___93 *, struct cftype___45 *, struct file___144 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___93 *, struct cftype___45 *, u64);
	int (*write_s64)(struct cgroup___93 *, struct cftype___45 *, s64);
	int (*write_string)(struct cgroup___93 *, struct cftype___45 *, const char *);
	int (*trigger)(struct cgroup___93 *, unsigned int);
	int (*release)(struct inode___144 *, struct file___144 *);
	int (*register_event)(struct cgroup___93 *, struct cftype___45 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___93 *, struct cftype___45 *, struct eventfd_ctx *);
};

struct cftype_set___43 {
	struct list_head node;
	struct cftype___45 *cfts;
};

struct task_and_cgroup___43 {
	struct task_struct___143 *task;
	struct cgroup___93 *cgrp;
	struct css_set___93 *cg;
};

struct cgroup_taskset___43 {
	struct task_and_cgroup___43 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___93 *cur_cgrp;
};

struct cgroup_subsys___43 {
	struct cgroup_subsys_state___93 * (*css_alloc)(struct cgroup___93 *);
	int (*css_online)(struct cgroup___93 *);
	void (*css_offline)(struct cgroup___93 *);
	void (*css_free)(struct cgroup___93 *);
	int (*can_attach)(struct cgroup___93 *, struct cgroup_taskset___43 *);
	void (*cancel_attach)(struct cgroup___93 *, struct cgroup_taskset___43 *);
	void (*attach)(struct cgroup___93 *, struct cgroup_taskset___43 *);
	void (*fork)(struct task_struct___143 *);
	void (*exit)(struct cgroup___93 *, struct cgroup___93 *, struct task_struct___143 *);
	void (*bind)(struct cgroup___93 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___93 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___45 *base_cftypes;
	struct cftype_set___43 base_cftset;
	struct module *module;
};

struct irq_chip___101 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___101 *);
	void (*irq_shutdown)(struct irq_data___101 *);
	void (*irq_enable)(struct irq_data___101 *);
	void (*irq_disable)(struct irq_data___101 *);
	void (*irq_ack)(struct irq_data___101 *);
	void (*irq_mask)(struct irq_data___101 *);
	void (*irq_mask_ack)(struct irq_data___101 *);
	void (*irq_unmask)(struct irq_data___101 *);
	void (*irq_eoi)(struct irq_data___101 *);
	int (*irq_set_affinity)(struct irq_data___101 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___101 *);
	int (*irq_set_type)(struct irq_data___101 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___101 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___101 *);
	void (*irq_bus_sync_unlock)(struct irq_data___101 *);
	void (*irq_cpu_online)(struct irq_data___101 *);
	void (*irq_cpu_offline)(struct irq_data___101 *);
	void (*irq_suspend)(struct irq_data___101 *);
	void (*irq_resume)(struct irq_data___101 *);
	void (*irq_pm_shutdown)(struct irq_data___101 *);
	void (*irq_print_chip)(struct irq_data___101 *, struct seq_file___106 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___101 *, void *);
	long unsigned int flags;
};

struct shmid_kernel {
	struct kern_ipc_perm shm_perm;
	struct file___144 *shm_file;
	long unsigned int shm_nattch;
	long unsigned int shm_segsz;
	time_t shm_atim;
	time_t shm_dtim;
	time_t shm_ctim;
	pid_t shm_cprid;
	pid_t shm_lprid;
	struct user_struct *mlock_user;
	struct task_struct___143 *shm_creator;
};

struct tlb_state___36 {
	struct mm_struct___148 *active_mm;
	int state;
};

struct hstate___14;

struct hugetlbfs_sb_info___5 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___14 *hstate;
	struct hugepage_subpool *spool;
};

struct hstate___14 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___45 cgroup_files[5];
	char name[32];
};

struct bus_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___112 *, char *);
	ssize_t (*store)(struct bus_type___112 *, const char *, size_t);
};

struct device_attribute___112;

struct driver_attribute___112;

struct bus_type___112 {
	const char *name;
	const char *dev_name;
	struct device___112 *dev_root;
	struct bus_attribute___112 *bus_attrs;
	struct device_attribute___112 *dev_attrs;
	struct driver_attribute___112 *drv_attrs;
	const struct attribute_group___105 **bus_groups;
	const struct attribute_group___105 **dev_groups;
	const struct attribute_group___105 **drv_groups;
	int (*match)(struct device___112 *, struct device_driver___112 *);
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	int (*probe)(struct device___112 *);
	int (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*online)(struct device___112 *);
	int (*offline)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct device___112 *, struct device_attribute___112 *, char *);
	ssize_t (*store)(struct device___112 *, struct device_attribute___112 *, const char *, size_t);
};

struct driver_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___112 *, char *);
	ssize_t (*store)(struct device_driver___112 *, const char *, size_t);
};

struct device_driver___112 {
	const char *name;
	struct bus_type___112 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___112 *);
	int (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	const struct attribute_group___105 **groups;
	const struct dev_pm_ops___112 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___112 {
	const char *name;
	const struct attribute_group___105 **groups;
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
};

struct class_attribute___112;

struct class___112 {
	const char *name;
	struct module *owner;
	struct class_attribute___112 *class_attrs;
	struct device_attribute___112 *dev_attrs;
	const struct attribute_group___105 **dev_groups;
	struct bin_attribute___107 *dev_bin_attrs;
	struct kobject___10 *dev_kobj;
	int (*dev_uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *);
	void (*class_release)(struct class___112 *);
	void (*dev_release)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
	struct subsys_private *p;
};

struct class_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct class___112 *, struct class_attribute___112 *, char *);
	ssize_t (*store)(struct class___112 *, struct class_attribute___112 *, const char *, size_t);
	const void * (*namespace)(struct class___112 *, const struct class_attribute___112 *);
};

struct device_rh___112 {
	struct dev_pm_info_rh___112 power;
};

struct shmem_inode_info___2 {
	spinlock_t lock;
	long unsigned int flags;
	long unsigned int alloced;
	union {
		long unsigned int swapped;
		char *symlink;
	};
	struct shared_policy policy;
	struct list_head swaplist;
	struct simple_xattrs xattrs;
	struct inode___144 vfs_inode;
};

struct seq_operations___105 {
	void * (*start)(struct seq_file___106 *, loff_t *);
	void (*stop)(struct seq_file___106 *, void *);
	void * (*next)(struct seq_file___106 *, void *, loff_t *);
	int (*show)(struct seq_file___106 *, void *);
};

struct ipc_namespace___3 {
	atomic_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	int auto_msgmni;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___35 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

struct perf_cpu_context___71;

struct pmu___71 {
	struct list_head entry;
	struct device___112 *dev;
	const struct attribute_group___105 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___71 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___71 *);
	void (*pmu_disable)(struct pmu___71 *);
	int (*event_init)(struct perf_event___71 *);
	int (*add)(struct perf_event___71 *, int);
	void (*del)(struct perf_event___71 *, int);
	void (*start)(struct perf_event___71 *, int);
	void (*stop)(struct perf_event___71 *, int);
	void (*read)(struct perf_event___71 *);
	void (*start_txn)(struct pmu___71 *);
	int (*commit_txn)(struct pmu___71 *);
	void (*cancel_txn)(struct pmu___71 *);
	int (*event_idx)(struct perf_event___71 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___71 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___71 *);
};

struct perf_cpu_context___71 {
	struct perf_event_context___71 ctx;
	struct perf_event_context___71 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___71 *unique_pmu;
	struct perf_cgroup___71 *cgrp;
};

struct trace_event_functions___61;

struct trace_event___61 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___61 *funcs;
};

struct ftrace_event_class___61;

struct ftrace_event_call___61 {
	struct list_head list;
	struct ftrace_event_class___61 *class;
	char *name;
	struct trace_event___61 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___71 {
	struct cgroup_subsys_state___93 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___61 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___144 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___61)(struct trace_iterator___61 *, int, struct trace_event___61 *);

struct trace_event_functions___61 {
	trace_print_func___61 trace;
	trace_print_func___61 raw;
	trace_print_func___61 hex;
	trace_print_func___61 binary;
};

struct ftrace_event_class___61 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___61 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___61 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___61 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___61 *);
};

struct syscall_metadata___30 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___61 *enter_event;
	struct ftrace_event_call___61 *exit_event;
};

struct ipc_ops___2 {
	int (*getnew)(struct ipc_namespace___3 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct shm_file_data {
	int id;
	struct ipc_namespace___3 *ns;
	struct file___144 *file;
	const struct vm_operations_struct___126 *vm_ops;
};

struct page___144;

typedef struct page___144 *pgtable_t___144;

struct address_space___145;

struct kmem_cache___131;

struct page___144 {
	long unsigned int flags;
	struct address_space___145 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___144 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___144 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___131 *slab_cache;
		struct page___144 *first_page;
	};
	long: 64;
};

struct thread_struct___72;

struct task_struct___144;

struct pv_cpu_ops___144 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___72 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___72 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___144 *);
	void (*end_context_switch)(struct task_struct___144 *);
};

struct perf_event___72;

struct thread_struct___72 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___72 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___81;

struct pid_link___81 {
	struct hlist_node node;
	struct pid___81 *pid;
};

struct mutex___145 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___144 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___140 {
	struct page___144 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___149;

struct nsproxy___86;

struct signal_struct___144;

struct css_set___94;

struct perf_event_context___72;

struct task_struct___144 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___144 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___149 *mm;
	struct mm_struct___149 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___144 *real_parent;
	struct task_struct___144 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___144 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___81 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___144 = 0,
		VTIME_USER___144 = 1,
		VTIME_SYS___144 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___72 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___86 *nsproxy;
	struct signal_struct___144 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___94 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___72 *perf_event_ctxp[2];
	struct mutex___145 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___140 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___149 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___149 *, struct mm_struct___149 *);
	void (*dup_mmap)(struct mm_struct___149 *, struct mm_struct___149 *);
	void (*exit_mmap)(struct mm_struct___149 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___149 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___149 *);
	void (*pgd_free)(struct mm_struct___149 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___149 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___149 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___149 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___149 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___149 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___149 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___149 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___149 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___149 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___149 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___149 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___145 lock;
	void *vdso;
} mm_context_t___145;

struct xol_area___144;

struct uprobes_state___144 {
	struct xol_area___144 *xol_area;
};

struct vm_area_struct___149;

struct file___145;

struct core_state___144;

struct mm_struct___149 {
	struct vm_area_struct___149 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___149 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___149 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___145 context;
	long unsigned int flags;
	struct core_state___144 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___144 *owner;
	struct file___145 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___144 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___72 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___144 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___144 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___144 *target;
};

typedef void (*perf_overflow_handler_t___72)(struct perf_event___72 *, struct perf_sample_data___6 *, struct pt_regs *);

struct ftrace_ops___72;

typedef void (*ftrace_func_t___72)(long unsigned int, long unsigned int, struct ftrace_ops___72 *, struct pt_regs *);

struct ftrace_ops___72 {
	ftrace_func_t___72 func;
	struct ftrace_ops___72 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___145 regex_lock;
};

struct pmu___72;

struct fasync_struct___145;

struct pid_namespace___81;

struct ftrace_event_call___62;

struct perf_cgroup___72;

struct perf_event___72 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___72 *group_leader;
	struct pmu___72 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___72 hw;
	struct perf_event_context___72 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___145 child_mutex;
	struct list_head child_list;
	struct perf_event___72 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___144 *owner;
	struct mutex___145 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___145 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___72 *);
	struct callback_head callback_head;
	struct pid_namespace___81 *ns;
	u64 id;
	perf_overflow_handler_t___72 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___62 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___72 ftrace_ops;
	struct perf_cgroup___72 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___73 {
	struct task_struct___144 *task;
	struct exec_domain___35 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___144;

struct lruvec___144 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___144 *zone;
};

struct pglist_data___144;

struct zone___144 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___144 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___144 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___144 {
	struct zone___144 *zone;
	int zone_idx;
};

struct zonelist___144 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___144 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___144 {
	struct zone___144 node_zones[4];
	struct zonelist___144 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___144 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___102;

struct x86_io_apic_ops___102 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___102 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___102;

struct irq_data___102 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___102 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___113;

struct dev_pm_ops___113 {
	int (*prepare)(struct device___113 *);
	void (*complete)(struct device___113 *);
	int (*suspend)(struct device___113 *);
	int (*resume)(struct device___113 *);
	int (*freeze)(struct device___113 *);
	int (*thaw)(struct device___113 *);
	int (*poweroff)(struct device___113 *);
	int (*restore)(struct device___113 *);
	int (*suspend_late)(struct device___113 *);
	int (*resume_early)(struct device___113 *);
	int (*freeze_late)(struct device___113 *);
	int (*thaw_early)(struct device___113 *);
	int (*poweroff_late)(struct device___113 *);
	int (*restore_early)(struct device___113 *);
	int (*suspend_noirq)(struct device___113 *);
	int (*resume_noirq)(struct device___113 *);
	int (*freeze_noirq)(struct device___113 *);
	int (*thaw_noirq)(struct device___113 *);
	int (*poweroff_noirq)(struct device___113 *);
	int (*restore_noirq)(struct device___113 *);
	int (*runtime_suspend)(struct device___113 *);
	int (*runtime_resume)(struct device___113 *);
	int (*runtime_idle)(struct device___113 *);
};

struct kset___11;

struct kobj_type___11;

struct kobject___11 {
	const char *name;
	struct list_head entry;
	struct kobject___11 *parent;
	struct kset___11 *kset;
	struct kobj_type___11 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___13;

struct dev_pm_info___13 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___13 *qos;
};

struct dma_map_ops___38;

struct dev_archdata___38 {
	struct dma_map_ops___38 *dma_ops;
	void *iommu;
};

struct device_type___113;

struct bus_type___113;

struct device_driver___113;

struct dev_pm_domain___113;

struct class___113;

struct attribute_group___106;

struct device_rh___113;

struct device___113 {
	struct device___113 *parent;
	struct device_private *p;
	struct kobject___11 kobj;
	const char *init_name;
	const struct device_type___113 *type;
	struct mutex___145 mutex;
	struct bus_type___113 *bus;
	struct device_driver___113 *driver;
	void *platform_data;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___113 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___38 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___113 *class;
	const struct attribute_group___106 **groups;
	void (*release)(struct device___113 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___113 *device_rh;
};

struct dev_pm_qos_request___13;

struct dev_pm_qos___13 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___13 *latency_req;
	struct dev_pm_qos_request___13 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___13 *latency_tolerance_req;
};

struct dev_pm_info_rh___113 {
	void (*set_latency_tolerance)(struct device___113 *, s32);
};

struct dev_pm_domain___113 {
	struct dev_pm_ops___113 ops;
};

struct smp_ops___144 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___144 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___144 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___144 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___130;

struct memcg_cache_params___131;

struct kmem_cache___131 {
	struct kmem_cache_cpu___130 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___131 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___145;

struct address_space_operations___145;

struct address_space___145 {
	struct inode___145 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___145 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___145 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___36;

struct dentry___145;

struct path___145 {
	struct vfsmount___36 *mnt;
	struct dentry___145 *dentry;
};

struct fown_struct___81 {
	rwlock_t lock;
	struct pid___81 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___145;

struct file___145 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___145 f_path;
	struct inode___145 *f_inode;
	const struct file_operations___145 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___81 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___145 *f_mapping;
	struct mutex___145 f_pos_lock;
};

struct vm_operations_struct___127;

struct vm_area_struct___149 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___149 *vm_next;
	struct vm_area_struct___149 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___149 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___127 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___145 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___124;

struct vm_operations_struct___127 {
	void (*open)(struct vm_area_struct___149 *);
	void (*close)(struct vm_area_struct___149 *);
	int (*fault)(struct vm_area_struct___149 *, struct vm_fault___124 *);
	int (*page_mkwrite)(struct vm_area_struct___149 *, struct vm_fault___124 *);
	int (*access)(struct vm_area_struct___149 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___149 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___149 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___149 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___149 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___144 {
	struct task_struct___144 *task;
	struct core_thread___144 *next;
};

struct core_state___144 {
	atomic_t nr_threads;
	struct core_thread___144 dumper;
	struct completion startup;
};

struct vm_fault___124 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___144 *page;
};

struct dentry_operations___145;

struct super_block___145;

struct dentry___145 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___145 *d_parent;
	struct qstr d_name;
	struct inode___145 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___145 *d_op;
	struct super_block___145 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___145;

struct file_lock___145;

struct dquot___145;

struct block_device___145;

struct inode___145 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___145 *i_op;
	struct super_block___145 *i_sb;
	struct address_space___145 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___145 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___145 *i_fop;
	struct file_lock___145 *i_flock;
	struct address_space___145 i_data;
	struct dquot___145 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___145 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___145 {
	int (*d_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_hash)(const struct dentry___145 *, struct qstr *);
	int (*d_compare)(const struct dentry___145 *, const struct dentry___145 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___145 *);
	void (*d_release)(struct dentry___145 *);
	void (*d_prune)(struct dentry___145 *);
	void (*d_iput)(struct dentry___145 *, struct inode___145 *);
	char * (*d_dname)(struct dentry___145 *, char *, int);
	struct vfsmount___36 * (*d_automount)(struct path___145 *);
	int (*d_manage)(struct dentry___145 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___145;

struct mem_dqinfo___145 {
	struct quota_format_type___145 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___145;

struct quota_info___145 {
	unsigned int flags;
	struct mutex___145 dqio_mutex;
	struct mutex___145 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___145 *files[2];
	struct mem_dqinfo___145 info[2];
	const struct quota_format_ops___145 *ops[2];
};

struct file_system_type___145;

struct super_operations___145;

struct dquot_operations___145;

struct quotactl_ops___145;

struct xattr_handler___94;

struct super_block___145 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___145 *s_type;
	const struct super_operations___145 *s_op;
	const struct dquot_operations___145 *dq_op;
	const struct quotactl_ops___145 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___145 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___94 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___145 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___145 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___145 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___145 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___36 {
	struct dentry___145 *mnt_root;
	struct super_block___145 *mnt_sb;
	int mnt_flags;
};

struct upid___81 {
	int nr;
	struct pid_namespace___81 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___81 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___144 *child_reaper;
	struct kmem_cache___131 *pid_cachep;
	unsigned int level;
	struct pid_namespace___81 *parent;
	struct vfsmount___36 *proc_mnt;
	struct dentry___145 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___81 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___81 numbers[1];
};

struct block_device___145 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___145 *bd_inode;
	struct super_block___145 *bd_super;
	struct mutex___145 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___145 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___145 bd_fsfreeze_mutex;
};

struct cgroup___94;

struct cgroup_subsys_state___94 {
	struct cgroup___94 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___15;

typedef int kiocb_cancel_fn___15(struct kiocb___15 *, struct io_event *);

struct kiocb___15 {
	atomic_t ki_users;
	struct file___145 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___15 *ki_cancel;
	void (*ki_dtor)(struct kiocb___15 *);
	union {
		void *user;
		struct task_struct___144 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___145 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___145 *ia_file;
};

struct dquot___145 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___145 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___145 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___145 {
	int qf_fmt_id;
	const struct quota_format_ops___145 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___145 *qf_next;
};

struct quota_format_ops___145 {
	int (*check_quota_file)(struct super_block___145 *, int);
	int (*read_file_info)(struct super_block___145 *, int);
	int (*write_file_info)(struct super_block___145 *, int);
	int (*free_file_info)(struct super_block___145 *, int);
	int (*read_dqblk)(struct dquot___145 *);
	int (*commit_dqblk)(struct dquot___145 *);
	int (*release_dqblk)(struct dquot___145 *);
};

struct dquot_operations___145 {
	int (*write_dquot)(struct dquot___145 *);
	struct dquot___145 * (*alloc_dquot)(struct super_block___145 *, int);
	void (*destroy_dquot)(struct dquot___145 *);
	int (*acquire_dquot)(struct dquot___145 *);
	int (*release_dquot)(struct dquot___145 *);
	int (*mark_dirty)(struct dquot___145 *);
	int (*write_info)(struct super_block___145 *, int);
	qsize_t * (*get_reserved_space)(struct inode___145 *);
};

struct quotactl_ops___145 {
	int (*quota_on)(struct super_block___145 *, int, int, struct path___145 *);
	int (*quota_on_meta)(struct super_block___145 *, int, int);
	int (*quota_off)(struct super_block___145 *, int);
	int (*quota_sync)(struct super_block___145 *, int);
	int (*get_info)(struct super_block___145 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___145 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___145 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___145 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___145 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___145 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___145 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___145 *, unsigned int);
};

struct address_space_operations___145 {
	int (*writepage)(struct page___144 *, struct writeback_control *);
	int (*readpage)(struct file___145 *, struct page___144 *);
	int (*writepages)(struct address_space___145 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___144 *);
	int (*readpages)(struct file___145 *, struct address_space___145 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___145 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___144 **, void **);
	int (*write_end)(struct file___145 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___144 *, void *);
	sector_t (*bmap)(struct address_space___145 *, sector_t);
	void (*invalidatepage)(struct page___144 *, long unsigned int);
	int (*releasepage)(struct page___144 *, gfp_t);
	void (*freepage)(struct page___144 *);
	ssize_t (*direct_IO)(int, struct kiocb___15 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___145 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___145 *, struct page___144 *, struct page___144 *, enum migrate_mode);
	int (*launder_page)(struct page___144 *);
	int (*is_partially_uptodate)(struct page___144 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___144 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___145 *, struct page___144 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___145 *, sector_t *);
	void (*swap_deactivate)(struct file___145 *);
	void (*invalidatepage_range)(struct page___144 *, unsigned int, unsigned int);
};

struct nameidata___23;

struct inode_operations___145 {
	struct dentry___145 * (*lookup)(struct inode___145 *, struct dentry___145 *, unsigned int);
	void * (*follow_link)(struct dentry___145 *, struct nameidata___23 *);
	int (*permission)(struct inode___145 *, int);
	struct posix_acl * (*get_acl)(struct inode___145 *, int);
	int (*readlink)(struct dentry___145 *, char *, int);
	void (*put_link)(struct dentry___145 *, struct nameidata___23 *, void *);
	int (*create)(struct inode___145 *, struct dentry___145 *, umode_t, bool);
	int (*link)(struct dentry___145 *, struct inode___145 *, struct dentry___145 *);
	int (*unlink)(struct inode___145 *, struct dentry___145 *);
	int (*symlink)(struct inode___145 *, struct dentry___145 *, const char *);
	int (*mkdir)(struct inode___145 *, struct dentry___145 *, umode_t);
	int (*rmdir)(struct inode___145 *, struct dentry___145 *);
	int (*mknod)(struct inode___145 *, struct dentry___145 *, umode_t, dev_t);
	int (*rename)(struct inode___145 *, struct dentry___145 *, struct inode___145 *, struct dentry___145 *);
	int (*setattr)(struct dentry___145 *, struct iattr___145 *);
	int (*getattr)(struct vfsmount___36 *, struct dentry___145 *, struct kstat *);
	int (*setxattr)(struct dentry___145 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___145 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___145 *, char *, size_t);
	int (*removexattr)(struct dentry___145 *, const char *);
	int (*fiemap)(struct inode___145 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___145 *, struct timespec *, int);
	int (*atomic_open)(struct inode___145 *, struct dentry___145 *, struct file___145 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___89;

struct seq_file___107;

struct file_operations___145 {
	struct module *owner;
	loff_t (*llseek)(struct file___145 *, loff_t, int);
	ssize_t (*read)(struct file___145 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___145 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___15 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___15 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___145 *, void *, filldir_t);
	unsigned int (*poll)(struct file___145 *, struct poll_table_struct___89 *);
	long int (*unlocked_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___145 *, struct vm_area_struct___149 *);
	int (*open)(struct inode___145 *, struct file___145 *);
	int (*flush)(struct file___145 *, fl_owner_t);
	int (*release)(struct inode___145 *, struct file___145 *);
	int (*fsync)(struct file___145 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___15 *, int);
	int (*fasync)(int, struct file___145 *, int);
	int (*lock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*sendpage)(struct file___145 *, struct page___144 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___145 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___145 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___145 *, long int, struct file_lock___145 **, void **);
		struct {
			int (*setlease)(struct file___145 *, long int, struct file_lock___145 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___145 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___107 *, struct file___145 *);
};

struct file_lock_operations___145;

struct lock_manager_operations___145;

struct file_lock___145 {
	struct file_lock___145 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___81 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___145 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___145 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___145 *fl_ops;
	const struct lock_manager_operations___145 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___145 {
	void (*fl_copy_lock)(struct file_lock___145 *, struct file_lock___145 *);
	void (*fl_release_private)(struct file_lock___145 *);
};

struct lock_manager_operations___145 {
	int (*lm_compare_owner)(struct file_lock___145 *, struct file_lock___145 *);
	long unsigned int (*lm_owner_key)(struct file_lock___145 *);
	void (*lm_notify)(struct file_lock___145 *);
	int (*lm_grant)(struct file_lock___145 *, struct file_lock___145 *, int);
	void (*lm_break)(struct file_lock___145 *);
	int (*lm_change)(struct file_lock___145 **, int);
};

struct fasync_struct___145 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___145 *fa_next;
	struct file___145 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___145 {
	const char *name;
	int fs_flags;
	struct dentry___145 * (*mount)(struct file_system_type___145 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___145 *);
	struct module *owner;
	struct file_system_type___145 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___145 {
	struct inode___145 * (*alloc_inode)(struct super_block___145 *);
	void (*destroy_inode)(struct inode___145 *);
	void (*dirty_inode)(struct inode___145 *, int);
	int (*write_inode)(struct inode___145 *, struct writeback_control *);
	int (*drop_inode)(struct inode___145 *);
	void (*evict_inode)(struct inode___145 *);
	void (*put_super)(struct super_block___145 *);
	int (*sync_fs)(struct super_block___145 *, int);
	int (*freeze_fs)(struct super_block___145 *);
	int (*unfreeze_fs)(struct super_block___145 *);
	int (*statfs)(struct dentry___145 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___145 *, int *, char *);
	void (*umount_begin)(struct super_block___145 *);
	int (*show_options)(struct seq_file___107 *, struct dentry___145 *);
	int (*show_devname)(struct seq_file___107 *, struct dentry___145 *);
	int (*show_path)(struct seq_file___107 *, struct dentry___145 *);
	int (*show_stats)(struct seq_file___107 *, struct dentry___145 *);
	ssize_t (*quota_read)(struct super_block___145 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___145 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___145 *);
	int (*bdev_try_to_free_page)(struct super_block___145 *, struct page___144 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___145 *);
	void (*free_cached_objects)(struct super_block___145 *, int);
};

struct xattr_handler___94 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___145 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___145 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___145 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___91)(struct file___145 *, wait_queue_head_t *, struct poll_table_struct___89 *);

struct poll_table_struct___89 {
	poll_queue_proc___91 _qproc;
	long unsigned int _key;
};

struct seq_operations___106;

struct seq_file___107 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___145 lock;
	const struct seq_operations___106 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nameidata___23 {
	struct path___145 path;
	struct qstr last;
	struct path___145 root;
	struct inode___145 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct irq_chip___102 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___102 *);
	void (*irq_shutdown)(struct irq_data___102 *);
	void (*irq_enable)(struct irq_data___102 *);
	void (*irq_disable)(struct irq_data___102 *);
	void (*irq_ack)(struct irq_data___102 *);
	void (*irq_mask)(struct irq_data___102 *);
	void (*irq_mask_ack)(struct irq_data___102 *);
	void (*irq_unmask)(struct irq_data___102 *);
	void (*irq_eoi)(struct irq_data___102 *);
	int (*irq_set_affinity)(struct irq_data___102 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___102 *);
	int (*irq_set_type)(struct irq_data___102 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___102 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___102 *);
	void (*irq_bus_sync_unlock)(struct irq_data___102 *);
	void (*irq_cpu_online)(struct irq_data___102 *);
	void (*irq_cpu_offline)(struct irq_data___102 *);
	void (*irq_suspend)(struct irq_data___102 *);
	void (*irq_resume)(struct irq_data___102 *);
	void (*irq_pm_shutdown)(struct irq_data___102 *);
	void (*irq_print_chip)(struct irq_data___102 *, struct seq_file___107 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___102 *, void *);
	long unsigned int flags;
};

struct fd___18 {
	struct file___145 *file;
	unsigned int flags;
};

struct ctl_table_header___22;

struct ctl_node___22 {
	struct rb_node node;
	struct ctl_table_header___22 *header;
};

struct ctl_table_root___22;

struct ctl_table_set___22;

struct ctl_dir___22;

struct ctl_table_header___22 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___22 *root;
	struct ctl_table_set___22 *set;
	struct ctl_dir___22 *parent;
	struct ctl_node___22 *node;
};

struct ctl_dir___22 {
	struct ctl_table_header___22 header;
	struct rb_root root;
};

struct ctl_table_set___22 {
	int (*is_seen)(struct ctl_table_set___22 *);
	struct ctl_dir___22 dir;
};

struct ctl_table_root___22 {
	struct ctl_table_set___22 default_set;
	struct ctl_table_set___22 * (*lookup)(struct ctl_table_root___22 *, struct nsproxy___86 *);
	int (*permissions)(struct ctl_table_header___22 *, struct ctl_table *);
};

struct ipc_namespace___4;

struct net___20;

struct nsproxy___86 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace___4 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___81 *pid_ns;
	struct net___20 *net_ns;
};

typedef struct poll_table_struct___89 poll_table___18;

struct socket_wq___8 {
	wait_queue_head_t wait;
	struct fasync_struct___145 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct sock___9;

struct proto_ops___8;

struct socket___8 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___8 *wq;
	struct file___145 *file;
	struct sock___9 *sk;
	const struct proto_ops___8 *ops;
};

struct proto___8;

struct sock_common___8 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___8 *skc_prot;
	struct net___20 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___13;

struct sk_buff_head___10 {
	struct sk_buff___13 *next;
	struct sk_buff___13 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___9;

struct dst_entry___8;

struct cg_proto___8;

struct sock___9 {
	struct sock_common___8 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___10 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___13 *head;
		struct sk_buff___13 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___9 *sk_filter;
	struct socket_wq___8 *sk_wq;
	struct sk_buff_head___10 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___8 *sk_rx_dst;
	struct dst_entry___8 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___10 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___10 sk_error_queue;
	struct proto___8 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___81 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___8 *sk_socket;
	void *sk_user_data;
	struct page_frag___140 sk_frag;
	struct sk_buff___13 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___8 *sk_cgrp;
	void (*sk_state_change)(struct sock___9 *);
	void (*sk_data_ready)(struct sock___9 *, int);
	void (*sk_write_space)(struct sock___9 *);
	void (*sk_error_report)(struct sock___9 *);
	int (*sk_backlog_rcv)(struct sock___9 *, struct sk_buff___13 *);
	void (*sk_destruct)(struct sock___9 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct proto_ops___8 {
	int family;
	struct module *owner;
	int (*release)(struct socket___8 *);
	int (*bind)(struct socket___8 *, struct sockaddr *, int);
	int (*connect)(struct socket___8 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___8 *, struct socket___8 *);
	int (*accept)(struct socket___8 *, struct socket___8 *, int);
	int (*getname)(struct socket___8 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___145 *, struct socket___8 *, struct poll_table_struct___89 *);
	int (*ioctl)(struct socket___8 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___8 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___8 *, int);
	int (*shutdown)(struct socket___8 *, int);
	int (*setsockopt)(struct socket___8 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___8 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___8 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___8 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___15 *, struct socket___8 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___15 *, struct socket___8 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___145 *, struct socket___8 *, struct vm_area_struct___149 *);
	ssize_t (*sendpage)(struct socket___8 *, struct page___144 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___8 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___9 *, int);
		struct {
			void (*set_peek_off)(struct sock___9 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct netns_core___19 {
	struct ctl_table_header___22 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___19 {
	struct mutex___145 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___19 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___22 *ctl;
};

struct netns_ipv4___19 {
	struct ctl_table_header___22 *forw_hdr;
	struct ctl_table_header___22 *frags_hdr;
	struct ctl_table_header___22 *ipv4_hdr;
	struct ctl_table_header___22 *route_hdr;
	struct ctl_table_header___22 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___9 *fibnl;
	struct sock___9 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___19 {
	struct ctl_table_header___22 *hdr;
	struct ctl_table_header___22 *route_hdr;
	struct ctl_table_header___22 *icmp_hdr;
	struct ctl_table_header___22 *frags_hdr;
	struct ctl_table_header___22 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___11;

struct neighbour___8;

struct dst_ops___19 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___19 *);
	struct dst_entry___8 * (*check)(struct dst_entry___8 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___8 *);
	unsigned int (*mtu)(const struct dst_entry___8 *);
	u32 * (*cow_metrics)(struct dst_entry___8 *, long unsigned int);
	void (*destroy)(struct dst_entry___8 *);
	void (*ifdown)(struct dst_entry___8 *, struct net_device___11 *, int);
	struct dst_entry___8 * (*negative_advice)(struct dst_entry___8 *);
	void (*link_failure)(struct sk_buff___13 *);
	void (*update_pmtu)(struct dst_entry___8 *, struct sock___9 *, struct sk_buff___13 *, u32);
	void (*redirect)(struct dst_entry___8 *, struct sock___9 *, struct sk_buff___13 *);
	int (*local_out)(struct sk_buff___13 *);
	struct neighbour___8 * (*neigh_lookup)(const struct dst_entry___8 *, struct sk_buff___13 *, const void *);
	struct kmem_cache___131 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___19 {
	struct netns_sysctl_ipv6___19 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___19 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___9 **icmp_sk;
	struct sock___9 *ndisc_sk;
	struct sock___9 *tcp_sk;
	struct sock___9 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___19 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___22 *sysctl_header;
	struct sock___9 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___8 {
	struct sock___9 *v4_ctl_sk;
	struct sock___9 *v6_ctl_sk;
};

struct netns_nf___19 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___22 *nf_log_dir_header;
};

struct nf_proto_net___19 {
	struct ctl_table_header___22 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___19 {
	struct nf_proto_net___19 pn;
	unsigned int timeout;
};

struct nf_tcp_net___19 {
	struct nf_proto_net___19 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___19 {
	struct nf_proto_net___19 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___19 {
	struct nf_proto_net___19 pn;
	unsigned int timeout;
};

struct nf_ip_net___19 {
	struct nf_generic_net___19 generic;
	struct nf_tcp_net___19 tcp;
	struct nf_udp_net___19 udp;
	struct nf_icmp_net___19 icmp;
	struct nf_icmp_net___19 icmpv6;
};

struct netns_ct___19 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___22 *sysctl_header;
	struct ctl_table_header___22 *acct_sysctl_header;
	struct ctl_table_header___22 *tstamp_sysctl_header;
	struct ctl_table_header___22 *event_sysctl_header;
	struct ctl_table_header___22 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___131 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___19 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___19 {
	struct netns_sysctl_ipv6___19 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___19 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___9 *nlsk;
	struct sock___9 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___22 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___19 xfrm4_dst_ops;
	struct dst_ops___19 xfrm6_dst_ops;
};

struct net___20 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___22 sysctls;
	struct sock___9 *rtnl;
	struct sock___9 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___11 *loopback_dev;
	struct netns_core___19 core;
	struct netns_mib___2 mib;
	struct netns_packet___19 packet;
	struct netns_unix___19 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___19 ipv4;
	struct netns_ipv6___19 ipv6;
	struct netns_sctp___19 sctp;
	struct netns_dccp___8 dccp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct___19 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___19 nf_frag;
	struct sock___9 *nfnl;
	struct sock___9 *nfnl_stash;
	struct sk_buff_head___10 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___19 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___9 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___9 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___145 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___145 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___8 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___9 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___108;

struct attribute_group___106 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___108 **bin_attrs;
};

struct bin_attribute___108 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___145 *, struct kobject___11 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___145 *, struct kobject___11 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	int (*mmap)(struct file___145 *, struct kobject___11 *, struct bin_attribute___108 *, struct vm_area_struct___149 *);
};

struct sysfs_ops___11 {
	ssize_t (*show)(struct kobject___11 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___11 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___11 *, const struct attribute *);
};

struct kset_uevent_ops___11;

struct kset___11 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___11 kobj;
	const struct kset_uevent_ops___11 *uevent_ops;
};

struct kobj_type___11 {
	void (*release)(struct kobject___11 *);
	const struct sysfs_ops___11 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___8 * (*child_ns_type)(struct kobject___11 *);
	const void * (*namespace)(struct kobject___11 *);
};

struct kset_uevent_ops___11 {
	int (* const filter)(struct kset___11 *, struct kobject___11 *);
	const char * (* const name)(struct kset___11 *, struct kobject___11 *);
	int (* const uevent)(struct kset___11 *, struct kobject___11 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___130 {
	void **freelist;
	long unsigned int tid;
	struct page___144 *page;
	struct page___144 *partial;
};

struct memcg_cache_params___131 {
	bool is_root_cache;
	union {
		struct kmem_cache___131 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___131 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___38 {
	void * (*alloc)(struct device___113 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___113 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___113 *, struct vm_area_struct___149 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___113 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___113 *, struct page___144 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___113 *, dma_addr_t);
	int (*dma_supported)(struct device___113 *, u64);
	int (*set_dma_mask)(struct device___113 *, u64);
	int is_phys;
};

struct bus_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___113 *, char *);
	ssize_t (*store)(struct bus_type___113 *, const char *, size_t);
};

struct device_attribute___113;

struct driver_attribute___113;

struct bus_type___113 {
	const char *name;
	const char *dev_name;
	struct device___113 *dev_root;
	struct bus_attribute___113 *bus_attrs;
	struct device_attribute___113 *dev_attrs;
	struct driver_attribute___113 *drv_attrs;
	const struct attribute_group___106 **bus_groups;
	const struct attribute_group___106 **dev_groups;
	const struct attribute_group___106 **drv_groups;
	int (*match)(struct device___113 *, struct device_driver___113 *);
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	int (*probe)(struct device___113 *);
	int (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*online)(struct device___113 *);
	int (*offline)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct device___113 *, struct device_attribute___113 *, char *);
	ssize_t (*store)(struct device___113 *, struct device_attribute___113 *, const char *, size_t);
};

struct driver_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___113 *, char *);
	ssize_t (*store)(struct device_driver___113 *, const char *, size_t);
};

struct device_driver___113 {
	const char *name;
	struct bus_type___113 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___113 *);
	int (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	const struct attribute_group___106 **groups;
	const struct dev_pm_ops___113 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___113 {
	const char *name;
	const struct attribute_group___106 **groups;
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
};

struct class_attribute___113;

struct class___113 {
	const char *name;
	struct module *owner;
	struct class_attribute___113 *class_attrs;
	struct device_attribute___113 *dev_attrs;
	const struct attribute_group___106 **dev_groups;
	struct bin_attribute___108 *dev_bin_attrs;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *);
	void (*class_release)(struct class___113 *);
	void (*dev_release)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
	struct subsys_private *p;
};

struct class_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct class___113 *, struct class_attribute___113 *, char *);
	ssize_t (*store)(struct class___113 *, struct class_attribute___113 *, const char *, size_t);
	const void * (*namespace)(struct class___113 *, const struct class_attribute___113 *);
};

struct device_rh___113 {
	struct dev_pm_info_rh___113 power;
};

struct signal_struct___144 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___144 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___144 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___81 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___81 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___145 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___94 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___94 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___72 {
	struct pmu___72 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___145 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___144 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___72 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct nf_bridge_info___9 {
	atomic_t use;
	unsigned int mask;
	struct net_device___11 *physindev;
	struct net_device___11 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___9(struct sk_buff___13 **);

struct net_device_ops___9;

struct ethtool_ops___9;

struct header_ops___9;

struct netdev_rx_queue___9;

struct netdev_queue___9;

struct rtnl_link_ops___8;

struct dcbnl_rtnl_ops___9;

struct net_device___11 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___9 *netdev_ops;
	const struct ethtool_ops___9 *ethtool_ops;
	const struct header_ops___9 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___11 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___9 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___9 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___9 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___9 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___9 = 0,
		NETREG_REGISTERED___9 = 1,
		NETREG_UNREGISTERING___9 = 2,
		NETREG_UNREGISTERED___9 = 3,
		NETREG_RELEASED___9 = 4,
		NETREG_DUMMY___9 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___9 = 0,
		RTNL_LINK_INITIALIZING___9 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___11 *);
	struct netpoll_info *npinfo;
	struct net___20 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide22;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___113 dev;
	const struct attribute_group___106 *sysfs_groups[4];
	const struct rtnl_link_ops___8 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___9 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___13 {
	struct sk_buff___13 *next;
	struct sk_buff___13 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___9 *sk;
	struct net_device___11 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___13 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___9 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ipc_namespace___4 {
	atomic_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	int auto_msgmni;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___36 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

struct netlink_callback___10 {
	struct sk_buff___13 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___13 *, struct netlink_callback___10 *);
	int (*done)(struct netlink_callback___10 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct seq_operations___106 {
	void * (*start)(struct seq_file___107 *, loff_t *);
	void (*stop)(struct seq_file___107 *, void *);
	void * (*next)(struct seq_file___107 *, void *, loff_t *);
	int (*show)(struct seq_file___107 *, void *);
};

struct cgroupfs_root___94;

struct cgroup___94 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___94 *parent;
	struct dentry___145 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___94 *subsys[11];
	struct cgroupfs_root___94 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___145 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___94 {
	struct super_block___145 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___94 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___46 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___145 *, struct file___145 *);
	ssize_t (*read)(struct cgroup___94 *, struct cftype___46 *, struct file___145 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___94 *, struct cftype___46 *);
	s64 (*read_s64)(struct cgroup___94 *, struct cftype___46 *);
	int (*read_map)(struct cgroup___94 *, struct cftype___46 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___94 *, struct cftype___46 *, struct seq_file___107 *);
	ssize_t (*write)(struct cgroup___94 *, struct cftype___46 *, struct file___145 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___94 *, struct cftype___46 *, u64);
	int (*write_s64)(struct cgroup___94 *, struct cftype___46 *, s64);
	int (*write_string)(struct cgroup___94 *, struct cftype___46 *, const char *);
	int (*trigger)(struct cgroup___94 *, unsigned int);
	int (*release)(struct inode___145 *, struct file___145 *);
	int (*register_event)(struct cgroup___94 *, struct cftype___46 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___94 *, struct cftype___46 *, struct eventfd_ctx *);
};

struct cftype_set___44 {
	struct list_head node;
	struct cftype___46 *cfts;
};

struct task_and_cgroup___44 {
	struct task_struct___144 *task;
	struct cgroup___94 *cgrp;
	struct css_set___94 *cg;
};

struct cgroup_taskset___44 {
	struct task_and_cgroup___44 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___94 *cur_cgrp;
};

struct cgroup_subsys___44 {
	struct cgroup_subsys_state___94 * (*css_alloc)(struct cgroup___94 *);
	int (*css_online)(struct cgroup___94 *);
	void (*css_offline)(struct cgroup___94 *);
	void (*css_free)(struct cgroup___94 *);
	int (*can_attach)(struct cgroup___94 *, struct cgroup_taskset___44 *);
	void (*cancel_attach)(struct cgroup___94 *, struct cgroup_taskset___44 *);
	void (*attach)(struct cgroup___94 *, struct cgroup_taskset___44 *);
	void (*fork)(struct task_struct___144 *);
	void (*exit)(struct cgroup___94 *, struct cgroup___94 *, struct task_struct___144 *);
	void (*bind)(struct cgroup___94 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___94 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___46 *base_cftypes;
	struct cftype_set___44 base_cftset;
	struct module *module;
};

struct perf_cpu_context___72;

struct pmu___72 {
	struct list_head entry;
	struct device___113 *dev;
	const struct attribute_group___106 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___72 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___72 *);
	void (*pmu_disable)(struct pmu___72 *);
	int (*event_init)(struct perf_event___72 *);
	int (*add)(struct perf_event___72 *, int);
	void (*del)(struct perf_event___72 *, int);
	void (*start)(struct perf_event___72 *, int);
	void (*stop)(struct perf_event___72 *, int);
	void (*read)(struct perf_event___72 *);
	void (*start_txn)(struct pmu___72 *);
	int (*commit_txn)(struct pmu___72 *);
	void (*cancel_txn)(struct pmu___72 *);
	int (*event_idx)(struct perf_event___72 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___72 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___72 *);
};

struct perf_cpu_context___72 {
	struct perf_event_context___72 ctx;
	struct perf_event_context___72 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___72 *unique_pmu;
	struct perf_cgroup___72 *cgrp;
};

struct trace_event_functions___62;

struct trace_event___62 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___62 *funcs;
};

struct ftrace_event_class___62;

struct ftrace_event_call___62 {
	struct list_head list;
	struct ftrace_event_class___62 *class;
	char *name;
	struct trace_event___62 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___72 {
	struct cgroup_subsys_state___94 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___62 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___145 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___62)(struct trace_iterator___62 *, int, struct trace_event___62 *);

struct trace_event_functions___62 {
	trace_print_func___62 trace;
	trace_print_func___62 raw;
	trace_print_func___62 hex;
	trace_print_func___62 binary;
};

struct ftrace_event_class___62 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___62 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___62 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___62 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___62 *);
};

struct syscall_metadata___31 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___62 *enter_event;
	struct ftrace_event_call___62 *exit_event;
};

struct dev_pm_qos_request___13 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___113 *dev;
};

struct ethtool_ops___9 {
	int (*get_settings)(struct net_device___11 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___11 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___11 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___11 *);
	void (*get_regs)(struct net_device___11 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___11 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___11 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___11 *);
	void (*set_msglevel)(struct net_device___11 *, u32);
	int (*nway_reset)(struct net_device___11 *);
	u32 (*get_link)(struct net_device___11 *);
	int (*get_eeprom_len)(struct net_device___11 *);
	int (*get_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___11 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___11 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___11 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___11 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___11 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___11 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___11 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___11 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___11 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___11 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___11 *);
	void (*complete)(struct net_device___11 *);
	u32 (*get_priv_flags)(struct net_device___11 *);
	int (*set_priv_flags)(struct net_device___11 *, u32);
	int (*get_sset_count)(struct net_device___11 *, int);
	int (*get_rxnfc)(struct net_device___11 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___11 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___11 *, struct ethtool_flash *);
	int (*reset)(struct net_device___11 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___11 *);
	int (*get_rxfh_indir)(struct net_device___11 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___11 *, const u32 *);
	void (*get_channels)(struct net_device___11 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___11 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___11 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___11 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___11 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___11 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___11 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___11 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___11 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___11 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___11 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___11 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___8 {
	struct callback_head callback_head;
	struct dst_entry___8 *child;
	struct net_device___11 *dev;
	struct dst_ops___19 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___8 *path;
	struct dst_entry___8 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___13 *);
	union {
		int (*output)(struct sock___9 *, struct sk_buff___13 *);
		struct {
			int (*output)(struct sk_buff___13 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___8 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___8;

struct neigh_parms___8;

struct neigh_ops___8;

struct neighbour___8 {
	struct neighbour___8 *next;
	struct neigh_table___8 *tbl;
	struct neigh_parms___8 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___10 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___8 *, struct sk_buff___13 *);
	const struct neigh_ops___8 *ops;
	struct callback_head rcu;
	struct net_device___11 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___19 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___13 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___13 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___20 *, struct dst_entry___8 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___13 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___13 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___9 {
	int (*ieee_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___11 *);
	u8 (*setstate)(struct net_device___11 *, u8);
	void (*getpermhwaddr)(struct net_device___11 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___11 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___11 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___11 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___11 *, int, u8 *);
	void (*setpfccfg)(struct net_device___11 *, int, u8);
	void (*getpfccfg)(struct net_device___11 *, int, u8 *);
	u8 (*setall)(struct net_device___11 *);
	u8 (*getcap)(struct net_device___11 *, int, u8 *);
	int (*getnumtcs)(struct net_device___11 *, int, u8 *);
	int (*setnumtcs)(struct net_device___11 *, int, u8);
	u8 (*getpfcstate)(struct net_device___11 *);
	void (*setpfcstate)(struct net_device___11 *, u8);
	void (*getbcncfg)(struct net_device___11 *, int, u32 *);
	void (*setbcncfg)(struct net_device___11 *, int, u32);
	void (*getbcnrp)(struct net_device___11 *, int, u8 *);
	void (*setbcnrp)(struct net_device___11 *, int, u8);
	u8 (*setapp)(struct net_device___11 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___11 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___11 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___11 *, int, u8);
	u8 (*getdcbx)(struct net_device___11 *);
	u8 (*setdcbx)(struct net_device___11 *, u8);
	int (*peer_getappinfo)(struct net_device___11 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___11 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___11 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___11 *, struct cee_pfc *);
};

struct header_ops___9 {
	int (*create)(struct sk_buff___13 *, struct net_device___11 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___13 *, unsigned char *);
	int (*rebuild)(struct sk_buff___13 *);
	int (*cache)(const struct neighbour___8 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___11 *, const unsigned char *);
};

struct napi_struct___9 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___9 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___11 *dev;
	struct sk_buff___13 *gro_list;
	struct sk_buff___13 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___9 {
	struct net_device___11 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___11 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___9 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___11 kobj;
	struct net_device___11 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___9 {
	int (*ndo_init)(struct net_device___11 *);
	void (*ndo_uninit)(struct net_device___11 *);
	int (*ndo_open)(struct net_device___11 *);
	int (*ndo_stop)(struct net_device___11 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___13 *, struct net_device___11 *);
	u16 (*ndo_select_queue)(struct net_device___11 *, struct sk_buff___13 *);
	void (*ndo_change_rx_flags)(struct net_device___11 *, int);
	void (*ndo_set_rx_mode)(struct net_device___11 *);
	int (*ndo_set_mac_address)(struct net_device___11 *, void *);
	int (*ndo_validate_addr)(struct net_device___11 *);
	int (*ndo_do_ioctl)(struct net_device___11 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___11 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___11 *, int);
	int (*ndo_neigh_setup)(struct net_device___11 *, struct neigh_parms___8 *);
	void (*ndo_tx_timeout)(struct net_device___11 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___11 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___11 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___11 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___11 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___11 *);
	int (*ndo_netpoll_setup)(struct net_device___11 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___11 *);
	int (*ndo_busy_poll)(struct napi_struct___9 *);
	int (*ndo_set_vf_mac)(struct net_device___11 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___11 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___11 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___11 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___11 *, int, struct ifla_vf_info___2 *);
	int (*ndo_set_vf_link_state)(struct net_device___11 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___11 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___11 *, int, struct sk_buff___13 *);
	int (*ndo_setup_tc)(struct net_device___11 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___11 *);
	int (*ndo_fcoe_disable)(struct net_device___11 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___11 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___11 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___11 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___11 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___11 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___11 *, const struct sk_buff___13 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___11 *, struct net_device___11 *);
	int (*ndo_del_slave)(struct net_device___11 *, struct net_device___11 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___8 *);
	void (*ndo_neigh_destroy)(struct neighbour___8 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___13 *, struct netlink_callback___10 *, struct net_device___11 *, int);
	int (*ndo_bridge_setlink)(struct net_device___11 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___13 *, u32, u32, struct net_device___11 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___11 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___11 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___11 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___11 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___11 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___11 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___13 *, struct net_device___11 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___11 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___11 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___11 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___8 {
	struct net___20 *net;
	struct net_device___11 *dev;
	struct neigh_parms___8 *next;
	int (*neigh_setup)(struct neighbour___8 *);
	void (*neigh_cleanup)(struct neighbour___8 *);
	struct neigh_table___8 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___8 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___11 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___20 *, struct net_device___11 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___11 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___11 *, struct list_head *);
	size_t (*get_size)(const struct net_device___11 *);
	int (*fill_info)(struct sk_buff___13 *, const struct net_device___11 *);
	size_t (*get_xstats_size)(const struct net_device___11 *);
	int (*fill_xstats)(struct sk_buff___13 *, const struct net_device___11 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___20 * (*get_link_net)(const struct net_device___11 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___11 *, struct net_device___11 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___11 *, const struct net_device___11 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___13 *, const struct net_device___11 *, const struct net_device___11 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___9 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___13 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___8;

struct neigh_hash_table___8;

struct neigh_table___8 {
	struct neigh_table___8 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___11 *, __u32 *);
	int (*constructor)(struct neighbour___8 *);
	int (*pconstructor)(struct pneigh_entry___8 *);
	void (*pdestructor)(struct pneigh_entry___8 *);
	void (*proxy_redo)(struct sk_buff___13 *);
	char *id;
	struct neigh_parms___8 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___10 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___8 *nht;
	struct pneigh_entry___8 **phash_buckets;
};

struct neigh_ops___8 {
	int family;
	void (*solicit)(struct neighbour___8 *, struct sk_buff___13 *);
	void (*error_report)(struct neighbour___8 *, struct sk_buff___13 *);
	int (*output)(struct neighbour___8 *, struct sk_buff___13 *);
	int (*connected_output)(struct neighbour___8 *, struct sk_buff___13 *);
};

struct pneigh_entry___8 {
	struct pneigh_entry___8 *next;
	struct net___20 *net;
	struct net_device___11 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___8 {
	struct neighbour___8 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___8 {
	void (*close)(struct sock___9 *, long int);
	int (*connect)(struct sock___9 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___9 *, int);
	struct sock___9 * (*accept)(struct sock___9 *, int, int *);
	int (*ioctl)(struct sock___9 *, int, long unsigned int);
	int (*init)(struct sock___9 *);
	void (*destroy)(struct sock___9 *);
	void (*shutdown)(struct sock___9 *, int);
	int (*setsockopt)(struct sock___9 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___9 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___9 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___9 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___9 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___15 *, struct sock___9 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___15 *, struct sock___9 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___9 *, struct page___144 *, int, size_t, int);
	int (*bind)(struct sock___9 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___9 *, struct sk_buff___13 *);
	void (*release_cb)(struct sock___9 *);
	void (*mtu_reduced)(struct sock___9 *);
	void (*hash)(struct sock___9 *);
	void (*unhash)(struct sock___9 *);
	void (*rehash)(struct sock___9 *);
	int (*get_port)(struct sock___9 *, short unsigned int);
	void (*clear_sk)(struct sock___9 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___9 *);
	void (*enter_memory_pressure)(struct sock___9 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___131 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___44 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___8 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___8 {
	void (*enter_memory_pressure)(struct sock___9 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct posix_msg_tree_node {
	struct rb_node rb_node;
	struct list_head msg_list;
	int priority;
};

struct ext_wait_queue {
	struct task_struct___144 *task;
	struct list_head list;
	struct msg_msg *msg;
	int state;
};

struct mqueue_inode_info {
	spinlock_t lock;
	struct inode___145 vfs_inode;
	wait_queue_head_t wait_q;
	struct rb_root msg_tree;
	struct posix_msg_tree_node *node_cache;
	struct mq_attr attr;
	struct sigevent notify;
	struct pid___81 *notify_owner;
	struct user_namespace *notify_user_ns;
	struct user_struct *user;
	struct sock___9 *notify_sock;
	struct sk_buff___13 *notify_cookie;
	struct ext_wait_queue e_wait_q[2];
	long unsigned int qsize;
};

struct compat_mq_attr {
	compat_long_t mq_flags;
	compat_long_t mq_maxmsg;
	compat_long_t mq_msgsize;
	compat_long_t mq_curmsgs;
	compat_long_t __reserved[4];
};

struct page___145;

typedef struct page___145 *pgtable_t___145;

struct address_space___146;

struct kmem_cache___132;

struct page___145 {
	long unsigned int flags;
	struct address_space___146 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___145 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___145 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___132 *slab_cache;
		struct page___145 *first_page;
	};
	long: 64;
};

struct task_struct___145;

struct pv_cpu_ops___145 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___72 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___72 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___145 *);
	void (*end_context_switch)(struct task_struct___145 *);
};

struct mutex___146 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___145 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___141 {
	struct page___145 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___150;

struct nsproxy___87;

struct signal_struct___145;

struct task_struct___145 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___145 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___150 *mm;
	struct mm_struct___150 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___145 *real_parent;
	struct task_struct___145 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___145 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___81 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___145 = 0,
		VTIME_USER___145 = 1,
		VTIME_SYS___145 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___72 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___87 *nsproxy;
	struct signal_struct___145 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___146 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___141 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___150 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___150 *, struct mm_struct___150 *);
	void (*dup_mmap)(struct mm_struct___150 *, struct mm_struct___150 *);
	void (*exit_mmap)(struct mm_struct___150 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___150 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___150 *);
	void (*pgd_free)(struct mm_struct___150 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___150 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___150 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___150 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___150 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___150 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___150 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___150 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___150 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___150 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___150 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___150 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___146 lock;
	void *vdso;
} mm_context_t___146;

struct xol_area___145;

struct uprobes_state___145 {
	struct xol_area___145 *xol_area;
};

struct vm_area_struct___150;

struct file___146;

struct core_state___145;

struct mm_struct___150 {
	struct vm_area_struct___150 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___150 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___150 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___146 context;
	long unsigned int flags;
	struct core_state___145 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___145 *owner;
	struct file___146 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___145 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___145 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___145 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___131;

struct memcg_cache_params___132;

struct kmem_cache___132 {
	struct kmem_cache_cpu___131 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___132 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___146;

struct address_space_operations___146;

struct address_space___146 {
	struct inode___146 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___146 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___146 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___37;

struct dentry___146;

struct path___146 {
	struct vfsmount___37 *mnt;
	struct dentry___146 *dentry;
};

struct file_operations___146;

struct file___146 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___146 f_path;
	struct inode___146 *f_inode;
	const struct file_operations___146 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___81 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___146 *f_mapping;
	struct mutex___146 f_pos_lock;
};

struct vm_area_struct___150 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___150 *vm_next;
	struct vm_area_struct___150 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___150 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___146 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___145 {
	struct task_struct___145 *task;
	struct core_thread___145 *next;
};

struct core_state___145 {
	atomic_t nr_threads;
	struct core_thread___145 dumper;
	struct completion startup;
};

struct smp_ops___145 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___145 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___145;

struct lruvec___145 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___145 *zone;
};

struct pglist_data___145;

struct zone___145 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___145 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___145 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___145 {
	struct zone___145 *zone;
	int zone_idx;
};

struct zonelist___145 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___145 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___145 {
	struct zone___145 node_zones[4];
	struct zonelist___145 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___145 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ipc_namespace___5;

struct nsproxy___87 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace___5 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net *net_ns;
};

struct signal_struct___145 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___145 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___145 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___81 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___81 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___146 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct ipc_namespace___5 {
	atomic_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	int auto_msgmni;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___37 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
};

struct super_block___146;

struct vfsmount___37 {
	struct dentry___146 *mnt_root;
	struct super_block___146 *mnt_sb;
	int mnt_flags;
};

struct kmem_cache_cpu___131 {
	void **freelist;
	long unsigned int tid;
	struct page___145 *page;
	struct page___145 *partial;
};

struct memcg_cache_params___132 {
	bool is_root_cache;
	union {
		struct kmem_cache___132 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___132 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___146;

struct dentry___146 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___146 *d_parent;
	struct qstr d_name;
	struct inode___146 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___146 *d_op;
	struct super_block___146 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___146;

struct file_lock___146;

struct dquot___146;

struct block_device___146;

struct inode___146 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___146 *i_op;
	struct super_block___146 *i_sb;
	struct address_space___146 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___146 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___146 *i_fop;
	struct file_lock___146 *i_flock;
	struct address_space___146 i_data;
	struct dquot___146 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___146 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___146 {
	int (*d_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_hash)(const struct dentry___146 *, struct qstr *);
	int (*d_compare)(const struct dentry___146 *, const struct dentry___146 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___146 *);
	void (*d_release)(struct dentry___146 *);
	void (*d_prune)(struct dentry___146 *);
	void (*d_iput)(struct dentry___146 *, struct inode___146 *);
	char * (*d_dname)(struct dentry___146 *, char *, int);
	struct vfsmount___37 * (*d_automount)(struct path___146 *);
	int (*d_manage)(struct dentry___146 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___146;

struct mem_dqinfo___146 {
	struct quota_format_type___146 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___146;

struct quota_info___146 {
	unsigned int flags;
	struct mutex___146 dqio_mutex;
	struct mutex___146 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___146 *files[2];
	struct mem_dqinfo___146 info[2];
	const struct quota_format_ops___146 *ops[2];
};

struct file_system_type___146;

struct super_operations___146;

struct dquot_operations___146;

struct quotactl_ops___146;

struct super_block___146 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___146 *s_type;
	const struct super_operations___146 *s_op;
	const struct dquot_operations___146 *dq_op;
	const struct quotactl_ops___146 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___146 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___146 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___146 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___146 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___146 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___146 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___146 *bd_inode;
	struct super_block___146 *bd_super;
	struct mutex___146 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___146 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___146 bd_fsfreeze_mutex;
};

struct iattr___146 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___146 *ia_file;
};

struct dquot___146 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___146 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___146 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___146 {
	int qf_fmt_id;
	const struct quota_format_ops___146 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___146 *qf_next;
};

struct quota_format_ops___146 {
	int (*check_quota_file)(struct super_block___146 *, int);
	int (*read_file_info)(struct super_block___146 *, int);
	int (*write_file_info)(struct super_block___146 *, int);
	int (*free_file_info)(struct super_block___146 *, int);
	int (*read_dqblk)(struct dquot___146 *);
	int (*commit_dqblk)(struct dquot___146 *);
	int (*release_dqblk)(struct dquot___146 *);
};

struct dquot_operations___146 {
	int (*write_dquot)(struct dquot___146 *);
	struct dquot___146 * (*alloc_dquot)(struct super_block___146 *, int);
	void (*destroy_dquot)(struct dquot___146 *);
	int (*acquire_dquot)(struct dquot___146 *);
	int (*release_dquot)(struct dquot___146 *);
	int (*mark_dirty)(struct dquot___146 *);
	int (*write_info)(struct super_block___146 *, int);
	qsize_t * (*get_reserved_space)(struct inode___146 *);
};

struct quotactl_ops___146 {
	int (*quota_on)(struct super_block___146 *, int, int, struct path___146 *);
	int (*quota_on_meta)(struct super_block___146 *, int, int);
	int (*quota_off)(struct super_block___146 *, int);
	int (*quota_sync)(struct super_block___146 *, int);
	int (*get_info)(struct super_block___146 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___146 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___146 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___146 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___146 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___146 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___146 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___146 *, unsigned int);
};

struct address_space_operations___146 {
	int (*writepage)(struct page___145 *, struct writeback_control *);
	int (*readpage)(struct file___146 *, struct page___145 *);
	int (*writepages)(struct address_space___146 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___145 *);
	int (*readpages)(struct file___146 *, struct address_space___146 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___146 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___145 **, void **);
	int (*write_end)(struct file___146 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___145 *, void *);
	sector_t (*bmap)(struct address_space___146 *, sector_t);
	void (*invalidatepage)(struct page___145 *, long unsigned int);
	int (*releasepage)(struct page___145 *, gfp_t);
	void (*freepage)(struct page___145 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___146 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___146 *, struct page___145 *, struct page___145 *, enum migrate_mode);
	int (*launder_page)(struct page___145 *);
	int (*is_partially_uptodate)(struct page___145 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___145 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___146 *, struct page___145 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___146 *, sector_t *);
	void (*swap_deactivate)(struct file___146 *);
	void (*invalidatepage_range)(struct page___145 *, unsigned int, unsigned int);
};

struct inode_operations___146 {
	struct dentry___146 * (*lookup)(struct inode___146 *, struct dentry___146 *, unsigned int);
	void * (*follow_link)(struct dentry___146 *, struct nameidata *);
	int (*permission)(struct inode___146 *, int);
	struct posix_acl * (*get_acl)(struct inode___146 *, int);
	int (*readlink)(struct dentry___146 *, char *, int);
	void (*put_link)(struct dentry___146 *, struct nameidata *, void *);
	int (*create)(struct inode___146 *, struct dentry___146 *, umode_t, bool);
	int (*link)(struct dentry___146 *, struct inode___146 *, struct dentry___146 *);
	int (*unlink)(struct inode___146 *, struct dentry___146 *);
	int (*symlink)(struct inode___146 *, struct dentry___146 *, const char *);
	int (*mkdir)(struct inode___146 *, struct dentry___146 *, umode_t);
	int (*rmdir)(struct inode___146 *, struct dentry___146 *);
	int (*mknod)(struct inode___146 *, struct dentry___146 *, umode_t, dev_t);
	int (*rename)(struct inode___146 *, struct dentry___146 *, struct inode___146 *, struct dentry___146 *);
	int (*setattr)(struct dentry___146 *, struct iattr___146 *);
	int (*getattr)(struct vfsmount___37 *, struct dentry___146 *, struct kstat *);
	int (*setxattr)(struct dentry___146 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___146 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___146 *, char *, size_t);
	int (*removexattr)(struct dentry___146 *, const char *);
	int (*fiemap)(struct inode___146 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___146 *, struct timespec *, int);
	int (*atomic_open)(struct inode___146 *, struct dentry___146 *, struct file___146 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___146 {
	struct module *owner;
	loff_t (*llseek)(struct file___146 *, loff_t, int);
	ssize_t (*read)(struct file___146 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___146 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___146 *, void *, filldir_t);
	unsigned int (*poll)(struct file___146 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___146 *, struct vm_area_struct___150 *);
	int (*open)(struct inode___146 *, struct file___146 *);
	int (*flush)(struct file___146 *, fl_owner_t);
	int (*release)(struct inode___146 *, struct file___146 *);
	int (*fsync)(struct file___146 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___146 *, int);
	int (*lock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*sendpage)(struct file___146 *, struct page___145 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___146 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___146 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___146 *, long int, struct file_lock___146 **, void **);
		struct {
			int (*setlease)(struct file___146 *, long int, struct file_lock___146 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___146 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___146 *);
};

struct fasync_struct___146;

struct file_lock_operations___146;

struct lock_manager_operations___146;

struct file_lock___146 {
	struct file_lock___146 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___81 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___146 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___146 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___146 *fl_ops;
	const struct lock_manager_operations___146 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___146 {
	void (*fl_copy_lock)(struct file_lock___146 *, struct file_lock___146 *);
	void (*fl_release_private)(struct file_lock___146 *);
};

struct lock_manager_operations___146 {
	int (*lm_compare_owner)(struct file_lock___146 *, struct file_lock___146 *);
	long unsigned int (*lm_owner_key)(struct file_lock___146 *);
	void (*lm_notify)(struct file_lock___146 *);
	int (*lm_grant)(struct file_lock___146 *, struct file_lock___146 *, int);
	void (*lm_break)(struct file_lock___146 *);
	int (*lm_change)(struct file_lock___146 **, int);
};

struct fasync_struct___146 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___146 *fa_next;
	struct file___146 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___146 {
	const char *name;
	int fs_flags;
	struct dentry___146 * (*mount)(struct file_system_type___146 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___146 *);
	struct module *owner;
	struct file_system_type___146 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___146 {
	struct inode___146 * (*alloc_inode)(struct super_block___146 *);
	void (*destroy_inode)(struct inode___146 *);
	void (*dirty_inode)(struct inode___146 *, int);
	int (*write_inode)(struct inode___146 *, struct writeback_control *);
	int (*drop_inode)(struct inode___146 *);
	void (*evict_inode)(struct inode___146 *);
	void (*put_super)(struct super_block___146 *);
	int (*sync_fs)(struct super_block___146 *, int);
	int (*freeze_fs)(struct super_block___146 *);
	int (*unfreeze_fs)(struct super_block___146 *);
	int (*statfs)(struct dentry___146 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___146 *, int *, char *);
	void (*umount_begin)(struct super_block___146 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___146 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___146 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___146 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___146 *);
	ssize_t (*quota_read)(struct super_block___146 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___146 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___146 *);
	int (*bdev_try_to_free_page)(struct super_block___146 *, struct page___145 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___146 *);
	void (*free_cached_objects)(struct super_block___146 *, int);
};

struct proc_ns_operations___13 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___145 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___87 *, void *);
	unsigned int (*inum)(void *);
};

struct key_user {
	struct rb_node node;
	struct mutex___127 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct assoc_array_edit;

struct task_struct___146;

struct pv_cpu_ops___146 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___72 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___72 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___146 *);
	void (*end_context_switch)(struct task_struct___146 *);
};

struct mutex___147 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___146 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___151;

struct cred___4;

struct signal_struct___146;

struct task_struct___146 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___146 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___151 *mm;
	struct mm_struct___151 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___146 *real_parent;
	struct task_struct___146 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___146 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___81 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___146 = 0,
		VTIME_USER___146 = 1,
		VTIME_SYS___146 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___4 *real_cred;
	const struct cred___4 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___72 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___146 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___147 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___141 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___151 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___151 *, struct mm_struct___151 *);
	void (*dup_mmap)(struct mm_struct___151 *, struct mm_struct___151 *);
	void (*exit_mmap)(struct mm_struct___151 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___151 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___151 *);
	void (*pgd_free)(struct mm_struct___151 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___151 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___151 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___151 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___151 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___151 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___151 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___151 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___151 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___151 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___151 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___151 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___147 lock;
	void *vdso;
} mm_context_t___147;

struct vm_area_struct___151;

struct core_state___146;

struct mm_struct___151 {
	struct vm_area_struct___151 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___151 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___151 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___147 context;
	long unsigned int flags;
	struct core_state___146 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___146 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___145 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___146;

struct lruvec___146 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___146 *zone;
};

struct pglist_data___146;

struct zone___146 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___146 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___146 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___146 {
	struct zone___146 *zone;
	int zone_idx;
};

struct zonelist___146 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___146 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___146 {
	struct zone___146 node_zones[4];
	struct zonelist___146 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___146 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___146 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___146 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___4;

struct user_struct___4;

struct cred___4 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___4 *session_keyring;
	struct key___4 *process_keyring;
	struct key___4 *thread_keyring;
	struct key___4 *request_key_auth;
	void *security;
	struct user_struct___4 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_area_struct___151 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___151 *vm_next;
	struct vm_area_struct___151 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___151 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___146 {
	struct task_struct___146 *task;
	struct core_thread___146 *next;
};

struct core_state___146 {
	atomic_t nr_threads;
	struct core_thread___146 dumper;
	struct completion startup;
};

struct user_struct___4 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___4 *uid_keyring;
	struct key___4 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct assoc_array_ops {
	long unsigned int (*get_key_chunk)(const void *, int);
	long unsigned int (*get_object_key_chunk)(const void *, int);
	bool (*compare_object)(const void *, const void *);
	int (*diff_objects)(const void *, const void *);
	void (*free_object)(void *);
};

struct key_type___4;

struct keyring_index_key___4 {
	struct key_type___4 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___4;

typedef int (*request_key_actor_t___4)(struct key_construction___4 *, const char *, void *);

struct seq_file___108;

struct key_type___4 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___4 *, struct key_preparsed_payload *);
	int (*update)(struct key___4 *, struct key_preparsed_payload *);
	int (*match)(const struct key___4 *, const void *);
	void (*revoke)(struct key___4 *);
	void (*destroy)(struct key___4 *);
	void (*describe)(const struct key___4 *, struct seq_file___108 *);
	long int (*read)(const struct key___4 *, char *, size_t);
	request_key_actor_t___4 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___2;

struct key___4 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___2 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___4 index_key;
		struct {
			struct key_type___4 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___2 {
	struct rb_node node;
	struct mutex___147 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct signal_struct___146 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___146 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___146 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___81 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___81 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___147 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___107;

struct seq_file___108 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___147 lock;
	const struct seq_operations___107 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___107 {
	void * (*start)(struct seq_file___108 *, loff_t *);
	void (*stop)(struct seq_file___108 *, void *);
	void * (*next)(struct seq_file___108 *, void *, loff_t *);
	int (*show)(struct seq_file___108 *, void *);
};

struct assoc_array_node {
	struct assoc_array_ptr *back_pointer;
	u8 parent_slot;
	struct assoc_array_ptr *slots[16];
	long unsigned int nr_leaves_on_branch;
};

struct assoc_array_shortcut {
	struct assoc_array_ptr *back_pointer;
	int parent_slot;
	int skip_to_level;
	struct assoc_array_ptr *next_node;
	long unsigned int index_key[0];
};

struct assoc_array_edit___2 {
	struct callback_head rcu;
	struct assoc_array *array;
	const struct assoc_array_ops *ops;
	const struct assoc_array_ops *ops_for_excised_subtree;
	struct assoc_array_ptr *leaf;
	struct assoc_array_ptr **leaf_p;
	struct assoc_array_ptr *dead_leaf;
	struct assoc_array_ptr *new_meta[3];
	struct assoc_array_ptr *excised_meta[1];
	struct assoc_array_ptr *excised_subtree;
	struct assoc_array_ptr **set_backpointers[16];
	struct assoc_array_ptr *set_backpointers_to;
	struct assoc_array_node *adjust_count_on;
	long int adjust_count_by;
	struct {
		struct assoc_array_ptr **ptr;
		struct assoc_array_ptr *to;
	} set[2];
	struct {
		u8 *p;
		u8 to;
	} set_parent_slot[1];
	u8 segment_cache[17];
};

struct key_construction___4 {
	struct key___4 *key;
	struct key___4 *authkey;
};

typedef int (*key_match_func_t)(const struct key___4 *, const void *);

struct keyring_search_context {
	struct keyring_index_key___4 index_key;
	const struct cred___4 *cred;
	key_match_func_t match;
	const void *match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	struct timespec now;
};

struct keyring_read_iterator_context {
	size_t qty;
	size_t count;
	key_serial_t *buffer;
};

struct page___146;

typedef struct page___146 *pgtable_t___146;

struct address_space___147;

struct kmem_cache___133;

struct page___146 {
	long unsigned int flags;
	struct address_space___147 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___146 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___146 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___133 *slab_cache;
		struct page___146 *first_page;
	};
	long: 64;
};

struct thread_struct___73;

struct task_struct___147;

struct pv_cpu_ops___147 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___73 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___73 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___147 *);
	void (*end_context_switch)(struct task_struct___147 *);
};

struct perf_event___73;

struct thread_struct___73 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___73 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___82;

struct pid_link___82 {
	struct hlist_node node;
	struct pid___82 *pid;
};

struct mutex___148 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___147 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___142 {
	struct page___146 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___152;

struct cred___5;

struct nsproxy___88;

struct signal_struct___147;

struct css_set___95;

struct perf_event_context___73;

struct task_struct___147 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___147 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___152 *mm;
	struct mm_struct___152 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___147 *real_parent;
	struct task_struct___147 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___147 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___82 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___147 = 0,
		VTIME_USER___147 = 1,
		VTIME_SYS___147 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___5 *real_cred;
	const struct cred___5 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___73 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___88 *nsproxy;
	struct signal_struct___147 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___95 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___73 *perf_event_ctxp[2];
	struct mutex___148 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___142 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___152 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___152 *, struct mm_struct___152 *);
	void (*dup_mmap)(struct mm_struct___152 *, struct mm_struct___152 *);
	void (*exit_mmap)(struct mm_struct___152 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___152 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___152 *);
	void (*pgd_free)(struct mm_struct___152 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___152 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___152 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___152 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___152 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___152 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___152 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___152 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___152 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___152 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___152 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___152 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___148 lock;
	void *vdso;
} mm_context_t___148;

struct xol_area___146;

struct uprobes_state___146 {
	struct xol_area___146 *xol_area;
};

struct vm_area_struct___152;

struct file___147;

struct core_state___147;

struct mm_struct___152 {
	struct vm_area_struct___152 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___152 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___152 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___148 context;
	long unsigned int flags;
	struct core_state___147 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___147 *owner;
	struct file___147 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___146 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___75;

struct module_kobject___74 {
	struct kobject___11 kobj;
	struct module___75 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___74;

struct ftrace_event_call___63;

struct module___75 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___74 mkobj;
	struct module_attribute___74 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___63 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___147 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___73 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___147 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___147 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___147 *target;
};

typedef void (*perf_overflow_handler_t___73)(struct perf_event___73 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___73;

typedef void (*ftrace_func_t___73)(long unsigned int, long unsigned int, struct ftrace_ops___73 *, struct pt_regs *);

struct ftrace_ops___73 {
	ftrace_func_t___73 func;
	struct ftrace_ops___73 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___148 regex_lock;
};

struct pmu___73;

struct fasync_struct___147;

struct pid_namespace___82;

struct perf_cgroup___73;

struct perf_event___73 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___73 *group_leader;
	struct pmu___73 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___73 hw;
	struct perf_event_context___73 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___148 child_mutex;
	struct list_head child_list;
	struct perf_event___73 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___147 *owner;
	struct mutex___148 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___147 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___73 *);
	struct callback_head callback_head;
	struct pid_namespace___82 *ns;
	u64 id;
	perf_overflow_handler_t___73 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___63 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___73 ftrace_ops;
	struct perf_cgroup___73 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct zone___147;

struct lruvec___147 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___147 *zone;
};

struct pglist_data___147;

struct zone___147 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___147 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___147 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___147 {
	struct zone___147 *zone;
	int zone_idx;
};

struct zonelist___147 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___147 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___147 {
	struct zone___147 node_zones[4];
	struct zonelist___147 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___147 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___103;

struct x86_io_apic_ops___103 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___103 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___103;

struct irq_data___103 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___103 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___114;

struct dev_pm_ops___114 {
	int (*prepare)(struct device___114 *);
	void (*complete)(struct device___114 *);
	int (*suspend)(struct device___114 *);
	int (*resume)(struct device___114 *);
	int (*freeze)(struct device___114 *);
	int (*thaw)(struct device___114 *);
	int (*poweroff)(struct device___114 *);
	int (*restore)(struct device___114 *);
	int (*suspend_late)(struct device___114 *);
	int (*resume_early)(struct device___114 *);
	int (*freeze_late)(struct device___114 *);
	int (*thaw_early)(struct device___114 *);
	int (*poweroff_late)(struct device___114 *);
	int (*restore_early)(struct device___114 *);
	int (*suspend_noirq)(struct device___114 *);
	int (*resume_noirq)(struct device___114 *);
	int (*freeze_noirq)(struct device___114 *);
	int (*thaw_noirq)(struct device___114 *);
	int (*poweroff_noirq)(struct device___114 *);
	int (*restore_noirq)(struct device___114 *);
	int (*runtime_suspend)(struct device___114 *);
	int (*runtime_resume)(struct device___114 *);
	int (*runtime_idle)(struct device___114 *);
};

struct device_type___114;

struct bus_type___114;

struct device_driver___114;

struct dev_pm_domain___114;

struct class___114;

struct attribute_group___107;

struct device_rh___114;

struct device___114 {
	struct device___114 *parent;
	struct device_private *p;
	struct kobject___11 kobj;
	const char *init_name;
	const struct device_type___114 *type;
	struct mutex___148 mutex;
	struct bus_type___114 *bus;
	struct device_driver___114 *driver;
	void *platform_data;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___114 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___38 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___114 *class;
	const struct attribute_group___107 **groups;
	void (*release)(struct device___114 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___114 *device_rh;
};

struct dev_pm_info_rh___114 {
	void (*set_latency_tolerance)(struct device___114 *, s32);
};

struct dev_pm_domain___114 {
	struct dev_pm_ops___114 ops;
};

struct smp_ops___147 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___147 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___88 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___82 *pid_ns;
	struct net *net_ns;
};

struct key___5;

struct user_struct___5;

struct cred___5 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___5 *session_keyring;
	struct key___5 *process_keyring;
	struct key___5 *thread_keyring;
	struct key___5 *request_key_auth;
	void *security;
	struct user_struct___5 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bin_attribute___109;

struct attribute_group___107 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___109 **bin_attrs;
};

struct bin_attribute___109 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___147 *, struct kobject___11 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___147 *, struct kobject___11 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	int (*mmap)(struct file___147 *, struct kobject___11 *, struct bin_attribute___109 *, struct vm_area_struct___152 *);
};

struct dentry___147;

struct path___147 {
	struct vfsmount *mnt;
	struct dentry___147 *dentry;
};

struct fown_struct___82 {
	rwlock_t lock;
	struct pid___82 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___147;

struct file_operations___147;

struct file___147 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___147 f_path;
	struct inode___147 *f_inode;
	const struct file_operations___147 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___82 f_owner;
	const struct cred___5 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___147 *f_mapping;
	struct mutex___148 f_pos_lock;
};

struct vm_operations_struct___128;

struct vm_area_struct___152 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___152 *vm_next;
	struct vm_area_struct___152 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___152 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___128 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___147 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___74 *, struct module_kobject___74 *, char *);
	ssize_t (*store)(struct module_attribute___74 *, struct module_kobject___74 *, const char *, size_t);
	void (*setup)(struct module___75 *, const char *);
	int (*test)(struct module___75 *);
	void (*free)(struct module___75 *);
};

struct trace_event_functions___63;

struct trace_event___63 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___63 *funcs;
};

struct ftrace_event_class___63;

struct ftrace_event_call___63 {
	struct list_head list;
	struct ftrace_event_class___63 *class;
	char *name;
	struct trace_event___63 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct xol_area___146 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___146 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___132;

struct memcg_cache_params___133;

struct kmem_cache___133 {
	struct kmem_cache_cpu___132 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___133 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___147;

struct address_space___147 {
	struct inode___147 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___148 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___147 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___125;

struct vm_operations_struct___128 {
	void (*open)(struct vm_area_struct___152 *);
	void (*close)(struct vm_area_struct___152 *);
	int (*fault)(struct vm_area_struct___152 *, struct vm_fault___125 *);
	int (*page_mkwrite)(struct vm_area_struct___152 *, struct vm_fault___125 *);
	int (*access)(struct vm_area_struct___152 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___152 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___152 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___152 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___152 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___147 {
	struct task_struct___147 *task;
	struct core_thread___147 *next;
};

struct core_state___147 {
	atomic_t nr_threads;
	struct core_thread___147 dumper;
	struct completion startup;
};

struct user_struct___5 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___5 *uid_keyring;
	struct key___5 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct upid___82 {
	int nr;
	struct pid_namespace___82 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___82 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___147 *child_reaper;
	struct kmem_cache___133 *pid_cachep;
	unsigned int level;
	struct pid_namespace___82 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___147 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___82 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___82 numbers[1];
};

struct key_type___5;

struct keyring_index_key___5 {
	struct key_type___5 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___5;

typedef int (*request_key_actor_t___5)(struct key_construction___5 *, const char *, void *);

struct seq_file___109;

struct key_type___5 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___5 *, struct key_preparsed_payload *);
	int (*update)(struct key___5 *, struct key_preparsed_payload *);
	int (*match)(const struct key___5 *, const void *);
	void (*revoke)(struct key___5 *);
	void (*destroy)(struct key___5 *);
	void (*describe)(const struct key___5 *, struct seq_file___109 *);
	long int (*read)(const struct key___5 *, char *, size_t);
	request_key_actor_t___5 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___3;

struct key___5 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___3 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___3 {
	struct rb_node node;
	struct mutex___148 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct signal_struct___147 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___147 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___147 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___82 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___82 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___148 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___95;

struct css_set___95 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___95 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___73 {
	struct pmu___73 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___148 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___147 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___73 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct kmem_cache_cpu___132 {
	void **freelist;
	long unsigned int tid;
	struct page___146 *page;
	struct page___146 *partial;
};

struct memcg_cache_params___133 {
	bool is_root_cache;
	union {
		struct kmem_cache___133 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___133 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct super_block___147;

struct dquot___147 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___148 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___147 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___147;

struct mem_dqinfo___147 {
	struct quota_format_type___147 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___147;

struct quota_info___147 {
	unsigned int flags;
	struct mutex___148 dqio_mutex;
	struct mutex___148 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___147 *files[2];
	struct mem_dqinfo___147 info[2];
	const struct quota_format_ops___147 *ops[2];
};

struct file_system_type___147;

struct super_operations___147;

struct dquot_operations___147;

struct quotactl_ops___147;

struct xattr_handler___95;

struct block_device___147;

struct dentry_operations___147;

struct super_block___147 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___147 *s_type;
	const struct super_operations___147 *s_op;
	const struct dquot_operations___147 *dq_op;
	const struct quotactl_ops___147 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___147 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___95 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___147 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___147 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___148 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___147 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___147 {
	int qf_fmt_id;
	const struct quota_format_ops___147 *qf_ops;
	struct module___75 *qf_owner;
	struct quota_format_type___147 *qf_next;
};

struct quota_format_ops___147 {
	int (*check_quota_file)(struct super_block___147 *, int);
	int (*read_file_info)(struct super_block___147 *, int);
	int (*write_file_info)(struct super_block___147 *, int);
	int (*free_file_info)(struct super_block___147 *, int);
	int (*read_dqblk)(struct dquot___147 *);
	int (*commit_dqblk)(struct dquot___147 *);
	int (*release_dqblk)(struct dquot___147 *);
};

struct dquot_operations___147 {
	int (*write_dquot)(struct dquot___147 *);
	struct dquot___147 * (*alloc_dquot)(struct super_block___147 *, int);
	void (*destroy_dquot)(struct dquot___147 *);
	int (*acquire_dquot)(struct dquot___147 *);
	int (*release_dquot)(struct dquot___147 *);
	int (*mark_dirty)(struct dquot___147 *);
	int (*write_info)(struct super_block___147 *, int);
	qsize_t * (*get_reserved_space)(struct inode___147 *);
};

struct inode_operations___147;

struct file_lock___147;

struct inode___147 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___147 *i_op;
	struct super_block___147 *i_sb;
	struct address_space___147 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___148 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___147 *i_fop;
	struct file_lock___147 *i_flock;
	struct address_space___147 i_data;
	struct dquot___147 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___147 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quotactl_ops___147 {
	int (*quota_on)(struct super_block___147 *, int, int, struct path___147 *);
	int (*quota_on_meta)(struct super_block___147 *, int, int);
	int (*quota_off)(struct super_block___147 *, int);
	int (*quota_sync)(struct super_block___147 *, int);
	int (*get_info)(struct super_block___147 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___147 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___147 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___147 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___147 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___147 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___147 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___147 *, unsigned int);
};

struct vm_fault___125 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___146 *page;
};

struct seq_operations___108;

struct seq_file___109 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___148 lock;
	const struct seq_operations___108 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___108 {
	void * (*start)(struct seq_file___109 *, loff_t *);
	void (*stop)(struct seq_file___109 *, void *);
	void * (*next)(struct seq_file___109 *, void *, loff_t *);
	int (*show)(struct seq_file___109 *, void *);
};

struct dentry___147 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___147 *d_parent;
	struct qstr d_name;
	struct inode___147 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___147 *d_op;
	struct super_block___147 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___147 {
	int (*d_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_hash)(const struct dentry___147 *, struct qstr *);
	int (*d_compare)(const struct dentry___147 *, const struct dentry___147 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___147 *);
	void (*d_release)(struct dentry___147 *);
	void (*d_prune)(struct dentry___147 *);
	void (*d_iput)(struct dentry___147 *, struct inode___147 *);
	char * (*d_dname)(struct dentry___147 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___147 *);
	int (*d_manage)(struct dentry___147 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___147 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___147 *bd_inode;
	struct super_block___147 *bd_super;
	struct mutex___148 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___147 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___148 bd_fsfreeze_mutex;
};

struct cgroup___95;

struct cgroup_subsys_state___95 {
	struct cgroup___95 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___147 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___147 *ia_file;
};

struct address_space_operations___147 {
	int (*writepage)(struct page___146 *, struct writeback_control *);
	int (*readpage)(struct file___147 *, struct page___146 *);
	int (*writepages)(struct address_space___147 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___146 *);
	int (*readpages)(struct file___147 *, struct address_space___147 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___147 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___146 **, void **);
	int (*write_end)(struct file___147 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___146 *, void *);
	sector_t (*bmap)(struct address_space___147 *, sector_t);
	void (*invalidatepage)(struct page___146 *, long unsigned int);
	int (*releasepage)(struct page___146 *, gfp_t);
	void (*freepage)(struct page___146 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___147 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___147 *, struct page___146 *, struct page___146 *, enum migrate_mode);
	int (*launder_page)(struct page___146 *);
	int (*is_partially_uptodate)(struct page___146 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___146 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___147 *, struct page___146 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___147 *, sector_t *);
	void (*swap_deactivate)(struct file___147 *);
	void (*invalidatepage_range)(struct page___146 *, unsigned int, unsigned int);
};

struct inode_operations___147 {
	struct dentry___147 * (*lookup)(struct inode___147 *, struct dentry___147 *, unsigned int);
	void * (*follow_link)(struct dentry___147 *, struct nameidata *);
	int (*permission)(struct inode___147 *, int);
	struct posix_acl * (*get_acl)(struct inode___147 *, int);
	int (*readlink)(struct dentry___147 *, char *, int);
	void (*put_link)(struct dentry___147 *, struct nameidata *, void *);
	int (*create)(struct inode___147 *, struct dentry___147 *, umode_t, bool);
	int (*link)(struct dentry___147 *, struct inode___147 *, struct dentry___147 *);
	int (*unlink)(struct inode___147 *, struct dentry___147 *);
	int (*symlink)(struct inode___147 *, struct dentry___147 *, const char *);
	int (*mkdir)(struct inode___147 *, struct dentry___147 *, umode_t);
	int (*rmdir)(struct inode___147 *, struct dentry___147 *);
	int (*mknod)(struct inode___147 *, struct dentry___147 *, umode_t, dev_t);
	int (*rename)(struct inode___147 *, struct dentry___147 *, struct inode___147 *, struct dentry___147 *);
	int (*setattr)(struct dentry___147 *, struct iattr___147 *);
	int (*getattr)(struct vfsmount *, struct dentry___147 *, struct kstat *);
	int (*setxattr)(struct dentry___147 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___147 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___147 *, char *, size_t);
	int (*removexattr)(struct dentry___147 *, const char *);
	int (*fiemap)(struct inode___147 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___147 *, struct timespec *, int);
	int (*atomic_open)(struct inode___147 *, struct dentry___147 *, struct file___147 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___90;

struct file_operations___147 {
	struct module___75 *owner;
	loff_t (*llseek)(struct file___147 *, loff_t, int);
	ssize_t (*read)(struct file___147 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___147 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___147 *, void *, filldir_t);
	unsigned int (*poll)(struct file___147 *, struct poll_table_struct___90 *);
	long int (*unlocked_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___147 *, struct vm_area_struct___152 *);
	int (*open)(struct inode___147 *, struct file___147 *);
	int (*flush)(struct file___147 *, fl_owner_t);
	int (*release)(struct inode___147 *, struct file___147 *);
	int (*fsync)(struct file___147 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___147 *, int);
	int (*lock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*sendpage)(struct file___147 *, struct page___146 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___147 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___147 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___147 *, long int, struct file_lock___147 **, void **);
		struct {
			int (*setlease)(struct file___147 *, long int, struct file_lock___147 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___147 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___109 *, struct file___147 *);
};

struct file_lock_operations___147;

struct lock_manager_operations___147;

struct file_lock___147 {
	struct file_lock___147 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___82 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___147 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___147 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___147 *fl_ops;
	const struct lock_manager_operations___147 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___147 {
	void (*fl_copy_lock)(struct file_lock___147 *, struct file_lock___147 *);
	void (*fl_release_private)(struct file_lock___147 *);
};

struct lock_manager_operations___147 {
	int (*lm_compare_owner)(struct file_lock___147 *, struct file_lock___147 *);
	long unsigned int (*lm_owner_key)(struct file_lock___147 *);
	void (*lm_notify)(struct file_lock___147 *);
	int (*lm_grant)(struct file_lock___147 *, struct file_lock___147 *, int);
	void (*lm_break)(struct file_lock___147 *);
	int (*lm_change)(struct file_lock___147 **, int);
};

struct fasync_struct___147 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___147 *fa_next;
	struct file___147 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___147 {
	const char *name;
	int fs_flags;
	struct dentry___147 * (*mount)(struct file_system_type___147 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___147 *);
	struct module___75 *owner;
	struct file_system_type___147 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___147 {
	struct inode___147 * (*alloc_inode)(struct super_block___147 *);
	void (*destroy_inode)(struct inode___147 *);
	void (*dirty_inode)(struct inode___147 *, int);
	int (*write_inode)(struct inode___147 *, struct writeback_control *);
	int (*drop_inode)(struct inode___147 *);
	void (*evict_inode)(struct inode___147 *);
	void (*put_super)(struct super_block___147 *);
	int (*sync_fs)(struct super_block___147 *, int);
	int (*freeze_fs)(struct super_block___147 *);
	int (*unfreeze_fs)(struct super_block___147 *);
	int (*statfs)(struct dentry___147 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___147 *, int *, char *);
	void (*umount_begin)(struct super_block___147 *);
	int (*show_options)(struct seq_file___109 *, struct dentry___147 *);
	int (*show_devname)(struct seq_file___109 *, struct dentry___147 *);
	int (*show_path)(struct seq_file___109 *, struct dentry___147 *);
	int (*show_stats)(struct seq_file___109 *, struct dentry___147 *);
	ssize_t (*quota_read)(struct super_block___147 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___147 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___147 *);
	int (*bdev_try_to_free_page)(struct super_block___147 *, struct page___146 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___147 *);
	void (*free_cached_objects)(struct super_block___147 *, int);
};

struct xattr_handler___95 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___147 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___147 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___147 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___92)(struct file___147 *, wait_queue_head_t *, struct poll_table_struct___90 *);

struct poll_table_struct___90 {
	poll_queue_proc___92 _qproc;
	long unsigned int _key;
};

struct irq_chip___103 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___103 *);
	void (*irq_shutdown)(struct irq_data___103 *);
	void (*irq_enable)(struct irq_data___103 *);
	void (*irq_disable)(struct irq_data___103 *);
	void (*irq_ack)(struct irq_data___103 *);
	void (*irq_mask)(struct irq_data___103 *);
	void (*irq_mask_ack)(struct irq_data___103 *);
	void (*irq_unmask)(struct irq_data___103 *);
	void (*irq_eoi)(struct irq_data___103 *);
	int (*irq_set_affinity)(struct irq_data___103 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___103 *);
	int (*irq_set_type)(struct irq_data___103 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___103 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___103 *);
	void (*irq_bus_sync_unlock)(struct irq_data___103 *);
	void (*irq_cpu_online)(struct irq_data___103 *);
	void (*irq_cpu_offline)(struct irq_data___103 *);
	void (*irq_suspend)(struct irq_data___103 *);
	void (*irq_resume)(struct irq_data___103 *);
	void (*irq_pm_shutdown)(struct irq_data___103 *);
	void (*irq_print_chip)(struct irq_data___103 *, struct seq_file___109 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___103 *, void *);
	long unsigned int flags;
};

struct bus_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___114 *, char *);
	ssize_t (*store)(struct bus_type___114 *, const char *, size_t);
};

struct device_attribute___114;

struct driver_attribute___114;

struct bus_type___114 {
	const char *name;
	const char *dev_name;
	struct device___114 *dev_root;
	struct bus_attribute___114 *bus_attrs;
	struct device_attribute___114 *dev_attrs;
	struct driver_attribute___114 *drv_attrs;
	const struct attribute_group___107 **bus_groups;
	const struct attribute_group___107 **dev_groups;
	const struct attribute_group___107 **drv_groups;
	int (*match)(struct device___114 *, struct device_driver___114 *);
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	int (*probe)(struct device___114 *);
	int (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*online)(struct device___114 *);
	int (*offline)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct device___114 *, struct device_attribute___114 *, char *);
	ssize_t (*store)(struct device___114 *, struct device_attribute___114 *, const char *, size_t);
};

struct driver_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___114 *, char *);
	ssize_t (*store)(struct device_driver___114 *, const char *, size_t);
};

struct device_driver___114 {
	const char *name;
	struct bus_type___114 *bus;
	struct module___75 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___114 *);
	int (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	const struct attribute_group___107 **groups;
	const struct dev_pm_ops___114 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___114 {
	const char *name;
	const struct attribute_group___107 **groups;
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
};

struct class_attribute___114;

struct class___114 {
	const char *name;
	struct module___75 *owner;
	struct class_attribute___114 *class_attrs;
	struct device_attribute___114 *dev_attrs;
	const struct attribute_group___107 **dev_groups;
	struct bin_attribute___109 *dev_bin_attrs;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *);
	void (*class_release)(struct class___114 *);
	void (*dev_release)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
	struct subsys_private *p;
};

struct class_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct class___114 *, struct class_attribute___114 *, char *);
	ssize_t (*store)(struct class___114 *, struct class_attribute___114 *, const char *, size_t);
	const void * (*namespace)(struct class___114 *, const struct class_attribute___114 *);
};

struct device_rh___114 {
	struct dev_pm_info_rh___114 power;
};

struct cgroupfs_root___95;

struct cgroup___95 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___95 *parent;
	struct dentry___147 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___95 *subsys[11];
	struct cgroupfs_root___95 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___148 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___95 {
	struct super_block___147 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___95 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___73;

struct pmu___73 {
	struct list_head entry;
	struct device___114 *dev;
	const struct attribute_group___107 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___73 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___73 *);
	void (*pmu_disable)(struct pmu___73 *);
	int (*event_init)(struct perf_event___73 *);
	int (*add)(struct perf_event___73 *, int);
	void (*del)(struct perf_event___73 *, int);
	void (*start)(struct perf_event___73 *, int);
	void (*stop)(struct perf_event___73 *, int);
	void (*read)(struct perf_event___73 *);
	void (*start_txn)(struct pmu___73 *);
	int (*commit_txn)(struct pmu___73 *);
	void (*cancel_txn)(struct pmu___73 *);
	int (*event_idx)(struct perf_event___73 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___75 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___73 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___73 *);
};

struct perf_cpu_context___73 {
	struct perf_event_context___73 ctx;
	struct perf_event_context___73 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___73 *unique_pmu;
	struct perf_cgroup___73 *cgrp;
};

struct perf_cgroup___73 {
	struct cgroup_subsys_state___95 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___63 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___148 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___63)(struct trace_iterator___63 *, int, struct trace_event___63 *);

struct trace_event_functions___63 {
	trace_print_func___63 trace;
	trace_print_func___63 raw;
	trace_print_func___63 hex;
	trace_print_func___63 binary;
};

struct ftrace_event_class___63 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___63 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___63 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___63 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___63 *);
};

struct syscall_metadata___32 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___63 *enter_event;
	struct ftrace_event_call___63 *exit_event;
};

struct key_construction___5 {
	struct key___5 *key;
	struct key___5 *authkey;
};

struct request_key_auth {
	struct key___5 *target_key;
	struct key___5 *dest_keyring;
	const struct cred___5 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
};

struct page___147;

typedef struct page___147 *pgtable_t___147;

struct address_space___148;

struct kmem_cache___134;

struct page___147 {
	long unsigned int flags;
	struct address_space___148 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___147 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___147 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___134 *slab_cache;
		struct page___147 *first_page;
	};
	long: 64;
};

struct task_struct___148;

struct pv_cpu_ops___148 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___73 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___73 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___148 *);
	void (*end_context_switch)(struct task_struct___148 *);
};

struct mutex___149 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___148 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___143 {
	struct page___147 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___153;

struct cred___6;

struct signal_struct___148;

struct task_struct___148 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___148 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___153 *mm;
	struct mm_struct___153 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___148 *real_parent;
	struct task_struct___148 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___148 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___82 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___148 = 0,
		VTIME_USER___148 = 1,
		VTIME_SYS___148 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___6 *real_cred;
	const struct cred___6 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___73 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___88 *nsproxy;
	struct signal_struct___148 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___149 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___143 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___153 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___153 *, struct mm_struct___153 *);
	void (*dup_mmap)(struct mm_struct___153 *, struct mm_struct___153 *);
	void (*exit_mmap)(struct mm_struct___153 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___153 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___153 *);
	void (*pgd_free)(struct mm_struct___153 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___153 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___153 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___153 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___153 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___153 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___153 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___153 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___153 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___153 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___153 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___153 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___149 lock;
	void *vdso;
} mm_context_t___149;

struct xol_area___147;

struct uprobes_state___147 {
	struct xol_area___147 *xol_area;
};

struct vm_area_struct___153;

struct file___148;

struct core_state___148;

struct mm_struct___153 {
	struct vm_area_struct___153 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___153 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___153 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___149 context;
	long unsigned int flags;
	struct core_state___148 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___148 *owner;
	struct file___148 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___147 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___76;

struct module_kobject___75 {
	struct kobject___11 kobj;
	struct module___76 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___75;

struct module___76 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___75 mkobj;
	struct module_attribute___75 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___148 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___148;

struct lruvec___148 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___148 *zone;
};

struct pglist_data___148;

struct zone___148 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___148 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___148 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___148 {
	struct zone___148 *zone;
	int zone_idx;
};

struct zonelist___148 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___148 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___148 {
	struct zone___148 node_zones[4];
	struct zonelist___148 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___148 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___148 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___148 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___6;

struct user_struct___6;

struct user_namespace___3;

struct cred___6 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___6 *session_keyring;
	struct key___6 *process_keyring;
	struct key___6 *thread_keyring;
	struct key___6 *request_key_auth;
	void *security;
	struct user_struct___6 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct dentry___148;

struct path___148 {
	struct vfsmount *mnt;
	struct dentry___148 *dentry;
};

struct inode___148;

struct file_operations___148;

struct file___148 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___148 f_path;
	struct inode___148 *f_inode;
	const struct file_operations___148 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___82 f_owner;
	const struct cred___6 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___148 *f_mapping;
	struct mutex___149 f_pos_lock;
};

struct vm_area_struct___153 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___153 *vm_next;
	struct vm_area_struct___153 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___153 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___148 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___75 *, struct module_kobject___75 *, char *);
	ssize_t (*store)(struct module_attribute___75 *, struct module_kobject___75 *, const char *, size_t);
	void (*setup)(struct module___76 *, const char *);
	int (*test)(struct module___76 *);
	void (*free)(struct module___76 *);
};

struct xol_area___147 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___147 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___133;

struct memcg_cache_params___134;

struct kmem_cache___134 {
	struct kmem_cache_cpu___133 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___134 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___148;

struct address_space___148 {
	struct inode___148 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___149 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___148 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct core_thread___148 {
	struct task_struct___148 *task;
	struct core_thread___148 *next;
};

struct core_state___148 {
	atomic_t nr_threads;
	struct core_thread___148 dumper;
	struct completion startup;
};

struct user_struct___6 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___6 *uid_keyring;
	struct key___6 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct key_type___6;

struct keyring_index_key___6 {
	struct key_type___6 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___6;

typedef int (*request_key_actor_t___6)(struct key_construction___6 *, const char *, void *);

struct key_type___6 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___6 *, struct key_preparsed_payload *);
	int (*update)(struct key___6 *, struct key_preparsed_payload *);
	int (*match)(const struct key___6 *, const void *);
	void (*revoke)(struct key___6 *);
	void (*destroy)(struct key___6 *);
	void (*describe)(const struct key___6 *, struct seq_file___5 *);
	long int (*read)(const struct key___6 *, char *, size_t);
	request_key_actor_t___6 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___4;

struct key___6 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___4 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___4 {
	struct rb_node node;
	struct mutex___149 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct user_namespace___3 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___3 *parent;
	kuid_t owner;
	kgid_t group;
	unsigned int proc_inum;
	bool may_mount_sysfs;
	bool may_mount_proc;
	struct key___6 *persistent_keyring_register;
	struct rw_semaphore persistent_keyring_register_sem;
	int level;
	long unsigned int flags;
};

struct signal_struct___148 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___148 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___148 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___82 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___82 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___149 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___148;

struct super_block___148;

struct dentry___148 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___148 *d_parent;
	struct qstr d_name;
	struct inode___148 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___148 *d_op;
	struct super_block___148 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___148;

struct file_lock___148;

struct dquot___148;

struct block_device___148;

struct inode___148 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___148 *i_op;
	struct super_block___148 *i_sb;
	struct address_space___148 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___149 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___148 *i_fop;
	struct file_lock___148 *i_flock;
	struct address_space___148 i_data;
	struct dquot___148 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___148 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___148 {
	int (*d_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_hash)(const struct dentry___148 *, struct qstr *);
	int (*d_compare)(const struct dentry___148 *, const struct dentry___148 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___148 *);
	void (*d_release)(struct dentry___148 *);
	void (*d_prune)(struct dentry___148 *);
	void (*d_iput)(struct dentry___148 *, struct inode___148 *);
	char * (*d_dname)(struct dentry___148 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___148 *);
	int (*d_manage)(struct dentry___148 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___148;

struct mem_dqinfo___148 {
	struct quota_format_type___148 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___148;

struct quota_info___148 {
	unsigned int flags;
	struct mutex___149 dqio_mutex;
	struct mutex___149 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___148 *files[2];
	struct mem_dqinfo___148 info[2];
	const struct quota_format_ops___148 *ops[2];
};

struct file_system_type___148;

struct super_operations___148;

struct dquot_operations___148;

struct quotactl_ops___148;

struct super_block___148 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___148 *s_type;
	const struct super_operations___148 *s_op;
	const struct dquot_operations___148 *dq_op;
	const struct quotactl_ops___148 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___148 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___148 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___148 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___149 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___148 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___148 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___148 *bd_inode;
	struct super_block___148 *bd_super;
	struct mutex___149 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___148 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___149 bd_fsfreeze_mutex;
};

struct iattr___148 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___148 *ia_file;
};

struct dquot___148 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___149 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___148 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___148 {
	int qf_fmt_id;
	const struct quota_format_ops___148 *qf_ops;
	struct module___76 *qf_owner;
	struct quota_format_type___148 *qf_next;
};

struct quota_format_ops___148 {
	int (*check_quota_file)(struct super_block___148 *, int);
	int (*read_file_info)(struct super_block___148 *, int);
	int (*write_file_info)(struct super_block___148 *, int);
	int (*free_file_info)(struct super_block___148 *, int);
	int (*read_dqblk)(struct dquot___148 *);
	int (*commit_dqblk)(struct dquot___148 *);
	int (*release_dqblk)(struct dquot___148 *);
};

struct dquot_operations___148 {
	int (*write_dquot)(struct dquot___148 *);
	struct dquot___148 * (*alloc_dquot)(struct super_block___148 *, int);
	void (*destroy_dquot)(struct dquot___148 *);
	int (*acquire_dquot)(struct dquot___148 *);
	int (*release_dquot)(struct dquot___148 *);
	int (*mark_dirty)(struct dquot___148 *);
	int (*write_info)(struct super_block___148 *, int);
	qsize_t * (*get_reserved_space)(struct inode___148 *);
};

struct quotactl_ops___148 {
	int (*quota_on)(struct super_block___148 *, int, int, struct path___148 *);
	int (*quota_on_meta)(struct super_block___148 *, int, int);
	int (*quota_off)(struct super_block___148 *, int);
	int (*quota_sync)(struct super_block___148 *, int);
	int (*get_info)(struct super_block___148 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___148 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___148 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___148 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___148 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___148 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___148 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___148 *, unsigned int);
};

struct address_space_operations___148 {
	int (*writepage)(struct page___147 *, struct writeback_control *);
	int (*readpage)(struct file___148 *, struct page___147 *);
	int (*writepages)(struct address_space___148 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___147 *);
	int (*readpages)(struct file___148 *, struct address_space___148 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___148 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___147 **, void **);
	int (*write_end)(struct file___148 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___147 *, void *);
	sector_t (*bmap)(struct address_space___148 *, sector_t);
	void (*invalidatepage)(struct page___147 *, long unsigned int);
	int (*releasepage)(struct page___147 *, gfp_t);
	void (*freepage)(struct page___147 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___148 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___148 *, struct page___147 *, struct page___147 *, enum migrate_mode);
	int (*launder_page)(struct page___147 *);
	int (*is_partially_uptodate)(struct page___147 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___147 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___148 *, struct page___147 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___148 *, sector_t *);
	void (*swap_deactivate)(struct file___148 *);
	void (*invalidatepage_range)(struct page___147 *, unsigned int, unsigned int);
};

struct inode_operations___148 {
	struct dentry___148 * (*lookup)(struct inode___148 *, struct dentry___148 *, unsigned int);
	void * (*follow_link)(struct dentry___148 *, struct nameidata *);
	int (*permission)(struct inode___148 *, int);
	struct posix_acl * (*get_acl)(struct inode___148 *, int);
	int (*readlink)(struct dentry___148 *, char *, int);
	void (*put_link)(struct dentry___148 *, struct nameidata *, void *);
	int (*create)(struct inode___148 *, struct dentry___148 *, umode_t, bool);
	int (*link)(struct dentry___148 *, struct inode___148 *, struct dentry___148 *);
	int (*unlink)(struct inode___148 *, struct dentry___148 *);
	int (*symlink)(struct inode___148 *, struct dentry___148 *, const char *);
	int (*mkdir)(struct inode___148 *, struct dentry___148 *, umode_t);
	int (*rmdir)(struct inode___148 *, struct dentry___148 *);
	int (*mknod)(struct inode___148 *, struct dentry___148 *, umode_t, dev_t);
	int (*rename)(struct inode___148 *, struct dentry___148 *, struct inode___148 *, struct dentry___148 *);
	int (*setattr)(struct dentry___148 *, struct iattr___148 *);
	int (*getattr)(struct vfsmount *, struct dentry___148 *, struct kstat *);
	int (*setxattr)(struct dentry___148 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___148 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___148 *, char *, size_t);
	int (*removexattr)(struct dentry___148 *, const char *);
	int (*fiemap)(struct inode___148 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___148 *, struct timespec *, int);
	int (*atomic_open)(struct inode___148 *, struct dentry___148 *, struct file___148 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___148 {
	struct module___76 *owner;
	loff_t (*llseek)(struct file___148 *, loff_t, int);
	ssize_t (*read)(struct file___148 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___148 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___148 *, void *, filldir_t);
	unsigned int (*poll)(struct file___148 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___148 *, struct vm_area_struct___153 *);
	int (*open)(struct inode___148 *, struct file___148 *);
	int (*flush)(struct file___148 *, fl_owner_t);
	int (*release)(struct inode___148 *, struct file___148 *);
	int (*fsync)(struct file___148 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___148 *, int);
	int (*lock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*sendpage)(struct file___148 *, struct page___147 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___148 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___148 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___148 *, long int, struct file_lock___148 **, void **);
		struct {
			int (*setlease)(struct file___148 *, long int, struct file_lock___148 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___148 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___148 *);
};

struct fasync_struct___148;

struct file_lock_operations___148;

struct lock_manager_operations___148;

struct file_lock___148 {
	struct file_lock___148 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___82 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___148 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___148 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___148 *fl_ops;
	const struct lock_manager_operations___148 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___148 {
	void (*fl_copy_lock)(struct file_lock___148 *, struct file_lock___148 *);
	void (*fl_release_private)(struct file_lock___148 *);
};

struct lock_manager_operations___148 {
	int (*lm_compare_owner)(struct file_lock___148 *, struct file_lock___148 *);
	long unsigned int (*lm_owner_key)(struct file_lock___148 *);
	void (*lm_notify)(struct file_lock___148 *);
	int (*lm_grant)(struct file_lock___148 *, struct file_lock___148 *, int);
	void (*lm_break)(struct file_lock___148 *);
	int (*lm_change)(struct file_lock___148 **, int);
};

struct fasync_struct___148 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___148 *fa_next;
	struct file___148 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___148 {
	const char *name;
	int fs_flags;
	struct dentry___148 * (*mount)(struct file_system_type___148 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___148 *);
	struct module___76 *owner;
	struct file_system_type___148 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___148 {
	struct inode___148 * (*alloc_inode)(struct super_block___148 *);
	void (*destroy_inode)(struct inode___148 *);
	void (*dirty_inode)(struct inode___148 *, int);
	int (*write_inode)(struct inode___148 *, struct writeback_control *);
	int (*drop_inode)(struct inode___148 *);
	void (*evict_inode)(struct inode___148 *);
	void (*put_super)(struct super_block___148 *);
	int (*sync_fs)(struct super_block___148 *, int);
	int (*freeze_fs)(struct super_block___148 *);
	int (*unfreeze_fs)(struct super_block___148 *);
	int (*statfs)(struct dentry___148 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___148 *, int *, char *);
	void (*umount_begin)(struct super_block___148 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___148 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___148 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___148 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___148 *);
	ssize_t (*quota_read)(struct super_block___148 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___148 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___148 *);
	int (*bdev_try_to_free_page)(struct super_block___148 *, struct page___147 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___148 *);
	void (*free_cached_objects)(struct super_block___148 *, int);
};

struct kmem_cache_cpu___133 {
	void **freelist;
	long unsigned int tid;
	struct page___147 *page;
	struct page___147 *partial;
};

struct memcg_cache_params___134 {
	bool is_root_cache;
	union {
		struct kmem_cache___134 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___134 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct key_construction___6 {
	struct key___6 *key;
	struct key___6 *authkey;
};

typedef int (*key_match_func_t___2)(const struct key___6 *, const void *);

struct keyring_search_context___2 {
	struct keyring_index_key___6 index_key;
	const struct cred___6 *cred;
	key_match_func_t___2 match;
	const void *match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	struct timespec now;
};

struct request_key_auth___2 {
	struct key___6 *target_key;
	struct key___6 *dest_keyring;
	const struct cred___6 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
};

typedef int (*key_match_func_t___3)(const struct key___5 *, const void *);

struct user_key_payload {
	struct callback_head rcu;
	short unsigned int datalen;
	char data[0];
};

struct page___148;

typedef struct page___148 *pgtable_t___148;

struct address_space___149;

struct kmem_cache___135;

struct page___148 {
	long unsigned int flags;
	struct address_space___149 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___148 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___148 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___135 *slab_cache;
		struct page___148 *first_page;
	};
	long: 64;
};

struct thread_struct___74;

struct task_struct___149;

struct pv_cpu_ops___149 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___149 *);
	void (*end_context_switch)(struct task_struct___149 *);
};

struct perf_event___74;

struct thread_struct___74 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___74 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___83;

struct pid_link___83 {
	struct hlist_node node;
	struct pid___83 *pid;
};

struct mutex___150 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___149 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___144 {
	struct page___148 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___154;

struct cred___7;

struct nsproxy___89;

struct signal_struct___149;

struct css_set___96;

struct perf_event_context___74;

struct task_struct___149 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___149 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___154 *mm;
	struct mm_struct___154 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___149 *real_parent;
	struct task_struct___149 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___149 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___149 = 0,
		VTIME_USER___149 = 1,
		VTIME_SYS___149 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___7 *real_cred;
	const struct cred___7 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___89 *nsproxy;
	struct signal_struct___149 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___96 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___74 *perf_event_ctxp[2];
	struct mutex___150 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___144 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___154 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___154 *, struct mm_struct___154 *);
	void (*dup_mmap)(struct mm_struct___154 *, struct mm_struct___154 *);
	void (*exit_mmap)(struct mm_struct___154 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___154 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___154 *);
	void (*pgd_free)(struct mm_struct___154 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___154 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___154 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___154 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___154 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___154 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___154 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___154 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___154 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___154 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___154 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___154 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___150 lock;
	void *vdso;
} mm_context_t___150;

struct xol_area___148;

struct uprobes_state___148 {
	struct xol_area___148 *xol_area;
};

struct vm_area_struct___154;

struct file___149;

struct core_state___149;

struct mm_struct___154 {
	struct vm_area_struct___154 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___154 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___154 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___150 context;
	long unsigned int flags;
	struct core_state___149 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___149 *owner;
	struct file___149 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___148 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___74 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___149 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___149 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___149 *target;
};

typedef void (*perf_overflow_handler_t___74)(struct perf_event___74 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___74;

typedef void (*ftrace_func_t___74)(long unsigned int, long unsigned int, struct ftrace_ops___74 *, struct pt_regs *);

struct ftrace_ops___74 {
	ftrace_func_t___74 func;
	struct ftrace_ops___74 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___150 regex_lock;
};

struct pmu___74;

struct fasync_struct___149;

struct pid_namespace___83;

struct ftrace_event_call___64;

struct perf_cgroup___74;

struct perf_event___74 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___74 *group_leader;
	struct pmu___74 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___74 hw;
	struct perf_event_context___74 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___150 child_mutex;
	struct list_head child_list;
	struct perf_event___74 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___149 *owner;
	struct mutex___150 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___149 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___74 *);
	struct callback_head callback_head;
	struct pid_namespace___83 *ns;
	u64 id;
	perf_overflow_handler_t___74 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___64 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___74 ftrace_ops;
	struct perf_cgroup___74 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct key___7;

struct user_struct___7 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___7 *uid_keyring;
	struct key___7 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct irq_data___104;

struct x86_io_apic_ops___104 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___104 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___104;

struct irq_data___104 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___104 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___115;

struct dev_pm_ops___115 {
	int (*prepare)(struct device___115 *);
	void (*complete)(struct device___115 *);
	int (*suspend)(struct device___115 *);
	int (*resume)(struct device___115 *);
	int (*freeze)(struct device___115 *);
	int (*thaw)(struct device___115 *);
	int (*poweroff)(struct device___115 *);
	int (*restore)(struct device___115 *);
	int (*suspend_late)(struct device___115 *);
	int (*resume_early)(struct device___115 *);
	int (*freeze_late)(struct device___115 *);
	int (*thaw_early)(struct device___115 *);
	int (*poweroff_late)(struct device___115 *);
	int (*restore_early)(struct device___115 *);
	int (*suspend_noirq)(struct device___115 *);
	int (*resume_noirq)(struct device___115 *);
	int (*freeze_noirq)(struct device___115 *);
	int (*thaw_noirq)(struct device___115 *);
	int (*poweroff_noirq)(struct device___115 *);
	int (*restore_noirq)(struct device___115 *);
	int (*runtime_suspend)(struct device___115 *);
	int (*runtime_resume)(struct device___115 *);
	int (*runtime_idle)(struct device___115 *);
};

struct device_type___115;

struct bus_type___115;

struct device_driver___115;

struct dev_pm_domain___115;

struct class___115;

struct attribute_group___108;

struct device_rh___115;

struct device___115 {
	struct device___115 *parent;
	struct device_private *p;
	struct kobject___11 kobj;
	const char *init_name;
	const struct device_type___115 *type;
	struct mutex___150 mutex;
	struct bus_type___115 *bus;
	struct device_driver___115 *driver;
	void *platform_data;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___115 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___38 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___115 *class;
	const struct attribute_group___108 **groups;
	void (*release)(struct device___115 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___115 *device_rh;
};

struct dev_pm_info_rh___115 {
	void (*set_latency_tolerance)(struct device___115 *, s32);
};

struct dev_pm_domain___115 {
	struct dev_pm_ops___115 ops;
};

struct smp_ops___149 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___149 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___149;

struct lruvec___149 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___149 *zone;
};

struct pglist_data___149;

struct zone___149 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___149 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___149 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___149 {
	struct zone___149 *zone;
	int zone_idx;
};

struct zonelist___149 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___149 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___149 {
	struct zone___149 node_zones[4];
	struct zonelist___149 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___149 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___149;

struct dquot___149 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___150 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___149 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___149;

struct mem_dqinfo___149 {
	struct quota_format_type___149 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___149;

struct quota_format_ops___149;

struct quota_info___149 {
	unsigned int flags;
	struct mutex___150 dqio_mutex;
	struct mutex___150 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___149 *files[2];
	struct mem_dqinfo___149 info[2];
	const struct quota_format_ops___149 *ops[2];
};

struct file_system_type___149;

struct super_operations___149;

struct dquot_operations___149;

struct quotactl_ops___149;

struct dentry___149;

struct xattr_handler___96;

struct block_device___149;

struct dentry_operations___149;

struct super_block___149 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___149 *s_type;
	const struct super_operations___149 *s_op;
	const struct dquot_operations___149 *dq_op;
	const struct quotactl_ops___149 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___149 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___96 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___149 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___149 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___150 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___149 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___149 {
	int qf_fmt_id;
	const struct quota_format_ops___149 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___149 *qf_next;
};

struct quota_format_ops___149 {
	int (*check_quota_file)(struct super_block___149 *, int);
	int (*read_file_info)(struct super_block___149 *, int);
	int (*write_file_info)(struct super_block___149 *, int);
	int (*free_file_info)(struct super_block___149 *, int);
	int (*read_dqblk)(struct dquot___149 *);
	int (*commit_dqblk)(struct dquot___149 *);
	int (*release_dqblk)(struct dquot___149 *);
};

struct dquot_operations___149 {
	int (*write_dquot)(struct dquot___149 *);
	struct dquot___149 * (*alloc_dquot)(struct super_block___149 *, int);
	void (*destroy_dquot)(struct dquot___149 *);
	int (*acquire_dquot)(struct dquot___149 *);
	int (*release_dquot)(struct dquot___149 *);
	int (*mark_dirty)(struct dquot___149 *);
	int (*write_info)(struct super_block___149 *, int);
	qsize_t * (*get_reserved_space)(struct inode___149 *);
};

struct address_space_operations___149;

struct address_space___149 {
	struct inode___149 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___150 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___149 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___149;

struct file_operations___149;

struct file_lock___149;

struct inode___149 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___149 *i_op;
	struct super_block___149 *i_sb;
	struct address_space___149 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___150 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___149 *i_fop;
	struct file_lock___149 *i_flock;
	struct address_space___149 i_data;
	struct dquot___149 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___149 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___149;

struct quotactl_ops___149 {
	int (*quota_on)(struct super_block___149 *, int, int, struct path___149 *);
	int (*quota_on_meta)(struct super_block___149 *, int, int);
	int (*quota_off)(struct super_block___149 *, int);
	int (*quota_sync)(struct super_block___149 *, int);
	int (*get_info)(struct super_block___149 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___149 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___149 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___149 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___149 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___149 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___149 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___149 *, unsigned int);
};

struct path___149 {
	struct vfsmount *mnt;
	struct dentry___149 *dentry;
};

struct nsproxy___89 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___83 *pid_ns;
	struct net *net_ns;
};

struct key_type___7;

struct keyring_index_key___7 {
	struct key_type___7 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___7;

typedef int (*request_key_actor_t___7)(struct key_construction___7 *, const char *, void *);

struct seq_file___110;

struct key_type___7 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___7 *, struct key_preparsed_payload *);
	int (*update)(struct key___7 *, struct key_preparsed_payload *);
	int (*match)(const struct key___7 *, const void *);
	void (*revoke)(struct key___7 *);
	void (*destroy)(struct key___7 *);
	void (*describe)(const struct key___7 *, struct seq_file___110 *);
	long int (*read)(const struct key___7 *, char *, size_t);
	request_key_actor_t___7 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___5;

struct key___7 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___5 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___7 index_key;
		struct {
			struct key_type___7 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___5 {
	struct rb_node node;
	struct mutex___150 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct xol_area___148 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___148 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___134;

struct memcg_cache_params___135;

struct kmem_cache___135 {
	struct kmem_cache_cpu___134 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___135 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___83 {
	rwlock_t lock;
	struct pid___83 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___149 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___149 f_path;
	struct inode___149 *f_inode;
	const struct file_operations___149 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___7 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___149 *f_mapping;
	struct mutex___150 f_pos_lock;
};

struct vm_operations_struct___129;

struct vm_area_struct___154 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___154 *vm_next;
	struct vm_area_struct___154 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___154 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___129 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___149 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___126;

struct vm_operations_struct___129 {
	void (*open)(struct vm_area_struct___154 *);
	void (*close)(struct vm_area_struct___154 *);
	int (*fault)(struct vm_area_struct___154 *, struct vm_fault___126 *);
	int (*page_mkwrite)(struct vm_area_struct___154 *, struct vm_fault___126 *);
	int (*access)(struct vm_area_struct___154 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___154 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___154 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___154 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___154 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___149 {
	struct task_struct___149 *task;
	struct core_thread___149 *next;
};

struct core_state___149 {
	atomic_t nr_threads;
	struct core_thread___149 dumper;
	struct completion startup;
};

struct vm_fault___126 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___148 *page;
};

struct seq_operations___109;

struct seq_file___110 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___150 lock;
	const struct seq_operations___109 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___109 {
	void * (*start)(struct seq_file___110 *, loff_t *);
	void (*stop)(struct seq_file___110 *, void *);
	void * (*next)(struct seq_file___110 *, void *, loff_t *);
	int (*show)(struct seq_file___110 *, void *);
};

struct dentry___149 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___149 *d_parent;
	struct qstr d_name;
	struct inode___149 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___149 *d_op;
	struct super_block___149 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___149 {
	int (*d_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_hash)(const struct dentry___149 *, struct qstr *);
	int (*d_compare)(const struct dentry___149 *, const struct dentry___149 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___149 *);
	void (*d_release)(struct dentry___149 *);
	void (*d_prune)(struct dentry___149 *);
	void (*d_iput)(struct dentry___149 *, struct inode___149 *);
	char * (*d_dname)(struct dentry___149 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___149 *);
	int (*d_manage)(struct dentry___149 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___83 {
	int nr;
	struct pid_namespace___83 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___83 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___149 *child_reaper;
	struct kmem_cache___135 *pid_cachep;
	unsigned int level;
	struct pid_namespace___83 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___149 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___83 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___83 numbers[1];
};

struct block_device___149 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___149 *bd_inode;
	struct super_block___149 *bd_super;
	struct mutex___150 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___149 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___150 bd_fsfreeze_mutex;
};

struct cgroup___96;

struct cgroup_subsys_state___96 {
	struct cgroup___96 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___149 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___149 *ia_file;
};

struct address_space_operations___149 {
	int (*writepage)(struct page___148 *, struct writeback_control *);
	int (*readpage)(struct file___149 *, struct page___148 *);
	int (*writepages)(struct address_space___149 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___148 *);
	int (*readpages)(struct file___149 *, struct address_space___149 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___149 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___148 **, void **);
	int (*write_end)(struct file___149 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___148 *, void *);
	sector_t (*bmap)(struct address_space___149 *, sector_t);
	void (*invalidatepage)(struct page___148 *, long unsigned int);
	int (*releasepage)(struct page___148 *, gfp_t);
	void (*freepage)(struct page___148 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___149 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___149 *, struct page___148 *, struct page___148 *, enum migrate_mode);
	int (*launder_page)(struct page___148 *);
	int (*is_partially_uptodate)(struct page___148 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___148 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___149 *, struct page___148 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___149 *, sector_t *);
	void (*swap_deactivate)(struct file___149 *);
	void (*invalidatepage_range)(struct page___148 *, unsigned int, unsigned int);
};

struct inode_operations___149 {
	struct dentry___149 * (*lookup)(struct inode___149 *, struct dentry___149 *, unsigned int);
	void * (*follow_link)(struct dentry___149 *, struct nameidata *);
	int (*permission)(struct inode___149 *, int);
	struct posix_acl * (*get_acl)(struct inode___149 *, int);
	int (*readlink)(struct dentry___149 *, char *, int);
	void (*put_link)(struct dentry___149 *, struct nameidata *, void *);
	int (*create)(struct inode___149 *, struct dentry___149 *, umode_t, bool);
	int (*link)(struct dentry___149 *, struct inode___149 *, struct dentry___149 *);
	int (*unlink)(struct inode___149 *, struct dentry___149 *);
	int (*symlink)(struct inode___149 *, struct dentry___149 *, const char *);
	int (*mkdir)(struct inode___149 *, struct dentry___149 *, umode_t);
	int (*rmdir)(struct inode___149 *, struct dentry___149 *);
	int (*mknod)(struct inode___149 *, struct dentry___149 *, umode_t, dev_t);
	int (*rename)(struct inode___149 *, struct dentry___149 *, struct inode___149 *, struct dentry___149 *);
	int (*setattr)(struct dentry___149 *, struct iattr___149 *);
	int (*getattr)(struct vfsmount *, struct dentry___149 *, struct kstat *);
	int (*setxattr)(struct dentry___149 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___149 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___149 *, char *, size_t);
	int (*removexattr)(struct dentry___149 *, const char *);
	int (*fiemap)(struct inode___149 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___149 *, struct timespec *, int);
	int (*atomic_open)(struct inode___149 *, struct dentry___149 *, struct file___149 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___91;

struct file_operations___149 {
	struct module *owner;
	loff_t (*llseek)(struct file___149 *, loff_t, int);
	ssize_t (*read)(struct file___149 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___149 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___149 *, void *, filldir_t);
	unsigned int (*poll)(struct file___149 *, struct poll_table_struct___91 *);
	long int (*unlocked_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___149 *, struct vm_area_struct___154 *);
	int (*open)(struct inode___149 *, struct file___149 *);
	int (*flush)(struct file___149 *, fl_owner_t);
	int (*release)(struct inode___149 *, struct file___149 *);
	int (*fsync)(struct file___149 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___149 *, int);
	int (*lock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*sendpage)(struct file___149 *, struct page___148 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___149 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___149 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___149 *, long int, struct file_lock___149 **, void **);
		struct {
			int (*setlease)(struct file___149 *, long int, struct file_lock___149 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___149 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___110 *, struct file___149 *);
};

struct file_lock_operations___149;

struct lock_manager_operations___149;

struct file_lock___149 {
	struct file_lock___149 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___83 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___149 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___149 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___149 *fl_ops;
	const struct lock_manager_operations___149 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct cred___7 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___7 *session_keyring;
	struct key___7 *process_keyring;
	struct key___7 *thread_keyring;
	struct key___7 *request_key_auth;
	void *security;
	struct user_struct___7 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct file_lock_operations___149 {
	void (*fl_copy_lock)(struct file_lock___149 *, struct file_lock___149 *);
	void (*fl_release_private)(struct file_lock___149 *);
};

struct lock_manager_operations___149 {
	int (*lm_compare_owner)(struct file_lock___149 *, struct file_lock___149 *);
	long unsigned int (*lm_owner_key)(struct file_lock___149 *);
	void (*lm_notify)(struct file_lock___149 *);
	int (*lm_grant)(struct file_lock___149 *, struct file_lock___149 *, int);
	void (*lm_break)(struct file_lock___149 *);
	int (*lm_change)(struct file_lock___149 **, int);
};

struct fasync_struct___149 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___149 *fa_next;
	struct file___149 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___149 {
	const char *name;
	int fs_flags;
	struct dentry___149 * (*mount)(struct file_system_type___149 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___149 *);
	struct module *owner;
	struct file_system_type___149 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___149 {
	struct inode___149 * (*alloc_inode)(struct super_block___149 *);
	void (*destroy_inode)(struct inode___149 *);
	void (*dirty_inode)(struct inode___149 *, int);
	int (*write_inode)(struct inode___149 *, struct writeback_control *);
	int (*drop_inode)(struct inode___149 *);
	void (*evict_inode)(struct inode___149 *);
	void (*put_super)(struct super_block___149 *);
	int (*sync_fs)(struct super_block___149 *, int);
	int (*freeze_fs)(struct super_block___149 *);
	int (*unfreeze_fs)(struct super_block___149 *);
	int (*statfs)(struct dentry___149 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___149 *, int *, char *);
	void (*umount_begin)(struct super_block___149 *);
	int (*show_options)(struct seq_file___110 *, struct dentry___149 *);
	int (*show_devname)(struct seq_file___110 *, struct dentry___149 *);
	int (*show_path)(struct seq_file___110 *, struct dentry___149 *);
	int (*show_stats)(struct seq_file___110 *, struct dentry___149 *);
	ssize_t (*quota_read)(struct super_block___149 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___149 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___149 *);
	int (*bdev_try_to_free_page)(struct super_block___149 *, struct page___148 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___149 *);
	void (*free_cached_objects)(struct super_block___149 *, int);
};

struct xattr_handler___96 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___149 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___149 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___149 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___93)(struct file___149 *, wait_queue_head_t *, struct poll_table_struct___91 *);

struct poll_table_struct___91 {
	poll_queue_proc___93 _qproc;
	long unsigned int _key;
};

struct irq_chip___104 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___104 *);
	void (*irq_shutdown)(struct irq_data___104 *);
	void (*irq_enable)(struct irq_data___104 *);
	void (*irq_disable)(struct irq_data___104 *);
	void (*irq_ack)(struct irq_data___104 *);
	void (*irq_mask)(struct irq_data___104 *);
	void (*irq_mask_ack)(struct irq_data___104 *);
	void (*irq_unmask)(struct irq_data___104 *);
	void (*irq_eoi)(struct irq_data___104 *);
	int (*irq_set_affinity)(struct irq_data___104 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___104 *);
	int (*irq_set_type)(struct irq_data___104 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___104 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___104 *);
	void (*irq_bus_sync_unlock)(struct irq_data___104 *);
	void (*irq_cpu_online)(struct irq_data___104 *);
	void (*irq_cpu_offline)(struct irq_data___104 *);
	void (*irq_suspend)(struct irq_data___104 *);
	void (*irq_resume)(struct irq_data___104 *);
	void (*irq_pm_shutdown)(struct irq_data___104 *);
	void (*irq_print_chip)(struct irq_data___104 *, struct seq_file___110 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___104 *, void *);
	long unsigned int flags;
};

struct signal_struct___149 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___149 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___149 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___150 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___96 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___96 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___74 {
	struct pmu___74 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___150 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___149 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___74 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___110;

struct attribute_group___108 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___110 **bin_attrs;
};

struct bin_attribute___110 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___149 *, struct kobject___11 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___149 *, struct kobject___11 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	int (*mmap)(struct file___149 *, struct kobject___11 *, struct bin_attribute___110 *, struct vm_area_struct___154 *);
};

struct bus_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___115 *, char *);
	ssize_t (*store)(struct bus_type___115 *, const char *, size_t);
};

struct device_attribute___115;

struct driver_attribute___115;

struct bus_type___115 {
	const char *name;
	const char *dev_name;
	struct device___115 *dev_root;
	struct bus_attribute___115 *bus_attrs;
	struct device_attribute___115 *dev_attrs;
	struct driver_attribute___115 *drv_attrs;
	const struct attribute_group___108 **bus_groups;
	const struct attribute_group___108 **dev_groups;
	const struct attribute_group___108 **drv_groups;
	int (*match)(struct device___115 *, struct device_driver___115 *);
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	int (*probe)(struct device___115 *);
	int (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*online)(struct device___115 *);
	int (*offline)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct device___115 *, struct device_attribute___115 *, char *);
	ssize_t (*store)(struct device___115 *, struct device_attribute___115 *, const char *, size_t);
};

struct driver_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___115 *, char *);
	ssize_t (*store)(struct device_driver___115 *, const char *, size_t);
};

struct device_driver___115 {
	const char *name;
	struct bus_type___115 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___115 *);
	int (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	const struct attribute_group___108 **groups;
	const struct dev_pm_ops___115 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___115 {
	const char *name;
	const struct attribute_group___108 **groups;
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
};

struct class_attribute___115;

struct class___115 {
	const char *name;
	struct module *owner;
	struct class_attribute___115 *class_attrs;
	struct device_attribute___115 *dev_attrs;
	const struct attribute_group___108 **dev_groups;
	struct bin_attribute___110 *dev_bin_attrs;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *);
	void (*class_release)(struct class___115 *);
	void (*dev_release)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
	struct subsys_private *p;
};

struct class_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct class___115 *, struct class_attribute___115 *, char *);
	ssize_t (*store)(struct class___115 *, struct class_attribute___115 *, const char *, size_t);
	const void * (*namespace)(struct class___115 *, const struct class_attribute___115 *);
};

struct device_rh___115 {
	struct dev_pm_info_rh___115 power;
};

struct kmem_cache_cpu___134 {
	void **freelist;
	long unsigned int tid;
	struct page___148 *page;
	struct page___148 *partial;
};

struct memcg_cache_params___135 {
	bool is_root_cache;
	union {
		struct kmem_cache___135 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___135 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___96;

struct cgroup___96 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___96 *parent;
	struct dentry___149 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___96 *subsys[11];
	struct cgroupfs_root___96 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___150 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___96 {
	struct super_block___149 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___96 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___74;

struct pmu___74 {
	struct list_head entry;
	struct device___115 *dev;
	const struct attribute_group___108 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___74 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___74 *);
	void (*pmu_disable)(struct pmu___74 *);
	int (*event_init)(struct perf_event___74 *);
	int (*add)(struct perf_event___74 *, int);
	void (*del)(struct perf_event___74 *, int);
	void (*start)(struct perf_event___74 *, int);
	void (*stop)(struct perf_event___74 *, int);
	void (*read)(struct perf_event___74 *);
	void (*start_txn)(struct pmu___74 *);
	int (*commit_txn)(struct pmu___74 *);
	void (*cancel_txn)(struct pmu___74 *);
	int (*event_idx)(struct perf_event___74 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___74 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___74 *);
};

struct perf_cpu_context___74 {
	struct perf_event_context___74 ctx;
	struct perf_event_context___74 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___74 *unique_pmu;
	struct perf_cgroup___74 *cgrp;
};

struct trace_event_functions___64;

struct trace_event___64 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___64 *funcs;
};

struct ftrace_event_class___64;

struct ftrace_event_call___64 {
	struct list_head list;
	struct ftrace_event_class___64 *class;
	char *name;
	struct trace_event___64 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___74 {
	struct cgroup_subsys_state___96 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___64 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___150 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___64)(struct trace_iterator___64 *, int, struct trace_event___64 *);

struct trace_event_functions___64 {
	trace_print_func___64 trace;
	trace_print_func___64 raw;
	trace_print_func___64 hex;
	trace_print_func___64 binary;
};

struct ftrace_event_class___64 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___64 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___64 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___64 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___64 *);
};

struct key_construction___7 {
	struct key___7 *key;
	struct key___7 *authkey;
};

struct keyring_search_context___3 {
	struct keyring_index_key___5 index_key;
	const struct cred___5 *cred;
	key_match_func_t___3 match;
	const void *match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	struct timespec now;
};

struct task_struct___150;

struct pv_cpu_ops___150 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___150 *);
	void (*end_context_switch)(struct task_struct___150 *);
};

struct mutex___151 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___150 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___155;

struct cred___8;

struct signal_struct___150;

struct task_struct___150 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___150 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___155 *mm;
	struct mm_struct___155 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___150 *real_parent;
	struct task_struct___150 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___150 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___150 = 0,
		VTIME_USER___150 = 1,
		VTIME_SYS___150 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___8 *real_cred;
	const struct cred___8 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___150 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___151 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___144 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___155 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___155 *, struct mm_struct___155 *);
	void (*dup_mmap)(struct mm_struct___155 *, struct mm_struct___155 *);
	void (*exit_mmap)(struct mm_struct___155 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___155 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___155 *);
	void (*pgd_free)(struct mm_struct___155 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___155 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___155 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___155 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___155 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___155 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___155 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___155 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___155 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___155 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___155 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___155 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___151 lock;
	void *vdso;
} mm_context_t___151;

struct vm_area_struct___155;

struct core_state___150;

struct mm_struct___155 {
	struct vm_area_struct___155 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___155 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___155 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___151 context;
	long unsigned int flags;
	struct core_state___150 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___150 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___148 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct key_type___8;

struct keyring_index_key___8 {
	struct key_type___8 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___8;

typedef int (*request_key_actor_t___8)(struct key_construction___8 *, const char *, void *);

struct key___8;

struct key_type___8 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___8 *, struct key_preparsed_payload *);
	int (*update)(struct key___8 *, struct key_preparsed_payload *);
	int (*match)(const struct key___8 *, const void *);
	void (*revoke)(struct key___8 *);
	void (*destroy)(struct key___8 *);
	void (*describe)(const struct key___8 *, struct seq_file___5 *);
	long int (*read)(const struct key___8 *, char *, size_t);
	request_key_actor_t___8 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___6;

struct key___8 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___6 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___8 index_key;
		struct {
			struct key_type___8 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___6 {
	struct rb_node node;
	struct mutex___151 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct vm_area_struct___155 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___155 *vm_next;
	struct vm_area_struct___155 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___155 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___150 {
	struct task_struct___150 *task;
	struct core_thread___150 *next;
};

struct core_state___150 {
	atomic_t nr_threads;
	struct core_thread___150 dumper;
	struct completion startup;
};

struct smp_ops___150 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___150 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct user_struct___8 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___8 *uid_keyring;
	struct key___8 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct zone___150;

struct lruvec___150 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___150 *zone;
};

struct pglist_data___150;

struct zone___150 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___150 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___150 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___150 {
	struct zone___150 *zone;
	int zone_idx;
};

struct zonelist___150 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___150 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___150 {
	struct zone___150 node_zones[4];
	struct zonelist___150 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___150 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___8 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___8 *session_keyring;
	struct key___8 *process_keyring;
	struct key___8 *thread_keyring;
	struct key___8 *request_key_auth;
	void *security;
	struct user_struct___8 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___150 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___150 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___150 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___151 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key_construction___8 {
	struct key___8 *key;
	struct key___8 *authkey;
};

struct task_struct___151;

struct pv_cpu_ops___151 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___151 *);
	void (*end_context_switch)(struct task_struct___151 *);
};

struct mutex___152 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___151 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct mm_struct___156;

struct cred___9;

struct signal_struct___151;

struct task_struct___151 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___151 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___156 *mm;
	struct mm_struct___156 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___151 *real_parent;
	struct task_struct___151 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___151 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___151 = 0,
		VTIME_USER___151 = 1,
		VTIME_SYS___151 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___89 *nsproxy;
	struct signal_struct___151 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___152 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___144 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___156 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___156 *, struct mm_struct___156 *);
	void (*dup_mmap)(struct mm_struct___156 *, struct mm_struct___156 *);
	void (*exit_mmap)(struct mm_struct___156 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___156 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___156 *);
	void (*pgd_free)(struct mm_struct___156 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___156 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___156 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___156 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___156 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___156 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___156 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___156 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___156 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___156 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___156 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___156 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___152 lock;
	void *vdso;
} mm_context_t___152;

struct vm_area_struct___156;

struct core_state___151;

struct mm_struct___156 {
	struct vm_area_struct___156 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___156 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___156 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___152 context;
	long unsigned int flags;
	struct core_state___151 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___151 *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___148 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct vm_area_struct___156 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___156 *vm_next;
	struct vm_area_struct___156 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___156 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___151 {
	struct task_struct___151 *task;
	struct core_thread___151 *next;
};

struct core_state___151 {
	atomic_t nr_threads;
	struct core_thread___151 dumper;
	struct completion startup;
};

struct smp_ops___151 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___151 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___9;

struct user_struct___9 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___9 *uid_keyring;
	struct key___9 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct zone___151;

struct lruvec___151 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___151 *zone;
};

struct pglist_data___151;

struct zone___151 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___151 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___151 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___151 {
	struct zone___151 *zone;
	int zone_idx;
};

struct zonelist___151 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___151 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___151 {
	struct zone___151 node_zones[4];
	struct zonelist___151 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___151 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_type___9;

struct keyring_index_key___9 {
	struct key_type___9 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___9;

typedef int (*request_key_actor_t___9)(struct key_construction___9 *, const char *, void *);

struct key_type___9 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___9 *, struct key_preparsed_payload *);
	int (*update)(struct key___9 *, struct key_preparsed_payload *);
	int (*match)(const struct key___9 *, const void *);
	void (*revoke)(struct key___9 *);
	void (*destroy)(struct key___9 *);
	void (*describe)(const struct key___9 *, struct seq_file___5 *);
	long int (*read)(const struct key___9 *, char *, size_t);
	request_key_actor_t___9 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key_user___7;

struct key___9 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user___7 *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___9 index_key;
		struct {
			struct key_type___9 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct key_user___7 {
	struct rb_node node;
	struct mutex___152 cons_lock;
	spinlock_t lock;
	atomic_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct user_namespace___4;

struct cred___9 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___9 *session_keyring;
	struct key___9 *process_keyring;
	struct key___9 *thread_keyring;
	struct key___9 *request_key_auth;
	void *security;
	struct user_struct___9 *user;
	struct user_namespace___4 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct user_namespace___4 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___4 *parent;
	kuid_t owner;
	kgid_t group;
	unsigned int proc_inum;
	bool may_mount_sysfs;
	bool may_mount_proc;
	struct key___9 *persistent_keyring_register;
	struct rw_semaphore persistent_keyring_register_sem;
	int level;
	long unsigned int flags;
};

struct signal_struct___151 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___151 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___151 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___152 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key_construction___9 {
	struct key___9 *key;
	struct key___9 *authkey;
};

struct page___149;

typedef struct page___149 *pgtable_t___149;

struct address_space___150;

struct kmem_cache___136;

struct page___149 {
	long unsigned int flags;
	struct address_space___150 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___149 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___149 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___136 *slab_cache;
		struct page___149 *first_page;
	};
	long: 64;
};

struct task_struct___152;

struct pv_cpu_ops___152 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___152 *);
	void (*end_context_switch)(struct task_struct___152 *);
};

struct mutex___153 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___152 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___145 {
	struct page___149 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___157;

struct cred___10;

struct signal_struct___152;

struct css_set___97;

struct task_struct___152 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___152 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___157 *mm;
	struct mm_struct___157 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___152 *real_parent;
	struct task_struct___152 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___152 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___152 = 0,
		VTIME_USER___152 = 1,
		VTIME_SYS___152 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___152 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___97 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___153 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___145 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___157 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___157 *, struct mm_struct___157 *);
	void (*dup_mmap)(struct mm_struct___157 *, struct mm_struct___157 *);
	void (*exit_mmap)(struct mm_struct___157 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___157 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___157 *);
	void (*pgd_free)(struct mm_struct___157 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___157 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___157 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___157 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___157 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___157 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___157 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___157 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___157 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___157 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___157 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___157 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___153 lock;
	void *vdso;
} mm_context_t___153;

struct xol_area___149;

struct uprobes_state___149 {
	struct xol_area___149 *xol_area;
};

struct vm_area_struct___157;

struct file___150;

struct core_state___152;

struct mm_struct___157 {
	struct vm_area_struct___157 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___157 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___157 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___153 context;
	long unsigned int flags;
	struct core_state___152 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___152 *owner;
	struct file___150 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___149 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___77;

struct module_kobject___76 {
	struct kobject___11 kobj;
	struct module___77 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___76;

struct module___77 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___76 mkobj;
	struct module_attribute___76 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___152 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___152;

struct lruvec___152 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___152 *zone;
};

struct pglist_data___152;

struct zone___152 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___152 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___152 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___152 {
	struct zone___152 *zone;
	int zone_idx;
};

struct zonelist___152 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___152 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___152 {
	struct zone___152 node_zones[4];
	struct zonelist___152 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___152 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___105;

struct x86_io_apic_ops___105 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___105 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___105;

struct irq_data___105 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___105 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___152 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___152 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct key___10;

struct user_struct___10;

struct cred___10 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	unsigned char jit_keyring;
	struct key___10 *session_keyring;
	struct key___10 *process_keyring;
	struct key___10 *thread_keyring;
	struct key___10 *request_key_auth;
	void *security;
	struct user_struct___10 *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct dentry___150;

struct path___150 {
	struct vfsmount *mnt;
	struct dentry___150 *dentry;
};

struct inode___150;

struct file_operations___150;

struct file___150 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___150 f_path;
	struct inode___150 *f_inode;
	const struct file_operations___150 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___150 *f_mapping;
	struct mutex___153 f_pos_lock;
};

struct vm_operations_struct___130;

struct vm_area_struct___157 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___157 *vm_next;
	struct vm_area_struct___157 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___157 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___130 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___150 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___76 *, struct module_kobject___76 *, char *);
	ssize_t (*store)(struct module_attribute___76 *, struct module_kobject___76 *, const char *, size_t);
	void (*setup)(struct module___77 *, const char *);
	int (*test)(struct module___77 *);
	void (*free)(struct module___77 *);
};

struct seq_operations___110;

struct seq_file___111 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___153 lock;
	const struct seq_operations___110 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___110 {
	void * (*start)(struct seq_file___111 *, loff_t *);
	void (*stop)(struct seq_file___111 *, void *);
	void * (*next)(struct seq_file___111 *, void *, loff_t *);
	int (*show)(struct seq_file___111 *, void *);
};

struct xol_area___149 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___149 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___135;

struct memcg_cache_params___136;

struct kmem_cache___136 {
	struct kmem_cache_cpu___135 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___136 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___150;

struct address_space___150 {
	struct inode___150 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___153 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___150 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___127;

struct vm_operations_struct___130 {
	void (*open)(struct vm_area_struct___157 *);
	void (*close)(struct vm_area_struct___157 *);
	int (*fault)(struct vm_area_struct___157 *, struct vm_fault___127 *);
	int (*page_mkwrite)(struct vm_area_struct___157 *, struct vm_fault___127 *);
	int (*access)(struct vm_area_struct___157 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___157 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___157 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___157 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___157 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___152 {
	struct task_struct___152 *task;
	struct core_thread___152 *next;
};

struct core_state___152 {
	atomic_t nr_threads;
	struct core_thread___152 dumper;
	struct completion startup;
};

struct user_struct___10 {
	atomic_t __count;
	atomic_t processes;
	atomic_t files;
	atomic_t sigpending;
	atomic_t inotify_watches;
	atomic_t inotify_devs;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	struct key___10 *uid_keyring;
	struct key___10 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
};

struct key_type___10;

struct keyring_index_key___10 {
	struct key_type___10 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___10;

typedef int (*request_key_actor_t___10)(struct key_construction___10 *, const char *, void *);

struct key_type___10 {
	const char *name;
	size_t def_datalen;
	unsigned int def_lookup_type;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___10 *, struct key_preparsed_payload *);
	int (*update)(struct key___10 *, struct key_preparsed_payload *);
	int (*match)(const struct key___10 *, const void *);
	void (*revoke)(struct key___10 *);
	void (*destroy)(struct key___10 *);
	void (*describe)(const struct key___10 *, struct seq_file___111 *);
	long int (*read)(const struct key___10 *, char *, size_t);
	request_key_actor_t___10 request_key;
	struct list_head link;
	struct lock_class_key lock_class;
};

struct key___10 {
	atomic_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time_t expiry;
		time_t revoked_at;
	};
	time_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	long unsigned int flags;
	union {
		struct keyring_index_key___10 index_key;
		struct {
			struct key_type___10 *type;
			char *description;
		};
	};
	union {
		struct list_head link;
		long unsigned int x[2];
		void *p[2];
		int reject_error;
	} type_data;
	union {
		union {
			long unsigned int value;
			void *rcudata;
			void *data;
			void *data2[2];
		} payload;
		struct assoc_array keys;
	};
};

struct signal_struct___152 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___152 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___152 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___153 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___97;

struct css_set___97 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___97 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___135 {
	void **freelist;
	long unsigned int tid;
	struct page___149 *page;
	struct page___149 *partial;
};

struct memcg_cache_params___136 {
	bool is_root_cache;
	union {
		struct kmem_cache___136 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___136 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___97 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___150 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___150 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___150 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___150;

struct super_block___150;

struct dentry___150 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___150 *d_parent;
	struct qstr d_name;
	struct inode___150 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___150 *d_op;
	struct super_block___150 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___150;

struct file_lock___150;

struct dquot___150;

struct block_device___150;

struct inode___150 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___150 *i_op;
	struct super_block___150 *i_sb;
	struct address_space___150 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___153 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___150 *i_fop;
	struct file_lock___150 *i_flock;
	struct address_space___150 i_data;
	struct dquot___150 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___150 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___150 {
	int (*d_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_hash)(const struct dentry___150 *, struct qstr *);
	int (*d_compare)(const struct dentry___150 *, const struct dentry___150 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___150 *);
	void (*d_release)(struct dentry___150 *);
	void (*d_prune)(struct dentry___150 *);
	void (*d_iput)(struct dentry___150 *, struct inode___150 *);
	char * (*d_dname)(struct dentry___150 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___150 *);
	int (*d_manage)(struct dentry___150 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___150;

struct mem_dqinfo___150 {
	struct quota_format_type___150 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___150;

struct quota_info___150 {
	unsigned int flags;
	struct mutex___153 dqio_mutex;
	struct mutex___153 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___150 *files[2];
	struct mem_dqinfo___150 info[2];
	const struct quota_format_ops___150 *ops[2];
};

struct file_system_type___150;

struct super_operations___150;

struct dquot_operations___150;

struct quotactl_ops___150;

struct super_block___150 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___150 *s_type;
	const struct super_operations___150 *s_op;
	const struct dquot_operations___150 *dq_op;
	const struct quotactl_ops___150 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___150 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___97 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___150 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___150 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___153 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___150 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___150 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___150 *bd_inode;
	struct super_block___150 *bd_super;
	struct mutex___153 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___150 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___153 bd_fsfreeze_mutex;
};

struct cgroup___97;

struct cgroup_subsys_state___97 {
	struct cgroup___97 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___150 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___150 *ia_file;
};

struct dquot___150 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___153 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___150 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___150 {
	int qf_fmt_id;
	const struct quota_format_ops___150 *qf_ops;
	struct module___77 *qf_owner;
	struct quota_format_type___150 *qf_next;
};

struct quota_format_ops___150 {
	int (*check_quota_file)(struct super_block___150 *, int);
	int (*read_file_info)(struct super_block___150 *, int);
	int (*write_file_info)(struct super_block___150 *, int);
	int (*free_file_info)(struct super_block___150 *, int);
	int (*read_dqblk)(struct dquot___150 *);
	int (*commit_dqblk)(struct dquot___150 *);
	int (*release_dqblk)(struct dquot___150 *);
};

struct dquot_operations___150 {
	int (*write_dquot)(struct dquot___150 *);
	struct dquot___150 * (*alloc_dquot)(struct super_block___150 *, int);
	void (*destroy_dquot)(struct dquot___150 *);
	int (*acquire_dquot)(struct dquot___150 *);
	int (*release_dquot)(struct dquot___150 *);
	int (*mark_dirty)(struct dquot___150 *);
	int (*write_info)(struct super_block___150 *, int);
	qsize_t * (*get_reserved_space)(struct inode___150 *);
};

struct quotactl_ops___150 {
	int (*quota_on)(struct super_block___150 *, int, int, struct path___150 *);
	int (*quota_on_meta)(struct super_block___150 *, int, int);
	int (*quota_off)(struct super_block___150 *, int);
	int (*quota_sync)(struct super_block___150 *, int);
	int (*get_info)(struct super_block___150 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___150 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___150 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___150 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___150 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___150 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___150 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___150 *, unsigned int);
};

struct swap_info_struct___35;

struct address_space_operations___150 {
	int (*writepage)(struct page___149 *, struct writeback_control *);
	int (*readpage)(struct file___150 *, struct page___149 *);
	int (*writepages)(struct address_space___150 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___149 *);
	int (*readpages)(struct file___150 *, struct address_space___150 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___150 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___149 **, void **);
	int (*write_end)(struct file___150 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___149 *, void *);
	sector_t (*bmap)(struct address_space___150 *, sector_t);
	void (*invalidatepage)(struct page___149 *, long unsigned int);
	int (*releasepage)(struct page___149 *, gfp_t);
	void (*freepage)(struct page___149 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___150 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___150 *, struct page___149 *, struct page___149 *, enum migrate_mode);
	int (*launder_page)(struct page___149 *);
	int (*is_partially_uptodate)(struct page___149 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___149 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___150 *, struct page___149 *);
	int (*swap_activate)(struct swap_info_struct___35 *, struct file___150 *, sector_t *);
	void (*swap_deactivate)(struct file___150 *);
	void (*invalidatepage_range)(struct page___149 *, unsigned int, unsigned int);
};

struct swap_info_struct___35 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___150 *bdev;
	struct file___150 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___150 {
	struct dentry___150 * (*lookup)(struct inode___150 *, struct dentry___150 *, unsigned int);
	void * (*follow_link)(struct dentry___150 *, struct nameidata *);
	int (*permission)(struct inode___150 *, int);
	struct posix_acl * (*get_acl)(struct inode___150 *, int);
	int (*readlink)(struct dentry___150 *, char *, int);
	void (*put_link)(struct dentry___150 *, struct nameidata *, void *);
	int (*create)(struct inode___150 *, struct dentry___150 *, umode_t, bool);
	int (*link)(struct dentry___150 *, struct inode___150 *, struct dentry___150 *);
	int (*unlink)(struct inode___150 *, struct dentry___150 *);
	int (*symlink)(struct inode___150 *, struct dentry___150 *, const char *);
	int (*mkdir)(struct inode___150 *, struct dentry___150 *, umode_t);
	int (*rmdir)(struct inode___150 *, struct dentry___150 *);
	int (*mknod)(struct inode___150 *, struct dentry___150 *, umode_t, dev_t);
	int (*rename)(struct inode___150 *, struct dentry___150 *, struct inode___150 *, struct dentry___150 *);
	int (*setattr)(struct dentry___150 *, struct iattr___150 *);
	int (*getattr)(struct vfsmount *, struct dentry___150 *, struct kstat *);
	int (*setxattr)(struct dentry___150 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___150 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___150 *, char *, size_t);
	int (*removexattr)(struct dentry___150 *, const char *);
	int (*fiemap)(struct inode___150 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___150 *, struct timespec *, int);
	int (*atomic_open)(struct inode___150 *, struct dentry___150 *, struct file___150 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___150 {
	struct module___77 *owner;
	loff_t (*llseek)(struct file___150 *, loff_t, int);
	ssize_t (*read)(struct file___150 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___150 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___150 *, void *, filldir_t);
	unsigned int (*poll)(struct file___150 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___150 *, struct vm_area_struct___157 *);
	int (*open)(struct inode___150 *, struct file___150 *);
	int (*flush)(struct file___150 *, fl_owner_t);
	int (*release)(struct inode___150 *, struct file___150 *);
	int (*fsync)(struct file___150 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___150 *, int);
	int (*lock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*sendpage)(struct file___150 *, struct page___149 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___150 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___150 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___150 *, long int, struct file_lock___150 **, void **);
		struct {
			int (*setlease)(struct file___150 *, long int, struct file_lock___150 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___150 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___111 *, struct file___150 *);
};

struct fasync_struct___150;

struct file_lock_operations___150;

struct lock_manager_operations___150;

struct file_lock___150 {
	struct file_lock___150 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___83 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___150 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___150 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___150 *fl_ops;
	const struct lock_manager_operations___150 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___150 {
	void (*fl_copy_lock)(struct file_lock___150 *, struct file_lock___150 *);
	void (*fl_release_private)(struct file_lock___150 *);
};

struct lock_manager_operations___150 {
	int (*lm_compare_owner)(struct file_lock___150 *, struct file_lock___150 *);
	long unsigned int (*lm_owner_key)(struct file_lock___150 *);
	void (*lm_notify)(struct file_lock___150 *);
	int (*lm_grant)(struct file_lock___150 *, struct file_lock___150 *, int);
	void (*lm_break)(struct file_lock___150 *);
	int (*lm_change)(struct file_lock___150 **, int);
};

struct fasync_struct___150 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___150 *fa_next;
	struct file___150 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___150 {
	const char *name;
	int fs_flags;
	struct dentry___150 * (*mount)(struct file_system_type___150 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___150 *);
	struct module___77 *owner;
	struct file_system_type___150 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___150 {
	struct inode___150 * (*alloc_inode)(struct super_block___150 *);
	void (*destroy_inode)(struct inode___150 *);
	void (*dirty_inode)(struct inode___150 *, int);
	int (*write_inode)(struct inode___150 *, struct writeback_control *);
	int (*drop_inode)(struct inode___150 *);
	void (*evict_inode)(struct inode___150 *);
	void (*put_super)(struct super_block___150 *);
	int (*sync_fs)(struct super_block___150 *, int);
	int (*freeze_fs)(struct super_block___150 *);
	int (*unfreeze_fs)(struct super_block___150 *);
	int (*statfs)(struct dentry___150 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___150 *, int *, char *);
	void (*umount_begin)(struct super_block___150 *);
	int (*show_options)(struct seq_file___111 *, struct dentry___150 *);
	int (*show_devname)(struct seq_file___111 *, struct dentry___150 *);
	int (*show_path)(struct seq_file___111 *, struct dentry___150 *);
	int (*show_stats)(struct seq_file___111 *, struct dentry___150 *);
	ssize_t (*quota_read)(struct super_block___150 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___150 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___150 *);
	int (*bdev_try_to_free_page)(struct super_block___150 *, struct page___149 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___150 *);
	void (*free_cached_objects)(struct super_block___150 *, int);
};

struct cgroupfs_root___97;

struct cgroup___97 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___97 *parent;
	struct dentry___150 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___97 *subsys[11];
	struct cgroupfs_root___97 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___153 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___97 {
	struct super_block___150 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___97 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___47 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___150 *, struct file___150 *);
	ssize_t (*read)(struct cgroup___97 *, struct cftype___47 *, struct file___150 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___97 *, struct cftype___47 *);
	s64 (*read_s64)(struct cgroup___97 *, struct cftype___47 *);
	int (*read_map)(struct cgroup___97 *, struct cftype___47 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___97 *, struct cftype___47 *, struct seq_file___111 *);
	ssize_t (*write)(struct cgroup___97 *, struct cftype___47 *, struct file___150 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___97 *, struct cftype___47 *, u64);
	int (*write_s64)(struct cgroup___97 *, struct cftype___47 *, s64);
	int (*write_string)(struct cgroup___97 *, struct cftype___47 *, const char *);
	int (*trigger)(struct cgroup___97 *, unsigned int);
	int (*release)(struct inode___150 *, struct file___150 *);
	int (*register_event)(struct cgroup___97 *, struct cftype___47 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___97 *, struct cftype___47 *, struct eventfd_ctx *);
};

struct cftype_set___45 {
	struct list_head node;
	struct cftype___47 *cfts;
};

struct task_and_cgroup___45 {
	struct task_struct___152 *task;
	struct cgroup___97 *cgrp;
	struct css_set___97 *cg;
};

struct cgroup_taskset___45 {
	struct task_and_cgroup___45 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___97 *cur_cgrp;
};

struct cgroup_subsys___45 {
	struct cgroup_subsys_state___97 * (*css_alloc)(struct cgroup___97 *);
	int (*css_online)(struct cgroup___97 *);
	void (*css_offline)(struct cgroup___97 *);
	void (*css_free)(struct cgroup___97 *);
	int (*can_attach)(struct cgroup___97 *, struct cgroup_taskset___45 *);
	void (*cancel_attach)(struct cgroup___97 *, struct cgroup_taskset___45 *);
	void (*attach)(struct cgroup___97 *, struct cgroup_taskset___45 *);
	void (*fork)(struct task_struct___152 *);
	void (*exit)(struct cgroup___97 *, struct cgroup___97 *, struct task_struct___152 *);
	void (*bind)(struct cgroup___97 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___97 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___47 *base_cftypes;
	struct cftype_set___45 base_cftset;
	struct module___77 *module;
};

struct irq_chip___105 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___105 *);
	void (*irq_shutdown)(struct irq_data___105 *);
	void (*irq_enable)(struct irq_data___105 *);
	void (*irq_disable)(struct irq_data___105 *);
	void (*irq_ack)(struct irq_data___105 *);
	void (*irq_mask)(struct irq_data___105 *);
	void (*irq_mask_ack)(struct irq_data___105 *);
	void (*irq_unmask)(struct irq_data___105 *);
	void (*irq_eoi)(struct irq_data___105 *);
	int (*irq_set_affinity)(struct irq_data___105 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___105 *);
	int (*irq_set_type)(struct irq_data___105 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___105 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___105 *);
	void (*irq_bus_sync_unlock)(struct irq_data___105 *);
	void (*irq_cpu_online)(struct irq_data___105 *);
	void (*irq_cpu_offline)(struct irq_data___105 *);
	void (*irq_suspend)(struct irq_data___105 *);
	void (*irq_resume)(struct irq_data___105 *);
	void (*irq_pm_shutdown)(struct irq_data___105 *);
	void (*irq_print_chip)(struct irq_data___105 *, struct seq_file___111 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___105 *, void *);
	long unsigned int flags;
};

struct vm_fault___127 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___149 *page;
};

struct key_construction___10 {
	struct key___10 *key;
	struct key___10 *authkey;
};

struct trusted_key_payload {
	struct callback_head rcu;
	unsigned int key_len;
	unsigned int blob_len;
	unsigned char migratable;
	unsigned char key[129];
	unsigned char blob[320];
};

struct tpm_buf {
	int len;
	unsigned char data[512];
};

struct osapsess {
	uint32_t handle;
	unsigned char secret[20];
	unsigned char enonce[20];
};

enum {
	SEAL_keytype = 1,
	SRK_keytype = 4,
};

struct trusted_key_options {
	uint16_t keytype;
	uint32_t keyhandle;
	unsigned char keyauth[20];
	unsigned char blobauth[20];
	uint32_t pcrinfo_len;
	unsigned char pcrinfo[64];
	int pcrlock;
};

struct sdesc {
	struct shash_desc shash;
	char ctx[0];
};

struct tpm_digests {
	unsigned char encauth[20];
	unsigned char pubauth[20];
	unsigned char xorwork[40];
	unsigned char xorhash[20];
	unsigned char nonceodd[20];
};

enum {
	Opt_err___8 = 4294967295,
	Opt_new = 0,
	Opt_load = 1,
	Opt_update = 2,
	Opt_keyhandle = 3,
	Opt_keyauth = 4,
	Opt_blobauth = 5,
	Opt_pcrinfo = 6,
	Opt_pcrlock = 7,
	Opt_migratable = 8,
};

struct encrypted_key_payload {
	struct callback_head rcu;
	char *format;
	char *master_desc;
	char *datalen;
	u8 *iv;
	u8 *encrypted_data;
	short unsigned int datablob_len;
	short unsigned int decrypted_datalen;
	short unsigned int payload_datalen;
	short unsigned int encrypted_key_format;
	u8 *decrypted_data;
	u8 payload_data[0];
};

struct ecryptfs_session_key {
	u32 flags;
	u32 encrypted_key_size;
	u32 decrypted_key_size;
	u8 encrypted_key[512];
	u8 decrypted_key[64];
};

struct ecryptfs_password {
	u32 password_bytes;
	s32 hash_algo;
	u32 hash_iterations;
	u32 session_key_encryption_key_bytes;
	u32 flags;
	u8 session_key_encryption_key[64];
	u8 signature[17];
	u8 salt[8];
};

struct ecryptfs_private_key {
	u32 key_size;
	u32 data_len;
	u8 signature[17];
	char pki_type[17];
	u8 data[0];
};

struct ecryptfs_auth_tok {
	u16 version;
	u16 token_type;
	u32 flags;
	struct ecryptfs_session_key session_key;
	u8 reserved[32];
	union {
		struct ecryptfs_password password;
		struct ecryptfs_private_key private_key;
	} token;
};

enum {
	Opt_err___9 = 4294967295,
	Opt_new___2 = 0,
	Opt_load___2 = 1,
	Opt_update___2 = 2,
};

enum {
	Opt_error = 4294967295,
	Opt_default = 0,
	Opt_ecryptfs = 1,
};

enum derived_key_type {
	ENC_KEY = 0,
	AUTH_KEY = 1,
};

enum ecryptfs_token_types {
	ECRYPTFS_PASSWORD = 0,
	ECRYPTFS_PRIVATE_KEY = 1,
};

struct vfs_cap_data {
	__le32 magic_etc;
	struct {
		__le32 permitted;
		__le32 inheritable;
	} data[2];
};

struct page___150;

typedef struct page___150 *pgtable_t___150;

struct address_space___151;

struct kmem_cache___137;

struct page___150 {
	long unsigned int flags;
	struct address_space___151 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___150 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___150 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___137 *slab_cache;
		struct page___150 *first_page;
	};
	long: 64;
};

struct task_struct___153;

struct pv_cpu_ops___153 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___153 *);
	void (*end_context_switch)(struct task_struct___153 *);
};

struct mutex___154 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___153 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___146 {
	struct page___150 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___158;

struct signal_struct___153;

struct css_set___98;

struct task_struct___153 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___153 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___158 *mm;
	struct mm_struct___158 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___153 *real_parent;
	struct task_struct___153 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___153 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___153 = 0,
		VTIME_USER___153 = 1,
		VTIME_SYS___153 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___89 *nsproxy;
	struct signal_struct___153 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___98 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___154 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___146 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___158 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___158 *, struct mm_struct___158 *);
	void (*dup_mmap)(struct mm_struct___158 *, struct mm_struct___158 *);
	void (*exit_mmap)(struct mm_struct___158 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___158 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___158 *);
	void (*pgd_free)(struct mm_struct___158 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___158 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___158 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___158 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___158 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___158 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___158 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___158 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___158 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___158 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___158 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___158 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___154 lock;
	void *vdso;
} mm_context_t___154;

struct xol_area___150;

struct uprobes_state___150 {
	struct xol_area___150 *xol_area;
};

struct vm_area_struct___158;

struct file___151;

struct linux_binfmt___23;

struct core_state___153;

struct mm_struct___158 {
	struct vm_area_struct___158 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___158 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___158 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___23 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___154 context;
	long unsigned int flags;
	struct core_state___153 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___153 *owner;
	struct file___151 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___150 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___78;

struct module_kobject___77 {
	struct kobject___11 kobj;
	struct module___78 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___77;

struct module___78 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___77 mkobj;
	struct module_attribute___77 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___153 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___150 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___150 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___136;

struct memcg_cache_params___137;

struct kmem_cache___137 {
	struct kmem_cache_cpu___136 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___137 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___151;

struct address_space_operations___151;

struct address_space___151 {
	struct inode___151 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___154 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___151 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___38;

struct dentry___151;

struct path___151 {
	struct vfsmount___38 *mnt;
	struct dentry___151 *dentry;
};

struct file_operations___151;

struct file___151 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___151 f_path;
	struct inode___151 *f_inode;
	const struct file_operations___151 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___151 *f_mapping;
	struct mutex___154 f_pos_lock;
};

struct vm_operations_struct___131;

struct vm_area_struct___158 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___158 *vm_next;
	struct vm_area_struct___158 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___158 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___131 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___151 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___128;

struct vm_operations_struct___131 {
	void (*open)(struct vm_area_struct___158 *);
	void (*close)(struct vm_area_struct___158 *);
	int (*fault)(struct vm_area_struct___158 *, struct vm_fault___128 *);
	int (*page_mkwrite)(struct vm_area_struct___158 *, struct vm_fault___128 *);
	int (*access)(struct vm_area_struct___158 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___158 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___158 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___158 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___158 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___153 {
	struct task_struct___153 *task;
	struct core_thread___153 *next;
};

struct core_state___153 {
	atomic_t nr_threads;
	struct core_thread___153 dumper;
	struct completion startup;
};

struct linux_binprm___24;

struct coredump_params___23;

struct linux_binfmt___23 {
	struct list_head lh;
	struct module___78 *module;
	int (*load_binary)(struct linux_binprm___24 *);
	int (*load_shlib)(struct file___151 *);
	int (*core_dump)(struct coredump_params___23 *);
	long unsigned int min_coredump;
};

struct device___116;

struct dev_pm_ops___116 {
	int (*prepare)(struct device___116 *);
	void (*complete)(struct device___116 *);
	int (*suspend)(struct device___116 *);
	int (*resume)(struct device___116 *);
	int (*freeze)(struct device___116 *);
	int (*thaw)(struct device___116 *);
	int (*poweroff)(struct device___116 *);
	int (*restore)(struct device___116 *);
	int (*suspend_late)(struct device___116 *);
	int (*resume_early)(struct device___116 *);
	int (*freeze_late)(struct device___116 *);
	int (*thaw_early)(struct device___116 *);
	int (*poweroff_late)(struct device___116 *);
	int (*restore_early)(struct device___116 *);
	int (*suspend_noirq)(struct device___116 *);
	int (*resume_noirq)(struct device___116 *);
	int (*freeze_noirq)(struct device___116 *);
	int (*thaw_noirq)(struct device___116 *);
	int (*poweroff_noirq)(struct device___116 *);
	int (*restore_noirq)(struct device___116 *);
	int (*runtime_suspend)(struct device___116 *);
	int (*runtime_resume)(struct device___116 *);
	int (*runtime_idle)(struct device___116 *);
};

struct dma_map_ops___39;

struct dev_archdata___39 {
	struct dma_map_ops___39 *dma_ops;
	void *iommu;
};

struct device_type___116;

struct bus_type___116;

struct device_driver___116;

struct dev_pm_domain___116;

struct class___116;

struct attribute_group___109;

struct device_rh___116;

struct device___116 {
	struct device___116 *parent;
	struct device_private *p;
	struct kobject___11 kobj;
	const char *init_name;
	const struct device_type___116 *type;
	struct mutex___154 mutex;
	struct bus_type___116 *bus;
	struct device_driver___116 *driver;
	void *platform_data;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___116 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___39 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___116 *class;
	const struct attribute_group___109 **groups;
	void (*release)(struct device___116 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___116 *device_rh;
};

struct dev_pm_info_rh___116 {
	void (*set_latency_tolerance)(struct device___116 *, s32);
};

struct dev_pm_domain___116 {
	struct dev_pm_ops___116 ops;
};

struct smp_ops___153 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___153 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___153;

struct lruvec___153 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___153 *zone;
};

struct pglist_data___153;

struct zone___153 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___153 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___153 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___153 {
	struct zone___153 *zone;
	int zone_idx;
};

struct zonelist___153 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___153 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___153 {
	struct zone___153 node_zones[4];
	struct zonelist___153 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___153 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___153 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___153 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___153 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___154 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___98;

struct css_set___98 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___98 *subsys[11];
	struct callback_head callback_head;
};

struct bin_attribute___111;

struct attribute_group___109 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___111 **bin_attrs;
};

struct bin_attribute___111 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___151 *, struct kobject___11 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___151 *, struct kobject___11 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	int (*mmap)(struct file___151 *, struct kobject___11 *, struct bin_attribute___111 *, struct vm_area_struct___158 *);
};

struct module_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___77 *, struct module_kobject___77 *, char *);
	ssize_t (*store)(struct module_attribute___77 *, struct module_kobject___77 *, const char *, size_t);
	void (*setup)(struct module___78 *, const char *);
	int (*test)(struct module___78 *);
	void (*free)(struct module___78 *);
};

struct kmem_cache_cpu___136 {
	void **freelist;
	long unsigned int tid;
	struct page___150 *page;
	struct page___150 *partial;
};

struct memcg_cache_params___137 {
	bool is_root_cache;
	union {
		struct kmem_cache___137 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___137 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct inode_operations___151;

struct super_block___151;

struct file_lock___151;

struct dquot___151;

struct block_device___151;

struct inode___151 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___151 *i_op;
	struct super_block___151 *i_sb;
	struct address_space___151 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___154 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___151 *i_fop;
	struct file_lock___151 *i_flock;
	struct address_space___151 i_data;
	struct dquot___151 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___151 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___151;

struct mem_dqinfo___151 {
	struct quota_format_type___151 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___151;

struct quota_info___151 {
	unsigned int flags;
	struct mutex___154 dqio_mutex;
	struct mutex___154 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___151 *files[2];
	struct mem_dqinfo___151 info[2];
	const struct quota_format_ops___151 *ops[2];
};

struct file_system_type___151;

struct super_operations___151;

struct dquot_operations___151;

struct quotactl_ops___151;

struct xattr_handler___98;

struct dentry_operations___151;

struct super_block___151 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___151 *s_type;
	const struct super_operations___151 *s_op;
	const struct dquot_operations___151 *dq_op;
	const struct quotactl_ops___151 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___151 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___98 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___151 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___151 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___154 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___151 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___151 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___151 *d_parent;
	struct qstr d_name;
	struct inode___151 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___151 *d_op;
	struct super_block___151 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct linux_binprm___24 {
	char buf[128];
	struct vm_area_struct___158 *vma;
	long unsigned int vma_pages;
	struct mm_struct___158 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___151 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct vfsmount___38 {
	struct dentry___151 *mnt_root;
	struct super_block___151 *mnt_sb;
	int mnt_flags;
};

struct iattr___151 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___151 *ia_file;
};

struct vm_fault___128 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___150 *page;
};

struct dentry_operations___151 {
	int (*d_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_hash)(const struct dentry___151 *, struct qstr *);
	int (*d_compare)(const struct dentry___151 *, const struct dentry___151 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___151 *);
	void (*d_release)(struct dentry___151 *);
	void (*d_prune)(struct dentry___151 *);
	void (*d_iput)(struct dentry___151 *, struct inode___151 *);
	char * (*d_dname)(struct dentry___151 *, char *, int);
	struct vfsmount___38 * (*d_automount)(struct path___151 *);
	int (*d_manage)(struct dentry___151 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___151 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___151 *bd_inode;
	struct super_block___151 *bd_super;
	struct mutex___154 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___151 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___154 bd_fsfreeze_mutex;
};

struct cgroup___98;

struct cgroup_subsys_state___98 {
	struct cgroup___98 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___151 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___154 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___151 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___151 {
	int qf_fmt_id;
	const struct quota_format_ops___151 *qf_ops;
	struct module___78 *qf_owner;
	struct quota_format_type___151 *qf_next;
};

struct quota_format_ops___151 {
	int (*check_quota_file)(struct super_block___151 *, int);
	int (*read_file_info)(struct super_block___151 *, int);
	int (*write_file_info)(struct super_block___151 *, int);
	int (*free_file_info)(struct super_block___151 *, int);
	int (*read_dqblk)(struct dquot___151 *);
	int (*commit_dqblk)(struct dquot___151 *);
	int (*release_dqblk)(struct dquot___151 *);
};

struct dquot_operations___151 {
	int (*write_dquot)(struct dquot___151 *);
	struct dquot___151 * (*alloc_dquot)(struct super_block___151 *, int);
	void (*destroy_dquot)(struct dquot___151 *);
	int (*acquire_dquot)(struct dquot___151 *);
	int (*release_dquot)(struct dquot___151 *);
	int (*mark_dirty)(struct dquot___151 *);
	int (*write_info)(struct super_block___151 *, int);
	qsize_t * (*get_reserved_space)(struct inode___151 *);
};

struct quotactl_ops___151 {
	int (*quota_on)(struct super_block___151 *, int, int, struct path___151 *);
	int (*quota_on_meta)(struct super_block___151 *, int, int);
	int (*quota_off)(struct super_block___151 *, int);
	int (*quota_sync)(struct super_block___151 *, int);
	int (*get_info)(struct super_block___151 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___151 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___151 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___151 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___151 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___151 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___151 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___151 *, unsigned int);
};

struct swap_info_struct___36;

struct address_space_operations___151 {
	int (*writepage)(struct page___150 *, struct writeback_control *);
	int (*readpage)(struct file___151 *, struct page___150 *);
	int (*writepages)(struct address_space___151 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___150 *);
	int (*readpages)(struct file___151 *, struct address_space___151 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___151 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___150 **, void **);
	int (*write_end)(struct file___151 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___150 *, void *);
	sector_t (*bmap)(struct address_space___151 *, sector_t);
	void (*invalidatepage)(struct page___150 *, long unsigned int);
	int (*releasepage)(struct page___150 *, gfp_t);
	void (*freepage)(struct page___150 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___151 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___151 *, struct page___150 *, struct page___150 *, enum migrate_mode);
	int (*launder_page)(struct page___150 *);
	int (*is_partially_uptodate)(struct page___150 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___150 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___151 *, struct page___150 *);
	int (*swap_activate)(struct swap_info_struct___36 *, struct file___151 *, sector_t *);
	void (*swap_deactivate)(struct file___151 *);
	void (*invalidatepage_range)(struct page___150 *, unsigned int, unsigned int);
};

struct swap_info_struct___36 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___151 *bdev;
	struct file___151 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___151 {
	struct dentry___151 * (*lookup)(struct inode___151 *, struct dentry___151 *, unsigned int);
	void * (*follow_link)(struct dentry___151 *, struct nameidata *);
	int (*permission)(struct inode___151 *, int);
	struct posix_acl * (*get_acl)(struct inode___151 *, int);
	int (*readlink)(struct dentry___151 *, char *, int);
	void (*put_link)(struct dentry___151 *, struct nameidata *, void *);
	int (*create)(struct inode___151 *, struct dentry___151 *, umode_t, bool);
	int (*link)(struct dentry___151 *, struct inode___151 *, struct dentry___151 *);
	int (*unlink)(struct inode___151 *, struct dentry___151 *);
	int (*symlink)(struct inode___151 *, struct dentry___151 *, const char *);
	int (*mkdir)(struct inode___151 *, struct dentry___151 *, umode_t);
	int (*rmdir)(struct inode___151 *, struct dentry___151 *);
	int (*mknod)(struct inode___151 *, struct dentry___151 *, umode_t, dev_t);
	int (*rename)(struct inode___151 *, struct dentry___151 *, struct inode___151 *, struct dentry___151 *);
	int (*setattr)(struct dentry___151 *, struct iattr___151 *);
	int (*getattr)(struct vfsmount___38 *, struct dentry___151 *, struct kstat *);
	int (*setxattr)(struct dentry___151 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___151 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___151 *, char *, size_t);
	int (*removexattr)(struct dentry___151 *, const char *);
	int (*fiemap)(struct inode___151 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___151 *, struct timespec *, int);
	int (*atomic_open)(struct inode___151 *, struct dentry___151 *, struct file___151 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___151 {
	struct module___78 *owner;
	loff_t (*llseek)(struct file___151 *, loff_t, int);
	ssize_t (*read)(struct file___151 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___151 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___151 *, void *, filldir_t);
	unsigned int (*poll)(struct file___151 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___151 *, struct vm_area_struct___158 *);
	int (*open)(struct inode___151 *, struct file___151 *);
	int (*flush)(struct file___151 *, fl_owner_t);
	int (*release)(struct inode___151 *, struct file___151 *);
	int (*fsync)(struct file___151 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___151 *, int);
	int (*lock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*sendpage)(struct file___151 *, struct page___150 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___151 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___151 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___151 *, long int, struct file_lock___151 **, void **);
		struct {
			int (*setlease)(struct file___151 *, long int, struct file_lock___151 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___151 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___151 *);
};

struct fasync_struct___151;

struct file_lock_operations___151;

struct lock_manager_operations___151;

struct file_lock___151 {
	struct file_lock___151 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___83 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___151 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___151 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___151 *fl_ops;
	const struct lock_manager_operations___151 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___151 {
	void (*fl_copy_lock)(struct file_lock___151 *, struct file_lock___151 *);
	void (*fl_release_private)(struct file_lock___151 *);
};

struct lock_manager_operations___151 {
	int (*lm_compare_owner)(struct file_lock___151 *, struct file_lock___151 *);
	long unsigned int (*lm_owner_key)(struct file_lock___151 *);
	void (*lm_notify)(struct file_lock___151 *);
	int (*lm_grant)(struct file_lock___151 *, struct file_lock___151 *, int);
	void (*lm_break)(struct file_lock___151 *);
	int (*lm_change)(struct file_lock___151 **, int);
};

struct fasync_struct___151 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___151 *fa_next;
	struct file___151 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___151 {
	const char *name;
	int fs_flags;
	struct dentry___151 * (*mount)(struct file_system_type___151 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___151 *);
	struct module___78 *owner;
	struct file_system_type___151 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___151 {
	struct inode___151 * (*alloc_inode)(struct super_block___151 *);
	void (*destroy_inode)(struct inode___151 *);
	void (*dirty_inode)(struct inode___151 *, int);
	int (*write_inode)(struct inode___151 *, struct writeback_control *);
	int (*drop_inode)(struct inode___151 *);
	void (*evict_inode)(struct inode___151 *);
	void (*put_super)(struct super_block___151 *);
	int (*sync_fs)(struct super_block___151 *, int);
	int (*freeze_fs)(struct super_block___151 *);
	int (*unfreeze_fs)(struct super_block___151 *);
	int (*statfs)(struct dentry___151 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___151 *, int *, char *);
	void (*umount_begin)(struct super_block___151 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___151 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___151 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___151 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___151 *);
	ssize_t (*quota_read)(struct super_block___151 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___151 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___151 *);
	int (*bdev_try_to_free_page)(struct super_block___151 *, struct page___150 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___151 *);
	void (*free_cached_objects)(struct super_block___151 *, int);
};

struct xattr_handler___98 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___151 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___151 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___151 *, const char *, const void *, size_t, int, int);
};

struct cgroupfs_root___98;

struct cgroup___98 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___98 *parent;
	struct dentry___151 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___98 *subsys[11];
	struct cgroupfs_root___98 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___154 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___98 {
	struct super_block___151 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___98 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___48 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___151 *, struct file___151 *);
	ssize_t (*read)(struct cgroup___98 *, struct cftype___48 *, struct file___151 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___98 *, struct cftype___48 *);
	s64 (*read_s64)(struct cgroup___98 *, struct cftype___48 *);
	int (*read_map)(struct cgroup___98 *, struct cftype___48 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___98 *, struct cftype___48 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___98 *, struct cftype___48 *, struct file___151 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___98 *, struct cftype___48 *, u64);
	int (*write_s64)(struct cgroup___98 *, struct cftype___48 *, s64);
	int (*write_string)(struct cgroup___98 *, struct cftype___48 *, const char *);
	int (*trigger)(struct cgroup___98 *, unsigned int);
	int (*release)(struct inode___151 *, struct file___151 *);
	int (*register_event)(struct cgroup___98 *, struct cftype___48 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___98 *, struct cftype___48 *, struct eventfd_ctx *);
};

struct cftype_set___46 {
	struct list_head node;
	struct cftype___48 *cfts;
};

struct task_and_cgroup___46 {
	struct task_struct___153 *task;
	struct cgroup___98 *cgrp;
	struct css_set___98 *cg;
};

struct cgroup_taskset___46 {
	struct task_and_cgroup___46 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___98 *cur_cgrp;
};

struct cgroup_subsys___46 {
	struct cgroup_subsys_state___98 * (*css_alloc)(struct cgroup___98 *);
	int (*css_online)(struct cgroup___98 *);
	void (*css_offline)(struct cgroup___98 *);
	void (*css_free)(struct cgroup___98 *);
	int (*can_attach)(struct cgroup___98 *, struct cgroup_taskset___46 *);
	void (*cancel_attach)(struct cgroup___98 *, struct cgroup_taskset___46 *);
	void (*attach)(struct cgroup___98 *, struct cgroup_taskset___46 *);
	void (*fork)(struct task_struct___153 *);
	void (*exit)(struct cgroup___98 *, struct cgroup___98 *, struct task_struct___153 *);
	void (*bind)(struct cgroup___98 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___98 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___48 *base_cftypes;
	struct cftype_set___46 base_cftset;
	struct module___78 *module;
};

struct dma_map_ops___39 {
	void * (*alloc)(struct device___116 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___116 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___116 *, struct vm_area_struct___158 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___116 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___116 *, struct page___150 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___116 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___116 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___116 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___116 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___116 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___116 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___116 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___116 *, dma_addr_t);
	int (*dma_supported)(struct device___116 *, u64);
	int (*set_dma_mask)(struct device___116 *, u64);
	int is_phys;
};

struct bus_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___116 *, char *);
	ssize_t (*store)(struct bus_type___116 *, const char *, size_t);
};

struct device_attribute___116;

struct driver_attribute___116;

struct bus_type___116 {
	const char *name;
	const char *dev_name;
	struct device___116 *dev_root;
	struct bus_attribute___116 *bus_attrs;
	struct device_attribute___116 *dev_attrs;
	struct driver_attribute___116 *drv_attrs;
	const struct attribute_group___109 **bus_groups;
	const struct attribute_group___109 **dev_groups;
	const struct attribute_group___109 **drv_groups;
	int (*match)(struct device___116 *, struct device_driver___116 *);
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	int (*probe)(struct device___116 *);
	int (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*online)(struct device___116 *);
	int (*offline)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct device___116 *, struct device_attribute___116 *, char *);
	ssize_t (*store)(struct device___116 *, struct device_attribute___116 *, const char *, size_t);
};

struct driver_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___116 *, char *);
	ssize_t (*store)(struct device_driver___116 *, const char *, size_t);
};

struct device_driver___116 {
	const char *name;
	struct bus_type___116 *bus;
	struct module___78 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___116 *);
	int (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	const struct attribute_group___109 **groups;
	const struct dev_pm_ops___116 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___116 {
	const char *name;
	const struct attribute_group___109 **groups;
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
};

struct class_attribute___116;

struct class___116 {
	const char *name;
	struct module___78 *owner;
	struct class_attribute___116 *class_attrs;
	struct device_attribute___116 *dev_attrs;
	const struct attribute_group___109 **dev_groups;
	struct bin_attribute___111 *dev_bin_attrs;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *);
	void (*class_release)(struct class___116 *);
	void (*dev_release)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
	struct subsys_private *p;
};

struct class_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct class___116 *, struct class_attribute___116 *, char *);
	ssize_t (*store)(struct class___116 *, struct class_attribute___116 *, const char *, size_t);
	const void * (*namespace)(struct class___116 *, const struct class_attribute___116 *);
};

struct device_rh___116 {
	struct dev_pm_info_rh___116 power;
};

struct tlb_state___37 {
	struct mm_struct___158 *active_mm;
	int state;
};

struct hstate___15 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___48 cgroup_files[5];
	char name[32];
};

struct coredump_params___23 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___151 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct page___151;

typedef struct page___151 *pgtable_t___151;

struct address_space___152;

struct kmem_cache___138;

struct page___151 {
	long unsigned int flags;
	struct address_space___152 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___151 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___151 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___138 *slab_cache;
		struct page___151 *first_page;
	};
	long: 64;
};

struct task_struct___154;

struct pv_cpu_ops___154 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___154 *);
	void (*end_context_switch)(struct task_struct___154 *);
};

struct mutex___155 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___154 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___147 {
	struct page___151 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___159;

struct signal_struct___154;

struct backing_dev_info___31;

struct task_struct___154 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___154 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___159 *mm;
	struct mm_struct___159 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___154 *real_parent;
	struct task_struct___154 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___154 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___154 = 0,
		VTIME_USER___154 = 1,
		VTIME_SYS___154 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___154 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___31 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___155 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___147 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___159 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___159 *, struct mm_struct___159 *);
	void (*dup_mmap)(struct mm_struct___159 *, struct mm_struct___159 *);
	void (*exit_mmap)(struct mm_struct___159 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___159 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___159 *);
	void (*pgd_free)(struct mm_struct___159 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___159 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___159 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___159 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___159 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___159 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___159 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___159 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___159 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___159 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___159 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___159 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___155 lock;
	void *vdso;
} mm_context_t___155;

struct xol_area___151;

struct uprobes_state___151 {
	struct xol_area___151 *xol_area;
};

struct vm_area_struct___159;

struct file___152;

struct core_state___154;

struct mm_struct___159 {
	struct vm_area_struct___159 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___159 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___159 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___155 context;
	long unsigned int flags;
	struct core_state___154 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___154 *owner;
	struct file___152 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___151 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___79;

struct module_kobject___78 {
	struct kobject___11 kobj;
	struct module___79 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___78;

struct module___79 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___78 mkobj;
	struct module_attribute___78 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___154 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___152;

struct dentry_operations___152;

struct super_block___152;

struct dentry___152 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___152 *d_parent;
	struct qstr d_name;
	struct inode___152 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___152 *d_op;
	struct super_block___152 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___152;

struct address_space___152 {
	struct inode___152 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___155 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___152 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___31 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___152;

struct file_operations___152;

struct file_lock___152;

struct dquot___152;

struct block_device___152;

struct inode___152 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___152 *i_op;
	struct super_block___152 *i_sb;
	struct address_space___152 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___155 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___152 *i_fop;
	struct file_lock___152 *i_flock;
	struct address_space___152 i_data;
	struct dquot___152 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___152 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct vfsmount___39;

struct path___152;

struct dentry_operations___152 {
	int (*d_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_hash)(const struct dentry___152 *, struct qstr *);
	int (*d_compare)(const struct dentry___152 *, const struct dentry___152 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___152 *);
	void (*d_release)(struct dentry___152 *);
	void (*d_prune)(struct dentry___152 *);
	void (*d_iput)(struct dentry___152 *, struct inode___152 *);
	char * (*d_dname)(struct dentry___152 *, char *, int);
	struct vfsmount___39 * (*d_automount)(struct path___152 *);
	int (*d_manage)(struct dentry___152 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___152;

struct mem_dqinfo___152 {
	struct quota_format_type___152 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___152;

struct quota_info___152 {
	unsigned int flags;
	struct mutex___155 dqio_mutex;
	struct mutex___155 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___152 *files[2];
	struct mem_dqinfo___152 info[2];
	const struct quota_format_ops___152 *ops[2];
};

struct file_system_type___152;

struct super_operations___152;

struct dquot_operations___152;

struct quotactl_ops___152;

struct xattr_handler___99;

struct super_block___152 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___152 *s_type;
	const struct super_operations___152 *s_op;
	const struct dquot_operations___152 *dq_op;
	const struct quotactl_ops___152 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___152 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___99 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___152 *s_bdev;
	struct backing_dev_info___31 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___152 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___155 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___152 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___39 {
	struct dentry___152 *mnt_root;
	struct super_block___152 *mnt_sb;
	int mnt_flags;
};

struct path___152 {
	struct vfsmount___39 *mnt;
	struct dentry___152 *dentry;
};

struct zone___154;

struct lruvec___154 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___154 *zone;
};

struct pglist_data___154;

struct zone___154 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___154 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___154 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___154 {
	struct zone___154 *zone;
	int zone_idx;
};

struct zonelist___154 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___154 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___154 {
	struct zone___154 node_zones[4];
	struct zonelist___154 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___154 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___154 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___154 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct file___152 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___152 f_path;
	struct inode___152 *f_inode;
	const struct file_operations___152 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___152 *f_mapping;
	struct mutex___155 f_pos_lock;
};

struct vm_operations_struct___132;

struct vm_area_struct___159 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___159 *vm_next;
	struct vm_area_struct___159 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___159 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___132 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___152 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___78 *, struct module_kobject___78 *, char *);
	ssize_t (*store)(struct module_attribute___78 *, struct module_kobject___78 *, const char *, size_t);
	void (*setup)(struct module___79 *, const char *);
	int (*test)(struct module___79 *);
	void (*free)(struct module___79 *);
};

struct kmem_cache_cpu___137 {
	void **freelist;
	long unsigned int tid;
	struct page___151 *page;
	struct page___151 *partial;
};

struct memcg_cache_params___138;

struct kmem_cache___138 {
	struct kmem_cache_cpu___137 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___11 kobj;
	struct memcg_cache_params___138 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___138 {
	bool is_root_cache;
	union {
		struct kmem_cache___138 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___138 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef int (*initxattrs___2)(struct inode___152 *, const struct xattr *, void *);

struct security_mnt_opts {
	char **mnt_opts;
	int *mnt_opts_flags;
	int num_mnt_opts;
};

struct msg_msg___2;

struct msg_queue___2;

struct shmid_kernel___2;

struct socket___9;

struct request_sock___6;

struct xfrm_sec_ctx;

struct xfrm_user_sec_ctx;

struct iattr___152;

struct security_operations {
	char name[11];
	int (*ptrace_access_check)(struct task_struct___154 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___154 *);
	int (*capget)(struct task_struct___154 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___10 *, const struct cred___10 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___10 *, struct user_namespace *, int, int);
	int (*quotactl)(int, int, int, struct super_block___152 *);
	int (*quota_on)(struct dentry___152 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___159 *, long int);
	int (*bprm_set_creds)(struct linux_binprm *);
	int (*bprm_check_security)(struct linux_binprm *);
	int (*bprm_secureexec)(struct linux_binprm *);
	void (*bprm_committing_creds)(struct linux_binprm *);
	void (*bprm_committed_creds)(struct linux_binprm *);
	int (*sb_alloc_security)(struct super_block___152 *);
	void (*sb_free_security)(struct super_block___152 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___152 *, void *);
	int (*sb_kern_mount)(struct super_block___152 *, int, void *);
	int (*sb_show_options)(struct seq_file___5 *, struct super_block___152 *);
	int (*sb_statfs)(struct dentry___152 *);
	int (*sb_mount)(const char *, struct path___152 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___39 *, int);
	int (*sb_pivotroot)(struct path___152 *, struct path___152 *);
	int (*sb_set_mnt_opts)(struct super_block___152 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___152 *, struct super_block___152 *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___152 *, int, struct qstr *, void **, u32 *);
	int (*inode_alloc_security)(struct inode___152 *);
	void (*inode_free_security)(struct inode___152 *);
	int (*inode_init_security)(struct inode___152 *, struct inode___152 *, const struct qstr *, char **, void **, size_t *);
	int (*inode_create)(struct inode___152 *, struct dentry___152 *, umode_t);
	int (*inode_link)(struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*inode_unlink)(struct inode___152 *, struct dentry___152 *);
	int (*inode_symlink)(struct inode___152 *, struct dentry___152 *, const char *);
	int (*inode_mkdir)(struct inode___152 *, struct dentry___152 *, umode_t);
	int (*inode_rmdir)(struct inode___152 *, struct dentry___152 *);
	int (*inode_mknod)(struct inode___152 *, struct dentry___152 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___152 *, struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*inode_readlink)(struct dentry___152 *);
	int (*inode_follow_link)(struct dentry___152 *, struct nameidata *);
	int (*inode_permission)(struct inode___152 *, int);
	int (*inode_setattr)(struct dentry___152 *, struct iattr___152 *);
	int (*inode_getattr)(struct vfsmount___39 *, struct dentry___152 *);
	int (*inode_setxattr)(struct dentry___152 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___152 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___152 *, const char *);
	int (*inode_listxattr)(struct dentry___152 *);
	int (*inode_removexattr)(struct dentry___152 *, const char *);
	int (*inode_need_killpriv)(struct dentry___152 *);
	int (*inode_killpriv)(struct dentry___152 *);
	int (*inode_getsecurity)(const struct inode___152 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___152 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___152 *, char *, size_t);
	void (*inode_getsecid)(const struct inode___152 *, u32 *);
	int (*file_permission)(struct file___152 *, int);
	int (*file_alloc_security)(struct file___152 *);
	void (*file_free_security)(struct file___152 *);
	int (*file_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___159 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___152 *, unsigned int);
	int (*file_fcntl)(struct file___152 *, unsigned int, long unsigned int);
	int (*file_set_fowner)(struct file___152 *);
	int (*file_send_sigiotask)(struct task_struct___154 *, struct fown_struct___83 *, int);
	int (*file_receive)(struct file___152 *);
	int (*file_open)(struct file___152 *, const struct cred___10 *);
	int (*task_create)(long unsigned int);
	void (*task_free)(struct task_struct___154 *);
	int (*cred_alloc_blank)(struct cred___10 *, gfp_t);
	void (*cred_free)(struct cred___10 *);
	int (*cred_prepare)(struct cred___10 *, const struct cred___10 *, gfp_t);
	void (*cred_transfer)(struct cred___10 *, const struct cred___10 *);
	int (*kernel_act_as)(struct cred___10 *, u32);
	int (*kernel_create_files_as)(struct cred___10 *, struct inode___152 *);
	int (*kernel_module_request)(char *);
	int (*kernel_module_from_file)(struct file___152 *);
	int (*task_fix_setuid)(struct cred___10 *, const struct cred___10 *, int);
	int (*task_setpgid)(struct task_struct___154 *, pid_t);
	int (*task_getpgid)(struct task_struct___154 *);
	int (*task_getsid)(struct task_struct___154 *);
	void (*task_getsecid)(struct task_struct___154 *, u32 *);
	int (*task_setnice)(struct task_struct___154 *, int);
	int (*task_setioprio)(struct task_struct___154 *, int);
	int (*task_getioprio)(struct task_struct___154 *);
	int (*task_setrlimit)(struct task_struct___154 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___154 *);
	int (*task_getscheduler)(struct task_struct___154 *);
	int (*task_movememory)(struct task_struct___154 *);
	int (*task_kill)(struct task_struct___154 *, struct siginfo *, int, u32);
	int (*task_wait)(struct task_struct___154 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___154 *, struct inode___152 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg___2 *);
	void (*msg_msg_free_security)(struct msg_msg___2 *);
	int (*msg_queue_alloc_security)(struct msg_queue___2 *);
	void (*msg_queue_free_security)(struct msg_queue___2 *);
	int (*msg_queue_associate)(struct msg_queue___2 *, int);
	int (*msg_queue_msgctl)(struct msg_queue___2 *, int);
	int (*msg_queue_msgsnd)(struct msg_queue___2 *, struct msg_msg___2 *, int);
	int (*msg_queue_msgrcv)(struct msg_queue___2 *, struct msg_msg___2 *, struct task_struct___154 *, long int, int);
	int (*shm_alloc_security)(struct shmid_kernel___2 *);
	void (*shm_free_security)(struct shmid_kernel___2 *);
	int (*shm_associate)(struct shmid_kernel___2 *, int);
	int (*shm_shmctl)(struct shmid_kernel___2 *, int);
	int (*shm_shmat)(struct shmid_kernel___2 *, char *, int);
	int (*sem_alloc_security)(struct sem_array *);
	void (*sem_free_security)(struct sem_array *);
	int (*sem_associate)(struct sem_array *, int);
	int (*sem_semctl)(struct sem_array *, int);
	int (*sem_semop)(struct sem_array *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___9 *);
	void (*d_instantiate)(struct dentry___152 *, struct inode___152 *);
	int (*getprocattr)(struct task_struct___154 *, char *, char **);
	int (*setprocattr)(struct task_struct___154 *, char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	int (*inode_notifysecctx)(struct inode___152 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___152 *, void *, u32);
	int (*inode_getsecctx)(struct inode___152 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___9 *, struct socket___9 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___9 *, int, int, int, int);
	int (*socket_bind)(struct socket___9 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___9 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___9 *, int);
	int (*socket_accept)(struct socket___9 *, struct socket___9 *);
	int (*socket_sendmsg)(struct socket___9 *, struct msghdr *, int);
	int (*socket_recvmsg)(struct socket___9 *, struct msghdr *, int, int);
	int (*socket_getsockname)(struct socket___9 *);
	int (*socket_getpeername)(struct socket___9 *);
	int (*socket_getsockopt)(struct socket___9 *, int, int);
	int (*socket_setsockopt)(struct socket___9 *, int, int);
	int (*socket_shutdown)(struct socket___9 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___9 *);
	int (*socket_getpeersec_stream)(struct socket___9 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___9 *, struct sk_buff___9 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___9 *);
	int (*inet_conn_request)(struct sock *, struct sk_buff___9 *, struct request_sock___6 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___6 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___9 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___6 *, struct flowi *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	void (*skb_owned_by)(struct sk_buff___9 *, struct sock *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc_security)(struct xfrm_state *, struct xfrm_user_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi *);
	int (*xfrm_decode_session)(struct sk_buff___9 *, u32 *, int);
	int (*key_alloc)(struct key___10 *, const struct cred___10 *, long unsigned int);
	void (*key_free)(struct key___10 *);
	int (*key_permission)(key_ref_t, const struct cred___10 *, key_perm_t);
	int (*key_getsecurity)(struct key___10 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
};

struct iattr___152 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___152 *ia_file;
};

struct block_device___152 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___152 *bd_inode;
	struct super_block___152 *bd_super;
	struct mutex___155 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___152 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___155 bd_fsfreeze_mutex;
};

struct dquot___152 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___155 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___152 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___152 {
	int qf_fmt_id;
	const struct quota_format_ops___152 *qf_ops;
	struct module___79 *qf_owner;
	struct quota_format_type___152 *qf_next;
};

struct quota_format_ops___152 {
	int (*check_quota_file)(struct super_block___152 *, int);
	int (*read_file_info)(struct super_block___152 *, int);
	int (*write_file_info)(struct super_block___152 *, int);
	int (*free_file_info)(struct super_block___152 *, int);
	int (*read_dqblk)(struct dquot___152 *);
	int (*commit_dqblk)(struct dquot___152 *);
	int (*release_dqblk)(struct dquot___152 *);
};

struct dquot_operations___152 {
	int (*write_dquot)(struct dquot___152 *);
	struct dquot___152 * (*alloc_dquot)(struct super_block___152 *, int);
	void (*destroy_dquot)(struct dquot___152 *);
	int (*acquire_dquot)(struct dquot___152 *);
	int (*release_dquot)(struct dquot___152 *);
	int (*mark_dirty)(struct dquot___152 *);
	int (*write_info)(struct super_block___152 *, int);
	qsize_t * (*get_reserved_space)(struct inode___152 *);
};

struct quotactl_ops___152 {
	int (*quota_on)(struct super_block___152 *, int, int, struct path___152 *);
	int (*quota_on_meta)(struct super_block___152 *, int, int);
	int (*quota_off)(struct super_block___152 *, int);
	int (*quota_sync)(struct super_block___152 *, int);
	int (*get_info)(struct super_block___152 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___152 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___152 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___152 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___152 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___152 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___152 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___152 *, unsigned int);
};

struct address_space_operations___152 {
	int (*writepage)(struct page___151 *, struct writeback_control *);
	int (*readpage)(struct file___152 *, struct page___151 *);
	int (*writepages)(struct address_space___152 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___151 *);
	int (*readpages)(struct file___152 *, struct address_space___152 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___152 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___151 **, void **);
	int (*write_end)(struct file___152 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___151 *, void *);
	sector_t (*bmap)(struct address_space___152 *, sector_t);
	void (*invalidatepage)(struct page___151 *, long unsigned int);
	int (*releasepage)(struct page___151 *, gfp_t);
	void (*freepage)(struct page___151 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___152 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___152 *, struct page___151 *, struct page___151 *, enum migrate_mode);
	int (*launder_page)(struct page___151 *);
	int (*is_partially_uptodate)(struct page___151 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___151 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___152 *, struct page___151 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___152 *, sector_t *);
	void (*swap_deactivate)(struct file___152 *);
	void (*invalidatepage_range)(struct page___151 *, unsigned int, unsigned int);
};

struct bdi_writeback___31 {
	struct backing_dev_info___31 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___31 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___31 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___31 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___152 *debug_dir;
	struct dentry___152 *debug_stats;
};

struct inode_operations___152 {
	struct dentry___152 * (*lookup)(struct inode___152 *, struct dentry___152 *, unsigned int);
	void * (*follow_link)(struct dentry___152 *, struct nameidata *);
	int (*permission)(struct inode___152 *, int);
	struct posix_acl * (*get_acl)(struct inode___152 *, int);
	int (*readlink)(struct dentry___152 *, char *, int);
	void (*put_link)(struct dentry___152 *, struct nameidata *, void *);
	int (*create)(struct inode___152 *, struct dentry___152 *, umode_t, bool);
	int (*link)(struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*unlink)(struct inode___152 *, struct dentry___152 *);
	int (*symlink)(struct inode___152 *, struct dentry___152 *, const char *);
	int (*mkdir)(struct inode___152 *, struct dentry___152 *, umode_t);
	int (*rmdir)(struct inode___152 *, struct dentry___152 *);
	int (*mknod)(struct inode___152 *, struct dentry___152 *, umode_t, dev_t);
	int (*rename)(struct inode___152 *, struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*setattr)(struct dentry___152 *, struct iattr___152 *);
	int (*getattr)(struct vfsmount___39 *, struct dentry___152 *, struct kstat *);
	int (*setxattr)(struct dentry___152 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___152 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___152 *, char *, size_t);
	int (*removexattr)(struct dentry___152 *, const char *);
	int (*fiemap)(struct inode___152 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___152 *, struct timespec *, int);
	int (*atomic_open)(struct inode___152 *, struct dentry___152 *, struct file___152 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___152 {
	struct module___79 *owner;
	loff_t (*llseek)(struct file___152 *, loff_t, int);
	ssize_t (*read)(struct file___152 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___152 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___152 *, void *, filldir_t);
	unsigned int (*poll)(struct file___152 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___152 *, struct vm_area_struct___159 *);
	int (*open)(struct inode___152 *, struct file___152 *);
	int (*flush)(struct file___152 *, fl_owner_t);
	int (*release)(struct inode___152 *, struct file___152 *);
	int (*fsync)(struct file___152 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___152 *, int);
	int (*lock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*sendpage)(struct file___152 *, struct page___151 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___152 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___152 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___152 *, long int, struct file_lock___152 **, void **);
		struct {
			int (*setlease)(struct file___152 *, long int, struct file_lock___152 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___152 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___152 *);
};

struct fasync_struct___152;

struct file_lock_operations___152;

struct lock_manager_operations___152;

struct file_lock___152 {
	struct file_lock___152 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___83 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___152 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___152 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___152 *fl_ops;
	const struct lock_manager_operations___152 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___152 {
	void (*fl_copy_lock)(struct file_lock___152 *, struct file_lock___152 *);
	void (*fl_release_private)(struct file_lock___152 *);
};

struct lock_manager_operations___152 {
	int (*lm_compare_owner)(struct file_lock___152 *, struct file_lock___152 *);
	long unsigned int (*lm_owner_key)(struct file_lock___152 *);
	void (*lm_notify)(struct file_lock___152 *);
	int (*lm_grant)(struct file_lock___152 *, struct file_lock___152 *, int);
	void (*lm_break)(struct file_lock___152 *);
	int (*lm_change)(struct file_lock___152 **, int);
};

struct fasync_struct___152 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___152 *fa_next;
	struct file___152 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___152 {
	const char *name;
	int fs_flags;
	struct dentry___152 * (*mount)(struct file_system_type___152 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___152 *);
	struct module___79 *owner;
	struct file_system_type___152 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___152 {
	struct inode___152 * (*alloc_inode)(struct super_block___152 *);
	void (*destroy_inode)(struct inode___152 *);
	void (*dirty_inode)(struct inode___152 *, int);
	int (*write_inode)(struct inode___152 *, struct writeback_control *);
	int (*drop_inode)(struct inode___152 *);
	void (*evict_inode)(struct inode___152 *);
	void (*put_super)(struct super_block___152 *);
	int (*sync_fs)(struct super_block___152 *, int);
	int (*freeze_fs)(struct super_block___152 *);
	int (*unfreeze_fs)(struct super_block___152 *);
	int (*statfs)(struct dentry___152 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___152 *, int *, char *);
	void (*umount_begin)(struct super_block___152 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___152 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___152 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___152 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___152 *);
	ssize_t (*quota_read)(struct super_block___152 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___152 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___152 *);
	int (*bdev_try_to_free_page)(struct super_block___152 *, struct page___151 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___152 *);
	void (*free_cached_objects)(struct super_block___152 *, int);
};

struct xattr_handler___99 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___152 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___152 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___152 *, const char *, const void *, size_t, int, int);
};

struct xol_area___151 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___151 *page;
	long unsigned int vaddr;
};

struct vm_fault___129;

struct vm_operations_struct___132 {
	void (*open)(struct vm_area_struct___159 *);
	void (*close)(struct vm_area_struct___159 *);
	int (*fault)(struct vm_area_struct___159 *, struct vm_fault___129 *);
	int (*page_mkwrite)(struct vm_area_struct___159 *, struct vm_fault___129 *);
	int (*access)(struct vm_area_struct___159 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___159 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___159 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___159 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___159 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___154 {
	struct task_struct___154 *task;
	struct core_thread___154 *next;
};

struct core_state___154 {
	atomic_t nr_threads;
	struct core_thread___154 dumper;
	struct completion startup;
};

struct signal_struct___154 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___154 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___154 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___155 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___129 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___151 *page;
};

struct page___152;

typedef struct page___152 *pgtable_t___152;

struct address_space___153;

struct kmem_cache___139;

struct page___152 {
	long unsigned int flags;
	struct address_space___153 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___152 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___152 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___139 *slab_cache;
		struct page___152 *first_page;
	};
	long: 64;
};

struct task_struct___155;

struct pv_cpu_ops___155 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___74 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___74 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___155 *);
	void (*end_context_switch)(struct task_struct___155 *);
};

struct mutex___156 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___155 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___148 {
	struct page___152 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___160;

struct nsproxy___90;

struct signal_struct___155;

struct css_set___99;

struct task_struct___155 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___155 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___160 *mm;
	struct mm_struct___160 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___155 *real_parent;
	struct task_struct___155 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___155 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___83 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___155 = 0,
		VTIME_USER___155 = 1,
		VTIME_SYS___155 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___74 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___90 *nsproxy;
	struct signal_struct___155 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___99 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___156 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___148 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___160 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___160 *, struct mm_struct___160 *);
	void (*dup_mmap)(struct mm_struct___160 *, struct mm_struct___160 *);
	void (*exit_mmap)(struct mm_struct___160 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___160 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___160 *);
	void (*pgd_free)(struct mm_struct___160 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___160 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___160 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___160 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___160 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___160 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___160 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___160 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___160 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___160 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___160 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___160 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___156 lock;
	void *vdso;
} mm_context_t___156;

struct xol_area___152;

struct uprobes_state___152 {
	struct xol_area___152 *xol_area;
};

struct vm_area_struct___160;

struct file___153;

struct core_state___155;

struct mm_struct___160 {
	struct vm_area_struct___160 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___160 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___160 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___156 context;
	long unsigned int flags;
	struct core_state___155 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___155 *owner;
	struct file___153 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___152 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___155;

struct lruvec___155 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___155 *zone;
};

struct pglist_data___155;

struct zone___155 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___155 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___155 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___155 {
	struct zone___155 *zone;
	int zone_idx;
};

struct zonelist___155 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___155 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___155 {
	struct zone___155 node_zones[4];
	struct zonelist___155 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___155 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___106;

struct x86_io_apic_ops___106 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___106 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___106;

struct irq_data___106 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___106 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___117;

struct dev_pm_ops___117 {
	int (*prepare)(struct device___117 *);
	void (*complete)(struct device___117 *);
	int (*suspend)(struct device___117 *);
	int (*resume)(struct device___117 *);
	int (*freeze)(struct device___117 *);
	int (*thaw)(struct device___117 *);
	int (*poweroff)(struct device___117 *);
	int (*restore)(struct device___117 *);
	int (*suspend_late)(struct device___117 *);
	int (*resume_early)(struct device___117 *);
	int (*freeze_late)(struct device___117 *);
	int (*thaw_early)(struct device___117 *);
	int (*poweroff_late)(struct device___117 *);
	int (*restore_early)(struct device___117 *);
	int (*suspend_noirq)(struct device___117 *);
	int (*resume_noirq)(struct device___117 *);
	int (*freeze_noirq)(struct device___117 *);
	int (*thaw_noirq)(struct device___117 *);
	int (*poweroff_noirq)(struct device___117 *);
	int (*restore_noirq)(struct device___117 *);
	int (*runtime_suspend)(struct device___117 *);
	int (*runtime_resume)(struct device___117 *);
	int (*runtime_idle)(struct device___117 *);
};

struct kset___12;

struct kobj_type___12;

struct kobject___12 {
	const char *name;
	struct list_head entry;
	struct kobject___12 *parent;
	struct kset___12 *kset;
	struct kobj_type___12 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___14;

struct dev_pm_info___14 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___14 *qos;
};

struct dma_map_ops___40;

struct dev_archdata___40 {
	struct dma_map_ops___40 *dma_ops;
	void *iommu;
};

struct device_type___117;

struct bus_type___117;

struct device_driver___117;

struct dev_pm_domain___117;

struct class___117;

struct attribute_group___110;

struct device_rh___117;

struct device___117 {
	struct device___117 *parent;
	struct device_private *p;
	struct kobject___12 kobj;
	const char *init_name;
	const struct device_type___117 *type;
	struct mutex___156 mutex;
	struct bus_type___117 *bus;
	struct device_driver___117 *driver;
	void *platform_data;
	struct dev_pm_info___14 power;
	struct dev_pm_domain___117 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___40 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___117 *class;
	const struct attribute_group___110 **groups;
	void (*release)(struct device___117 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___117 *device_rh;
};

struct dev_pm_qos_request___14;

struct dev_pm_qos___14 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___14 *latency_req;
	struct dev_pm_qos_request___14 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___14 *latency_tolerance_req;
};

struct dev_pm_info_rh___117 {
	void (*set_latency_tolerance)(struct device___117 *, s32);
};

struct dev_pm_domain___117 {
	struct dev_pm_ops___117 ops;
};

struct smp_ops___155 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___155 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___10;

struct kobj_ns_type_operations___9 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___10 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___9;

struct net___21;

struct sock_common___9 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___9 *skc_prot;
	struct net___21 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___14;

struct sk_buff_head___11 {
	struct sk_buff___14 *next;
	struct sk_buff___14 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___10;

struct socket_wq___9;

struct dst_entry___9;

struct socket___10;

struct cg_proto___9;

struct sock___10 {
	struct sock_common___9 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___11 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___14 *head;
		struct sk_buff___14 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___10 *sk_filter;
	struct socket_wq___9 *sk_wq;
	struct sk_buff_head___11 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___9 *sk_rx_dst;
	struct dst_entry___9 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___11 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___11 sk_error_queue;
	struct proto___9 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___83 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___10 *sk_socket;
	void *sk_user_data;
	struct page_frag___148 sk_frag;
	struct sk_buff___14 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___9 *sk_cgrp;
	void (*sk_state_change)(struct sock___10 *);
	void (*sk_data_ready)(struct sock___10 *, int);
	void (*sk_write_space)(struct sock___10 *);
	void (*sk_error_report)(struct sock___10 *);
	int (*sk_backlog_rcv)(struct sock___10 *, struct sk_buff___14 *);
	void (*sk_destruct)(struct sock___10 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___112;

struct attribute_group___110 {
	const char *name;
	umode_t (*is_visible)(struct kobject___12 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___112 **bin_attrs;
};

struct bin_attribute___112 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___153 *, struct kobject___12 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___153 *, struct kobject___12 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	int (*mmap)(struct file___153 *, struct kobject___12 *, struct bin_attribute___112 *, struct vm_area_struct___160 *);
};

struct dentry___153;

struct path___153 {
	struct vfsmount *mnt;
	struct dentry___153 *dentry;
};

struct inode___153;

struct file_operations___153;

struct file___153 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___153 f_path;
	struct inode___153 *f_inode;
	const struct file_operations___153 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___153 *f_mapping;
	struct mutex___156 f_pos_lock;
};

struct vm_operations_struct___133;

struct vm_area_struct___160 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___160 *vm_next;
	struct vm_area_struct___160 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___160 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___133 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___153 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___12 {
	ssize_t (*show)(struct kobject___12 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___12 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___12 *, const struct attribute *);
};

struct kset_uevent_ops___12;

struct kset___12 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___12 kobj;
	const struct kset_uevent_ops___12 *uevent_ops;
};

struct kobj_type___12 {
	void (*release)(struct kobject___12 *);
	const struct sysfs_ops___12 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___12 *);
	const void * (*namespace)(struct kobject___12 *);
};

struct kset_uevent_ops___12 {
	int (* const filter)(struct kset___12 *, struct kobject___12 *);
	const char * (* const name)(struct kset___12 *, struct kobject___12 *);
	int (* const uevent)(struct kset___12 *, struct kobject___12 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___138 {
	void **freelist;
	long unsigned int tid;
	struct page___152 *page;
	struct page___152 *partial;
};

struct memcg_cache_params___139;

struct kmem_cache___139 {
	struct kmem_cache_cpu___138 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___12 kobj;
	struct memcg_cache_params___139 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___139 {
	bool is_root_cache;
	union {
		struct kmem_cache___139 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___139 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___153;

struct super_block___153;

struct dentry___153 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___153 *d_parent;
	struct qstr d_name;
	struct inode___153 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___153 *d_op;
	struct super_block___153 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___153;

struct address_space___153 {
	struct inode___153 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___156 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___153 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___153;

struct file_lock___153;

struct dquot___153;

struct block_device___153;

struct inode___153 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___153 *i_op;
	struct super_block___153 *i_sb;
	struct address_space___153 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___156 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___153 *i_fop;
	struct file_lock___153 *i_flock;
	struct address_space___153 i_data;
	struct dquot___153 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___153 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___153 {
	int (*d_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_hash)(const struct dentry___153 *, struct qstr *);
	int (*d_compare)(const struct dentry___153 *, const struct dentry___153 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___153 *);
	void (*d_release)(struct dentry___153 *);
	void (*d_prune)(struct dentry___153 *);
	void (*d_iput)(struct dentry___153 *, struct inode___153 *);
	char * (*d_dname)(struct dentry___153 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___153 *);
	int (*d_manage)(struct dentry___153 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___153;

struct mem_dqinfo___153 {
	struct quota_format_type___153 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___153;

struct quota_info___153 {
	unsigned int flags;
	struct mutex___156 dqio_mutex;
	struct mutex___156 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___153 *files[2];
	struct mem_dqinfo___153 info[2];
	const struct quota_format_ops___153 *ops[2];
};

struct file_system_type___153;

struct super_operations___153;

struct dquot_operations___153;

struct quotactl_ops___153;

struct xattr_handler___100;

struct super_block___153 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___153 *s_type;
	const struct super_operations___153 *s_op;
	const struct dquot_operations___153 *dq_op;
	const struct quotactl_ops___153 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___153 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___100 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___153 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___153 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___156 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___153 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___153 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___153 *bd_inode;
	struct super_block___153 *bd_super;
	struct mutex___156 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___153 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___156 bd_fsfreeze_mutex;
};

struct cgroup___99;

struct cgroup_subsys_state___99 {
	struct cgroup___99 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___16;

typedef int kiocb_cancel_fn___16(struct kiocb___16 *, struct io_event *);

struct kiocb___16 {
	atomic_t ki_users;
	struct file___153 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___16 *ki_cancel;
	void (*ki_dtor)(struct kiocb___16 *);
	union {
		void *user;
		struct task_struct___155 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___153 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___153 *ia_file;
};

struct dquot___153 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___156 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___153 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___153 {
	int qf_fmt_id;
	const struct quota_format_ops___153 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___153 *qf_next;
};

struct quota_format_ops___153 {
	int (*check_quota_file)(struct super_block___153 *, int);
	int (*read_file_info)(struct super_block___153 *, int);
	int (*write_file_info)(struct super_block___153 *, int);
	int (*free_file_info)(struct super_block___153 *, int);
	int (*read_dqblk)(struct dquot___153 *);
	int (*commit_dqblk)(struct dquot___153 *);
	int (*release_dqblk)(struct dquot___153 *);
};

struct dquot_operations___153 {
	int (*write_dquot)(struct dquot___153 *);
	struct dquot___153 * (*alloc_dquot)(struct super_block___153 *, int);
	void (*destroy_dquot)(struct dquot___153 *);
	int (*acquire_dquot)(struct dquot___153 *);
	int (*release_dquot)(struct dquot___153 *);
	int (*mark_dirty)(struct dquot___153 *);
	int (*write_info)(struct super_block___153 *, int);
	qsize_t * (*get_reserved_space)(struct inode___153 *);
};

struct quotactl_ops___153 {
	int (*quota_on)(struct super_block___153 *, int, int, struct path___153 *);
	int (*quota_on_meta)(struct super_block___153 *, int, int);
	int (*quota_off)(struct super_block___153 *, int);
	int (*quota_sync)(struct super_block___153 *, int);
	int (*get_info)(struct super_block___153 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___153 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___153 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___153 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___153 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___153 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___153 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___153 *, unsigned int);
};

struct address_space_operations___153 {
	int (*writepage)(struct page___152 *, struct writeback_control *);
	int (*readpage)(struct file___153 *, struct page___152 *);
	int (*writepages)(struct address_space___153 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___152 *);
	int (*readpages)(struct file___153 *, struct address_space___153 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___153 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___152 **, void **);
	int (*write_end)(struct file___153 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___152 *, void *);
	sector_t (*bmap)(struct address_space___153 *, sector_t);
	void (*invalidatepage)(struct page___152 *, long unsigned int);
	int (*releasepage)(struct page___152 *, gfp_t);
	void (*freepage)(struct page___152 *);
	ssize_t (*direct_IO)(int, struct kiocb___16 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___153 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___153 *, struct page___152 *, struct page___152 *, enum migrate_mode);
	int (*launder_page)(struct page___152 *);
	int (*is_partially_uptodate)(struct page___152 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___152 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___153 *, struct page___152 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___153 *, sector_t *);
	void (*swap_deactivate)(struct file___153 *);
	void (*invalidatepage_range)(struct page___152 *, unsigned int, unsigned int);
};

struct inode_operations___153 {
	struct dentry___153 * (*lookup)(struct inode___153 *, struct dentry___153 *, unsigned int);
	void * (*follow_link)(struct dentry___153 *, struct nameidata *);
	int (*permission)(struct inode___153 *, int);
	struct posix_acl * (*get_acl)(struct inode___153 *, int);
	int (*readlink)(struct dentry___153 *, char *, int);
	void (*put_link)(struct dentry___153 *, struct nameidata *, void *);
	int (*create)(struct inode___153 *, struct dentry___153 *, umode_t, bool);
	int (*link)(struct dentry___153 *, struct inode___153 *, struct dentry___153 *);
	int (*unlink)(struct inode___153 *, struct dentry___153 *);
	int (*symlink)(struct inode___153 *, struct dentry___153 *, const char *);
	int (*mkdir)(struct inode___153 *, struct dentry___153 *, umode_t);
	int (*rmdir)(struct inode___153 *, struct dentry___153 *);
	int (*mknod)(struct inode___153 *, struct dentry___153 *, umode_t, dev_t);
	int (*rename)(struct inode___153 *, struct dentry___153 *, struct inode___153 *, struct dentry___153 *);
	int (*setattr)(struct dentry___153 *, struct iattr___153 *);
	int (*getattr)(struct vfsmount *, struct dentry___153 *, struct kstat *);
	int (*setxattr)(struct dentry___153 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___153 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___153 *, char *, size_t);
	int (*removexattr)(struct dentry___153 *, const char *);
	int (*fiemap)(struct inode___153 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___153 *, struct timespec *, int);
	int (*atomic_open)(struct inode___153 *, struct dentry___153 *, struct file___153 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___92;

struct seq_file___112;

struct file_operations___153 {
	struct module *owner;
	loff_t (*llseek)(struct file___153 *, loff_t, int);
	ssize_t (*read)(struct file___153 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___153 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___16 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___16 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___153 *, void *, filldir_t);
	unsigned int (*poll)(struct file___153 *, struct poll_table_struct___92 *);
	long int (*unlocked_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___153 *, struct vm_area_struct___160 *);
	int (*open)(struct inode___153 *, struct file___153 *);
	int (*flush)(struct file___153 *, fl_owner_t);
	int (*release)(struct inode___153 *, struct file___153 *);
	int (*fsync)(struct file___153 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___16 *, int);
	int (*fasync)(int, struct file___153 *, int);
	int (*lock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*sendpage)(struct file___153 *, struct page___152 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___153 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___153 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___153 *, long int, struct file_lock___153 **, void **);
		struct {
			int (*setlease)(struct file___153 *, long int, struct file_lock___153 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___153 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___112 *, struct file___153 *);
};

struct fasync_struct___153;

struct file_lock_operations___153;

struct lock_manager_operations___153;

struct file_lock___153 {
	struct file_lock___153 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___83 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___153 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___153 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___153 *fl_ops;
	const struct lock_manager_operations___153 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___153 {
	void (*fl_copy_lock)(struct file_lock___153 *, struct file_lock___153 *);
	void (*fl_release_private)(struct file_lock___153 *);
};

struct lock_manager_operations___153 {
	int (*lm_compare_owner)(struct file_lock___153 *, struct file_lock___153 *);
	long unsigned int (*lm_owner_key)(struct file_lock___153 *);
	void (*lm_notify)(struct file_lock___153 *);
	int (*lm_grant)(struct file_lock___153 *, struct file_lock___153 *, int);
	void (*lm_break)(struct file_lock___153 *);
	int (*lm_change)(struct file_lock___153 **, int);
};

struct fasync_struct___153 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___153 *fa_next;
	struct file___153 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___153 {
	const char *name;
	int fs_flags;
	struct dentry___153 * (*mount)(struct file_system_type___153 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___153 *);
	struct module *owner;
	struct file_system_type___153 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___153 {
	struct inode___153 * (*alloc_inode)(struct super_block___153 *);
	void (*destroy_inode)(struct inode___153 *);
	void (*dirty_inode)(struct inode___153 *, int);
	int (*write_inode)(struct inode___153 *, struct writeback_control *);
	int (*drop_inode)(struct inode___153 *);
	void (*evict_inode)(struct inode___153 *);
	void (*put_super)(struct super_block___153 *);
	int (*sync_fs)(struct super_block___153 *, int);
	int (*freeze_fs)(struct super_block___153 *);
	int (*unfreeze_fs)(struct super_block___153 *);
	int (*statfs)(struct dentry___153 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___153 *, int *, char *);
	void (*umount_begin)(struct super_block___153 *);
	int (*show_options)(struct seq_file___112 *, struct dentry___153 *);
	int (*show_devname)(struct seq_file___112 *, struct dentry___153 *);
	int (*show_path)(struct seq_file___112 *, struct dentry___153 *);
	int (*show_stats)(struct seq_file___112 *, struct dentry___153 *);
	ssize_t (*quota_read)(struct super_block___153 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___153 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___153 *);
	int (*bdev_try_to_free_page)(struct super_block___153 *, struct page___152 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___153 *);
	void (*free_cached_objects)(struct super_block___153 *, int);
};

struct xattr_handler___100 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___153 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___153 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___153 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___94)(struct file___153 *, wait_queue_head_t *, struct poll_table_struct___92 *);

struct poll_table_struct___92 {
	poll_queue_proc___94 _qproc;
	long unsigned int _key;
};

struct seq_operations___111;

struct seq_file___112 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___156 lock;
	const struct seq_operations___111 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___152 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___152 *page;
	long unsigned int vaddr;
};

struct vm_fault___130;

struct vm_operations_struct___133 {
	void (*open)(struct vm_area_struct___160 *);
	void (*close)(struct vm_area_struct___160 *);
	int (*fault)(struct vm_area_struct___160 *, struct vm_fault___130 *);
	int (*page_mkwrite)(struct vm_area_struct___160 *, struct vm_fault___130 *);
	int (*access)(struct vm_area_struct___160 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___160 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___160 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___160 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___160 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___155 {
	struct task_struct___155 *task;
	struct core_thread___155 *next;
};

struct core_state___155 {
	atomic_t nr_threads;
	struct core_thread___155 dumper;
	struct completion startup;
};

struct socket_wq___9 {
	wait_queue_head_t wait;
	struct fasync_struct___153 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___9;

struct socket___10 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___9 *wq;
	struct file___153 *file;
	struct sock___10 *sk;
	const struct proto_ops___9 *ops;
};

struct proto_ops___9 {
	int family;
	struct module *owner;
	int (*release)(struct socket___10 *);
	int (*bind)(struct socket___10 *, struct sockaddr *, int);
	int (*connect)(struct socket___10 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___10 *, struct socket___10 *);
	int (*accept)(struct socket___10 *, struct socket___10 *, int);
	int (*getname)(struct socket___10 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___153 *, struct socket___10 *, struct poll_table_struct___92 *);
	int (*ioctl)(struct socket___10 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___10 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___10 *, int);
	int (*shutdown)(struct socket___10 *, int);
	int (*setsockopt)(struct socket___10 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___10 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___10 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___10 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___16 *, struct socket___10 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___16 *, struct socket___10 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___153 *, struct socket___10 *, struct vm_area_struct___160 *);
	ssize_t (*sendpage)(struct socket___10 *, struct page___152 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___10 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___10 *, int);
		struct {
			void (*set_peek_off)(struct sock___10 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct ctl_table_root___23;

struct ctl_table_set___23;

struct ctl_dir___23;

struct ctl_node___23;

struct ctl_table_header___23 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___23 *root;
	struct ctl_table_set___23 *set;
	struct ctl_dir___23 *parent;
	struct ctl_node___23 *node;
};

struct ctl_dir___23 {
	struct ctl_table_header___23 header;
	struct rb_root root;
};

struct ctl_table_set___23 {
	int (*is_seen)(struct ctl_table_set___23 *);
	struct ctl_dir___23 dir;
};

struct netns_core___20 {
	struct ctl_table_header___23 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___20 {
	struct mutex___156 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___20 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___23 *ctl;
};

struct netns_ipv4___20 {
	struct ctl_table_header___23 *forw_hdr;
	struct ctl_table_header___23 *frags_hdr;
	struct ctl_table_header___23 *ipv4_hdr;
	struct ctl_table_header___23 *route_hdr;
	struct ctl_table_header___23 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___10 *fibnl;
	struct sock___10 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___20 {
	struct ctl_table_header___23 *hdr;
	struct ctl_table_header___23 *route_hdr;
	struct ctl_table_header___23 *icmp_hdr;
	struct ctl_table_header___23 *frags_hdr;
	struct ctl_table_header___23 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___12;

struct neighbour___9;

struct dst_ops___20 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___20 *);
	struct dst_entry___9 * (*check)(struct dst_entry___9 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___9 *);
	unsigned int (*mtu)(const struct dst_entry___9 *);
	u32 * (*cow_metrics)(struct dst_entry___9 *, long unsigned int);
	void (*destroy)(struct dst_entry___9 *);
	void (*ifdown)(struct dst_entry___9 *, struct net_device___12 *, int);
	struct dst_entry___9 * (*negative_advice)(struct dst_entry___9 *);
	void (*link_failure)(struct sk_buff___14 *);
	void (*update_pmtu)(struct dst_entry___9 *, struct sock___10 *, struct sk_buff___14 *, u32);
	void (*redirect)(struct dst_entry___9 *, struct sock___10 *, struct sk_buff___14 *);
	int (*local_out)(struct sk_buff___14 *);
	struct neighbour___9 * (*neigh_lookup)(const struct dst_entry___9 *, struct sk_buff___14 *, const void *);
	struct kmem_cache___139 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___20 {
	struct netns_sysctl_ipv6___20 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___20 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___10 **icmp_sk;
	struct sock___10 *ndisc_sk;
	struct sock___10 *tcp_sk;
	struct sock___10 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___20 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___23 *sysctl_header;
	struct sock___10 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___9 {
	struct sock___10 *v4_ctl_sk;
	struct sock___10 *v6_ctl_sk;
};

struct netns_nf___20 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___23 *nf_log_dir_header;
};

struct nf_proto_net___20 {
	struct ctl_table_header___23 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___20 {
	struct nf_proto_net___20 pn;
	unsigned int timeout;
};

struct nf_tcp_net___20 {
	struct nf_proto_net___20 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___20 {
	struct nf_proto_net___20 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___20 {
	struct nf_proto_net___20 pn;
	unsigned int timeout;
};

struct nf_ip_net___20 {
	struct nf_generic_net___20 generic;
	struct nf_tcp_net___20 tcp;
	struct nf_udp_net___20 udp;
	struct nf_icmp_net___20 icmp;
	struct nf_icmp_net___20 icmpv6;
};

struct netns_ct___20 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___23 *sysctl_header;
	struct ctl_table_header___23 *acct_sysctl_header;
	struct ctl_table_header___23 *tstamp_sysctl_header;
	struct ctl_table_header___23 *event_sysctl_header;
	struct ctl_table_header___23 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___139 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___20 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___20 {
	struct netns_sysctl_ipv6___20 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___20 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___10 *nlsk;
	struct sock___10 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___23 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___20 xfrm4_dst_ops;
	struct dst_ops___20 xfrm6_dst_ops;
};

struct net___21 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___23 sysctls;
	struct sock___10 *rtnl;
	struct sock___10 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___12 *loopback_dev;
	struct netns_core___20 core;
	struct netns_mib___2 mib;
	struct netns_packet___20 packet;
	struct netns_unix___20 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___20 ipv4;
	struct netns_ipv6___20 ipv6;
	struct netns_sctp___20 sctp;
	struct netns_dccp___9 dccp;
	struct netns_nf___20 nf;
	struct netns_xt xt;
	struct netns_ct___20 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___20 nf_frag;
	struct sock___10 *nfnl;
	struct sock___10 *nfnl_stash;
	struct sk_buff_head___11 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___20 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___10 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___10 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___156 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___156 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___40 {
	void * (*alloc)(struct device___117 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___117 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___117 *, struct vm_area_struct___160 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___117 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___117 *, struct page___152 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___117 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___117 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___117 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___117 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___117 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___117 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___117 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___117 *, dma_addr_t);
	int (*dma_supported)(struct device___117 *, u64);
	int (*set_dma_mask)(struct device___117 *, u64);
	int is_phys;
};

struct bus_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___117 *, char *);
	ssize_t (*store)(struct bus_type___117 *, const char *, size_t);
};

struct device_attribute___117;

struct driver_attribute___117;

struct bus_type___117 {
	const char *name;
	const char *dev_name;
	struct device___117 *dev_root;
	struct bus_attribute___117 *bus_attrs;
	struct device_attribute___117 *dev_attrs;
	struct driver_attribute___117 *drv_attrs;
	const struct attribute_group___110 **bus_groups;
	const struct attribute_group___110 **dev_groups;
	const struct attribute_group___110 **drv_groups;
	int (*match)(struct device___117 *, struct device_driver___117 *);
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	int (*probe)(struct device___117 *);
	int (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*online)(struct device___117 *);
	int (*offline)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct device___117 *, struct device_attribute___117 *, char *);
	ssize_t (*store)(struct device___117 *, struct device_attribute___117 *, const char *, size_t);
};

struct driver_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___117 *, char *);
	ssize_t (*store)(struct device_driver___117 *, const char *, size_t);
};

struct device_driver___117 {
	const char *name;
	struct bus_type___117 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___117 *);
	int (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	const struct attribute_group___110 **groups;
	const struct dev_pm_ops___117 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___117 {
	const char *name;
	const struct attribute_group___110 **groups;
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
};

struct class_attribute___117;

struct class___117 {
	const char *name;
	struct module *owner;
	struct class_attribute___117 *class_attrs;
	struct device_attribute___117 *dev_attrs;
	const struct attribute_group___110 **dev_groups;
	struct bin_attribute___112 *dev_bin_attrs;
	struct kobject___12 *dev_kobj;
	int (*dev_uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *);
	void (*class_release)(struct class___117 *);
	void (*dev_release)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
	struct subsys_private *p;
};

struct class_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct class___117 *, struct class_attribute___117 *, char *);
	ssize_t (*store)(struct class___117 *, struct class_attribute___117 *, const char *, size_t);
	const void * (*namespace)(struct class___117 *, const struct class_attribute___117 *);
};

struct device_rh___117 {
	struct dev_pm_info_rh___117 power;
};

struct vm_fault___130 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___152 *page;
};

struct ctl_node___23 {
	struct rb_node node;
	struct ctl_table_header___23 *header;
};

struct ctl_table_root___23 {
	struct ctl_table_set___23 default_set;
	struct ctl_table_set___23 * (*lookup)(struct ctl_table_root___23 *, struct nsproxy___90 *);
	int (*permissions)(struct ctl_table_header___23 *, struct ctl_table *);
};

struct nsproxy___90 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___21 *net_ns;
};

struct signal_struct___155 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___155 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___155 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___83 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___156 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___99 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___99 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___10 {
	atomic_t use;
	unsigned int mask;
	struct net_device___12 *physindev;
	struct net_device___12 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___10(struct sk_buff___14 **);

struct net_device_ops___10;

struct ethtool_ops___10;

struct header_ops___10;

struct inet6_dev___6;

struct netdev_rx_queue___10;

struct netdev_queue___10;

struct rtnl_link_ops___9;

struct dcbnl_rtnl_ops___10;

struct net_device___12 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___10 *netdev_ops;
	const struct ethtool_ops___10 *ethtool_ops;
	const struct header_ops___10 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___12 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___6 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___10 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___10 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___10 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___10 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___10 = 0,
		NETREG_REGISTERED___10 = 1,
		NETREG_UNREGISTERING___10 = 2,
		NETREG_UNREGISTERED___10 = 3,
		NETREG_RELEASED___10 = 4,
		NETREG_DUMMY___10 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___10 = 0,
		RTNL_LINK_INITIALIZING___10 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___12 *);
	struct netpoll_info *npinfo;
	struct net___21 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___117 dev;
	const struct attribute_group___110 *sysfs_groups[4];
	const struct rtnl_link_ops___9 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___10 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___14 {
	struct sk_buff___14 *next;
	struct sk_buff___14 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___10 *sk;
	struct net_device___12 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___14 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___10 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct irq_chip___106 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___106 *);
	void (*irq_shutdown)(struct irq_data___106 *);
	void (*irq_enable)(struct irq_data___106 *);
	void (*irq_disable)(struct irq_data___106 *);
	void (*irq_ack)(struct irq_data___106 *);
	void (*irq_mask)(struct irq_data___106 *);
	void (*irq_mask_ack)(struct irq_data___106 *);
	void (*irq_unmask)(struct irq_data___106 *);
	void (*irq_eoi)(struct irq_data___106 *);
	int (*irq_set_affinity)(struct irq_data___106 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___106 *);
	int (*irq_set_type)(struct irq_data___106 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___106 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___106 *);
	void (*irq_bus_sync_unlock)(struct irq_data___106 *);
	void (*irq_cpu_online)(struct irq_data___106 *);
	void (*irq_cpu_offline)(struct irq_data___106 *);
	void (*irq_suspend)(struct irq_data___106 *);
	void (*irq_resume)(struct irq_data___106 *);
	void (*irq_pm_shutdown)(struct irq_data___106 *);
	void (*irq_print_chip)(struct irq_data___106 *, struct seq_file___112 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___106 *, void *);
	long unsigned int flags;
};

struct dev_pm_qos_request___14 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___117 *dev;
};

struct ethtool_ops___10 {
	int (*get_settings)(struct net_device___12 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___12 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___12 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___12 *);
	void (*get_regs)(struct net_device___12 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___12 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___12 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___12 *);
	void (*set_msglevel)(struct net_device___12 *, u32);
	int (*nway_reset)(struct net_device___12 *);
	u32 (*get_link)(struct net_device___12 *);
	int (*get_eeprom_len)(struct net_device___12 *);
	int (*get_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___12 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___12 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___12 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___12 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___12 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___12 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___12 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___12 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___12 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___12 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___12 *);
	void (*complete)(struct net_device___12 *);
	u32 (*get_priv_flags)(struct net_device___12 *);
	int (*set_priv_flags)(struct net_device___12 *, u32);
	int (*get_sset_count)(struct net_device___12 *, int);
	int (*get_rxnfc)(struct net_device___12 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___12 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___12 *, struct ethtool_flash *);
	int (*reset)(struct net_device___12 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___12 *);
	int (*get_rxfh_indir)(struct net_device___12 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___12 *, const u32 *);
	void (*get_channels)(struct net_device___12 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___12 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___12 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___12 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___12 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___12 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___12 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___12 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___12 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___12 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___12 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___12 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___9 {
	struct callback_head callback_head;
	struct dst_entry___9 *child;
	struct net_device___12 *dev;
	struct dst_ops___20 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___9 *path;
	struct dst_entry___9 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___14 *);
	union {
		int (*output)(struct sock___10 *, struct sk_buff___14 *);
		struct {
			int (*output)(struct sk_buff___14 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___9 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___9;

struct neigh_parms___9;

struct neigh_ops___9;

struct neighbour___9 {
	struct neighbour___9 *next;
	struct neigh_table___9 *tbl;
	struct neigh_parms___9 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___11 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___9 *, struct sk_buff___14 *);
	const struct neigh_ops___9 *ops;
	struct callback_head rcu;
	struct net_device___12 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___20 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___14 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___14 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___21 *, struct dst_entry___9 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___14 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___14 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___111 {
	void * (*start)(struct seq_file___112 *, loff_t *);
	void (*stop)(struct seq_file___112 *, void *);
	void * (*next)(struct seq_file___112 *, void *, loff_t *);
	int (*show)(struct seq_file___112 *, void *);
};

struct dcbnl_rtnl_ops___10 {
	int (*ieee_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___12 *);
	u8 (*setstate)(struct net_device___12 *, u8);
	void (*getpermhwaddr)(struct net_device___12 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___12 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___12 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___12 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___12 *, int, u8 *);
	void (*setpfccfg)(struct net_device___12 *, int, u8);
	void (*getpfccfg)(struct net_device___12 *, int, u8 *);
	u8 (*setall)(struct net_device___12 *);
	u8 (*getcap)(struct net_device___12 *, int, u8 *);
	int (*getnumtcs)(struct net_device___12 *, int, u8 *);
	int (*setnumtcs)(struct net_device___12 *, int, u8);
	u8 (*getpfcstate)(struct net_device___12 *);
	void (*setpfcstate)(struct net_device___12 *, u8);
	void (*getbcncfg)(struct net_device___12 *, int, u32 *);
	void (*setbcncfg)(struct net_device___12 *, int, u32);
	void (*getbcnrp)(struct net_device___12 *, int, u8 *);
	void (*setbcnrp)(struct net_device___12 *, int, u8);
	u8 (*setapp)(struct net_device___12 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___12 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___12 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___12 *, int, u8);
	u8 (*getdcbx)(struct net_device___12 *);
	u8 (*setdcbx)(struct net_device___12 *, u8);
	int (*peer_getappinfo)(struct net_device___12 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___12 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___12 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___12 *, struct cee_pfc *);
};

struct cgroupfs_root___99;

struct cgroup___99 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___99 *parent;
	struct dentry___153 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___99 *subsys[11];
	struct cgroupfs_root___99 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___156 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___99 {
	struct super_block___153 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___99 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___49 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___153 *, struct file___153 *);
	ssize_t (*read)(struct cgroup___99 *, struct cftype___49 *, struct file___153 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___99 *, struct cftype___49 *);
	s64 (*read_s64)(struct cgroup___99 *, struct cftype___49 *);
	int (*read_map)(struct cgroup___99 *, struct cftype___49 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___99 *, struct cftype___49 *, struct seq_file___112 *);
	ssize_t (*write)(struct cgroup___99 *, struct cftype___49 *, struct file___153 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___99 *, struct cftype___49 *, u64);
	int (*write_s64)(struct cgroup___99 *, struct cftype___49 *, s64);
	int (*write_string)(struct cgroup___99 *, struct cftype___49 *, const char *);
	int (*trigger)(struct cgroup___99 *, unsigned int);
	int (*release)(struct inode___153 *, struct file___153 *);
	int (*register_event)(struct cgroup___99 *, struct cftype___49 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___99 *, struct cftype___49 *, struct eventfd_ctx *);
};

struct cftype_set___47 {
	struct list_head node;
	struct cftype___49 *cfts;
};

struct task_and_cgroup___47 {
	struct task_struct___155 *task;
	struct cgroup___99 *cgrp;
	struct css_set___99 *cg;
};

struct cgroup_taskset___47 {
	struct task_and_cgroup___47 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___99 *cur_cgrp;
};

struct cgroup_subsys___47 {
	struct cgroup_subsys_state___99 * (*css_alloc)(struct cgroup___99 *);
	int (*css_online)(struct cgroup___99 *);
	void (*css_offline)(struct cgroup___99 *);
	void (*css_free)(struct cgroup___99 *);
	int (*can_attach)(struct cgroup___99 *, struct cgroup_taskset___47 *);
	void (*cancel_attach)(struct cgroup___99 *, struct cgroup_taskset___47 *);
	void (*attach)(struct cgroup___99 *, struct cgroup_taskset___47 *);
	void (*fork)(struct task_struct___155 *);
	void (*exit)(struct cgroup___99 *, struct cgroup___99 *, struct task_struct___155 *);
	void (*bind)(struct cgroup___99 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___99 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___49 *base_cftypes;
	struct cftype_set___47 base_cftset;
	struct module *module;
};

struct request_sock_ops___7;

struct request_sock___7 {
	struct sock_common___9 __req_common;
	struct request_sock___7 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___7 *rsk_ops;
	struct sock___10 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___11 {
	struct sk_buff___14 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___14 *, struct netlink_callback___11 *);
	int (*done)(struct netlink_callback___11 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___10 {
	int (*create)(struct sk_buff___14 *, struct net_device___12 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___14 *, unsigned char *);
	int (*rebuild)(struct sk_buff___14 *);
	int (*cache)(const struct neighbour___9 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___12 *, const unsigned char *);
};

struct napi_struct___10 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___10 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___12 *dev;
	struct sk_buff___14 *gro_list;
	struct sk_buff___14 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___10 {
	struct net_device___12 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___12 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___10 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___12 kobj;
	struct net_device___12 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___10 {
	int (*ndo_init)(struct net_device___12 *);
	void (*ndo_uninit)(struct net_device___12 *);
	int (*ndo_open)(struct net_device___12 *);
	int (*ndo_stop)(struct net_device___12 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___14 *, struct net_device___12 *);
	u16 (*ndo_select_queue)(struct net_device___12 *, struct sk_buff___14 *);
	void (*ndo_change_rx_flags)(struct net_device___12 *, int);
	void (*ndo_set_rx_mode)(struct net_device___12 *);
	int (*ndo_set_mac_address)(struct net_device___12 *, void *);
	int (*ndo_validate_addr)(struct net_device___12 *);
	int (*ndo_do_ioctl)(struct net_device___12 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___12 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___12 *, int);
	int (*ndo_neigh_setup)(struct net_device___12 *, struct neigh_parms___9 *);
	void (*ndo_tx_timeout)(struct net_device___12 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___12 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___12 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___12 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___12 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___12 *);
	int (*ndo_netpoll_setup)(struct net_device___12 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___12 *);
	int (*ndo_busy_poll)(struct napi_struct___10 *);
	int (*ndo_set_vf_mac)(struct net_device___12 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___12 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___12 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___12 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___12 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___12 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___12 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___12 *, int, struct sk_buff___14 *);
	int (*ndo_setup_tc)(struct net_device___12 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___12 *);
	int (*ndo_fcoe_disable)(struct net_device___12 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___12 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___12 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___12 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___12 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___12 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___12 *, const struct sk_buff___14 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___12 *, struct net_device___12 *);
	int (*ndo_del_slave)(struct net_device___12 *, struct net_device___12 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___9 *);
	void (*ndo_neigh_destroy)(struct neighbour___9 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___14 *, struct netlink_callback___11 *, struct net_device___12 *, int);
	int (*ndo_bridge_setlink)(struct net_device___12 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___14 *, u32, u32, struct net_device___12 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___12 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___12 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___12 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___12 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___12 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___12 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___14 *, struct net_device___12 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___12 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___12 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___12 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___9 {
	struct net___21 *net;
	struct net_device___12 *dev;
	struct neigh_parms___9 *next;
	int (*neigh_setup)(struct neighbour___9 *);
	void (*neigh_cleanup)(struct neighbour___9 *);
	struct neigh_table___9 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___6;

struct ifacaddr6___6;

struct inet6_dev___6 {
	struct net_device___12 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___6 *mc_list;
	struct ifmcaddr6___6 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___6 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___9 *nd_parms;
	struct inet6_dev___6 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___9 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___12 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___21 *, struct net_device___12 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___12 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___12 *, struct list_head *);
	size_t (*get_size)(const struct net_device___12 *);
	int (*fill_info)(struct sk_buff___14 *, const struct net_device___12 *);
	size_t (*get_xstats_size)(const struct net_device___12 *);
	int (*fill_xstats)(struct sk_buff___14 *, const struct net_device___12 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___21 * (*get_link_net)(const struct net_device___12 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___12 *, struct net_device___12 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___12 *, const struct net_device___12 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___14 *, const struct net_device___12 *, const struct net_device___12 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___10 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___14 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___9;

struct neigh_hash_table___9;

struct neigh_table___9 {
	struct neigh_table___9 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___12 *, __u32 *);
	int (*constructor)(struct neighbour___9 *);
	int (*pconstructor)(struct pneigh_entry___9 *);
	void (*pdestructor)(struct pneigh_entry___9 *);
	void (*proxy_redo)(struct sk_buff___14 *);
	char *id;
	struct neigh_parms___9 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___11 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___9 *nht;
	struct pneigh_entry___9 **phash_buckets;
};

struct neigh_ops___9 {
	int family;
	void (*solicit)(struct neighbour___9 *, struct sk_buff___14 *);
	void (*error_report)(struct neighbour___9 *, struct sk_buff___14 *);
	int (*output)(struct neighbour___9 *, struct sk_buff___14 *);
	int (*connected_output)(struct neighbour___9 *, struct sk_buff___14 *);
};

struct pneigh_entry___9 {
	struct pneigh_entry___9 *next;
	struct net___21 *net;
	struct net_device___12 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___9 {
	struct neighbour___9 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___7;

struct proto___9 {
	void (*close)(struct sock___10 *, long int);
	int (*connect)(struct sock___10 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___10 *, int);
	struct sock___10 * (*accept)(struct sock___10 *, int, int *);
	int (*ioctl)(struct sock___10 *, int, long unsigned int);
	int (*init)(struct sock___10 *);
	void (*destroy)(struct sock___10 *);
	void (*shutdown)(struct sock___10 *, int);
	int (*setsockopt)(struct sock___10 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___10 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___10 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___10 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___10 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___16 *, struct sock___10 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___16 *, struct sock___10 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___10 *, struct page___152 *, int, size_t, int);
	int (*bind)(struct sock___10 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___10 *, struct sk_buff___14 *);
	void (*release_cb)(struct sock___10 *);
	void (*mtu_reduced)(struct sock___10 *);
	void (*hash)(struct sock___10 *);
	void (*unhash)(struct sock___10 *);
	void (*rehash)(struct sock___10 *);
	int (*get_port)(struct sock___10 *, short unsigned int);
	void (*clear_sk)(struct sock___10 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___10 *);
	void (*enter_memory_pressure)(struct sock___10 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___139 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___7 *rsk_prot;
	struct timewait_sock_ops___7 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___47 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___9 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___9 {
	void (*enter_memory_pressure)(struct sock___10 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___7 {
	int family;
	int obj_size;
	struct kmem_cache___139 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___10 *, struct request_sock___7 *);
	void (*send_ack)(struct sock___10 *, struct sk_buff___14 *, struct request_sock___7 *);
	void (*send_reset)(struct sock___10 *, struct sk_buff___14 *);
	void (*destructor)(struct request_sock___7 *);
	void (*syn_ack_timeout)(struct sock___10 *, struct request_sock___7 *);
};

struct timewait_sock_ops___7 {
	struct kmem_cache___139 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___10 *, struct sock___10 *, void *);
	void (*twsk_destructor)(struct sock___10 *);
};

struct ifmcaddr6___6 {
	struct in6_addr mca_addr;
	struct inet6_dev___6 *idev;
	struct ifmcaddr6___6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___6 {
	struct in6_addr aca_addr;
	struct inet6_dev___6 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___6 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct lsm_network_audit {
	int netif;
	struct sock___10 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct selinux_audit_data {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	u32 requested;
	u32 audited;
	u32 denied;
	int result;
};

struct common_audit_data {
	char type;
	union {
		struct path___153 path;
		struct dentry___153 *dentry;
		struct inode___153 *inode;
		struct lsm_network_audit *net;
		int cap;
		int ipc_id;
		struct task_struct___155 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct av_decision {
	u32 allowed;
	u32 auditallow;
	u32 auditdeny;
	u32 seqno;
	u32 flags;
};

struct avc_cache_stats {
	unsigned int lookups;
	unsigned int misses;
	unsigned int allocations;
	unsigned int reclaims;
	unsigned int frees;
};

struct security_class_mapping {
	const char *name;
	const char *perms[33];
};

struct avc_entry {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	struct av_decision avd;
};

struct avc_node {
	struct avc_entry ae;
	struct hlist_node list;
	struct callback_head rhead;
};

struct avc_cache {
	struct hlist_head slots[512];
	spinlock_t slots_lock[512];
	atomic_t lru_hint;
	atomic_t active_nodes;
	u32 latest_notif;
};

struct avc_callback_node {
	int (*callback)(u32);
	u32 events;
	struct avc_callback_node *next;
};

struct page___153;

typedef struct page___153 *pgtable_t___153;

struct address_space___154;

struct kmem_cache___140;

struct page___153 {
	long unsigned int flags;
	struct address_space___154 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___153 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___153 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___140 *slab_cache;
		struct page___153 *first_page;
	};
	long: 64;
};

struct thread_struct___75;

struct task_struct___156;

struct pv_cpu_ops___156 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___156 *);
	void (*end_context_switch)(struct task_struct___156 *);
};

struct perf_event___75;

struct thread_struct___75 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___75 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___84;

struct pid_link___84 {
	struct hlist_node node;
	struct pid___84 *pid;
};

struct mutex___157 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___156 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___149 {
	struct page___153 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___161;

struct files_struct___13;

struct nsproxy___91;

struct signal_struct___156;

struct css_set___100;

struct perf_event_context___75;

struct task_struct___156 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___156 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___161 *mm;
	struct mm_struct___161 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___156 *real_parent;
	struct task_struct___156 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___156 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___156 = 0,
		VTIME_USER___156 = 1,
		VTIME_SYS___156 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct___13 *files;
	struct nsproxy___91 *nsproxy;
	struct signal_struct___156 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___100 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___75 *perf_event_ctxp[2];
	struct mutex___157 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___149 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___161 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___161 *, struct mm_struct___161 *);
	void (*dup_mmap)(struct mm_struct___161 *, struct mm_struct___161 *);
	void (*exit_mmap)(struct mm_struct___161 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___161 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___161 *);
	void (*pgd_free)(struct mm_struct___161 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___161 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___161 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___161 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___161 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___161 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___161 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___161 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___161 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___161 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___161 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___161 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___157 lock;
	void *vdso;
} mm_context_t___157;

struct xol_area___153;

struct uprobes_state___153 {
	struct xol_area___153 *xol_area;
};

struct vm_area_struct___161;

struct file___154;

struct linux_binfmt___24;

struct core_state___156;

struct mm_struct___161 {
	struct vm_area_struct___161 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___161 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___161 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___24 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___157 context;
	long unsigned int flags;
	struct core_state___156 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___156 *owner;
	struct file___154 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___153 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___75 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___156 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___156 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___156 *target;
};

typedef void (*perf_overflow_handler_t___75)(struct perf_event___75 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___75;

typedef void (*ftrace_func_t___75)(long unsigned int, long unsigned int, struct ftrace_ops___75 *, struct pt_regs *);

struct ftrace_ops___75 {
	ftrace_func_t___75 func;
	struct ftrace_ops___75 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___157 regex_lock;
};

struct pmu___75;

struct fasync_struct___154;

struct pid_namespace___84;

struct ftrace_event_call___65;

struct perf_cgroup___75;

struct perf_event___75 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___75 *group_leader;
	struct pmu___75 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___75 hw;
	struct perf_event_context___75 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___157 child_mutex;
	struct list_head child_list;
	struct perf_event___75 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___156 *owner;
	struct mutex___157 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___154 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___75 *);
	struct callback_head callback_head;
	struct pid_namespace___84 *ns;
	u64 id;
	perf_overflow_handler_t___75 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___65 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___75 ftrace_ops;
	struct perf_cgroup___75 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___153 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___153 *page;
	long unsigned int vaddr;
};

struct kset___13;

struct kobj_type___13;

struct kobject___13 {
	const char *name;
	struct list_head entry;
	struct kobject___13 *parent;
	struct kset___13 *kset;
	struct kobj_type___13 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___139;

struct memcg_cache_params___140;

struct kmem_cache___140 {
	struct kmem_cache_cpu___139 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___13 kobj;
	struct memcg_cache_params___140 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___154;

struct address_space_operations___154;

struct address_space___154 {
	struct inode___154 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___157 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___154 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___40;

struct dentry___154;

struct path___154 {
	struct vfsmount___40 *mnt;
	struct dentry___154 *dentry;
};

struct fown_struct___84 {
	rwlock_t lock;
	struct pid___84 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___154;

struct file___154 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___154 f_path;
	struct inode___154 *f_inode;
	const struct file_operations___154 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___154 *f_mapping;
	struct mutex___157 f_pos_lock;
};

struct vm_operations_struct___134;

struct vm_area_struct___161 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___161 *vm_next;
	struct vm_area_struct___161 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___161 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___134 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___154 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___131;

struct vm_operations_struct___134 {
	void (*open)(struct vm_area_struct___161 *);
	void (*close)(struct vm_area_struct___161 *);
	int (*fault)(struct vm_area_struct___161 *, struct vm_fault___131 *);
	int (*page_mkwrite)(struct vm_area_struct___161 *, struct vm_fault___131 *);
	int (*access)(struct vm_area_struct___161 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___161 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___161 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___161 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___161 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___156 {
	struct task_struct___156 *task;
	struct core_thread___156 *next;
};

struct core_state___156 {
	atomic_t nr_threads;
	struct core_thread___156 dumper;
	struct completion startup;
};

struct linux_binprm___25;

struct coredump_params___24;

struct linux_binfmt___24 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___25 *);
	int (*load_shlib)(struct file___154 *);
	int (*core_dump)(struct coredump_params___24 *);
	long unsigned int min_coredump;
};

struct irq_data___107;

struct x86_io_apic_ops___107 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___107 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___107;

struct irq_data___107 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___107 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___118;

struct dev_pm_ops___118 {
	int (*prepare)(struct device___118 *);
	void (*complete)(struct device___118 *);
	int (*suspend)(struct device___118 *);
	int (*resume)(struct device___118 *);
	int (*freeze)(struct device___118 *);
	int (*thaw)(struct device___118 *);
	int (*poweroff)(struct device___118 *);
	int (*restore)(struct device___118 *);
	int (*suspend_late)(struct device___118 *);
	int (*resume_early)(struct device___118 *);
	int (*freeze_late)(struct device___118 *);
	int (*thaw_early)(struct device___118 *);
	int (*poweroff_late)(struct device___118 *);
	int (*restore_early)(struct device___118 *);
	int (*suspend_noirq)(struct device___118 *);
	int (*resume_noirq)(struct device___118 *);
	int (*freeze_noirq)(struct device___118 *);
	int (*thaw_noirq)(struct device___118 *);
	int (*poweroff_noirq)(struct device___118 *);
	int (*restore_noirq)(struct device___118 *);
	int (*runtime_suspend)(struct device___118 *);
	int (*runtime_resume)(struct device___118 *);
	int (*runtime_idle)(struct device___118 *);
};

struct dev_pm_qos___15;

struct dev_pm_info___15 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___15 *qos;
};

struct dma_map_ops___41;

struct dev_archdata___41 {
	struct dma_map_ops___41 *dma_ops;
	void *iommu;
};

struct device_type___118;

struct bus_type___118;

struct device_driver___118;

struct dev_pm_domain___118;

struct class___118;

struct attribute_group___111;

struct device_rh___118;

struct device___118 {
	struct device___118 *parent;
	struct device_private *p;
	struct kobject___13 kobj;
	const char *init_name;
	const struct device_type___118 *type;
	struct mutex___157 mutex;
	struct bus_type___118 *bus;
	struct device_driver___118 *driver;
	void *platform_data;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___118 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___41 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___118 *class;
	const struct attribute_group___111 **groups;
	void (*release)(struct device___118 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___118 *device_rh;
};

struct dev_pm_qos_request___15;

struct dev_pm_qos___15 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___15 *latency_req;
	struct dev_pm_qos_request___15 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___15 *latency_tolerance_req;
};

struct dev_pm_info_rh___118 {
	void (*set_latency_tolerance)(struct device___118 *, s32);
};

struct dev_pm_domain___118 {
	struct dev_pm_ops___118 ops;
};

struct smp_ops___156 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___156 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___84 {
	int nr;
	struct pid_namespace___84 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___84 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___156 *child_reaper;
	struct kmem_cache___140 *pid_cachep;
	unsigned int level;
	struct pid_namespace___84 *parent;
	struct vfsmount___40 *proc_mnt;
	struct dentry___154 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___84 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___84 numbers[1];
};

struct zone___156;

struct lruvec___156 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___156 *zone;
};

struct pglist_data___156;

struct zone___156 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___156 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___156 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___156 {
	struct zone___156 *zone;
	int zone_idx;
};

struct zonelist___156 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___156 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___156 {
	struct zone___156 node_zones[4];
	struct zonelist___156 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___156 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___24;

struct ctl_node___24 {
	struct rb_node node;
	struct ctl_table_header___24 *header;
};

struct ctl_table_root___24;

struct ctl_table_set___24;

struct ctl_dir___24;

struct ctl_table_header___24 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___24 *root;
	struct ctl_table_set___24 *set;
	struct ctl_dir___24 *parent;
	struct ctl_node___24 *node;
};

struct ctl_dir___24 {
	struct ctl_table_header___24 header;
	struct rb_root root;
};

struct ctl_table_set___24 {
	int (*is_seen)(struct ctl_table_set___24 *);
	struct ctl_dir___24 dir;
};

struct ctl_table_root___24 {
	struct ctl_table_set___24 default_set;
	struct ctl_table_set___24 * (*lookup)(struct ctl_table_root___24 *, struct nsproxy___91 *);
	int (*permissions)(struct ctl_table_header___24 *, struct ctl_table *);
};

struct net___22;

struct nsproxy___91 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___84 *pid_ns;
	struct net___22 *net_ns;
};

struct tty_struct___14;

struct signal_struct___156 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___156 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___156 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct___14 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___157 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___14;

struct tty_operations___14;

struct tty_ldisc___14;

struct tty_port___14;

struct tty_struct___14 {
	int magic;
	struct kref kref;
	struct device___118 *dev;
	struct tty_driver___14 *driver;
	const struct tty_operations___14 *ops;
	int index;
	struct mutex___157 ldisc_mutex;
	struct tty_ldisc___14 *ldisc;
	struct mutex___157 atomic_write_lock;
	struct mutex___157 legacy_mutex;
	struct mutex___157 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___84 *pgrp;
	struct pid___84 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___14 *link;
	struct fasync_struct___154 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___14 *port;
	struct ld_semaphore ldisc_sem;
};

struct fdtable___13 {
	unsigned int max_fds;
	struct file___154 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___13 {
	atomic_t count;
	struct fdtable___13 *fdt;
	struct fdtable___13 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___154 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_subsys_state___100;

struct css_set___100 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___100 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___75 {
	struct pmu___75 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___157 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___156 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___75 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct sock___11;

struct kobj_ns_type_operations___10 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___11 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___10;

struct sock_common___10 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___10 *skc_prot;
	struct net___22 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___15;

struct sk_buff_head___12 {
	struct sk_buff___15 *next;
	struct sk_buff___15 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___11;

struct socket_wq___10;

struct dst_entry___10;

struct socket___11;

struct cg_proto___10;

struct sock___11 {
	struct sock_common___10 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___12 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___15 *head;
		struct sk_buff___15 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___11 *sk_filter;
	struct socket_wq___10 *sk_wq;
	struct sk_buff_head___12 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___10 *sk_rx_dst;
	struct dst_entry___10 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___12 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___12 sk_error_queue;
	struct proto___10 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___11 *sk_socket;
	void *sk_user_data;
	struct page_frag___149 sk_frag;
	struct sk_buff___15 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___10 *sk_cgrp;
	void (*sk_state_change)(struct sock___11 *);
	void (*sk_data_ready)(struct sock___11 *, int);
	void (*sk_write_space)(struct sock___11 *);
	void (*sk_error_report)(struct sock___11 *);
	int (*sk_backlog_rcv)(struct sock___11 *, struct sk_buff___15 *);
	void (*sk_destruct)(struct sock___11 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___113;

struct attribute_group___111 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___113 **bin_attrs;
};

struct bin_attribute___113 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___154 *, struct kobject___13 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___154 *, struct kobject___13 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	int (*mmap)(struct file___154 *, struct kobject___13 *, struct bin_attribute___113 *, struct vm_area_struct___161 *);
};

struct sysfs_ops___13 {
	ssize_t (*show)(struct kobject___13 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___13 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___13 *, const struct attribute *);
};

struct kset_uevent_ops___13;

struct kset___13 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___13 kobj;
	const struct kset_uevent_ops___13 *uevent_ops;
};

struct kobj_type___13 {
	void (*release)(struct kobject___13 *);
	const struct sysfs_ops___13 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___13 *);
	const void * (*namespace)(struct kobject___13 *);
};

struct kset_uevent_ops___13 {
	int (* const filter)(struct kset___13 *, struct kobject___13 *);
	const char * (* const name)(struct kset___13 *, struct kobject___13 *);
	int (* const uevent)(struct kset___13 *, struct kobject___13 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___139 {
	void **freelist;
	long unsigned int tid;
	struct page___153 *page;
	struct page___153 *partial;
};

struct memcg_cache_params___140 {
	bool is_root_cache;
	union {
		struct kmem_cache___140 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___140 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct inode_operations___154;

struct super_block___154;

struct file_lock___154;

struct dquot___154;

struct block_device___154;

struct cdev___41;

struct inode___154 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___154 *i_op;
	struct super_block___154 *i_sb;
	struct address_space___154 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___157 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___154 *i_fop;
	struct file_lock___154 *i_flock;
	struct address_space___154 i_data;
	struct dquot___154 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___154 *i_bdev;
		struct cdev___41 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct seq_file___113;

struct nameidata___24;

struct iattr___154;

struct shmid_kernel___3;

struct request_sock___8;

struct xfrm_sec_ctx___2;

struct xfrm_user_sec_ctx___2;

struct security_operations___2 {
	char name[11];
	int (*ptrace_access_check)(struct task_struct___156 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___156 *);
	int (*capget)(struct task_struct___156 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___10 *, const struct cred___10 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___10 *, struct user_namespace *, int, int);
	int (*quotactl)(int, int, int, struct super_block___154 *);
	int (*quota_on)(struct dentry___154 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___161 *, long int);
	int (*bprm_set_creds)(struct linux_binprm___25 *);
	int (*bprm_check_security)(struct linux_binprm___25 *);
	int (*bprm_secureexec)(struct linux_binprm___25 *);
	void (*bprm_committing_creds)(struct linux_binprm___25 *);
	void (*bprm_committed_creds)(struct linux_binprm___25 *);
	int (*sb_alloc_security)(struct super_block___154 *);
	void (*sb_free_security)(struct super_block___154 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___154 *, void *);
	int (*sb_kern_mount)(struct super_block___154 *, int, void *);
	int (*sb_show_options)(struct seq_file___113 *, struct super_block___154 *);
	int (*sb_statfs)(struct dentry___154 *);
	int (*sb_mount)(const char *, struct path___154 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___40 *, int);
	int (*sb_pivotroot)(struct path___154 *, struct path___154 *);
	int (*sb_set_mnt_opts)(struct super_block___154 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___154 *, struct super_block___154 *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___154 *, int, struct qstr *, void **, u32 *);
	int (*inode_alloc_security)(struct inode___154 *);
	void (*inode_free_security)(struct inode___154 *);
	int (*inode_init_security)(struct inode___154 *, struct inode___154 *, const struct qstr *, char **, void **, size_t *);
	int (*inode_create)(struct inode___154 *, struct dentry___154 *, umode_t);
	int (*inode_link)(struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*inode_unlink)(struct inode___154 *, struct dentry___154 *);
	int (*inode_symlink)(struct inode___154 *, struct dentry___154 *, const char *);
	int (*inode_mkdir)(struct inode___154 *, struct dentry___154 *, umode_t);
	int (*inode_rmdir)(struct inode___154 *, struct dentry___154 *);
	int (*inode_mknod)(struct inode___154 *, struct dentry___154 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___154 *, struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*inode_readlink)(struct dentry___154 *);
	int (*inode_follow_link)(struct dentry___154 *, struct nameidata___24 *);
	int (*inode_permission)(struct inode___154 *, int);
	int (*inode_setattr)(struct dentry___154 *, struct iattr___154 *);
	int (*inode_getattr)(struct vfsmount___40 *, struct dentry___154 *);
	int (*inode_setxattr)(struct dentry___154 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___154 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___154 *, const char *);
	int (*inode_listxattr)(struct dentry___154 *);
	int (*inode_removexattr)(struct dentry___154 *, const char *);
	int (*inode_need_killpriv)(struct dentry___154 *);
	int (*inode_killpriv)(struct dentry___154 *);
	int (*inode_getsecurity)(const struct inode___154 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___154 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___154 *, char *, size_t);
	void (*inode_getsecid)(const struct inode___154 *, u32 *);
	int (*file_permission)(struct file___154 *, int);
	int (*file_alloc_security)(struct file___154 *);
	void (*file_free_security)(struct file___154 *);
	int (*file_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___161 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___154 *, unsigned int);
	int (*file_fcntl)(struct file___154 *, unsigned int, long unsigned int);
	int (*file_set_fowner)(struct file___154 *);
	int (*file_send_sigiotask)(struct task_struct___156 *, struct fown_struct___84 *, int);
	int (*file_receive)(struct file___154 *);
	int (*file_open)(struct file___154 *, const struct cred___10 *);
	int (*task_create)(long unsigned int);
	void (*task_free)(struct task_struct___156 *);
	int (*cred_alloc_blank)(struct cred___10 *, gfp_t);
	void (*cred_free)(struct cred___10 *);
	int (*cred_prepare)(struct cred___10 *, const struct cred___10 *, gfp_t);
	void (*cred_transfer)(struct cred___10 *, const struct cred___10 *);
	int (*kernel_act_as)(struct cred___10 *, u32);
	int (*kernel_create_files_as)(struct cred___10 *, struct inode___154 *);
	int (*kernel_module_request)(char *);
	int (*kernel_module_from_file)(struct file___154 *);
	int (*task_fix_setuid)(struct cred___10 *, const struct cred___10 *, int);
	int (*task_setpgid)(struct task_struct___156 *, pid_t);
	int (*task_getpgid)(struct task_struct___156 *);
	int (*task_getsid)(struct task_struct___156 *);
	void (*task_getsecid)(struct task_struct___156 *, u32 *);
	int (*task_setnice)(struct task_struct___156 *, int);
	int (*task_setioprio)(struct task_struct___156 *, int);
	int (*task_getioprio)(struct task_struct___156 *);
	int (*task_setrlimit)(struct task_struct___156 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___156 *);
	int (*task_getscheduler)(struct task_struct___156 *);
	int (*task_movememory)(struct task_struct___156 *);
	int (*task_kill)(struct task_struct___156 *, struct siginfo *, int, u32);
	int (*task_wait)(struct task_struct___156 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___156 *, struct inode___154 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct msg_queue *);
	void (*msg_queue_free_security)(struct msg_queue *);
	int (*msg_queue_associate)(struct msg_queue *, int);
	int (*msg_queue_msgctl)(struct msg_queue *, int);
	int (*msg_queue_msgsnd)(struct msg_queue *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct msg_queue *, struct msg_msg *, struct task_struct___156 *, long int, int);
	int (*shm_alloc_security)(struct shmid_kernel___3 *);
	void (*shm_free_security)(struct shmid_kernel___3 *);
	int (*shm_associate)(struct shmid_kernel___3 *, int);
	int (*shm_shmctl)(struct shmid_kernel___3 *, int);
	int (*shm_shmat)(struct shmid_kernel___3 *, char *, int);
	int (*sem_alloc_security)(struct sem_array *);
	void (*sem_free_security)(struct sem_array *);
	int (*sem_associate)(struct sem_array *, int);
	int (*sem_semctl)(struct sem_array *, int);
	int (*sem_semop)(struct sem_array *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___11 *, struct sk_buff___15 *);
	void (*d_instantiate)(struct dentry___154 *, struct inode___154 *);
	int (*getprocattr)(struct task_struct___156 *, char *, char **);
	int (*setprocattr)(struct task_struct___156 *, char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	int (*inode_notifysecctx)(struct inode___154 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___154 *, void *, u32);
	int (*inode_getsecctx)(struct inode___154 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock___11 *, struct sock___11 *, struct sock___11 *);
	int (*unix_may_send)(struct socket___11 *, struct socket___11 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___11 *, int, int, int, int);
	int (*socket_bind)(struct socket___11 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___11 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___11 *, int);
	int (*socket_accept)(struct socket___11 *, struct socket___11 *);
	int (*socket_sendmsg)(struct socket___11 *, struct msghdr *, int);
	int (*socket_recvmsg)(struct socket___11 *, struct msghdr *, int, int);
	int (*socket_getsockname)(struct socket___11 *);
	int (*socket_getpeername)(struct socket___11 *);
	int (*socket_getsockopt)(struct socket___11 *, int, int);
	int (*socket_setsockopt)(struct socket___11 *, int, int);
	int (*socket_shutdown)(struct socket___11 *, int);
	int (*socket_sock_rcv_skb)(struct sock___11 *, struct sk_buff___15 *);
	int (*socket_getpeersec_stream)(struct socket___11 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___11 *, struct sk_buff___15 *, u32 *);
	int (*sk_alloc_security)(struct sock___11 *, int, gfp_t);
	void (*sk_free_security)(struct sock___11 *);
	void (*sk_clone_security)(const struct sock___11 *, struct sock___11 *);
	void (*sk_getsecid)(struct sock___11 *, u32 *);
	void (*sock_graft)(struct sock___11 *, struct socket___11 *);
	int (*inet_conn_request)(struct sock___11 *, struct sk_buff___15 *, struct request_sock___8 *);
	void (*inet_csk_clone)(struct sock___11 *, const struct request_sock___8 *);
	void (*inet_conn_established)(struct sock___11 *, struct sk_buff___15 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___8 *, struct flowi *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___11 *, void *);
	int (*tun_dev_open)(void *);
	void (*skb_owned_by)(struct sk_buff___15 *, struct sock___11 *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx___2 **, struct xfrm_user_sec_ctx___2 *);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx___2 *, struct xfrm_sec_ctx___2 **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_state_alloc_security)(struct xfrm_state *, struct xfrm_user_sec_ctx___2 *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx___2 *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi *);
	int (*xfrm_decode_session)(struct sk_buff___15 *, u32 *, int);
	int (*key_alloc)(struct key___10 *, const struct cred___10 *, long unsigned int);
	void (*key_free)(struct key___10 *);
	int (*key_permission)(key_ref_t, const struct cred___10 *, key_perm_t);
	int (*key_getsecurity)(struct key___10 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
};

struct quota_format_type___154;

struct mem_dqinfo___154 {
	struct quota_format_type___154 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___154;

struct quota_info___154 {
	unsigned int flags;
	struct mutex___157 dqio_mutex;
	struct mutex___157 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___154 *files[2];
	struct mem_dqinfo___154 info[2];
	const struct quota_format_ops___154 *ops[2];
};

struct file_system_type___154;

struct super_operations___154;

struct dquot_operations___154;

struct quotactl_ops___154;

struct xattr_handler___101;

struct dentry_operations___154;

struct super_block___154 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___154 *s_type;
	const struct super_operations___154 *s_op;
	const struct dquot_operations___154 *dq_op;
	const struct quotactl_ops___154 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___154 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___101 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___154 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___154 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___157 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___154 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___154 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___154 *d_parent;
	struct qstr d_name;
	struct inode___154 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___154 *d_op;
	struct super_block___154 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct linux_binprm___25 {
	char buf[128];
	struct vm_area_struct___161 *vma;
	long unsigned int vma_pages;
	struct mm_struct___161 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___154 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct seq_operations___112;

struct seq_file___113 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___157 lock;
	const struct seq_operations___112 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct vfsmount___40 {
	struct dentry___154 *mnt_root;
	struct super_block___154 *mnt_sb;
	int mnt_flags;
};

struct nameidata___24 {
	struct path___154 path;
	struct qstr last;
	struct path___154 root;
	struct inode___154 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct iattr___154 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___154 *ia_file;
};

struct shmid_kernel___3 {
	struct kern_ipc_perm shm_perm;
	struct file___154 *shm_file;
	long unsigned int shm_nattch;
	long unsigned int shm_segsz;
	time_t shm_atim;
	time_t shm_dtim;
	time_t shm_ctim;
	pid_t shm_cprid;
	pid_t shm_lprid;
	struct user_struct___10 *mlock_user;
	struct task_struct___156 *shm_creator;
};

struct net_device___13;

struct nf_bridge_info___11;

struct sk_buff___15 {
	struct sk_buff___15 *next;
	struct sk_buff___15 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___11 *sk;
	struct net_device___13 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___15 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___11 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct proto_ops___10;

struct socket___11 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___10 *wq;
	struct file___154 *file;
	struct sock___11 *sk;
	const struct proto_ops___10 *ops;
};

struct request_sock_ops___8;

struct request_sock___8 {
	struct sock_common___10 __req_common;
	struct request_sock___8 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___8 *rsk_ops;
	struct sock___11 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_sec_ctx___2 {
	__u8 ctx_doi;
	__u8 ctx_alg;
	__u16 ctx_len;
	__u32 ctx_sid;
	char ctx_str[0];
};

struct xfrm_user_sec_ctx___2 {
	__u16 len;
	__u16 exttype;
	__u8 ctx_alg;
	__u8 ctx_doi;
	__u16 ctx_len;
};

struct xattr_handler___101 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___154 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___154 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___154 *, const char *, const void *, size_t, int, int);
};

struct vm_fault___131 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___153 *page;
};

struct dentry_operations___154 {
	int (*d_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_hash)(const struct dentry___154 *, struct qstr *);
	int (*d_compare)(const struct dentry___154 *, const struct dentry___154 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___154 *);
	void (*d_release)(struct dentry___154 *);
	void (*d_prune)(struct dentry___154 *);
	void (*d_iput)(struct dentry___154 *, struct inode___154 *);
	char * (*d_dname)(struct dentry___154 *, char *, int);
	struct vfsmount___40 * (*d_automount)(struct path___154 *);
	int (*d_manage)(struct dentry___154 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___154 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___154 *bd_inode;
	struct super_block___154 *bd_super;
	struct mutex___157 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___154 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___157 bd_fsfreeze_mutex;
};

struct cgroup___100;

struct cgroup_subsys_state___100 {
	struct cgroup___100 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___17;

typedef int kiocb_cancel_fn___17(struct kiocb___17 *, struct io_event *);

struct kiocb___17 {
	atomic_t ki_users;
	struct file___154 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___17 *ki_cancel;
	void (*ki_dtor)(struct kiocb___17 *);
	union {
		void *user;
		struct task_struct___156 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct dquot___154 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___157 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___154 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___154 {
	int qf_fmt_id;
	const struct quota_format_ops___154 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___154 *qf_next;
};

struct quota_format_ops___154 {
	int (*check_quota_file)(struct super_block___154 *, int);
	int (*read_file_info)(struct super_block___154 *, int);
	int (*write_file_info)(struct super_block___154 *, int);
	int (*free_file_info)(struct super_block___154 *, int);
	int (*read_dqblk)(struct dquot___154 *);
	int (*commit_dqblk)(struct dquot___154 *);
	int (*release_dqblk)(struct dquot___154 *);
};

struct dquot_operations___154 {
	int (*write_dquot)(struct dquot___154 *);
	struct dquot___154 * (*alloc_dquot)(struct super_block___154 *, int);
	void (*destroy_dquot)(struct dquot___154 *);
	int (*acquire_dquot)(struct dquot___154 *);
	int (*release_dquot)(struct dquot___154 *);
	int (*mark_dirty)(struct dquot___154 *);
	int (*write_info)(struct super_block___154 *, int);
	qsize_t * (*get_reserved_space)(struct inode___154 *);
};

struct quotactl_ops___154 {
	int (*quota_on)(struct super_block___154 *, int, int, struct path___154 *);
	int (*quota_on_meta)(struct super_block___154 *, int, int);
	int (*quota_off)(struct super_block___154 *, int);
	int (*quota_sync)(struct super_block___154 *, int);
	int (*get_info)(struct super_block___154 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___154 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___154 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___154 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___154 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___154 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___154 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___154 *, unsigned int);
};

struct swap_info_struct___37;

struct address_space_operations___154 {
	int (*writepage)(struct page___153 *, struct writeback_control *);
	int (*readpage)(struct file___154 *, struct page___153 *);
	int (*writepages)(struct address_space___154 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___153 *);
	int (*readpages)(struct file___154 *, struct address_space___154 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___154 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___153 **, void **);
	int (*write_end)(struct file___154 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___153 *, void *);
	sector_t (*bmap)(struct address_space___154 *, sector_t);
	void (*invalidatepage)(struct page___153 *, long unsigned int);
	int (*releasepage)(struct page___153 *, gfp_t);
	void (*freepage)(struct page___153 *);
	ssize_t (*direct_IO)(int, struct kiocb___17 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___154 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___154 *, struct page___153 *, struct page___153 *, enum migrate_mode);
	int (*launder_page)(struct page___153 *);
	int (*is_partially_uptodate)(struct page___153 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___153 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___154 *, struct page___153 *);
	int (*swap_activate)(struct swap_info_struct___37 *, struct file___154 *, sector_t *);
	void (*swap_deactivate)(struct file___154 *);
	void (*invalidatepage_range)(struct page___153 *, unsigned int, unsigned int);
};

struct swap_info_struct___37 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___154 *bdev;
	struct file___154 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___41 {
	struct kobject___13 kobj;
	struct module *owner;
	const struct file_operations___154 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___154 {
	struct dentry___154 * (*lookup)(struct inode___154 *, struct dentry___154 *, unsigned int);
	void * (*follow_link)(struct dentry___154 *, struct nameidata___24 *);
	int (*permission)(struct inode___154 *, int);
	struct posix_acl * (*get_acl)(struct inode___154 *, int);
	int (*readlink)(struct dentry___154 *, char *, int);
	void (*put_link)(struct dentry___154 *, struct nameidata___24 *, void *);
	int (*create)(struct inode___154 *, struct dentry___154 *, umode_t, bool);
	int (*link)(struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*unlink)(struct inode___154 *, struct dentry___154 *);
	int (*symlink)(struct inode___154 *, struct dentry___154 *, const char *);
	int (*mkdir)(struct inode___154 *, struct dentry___154 *, umode_t);
	int (*rmdir)(struct inode___154 *, struct dentry___154 *);
	int (*mknod)(struct inode___154 *, struct dentry___154 *, umode_t, dev_t);
	int (*rename)(struct inode___154 *, struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*setattr)(struct dentry___154 *, struct iattr___154 *);
	int (*getattr)(struct vfsmount___40 *, struct dentry___154 *, struct kstat *);
	int (*setxattr)(struct dentry___154 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___154 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___154 *, char *, size_t);
	int (*removexattr)(struct dentry___154 *, const char *);
	int (*fiemap)(struct inode___154 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___154 *, struct timespec *, int);
	int (*atomic_open)(struct inode___154 *, struct dentry___154 *, struct file___154 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___13 *fl_owner_t___13;

struct poll_table_struct___93;

struct file_operations___154 {
	struct module *owner;
	loff_t (*llseek)(struct file___154 *, loff_t, int);
	ssize_t (*read)(struct file___154 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___154 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___17 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___17 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___154 *, void *, filldir_t);
	unsigned int (*poll)(struct file___154 *, struct poll_table_struct___93 *);
	long int (*unlocked_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___154 *, struct vm_area_struct___161 *);
	int (*open)(struct inode___154 *, struct file___154 *);
	int (*flush)(struct file___154 *, fl_owner_t___13);
	int (*release)(struct inode___154 *, struct file___154 *);
	int (*fsync)(struct file___154 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___17 *, int);
	int (*fasync)(int, struct file___154 *, int);
	int (*lock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*sendpage)(struct file___154 *, struct page___153 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___154 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___154 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___154 *, long int, struct file_lock___154 **, void **);
		struct {
			int (*setlease)(struct file___154 *, long int, struct file_lock___154 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___154 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___113 *, struct file___154 *);
};

struct file_lock_operations___154;

struct lock_manager_operations___154;

struct file_lock___154 {
	struct file_lock___154 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___13 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___154 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___154 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___154 *fl_ops;
	const struct lock_manager_operations___154 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___154 {
	void (*fl_copy_lock)(struct file_lock___154 *, struct file_lock___154 *);
	void (*fl_release_private)(struct file_lock___154 *);
};

struct lock_manager_operations___154 {
	int (*lm_compare_owner)(struct file_lock___154 *, struct file_lock___154 *);
	long unsigned int (*lm_owner_key)(struct file_lock___154 *);
	void (*lm_notify)(struct file_lock___154 *);
	int (*lm_grant)(struct file_lock___154 *, struct file_lock___154 *, int);
	void (*lm_break)(struct file_lock___154 *);
	int (*lm_change)(struct file_lock___154 **, int);
};

struct fasync_struct___154 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___154 *fa_next;
	struct file___154 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___154 {
	const char *name;
	int fs_flags;
	struct dentry___154 * (*mount)(struct file_system_type___154 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___154 *);
	struct module *owner;
	struct file_system_type___154 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___154 {
	struct inode___154 * (*alloc_inode)(struct super_block___154 *);
	void (*destroy_inode)(struct inode___154 *);
	void (*dirty_inode)(struct inode___154 *, int);
	int (*write_inode)(struct inode___154 *, struct writeback_control *);
	int (*drop_inode)(struct inode___154 *);
	void (*evict_inode)(struct inode___154 *);
	void (*put_super)(struct super_block___154 *);
	int (*sync_fs)(struct super_block___154 *, int);
	int (*freeze_fs)(struct super_block___154 *);
	int (*unfreeze_fs)(struct super_block___154 *);
	int (*statfs)(struct dentry___154 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___154 *, int *, char *);
	void (*umount_begin)(struct super_block___154 *);
	int (*show_options)(struct seq_file___113 *, struct dentry___154 *);
	int (*show_devname)(struct seq_file___113 *, struct dentry___154 *);
	int (*show_path)(struct seq_file___113 *, struct dentry___154 *);
	int (*show_stats)(struct seq_file___113 *, struct dentry___154 *);
	ssize_t (*quota_read)(struct super_block___154 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___154 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___154 *);
	int (*bdev_try_to_free_page)(struct super_block___154 *, struct page___153 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___154 *);
	void (*free_cached_objects)(struct super_block___154 *, int);
};

typedef void (*poll_queue_proc___95)(struct file___154 *, wait_queue_head_t *, struct poll_table_struct___93 *);

struct poll_table_struct___93 {
	poll_queue_proc___95 _qproc;
	long unsigned int _key;
};

struct irq_chip___107 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___107 *);
	void (*irq_shutdown)(struct irq_data___107 *);
	void (*irq_enable)(struct irq_data___107 *);
	void (*irq_disable)(struct irq_data___107 *);
	void (*irq_ack)(struct irq_data___107 *);
	void (*irq_mask)(struct irq_data___107 *);
	void (*irq_mask_ack)(struct irq_data___107 *);
	void (*irq_unmask)(struct irq_data___107 *);
	void (*irq_eoi)(struct irq_data___107 *);
	int (*irq_set_affinity)(struct irq_data___107 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___107 *);
	int (*irq_set_type)(struct irq_data___107 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___107 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___107 *);
	void (*irq_bus_sync_unlock)(struct irq_data___107 *);
	void (*irq_cpu_online)(struct irq_data___107 *);
	void (*irq_cpu_offline)(struct irq_data___107 *);
	void (*irq_suspend)(struct irq_data___107 *);
	void (*irq_resume)(struct irq_data___107 *);
	void (*irq_pm_shutdown)(struct irq_data___107 *);
	void (*irq_print_chip)(struct irq_data___107 *, struct seq_file___113 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___107 *, void *);
	long unsigned int flags;
};

struct cgroupfs_root___100;

struct cgroup___100 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___100 *parent;
	struct dentry___154 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___100 *subsys[11];
	struct cgroupfs_root___100 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___157 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___100 {
	struct super_block___154 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___100 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___50 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___154 *, struct file___154 *);
	ssize_t (*read)(struct cgroup___100 *, struct cftype___50 *, struct file___154 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___100 *, struct cftype___50 *);
	s64 (*read_s64)(struct cgroup___100 *, struct cftype___50 *);
	int (*read_map)(struct cgroup___100 *, struct cftype___50 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___100 *, struct cftype___50 *, struct seq_file___113 *);
	ssize_t (*write)(struct cgroup___100 *, struct cftype___50 *, struct file___154 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___100 *, struct cftype___50 *, u64);
	int (*write_s64)(struct cgroup___100 *, struct cftype___50 *, s64);
	int (*write_string)(struct cgroup___100 *, struct cftype___50 *, const char *);
	int (*trigger)(struct cgroup___100 *, unsigned int);
	int (*release)(struct inode___154 *, struct file___154 *);
	int (*register_event)(struct cgroup___100 *, struct cftype___50 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___100 *, struct cftype___50 *, struct eventfd_ctx *);
};

struct cftype_set___48 {
	struct list_head node;
	struct cftype___50 *cfts;
};

struct task_and_cgroup___48 {
	struct task_struct___156 *task;
	struct cgroup___100 *cgrp;
	struct css_set___100 *cg;
};

struct cgroup_taskset___48 {
	struct task_and_cgroup___48 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___100 *cur_cgrp;
};

struct cgroup_subsys___48 {
	struct cgroup_subsys_state___100 * (*css_alloc)(struct cgroup___100 *);
	int (*css_online)(struct cgroup___100 *);
	void (*css_offline)(struct cgroup___100 *);
	void (*css_free)(struct cgroup___100 *);
	int (*can_attach)(struct cgroup___100 *, struct cgroup_taskset___48 *);
	void (*cancel_attach)(struct cgroup___100 *, struct cgroup_taskset___48 *);
	void (*attach)(struct cgroup___100 *, struct cgroup_taskset___48 *);
	void (*fork)(struct task_struct___156 *);
	void (*exit)(struct cgroup___100 *, struct cgroup___100 *, struct task_struct___156 *);
	void (*bind)(struct cgroup___100 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___100 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___50 *base_cftypes;
	struct cftype_set___48 base_cftset;
	struct module *module;
};

struct dma_map_ops___41 {
	void * (*alloc)(struct device___118 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___118 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___118 *, struct vm_area_struct___161 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___118 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___118 *, struct page___153 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___118 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___118 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___118 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___118 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___118 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___118 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___118 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___118 *, dma_addr_t);
	int (*dma_supported)(struct device___118 *, u64);
	int (*set_dma_mask)(struct device___118 *, u64);
	int is_phys;
};

struct bus_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___118 *, char *);
	ssize_t (*store)(struct bus_type___118 *, const char *, size_t);
};

struct device_attribute___118;

struct driver_attribute___118;

struct bus_type___118 {
	const char *name;
	const char *dev_name;
	struct device___118 *dev_root;
	struct bus_attribute___118 *bus_attrs;
	struct device_attribute___118 *dev_attrs;
	struct driver_attribute___118 *drv_attrs;
	const struct attribute_group___111 **bus_groups;
	const struct attribute_group___111 **dev_groups;
	const struct attribute_group___111 **drv_groups;
	int (*match)(struct device___118 *, struct device_driver___118 *);
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	int (*probe)(struct device___118 *);
	int (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*online)(struct device___118 *);
	int (*offline)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct device___118 *, struct device_attribute___118 *, char *);
	ssize_t (*store)(struct device___118 *, struct device_attribute___118 *, const char *, size_t);
};

struct driver_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___118 *, char *);
	ssize_t (*store)(struct device_driver___118 *, const char *, size_t);
};

struct device_driver___118 {
	const char *name;
	struct bus_type___118 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___118 *);
	int (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	const struct attribute_group___111 **groups;
	const struct dev_pm_ops___118 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___118 {
	const char *name;
	const struct attribute_group___111 **groups;
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
};

struct class_attribute___118;

struct class___118 {
	const char *name;
	struct module *owner;
	struct class_attribute___118 *class_attrs;
	struct device_attribute___118 *dev_attrs;
	const struct attribute_group___111 **dev_groups;
	struct bin_attribute___113 *dev_bin_attrs;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *);
	void (*class_release)(struct class___118 *);
	void (*dev_release)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
	struct subsys_private *p;
};

struct class_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct class___118 *, struct class_attribute___118 *, char *);
	ssize_t (*store)(struct class___118 *, struct class_attribute___118 *, const char *, size_t);
	const void * (*namespace)(struct class___118 *, const struct class_attribute___118 *);
};

struct device_rh___118 {
	struct dev_pm_info_rh___118 power;
};

struct seq_operations___112 {
	void * (*start)(struct seq_file___113 *, loff_t *);
	void (*stop)(struct seq_file___113 *, void *);
	void * (*next)(struct seq_file___113 *, void *, loff_t *);
	int (*show)(struct seq_file___113 *, void *);
};

struct netns_core___21 {
	struct ctl_table_header___24 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___21 {
	struct mutex___157 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___21 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___24 *ctl;
};

struct netns_ipv4___21 {
	struct ctl_table_header___24 *forw_hdr;
	struct ctl_table_header___24 *frags_hdr;
	struct ctl_table_header___24 *ipv4_hdr;
	struct ctl_table_header___24 *route_hdr;
	struct ctl_table_header___24 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___11 *fibnl;
	struct sock___11 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___21 {
	struct ctl_table_header___24 *hdr;
	struct ctl_table_header___24 *route_hdr;
	struct ctl_table_header___24 *icmp_hdr;
	struct ctl_table_header___24 *frags_hdr;
	struct ctl_table_header___24 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___10;

struct dst_ops___21 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___21 *);
	struct dst_entry___10 * (*check)(struct dst_entry___10 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___10 *);
	unsigned int (*mtu)(const struct dst_entry___10 *);
	u32 * (*cow_metrics)(struct dst_entry___10 *, long unsigned int);
	void (*destroy)(struct dst_entry___10 *);
	void (*ifdown)(struct dst_entry___10 *, struct net_device___13 *, int);
	struct dst_entry___10 * (*negative_advice)(struct dst_entry___10 *);
	void (*link_failure)(struct sk_buff___15 *);
	void (*update_pmtu)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___15 *, u32);
	void (*redirect)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___15 *);
	int (*local_out)(struct sk_buff___15 *);
	struct neighbour___10 * (*neigh_lookup)(const struct dst_entry___10 *, struct sk_buff___15 *, const void *);
	struct kmem_cache___140 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___21 {
	struct netns_sysctl_ipv6___21 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___21 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___11 **icmp_sk;
	struct sock___11 *ndisc_sk;
	struct sock___11 *tcp_sk;
	struct sock___11 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___21 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___24 *sysctl_header;
	struct sock___11 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___10 {
	struct sock___11 *v4_ctl_sk;
	struct sock___11 *v6_ctl_sk;
};

struct netns_nf___21 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___24 *nf_log_dir_header;
};

struct nf_proto_net___21 {
	struct ctl_table_header___24 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___21 {
	struct nf_proto_net___21 pn;
	unsigned int timeout;
};

struct nf_tcp_net___21 {
	struct nf_proto_net___21 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___21 {
	struct nf_proto_net___21 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___21 {
	struct nf_proto_net___21 pn;
	unsigned int timeout;
};

struct nf_ip_net___21 {
	struct nf_generic_net___21 generic;
	struct nf_tcp_net___21 tcp;
	struct nf_udp_net___21 udp;
	struct nf_icmp_net___21 icmp;
	struct nf_icmp_net___21 icmpv6;
};

struct netns_ct___21 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___24 *sysctl_header;
	struct ctl_table_header___24 *acct_sysctl_header;
	struct ctl_table_header___24 *tstamp_sysctl_header;
	struct ctl_table_header___24 *event_sysctl_header;
	struct ctl_table_header___24 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___140 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___21 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___21 {
	struct netns_sysctl_ipv6___21 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___21 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___11 *nlsk;
	struct sock___11 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___24 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___21 xfrm4_dst_ops;
	struct dst_ops___21 xfrm6_dst_ops;
};

struct net___22 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___24 sysctls;
	struct sock___11 *rtnl;
	struct sock___11 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___13 *loopback_dev;
	struct netns_core___21 core;
	struct netns_mib___2 mib;
	struct netns_packet___21 packet;
	struct netns_unix___21 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___21 ipv4;
	struct netns_ipv6___21 ipv6;
	struct netns_sctp___21 sctp;
	struct netns_dccp___10 dccp;
	struct netns_nf___21 nf;
	struct netns_xt xt;
	struct netns_ct___21 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___21 nf_frag;
	struct sock___11 *nfnl;
	struct sock___11 *nfnl_stash;
	struct sk_buff_head___12 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___21 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___11 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___11 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___157 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___157 flow_flush_sem;
	long: 64;
	long: 64;
};

struct perf_cpu_context___75;

struct pmu___75 {
	struct list_head entry;
	struct device___118 *dev;
	const struct attribute_group___111 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___75 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___75 *);
	void (*pmu_disable)(struct pmu___75 *);
	int (*event_init)(struct perf_event___75 *);
	int (*add)(struct perf_event___75 *, int);
	void (*del)(struct perf_event___75 *, int);
	void (*start)(struct perf_event___75 *, int);
	void (*stop)(struct perf_event___75 *, int);
	void (*read)(struct perf_event___75 *);
	void (*start_txn)(struct pmu___75 *);
	int (*commit_txn)(struct pmu___75 *);
	void (*cancel_txn)(struct pmu___75 *);
	int (*event_idx)(struct perf_event___75 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___75 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___75 *);
};

struct perf_cpu_context___75 {
	struct perf_event_context___75 ctx;
	struct perf_event_context___75 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___75 *unique_pmu;
	struct perf_cgroup___75 *cgrp;
};

struct trace_event_functions___65;

struct trace_event___65 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___65 *funcs;
};

struct ftrace_event_class___65;

struct ftrace_event_call___65 {
	struct list_head list;
	struct ftrace_event_class___65 *class;
	char *name;
	struct trace_event___65 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___75 {
	struct cgroup_subsys_state___100 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___65 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___157 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___65)(struct trace_iterator___65 *, int, struct trace_event___65 *);

struct trace_event_functions___65 {
	trace_print_func___65 trace;
	trace_print_func___65 raw;
	trace_print_func___65 hex;
	trace_print_func___65 binary;
};

struct ftrace_event_class___65 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___65 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___65 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___65 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___65 *);
};

enum sock_type {
	SOCK_STREAM = 1,
	SOCK_DGRAM = 2,
	SOCK_RAW = 3,
	SOCK_RDM = 4,
	SOCK_SEQPACKET = 5,
	SOCK_DCCP = 6,
	SOCK_PACKET = 10,
};

struct socket_wq___10 {
	wait_queue_head_t wait;
	struct fasync_struct___154 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___10 {
	int family;
	struct module *owner;
	int (*release)(struct socket___11 *);
	int (*bind)(struct socket___11 *, struct sockaddr *, int);
	int (*connect)(struct socket___11 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___11 *, struct socket___11 *);
	int (*accept)(struct socket___11 *, struct socket___11 *, int);
	int (*getname)(struct socket___11 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___154 *, struct socket___11 *, struct poll_table_struct___93 *);
	int (*ioctl)(struct socket___11 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___11 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___11 *, int);
	int (*shutdown)(struct socket___11 *, int);
	int (*setsockopt)(struct socket___11 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___11 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___11 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___11 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___17 *, struct socket___11 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___17 *, struct socket___11 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___154 *, struct socket___11 *, struct vm_area_struct___161 *);
	ssize_t (*sendpage)(struct socket___11 *, struct page___153 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___11 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___11 *, int);
		struct {
			void (*set_peek_off)(struct sock___11 *, int);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
};

struct nf_bridge_info___11 {
	atomic_t use;
	unsigned int mask;
	struct net_device___13 *physindev;
	struct net_device___13 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___11(struct sk_buff___15 **);

struct net_device_ops___11;

struct ethtool_ops___11;

struct header_ops___11;

struct inet6_dev___7;

struct netdev_rx_queue___11;

struct netdev_queue___11;

struct rtnl_link_ops___10;

struct dcbnl_rtnl_ops___11;

struct net_device___13 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___11 *netdev_ops;
	const struct ethtool_ops___11 *ethtool_ops;
	const struct header_ops___11 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___13 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___7 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___11 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___11 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___11 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___11 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___11 = 0,
		NETREG_REGISTERED___11 = 1,
		NETREG_UNREGISTERING___11 = 2,
		NETREG_UNREGISTERED___11 = 3,
		NETREG_RELEASED___11 = 4,
		NETREG_DUMMY___11 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___11 = 0,
		RTNL_LINK_INITIALIZING___11 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___13 *);
	struct netpoll_info *npinfo;
	struct net___22 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide22;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___118 dev;
	const struct attribute_group___111 *sysfs_groups[4];
	const struct rtnl_link_ops___10 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___11 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	IPPROTO_IP = 0,
	IPPROTO_ICMP = 1,
	IPPROTO_IGMP = 2,
	IPPROTO_IPIP = 4,
	IPPROTO_TCP = 6,
	IPPROTO_EGP = 8,
	IPPROTO_PUP = 12,
	IPPROTO_UDP = 17,
	IPPROTO_IDP = 22,
	IPPROTO_DCCP = 33,
	IPPROTO_RSVP = 46,
	IPPROTO_GRE = 47,
	IPPROTO_IPV6 = 41,
	IPPROTO_ESP = 50,
	IPPROTO_AH = 51,
	IPPROTO_BEETPH = 94,
	IPPROTO_PIM = 103,
	IPPROTO_COMP = 108,
	IPPROTO_SCTP = 132,
	IPPROTO_UDPLITE = 136,
	IPPROTO_RAW = 255,
	IPPROTO_MAX = 256,
};

struct sockaddr_in {
	__kernel_sa_family_t sin_family;
	__be16 sin_port;
	struct in_addr sin_addr;
	unsigned char __pad[8];
};

struct sockaddr_in6 {
	short unsigned int sin6_family;
	__be16 sin6_port;
	__be32 sin6_flowinfo;
	struct in6_addr sin6_addr;
	__u32 sin6_scope_id;
};

struct nf_hook_state___3 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___13 *in;
	struct net_device___13 *out;
	struct sock___11 *sk;
	int (*okfn)(struct sock___11 *, struct sk_buff___15 *);
};

struct nf_hook_ops___2;

typedef unsigned int nf_hookfn(const struct nf_hook_ops___2 *, struct sk_buff___15 *, const struct net_device___13 *, const struct net_device___13 *, const struct nf_hook_state___3 *);

struct nf_hook_ops___2 {
	struct list_head list;
	nf_hookfn *hook;
	struct module *owner;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
	long unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct nf_afinfo___21 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___15 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___15 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___22 *, struct dst_entry___10 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___15 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___15 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct rtable___4;

struct dst_entry___10 {
	struct callback_head callback_head;
	struct dst_entry___10 *child;
	struct net_device___13 *dev;
	struct dst_ops___21 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___10 *path;
	struct dst_entry___10 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___15 *);
	union {
		int (*output)(struct sock___11 *, struct sk_buff___15 *);
		struct {
			int (*output)(struct sk_buff___15 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___10 *next;
		struct rtable___4 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

enum nf_ip_hook_priorities {
	NF_IP_PRI_FIRST = 2147483648,
	NF_IP_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP_PRI_RAW = 4294966996,
	NF_IP_PRI_SELINUX_FIRST = 4294967071,
	NF_IP_PRI_CONNTRACK = 4294967096,
	NF_IP_PRI_MANGLE = 4294967146,
	NF_IP_PRI_NAT_DST = 4294967196,
	NF_IP_PRI_FILTER = 0,
	NF_IP_PRI_SECURITY = 50,
	NF_IP_PRI_NAT_SRC = 100,
	NF_IP_PRI_SELINUX_LAST = 225,
	NF_IP_PRI_CONNTRACK_HELPER = 300,
	NF_IP_PRI_CONNTRACK_CONFIRM = 2147483647,
	NF_IP_PRI_LAST = 2147483647,
};

enum nf_ip6_hook_priorities {
	NF_IP6_PRI_FIRST = 2147483648,
	NF_IP6_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP6_PRI_RAW = 4294966996,
	NF_IP6_PRI_SELINUX_FIRST = 4294967071,
	NF_IP6_PRI_CONNTRACK = 4294967096,
	NF_IP6_PRI_MANGLE = 4294967146,
	NF_IP6_PRI_NAT_DST = 4294967196,
	NF_IP6_PRI_FILTER = 0,
	NF_IP6_PRI_SECURITY = 50,
	NF_IP6_PRI_NAT_SRC = 100,
	NF_IP6_PRI_SELINUX_LAST = 225,
	NF_IP6_PRI_CONNTRACK_HELPER = 300,
	NF_IP6_PRI_LAST = 2147483647,
};

struct nf_ipv6_ops___2 {
	int (*chk_addr)(struct net___22 *, const struct in6_addr *, const struct net_device___13 *, int);
};

struct tty_operations___14 {
	struct tty_struct___14 * (*lookup)(struct tty_driver___14 *, struct inode___154 *, int);
	int (*install)(struct tty_driver___14 *, struct tty_struct___14 *);
	void (*remove)(struct tty_driver___14 *, struct tty_struct___14 *);
	int (*open)(struct tty_struct___14 *, struct file___154 *);
	void (*close)(struct tty_struct___14 *, struct file___154 *);
	void (*shutdown)(struct tty_struct___14 *);
	void (*cleanup)(struct tty_struct___14 *);
	int (*write)(struct tty_struct___14 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___14 *, unsigned char);
	void (*flush_chars)(struct tty_struct___14 *);
	int (*write_room)(struct tty_struct___14 *);
	int (*chars_in_buffer)(struct tty_struct___14 *);
	int (*ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	void (*throttle)(struct tty_struct___14 *);
	void (*unthrottle)(struct tty_struct___14 *);
	void (*stop)(struct tty_struct___14 *);
	void (*start)(struct tty_struct___14 *);
	void (*hangup)(struct tty_struct___14 *);
	int (*break_ctl)(struct tty_struct___14 *, int);
	void (*flush_buffer)(struct tty_struct___14 *);
	void (*set_ldisc)(struct tty_struct___14 *);
	void (*wait_until_sent)(struct tty_struct___14 *, int);
	void (*send_xchar)(struct tty_struct___14 *, char);
	int (*tiocmget)(struct tty_struct___14 *);
	int (*tiocmset)(struct tty_struct___14 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___14 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___14 *, struct termiox *);
	int (*get_icount)(struct tty_struct___14 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___14 *, int, char *);
	int (*poll_get_char)(struct tty_driver___14 *, int);
	void (*poll_put_char)(struct tty_driver___14 *, int, char);
	const struct file_operations___154 *proc_fops;
};

struct tty_driver___14 {
	int magic;
	struct kref kref;
	struct cdev___41 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___14 *other;
	struct tty_struct___14 **ttys;
	struct tty_port___14 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___14 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___14;

struct tty_port___14 {
	struct tty_bufhead buf;
	struct tty_struct___14 *tty;
	struct tty_struct___14 *itty;
	const struct tty_port_operations___14 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___157 mutex;
	struct mutex___157 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___14 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___14 *);
	void (*close)(struct tty_struct___14 *);
	void (*flush_buffer)(struct tty_struct___14 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___14 *);
	ssize_t (*read)(struct tty_struct___14 *, struct file___154 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___14 *, struct file___154 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___14 *, struct file___154 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___14 *, struct file___154 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___14 *, struct file___154 *, struct poll_table_struct___93 *);
	int (*hangup)(struct tty_struct___14 *);
	void (*receive_buf)(struct tty_struct___14 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___14 *);
	void (*dcd_change)(struct tty_struct___14 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___14 *, int);
};

struct tty_ldisc___14 {
	struct tty_ldisc_ops___14 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___14 *tty;
};

struct tty_port_operations___14 {
	int (*carrier_raised)(struct tty_port___14 *);
	void (*dtr_rts)(struct tty_port___14 *, int);
	void (*shutdown)(struct tty_port___14 *);
	void (*drop)(struct tty_port___14 *);
	int (*activate)(struct tty_port___14 *, struct tty_struct___14 *);
	void (*destruct)(struct tty_port___14 *);
};

struct tty_file_private {
	struct tty_struct___14 *tty;
	struct file___154 *file;
	struct list_head list;
};

struct dev_pm_qos_request___15 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___118 *dev;
};

struct ethtool_ops___11 {
	int (*get_settings)(struct net_device___13 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___13 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___13 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___13 *);
	void (*get_regs)(struct net_device___13 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___13 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___13 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___13 *);
	void (*set_msglevel)(struct net_device___13 *, u32);
	int (*nway_reset)(struct net_device___13 *);
	u32 (*get_link)(struct net_device___13 *);
	int (*get_eeprom_len)(struct net_device___13 *);
	int (*get_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___13 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___13 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___13 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___13 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___13 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___13 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___13 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___13 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___13 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___13 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___13 *);
	void (*complete)(struct net_device___13 *);
	u32 (*get_priv_flags)(struct net_device___13 *);
	int (*set_priv_flags)(struct net_device___13 *, u32);
	int (*get_sset_count)(struct net_device___13 *, int);
	int (*get_rxnfc)(struct net_device___13 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___13 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___13 *, struct ethtool_flash *);
	int (*reset)(struct net_device___13 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___13 *);
	int (*get_rxfh_indir)(struct net_device___13 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___13 *, const u32 *);
	void (*get_channels)(struct net_device___13 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___13 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___13 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___13 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___13 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___13 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___13 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___13 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___13 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___13 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___13 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___13 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_table___10;

struct neigh_parms___10;

struct neigh_ops___10;

struct neighbour___10 {
	struct neighbour___10 *next;
	struct neigh_table___10 *tbl;
	struct neigh_parms___10 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___12 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___10 *, struct sk_buff___15 *);
	const struct neigh_ops___10 *ops;
	struct callback_head rcu;
	struct net_device___13 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___11 {
	int (*ieee_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___13 *);
	u8 (*setstate)(struct net_device___13 *, u8);
	void (*getpermhwaddr)(struct net_device___13 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___13 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___13 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___13 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___13 *, int, u8 *);
	void (*setpfccfg)(struct net_device___13 *, int, u8);
	void (*getpfccfg)(struct net_device___13 *, int, u8 *);
	u8 (*setall)(struct net_device___13 *);
	u8 (*getcap)(struct net_device___13 *, int, u8 *);
	int (*getnumtcs)(struct net_device___13 *, int, u8 *);
	int (*setnumtcs)(struct net_device___13 *, int, u8);
	u8 (*getpfcstate)(struct net_device___13 *);
	void (*setpfcstate)(struct net_device___13 *, u8);
	void (*getbcncfg)(struct net_device___13 *, int, u32 *);
	void (*setbcncfg)(struct net_device___13 *, int, u32);
	void (*getbcnrp)(struct net_device___13 *, int, u8 *);
	void (*setbcnrp)(struct net_device___13 *, int, u8);
	u8 (*setapp)(struct net_device___13 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___13 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___13 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___13 *, int, u8);
	u8 (*getdcbx)(struct net_device___13 *);
	u8 (*setdcbx)(struct net_device___13 *, u8);
	int (*peer_getappinfo)(struct net_device___13 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___13 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___13 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___13 *, struct cee_pfc *);
};

struct netlink_callback___12 {
	struct sk_buff___15 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___15 *, struct netlink_callback___12 *);
	int (*done)(struct netlink_callback___12 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___11 {
	int (*create)(struct sk_buff___15 *, struct net_device___13 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___15 *, unsigned char *);
	int (*rebuild)(struct sk_buff___15 *);
	int (*cache)(const struct neighbour___10 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___13 *, const unsigned char *);
};

struct napi_struct___11 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___11 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___13 *dev;
	struct sk_buff___15 *gro_list;
	struct sk_buff___15 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___11 {
	struct net_device___13 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___13 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___11 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___13 kobj;
	struct net_device___13 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___11 {
	int (*ndo_init)(struct net_device___13 *);
	void (*ndo_uninit)(struct net_device___13 *);
	int (*ndo_open)(struct net_device___13 *);
	int (*ndo_stop)(struct net_device___13 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___15 *, struct net_device___13 *);
	u16 (*ndo_select_queue)(struct net_device___13 *, struct sk_buff___15 *);
	void (*ndo_change_rx_flags)(struct net_device___13 *, int);
	void (*ndo_set_rx_mode)(struct net_device___13 *);
	int (*ndo_set_mac_address)(struct net_device___13 *, void *);
	int (*ndo_validate_addr)(struct net_device___13 *);
	int (*ndo_do_ioctl)(struct net_device___13 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___13 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___13 *, int);
	int (*ndo_neigh_setup)(struct net_device___13 *, struct neigh_parms___10 *);
	void (*ndo_tx_timeout)(struct net_device___13 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___13 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___13 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___13 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___13 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___13 *);
	int (*ndo_netpoll_setup)(struct net_device___13 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___13 *);
	int (*ndo_busy_poll)(struct napi_struct___11 *);
	int (*ndo_set_vf_mac)(struct net_device___13 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___13 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___13 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___13 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___13 *, int, struct ifla_vf_info___2 *);
	int (*ndo_set_vf_link_state)(struct net_device___13 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___13 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___13 *, int, struct sk_buff___15 *);
	int (*ndo_setup_tc)(struct net_device___13 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___13 *);
	int (*ndo_fcoe_disable)(struct net_device___13 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___13 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___13 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___13 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___13 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___13 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___13 *, const struct sk_buff___15 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___13 *, struct net_device___13 *);
	int (*ndo_del_slave)(struct net_device___13 *, struct net_device___13 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___10 *);
	void (*ndo_neigh_destroy)(struct neighbour___10 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___15 *, struct netlink_callback___12 *, struct net_device___13 *, int);
	int (*ndo_bridge_setlink)(struct net_device___13 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___15 *, u32, u32, struct net_device___13 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___13 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___13 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___13 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___13 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___13 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___13 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___15 *, struct net_device___13 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___13 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___13 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___13 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___10 {
	struct net___22 *net;
	struct net_device___13 *dev;
	struct neigh_parms___10 *next;
	int (*neigh_setup)(struct neighbour___10 *);
	void (*neigh_cleanup)(struct neighbour___10 *);
	struct neigh_table___10 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___7;

struct ifacaddr6___7;

struct inet6_dev___7 {
	struct net_device___13 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___7 *mc_list;
	struct ifmcaddr6___7 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___10 *nd_parms;
	struct inet6_dev___7 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___10 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___13 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___22 *, struct net_device___13 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___13 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___13 *, struct list_head *);
	size_t (*get_size)(const struct net_device___13 *);
	int (*fill_info)(struct sk_buff___15 *, const struct net_device___13 *);
	size_t (*get_xstats_size)(const struct net_device___13 *);
	int (*fill_xstats)(struct sk_buff___15 *, const struct net_device___13 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___22 * (*get_link_net)(const struct net_device___13 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___13 *, struct net_device___13 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___13 *, const struct net_device___13 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___15 *, const struct net_device___13 *, const struct net_device___13 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___11 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___15 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___10;

struct neigh_hash_table___10;

struct neigh_table___10 {
	struct neigh_table___10 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___13 *, __u32 *);
	int (*constructor)(struct neighbour___10 *);
	int (*pconstructor)(struct pneigh_entry___10 *);
	void (*pdestructor)(struct pneigh_entry___10 *);
	void (*proxy_redo)(struct sk_buff___15 *);
	char *id;
	struct neigh_parms___10 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___12 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___10 *nht;
	struct pneigh_entry___10 **phash_buckets;
};

struct neigh_ops___10 {
	int family;
	void (*solicit)(struct neighbour___10 *, struct sk_buff___15 *);
	void (*error_report)(struct neighbour___10 *, struct sk_buff___15 *);
	int (*output)(struct neighbour___10 *, struct sk_buff___15 *);
	int (*connected_output)(struct neighbour___10 *, struct sk_buff___15 *);
};

struct pneigh_entry___10 {
	struct pneigh_entry___10 *next;
	struct net___22 *net;
	struct net_device___13 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___10 {
	struct neighbour___10 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___4 {
	struct dst_entry___10 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___8;

struct proto___10 {
	void (*close)(struct sock___11 *, long int);
	int (*connect)(struct sock___11 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___11 *, int);
	struct sock___11 * (*accept)(struct sock___11 *, int, int *);
	int (*ioctl)(struct sock___11 *, int, long unsigned int);
	int (*init)(struct sock___11 *);
	void (*destroy)(struct sock___11 *);
	void (*shutdown)(struct sock___11 *, int);
	int (*setsockopt)(struct sock___11 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___11 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___11 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___11 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___11 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___17 *, struct sock___11 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___17 *, struct sock___11 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___11 *, struct page___153 *, int, size_t, int);
	int (*bind)(struct sock___11 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___11 *, struct sk_buff___15 *);
	void (*release_cb)(struct sock___11 *);
	void (*mtu_reduced)(struct sock___11 *);
	void (*hash)(struct sock___11 *);
	void (*unhash)(struct sock___11 *);
	void (*rehash)(struct sock___11 *);
	int (*get_port)(struct sock___11 *, short unsigned int);
	void (*clear_sk)(struct sock___11 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___11 *);
	void (*enter_memory_pressure)(struct sock___11 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___140 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___8 *rsk_prot;
	struct timewait_sock_ops___8 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___48 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___10 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___10 {
	void (*enter_memory_pressure)(struct sock___11 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_listen_hashbucket {
	spinlock_t lock;
	struct hlist_nulls_head head;
};

struct inet_ehash_bucket;

struct inet_bind_hashbucket;

struct inet_hashinfo {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___140 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___8 {
	int family;
	int obj_size;
	struct kmem_cache___140 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___11 *, struct request_sock___8 *);
	void (*send_ack)(struct sock___11 *, struct sk_buff___15 *, struct request_sock___8 *);
	void (*send_reset)(struct sock___11 *, struct sk_buff___15 *);
	void (*destructor)(struct request_sock___8 *);
	void (*syn_ack_timeout)(struct sock___11 *, struct request_sock___8 *);
};

struct timewait_sock_ops___8 {
	struct kmem_cache___140 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___11 *, struct sock___11 *, void *);
	void (*twsk_destructor)(struct sock___11 *);
};

struct socket_alloc {
	struct socket___11 socket;
	struct inode___154 vfs_inode;
};

struct ip_options {
	__be32 faddr;
	__be32 nexthop;
	unsigned char optlen;
	unsigned char srr;
	unsigned char rr;
	unsigned char ts;
	unsigned char is_strictroute: 1;
	unsigned char srr_is_hit: 1;
	unsigned char is_changed: 1;
	unsigned char rr_needaddr: 1;
	unsigned char ts_needtime: 1;
	unsigned char ts_needaddr: 1;
	unsigned char router_alert;
	unsigned char cipso;
	unsigned char __pad2;
	unsigned char __data[0];
};

struct ipv6hdr {
	__u8 priority: 4;
	__u8 version: 4;
	__u8 flow_lbl[3];
	__be16 payload_len;
	__u8 nexthdr;
	__u8 hop_limit;
	struct in6_addr saddr;
	struct in6_addr daddr;
};

enum {
	TCP_ESTABLISHED = 1,
	TCP_SYN_SENT = 2,
	TCP_SYN_RECV = 3,
	TCP_FIN_WAIT1 = 4,
	TCP_FIN_WAIT2 = 5,
	TCP_TIME_WAIT = 6,
	TCP_CLOSE = 7,
	TCP_CLOSE_WAIT = 8,
	TCP_LAST_ACK = 9,
	TCP_LISTEN = 10,
	TCP_CLOSING = 11,
	TCP_MAX_STATES = 12,
};

enum {
	TCPF_ESTABLISHED = 2,
	TCPF_SYN_SENT = 4,
	TCPF_SYN_RECV = 8,
	TCPF_FIN_WAIT1 = 16,
	TCPF_FIN_WAIT2 = 32,
	TCPF_TIME_WAIT = 64,
	TCPF_CLOSE = 128,
	TCPF_CLOSE_WAIT = 256,
	TCPF_LAST_ACK = 512,
	TCPF_LISTEN = 1024,
	TCPF_CLOSING = 2048,
};

struct tcphdr {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1: 4;
	__u16 doff: 4;
	__u16 fin: 1;
	__u16 syn: 1;
	__u16 rst: 1;
	__u16 psh: 1;
	__u16 ack: 1;
	__u16 urg: 1;
	__u16 ece: 1;
	__u16 cwr: 1;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

struct udphdr {
	__be16 source;
	__be16 dest;
	__be16 len;
	__sum16 check;
};

struct inet6_skb_parm {
	int iif;
	__be16 ra;
	__u16 hop;
	__u16 dst0;
	__u16 srcrt;
	__u16 dst1;
	__u16 lastopt;
	__u16 nhoff;
	__u16 flags;
	__u16 dsthao;
	__u16 frag_max_size;
};

struct ifmcaddr6___7 {
	struct in6_addr mca_addr;
	struct inet6_dev___7 *idev;
	struct ifmcaddr6___7 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___7 {
	struct in6_addr aca_addr;
	struct inet6_dev___7 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___7 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct inet_skb_parm {
	struct ip_options opt;
	unsigned char flags;
	u16 frag_max_size;
};

struct inet_ehash_bucket {
	struct hlist_nulls_head chain;
};

struct inet_bind_hashbucket {
	spinlock_t lock;
	struct hlist_head chain;
};

struct netlbl_lsm_cache {
	atomic_t refcount;
	void (*free)(const void *);
	void *data;
};

struct netlbl_lsm_catmap {
	u32 startbit;
	u64 bitmap[4];
	struct netlbl_lsm_catmap *next;
};

struct netlbl_lsm_secattr {
	u32 flags;
	u32 type;
	char *domain;
	struct netlbl_lsm_cache *cache;
	struct {
		struct {
			struct netlbl_lsm_catmap *cat;
			u32 lvl;
		} mls;
		u32 secid;
	} attr;
};

struct dccp_hdr {
	__be16 dccph_sport;
	__be16 dccph_dport;
	__u8 dccph_doff;
	__u8 dccph_cscov: 4;
	__u8 dccph_ccval: 4;
	__sum16 dccph_checksum;
	__u8 dccph_x: 1;
	__u8 dccph_type: 4;
	__u8 dccph_reserved: 3;
	__u8 dccph_seq2;
	__be16 dccph_seq;
};

enum dccp_state {
	DCCP_OPEN = 1,
	DCCP_REQUESTING = 2,
	DCCP_LISTEN = 10,
	DCCP_RESPOND = 3,
	DCCP_ACTIVE_CLOSEREQ = 4,
	DCCP_PASSIVE_CLOSE = 8,
	DCCP_CLOSING = 11,
	DCCP_TIME_WAIT = 6,
	DCCP_CLOSED = 7,
	DCCP_PARTOPEN = 12,
	DCCP_PASSIVE_CLOSEREQ = 13,
	DCCP_MAX_STATES = 14,
};

struct tlb_state___38 {
	struct mm_struct___161 *active_mm;
	int state;
};

struct hstate___16 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___50 cgroup_files[5];
	char name[32];
};

struct lsm_network_audit___2 {
	int netif;
	struct sock___11 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct common_audit_data___2 {
	char type;
	union {
		struct path___154 path;
		struct dentry___154 *dentry;
		struct inode___154 *inode;
		struct lsm_network_audit___2 *net;
		int cap;
		int ipc_id;
		struct task_struct___156 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct coredump_params___24 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___154 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct task_security_struct {
	u32 osid;
	u32 sid;
	u32 exec_sid;
	u32 create_sid;
	u32 keycreate_sid;
	u32 sockcreate_sid;
};

struct inode_security_struct {
	struct inode___154 *inode;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
	u32 task_sid;
	u32 sid;
	u16 sclass;
	unsigned char initialized;
	struct mutex___157 lock;
};

struct file_security_struct {
	u32 sid;
	u32 fown_sid;
	u32 isid;
	u32 pseqno;
};

struct superblock_security_struct {
	struct super_block___154 *sb;
	u32 sid;
	u32 def_sid;
	u32 mntpoint_sid;
	unsigned int behavior;
	unsigned char flags;
	struct mutex___157 lock;
	struct list_head isec_head;
	spinlock_t isec_lock;
};

struct msg_security_struct {
	u32 sid;
};

struct ipc_security_struct {
	u16 sclass;
	u32 sid;
};

struct sk_security_struct {
	enum {
		NLBL_UNSET = 0,
		NLBL_REQUIRE = 1,
		NLBL_LABELED = 2,
		NLBL_REQSKB = 3,
		NLBL_CONNLABELED = 4,
	} nlbl_state;
	struct netlbl_lsm_secattr *nlbl_secattr;
	u32 sid;
	u32 peer_sid;
	u16 sclass;
};

struct tun_security_struct {
	u32 sid;
};

struct key_security_struct {
	u32 sid;
};

enum {
	Opt_error___2 = 4294967295,
	Opt_context = 1,
	Opt_fscontext = 2,
	Opt_defcontext = 3,
	Opt_rootcontext = 4,
	Opt_labelsupport = 5,
};

struct device___119;

struct dev_pm_ops___119 {
	int (*prepare)(struct device___119 *);
	void (*complete)(struct device___119 *);
	int (*suspend)(struct device___119 *);
	int (*resume)(struct device___119 *);
	int (*freeze)(struct device___119 *);
	int (*thaw)(struct device___119 *);
	int (*poweroff)(struct device___119 *);
	int (*restore)(struct device___119 *);
	int (*suspend_late)(struct device___119 *);
	int (*resume_early)(struct device___119 *);
	int (*freeze_late)(struct device___119 *);
	int (*thaw_early)(struct device___119 *);
	int (*poweroff_late)(struct device___119 *);
	int (*restore_early)(struct device___119 *);
	int (*suspend_noirq)(struct device___119 *);
	int (*resume_noirq)(struct device___119 *);
	int (*freeze_noirq)(struct device___119 *);
	int (*thaw_noirq)(struct device___119 *);
	int (*poweroff_noirq)(struct device___119 *);
	int (*restore_noirq)(struct device___119 *);
	int (*runtime_suspend)(struct device___119 *);
	int (*runtime_resume)(struct device___119 *);
	int (*runtime_idle)(struct device___119 *);
};

struct dma_map_ops___42;

struct dev_archdata___42 {
	struct dma_map_ops___42 *dma_ops;
	void *iommu;
};

struct device_type___119;

struct bus_type___119;

struct device_driver___119;

struct dev_pm_domain___119;

struct class___119;

struct device_rh___119;

struct device___119 {
	struct device___119 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___119 *type;
	struct mutex___51 mutex;
	struct bus_type___119 *bus;
	struct device_driver___119 *driver;
	void *platform_data;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___119 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___42 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___8 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___119 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___119 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___119 *device_rh;
};

struct dev_pm_info_rh___119 {
	void (*set_latency_tolerance)(struct device___119 *, s32);
};

struct dev_pm_domain___119 {
	struct dev_pm_ops___119 ops;
};

struct tree_descr___3 {
	char *name;
	const struct file_operations___50 *ops;
	int mode;
};

struct dst_ops___22 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___22 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___14 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *);
	int (*local_out)(struct sk_buff___14 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___14 *, const void *);
	struct kmem_cache___41 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___22 {
	struct netns_sysctl_ipv6___21 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___22 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_xfrm___22 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___24 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___22 xfrm4_dst_ops;
	struct dst_ops___22 xfrm6_dst_ops;
};

struct net___23 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___24 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___21 core;
	struct netns_mib___2 mib;
	struct netns_packet___4 packet;
	struct netns_unix___21 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___21 ipv4;
	struct netns_ipv6___22 ipv6;
	struct netns_sctp___21 sctp;
	struct netns_dccp___10 dccp;
	struct netns_nf___21 nf;
	struct netns_xt xt;
	struct netns_ct___4 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___21 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___11 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___22 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___51 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___51 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___42 {
	void * (*alloc)(struct device___119 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___119 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___119 *, struct vm_area_struct___54 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___119 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___119 *, struct page___50 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___119 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___119 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___119 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___119 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___119 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___119 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___119 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___119 *, dma_addr_t);
	int (*dma_supported)(struct device___119 *, u64);
	int (*set_dma_mask)(struct device___119 *, u64);
	int is_phys;
};

struct bus_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___119 *, char *);
	ssize_t (*store)(struct bus_type___119 *, const char *, size_t);
};

struct device_attribute___119;

struct driver_attribute___119;

struct bus_type___119 {
	const char *name;
	const char *dev_name;
	struct device___119 *dev_root;
	struct bus_attribute___119 *bus_attrs;
	struct device_attribute___119 *dev_attrs;
	struct driver_attribute___119 *drv_attrs;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___119 *, struct device_driver___119 *);
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	int (*probe)(struct device___119 *);
	int (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*online)(struct device___119 *);
	int (*offline)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct device___119 *, struct device_attribute___119 *, char *);
	ssize_t (*store)(struct device___119 *, struct device_attribute___119 *, const char *, size_t);
};

struct driver_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___119 *, char *);
	ssize_t (*store)(struct device_driver___119 *, const char *, size_t);
};

struct device_driver___119 {
	const char *name;
	struct bus_type___119 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___119 *);
	int (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	const struct attribute_group___34 **groups;
	const struct dev_pm_ops___119 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___119 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
};

struct class_attribute___119;

struct class___119 {
	const char *name;
	struct module *owner;
	struct class_attribute___119 *class_attrs;
	struct device_attribute___119 *dev_attrs;
	const struct attribute_group___34 **dev_groups;
	struct bin_attribute___34 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *);
	void (*class_release)(struct class___119 *);
	void (*dev_release)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
	struct subsys_private *p;
};

struct class_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct class___119 *, struct class_attribute___119 *, char *);
	ssize_t (*store)(struct class___119 *, struct class_attribute___119 *, const char *, size_t);
	const void * (*namespace)(struct class___119 *, const struct class_attribute___119 *);
};

struct device_rh___119 {
	struct dev_pm_info_rh___119 power;
};

struct common_audit_data___3 {
	char type;
	union {
		struct path___50 path;
		struct dentry___51 *dentry;
		struct inode___51 *inode;
		struct lsm_network_audit___2 *net;
		int cap;
		int ipc_id;
		struct task_struct___51 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

enum {
	POLICYDB_CAPABILITY_NETPEER = 0,
	POLICYDB_CAPABILITY_OPENPERM = 1,
	__POLICYDB_CAPABILITY_MAX = 2,
};

struct nf_afinfo___22 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___14 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___14 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___23 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___14 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___14 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct inode_security_struct___2 {
	struct inode___51 *inode;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
	u32 task_sid;
	u32 sid;
	u16 sclass;
	unsigned char initialized;
	struct mutex___51 lock;
};

enum sel_inos {
	SEL_ROOT_INO = 2,
	SEL_LOAD = 3,
	SEL_ENFORCE = 4,
	SEL_CONTEXT = 5,
	SEL_ACCESS = 6,
	SEL_CREATE = 7,
	SEL_RELABEL = 8,
	SEL_USER = 9,
	SEL_POLICYVERS = 10,
	SEL_COMMIT_BOOLS = 11,
	SEL_MLS = 12,
	SEL_DISABLE = 13,
	SEL_MEMBER = 14,
	SEL_CHECKREQPROT = 15,
	SEL_COMPAT_NET = 16,
	SEL_REJECT_UNKNOWN = 17,
	SEL_DENY_UNKNOWN = 18,
	SEL_STATUS = 19,
	SEL_POLICY = 20,
	SEL_INO_NEXT = 21,
};

struct policy_load_memory {
	size_t len;
	void *data;
};

struct page___154;

typedef struct page___154 *pgtable_t___154;

struct address_space___155;

struct kmem_cache___141;

struct page___154 {
	long unsigned int flags;
	struct address_space___155 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___154 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___154 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___141 *slab_cache;
		struct page___154 *first_page;
	};
	long: 64;
};

struct task_struct___157;

struct pv_cpu_ops___157 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___157 *);
	void (*end_context_switch)(struct task_struct___157 *);
};

struct mutex___158 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___157 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___150 {
	struct page___154 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___162;

struct nsproxy___92;

struct signal_struct___157;

struct task_struct___157 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___157 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___162 *mm;
	struct mm_struct___162 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___157 *real_parent;
	struct task_struct___157 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___157 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___157 = 0,
		VTIME_USER___157 = 1,
		VTIME_SYS___157 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___92 *nsproxy;
	struct signal_struct___157 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___158 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___150 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___162 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___162 *, struct mm_struct___162 *);
	void (*dup_mmap)(struct mm_struct___162 *, struct mm_struct___162 *);
	void (*exit_mmap)(struct mm_struct___162 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___162 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___162 *);
	void (*pgd_free)(struct mm_struct___162 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___162 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___162 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___162 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___162 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___162 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___162 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___162 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___162 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___162 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___162 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___162 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___158 lock;
	void *vdso;
} mm_context_t___158;

struct xol_area___154;

struct uprobes_state___154 {
	struct xol_area___154 *xol_area;
};

struct vm_area_struct___162;

struct file___155;

struct core_state___157;

struct mm_struct___162 {
	struct vm_area_struct___162 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___162 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___162 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___158 context;
	long unsigned int flags;
	struct core_state___157 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___157 *owner;
	struct file___155 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___154 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___157;

struct lruvec___157 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___157 *zone;
};

struct pglist_data___157;

struct zone___157 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___157 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___157 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___157 {
	struct zone___157 *zone;
	int zone_idx;
};

struct zonelist___157 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___157 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___157 {
	struct zone___157 node_zones[4];
	struct zonelist___157 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___157 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___108;

struct x86_io_apic_ops___108 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___108 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___108;

struct irq_data___108 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___108 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___120;

struct dev_pm_ops___120 {
	int (*prepare)(struct device___120 *);
	void (*complete)(struct device___120 *);
	int (*suspend)(struct device___120 *);
	int (*resume)(struct device___120 *);
	int (*freeze)(struct device___120 *);
	int (*thaw)(struct device___120 *);
	int (*poweroff)(struct device___120 *);
	int (*restore)(struct device___120 *);
	int (*suspend_late)(struct device___120 *);
	int (*resume_early)(struct device___120 *);
	int (*freeze_late)(struct device___120 *);
	int (*thaw_early)(struct device___120 *);
	int (*poweroff_late)(struct device___120 *);
	int (*restore_early)(struct device___120 *);
	int (*suspend_noirq)(struct device___120 *);
	int (*resume_noirq)(struct device___120 *);
	int (*freeze_noirq)(struct device___120 *);
	int (*thaw_noirq)(struct device___120 *);
	int (*poweroff_noirq)(struct device___120 *);
	int (*restore_noirq)(struct device___120 *);
	int (*runtime_suspend)(struct device___120 *);
	int (*runtime_resume)(struct device___120 *);
	int (*runtime_idle)(struct device___120 *);
};

struct dma_map_ops___43;

struct dev_archdata___43 {
	struct dma_map_ops___43 *dma_ops;
	void *iommu;
};

struct device_type___120;

struct bus_type___120;

struct device_driver___120;

struct dev_pm_domain___120;

struct class___120;

struct attribute_group___112;

struct device_rh___120;

struct device___120 {
	struct device___120 *parent;
	struct device_private *p;
	struct kobject___13 kobj;
	const char *init_name;
	const struct device_type___120 *type;
	struct mutex___158 mutex;
	struct bus_type___120 *bus;
	struct device_driver___120 *driver;
	void *platform_data;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___120 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___43 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___120 *class;
	const struct attribute_group___112 **groups;
	void (*release)(struct device___120 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___120 *device_rh;
};

struct dev_pm_info_rh___120 {
	void (*set_latency_tolerance)(struct device___120 *, s32);
};

struct dev_pm_domain___120 {
	struct dev_pm_ops___120 ops;
};

struct smp_ops___157 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___157 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___114;

struct attribute_group___112 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___114 **bin_attrs;
};

struct bin_attribute___114 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___155 *, struct kobject___13 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___155 *, struct kobject___13 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	int (*mmap)(struct file___155 *, struct kobject___13 *, struct bin_attribute___114 *, struct vm_area_struct___162 *);
};

struct dentry___155;

struct path___155 {
	struct vfsmount *mnt;
	struct dentry___155 *dentry;
};

struct inode___155;

struct file_operations___155;

struct file___155 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___155 f_path;
	struct inode___155 *f_inode;
	const struct file_operations___155 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___155 *f_mapping;
	struct mutex___158 f_pos_lock;
};

struct vm_operations_struct___135;

struct vm_area_struct___162 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___162 *vm_next;
	struct vm_area_struct___162 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___162 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___135 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___155 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___140 {
	void **freelist;
	long unsigned int tid;
	struct page___154 *page;
	struct page___154 *partial;
};

struct memcg_cache_params___141;

struct kmem_cache___141 {
	struct kmem_cache_cpu___140 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___13 kobj;
	struct memcg_cache_params___141 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___141 {
	bool is_root_cache;
	union {
		struct kmem_cache___141 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___141 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___154 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___154 *page;
	long unsigned int vaddr;
};

struct address_space_operations___155;

struct address_space___155 {
	struct inode___155 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___158 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___155 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___132;

struct vm_operations_struct___135 {
	void (*open)(struct vm_area_struct___162 *);
	void (*close)(struct vm_area_struct___162 *);
	int (*fault)(struct vm_area_struct___162 *, struct vm_fault___132 *);
	int (*page_mkwrite)(struct vm_area_struct___162 *, struct vm_fault___132 *);
	int (*access)(struct vm_area_struct___162 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___162 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___162 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___162 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___162 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___157 {
	struct task_struct___157 *task;
	struct core_thread___157 *next;
};

struct core_state___157 {
	atomic_t nr_threads;
	struct core_thread___157 dumper;
	struct completion startup;
};

struct fasync_struct___155 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___155 *fa_next;
	struct file___155 *fa_file;
	struct callback_head fa_rcu;
};

struct ctl_table_root___25;

struct ctl_table_set___25;

struct ctl_dir___25;

struct ctl_node___25;

struct ctl_table_header___25 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___25 *root;
	struct ctl_table_set___25 *set;
	struct ctl_dir___25 *parent;
	struct ctl_node___25 *node;
};

struct ctl_dir___25 {
	struct ctl_table_header___25 header;
	struct rb_root root;
};

struct ctl_table_set___25 {
	int (*is_seen)(struct ctl_table_set___25 *);
	struct ctl_dir___25 dir;
};

struct netns_core___22 {
	struct ctl_table_header___25 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___22 {
	struct mutex___158 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___22 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___25 *ctl;
};

struct netns_ipv4___22 {
	struct ctl_table_header___25 *forw_hdr;
	struct ctl_table_header___25 *frags_hdr;
	struct ctl_table_header___25 *ipv4_hdr;
	struct ctl_table_header___25 *route_hdr;
	struct ctl_table_header___25 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___22 {
	struct ctl_table_header___25 *hdr;
	struct ctl_table_header___25 *route_hdr;
	struct ctl_table_header___25 *icmp_hdr;
	struct ctl_table_header___25 *frags_hdr;
	struct ctl_table_header___25 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___23 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___23 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___3 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___3 *);
	int (*local_out)(struct sk_buff___3 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___3 *, const void *);
	struct kmem_cache___141 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___23 {
	struct netns_sysctl_ipv6___22 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___23 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___22 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___25 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___22 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___25 *nf_log_dir_header;
};

struct nf_proto_net___22 {
	struct ctl_table_header___25 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___22 {
	struct nf_proto_net___22 pn;
	unsigned int timeout;
};

struct nf_tcp_net___22 {
	struct nf_proto_net___22 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___22 {
	struct nf_proto_net___22 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___22 {
	struct nf_proto_net___22 pn;
	unsigned int timeout;
};

struct nf_ip_net___22 {
	struct nf_generic_net___22 generic;
	struct nf_tcp_net___22 tcp;
	struct nf_udp_net___22 udp;
	struct nf_icmp_net___22 icmp;
	struct nf_icmp_net___22 icmpv6;
};

struct netns_ct___22 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___25 *sysctl_header;
	struct ctl_table_header___25 *acct_sysctl_header;
	struct ctl_table_header___25 *tstamp_sysctl_header;
	struct ctl_table_header___25 *event_sysctl_header;
	struct ctl_table_header___25 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___141 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___22 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___22 {
	struct netns_sysctl_ipv6___22 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___23 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___25 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___23 xfrm4_dst_ops;
	struct dst_ops___23 xfrm6_dst_ops;
};

struct net___24 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___25 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___22 core;
	struct netns_mib___2 mib;
	struct netns_packet___22 packet;
	struct netns_unix___22 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___22 ipv4;
	struct netns_ipv6___23 ipv6;
	struct netns_sctp___22 sctp;
	struct netns_dccp___10 dccp;
	struct netns_nf___22 nf;
	struct netns_xt xt;
	struct netns_ct___22 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___22 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___3 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___23 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___158 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___158 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___43 {
	void * (*alloc)(struct device___120 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___120 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___120 *, struct vm_area_struct___162 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___120 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___120 *, struct page___154 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___120 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___120 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___120 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___120 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___120 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___120 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___120 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___120 *, dma_addr_t);
	int (*dma_supported)(struct device___120 *, u64);
	int (*set_dma_mask)(struct device___120 *, u64);
	int is_phys;
};

struct bus_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___120 *, char *);
	ssize_t (*store)(struct bus_type___120 *, const char *, size_t);
};

struct device_attribute___120;

struct driver_attribute___120;

struct bus_type___120 {
	const char *name;
	const char *dev_name;
	struct device___120 *dev_root;
	struct bus_attribute___120 *bus_attrs;
	struct device_attribute___120 *dev_attrs;
	struct driver_attribute___120 *drv_attrs;
	const struct attribute_group___112 **bus_groups;
	const struct attribute_group___112 **dev_groups;
	const struct attribute_group___112 **drv_groups;
	int (*match)(struct device___120 *, struct device_driver___120 *);
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	int (*probe)(struct device___120 *);
	int (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*online)(struct device___120 *);
	int (*offline)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct device___120 *, struct device_attribute___120 *, char *);
	ssize_t (*store)(struct device___120 *, struct device_attribute___120 *, const char *, size_t);
};

struct driver_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___120 *, char *);
	ssize_t (*store)(struct device_driver___120 *, const char *, size_t);
};

struct device_driver___120 {
	const char *name;
	struct bus_type___120 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___120 *);
	int (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	const struct attribute_group___112 **groups;
	const struct dev_pm_ops___120 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___120 {
	const char *name;
	const struct attribute_group___112 **groups;
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
};

struct class_attribute___120;

struct class___120 {
	const char *name;
	struct module *owner;
	struct class_attribute___120 *class_attrs;
	struct device_attribute___120 *dev_attrs;
	const struct attribute_group___112 **dev_groups;
	struct bin_attribute___114 *dev_bin_attrs;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *);
	void (*class_release)(struct class___120 *);
	void (*dev_release)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
	struct subsys_private *p;
};

struct class_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct class___120 *, struct class_attribute___120 *, char *);
	ssize_t (*store)(struct class___120 *, struct class_attribute___120 *, const char *, size_t);
	const void * (*namespace)(struct class___120 *, const struct class_attribute___120 *);
};

struct device_rh___120 {
	struct dev_pm_info_rh___120 power;
};

struct vm_fault___132 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___154 *page;
};

struct ctl_node___25 {
	struct rb_node node;
	struct ctl_table_header___25 *header;
};

struct ctl_table_root___25 {
	struct ctl_table_set___25 default_set;
	struct ctl_table_set___25 * (*lookup)(struct ctl_table_root___25 *, struct nsproxy___92 *);
	int (*permissions)(struct ctl_table_header___25 *, struct ctl_table *);
};

struct nsproxy___92 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___24 *net_ns;
};

struct signal_struct___157 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___157 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___157 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___158 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	SELNL_MSG_SETENFORCE = 16,
	SELNL_MSG_POLICYLOAD = 17,
	SELNL_MSG_MAX = 18,
};

enum selinux_nlgroups {
	SELNLGRP_NONE = 0,
	SELNLGRP_AVC = 1,
	__SELNLGRP_MAX = 2,
};

struct selnl_msg_setenforce {
	__s32 val;
};

struct selnl_msg_policyload {
	__u32 seqno;
};

struct dentry_operations___155;

struct super_block___155;

struct dentry___155 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___155 *d_parent;
	struct qstr d_name;
	struct inode___155 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___155 *d_op;
	struct super_block___155 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___155;

struct file_lock___155;

struct dquot___155;

struct block_device___155;

struct inode___155 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___155 *i_op;
	struct super_block___155 *i_sb;
	struct address_space___155 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___158 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___155 *i_fop;
	struct file_lock___155 *i_flock;
	struct address_space___155 i_data;
	struct dquot___155 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___155 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___155 {
	int (*d_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_hash)(const struct dentry___155 *, struct qstr *);
	int (*d_compare)(const struct dentry___155 *, const struct dentry___155 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___155 *);
	void (*d_release)(struct dentry___155 *);
	void (*d_prune)(struct dentry___155 *);
	void (*d_iput)(struct dentry___155 *, struct inode___155 *);
	char * (*d_dname)(struct dentry___155 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___155 *);
	int (*d_manage)(struct dentry___155 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___155;

struct mem_dqinfo___155 {
	struct quota_format_type___155 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___155;

struct quota_info___155 {
	unsigned int flags;
	struct mutex___158 dqio_mutex;
	struct mutex___158 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___155 *files[2];
	struct mem_dqinfo___155 info[2];
	const struct quota_format_ops___155 *ops[2];
};

struct file_system_type___155;

struct super_operations___155;

struct dquot_operations___155;

struct quotactl_ops___155;

struct super_block___155 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___155 *s_type;
	const struct super_operations___155 *s_op;
	const struct dquot_operations___155 *dq_op;
	const struct quotactl_ops___155 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___155 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___155 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___155 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___158 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___155 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___155 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___155 *bd_inode;
	struct super_block___155 *bd_super;
	struct mutex___158 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___155 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___158 bd_fsfreeze_mutex;
};

struct iattr___155 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___155 *ia_file;
};

struct dquot___155 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___158 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___155 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___155 {
	int qf_fmt_id;
	const struct quota_format_ops___155 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___155 *qf_next;
};

struct quota_format_ops___155 {
	int (*check_quota_file)(struct super_block___155 *, int);
	int (*read_file_info)(struct super_block___155 *, int);
	int (*write_file_info)(struct super_block___155 *, int);
	int (*free_file_info)(struct super_block___155 *, int);
	int (*read_dqblk)(struct dquot___155 *);
	int (*commit_dqblk)(struct dquot___155 *);
	int (*release_dqblk)(struct dquot___155 *);
};

struct dquot_operations___155 {
	int (*write_dquot)(struct dquot___155 *);
	struct dquot___155 * (*alloc_dquot)(struct super_block___155 *, int);
	void (*destroy_dquot)(struct dquot___155 *);
	int (*acquire_dquot)(struct dquot___155 *);
	int (*release_dquot)(struct dquot___155 *);
	int (*mark_dirty)(struct dquot___155 *);
	int (*write_info)(struct super_block___155 *, int);
	qsize_t * (*get_reserved_space)(struct inode___155 *);
};

struct quotactl_ops___155 {
	int (*quota_on)(struct super_block___155 *, int, int, struct path___155 *);
	int (*quota_on_meta)(struct super_block___155 *, int, int);
	int (*quota_off)(struct super_block___155 *, int);
	int (*quota_sync)(struct super_block___155 *, int);
	int (*get_info)(struct super_block___155 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___155 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___155 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___155 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___155 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___155 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___155 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___155 *, unsigned int);
};

struct address_space_operations___155 {
	int (*writepage)(struct page___154 *, struct writeback_control *);
	int (*readpage)(struct file___155 *, struct page___154 *);
	int (*writepages)(struct address_space___155 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___154 *);
	int (*readpages)(struct file___155 *, struct address_space___155 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___155 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___154 **, void **);
	int (*write_end)(struct file___155 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___154 *, void *);
	sector_t (*bmap)(struct address_space___155 *, sector_t);
	void (*invalidatepage)(struct page___154 *, long unsigned int);
	int (*releasepage)(struct page___154 *, gfp_t);
	void (*freepage)(struct page___154 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___155 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___155 *, struct page___154 *, struct page___154 *, enum migrate_mode);
	int (*launder_page)(struct page___154 *);
	int (*is_partially_uptodate)(struct page___154 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___154 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___155 *, struct page___154 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___155 *, sector_t *);
	void (*swap_deactivate)(struct file___155 *);
	void (*invalidatepage_range)(struct page___154 *, unsigned int, unsigned int);
};

struct inode_operations___155 {
	struct dentry___155 * (*lookup)(struct inode___155 *, struct dentry___155 *, unsigned int);
	void * (*follow_link)(struct dentry___155 *, struct nameidata *);
	int (*permission)(struct inode___155 *, int);
	struct posix_acl * (*get_acl)(struct inode___155 *, int);
	int (*readlink)(struct dentry___155 *, char *, int);
	void (*put_link)(struct dentry___155 *, struct nameidata *, void *);
	int (*create)(struct inode___155 *, struct dentry___155 *, umode_t, bool);
	int (*link)(struct dentry___155 *, struct inode___155 *, struct dentry___155 *);
	int (*unlink)(struct inode___155 *, struct dentry___155 *);
	int (*symlink)(struct inode___155 *, struct dentry___155 *, const char *);
	int (*mkdir)(struct inode___155 *, struct dentry___155 *, umode_t);
	int (*rmdir)(struct inode___155 *, struct dentry___155 *);
	int (*mknod)(struct inode___155 *, struct dentry___155 *, umode_t, dev_t);
	int (*rename)(struct inode___155 *, struct dentry___155 *, struct inode___155 *, struct dentry___155 *);
	int (*setattr)(struct dentry___155 *, struct iattr___155 *);
	int (*getattr)(struct vfsmount *, struct dentry___155 *, struct kstat *);
	int (*setxattr)(struct dentry___155 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___155 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___155 *, char *, size_t);
	int (*removexattr)(struct dentry___155 *, const char *);
	int (*fiemap)(struct inode___155 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___155 *, struct timespec *, int);
	int (*atomic_open)(struct inode___155 *, struct dentry___155 *, struct file___155 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___114;

struct file_operations___155 {
	struct module *owner;
	loff_t (*llseek)(struct file___155 *, loff_t, int);
	ssize_t (*read)(struct file___155 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___155 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___155 *, void *, filldir_t);
	unsigned int (*poll)(struct file___155 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___155 *, struct vm_area_struct___162 *);
	int (*open)(struct inode___155 *, struct file___155 *);
	int (*flush)(struct file___155 *, fl_owner_t);
	int (*release)(struct inode___155 *, struct file___155 *);
	int (*fsync)(struct file___155 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___155 *, int);
	int (*lock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*sendpage)(struct file___155 *, struct page___154 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___155 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___155 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___155 *, long int, struct file_lock___155 **, void **);
		struct {
			int (*setlease)(struct file___155 *, long int, struct file_lock___155 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___155 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___114 *, struct file___155 *);
};

struct file_lock_operations___155;

struct lock_manager_operations___155;

struct file_lock___155 {
	struct file_lock___155 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___155 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___155 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___155 *fl_ops;
	const struct lock_manager_operations___155 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___155 {
	void (*fl_copy_lock)(struct file_lock___155 *, struct file_lock___155 *);
	void (*fl_release_private)(struct file_lock___155 *);
};

struct lock_manager_operations___155 {
	int (*lm_compare_owner)(struct file_lock___155 *, struct file_lock___155 *);
	long unsigned int (*lm_owner_key)(struct file_lock___155 *);
	void (*lm_notify)(struct file_lock___155 *);
	int (*lm_grant)(struct file_lock___155 *, struct file_lock___155 *, int);
	void (*lm_break)(struct file_lock___155 *);
	int (*lm_change)(struct file_lock___155 **, int);
};

struct file_system_type___155 {
	const char *name;
	int fs_flags;
	struct dentry___155 * (*mount)(struct file_system_type___155 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___155 *);
	struct module *owner;
	struct file_system_type___155 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___155 {
	struct inode___155 * (*alloc_inode)(struct super_block___155 *);
	void (*destroy_inode)(struct inode___155 *);
	void (*dirty_inode)(struct inode___155 *, int);
	int (*write_inode)(struct inode___155 *, struct writeback_control *);
	int (*drop_inode)(struct inode___155 *);
	void (*evict_inode)(struct inode___155 *);
	void (*put_super)(struct super_block___155 *);
	int (*sync_fs)(struct super_block___155 *, int);
	int (*freeze_fs)(struct super_block___155 *);
	int (*unfreeze_fs)(struct super_block___155 *);
	int (*statfs)(struct dentry___155 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___155 *, int *, char *);
	void (*umount_begin)(struct super_block___155 *);
	int (*show_options)(struct seq_file___114 *, struct dentry___155 *);
	int (*show_devname)(struct seq_file___114 *, struct dentry___155 *);
	int (*show_path)(struct seq_file___114 *, struct dentry___155 *);
	int (*show_stats)(struct seq_file___114 *, struct dentry___155 *);
	ssize_t (*quota_read)(struct super_block___155 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___155 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___155 *);
	int (*bdev_try_to_free_page)(struct super_block___155 *, struct page___154 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___155 *);
	void (*free_cached_objects)(struct super_block___155 *, int);
};

struct seq_operations___113;

struct seq_file___114 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___158 lock;
	const struct seq_operations___113 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct nf_afinfo___23 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___3 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___3 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___24 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___3 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___3 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___108 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___108 *);
	void (*irq_shutdown)(struct irq_data___108 *);
	void (*irq_enable)(struct irq_data___108 *);
	void (*irq_disable)(struct irq_data___108 *);
	void (*irq_ack)(struct irq_data___108 *);
	void (*irq_mask)(struct irq_data___108 *);
	void (*irq_mask_ack)(struct irq_data___108 *);
	void (*irq_unmask)(struct irq_data___108 *);
	void (*irq_eoi)(struct irq_data___108 *);
	int (*irq_set_affinity)(struct irq_data___108 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___108 *);
	int (*irq_set_type)(struct irq_data___108 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___108 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___108 *);
	void (*irq_bus_sync_unlock)(struct irq_data___108 *);
	void (*irq_cpu_online)(struct irq_data___108 *);
	void (*irq_cpu_offline)(struct irq_data___108 *);
	void (*irq_suspend)(struct irq_data___108 *);
	void (*irq_resume)(struct irq_data___108 *);
	void (*irq_pm_shutdown)(struct irq_data___108 *);
	void (*irq_print_chip)(struct irq_data___108 *, struct seq_file___114 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___108 *, void *);
	long unsigned int flags;
};

struct seq_operations___113 {
	void * (*start)(struct seq_file___114 *, loff_t *);
	void (*stop)(struct seq_file___114 *, void *);
	void * (*next)(struct seq_file___114 *, void *, loff_t *);
	int (*show)(struct seq_file___114 *, void *);
};

struct netlink_kernel_cfg___2 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___3 *);
	struct mutex___158 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___24 *, struct sock *);
};

enum {
	XFRM_MSG_BASE = 16,
	XFRM_MSG_NEWSA = 16,
	XFRM_MSG_DELSA = 17,
	XFRM_MSG_GETSA = 18,
	XFRM_MSG_NEWPOLICY = 19,
	XFRM_MSG_DELPOLICY = 20,
	XFRM_MSG_GETPOLICY = 21,
	XFRM_MSG_ALLOCSPI = 22,
	XFRM_MSG_ACQUIRE = 23,
	XFRM_MSG_EXPIRE = 24,
	XFRM_MSG_UPDPOLICY = 25,
	XFRM_MSG_UPDSA = 26,
	XFRM_MSG_POLEXPIRE = 27,
	XFRM_MSG_FLUSHSA = 28,
	XFRM_MSG_FLUSHPOLICY = 29,
	XFRM_MSG_NEWAE = 30,
	XFRM_MSG_GETAE = 31,
	XFRM_MSG_REPORT = 32,
	XFRM_MSG_MIGRATE = 33,
	XFRM_MSG_NEWSADINFO = 34,
	XFRM_MSG_GETSADINFO = 35,
	XFRM_MSG_NEWSPDINFO = 36,
	XFRM_MSG_GETSPDINFO = 37,
	XFRM_MSG_MAPPING = 38,
	__XFRM_MSG_MAX = 39,
};

enum {
	RTM_BASE = 16,
	RTM_NEWLINK = 16,
	RTM_DELLINK = 17,
	RTM_GETLINK = 18,
	RTM_SETLINK = 19,
	RTM_NEWADDR = 20,
	RTM_DELADDR = 21,
	RTM_GETADDR = 22,
	RTM_NEWROUTE = 24,
	RTM_DELROUTE = 25,
	RTM_GETROUTE = 26,
	RTM_NEWNEIGH = 28,
	RTM_DELNEIGH = 29,
	RTM_GETNEIGH = 30,
	RTM_NEWRULE = 32,
	RTM_DELRULE = 33,
	RTM_GETRULE = 34,
	RTM_NEWQDISC = 36,
	RTM_DELQDISC = 37,
	RTM_GETQDISC = 38,
	RTM_NEWTCLASS = 40,
	RTM_DELTCLASS = 41,
	RTM_GETTCLASS = 42,
	RTM_NEWTFILTER = 44,
	RTM_DELTFILTER = 45,
	RTM_GETTFILTER = 46,
	RTM_NEWACTION = 48,
	RTM_DELACTION = 49,
	RTM_GETACTION = 50,
	RTM_NEWPREFIX = 52,
	RTM_GETMULTICAST = 58,
	RTM_GETANYCAST = 62,
	RTM_NEWNEIGHTBL = 64,
	RTM_GETNEIGHTBL = 66,
	RTM_SETNEIGHTBL = 67,
	RTM_NEWNDUSEROPT = 68,
	RTM_NEWADDRLABEL = 72,
	RTM_DELADDRLABEL = 73,
	RTM_GETADDRLABEL = 74,
	RTM_GETDCB = 78,
	RTM_SETDCB = 79,
	RTM_NEWNETCONF = 80,
	RTM_GETNETCONF = 82,
	RTM_NEWMDB = 84,
	RTM_DELMDB = 85,
	RTM_GETMDB = 86,
	RTM_NEWNSID = 88,
	RTM_DELNSID = 89,
	RTM_GETNSID = 90,
	__RTM_MAX = 91,
};

struct nlmsg_perm {
	u16 nlmsg_type;
	u32 perm;
};

typedef long unsigned int uintptr_t;

struct page___155;

typedef struct page___155 *pgtable_t___155;

struct address_space___156;

struct kmem_cache___142;

struct page___155 {
	long unsigned int flags;
	struct address_space___156 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___155 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___155 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___142 *slab_cache;
		struct page___155 *first_page;
	};
	long: 64;
};

struct task_struct___158;

struct pv_cpu_ops___158 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___158 *);
	void (*end_context_switch)(struct task_struct___158 *);
};

struct mutex___159 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___158 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___151 {
	struct page___155 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___163;

struct nsproxy___93;

struct signal_struct___158;

struct css_set___101;

struct task_struct___158 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___158 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___163 *mm;
	struct mm_struct___163 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___158 *real_parent;
	struct task_struct___158 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___158 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___158 = 0,
		VTIME_USER___158 = 1,
		VTIME_SYS___158 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___93 *nsproxy;
	struct signal_struct___158 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___101 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___159 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___151 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___163 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___163 *, struct mm_struct___163 *);
	void (*dup_mmap)(struct mm_struct___163 *, struct mm_struct___163 *);
	void (*exit_mmap)(struct mm_struct___163 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___163 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___163 *);
	void (*pgd_free)(struct mm_struct___163 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___163 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___163 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___163 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___163 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___163 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___163 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___163 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___163 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___163 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___163 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___163 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___159 lock;
	void *vdso;
} mm_context_t___159;

struct xol_area___155;

struct uprobes_state___155 {
	struct xol_area___155 *xol_area;
};

struct vm_area_struct___163;

struct file___156;

struct linux_binfmt___25;

struct core_state___158;

struct mm_struct___163 {
	struct vm_area_struct___163 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___163 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___163 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___25 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___159 context;
	long unsigned int flags;
	struct core_state___158 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___158 *owner;
	struct file___156 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___155 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___158;

struct lruvec___158 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___158 *zone;
};

struct pglist_data___158;

struct zone___158 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___158 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___158 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___158 {
	struct zone___158 *zone;
	int zone_idx;
};

struct zonelist___158 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___158 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___158 {
	struct zone___158 node_zones[4];
	struct zonelist___158 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___158 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___109;

struct x86_io_apic_ops___109 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___109 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___109;

struct irq_data___109 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___109 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___121;

struct dev_pm_ops___121 {
	int (*prepare)(struct device___121 *);
	void (*complete)(struct device___121 *);
	int (*suspend)(struct device___121 *);
	int (*resume)(struct device___121 *);
	int (*freeze)(struct device___121 *);
	int (*thaw)(struct device___121 *);
	int (*poweroff)(struct device___121 *);
	int (*restore)(struct device___121 *);
	int (*suspend_late)(struct device___121 *);
	int (*resume_early)(struct device___121 *);
	int (*freeze_late)(struct device___121 *);
	int (*thaw_early)(struct device___121 *);
	int (*poweroff_late)(struct device___121 *);
	int (*restore_early)(struct device___121 *);
	int (*suspend_noirq)(struct device___121 *);
	int (*resume_noirq)(struct device___121 *);
	int (*freeze_noirq)(struct device___121 *);
	int (*thaw_noirq)(struct device___121 *);
	int (*poweroff_noirq)(struct device___121 *);
	int (*restore_noirq)(struct device___121 *);
	int (*runtime_suspend)(struct device___121 *);
	int (*runtime_resume)(struct device___121 *);
	int (*runtime_idle)(struct device___121 *);
};

struct dev_pm_qos___16;

struct dev_pm_info___16 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___16 *qos;
};

struct dma_map_ops___44;

struct dev_archdata___44 {
	struct dma_map_ops___44 *dma_ops;
	void *iommu;
};

struct device_type___121;

struct bus_type___121;

struct device_driver___121;

struct dev_pm_domain___121;

struct class___121;

struct attribute_group___113;

struct device_rh___121;

struct device___121 {
	struct device___121 *parent;
	struct device_private *p;
	struct kobject___13 kobj;
	const char *init_name;
	const struct device_type___121 *type;
	struct mutex___159 mutex;
	struct bus_type___121 *bus;
	struct device_driver___121 *driver;
	void *platform_data;
	struct dev_pm_info___16 power;
	struct dev_pm_domain___121 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___44 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___9 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___121 *class;
	const struct attribute_group___113 **groups;
	void (*release)(struct device___121 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___121 *device_rh;
};

struct dev_pm_qos_request___16;

struct dev_pm_qos___16 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___16 *latency_req;
	struct dev_pm_qos_request___16 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___16 *latency_tolerance_req;
};

struct dev_pm_info_rh___121 {
	void (*set_latency_tolerance)(struct device___121 *, s32);
};

struct dev_pm_domain___121 {
	struct dev_pm_ops___121 ops;
};

struct smp_ops___158 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___158 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___115;

struct attribute_group___113 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___115 **bin_attrs;
};

struct bin_attribute___115 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___156 *, struct kobject___13 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___156 *, struct kobject___13 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	int (*mmap)(struct file___156 *, struct kobject___13 *, struct bin_attribute___115 *, struct vm_area_struct___163 *);
};

struct dentry___156;

struct path___156 {
	struct vfsmount *mnt;
	struct dentry___156 *dentry;
};

struct inode___156;

struct file_operations___156;

struct file___156 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___156 f_path;
	struct inode___156 *f_inode;
	const struct file_operations___156 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___156 *f_mapping;
	struct mutex___159 f_pos_lock;
};

struct vm_operations_struct___136;

struct vm_area_struct___163 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___163 *vm_next;
	struct vm_area_struct___163 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___163 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___136 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___156 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___141 {
	void **freelist;
	long unsigned int tid;
	struct page___155 *page;
	struct page___155 *partial;
};

struct memcg_cache_params___142;

struct kmem_cache___142 {
	struct kmem_cache_cpu___141 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___13 kobj;
	struct memcg_cache_params___142 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___142 {
	bool is_root_cache;
	union {
		struct kmem_cache___142 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___142 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct file_lock___156;

struct seq_file___115;

struct file_operations___156 {
	struct module *owner;
	loff_t (*llseek)(struct file___156 *, loff_t, int);
	ssize_t (*read)(struct file___156 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___156 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___156 *, void *, filldir_t);
	unsigned int (*poll)(struct file___156 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___156 *, struct vm_area_struct___163 *);
	int (*open)(struct inode___156 *, struct file___156 *);
	int (*flush)(struct file___156 *, fl_owner_t);
	int (*release)(struct inode___156 *, struct file___156 *);
	int (*fsync)(struct file___156 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___156 *, int);
	int (*lock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*sendpage)(struct file___156 *, struct page___155 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___156 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___156 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___156 *, long int, struct file_lock___156 **, void **);
		struct {
			int (*setlease)(struct file___156 *, long int, struct file_lock___156 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___156 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___115 *, struct file___156 *);
};

struct dma_map_ops___44 {
	void * (*alloc)(struct device___121 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___121 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___121 *, struct vm_area_struct___163 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___121 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___121 *, struct page___155 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___121 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___121 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___121 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___121 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___121 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___121 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___121 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___121 *, dma_addr_t);
	int (*dma_supported)(struct device___121 *, u64);
	int (*set_dma_mask)(struct device___121 *, u64);
	int is_phys;
};

struct bus_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___121 *, char *);
	ssize_t (*store)(struct bus_type___121 *, const char *, size_t);
};

struct device_attribute___121;

struct driver_attribute___121;

struct bus_type___121 {
	const char *name;
	const char *dev_name;
	struct device___121 *dev_root;
	struct bus_attribute___121 *bus_attrs;
	struct device_attribute___121 *dev_attrs;
	struct driver_attribute___121 *drv_attrs;
	const struct attribute_group___113 **bus_groups;
	const struct attribute_group___113 **dev_groups;
	const struct attribute_group___113 **drv_groups;
	int (*match)(struct device___121 *, struct device_driver___121 *);
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	int (*probe)(struct device___121 *);
	int (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*online)(struct device___121 *);
	int (*offline)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct device___121 *, struct device_attribute___121 *, char *);
	ssize_t (*store)(struct device___121 *, struct device_attribute___121 *, const char *, size_t);
};

struct driver_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___121 *, char *);
	ssize_t (*store)(struct device_driver___121 *, const char *, size_t);
};

struct device_driver___121 {
	const char *name;
	struct bus_type___121 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___121 *);
	int (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	const struct attribute_group___113 **groups;
	const struct dev_pm_ops___121 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___121 {
	const char *name;
	const struct attribute_group___113 **groups;
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
};

struct class_attribute___121;

struct class___121 {
	const char *name;
	struct module *owner;
	struct class_attribute___121 *class_attrs;
	struct device_attribute___121 *dev_attrs;
	const struct attribute_group___113 **dev_groups;
	struct bin_attribute___115 *dev_bin_attrs;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *);
	void (*class_release)(struct class___121 *);
	void (*dev_release)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
	struct subsys_private *p;
};

struct class_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct class___121 *, struct class_attribute___121 *, char *);
	ssize_t (*store)(struct class___121 *, struct class_attribute___121 *, const char *, size_t);
	const void * (*namespace)(struct class___121 *, const struct class_attribute___121 *);
};

struct device_rh___121 {
	struct dev_pm_info_rh___121 power;
};

struct dev_pm_qos_request___16 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___121 *dev;
};

struct xol_area___155 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___155 *page;
	long unsigned int vaddr;
};

struct address_space_operations___156;

struct address_space___156 {
	struct inode___156 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___159 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___156 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___133;

struct vm_operations_struct___136 {
	void (*open)(struct vm_area_struct___163 *);
	void (*close)(struct vm_area_struct___163 *);
	int (*fault)(struct vm_area_struct___163 *, struct vm_fault___133 *);
	int (*page_mkwrite)(struct vm_area_struct___163 *, struct vm_fault___133 *);
	int (*access)(struct vm_area_struct___163 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___163 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___163 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___163 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___163 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___158 {
	struct task_struct___158 *task;
	struct core_thread___158 *next;
};

struct core_state___158 {
	atomic_t nr_threads;
	struct core_thread___158 dumper;
	struct completion startup;
};

struct linux_binprm___26;

struct coredump_params___25;

struct linux_binfmt___25 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___26 *);
	int (*load_shlib)(struct file___156 *);
	int (*core_dump)(struct coredump_params___25 *);
	long unsigned int min_coredump;
};

struct vm_fault___133 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___155 *page;
};

struct dentry_operations___156;

struct super_block___156;

struct dentry___156 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___156 *d_parent;
	struct qstr d_name;
	struct inode___156 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___156 *d_op;
	struct super_block___156 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___156;

struct dquot___156;

struct block_device___156;

struct inode___156 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___156 *i_op;
	struct super_block___156 *i_sb;
	struct address_space___156 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___159 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___156 *i_fop;
	struct file_lock___156 *i_flock;
	struct address_space___156 i_data;
	struct dquot___156 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___156 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___156 {
	int (*d_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_hash)(const struct dentry___156 *, struct qstr *);
	int (*d_compare)(const struct dentry___156 *, const struct dentry___156 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___156 *);
	void (*d_release)(struct dentry___156 *);
	void (*d_prune)(struct dentry___156 *);
	void (*d_iput)(struct dentry___156 *, struct inode___156 *);
	char * (*d_dname)(struct dentry___156 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___156 *);
	int (*d_manage)(struct dentry___156 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___156;

struct mem_dqinfo___156 {
	struct quota_format_type___156 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___156;

struct quota_info___156 {
	unsigned int flags;
	struct mutex___159 dqio_mutex;
	struct mutex___159 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___156 *files[2];
	struct mem_dqinfo___156 info[2];
	const struct quota_format_ops___156 *ops[2];
};

struct file_system_type___156;

struct super_operations___156;

struct dquot_operations___156;

struct quotactl_ops___156;

struct xattr_handler___102;

struct super_block___156 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___156 *s_type;
	const struct super_operations___156 *s_op;
	const struct dquot_operations___156 *dq_op;
	const struct quotactl_ops___156 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___156 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___102 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___156 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___156 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___159 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___156 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___156 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___156 *bd_inode;
	struct super_block___156 *bd_super;
	struct mutex___159 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___156 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___159 bd_fsfreeze_mutex;
};

struct cgroup___101;

struct cgroup_subsys_state___101 {
	struct cgroup___101 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___156 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___156 *ia_file;
};

struct dquot___156 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___159 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___156 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___156 {
	int qf_fmt_id;
	const struct quota_format_ops___156 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___156 *qf_next;
};

struct quota_format_ops___156 {
	int (*check_quota_file)(struct super_block___156 *, int);
	int (*read_file_info)(struct super_block___156 *, int);
	int (*write_file_info)(struct super_block___156 *, int);
	int (*free_file_info)(struct super_block___156 *, int);
	int (*read_dqblk)(struct dquot___156 *);
	int (*commit_dqblk)(struct dquot___156 *);
	int (*release_dqblk)(struct dquot___156 *);
};

struct dquot_operations___156 {
	int (*write_dquot)(struct dquot___156 *);
	struct dquot___156 * (*alloc_dquot)(struct super_block___156 *, int);
	void (*destroy_dquot)(struct dquot___156 *);
	int (*acquire_dquot)(struct dquot___156 *);
	int (*release_dquot)(struct dquot___156 *);
	int (*mark_dirty)(struct dquot___156 *);
	int (*write_info)(struct super_block___156 *, int);
	qsize_t * (*get_reserved_space)(struct inode___156 *);
};

struct quotactl_ops___156 {
	int (*quota_on)(struct super_block___156 *, int, int, struct path___156 *);
	int (*quota_on_meta)(struct super_block___156 *, int, int);
	int (*quota_off)(struct super_block___156 *, int);
	int (*quota_sync)(struct super_block___156 *, int);
	int (*get_info)(struct super_block___156 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___156 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___156 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___156 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___156 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___156 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___156 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___156 *, unsigned int);
};

struct address_space_operations___156 {
	int (*writepage)(struct page___155 *, struct writeback_control *);
	int (*readpage)(struct file___156 *, struct page___155 *);
	int (*writepages)(struct address_space___156 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___155 *);
	int (*readpages)(struct file___156 *, struct address_space___156 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___156 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___155 **, void **);
	int (*write_end)(struct file___156 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___155 *, void *);
	sector_t (*bmap)(struct address_space___156 *, sector_t);
	void (*invalidatepage)(struct page___155 *, long unsigned int);
	int (*releasepage)(struct page___155 *, gfp_t);
	void (*freepage)(struct page___155 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___156 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___156 *, struct page___155 *, struct page___155 *, enum migrate_mode);
	int (*launder_page)(struct page___155 *);
	int (*is_partially_uptodate)(struct page___155 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___155 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___156 *, struct page___155 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___156 *, sector_t *);
	void (*swap_deactivate)(struct file___156 *);
	void (*invalidatepage_range)(struct page___155 *, unsigned int, unsigned int);
};

struct inode_operations___156 {
	struct dentry___156 * (*lookup)(struct inode___156 *, struct dentry___156 *, unsigned int);
	void * (*follow_link)(struct dentry___156 *, struct nameidata *);
	int (*permission)(struct inode___156 *, int);
	struct posix_acl * (*get_acl)(struct inode___156 *, int);
	int (*readlink)(struct dentry___156 *, char *, int);
	void (*put_link)(struct dentry___156 *, struct nameidata *, void *);
	int (*create)(struct inode___156 *, struct dentry___156 *, umode_t, bool);
	int (*link)(struct dentry___156 *, struct inode___156 *, struct dentry___156 *);
	int (*unlink)(struct inode___156 *, struct dentry___156 *);
	int (*symlink)(struct inode___156 *, struct dentry___156 *, const char *);
	int (*mkdir)(struct inode___156 *, struct dentry___156 *, umode_t);
	int (*rmdir)(struct inode___156 *, struct dentry___156 *);
	int (*mknod)(struct inode___156 *, struct dentry___156 *, umode_t, dev_t);
	int (*rename)(struct inode___156 *, struct dentry___156 *, struct inode___156 *, struct dentry___156 *);
	int (*setattr)(struct dentry___156 *, struct iattr___156 *);
	int (*getattr)(struct vfsmount *, struct dentry___156 *, struct kstat *);
	int (*setxattr)(struct dentry___156 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___156 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___156 *, char *, size_t);
	int (*removexattr)(struct dentry___156 *, const char *);
	int (*fiemap)(struct inode___156 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___156 *, struct timespec *, int);
	int (*atomic_open)(struct inode___156 *, struct dentry___156 *, struct file___156 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___156;

struct file_lock_operations___156;

struct lock_manager_operations___156;

struct file_lock___156 {
	struct file_lock___156 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___156 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___156 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___156 *fl_ops;
	const struct lock_manager_operations___156 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___156 {
	void (*fl_copy_lock)(struct file_lock___156 *, struct file_lock___156 *);
	void (*fl_release_private)(struct file_lock___156 *);
};

struct lock_manager_operations___156 {
	int (*lm_compare_owner)(struct file_lock___156 *, struct file_lock___156 *);
	long unsigned int (*lm_owner_key)(struct file_lock___156 *);
	void (*lm_notify)(struct file_lock___156 *);
	int (*lm_grant)(struct file_lock___156 *, struct file_lock___156 *, int);
	void (*lm_break)(struct file_lock___156 *);
	int (*lm_change)(struct file_lock___156 **, int);
};

struct fasync_struct___156 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___156 *fa_next;
	struct file___156 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___156 {
	const char *name;
	int fs_flags;
	struct dentry___156 * (*mount)(struct file_system_type___156 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___156 *);
	struct module *owner;
	struct file_system_type___156 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___156 {
	struct inode___156 * (*alloc_inode)(struct super_block___156 *);
	void (*destroy_inode)(struct inode___156 *);
	void (*dirty_inode)(struct inode___156 *, int);
	int (*write_inode)(struct inode___156 *, struct writeback_control *);
	int (*drop_inode)(struct inode___156 *);
	void (*evict_inode)(struct inode___156 *);
	void (*put_super)(struct super_block___156 *);
	int (*sync_fs)(struct super_block___156 *, int);
	int (*freeze_fs)(struct super_block___156 *);
	int (*unfreeze_fs)(struct super_block___156 *);
	int (*statfs)(struct dentry___156 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___156 *, int *, char *);
	void (*umount_begin)(struct super_block___156 *);
	int (*show_options)(struct seq_file___115 *, struct dentry___156 *);
	int (*show_devname)(struct seq_file___115 *, struct dentry___156 *);
	int (*show_path)(struct seq_file___115 *, struct dentry___156 *);
	int (*show_stats)(struct seq_file___115 *, struct dentry___156 *);
	ssize_t (*quota_read)(struct super_block___156 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___156 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___156 *);
	int (*bdev_try_to_free_page)(struct super_block___156 *, struct page___155 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___156 *);
	void (*free_cached_objects)(struct super_block___156 *, int);
};

struct xattr_handler___102 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___156 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___156 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___156 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___114;

struct seq_file___115 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___159 lock;
	const struct seq_operations___114 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_table_header___26;

struct ctl_node___26 {
	struct rb_node node;
	struct ctl_table_header___26 *header;
};

struct ctl_table_root___26;

struct ctl_table_set___26;

struct ctl_dir___26;

struct ctl_table_header___26 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___26 *root;
	struct ctl_table_set___26 *set;
	struct ctl_dir___26 *parent;
	struct ctl_node___26 *node;
};

struct ctl_dir___26 {
	struct ctl_table_header___26 header;
	struct rb_root root;
};

struct ctl_table_set___26 {
	int (*is_seen)(struct ctl_table_set___26 *);
	struct ctl_dir___26 dir;
};

struct ctl_table_root___26 {
	struct ctl_table_set___26 default_set;
	struct ctl_table_set___26 * (*lookup)(struct ctl_table_root___26 *, struct nsproxy___93 *);
	int (*permissions)(struct ctl_table_header___26 *, struct ctl_table *);
};

struct net___25;

struct nsproxy___93 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___25 *net_ns;
};

struct signal_struct___158 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___158 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___158 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___159 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___101 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___101 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___23 {
	struct ctl_table_header___26 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___23 {
	struct mutex___159 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___23 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___26 *ctl;
};

struct netns_ipv4___23 {
	struct ctl_table_header___26 *forw_hdr;
	struct ctl_table_header___26 *frags_hdr;
	struct ctl_table_header___26 *ipv4_hdr;
	struct ctl_table_header___26 *route_hdr;
	struct ctl_table_header___26 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___23 {
	struct ctl_table_header___26 *hdr;
	struct ctl_table_header___26 *route_hdr;
	struct ctl_table_header___26 *icmp_hdr;
	struct ctl_table_header___26 *frags_hdr;
	struct ctl_table_header___26 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___14;

struct sk_buff___16;

struct dst_ops___24 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___24 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___14 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___16 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___16 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___16 *);
	int (*local_out)(struct sk_buff___16 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___16 *, const void *);
	struct kmem_cache___142 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___24 {
	struct netns_sysctl_ipv6___23 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___24 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___23 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___26 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___23 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___26 *nf_log_dir_header;
};

struct nf_proto_net___23 {
	struct ctl_table_header___26 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___23 {
	struct nf_proto_net___23 pn;
	unsigned int timeout;
};

struct nf_tcp_net___23 {
	struct nf_proto_net___23 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___23 {
	struct nf_proto_net___23 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___23 {
	struct nf_proto_net___23 pn;
	unsigned int timeout;
};

struct nf_ip_net___23 {
	struct nf_generic_net___23 generic;
	struct nf_tcp_net___23 tcp;
	struct nf_udp_net___23 udp;
	struct nf_icmp_net___23 icmp;
	struct nf_icmp_net___23 icmpv6;
};

struct netns_ct___23 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___26 *sysctl_header;
	struct ctl_table_header___26 *acct_sysctl_header;
	struct ctl_table_header___26 *tstamp_sysctl_header;
	struct ctl_table_header___26 *event_sysctl_header;
	struct ctl_table_header___26 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___142 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___23 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___23 {
	struct netns_sysctl_ipv6___23 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___13 {
	struct sk_buff___16 *next;
	struct sk_buff___16 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___24 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___26 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___24 xfrm4_dst_ops;
	struct dst_ops___24 xfrm6_dst_ops;
};

struct net___25 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___26 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___14 *loopback_dev;
	struct netns_core___23 core;
	struct netns_mib___2 mib;
	struct netns_packet___23 packet;
	struct netns_unix___23 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___23 ipv4;
	struct netns_ipv6___24 ipv6;
	struct netns_sctp___23 sctp;
	struct netns_dccp___10 dccp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct___23 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___23 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___13 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___24 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___159 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___159 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___12 {
	atomic_t use;
	unsigned int mask;
	struct net_device___14 *physindev;
	struct net_device___14 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___12(struct sk_buff___16 **);

struct net_device_ops___12;

struct ethtool_ops___12;

struct header_ops___12;

struct netdev_rx_queue___12;

struct netdev_queue___12;

struct dcbnl_rtnl_ops___12;

struct net_device___14 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___12 *netdev_ops;
	const struct ethtool_ops___12 *ethtool_ops;
	const struct header_ops___12 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___13 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___12 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___12 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___12 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___12 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___12 = 0,
		NETREG_REGISTERED___12 = 1,
		NETREG_UNREGISTERING___12 = 2,
		NETREG_UNREGISTERED___12 = 3,
		NETREG_RELEASED___12 = 4,
		NETREG_DUMMY___12 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___12 = 0,
		RTNL_LINK_INITIALIZING___12 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___14 *);
	struct netpoll_info *npinfo;
	struct net___25 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___121 dev;
	const struct attribute_group___113 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___12 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___16 {
	struct sk_buff___16 *next;
	struct sk_buff___16 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___14 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___16 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___12 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___12 {
	int (*get_settings)(struct net_device___14 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___14 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___14 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___14 *);
	void (*get_regs)(struct net_device___14 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___14 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___14 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___14 *);
	void (*set_msglevel)(struct net_device___14 *, u32);
	int (*nway_reset)(struct net_device___14 *);
	u32 (*get_link)(struct net_device___14 *);
	int (*get_eeprom_len)(struct net_device___14 *);
	int (*get_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___14 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___14 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___14 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___14 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___14 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___14 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___14 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___14 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___14 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___14 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___14 *);
	void (*complete)(struct net_device___14 *);
	u32 (*get_priv_flags)(struct net_device___14 *);
	int (*set_priv_flags)(struct net_device___14 *, u32);
	int (*get_sset_count)(struct net_device___14 *, int);
	int (*get_rxnfc)(struct net_device___14 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___14 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___14 *, struct ethtool_flash *);
	int (*reset)(struct net_device___14 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___14 *);
	int (*get_rxfh_indir)(struct net_device___14 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___14 *, const u32 *);
	void (*get_channels)(struct net_device___14 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___14 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___14 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___14 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___14 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___14 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___14 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___14 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___14 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___14 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___14 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___14 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___24 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___16 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___16 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___25 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___16 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___16 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___109 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___109 *);
	void (*irq_shutdown)(struct irq_data___109 *);
	void (*irq_enable)(struct irq_data___109 *);
	void (*irq_disable)(struct irq_data___109 *);
	void (*irq_ack)(struct irq_data___109 *);
	void (*irq_mask)(struct irq_data___109 *);
	void (*irq_mask_ack)(struct irq_data___109 *);
	void (*irq_unmask)(struct irq_data___109 *);
	void (*irq_eoi)(struct irq_data___109 *);
	int (*irq_set_affinity)(struct irq_data___109 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___109 *);
	int (*irq_set_type)(struct irq_data___109 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___109 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___109 *);
	void (*irq_bus_sync_unlock)(struct irq_data___109 *);
	void (*irq_cpu_online)(struct irq_data___109 *);
	void (*irq_cpu_offline)(struct irq_data___109 *);
	void (*irq_suspend)(struct irq_data___109 *);
	void (*irq_resume)(struct irq_data___109 *);
	void (*irq_pm_shutdown)(struct irq_data___109 *);
	void (*irq_print_chip)(struct irq_data___109 *, struct seq_file___115 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___109 *, void *);
	long unsigned int flags;
};

struct seq_operations___114 {
	void * (*start)(struct seq_file___115 *, loff_t *);
	void (*stop)(struct seq_file___115 *, void *);
	void * (*next)(struct seq_file___115 *, void *, loff_t *);
	int (*show)(struct seq_file___115 *, void *);
};

struct dcbnl_rtnl_ops___12 {
	int (*ieee_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___14 *);
	u8 (*setstate)(struct net_device___14 *, u8);
	void (*getpermhwaddr)(struct net_device___14 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___14 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___14 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___14 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___14 *, int, u8 *);
	void (*setpfccfg)(struct net_device___14 *, int, u8);
	void (*getpfccfg)(struct net_device___14 *, int, u8 *);
	u8 (*setall)(struct net_device___14 *);
	u8 (*getcap)(struct net_device___14 *, int, u8 *);
	int (*getnumtcs)(struct net_device___14 *, int, u8 *);
	int (*setnumtcs)(struct net_device___14 *, int, u8);
	u8 (*getpfcstate)(struct net_device___14 *);
	void (*setpfcstate)(struct net_device___14 *, u8);
	void (*getbcncfg)(struct net_device___14 *, int, u32 *);
	void (*setbcncfg)(struct net_device___14 *, int, u32);
	void (*getbcnrp)(struct net_device___14 *, int, u8 *);
	void (*setbcnrp)(struct net_device___14 *, int, u8);
	u8 (*setapp)(struct net_device___14 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___14 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___14 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___14 *, int, u8);
	u8 (*getdcbx)(struct net_device___14 *);
	u8 (*setdcbx)(struct net_device___14 *, u8);
	int (*peer_getappinfo)(struct net_device___14 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___14 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___14 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___14 *, struct cee_pfc *);
};

struct cgroupfs_root___101;

struct cgroup___101 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___101 *parent;
	struct dentry___156 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___101 *subsys[11];
	struct cgroupfs_root___101 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___159 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___101 {
	struct super_block___156 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___101 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct linux_binprm___26 {
	char buf[128];
	struct vm_area_struct___163 *vma;
	long unsigned int vma_pages;
	struct mm_struct___163 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___156 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct netlink_callback___13 {
	struct sk_buff___16 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___16 *, struct netlink_callback___13 *);
	int (*done)(struct netlink_callback___13 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___12 {
	int (*create)(struct sk_buff___16 *, struct net_device___14 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___16 *, unsigned char *);
	int (*rebuild)(struct sk_buff___16 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___14 *, const unsigned char *);
};

struct napi_struct___12 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___12 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___14 *dev;
	struct sk_buff___16 *gro_list;
	struct sk_buff___16 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___12 {
	struct net_device___14 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___13 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___12 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___13 kobj;
	struct net_device___14 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___12 {
	int (*ndo_init)(struct net_device___14 *);
	void (*ndo_uninit)(struct net_device___14 *);
	int (*ndo_open)(struct net_device___14 *);
	int (*ndo_stop)(struct net_device___14 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___16 *, struct net_device___14 *);
	u16 (*ndo_select_queue)(struct net_device___14 *, struct sk_buff___16 *);
	void (*ndo_change_rx_flags)(struct net_device___14 *, int);
	void (*ndo_set_rx_mode)(struct net_device___14 *);
	int (*ndo_set_mac_address)(struct net_device___14 *, void *);
	int (*ndo_validate_addr)(struct net_device___14 *);
	int (*ndo_do_ioctl)(struct net_device___14 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___14 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___14 *, int);
	int (*ndo_neigh_setup)(struct net_device___14 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___14 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___14 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___14 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___14 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___14 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___14 *);
	int (*ndo_netpoll_setup)(struct net_device___14 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___14 *);
	int (*ndo_busy_poll)(struct napi_struct___12 *);
	int (*ndo_set_vf_mac)(struct net_device___14 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___14 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___14 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___14 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___14 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___14 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___14 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___14 *, int, struct sk_buff___16 *);
	int (*ndo_setup_tc)(struct net_device___14 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___14 *);
	int (*ndo_fcoe_disable)(struct net_device___14 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___14 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___14 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___14 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___14 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___14 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___14 *, const struct sk_buff___16 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___14 *, struct net_device___14 *);
	int (*ndo_del_slave)(struct net_device___14 *, struct net_device___14 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___16 *, struct netlink_callback___13 *, struct net_device___14 *, int);
	int (*ndo_bridge_setlink)(struct net_device___14 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___16 *, u32, u32, struct net_device___14 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___14 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___14 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___14 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___14 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___14 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___14 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___16 *, struct net_device___14 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___14 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___14 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___14 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct coredump_params___25 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___156 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct netif_security_struct {
	struct net___25 *ns;
	int ifindex;
	u32 sid;
};

struct sel_netif {
	struct list_head list;
	struct netif_security_struct nsec;
	struct callback_head callback_head;
};

struct page___156;

typedef struct page___156 *pgtable_t___156;

struct address_space___157;

struct kmem_cache___143;

struct page___156 {
	long unsigned int flags;
	struct address_space___157 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___156 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___156 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___143 *slab_cache;
		struct page___156 *first_page;
	};
	long: 64;
};

struct task_struct___159;

struct pv_cpu_ops___159 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___159 *);
	void (*end_context_switch)(struct task_struct___159 *);
};

struct mutex___160 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___159 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___152 {
	struct page___156 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___164;

struct nsproxy___94;

struct signal_struct___159;

struct css_set___102;

struct task_struct___159 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___159 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___164 *mm;
	struct mm_struct___164 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___159 *real_parent;
	struct task_struct___159 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___159 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___159 = 0,
		VTIME_USER___159 = 1,
		VTIME_SYS___159 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___94 *nsproxy;
	struct signal_struct___159 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___102 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___160 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___152 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___164 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___164 *, struct mm_struct___164 *);
	void (*dup_mmap)(struct mm_struct___164 *, struct mm_struct___164 *);
	void (*exit_mmap)(struct mm_struct___164 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___164 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___164 *);
	void (*pgd_free)(struct mm_struct___164 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___164 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___164 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___164 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___164 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___164 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___164 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___164 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___164 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___164 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___164 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___164 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___160 lock;
	void *vdso;
} mm_context_t___160;

struct xol_area___156;

struct uprobes_state___156 {
	struct xol_area___156 *xol_area;
};

struct vm_area_struct___164;

struct file___157;

struct linux_binfmt___26;

struct core_state___159;

struct mm_struct___164 {
	struct vm_area_struct___164 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___164 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___164 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___26 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___160 context;
	long unsigned int flags;
	struct core_state___159 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___159 *owner;
	struct file___157 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___156 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___159;

struct lruvec___159 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___159 *zone;
};

struct pglist_data___159;

struct zone___159 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___159 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___159 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___159 {
	struct zone___159 *zone;
	int zone_idx;
};

struct zonelist___159 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___159 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___159 {
	struct zone___159 node_zones[4];
	struct zonelist___159 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___159 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___110;

struct x86_io_apic_ops___110 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___110 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___110;

struct irq_data___110 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___110 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___122;

struct dev_pm_ops___122 {
	int (*prepare)(struct device___122 *);
	void (*complete)(struct device___122 *);
	int (*suspend)(struct device___122 *);
	int (*resume)(struct device___122 *);
	int (*freeze)(struct device___122 *);
	int (*thaw)(struct device___122 *);
	int (*poweroff)(struct device___122 *);
	int (*restore)(struct device___122 *);
	int (*suspend_late)(struct device___122 *);
	int (*resume_early)(struct device___122 *);
	int (*freeze_late)(struct device___122 *);
	int (*thaw_early)(struct device___122 *);
	int (*poweroff_late)(struct device___122 *);
	int (*restore_early)(struct device___122 *);
	int (*suspend_noirq)(struct device___122 *);
	int (*resume_noirq)(struct device___122 *);
	int (*freeze_noirq)(struct device___122 *);
	int (*thaw_noirq)(struct device___122 *);
	int (*poweroff_noirq)(struct device___122 *);
	int (*restore_noirq)(struct device___122 *);
	int (*runtime_suspend)(struct device___122 *);
	int (*runtime_resume)(struct device___122 *);
	int (*runtime_idle)(struct device___122 *);
};

struct kset___14;

struct kobj_type___14;

struct kobject___14 {
	const char *name;
	struct list_head entry;
	struct kobject___14 *parent;
	struct kset___14 *kset;
	struct kobj_type___14 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___17;

struct dev_pm_info___17 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___17 *qos;
};

struct dma_map_ops___45;

struct dev_archdata___45 {
	struct dma_map_ops___45 *dma_ops;
	void *iommu;
};

struct device_type___122;

struct bus_type___122;

struct device_driver___122;

struct dev_pm_domain___122;

struct class___122;

struct attribute_group___114;

struct device_rh___122;

struct device___122 {
	struct device___122 *parent;
	struct device_private *p;
	struct kobject___14 kobj;
	const char *init_name;
	const struct device_type___122 *type;
	struct mutex___160 mutex;
	struct bus_type___122 *bus;
	struct device_driver___122 *driver;
	void *platform_data;
	struct dev_pm_info___17 power;
	struct dev_pm_domain___122 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___45 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___122 *class;
	const struct attribute_group___114 **groups;
	void (*release)(struct device___122 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___122 *device_rh;
};

struct dev_pm_qos_request___17;

struct dev_pm_qos___17 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___17 *latency_req;
	struct dev_pm_qos_request___17 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___17 *latency_tolerance_req;
};

struct dev_pm_info_rh___122 {
	void (*set_latency_tolerance)(struct device___122 *, s32);
};

struct dev_pm_domain___122 {
	struct dev_pm_ops___122 ops;
};

struct smp_ops___159 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___159 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___12;

struct kobj_ns_type_operations___11 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___12 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___11;

struct net___26;

struct sock_common___11 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___11 *skc_prot;
	struct net___26 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___17;

struct sk_buff_head___14 {
	struct sk_buff___17 *next;
	struct sk_buff___17 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___12;

struct socket_wq___11;

struct dst_entry___11;

struct socket___12;

struct cg_proto___11;

struct sock___12 {
	struct sock_common___11 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___14 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___17 *head;
		struct sk_buff___17 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___12 *sk_filter;
	struct socket_wq___11 *sk_wq;
	struct sk_buff_head___14 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___11 *sk_rx_dst;
	struct dst_entry___11 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___14 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___14 sk_error_queue;
	struct proto___11 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___12 *sk_socket;
	void *sk_user_data;
	struct page_frag___152 sk_frag;
	struct sk_buff___17 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___11 *sk_cgrp;
	void (*sk_state_change)(struct sock___12 *);
	void (*sk_data_ready)(struct sock___12 *, int);
	void (*sk_write_space)(struct sock___12 *);
	void (*sk_error_report)(struct sock___12 *);
	int (*sk_backlog_rcv)(struct sock___12 *, struct sk_buff___17 *);
	void (*sk_destruct)(struct sock___12 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___116;

struct attribute_group___114 {
	const char *name;
	umode_t (*is_visible)(struct kobject___14 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___116 **bin_attrs;
};

struct bin_attribute___116 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___157 *, struct kobject___14 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___157 *, struct kobject___14 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	int (*mmap)(struct file___157 *, struct kobject___14 *, struct bin_attribute___116 *, struct vm_area_struct___164 *);
};

struct dentry___157;

struct path___157 {
	struct vfsmount *mnt;
	struct dentry___157 *dentry;
};

struct inode___157;

struct file_operations___157;

struct file___157 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___157 f_path;
	struct inode___157 *f_inode;
	const struct file_operations___157 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___157 *f_mapping;
	struct mutex___160 f_pos_lock;
};

struct vm_operations_struct___137;

struct vm_area_struct___164 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___164 *vm_next;
	struct vm_area_struct___164 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___164 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___137 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___157 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___14 {
	ssize_t (*show)(struct kobject___14 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___14 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___14 *, const struct attribute *);
};

struct kset_uevent_ops___14;

struct kset___14 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___14 kobj;
	const struct kset_uevent_ops___14 *uevent_ops;
};

struct kobj_type___14 {
	void (*release)(struct kobject___14 *);
	const struct sysfs_ops___14 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___14 *);
	const void * (*namespace)(struct kobject___14 *);
};

struct kset_uevent_ops___14 {
	int (* const filter)(struct kset___14 *, struct kobject___14 *);
	const char * (* const name)(struct kset___14 *, struct kobject___14 *);
	int (* const uevent)(struct kset___14 *, struct kobject___14 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___142 {
	void **freelist;
	long unsigned int tid;
	struct page___156 *page;
	struct page___156 *partial;
};

struct memcg_cache_params___143;

struct kmem_cache___143 {
	struct kmem_cache_cpu___142 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___14 kobj;
	struct memcg_cache_params___143 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___143 {
	bool is_root_cache;
	union {
		struct kmem_cache___143 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___143 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___156 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___156 *page;
	long unsigned int vaddr;
};

struct address_space_operations___157;

struct address_space___157 {
	struct inode___157 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___160 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___157 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___134;

struct vm_operations_struct___137 {
	void (*open)(struct vm_area_struct___164 *);
	void (*close)(struct vm_area_struct___164 *);
	int (*fault)(struct vm_area_struct___164 *, struct vm_fault___134 *);
	int (*page_mkwrite)(struct vm_area_struct___164 *, struct vm_fault___134 *);
	int (*access)(struct vm_area_struct___164 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___164 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___164 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___164 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___164 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___159 {
	struct task_struct___159 *task;
	struct core_thread___159 *next;
};

struct core_state___159 {
	atomic_t nr_threads;
	struct core_thread___159 dumper;
	struct completion startup;
};

struct linux_binprm___27;

struct coredump_params___26;

struct linux_binfmt___26 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___27 *);
	int (*load_shlib)(struct file___157 *);
	int (*core_dump)(struct coredump_params___26 *);
	long unsigned int min_coredump;
};

struct fasync_struct___157;

struct socket_wq___11 {
	wait_queue_head_t wait;
	struct fasync_struct___157 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___157 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___157 *fa_next;
	struct file___157 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___11;

struct socket___12 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___11 *wq;
	struct file___157 *file;
	struct sock___12 *sk;
	const struct proto_ops___11 *ops;
};

struct poll_table_struct___94;

struct kiocb___18;

struct proto_ops___11 {
	int family;
	struct module *owner;
	int (*release)(struct socket___12 *);
	int (*bind)(struct socket___12 *, struct sockaddr *, int);
	int (*connect)(struct socket___12 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___12 *, struct socket___12 *);
	int (*accept)(struct socket___12 *, struct socket___12 *, int);
	int (*getname)(struct socket___12 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___157 *, struct socket___12 *, struct poll_table_struct___94 *);
	int (*ioctl)(struct socket___12 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___12 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___12 *, int);
	int (*shutdown)(struct socket___12 *, int);
	int (*setsockopt)(struct socket___12 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___12 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___12 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___12 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___18 *, struct socket___12 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___18 *, struct socket___12 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___157 *, struct socket___12 *, struct vm_area_struct___164 *);
	ssize_t (*sendpage)(struct socket___12 *, struct page___156 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___12 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___12 *, int);
		struct {
			void (*set_peek_off)(struct sock___12 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___96)(struct file___157 *, wait_queue_head_t *, struct poll_table_struct___94 *);

struct poll_table_struct___94 {
	poll_queue_proc___96 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___18(struct kiocb___18 *, struct io_event *);

struct kiocb___18 {
	atomic_t ki_users;
	struct file___157 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___18 *ki_cancel;
	void (*ki_dtor)(struct kiocb___18 *);
	union {
		void *user;
		struct task_struct___159 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___27;

struct ctl_table_set___27;

struct ctl_dir___27;

struct ctl_node___27;

struct ctl_table_header___27 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___27 *root;
	struct ctl_table_set___27 *set;
	struct ctl_dir___27 *parent;
	struct ctl_node___27 *node;
};

struct ctl_dir___27 {
	struct ctl_table_header___27 header;
	struct rb_root root;
};

struct ctl_table_set___27 {
	int (*is_seen)(struct ctl_table_set___27 *);
	struct ctl_dir___27 dir;
};

struct netns_core___24 {
	struct ctl_table_header___27 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___24 {
	struct mutex___160 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___24 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___27 *ctl;
};

struct netns_ipv4___24 {
	struct ctl_table_header___27 *forw_hdr;
	struct ctl_table_header___27 *frags_hdr;
	struct ctl_table_header___27 *ipv4_hdr;
	struct ctl_table_header___27 *route_hdr;
	struct ctl_table_header___27 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___12 *fibnl;
	struct sock___12 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___24 {
	struct ctl_table_header___27 *hdr;
	struct ctl_table_header___27 *route_hdr;
	struct ctl_table_header___27 *icmp_hdr;
	struct ctl_table_header___27 *frags_hdr;
	struct ctl_table_header___27 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___15;

struct neighbour___11;

struct dst_ops___25 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___25 *);
	struct dst_entry___11 * (*check)(struct dst_entry___11 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___11 *);
	unsigned int (*mtu)(const struct dst_entry___11 *);
	u32 * (*cow_metrics)(struct dst_entry___11 *, long unsigned int);
	void (*destroy)(struct dst_entry___11 *);
	void (*ifdown)(struct dst_entry___11 *, struct net_device___15 *, int);
	struct dst_entry___11 * (*negative_advice)(struct dst_entry___11 *);
	void (*link_failure)(struct sk_buff___17 *);
	void (*update_pmtu)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___17 *, u32);
	void (*redirect)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___17 *);
	int (*local_out)(struct sk_buff___17 *);
	struct neighbour___11 * (*neigh_lookup)(const struct dst_entry___11 *, struct sk_buff___17 *, const void *);
	struct kmem_cache___143 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___25 {
	struct netns_sysctl_ipv6___24 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___25 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___12 **icmp_sk;
	struct sock___12 *ndisc_sk;
	struct sock___12 *tcp_sk;
	struct sock___12 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___24 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___27 *sysctl_header;
	struct sock___12 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___11 {
	struct sock___12 *v4_ctl_sk;
	struct sock___12 *v6_ctl_sk;
};

struct netns_nf___24 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___27 *nf_log_dir_header;
};

struct nf_proto_net___24 {
	struct ctl_table_header___27 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___24 {
	struct nf_proto_net___24 pn;
	unsigned int timeout;
};

struct nf_tcp_net___24 {
	struct nf_proto_net___24 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___24 {
	struct nf_proto_net___24 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___24 {
	struct nf_proto_net___24 pn;
	unsigned int timeout;
};

struct nf_ip_net___24 {
	struct nf_generic_net___24 generic;
	struct nf_tcp_net___24 tcp;
	struct nf_udp_net___24 udp;
	struct nf_icmp_net___24 icmp;
	struct nf_icmp_net___24 icmpv6;
};

struct netns_ct___24 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___27 *sysctl_header;
	struct ctl_table_header___27 *acct_sysctl_header;
	struct ctl_table_header___27 *tstamp_sysctl_header;
	struct ctl_table_header___27 *event_sysctl_header;
	struct ctl_table_header___27 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___143 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___24 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___24 {
	struct netns_sysctl_ipv6___24 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___25 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___12 *nlsk;
	struct sock___12 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___27 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___25 xfrm4_dst_ops;
	struct dst_ops___25 xfrm6_dst_ops;
};

struct net___26 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___27 sysctls;
	struct sock___12 *rtnl;
	struct sock___12 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___15 *loopback_dev;
	struct netns_core___24 core;
	struct netns_mib___2 mib;
	struct netns_packet___24 packet;
	struct netns_unix___24 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___24 ipv4;
	struct netns_ipv6___25 ipv6;
	struct netns_sctp___24 sctp;
	struct netns_dccp___11 dccp;
	struct netns_nf___24 nf;
	struct netns_xt xt;
	struct netns_ct___24 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___24 nf_frag;
	struct sock___12 *nfnl;
	struct sock___12 *nfnl_stash;
	struct sk_buff_head___14 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___25 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___12 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___12 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___160 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___160 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___45 {
	void * (*alloc)(struct device___122 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___122 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___122 *, struct vm_area_struct___164 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___122 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___122 *, struct page___156 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___122 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___122 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___122 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___122 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___122 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___122 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___122 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___122 *, dma_addr_t);
	int (*dma_supported)(struct device___122 *, u64);
	int (*set_dma_mask)(struct device___122 *, u64);
	int is_phys;
};

struct bus_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___122 *, char *);
	ssize_t (*store)(struct bus_type___122 *, const char *, size_t);
};

struct device_attribute___122;

struct driver_attribute___122;

struct bus_type___122 {
	const char *name;
	const char *dev_name;
	struct device___122 *dev_root;
	struct bus_attribute___122 *bus_attrs;
	struct device_attribute___122 *dev_attrs;
	struct driver_attribute___122 *drv_attrs;
	const struct attribute_group___114 **bus_groups;
	const struct attribute_group___114 **dev_groups;
	const struct attribute_group___114 **drv_groups;
	int (*match)(struct device___122 *, struct device_driver___122 *);
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	int (*probe)(struct device___122 *);
	int (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*online)(struct device___122 *);
	int (*offline)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct device___122 *, struct device_attribute___122 *, char *);
	ssize_t (*store)(struct device___122 *, struct device_attribute___122 *, const char *, size_t);
};

struct driver_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___122 *, char *);
	ssize_t (*store)(struct device_driver___122 *, const char *, size_t);
};

struct device_driver___122 {
	const char *name;
	struct bus_type___122 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___122 *);
	int (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	const struct attribute_group___114 **groups;
	const struct dev_pm_ops___122 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___122 {
	const char *name;
	const struct attribute_group___114 **groups;
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
};

struct class_attribute___122;

struct class___122 {
	const char *name;
	struct module *owner;
	struct class_attribute___122 *class_attrs;
	struct device_attribute___122 *dev_attrs;
	const struct attribute_group___114 **dev_groups;
	struct bin_attribute___116 *dev_bin_attrs;
	struct kobject___14 *dev_kobj;
	int (*dev_uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *);
	void (*class_release)(struct class___122 *);
	void (*dev_release)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
	struct subsys_private *p;
};

struct class_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct class___122 *, struct class_attribute___122 *, char *);
	ssize_t (*store)(struct class___122 *, struct class_attribute___122 *, const char *, size_t);
	const void * (*namespace)(struct class___122 *, const struct class_attribute___122 *);
};

struct device_rh___122 {
	struct dev_pm_info_rh___122 power;
};

struct vm_fault___134 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___156 *page;
};

struct ctl_node___27 {
	struct rb_node node;
	struct ctl_table_header___27 *header;
};

struct ctl_table_root___27 {
	struct ctl_table_set___27 default_set;
	struct ctl_table_set___27 * (*lookup)(struct ctl_table_root___27 *, struct nsproxy___94 *);
	int (*permissions)(struct ctl_table_header___27 *, struct ctl_table *);
};

struct nsproxy___94 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___26 *net_ns;
};

struct signal_struct___159 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___159 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___159 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___160 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___102;

struct css_set___102 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___102 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___13 {
	atomic_t use;
	unsigned int mask;
	struct net_device___15 *physindev;
	struct net_device___15 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___13(struct sk_buff___17 **);

struct net_device_ops___13;

struct ethtool_ops___13;

struct header_ops___13;

struct inet6_dev___8;

struct netdev_rx_queue___13;

struct netdev_queue___13;

struct rtnl_link_ops___11;

struct dcbnl_rtnl_ops___13;

struct net_device___15 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___13 *netdev_ops;
	const struct ethtool_ops___13 *ethtool_ops;
	const struct header_ops___13 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___14 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___8 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___13 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___13 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___13 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___13 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___13 = 0,
		NETREG_REGISTERED___13 = 1,
		NETREG_UNREGISTERING___13 = 2,
		NETREG_UNREGISTERED___13 = 3,
		NETREG_RELEASED___13 = 4,
		NETREG_DUMMY___13 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___13 = 0,
		RTNL_LINK_INITIALIZING___13 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___15 *);
	struct netpoll_info *npinfo;
	struct net___26 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___122 dev;
	const struct attribute_group___114 *sysfs_groups[4];
	const struct rtnl_link_ops___11 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___13 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___17 {
	struct sk_buff___17 *next;
	struct sk_buff___17 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___12 *sk;
	struct net_device___15 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___17 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___13 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct file_lock___157;

struct seq_file___116;

struct file_operations___157 {
	struct module *owner;
	loff_t (*llseek)(struct file___157 *, loff_t, int);
	ssize_t (*read)(struct file___157 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___157 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___18 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___18 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___157 *, void *, filldir_t);
	unsigned int (*poll)(struct file___157 *, struct poll_table_struct___94 *);
	long int (*unlocked_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___157 *, struct vm_area_struct___164 *);
	int (*open)(struct inode___157 *, struct file___157 *);
	int (*flush)(struct file___157 *, fl_owner_t);
	int (*release)(struct inode___157 *, struct file___157 *);
	int (*fsync)(struct file___157 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___18 *, int);
	int (*fasync)(int, struct file___157 *, int);
	int (*lock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*sendpage)(struct file___157 *, struct page___156 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___157 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___157 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___157 *, long int, struct file_lock___157 **, void **);
		struct {
			int (*setlease)(struct file___157 *, long int, struct file_lock___157 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___157 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___116 *, struct file___157 *);
};

struct dev_pm_qos_request___17 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___122 *dev;
};

struct dentry_operations___157;

struct super_block___157;

struct dentry___157 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___157 *d_parent;
	struct qstr d_name;
	struct inode___157 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___157 *d_op;
	struct super_block___157 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___157;

struct dquot___157;

struct block_device___157;

struct inode___157 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___157 *i_op;
	struct super_block___157 *i_sb;
	struct address_space___157 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___160 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___157 *i_fop;
	struct file_lock___157 *i_flock;
	struct address_space___157 i_data;
	struct dquot___157 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___157 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___157 {
	int (*d_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_hash)(const struct dentry___157 *, struct qstr *);
	int (*d_compare)(const struct dentry___157 *, const struct dentry___157 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___157 *);
	void (*d_release)(struct dentry___157 *);
	void (*d_prune)(struct dentry___157 *);
	void (*d_iput)(struct dentry___157 *, struct inode___157 *);
	char * (*d_dname)(struct dentry___157 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___157 *);
	int (*d_manage)(struct dentry___157 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___157;

struct mem_dqinfo___157 {
	struct quota_format_type___157 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___157;

struct quota_info___157 {
	unsigned int flags;
	struct mutex___160 dqio_mutex;
	struct mutex___160 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___157 *files[2];
	struct mem_dqinfo___157 info[2];
	const struct quota_format_ops___157 *ops[2];
};

struct file_system_type___157;

struct super_operations___157;

struct dquot_operations___157;

struct quotactl_ops___157;

struct xattr_handler___103;

struct super_block___157 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___157 *s_type;
	const struct super_operations___157 *s_op;
	const struct dquot_operations___157 *dq_op;
	const struct quotactl_ops___157 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___157 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___103 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___157 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___157 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___160 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___157 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___157 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___157 *bd_inode;
	struct super_block___157 *bd_super;
	struct mutex___160 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___157 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___160 bd_fsfreeze_mutex;
};

struct cgroup___102;

struct cgroup_subsys_state___102 {
	struct cgroup___102 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___157 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___157 *ia_file;
};

struct dquot___157 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___160 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___157 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___157 {
	int qf_fmt_id;
	const struct quota_format_ops___157 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___157 *qf_next;
};

struct quota_format_ops___157 {
	int (*check_quota_file)(struct super_block___157 *, int);
	int (*read_file_info)(struct super_block___157 *, int);
	int (*write_file_info)(struct super_block___157 *, int);
	int (*free_file_info)(struct super_block___157 *, int);
	int (*read_dqblk)(struct dquot___157 *);
	int (*commit_dqblk)(struct dquot___157 *);
	int (*release_dqblk)(struct dquot___157 *);
};

struct dquot_operations___157 {
	int (*write_dquot)(struct dquot___157 *);
	struct dquot___157 * (*alloc_dquot)(struct super_block___157 *, int);
	void (*destroy_dquot)(struct dquot___157 *);
	int (*acquire_dquot)(struct dquot___157 *);
	int (*release_dquot)(struct dquot___157 *);
	int (*mark_dirty)(struct dquot___157 *);
	int (*write_info)(struct super_block___157 *, int);
	qsize_t * (*get_reserved_space)(struct inode___157 *);
};

struct quotactl_ops___157 {
	int (*quota_on)(struct super_block___157 *, int, int, struct path___157 *);
	int (*quota_on_meta)(struct super_block___157 *, int, int);
	int (*quota_off)(struct super_block___157 *, int);
	int (*quota_sync)(struct super_block___157 *, int);
	int (*get_info)(struct super_block___157 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___157 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___157 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___157 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___157 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___157 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___157 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___157 *, unsigned int);
};

struct address_space_operations___157 {
	int (*writepage)(struct page___156 *, struct writeback_control *);
	int (*readpage)(struct file___157 *, struct page___156 *);
	int (*writepages)(struct address_space___157 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___156 *);
	int (*readpages)(struct file___157 *, struct address_space___157 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___157 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___156 **, void **);
	int (*write_end)(struct file___157 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___156 *, void *);
	sector_t (*bmap)(struct address_space___157 *, sector_t);
	void (*invalidatepage)(struct page___156 *, long unsigned int);
	int (*releasepage)(struct page___156 *, gfp_t);
	void (*freepage)(struct page___156 *);
	ssize_t (*direct_IO)(int, struct kiocb___18 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___157 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___157 *, struct page___156 *, struct page___156 *, enum migrate_mode);
	int (*launder_page)(struct page___156 *);
	int (*is_partially_uptodate)(struct page___156 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___156 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___157 *, struct page___156 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___157 *, sector_t *);
	void (*swap_deactivate)(struct file___157 *);
	void (*invalidatepage_range)(struct page___156 *, unsigned int, unsigned int);
};

struct inode_operations___157 {
	struct dentry___157 * (*lookup)(struct inode___157 *, struct dentry___157 *, unsigned int);
	void * (*follow_link)(struct dentry___157 *, struct nameidata *);
	int (*permission)(struct inode___157 *, int);
	struct posix_acl * (*get_acl)(struct inode___157 *, int);
	int (*readlink)(struct dentry___157 *, char *, int);
	void (*put_link)(struct dentry___157 *, struct nameidata *, void *);
	int (*create)(struct inode___157 *, struct dentry___157 *, umode_t, bool);
	int (*link)(struct dentry___157 *, struct inode___157 *, struct dentry___157 *);
	int (*unlink)(struct inode___157 *, struct dentry___157 *);
	int (*symlink)(struct inode___157 *, struct dentry___157 *, const char *);
	int (*mkdir)(struct inode___157 *, struct dentry___157 *, umode_t);
	int (*rmdir)(struct inode___157 *, struct dentry___157 *);
	int (*mknod)(struct inode___157 *, struct dentry___157 *, umode_t, dev_t);
	int (*rename)(struct inode___157 *, struct dentry___157 *, struct inode___157 *, struct dentry___157 *);
	int (*setattr)(struct dentry___157 *, struct iattr___157 *);
	int (*getattr)(struct vfsmount *, struct dentry___157 *, struct kstat *);
	int (*setxattr)(struct dentry___157 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___157 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___157 *, char *, size_t);
	int (*removexattr)(struct dentry___157 *, const char *);
	int (*fiemap)(struct inode___157 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___157 *, struct timespec *, int);
	int (*atomic_open)(struct inode___157 *, struct dentry___157 *, struct file___157 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___157;

struct lock_manager_operations___157;

struct file_lock___157 {
	struct file_lock___157 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___157 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___157 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___157 *fl_ops;
	const struct lock_manager_operations___157 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___157 {
	void (*fl_copy_lock)(struct file_lock___157 *, struct file_lock___157 *);
	void (*fl_release_private)(struct file_lock___157 *);
};

struct lock_manager_operations___157 {
	int (*lm_compare_owner)(struct file_lock___157 *, struct file_lock___157 *);
	long unsigned int (*lm_owner_key)(struct file_lock___157 *);
	void (*lm_notify)(struct file_lock___157 *);
	int (*lm_grant)(struct file_lock___157 *, struct file_lock___157 *, int);
	void (*lm_break)(struct file_lock___157 *);
	int (*lm_change)(struct file_lock___157 **, int);
};

struct file_system_type___157 {
	const char *name;
	int fs_flags;
	struct dentry___157 * (*mount)(struct file_system_type___157 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___157 *);
	struct module *owner;
	struct file_system_type___157 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___157 {
	struct inode___157 * (*alloc_inode)(struct super_block___157 *);
	void (*destroy_inode)(struct inode___157 *);
	void (*dirty_inode)(struct inode___157 *, int);
	int (*write_inode)(struct inode___157 *, struct writeback_control *);
	int (*drop_inode)(struct inode___157 *);
	void (*evict_inode)(struct inode___157 *);
	void (*put_super)(struct super_block___157 *);
	int (*sync_fs)(struct super_block___157 *, int);
	int (*freeze_fs)(struct super_block___157 *);
	int (*unfreeze_fs)(struct super_block___157 *);
	int (*statfs)(struct dentry___157 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___157 *, int *, char *);
	void (*umount_begin)(struct super_block___157 *);
	int (*show_options)(struct seq_file___116 *, struct dentry___157 *);
	int (*show_devname)(struct seq_file___116 *, struct dentry___157 *);
	int (*show_path)(struct seq_file___116 *, struct dentry___157 *);
	int (*show_stats)(struct seq_file___116 *, struct dentry___157 *);
	ssize_t (*quota_read)(struct super_block___157 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___157 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___157 *);
	int (*bdev_try_to_free_page)(struct super_block___157 *, struct page___156 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___157 *);
	void (*free_cached_objects)(struct super_block___157 *, int);
};

struct xattr_handler___103 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___157 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___157 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___157 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___115;

struct seq_file___116 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___160 lock;
	const struct seq_operations___115 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___13 {
	int (*get_settings)(struct net_device___15 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___15 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___15 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___15 *);
	void (*get_regs)(struct net_device___15 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___15 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___15 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___15 *);
	void (*set_msglevel)(struct net_device___15 *, u32);
	int (*nway_reset)(struct net_device___15 *);
	u32 (*get_link)(struct net_device___15 *);
	int (*get_eeprom_len)(struct net_device___15 *);
	int (*get_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___15 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___15 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___15 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___15 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___15 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___15 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___15 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___15 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___15 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___15 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___15 *);
	void (*complete)(struct net_device___15 *);
	u32 (*get_priv_flags)(struct net_device___15 *);
	int (*set_priv_flags)(struct net_device___15 *, u32);
	int (*get_sset_count)(struct net_device___15 *, int);
	int (*get_rxnfc)(struct net_device___15 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___15 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___15 *, struct ethtool_flash *);
	int (*reset)(struct net_device___15 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___15 *);
	int (*get_rxfh_indir)(struct net_device___15 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___15 *, const u32 *);
	void (*get_channels)(struct net_device___15 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___15 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___15 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___15 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___15 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___15 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___15 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___15 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___15 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___15 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___15 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___15 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___11 {
	struct callback_head callback_head;
	struct dst_entry___11 *child;
	struct net_device___15 *dev;
	struct dst_ops___25 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___11 *path;
	struct dst_entry___11 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___17 *);
	union {
		int (*output)(struct sock___12 *, struct sk_buff___17 *);
		struct {
			int (*output)(struct sk_buff___17 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___11 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___11;

struct neigh_parms___11;

struct neigh_ops___11;

struct neighbour___11 {
	struct neighbour___11 *next;
	struct neigh_table___11 *tbl;
	struct neigh_parms___11 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___14 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___11 *, struct sk_buff___17 *);
	const struct neigh_ops___11 *ops;
	struct callback_head rcu;
	struct net_device___15 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___25 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___17 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___17 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___26 *, struct dst_entry___11 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___17 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___17 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___110 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___110 *);
	void (*irq_shutdown)(struct irq_data___110 *);
	void (*irq_enable)(struct irq_data___110 *);
	void (*irq_disable)(struct irq_data___110 *);
	void (*irq_ack)(struct irq_data___110 *);
	void (*irq_mask)(struct irq_data___110 *);
	void (*irq_mask_ack)(struct irq_data___110 *);
	void (*irq_unmask)(struct irq_data___110 *);
	void (*irq_eoi)(struct irq_data___110 *);
	int (*irq_set_affinity)(struct irq_data___110 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___110 *);
	int (*irq_set_type)(struct irq_data___110 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___110 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___110 *);
	void (*irq_bus_sync_unlock)(struct irq_data___110 *);
	void (*irq_cpu_online)(struct irq_data___110 *);
	void (*irq_cpu_offline)(struct irq_data___110 *);
	void (*irq_suspend)(struct irq_data___110 *);
	void (*irq_resume)(struct irq_data___110 *);
	void (*irq_pm_shutdown)(struct irq_data___110 *);
	void (*irq_print_chip)(struct irq_data___110 *, struct seq_file___116 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___110 *, void *);
	long unsigned int flags;
};

struct seq_operations___115 {
	void * (*start)(struct seq_file___116 *, loff_t *);
	void (*stop)(struct seq_file___116 *, void *);
	void * (*next)(struct seq_file___116 *, void *, loff_t *);
	int (*show)(struct seq_file___116 *, void *);
};

struct dcbnl_rtnl_ops___13 {
	int (*ieee_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___15 *);
	u8 (*setstate)(struct net_device___15 *, u8);
	void (*getpermhwaddr)(struct net_device___15 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___15 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___15 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___15 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___15 *, int, u8 *);
	void (*setpfccfg)(struct net_device___15 *, int, u8);
	void (*getpfccfg)(struct net_device___15 *, int, u8 *);
	u8 (*setall)(struct net_device___15 *);
	u8 (*getcap)(struct net_device___15 *, int, u8 *);
	int (*getnumtcs)(struct net_device___15 *, int, u8 *);
	int (*setnumtcs)(struct net_device___15 *, int, u8);
	u8 (*getpfcstate)(struct net_device___15 *);
	void (*setpfcstate)(struct net_device___15 *, u8);
	void (*getbcncfg)(struct net_device___15 *, int, u32 *);
	void (*setbcncfg)(struct net_device___15 *, int, u32);
	void (*getbcnrp)(struct net_device___15 *, int, u8 *);
	void (*setbcnrp)(struct net_device___15 *, int, u8);
	u8 (*setapp)(struct net_device___15 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___15 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___15 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___15 *, int, u8);
	u8 (*getdcbx)(struct net_device___15 *);
	u8 (*setdcbx)(struct net_device___15 *, u8);
	int (*peer_getappinfo)(struct net_device___15 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___15 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___15 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___15 *, struct cee_pfc *);
};

struct cgroupfs_root___102;

struct cgroup___102 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___102 *parent;
	struct dentry___157 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___102 *subsys[11];
	struct cgroupfs_root___102 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___160 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___102 {
	struct super_block___157 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___102 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___51 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___157 *, struct file___157 *);
	ssize_t (*read)(struct cgroup___102 *, struct cftype___51 *, struct file___157 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___102 *, struct cftype___51 *);
	s64 (*read_s64)(struct cgroup___102 *, struct cftype___51 *);
	int (*read_map)(struct cgroup___102 *, struct cftype___51 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___102 *, struct cftype___51 *, struct seq_file___116 *);
	ssize_t (*write)(struct cgroup___102 *, struct cftype___51 *, struct file___157 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___102 *, struct cftype___51 *, u64);
	int (*write_s64)(struct cgroup___102 *, struct cftype___51 *, s64);
	int (*write_string)(struct cgroup___102 *, struct cftype___51 *, const char *);
	int (*trigger)(struct cgroup___102 *, unsigned int);
	int (*release)(struct inode___157 *, struct file___157 *);
	int (*register_event)(struct cgroup___102 *, struct cftype___51 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___102 *, struct cftype___51 *, struct eventfd_ctx *);
};

struct cftype_set___49 {
	struct list_head node;
	struct cftype___51 *cfts;
};

struct task_and_cgroup___49 {
	struct task_struct___159 *task;
	struct cgroup___102 *cgrp;
	struct css_set___102 *cg;
};

struct cgroup_taskset___49 {
	struct task_and_cgroup___49 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___102 *cur_cgrp;
};

struct cgroup_subsys___49 {
	struct cgroup_subsys_state___102 * (*css_alloc)(struct cgroup___102 *);
	int (*css_online)(struct cgroup___102 *);
	void (*css_offline)(struct cgroup___102 *);
	void (*css_free)(struct cgroup___102 *);
	int (*can_attach)(struct cgroup___102 *, struct cgroup_taskset___49 *);
	void (*cancel_attach)(struct cgroup___102 *, struct cgroup_taskset___49 *);
	void (*attach)(struct cgroup___102 *, struct cgroup_taskset___49 *);
	void (*fork)(struct task_struct___159 *);
	void (*exit)(struct cgroup___102 *, struct cgroup___102 *, struct task_struct___159 *);
	void (*bind)(struct cgroup___102 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___102 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___51 *base_cftypes;
	struct cftype_set___49 base_cftset;
	struct module *module;
};

struct linux_binprm___27 {
	char buf[128];
	struct vm_area_struct___164 *vma;
	long unsigned int vma_pages;
	struct mm_struct___164 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___157 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct request_sock_ops___9;

struct request_sock___9 {
	struct sock_common___11 __req_common;
	struct request_sock___9 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___9 *rsk_ops;
	struct sock___12 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___14 {
	struct sk_buff___17 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___17 *, struct netlink_callback___14 *);
	int (*done)(struct netlink_callback___14 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___13 {
	int (*create)(struct sk_buff___17 *, struct net_device___15 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___17 *, unsigned char *);
	int (*rebuild)(struct sk_buff___17 *);
	int (*cache)(const struct neighbour___11 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___15 *, const unsigned char *);
};

struct napi_struct___13 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___13 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___15 *dev;
	struct sk_buff___17 *gro_list;
	struct sk_buff___17 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___13 {
	struct net_device___15 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___14 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___13 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___14 kobj;
	struct net_device___15 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___13 {
	int (*ndo_init)(struct net_device___15 *);
	void (*ndo_uninit)(struct net_device___15 *);
	int (*ndo_open)(struct net_device___15 *);
	int (*ndo_stop)(struct net_device___15 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___17 *, struct net_device___15 *);
	u16 (*ndo_select_queue)(struct net_device___15 *, struct sk_buff___17 *);
	void (*ndo_change_rx_flags)(struct net_device___15 *, int);
	void (*ndo_set_rx_mode)(struct net_device___15 *);
	int (*ndo_set_mac_address)(struct net_device___15 *, void *);
	int (*ndo_validate_addr)(struct net_device___15 *);
	int (*ndo_do_ioctl)(struct net_device___15 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___15 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___15 *, int);
	int (*ndo_neigh_setup)(struct net_device___15 *, struct neigh_parms___11 *);
	void (*ndo_tx_timeout)(struct net_device___15 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___15 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___15 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___15 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___15 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___15 *);
	int (*ndo_netpoll_setup)(struct net_device___15 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___15 *);
	int (*ndo_busy_poll)(struct napi_struct___13 *);
	int (*ndo_set_vf_mac)(struct net_device___15 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___15 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___15 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___15 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___15 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___15 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___15 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___15 *, int, struct sk_buff___17 *);
	int (*ndo_setup_tc)(struct net_device___15 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___15 *);
	int (*ndo_fcoe_disable)(struct net_device___15 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___15 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___15 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___15 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___15 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___15 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___15 *, const struct sk_buff___17 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___15 *, struct net_device___15 *);
	int (*ndo_del_slave)(struct net_device___15 *, struct net_device___15 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___11 *);
	void (*ndo_neigh_destroy)(struct neighbour___11 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___17 *, struct netlink_callback___14 *, struct net_device___15 *, int);
	int (*ndo_bridge_setlink)(struct net_device___15 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___17 *, u32, u32, struct net_device___15 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___15 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___15 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___15 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___15 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___15 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___15 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___17 *, struct net_device___15 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___15 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___15 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___15 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___11 {
	struct net___26 *net;
	struct net_device___15 *dev;
	struct neigh_parms___11 *next;
	int (*neigh_setup)(struct neighbour___11 *);
	void (*neigh_cleanup)(struct neighbour___11 *);
	struct neigh_table___11 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___8;

struct ifacaddr6___8;

struct inet6_dev___8 {
	struct net_device___15 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___8 *mc_list;
	struct ifmcaddr6___8 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___8 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___11 *nd_parms;
	struct inet6_dev___8 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___11 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___15 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___26 *, struct net_device___15 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___15 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___15 *, struct list_head *);
	size_t (*get_size)(const struct net_device___15 *);
	int (*fill_info)(struct sk_buff___17 *, const struct net_device___15 *);
	size_t (*get_xstats_size)(const struct net_device___15 *);
	int (*fill_xstats)(struct sk_buff___17 *, const struct net_device___15 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___26 * (*get_link_net)(const struct net_device___15 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___15 *, struct net_device___15 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___15 *, const struct net_device___15 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___17 *, const struct net_device___15 *, const struct net_device___15 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___12 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___17 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___11;

struct neigh_hash_table___11;

struct neigh_table___11 {
	struct neigh_table___11 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___15 *, __u32 *);
	int (*constructor)(struct neighbour___11 *);
	int (*pconstructor)(struct pneigh_entry___11 *);
	void (*pdestructor)(struct pneigh_entry___11 *);
	void (*proxy_redo)(struct sk_buff___17 *);
	char *id;
	struct neigh_parms___11 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___14 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___11 *nht;
	struct pneigh_entry___11 **phash_buckets;
};

struct neigh_ops___11 {
	int family;
	void (*solicit)(struct neighbour___11 *, struct sk_buff___17 *);
	void (*error_report)(struct neighbour___11 *, struct sk_buff___17 *);
	int (*output)(struct neighbour___11 *, struct sk_buff___17 *);
	int (*connected_output)(struct neighbour___11 *, struct sk_buff___17 *);
};

struct pneigh_entry___11 {
	struct pneigh_entry___11 *next;
	struct net___26 *net;
	struct net_device___15 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___11 {
	struct neighbour___11 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable {
	struct dst_entry___11 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct proto___11 {
	void (*close)(struct sock___12 *, long int);
	int (*connect)(struct sock___12 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___12 *, int);
	struct sock___12 * (*accept)(struct sock___12 *, int, int *);
	int (*ioctl)(struct sock___12 *, int, long unsigned int);
	int (*init)(struct sock___12 *);
	void (*destroy)(struct sock___12 *);
	void (*shutdown)(struct sock___12 *, int);
	int (*setsockopt)(struct sock___12 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___12 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___12 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___12 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___12 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___18 *, struct sock___12 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___18 *, struct sock___12 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___12 *, struct page___156 *, int, size_t, int);
	int (*bind)(struct sock___12 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___12 *, struct sk_buff___17 *);
	void (*release_cb)(struct sock___12 *);
	void (*mtu_reduced)(struct sock___12 *);
	void (*hash)(struct sock___12 *);
	void (*unhash)(struct sock___12 *);
	void (*rehash)(struct sock___12 *);
	int (*get_port)(struct sock___12 *, short unsigned int);
	void (*clear_sk)(struct sock___12 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___12 *);
	void (*enter_memory_pressure)(struct sock___12 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___143 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___9 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___49 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___11 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___11 {
	void (*enter_memory_pressure)(struct sock___12 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___9 {
	int family;
	int obj_size;
	struct kmem_cache___143 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___12 *, struct request_sock___9 *);
	void (*send_ack)(struct sock___12 *, struct sk_buff___17 *, struct request_sock___9 *);
	void (*send_reset)(struct sock___12 *, struct sk_buff___17 *);
	void (*destructor)(struct request_sock___9 *);
	void (*syn_ack_timeout)(struct sock___12 *, struct request_sock___9 *);
};

struct timewait_sock_ops___4 {
	struct kmem_cache___143 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___12 *, struct sock___12 *, void *);
	void (*twsk_destructor)(struct sock___12 *);
};

struct ifmcaddr6___8 {
	struct in6_addr mca_addr;
	struct inet6_dev___8 *idev;
	struct ifmcaddr6___8 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___8 {
	struct in6_addr aca_addr;
	struct inet6_dev___8 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___8 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct coredump_params___26 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___157 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct netnode_security_struct {
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} addr;
	u32 sid;
	u16 family;
};

struct sel_netnode_bkt {
	unsigned int size;
	struct list_head list;
};

struct sel_netnode {
	struct netnode_security_struct nsec;
	struct list_head list;
	struct callback_head rcu;
};

struct netport_security_struct {
	u32 sid;
	u16 port;
	u8 protocol;
};

struct sel_netport_bkt {
	int size;
	struct list_head list;
};

struct sel_netport {
	struct netport_security_struct psec;
	struct list_head list;
	struct callback_head rcu;
};

struct ebitmap_node {
	struct ebitmap_node *next;
	long unsigned int maps[6];
	u32 startbit;
};

struct ebitmap {
	struct ebitmap_node *node;
	u32 highbit;
};

struct policy_file {
	char *data;
	size_t len;
};

struct hashtab_node {
	void *key;
	void *datum;
	struct hashtab_node *next;
};

struct hashtab {
	struct hashtab_node **htable;
	u32 size;
	u32 nel;
	u32 (*hash_value)(struct hashtab *, const void *);
	int (*keycmp)(struct hashtab *, const void *, const void *);
};

struct hashtab_info {
	u32 slots_used;
	u32 max_chain_len;
};

struct symtab {
	struct hashtab *table;
	u32 nprim;
};

struct mls_level {
	u32 sens;
	struct ebitmap cat;
};

struct mls_range {
	struct mls_level level[2];
};

struct context___2 {
	u32 user;
	u32 role;
	u32 type;
	u32 len;
	struct mls_range range;
	char *str;
};

struct sidtab_node {
	u32 sid;
	struct context___2 context;
	struct sidtab_node *next;
};

struct sidtab {
	struct sidtab_node **htable;
	unsigned int nel;
	unsigned int next_sid;
	unsigned char shutdown;
	struct sidtab_node *cache[3];
	spinlock_t lock;
};

struct avtab_key {
	u16 source_type;
	u16 target_type;
	u16 target_class;
	u16 specified;
};

struct avtab_datum {
	u32 data;
};

struct avtab_node {
	struct avtab_key key;
	struct avtab_datum datum;
	struct avtab_node *next;
};

struct avtab {
	struct avtab_node **htable;
	u32 nel;
	u32 nslot;
	u16 mask;
};

struct constraint_expr {
	u32 expr_type;
	u32 attr;
	u32 op;
	struct ebitmap names;
	struct constraint_expr *next;
};

struct constraint_node {
	u32 permissions;
	struct constraint_expr *expr;
	struct constraint_node *next;
};

struct common_datum {
	u32 value;
	struct symtab permissions;
};

struct class_datum {
	u32 value;
	char *comkey;
	struct common_datum *comdatum;
	struct symtab permissions;
	struct constraint_node *constraints;
	struct constraint_node *validatetrans;
	char default_user;
	char default_role;
	char default_type;
	char default_range;
};

struct role_datum {
	u32 value;
	u32 bounds;
	struct ebitmap dominates;
	struct ebitmap types;
};

struct role_trans {
	u32 role;
	u32 type;
	u32 tclass;
	u32 new_role;
	struct role_trans *next;
};

struct role_allow {
	u32 role;
	u32 new_role;
	struct role_allow *next;
};

struct user_datum {
	u32 value;
	u32 bounds;
	struct ebitmap roles;
	struct mls_range range;
	struct mls_level dfltlevel;
};

struct cond_bool_datum {
	__u32 value;
	int state;
};

struct ocontext {
	union {
		char *name;
		struct {
			u8 protocol;
			u16 low_port;
			u16 high_port;
		} port;
		struct {
			u32 addr;
			u32 mask;
		} node;
		struct {
			u32 addr[4];
			u32 mask[4];
		} node6;
	} u;
	union {
		u32 sclass;
		u32 behavior;
	} v;
	struct context___2 context[2];
	u32 sid[2];
	struct ocontext *next;
};

struct genfs {
	char *fstype;
	struct ocontext *head;
	struct genfs *next;
};

struct cond_node;

struct policydb {
	int mls_enabled;
	struct symtab symtab[8];
	struct flex_array *sym_val_to_name[8];
	struct class_datum **class_val_to_struct;
	struct role_datum **role_val_to_struct;
	struct user_datum **user_val_to_struct;
	struct flex_array *type_val_to_struct_array;
	struct avtab te_avtab;
	struct role_trans *role_tr;
	struct ebitmap filename_trans_ttypes;
	struct hashtab *filename_trans;
	struct cond_bool_datum **bool_val_to_struct;
	struct avtab te_cond_avtab;
	struct cond_node *cond_list;
	struct role_allow *role_allow;
	struct ocontext *ocontexts[7];
	struct genfs *genfs;
	struct hashtab *range_tr;
	struct flex_array *type_attr_map_array;
	struct ebitmap policycaps;
	struct ebitmap permissive_map;
	size_t len;
	unsigned int policyvers;
	unsigned int reject_unknown: 1;
	unsigned int allow_unknown: 1;
	u16 process_class;
	u32 process_trans_perms;
};

struct page___157;

typedef struct page___157 *pgtable_t___157;

struct address_space___158;

struct kmem_cache___144;

struct page___157 {
	long unsigned int flags;
	struct address_space___158 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___157 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___157 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___144 *slab_cache;
		struct page___157 *first_page;
	};
	long: 64;
};

struct task_struct___160;

struct pv_cpu_ops___160 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___160 *);
	void (*end_context_switch)(struct task_struct___160 *);
};

struct mutex___161 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___160 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___153 {
	struct page___157 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___165;

struct nsproxy___95;

struct signal_struct___160;

struct css_set___103;

struct task_struct___160 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___160 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___165 *mm;
	struct mm_struct___165 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___160 *real_parent;
	struct task_struct___160 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___160 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___160 = 0,
		VTIME_USER___160 = 1,
		VTIME_SYS___160 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___95 *nsproxy;
	struct signal_struct___160 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___103 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___161 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___153 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___165 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___165 *, struct mm_struct___165 *);
	void (*dup_mmap)(struct mm_struct___165 *, struct mm_struct___165 *);
	void (*exit_mmap)(struct mm_struct___165 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___165 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___165 *);
	void (*pgd_free)(struct mm_struct___165 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___165 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___165 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___165 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___165 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___165 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___165 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___165 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___165 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___165 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___165 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___165 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___161 lock;
	void *vdso;
} mm_context_t___161;

struct xol_area___157;

struct uprobes_state___157 {
	struct xol_area___157 *xol_area;
};

struct vm_area_struct___165;

struct file___158;

struct core_state___160;

struct mm_struct___165 {
	struct vm_area_struct___165 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___165 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___165 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___161 context;
	long unsigned int flags;
	struct core_state___160 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___160 *owner;
	struct file___158 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___157 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___157 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___157 *page;
	long unsigned int vaddr;
};

struct kset___15;

struct kobj_type___15;

struct kobject___15 {
	const char *name;
	struct list_head entry;
	struct kobject___15 *parent;
	struct kset___15 *kset;
	struct kobj_type___15 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___143;

struct memcg_cache_params___144;

struct kmem_cache___144 {
	struct kmem_cache_cpu___143 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___15 kobj;
	struct memcg_cache_params___144 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___158;

struct address_space_operations___158;

struct address_space___158 {
	struct inode___158 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___161 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___158 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___158;

struct path___158 {
	struct vfsmount *mnt;
	struct dentry___158 *dentry;
};

struct file_operations___158;

struct file___158 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___158 f_path;
	struct inode___158 *f_inode;
	const struct file_operations___158 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___158 *f_mapping;
	struct mutex___161 f_pos_lock;
};

struct vm_operations_struct___138;

struct vm_area_struct___165 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___165 *vm_next;
	struct vm_area_struct___165 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___165 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___138 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___158 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___135;

struct vm_operations_struct___138 {
	void (*open)(struct vm_area_struct___165 *);
	void (*close)(struct vm_area_struct___165 *);
	int (*fault)(struct vm_area_struct___165 *, struct vm_fault___135 *);
	int (*page_mkwrite)(struct vm_area_struct___165 *, struct vm_fault___135 *);
	int (*access)(struct vm_area_struct___165 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___165 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___165 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___165 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___165 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___160 {
	struct task_struct___160 *task;
	struct core_thread___160 *next;
};

struct core_state___160 {
	atomic_t nr_threads;
	struct core_thread___160 dumper;
	struct completion startup;
};

struct irq_data___111;

struct x86_io_apic_ops___111 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___111 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___111;

struct irq_data___111 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___111 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___123;

struct dev_pm_ops___123 {
	int (*prepare)(struct device___123 *);
	void (*complete)(struct device___123 *);
	int (*suspend)(struct device___123 *);
	int (*resume)(struct device___123 *);
	int (*freeze)(struct device___123 *);
	int (*thaw)(struct device___123 *);
	int (*poweroff)(struct device___123 *);
	int (*restore)(struct device___123 *);
	int (*suspend_late)(struct device___123 *);
	int (*resume_early)(struct device___123 *);
	int (*freeze_late)(struct device___123 *);
	int (*thaw_early)(struct device___123 *);
	int (*poweroff_late)(struct device___123 *);
	int (*restore_early)(struct device___123 *);
	int (*suspend_noirq)(struct device___123 *);
	int (*resume_noirq)(struct device___123 *);
	int (*freeze_noirq)(struct device___123 *);
	int (*thaw_noirq)(struct device___123 *);
	int (*poweroff_noirq)(struct device___123 *);
	int (*restore_noirq)(struct device___123 *);
	int (*runtime_suspend)(struct device___123 *);
	int (*runtime_resume)(struct device___123 *);
	int (*runtime_idle)(struct device___123 *);
};

struct dev_pm_qos___18;

struct dev_pm_info___18 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___18 *qos;
};

struct dma_map_ops___46;

struct dev_archdata___46 {
	struct dma_map_ops___46 *dma_ops;
	void *iommu;
};

struct acpi_dev_node___17 {
	union {
		struct acpi_device *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
};

struct device_type___123;

struct bus_type___123;

struct device_driver___123;

struct dev_pm_domain___123;

struct class___123;

struct attribute_group___115;

struct device_rh___123;

struct device___123 {
	struct device___123 *parent;
	struct device_private *p;
	struct kobject___15 kobj;
	const char *init_name;
	const struct device_type___123 *type;
	struct mutex___161 mutex;
	struct bus_type___123 *bus;
	struct device_driver___123 *driver;
	void *platform_data;
	struct dev_pm_info___18 power;
	struct dev_pm_domain___123 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___46 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___123 *class;
	const struct attribute_group___115 **groups;
	void (*release)(struct device___123 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___123 *device_rh;
};

struct dev_pm_qos_request___18;

struct dev_pm_qos___18 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___18 *latency_req;
	struct dev_pm_qos_request___18 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___18 *latency_tolerance_req;
};

struct dev_pm_info_rh___123 {
	void (*set_latency_tolerance)(struct device___123 *, s32);
};

struct dev_pm_domain___123 {
	struct dev_pm_ops___123 ops;
};

struct smp_ops___160 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___160 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___160;

struct lruvec___160 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___160 *zone;
};

struct pglist_data___160;

struct zone___160 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___160 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___160 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___160 {
	struct zone___160 *zone;
	int zone_idx;
};

struct zonelist___160 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___160 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___160 {
	struct zone___160 node_zones[4];
	struct zonelist___160 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___160 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___28;

struct ctl_node___28 {
	struct rb_node node;
	struct ctl_table_header___28 *header;
};

struct ctl_table_root___28;

struct ctl_table_set___28;

struct ctl_dir___28;

struct ctl_table_header___28 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___28 *root;
	struct ctl_table_set___28 *set;
	struct ctl_dir___28 *parent;
	struct ctl_node___28 *node;
};

struct ctl_dir___28 {
	struct ctl_table_header___28 header;
	struct rb_root root;
};

struct ctl_table_set___28 {
	int (*is_seen)(struct ctl_table_set___28 *);
	struct ctl_dir___28 dir;
};

struct ctl_table_root___28 {
	struct ctl_table_set___28 default_set;
	struct ctl_table_set___28 * (*lookup)(struct ctl_table_root___28 *, struct nsproxy___95 *);
	int (*permissions)(struct ctl_table_header___28 *, struct ctl_table *);
};

struct net___27;

struct nsproxy___95 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___27 *net_ns;
};

struct signal_struct___160 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___160 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___160 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___161 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___103;

struct css_set___103 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___103 *subsys[11];
	struct callback_head callback_head;
};

struct sock___13;

struct kobj_ns_type_operations___12 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___13 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___12;

struct sock_common___12 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___12 *skc_prot;
	struct net___27 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___18;

struct sk_buff_head___15 {
	struct sk_buff___18 *next;
	struct sk_buff___18 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___13;

struct socket_wq___12;

struct dst_entry___12;

struct socket___13;

struct cg_proto___12;

struct sock___13 {
	struct sock_common___12 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___15 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___18 *head;
		struct sk_buff___18 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___13 *sk_filter;
	struct socket_wq___12 *sk_wq;
	struct sk_buff_head___15 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___12 *sk_rx_dst;
	struct dst_entry___12 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___15 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___15 sk_error_queue;
	struct proto___12 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___13 *sk_socket;
	void *sk_user_data;
	struct page_frag___153 sk_frag;
	struct sk_buff___18 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___12 *sk_cgrp;
	void (*sk_state_change)(struct sock___13 *);
	void (*sk_data_ready)(struct sock___13 *, int);
	void (*sk_write_space)(struct sock___13 *);
	void (*sk_error_report)(struct sock___13 *);
	int (*sk_backlog_rcv)(struct sock___13 *, struct sk_buff___18 *);
	void (*sk_destruct)(struct sock___13 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___117;

struct attribute_group___115 {
	const char *name;
	umode_t (*is_visible)(struct kobject___15 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___117 **bin_attrs;
};

struct bin_attribute___117 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___158 *, struct kobject___15 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___158 *, struct kobject___15 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	int (*mmap)(struct file___158 *, struct kobject___15 *, struct bin_attribute___117 *, struct vm_area_struct___165 *);
};

struct sysfs_ops___15 {
	ssize_t (*show)(struct kobject___15 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___15 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___15 *, const struct attribute *);
};

struct kset_uevent_ops___15;

struct kset___15 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___15 kobj;
	const struct kset_uevent_ops___15 *uevent_ops;
};

struct kobj_type___15 {
	void (*release)(struct kobject___15 *);
	const struct sysfs_ops___15 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___15 *);
	const void * (*namespace)(struct kobject___15 *);
};

struct kset_uevent_ops___15 {
	int (* const filter)(struct kset___15 *, struct kobject___15 *);
	const char * (* const name)(struct kset___15 *, struct kobject___15 *);
	int (* const uevent)(struct kset___15 *, struct kobject___15 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___143 {
	void **freelist;
	long unsigned int tid;
	struct page___157 *page;
	struct page___157 *partial;
};

struct memcg_cache_params___144 {
	bool is_root_cache;
	union {
		struct kmem_cache___144 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___144 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___158;

struct super_block___158;

struct dentry___158 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___158 *d_parent;
	struct qstr d_name;
	struct inode___158 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___158 *d_op;
	struct super_block___158 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___158;

struct file_lock___158;

struct dquot___158;

struct block_device___158;

struct inode___158 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___158 *i_op;
	struct super_block___158 *i_sb;
	struct address_space___158 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___161 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___158 *i_fop;
	struct file_lock___158 *i_flock;
	struct address_space___158 i_data;
	struct dquot___158 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___158 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___158 {
	int (*d_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_hash)(const struct dentry___158 *, struct qstr *);
	int (*d_compare)(const struct dentry___158 *, const struct dentry___158 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___158 *);
	void (*d_release)(struct dentry___158 *);
	void (*d_prune)(struct dentry___158 *);
	void (*d_iput)(struct dentry___158 *, struct inode___158 *);
	char * (*d_dname)(struct dentry___158 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___158 *);
	int (*d_manage)(struct dentry___158 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___158;

struct mem_dqinfo___158 {
	struct quota_format_type___158 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___158;

struct quota_info___158 {
	unsigned int flags;
	struct mutex___161 dqio_mutex;
	struct mutex___161 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___158 *files[2];
	struct mem_dqinfo___158 info[2];
	const struct quota_format_ops___158 *ops[2];
};

struct file_system_type___158;

struct super_operations___158;

struct dquot_operations___158;

struct quotactl_ops___158;

struct xattr_handler___104;

struct super_block___158 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___158 *s_type;
	const struct super_operations___158 *s_op;
	const struct dquot_operations___158 *dq_op;
	const struct quotactl_ops___158 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___158 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___104 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___158 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___158 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___161 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___158 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct fasync_struct___158;

struct socket_wq___12 {
	wait_queue_head_t wait;
	struct fasync_struct___158 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___158 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___158 *fa_next;
	struct file___158 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___12;

struct socket___13 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___12 *wq;
	struct file___158 *file;
	struct sock___13 *sk;
	const struct proto_ops___12 *ops;
};

struct poll_table_struct___95;

struct kiocb___19;

struct proto_ops___12 {
	int family;
	struct module *owner;
	int (*release)(struct socket___13 *);
	int (*bind)(struct socket___13 *, struct sockaddr *, int);
	int (*connect)(struct socket___13 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___13 *, struct socket___13 *);
	int (*accept)(struct socket___13 *, struct socket___13 *, int);
	int (*getname)(struct socket___13 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___158 *, struct socket___13 *, struct poll_table_struct___95 *);
	int (*ioctl)(struct socket___13 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___13 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___13 *, int);
	int (*shutdown)(struct socket___13 *, int);
	int (*setsockopt)(struct socket___13 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___13 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___13 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___13 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___19 *, struct socket___13 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___19 *, struct socket___13 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___158 *, struct socket___13 *, struct vm_area_struct___165 *);
	ssize_t (*sendpage)(struct socket___13 *, struct page___157 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___13 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___13 *, int);
		struct {
			void (*set_peek_off)(struct sock___13 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___97)(struct file___158 *, wait_queue_head_t *, struct poll_table_struct___95 *);

struct poll_table_struct___95 {
	poll_queue_proc___97 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___19(struct kiocb___19 *, struct io_event *);

struct kiocb___19 {
	atomic_t ki_users;
	struct file___158 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___19 *ki_cancel;
	void (*ki_dtor)(struct kiocb___19 *);
	union {
		void *user;
		struct task_struct___160 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___25 {
	struct ctl_table_header___28 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___25 {
	struct mutex___161 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___25 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___28 *ctl;
};

struct netns_ipv4___25 {
	struct ctl_table_header___28 *forw_hdr;
	struct ctl_table_header___28 *frags_hdr;
	struct ctl_table_header___28 *ipv4_hdr;
	struct ctl_table_header___28 *route_hdr;
	struct ctl_table_header___28 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___13 *fibnl;
	struct sock___13 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___25 {
	struct ctl_table_header___28 *hdr;
	struct ctl_table_header___28 *route_hdr;
	struct ctl_table_header___28 *icmp_hdr;
	struct ctl_table_header___28 *frags_hdr;
	struct ctl_table_header___28 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___16;

struct neighbour___12;

struct dst_ops___26 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___26 *);
	struct dst_entry___12 * (*check)(struct dst_entry___12 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___12 *);
	unsigned int (*mtu)(const struct dst_entry___12 *);
	u32 * (*cow_metrics)(struct dst_entry___12 *, long unsigned int);
	void (*destroy)(struct dst_entry___12 *);
	void (*ifdown)(struct dst_entry___12 *, struct net_device___16 *, int);
	struct dst_entry___12 * (*negative_advice)(struct dst_entry___12 *);
	void (*link_failure)(struct sk_buff___18 *);
	void (*update_pmtu)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___18 *, u32);
	void (*redirect)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___18 *);
	int (*local_out)(struct sk_buff___18 *);
	struct neighbour___12 * (*neigh_lookup)(const struct dst_entry___12 *, struct sk_buff___18 *, const void *);
	struct kmem_cache___144 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___26 {
	struct netns_sysctl_ipv6___25 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___26 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___13 **icmp_sk;
	struct sock___13 *ndisc_sk;
	struct sock___13 *tcp_sk;
	struct sock___13 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___25 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___28 *sysctl_header;
	struct sock___13 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___12 {
	struct sock___13 *v4_ctl_sk;
	struct sock___13 *v6_ctl_sk;
};

struct netns_nf___25 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___28 *nf_log_dir_header;
};

struct nf_proto_net___25 {
	struct ctl_table_header___28 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___25 {
	struct nf_proto_net___25 pn;
	unsigned int timeout;
};

struct nf_tcp_net___25 {
	struct nf_proto_net___25 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___25 {
	struct nf_proto_net___25 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___25 {
	struct nf_proto_net___25 pn;
	unsigned int timeout;
};

struct nf_ip_net___25 {
	struct nf_generic_net___25 generic;
	struct nf_tcp_net___25 tcp;
	struct nf_udp_net___25 udp;
	struct nf_icmp_net___25 icmp;
	struct nf_icmp_net___25 icmpv6;
};

struct netns_ct___25 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___28 *sysctl_header;
	struct ctl_table_header___28 *acct_sysctl_header;
	struct ctl_table_header___28 *tstamp_sysctl_header;
	struct ctl_table_header___28 *event_sysctl_header;
	struct ctl_table_header___28 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___144 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___25 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___25 {
	struct netns_sysctl_ipv6___25 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___26 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___13 *nlsk;
	struct sock___13 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___28 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___26 xfrm4_dst_ops;
	struct dst_ops___26 xfrm6_dst_ops;
};

struct net___27 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___28 sysctls;
	struct sock___13 *rtnl;
	struct sock___13 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___16 *loopback_dev;
	struct netns_core___25 core;
	struct netns_mib___2 mib;
	struct netns_packet___25 packet;
	struct netns_unix___25 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___25 ipv4;
	struct netns_ipv6___26 ipv6;
	struct netns_sctp___25 sctp;
	struct netns_dccp___12 dccp;
	struct netns_nf___25 nf;
	struct netns_xt xt;
	struct netns_ct___25 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___25 nf_frag;
	struct sock___13 *nfnl;
	struct sock___13 *nfnl_stash;
	struct sk_buff_head___15 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___26 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___13 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___13 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___161 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___161 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___46 {
	void * (*alloc)(struct device___123 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___123 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___123 *, struct vm_area_struct___165 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___123 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___123 *, struct page___157 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___123 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___123 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___123 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___123 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___123 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___123 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___123 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___123 *, dma_addr_t);
	int (*dma_supported)(struct device___123 *, u64);
	int (*set_dma_mask)(struct device___123 *, u64);
	int is_phys;
};

struct bus_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___123 *, char *);
	ssize_t (*store)(struct bus_type___123 *, const char *, size_t);
};

struct device_attribute___123;

struct driver_attribute___123;

struct bus_type___123 {
	const char *name;
	const char *dev_name;
	struct device___123 *dev_root;
	struct bus_attribute___123 *bus_attrs;
	struct device_attribute___123 *dev_attrs;
	struct driver_attribute___123 *drv_attrs;
	const struct attribute_group___115 **bus_groups;
	const struct attribute_group___115 **dev_groups;
	const struct attribute_group___115 **drv_groups;
	int (*match)(struct device___123 *, struct device_driver___123 *);
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	int (*probe)(struct device___123 *);
	int (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*online)(struct device___123 *);
	int (*offline)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct device___123 *, struct device_attribute___123 *, char *);
	ssize_t (*store)(struct device___123 *, struct device_attribute___123 *, const char *, size_t);
};

struct driver_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___123 *, char *);
	ssize_t (*store)(struct device_driver___123 *, const char *, size_t);
};

struct device_driver___123 {
	const char *name;
	struct bus_type___123 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___123 *);
	int (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	const struct attribute_group___115 **groups;
	const struct dev_pm_ops___123 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___123 {
	const char *name;
	const struct attribute_group___115 **groups;
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
};

struct class_attribute___123;

struct class___123 {
	const char *name;
	struct module *owner;
	struct class_attribute___123 *class_attrs;
	struct device_attribute___123 *dev_attrs;
	const struct attribute_group___115 **dev_groups;
	struct bin_attribute___117 *dev_bin_attrs;
	struct kobject___15 *dev_kobj;
	int (*dev_uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *);
	void (*class_release)(struct class___123 *);
	void (*dev_release)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
	struct subsys_private *p;
};

struct class_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct class___123 *, struct class_attribute___123 *, char *);
	ssize_t (*store)(struct class___123 *, struct class_attribute___123 *, const char *, size_t);
	const void * (*namespace)(struct class___123 *, const struct class_attribute___123 *);
};

struct device_rh___123 {
	struct dev_pm_info_rh___123 power;
};

struct vm_fault___135 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___157 *page;
};

struct nf_bridge_info___14 {
	atomic_t use;
	unsigned int mask;
	struct net_device___16 *physindev;
	struct net_device___16 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___14(struct sk_buff___18 **);

struct net_device_ops___14;

struct ethtool_ops___14;

struct header_ops___14;

struct netdev_rx_queue___14;

struct netdev_queue___14;

struct rtnl_link_ops___12;

struct dcbnl_rtnl_ops___14;

struct net_device___16 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___14 *netdev_ops;
	const struct ethtool_ops___14 *ethtool_ops;
	const struct header_ops___14 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___15 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___14 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___14 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___14 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___14 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___14 = 0,
		NETREG_REGISTERED___14 = 1,
		NETREG_UNREGISTERING___14 = 2,
		NETREG_UNREGISTERED___14 = 3,
		NETREG_RELEASED___14 = 4,
		NETREG_DUMMY___14 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___14 = 0,
		RTNL_LINK_INITIALIZING___14 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___16 *);
	struct netpoll_info *npinfo;
	struct net___27 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___123 dev;
	const struct attribute_group___115 *sysfs_groups[4];
	const struct rtnl_link_ops___12 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___14 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___18 {
	struct sk_buff___18 *next;
	struct sk_buff___18 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___13 *sk;
	struct net_device___16 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___18 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___14 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct seq_operations___116;

struct seq_file___117 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___161 lock;
	const struct seq_operations___116 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct iattr___158 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___158 *ia_file;
};

struct request_sock_ops___10;

struct request_sock___10 {
	struct sock_common___12 __req_common;
	struct request_sock___10 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___10 *rsk_ops;
	struct sock___13 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___15 {
	struct sk_buff___18 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___18 *, struct netlink_callback___15 *);
	int (*done)(struct netlink_callback___15 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct irq_chip___111 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___111 *);
	void (*irq_shutdown)(struct irq_data___111 *);
	void (*irq_enable)(struct irq_data___111 *);
	void (*irq_disable)(struct irq_data___111 *);
	void (*irq_ack)(struct irq_data___111 *);
	void (*irq_mask)(struct irq_data___111 *);
	void (*irq_mask_ack)(struct irq_data___111 *);
	void (*irq_unmask)(struct irq_data___111 *);
	void (*irq_eoi)(struct irq_data___111 *);
	int (*irq_set_affinity)(struct irq_data___111 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___111 *);
	int (*irq_set_type)(struct irq_data___111 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___111 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___111 *);
	void (*irq_bus_sync_unlock)(struct irq_data___111 *);
	void (*irq_cpu_online)(struct irq_data___111 *);
	void (*irq_cpu_offline)(struct irq_data___111 *);
	void (*irq_suspend)(struct irq_data___111 *);
	void (*irq_resume)(struct irq_data___111 *);
	void (*irq_pm_shutdown)(struct irq_data___111 *);
	void (*irq_print_chip)(struct irq_data___111 *, struct seq_file___117 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___111 *, void *);
	long unsigned int flags;
};

struct file_operations___158 {
	struct module *owner;
	loff_t (*llseek)(struct file___158 *, loff_t, int);
	ssize_t (*read)(struct file___158 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___158 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___19 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___19 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___158 *, void *, filldir_t);
	unsigned int (*poll)(struct file___158 *, struct poll_table_struct___95 *);
	long int (*unlocked_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___158 *, struct vm_area_struct___165 *);
	int (*open)(struct inode___158 *, struct file___158 *);
	int (*flush)(struct file___158 *, fl_owner_t);
	int (*release)(struct inode___158 *, struct file___158 *);
	int (*fsync)(struct file___158 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___19 *, int);
	int (*fasync)(int, struct file___158 *, int);
	int (*lock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*sendpage)(struct file___158 *, struct page___157 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___158 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___158 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___158 *, long int, struct file_lock___158 **, void **);
		struct {
			int (*setlease)(struct file___158 *, long int, struct file_lock___158 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___158 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___117 *, struct file___158 *);
};

struct dev_pm_qos_request___18 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___123 *dev;
};

struct block_device___158 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___158 *bd_inode;
	struct super_block___158 *bd_super;
	struct mutex___161 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___158 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___161 bd_fsfreeze_mutex;
};

struct cgroup___103;

struct cgroup_subsys_state___103 {
	struct cgroup___103 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___158 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___161 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___158 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___158 {
	int qf_fmt_id;
	const struct quota_format_ops___158 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___158 *qf_next;
};

struct quota_format_ops___158 {
	int (*check_quota_file)(struct super_block___158 *, int);
	int (*read_file_info)(struct super_block___158 *, int);
	int (*write_file_info)(struct super_block___158 *, int);
	int (*free_file_info)(struct super_block___158 *, int);
	int (*read_dqblk)(struct dquot___158 *);
	int (*commit_dqblk)(struct dquot___158 *);
	int (*release_dqblk)(struct dquot___158 *);
};

struct dquot_operations___158 {
	int (*write_dquot)(struct dquot___158 *);
	struct dquot___158 * (*alloc_dquot)(struct super_block___158 *, int);
	void (*destroy_dquot)(struct dquot___158 *);
	int (*acquire_dquot)(struct dquot___158 *);
	int (*release_dquot)(struct dquot___158 *);
	int (*mark_dirty)(struct dquot___158 *);
	int (*write_info)(struct super_block___158 *, int);
	qsize_t * (*get_reserved_space)(struct inode___158 *);
};

struct quotactl_ops___158 {
	int (*quota_on)(struct super_block___158 *, int, int, struct path___158 *);
	int (*quota_on_meta)(struct super_block___158 *, int, int);
	int (*quota_off)(struct super_block___158 *, int);
	int (*quota_sync)(struct super_block___158 *, int);
	int (*get_info)(struct super_block___158 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___158 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___158 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___158 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___158 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___158 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___158 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___158 *, unsigned int);
};

struct address_space_operations___158 {
	int (*writepage)(struct page___157 *, struct writeback_control *);
	int (*readpage)(struct file___158 *, struct page___157 *);
	int (*writepages)(struct address_space___158 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___157 *);
	int (*readpages)(struct file___158 *, struct address_space___158 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___158 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___157 **, void **);
	int (*write_end)(struct file___158 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___157 *, void *);
	sector_t (*bmap)(struct address_space___158 *, sector_t);
	void (*invalidatepage)(struct page___157 *, long unsigned int);
	int (*releasepage)(struct page___157 *, gfp_t);
	void (*freepage)(struct page___157 *);
	ssize_t (*direct_IO)(int, struct kiocb___19 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___158 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___158 *, struct page___157 *, struct page___157 *, enum migrate_mode);
	int (*launder_page)(struct page___157 *);
	int (*is_partially_uptodate)(struct page___157 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___157 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___158 *, struct page___157 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___158 *, sector_t *);
	void (*swap_deactivate)(struct file___158 *);
	void (*invalidatepage_range)(struct page___157 *, unsigned int, unsigned int);
};

struct inode_operations___158 {
	struct dentry___158 * (*lookup)(struct inode___158 *, struct dentry___158 *, unsigned int);
	void * (*follow_link)(struct dentry___158 *, struct nameidata *);
	int (*permission)(struct inode___158 *, int);
	struct posix_acl * (*get_acl)(struct inode___158 *, int);
	int (*readlink)(struct dentry___158 *, char *, int);
	void (*put_link)(struct dentry___158 *, struct nameidata *, void *);
	int (*create)(struct inode___158 *, struct dentry___158 *, umode_t, bool);
	int (*link)(struct dentry___158 *, struct inode___158 *, struct dentry___158 *);
	int (*unlink)(struct inode___158 *, struct dentry___158 *);
	int (*symlink)(struct inode___158 *, struct dentry___158 *, const char *);
	int (*mkdir)(struct inode___158 *, struct dentry___158 *, umode_t);
	int (*rmdir)(struct inode___158 *, struct dentry___158 *);
	int (*mknod)(struct inode___158 *, struct dentry___158 *, umode_t, dev_t);
	int (*rename)(struct inode___158 *, struct dentry___158 *, struct inode___158 *, struct dentry___158 *);
	int (*setattr)(struct dentry___158 *, struct iattr___158 *);
	int (*getattr)(struct vfsmount *, struct dentry___158 *, struct kstat *);
	int (*setxattr)(struct dentry___158 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___158 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___158 *, char *, size_t);
	int (*removexattr)(struct dentry___158 *, const char *);
	int (*fiemap)(struct inode___158 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___158 *, struct timespec *, int);
	int (*atomic_open)(struct inode___158 *, struct dentry___158 *, struct file___158 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___158;

struct lock_manager_operations___158;

struct file_lock___158 {
	struct file_lock___158 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___158 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___158 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___158 *fl_ops;
	const struct lock_manager_operations___158 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___158 {
	void (*fl_copy_lock)(struct file_lock___158 *, struct file_lock___158 *);
	void (*fl_release_private)(struct file_lock___158 *);
};

struct lock_manager_operations___158 {
	int (*lm_compare_owner)(struct file_lock___158 *, struct file_lock___158 *);
	long unsigned int (*lm_owner_key)(struct file_lock___158 *);
	void (*lm_notify)(struct file_lock___158 *);
	int (*lm_grant)(struct file_lock___158 *, struct file_lock___158 *, int);
	void (*lm_break)(struct file_lock___158 *);
	int (*lm_change)(struct file_lock___158 **, int);
};

struct file_system_type___158 {
	const char *name;
	int fs_flags;
	struct dentry___158 * (*mount)(struct file_system_type___158 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___158 *);
	struct module *owner;
	struct file_system_type___158 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___158 {
	struct inode___158 * (*alloc_inode)(struct super_block___158 *);
	void (*destroy_inode)(struct inode___158 *);
	void (*dirty_inode)(struct inode___158 *, int);
	int (*write_inode)(struct inode___158 *, struct writeback_control *);
	int (*drop_inode)(struct inode___158 *);
	void (*evict_inode)(struct inode___158 *);
	void (*put_super)(struct super_block___158 *);
	int (*sync_fs)(struct super_block___158 *, int);
	int (*freeze_fs)(struct super_block___158 *);
	int (*unfreeze_fs)(struct super_block___158 *);
	int (*statfs)(struct dentry___158 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___158 *, int *, char *);
	void (*umount_begin)(struct super_block___158 *);
	int (*show_options)(struct seq_file___117 *, struct dentry___158 *);
	int (*show_devname)(struct seq_file___117 *, struct dentry___158 *);
	int (*show_path)(struct seq_file___117 *, struct dentry___158 *);
	int (*show_stats)(struct seq_file___117 *, struct dentry___158 *);
	ssize_t (*quota_read)(struct super_block___158 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___158 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___158 *);
	int (*bdev_try_to_free_page)(struct super_block___158 *, struct page___157 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___158 *);
	void (*free_cached_objects)(struct super_block___158 *, int);
};

struct xattr_handler___104 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___158 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___158 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___158 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___14 {
	int (*get_settings)(struct net_device___16 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___16 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___16 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___16 *);
	void (*get_regs)(struct net_device___16 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___16 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___16 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___16 *);
	void (*set_msglevel)(struct net_device___16 *, u32);
	int (*nway_reset)(struct net_device___16 *);
	u32 (*get_link)(struct net_device___16 *);
	int (*get_eeprom_len)(struct net_device___16 *);
	int (*get_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___16 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___16 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___16 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___16 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___16 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___16 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___16 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___16 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___16 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___16 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___16 *);
	void (*complete)(struct net_device___16 *);
	u32 (*get_priv_flags)(struct net_device___16 *);
	int (*set_priv_flags)(struct net_device___16 *, u32);
	int (*get_sset_count)(struct net_device___16 *, int);
	int (*get_rxnfc)(struct net_device___16 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___16 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___16 *, struct ethtool_flash *);
	int (*reset)(struct net_device___16 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___16 *);
	int (*get_rxfh_indir)(struct net_device___16 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___16 *, const u32 *);
	void (*get_channels)(struct net_device___16 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___16 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___16 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___16 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___16 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___16 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___16 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___16 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___16 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___16 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___16 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___16 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___12 {
	struct callback_head callback_head;
	struct dst_entry___12 *child;
	struct net_device___16 *dev;
	struct dst_ops___26 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___12 *path;
	struct dst_entry___12 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___18 *);
	union {
		int (*output)(struct sock___13 *, struct sk_buff___18 *);
		struct {
			int (*output)(struct sk_buff___18 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___12 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___12;

struct neigh_parms___12;

struct neigh_ops___12;

struct neighbour___12 {
	struct neighbour___12 *next;
	struct neigh_table___12 *tbl;
	struct neigh_parms___12 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___15 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___12 *, struct sk_buff___18 *);
	const struct neigh_ops___12 *ops;
	struct callback_head rcu;
	struct net_device___16 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___26 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___18 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___18 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___27 *, struct dst_entry___12 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___18 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___18 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___116 {
	void * (*start)(struct seq_file___117 *, loff_t *);
	void (*stop)(struct seq_file___117 *, void *);
	void * (*next)(struct seq_file___117 *, void *, loff_t *);
	int (*show)(struct seq_file___117 *, void *);
};

struct dcbnl_rtnl_ops___14 {
	int (*ieee_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___16 *);
	u8 (*setstate)(struct net_device___16 *, u8);
	void (*getpermhwaddr)(struct net_device___16 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___16 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___16 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___16 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___16 *, int, u8 *);
	void (*setpfccfg)(struct net_device___16 *, int, u8);
	void (*getpfccfg)(struct net_device___16 *, int, u8 *);
	u8 (*setall)(struct net_device___16 *);
	u8 (*getcap)(struct net_device___16 *, int, u8 *);
	int (*getnumtcs)(struct net_device___16 *, int, u8 *);
	int (*setnumtcs)(struct net_device___16 *, int, u8);
	u8 (*getpfcstate)(struct net_device___16 *);
	void (*setpfcstate)(struct net_device___16 *, u8);
	void (*getbcncfg)(struct net_device___16 *, int, u32 *);
	void (*setbcncfg)(struct net_device___16 *, int, u32);
	void (*getbcnrp)(struct net_device___16 *, int, u8 *);
	void (*setbcnrp)(struct net_device___16 *, int, u8);
	u8 (*setapp)(struct net_device___16 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___16 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___16 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___16 *, int, u8);
	u8 (*getdcbx)(struct net_device___16 *);
	u8 (*setdcbx)(struct net_device___16 *, u8);
	int (*peer_getappinfo)(struct net_device___16 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___16 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___16 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___16 *, struct cee_pfc *);
};

struct cgroupfs_root___103;

struct cgroup___103 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___103 *parent;
	struct dentry___158 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___103 *subsys[11];
	struct cgroupfs_root___103 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___161 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___103 {
	struct super_block___158 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___103 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___52 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___158 *, struct file___158 *);
	ssize_t (*read)(struct cgroup___103 *, struct cftype___52 *, struct file___158 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___103 *, struct cftype___52 *);
	s64 (*read_s64)(struct cgroup___103 *, struct cftype___52 *);
	int (*read_map)(struct cgroup___103 *, struct cftype___52 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___103 *, struct cftype___52 *, struct seq_file___117 *);
	ssize_t (*write)(struct cgroup___103 *, struct cftype___52 *, struct file___158 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___103 *, struct cftype___52 *, u64);
	int (*write_s64)(struct cgroup___103 *, struct cftype___52 *, s64);
	int (*write_string)(struct cgroup___103 *, struct cftype___52 *, const char *);
	int (*trigger)(struct cgroup___103 *, unsigned int);
	int (*release)(struct inode___158 *, struct file___158 *);
	int (*register_event)(struct cgroup___103 *, struct cftype___52 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___103 *, struct cftype___52 *, struct eventfd_ctx *);
};

struct cftype_set___50 {
	struct list_head node;
	struct cftype___52 *cfts;
};

struct task_and_cgroup___50 {
	struct task_struct___160 *task;
	struct cgroup___103 *cgrp;
	struct css_set___103 *cg;
};

struct cgroup_taskset___50 {
	struct task_and_cgroup___50 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___103 *cur_cgrp;
};

struct cgroup_subsys___50 {
	struct cgroup_subsys_state___103 * (*css_alloc)(struct cgroup___103 *);
	int (*css_online)(struct cgroup___103 *);
	void (*css_offline)(struct cgroup___103 *);
	void (*css_free)(struct cgroup___103 *);
	int (*can_attach)(struct cgroup___103 *, struct cgroup_taskset___50 *);
	void (*cancel_attach)(struct cgroup___103 *, struct cgroup_taskset___50 *);
	void (*attach)(struct cgroup___103 *, struct cgroup_taskset___50 *);
	void (*fork)(struct task_struct___160 *);
	void (*exit)(struct cgroup___103 *, struct cgroup___103 *, struct task_struct___160 *);
	void (*bind)(struct cgroup___103 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___103 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___52 *base_cftypes;
	struct cftype_set___50 base_cftset;
	struct module *module;
};

struct header_ops___14 {
	int (*create)(struct sk_buff___18 *, struct net_device___16 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___18 *, unsigned char *);
	int (*rebuild)(struct sk_buff___18 *);
	int (*cache)(const struct neighbour___12 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___16 *, const unsigned char *);
};

struct napi_struct___14 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___14 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___16 *dev;
	struct sk_buff___18 *gro_list;
	struct sk_buff___18 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___14 {
	struct net_device___16 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___15 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___14 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___15 kobj;
	struct net_device___16 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___14 {
	int (*ndo_init)(struct net_device___16 *);
	void (*ndo_uninit)(struct net_device___16 *);
	int (*ndo_open)(struct net_device___16 *);
	int (*ndo_stop)(struct net_device___16 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___18 *, struct net_device___16 *);
	u16 (*ndo_select_queue)(struct net_device___16 *, struct sk_buff___18 *);
	void (*ndo_change_rx_flags)(struct net_device___16 *, int);
	void (*ndo_set_rx_mode)(struct net_device___16 *);
	int (*ndo_set_mac_address)(struct net_device___16 *, void *);
	int (*ndo_validate_addr)(struct net_device___16 *);
	int (*ndo_do_ioctl)(struct net_device___16 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___16 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___16 *, int);
	int (*ndo_neigh_setup)(struct net_device___16 *, struct neigh_parms___12 *);
	void (*ndo_tx_timeout)(struct net_device___16 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___16 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___16 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___16 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___16 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___16 *);
	int (*ndo_netpoll_setup)(struct net_device___16 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___16 *);
	int (*ndo_busy_poll)(struct napi_struct___14 *);
	int (*ndo_set_vf_mac)(struct net_device___16 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___16 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___16 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___16 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___16 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___16 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___16 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___16 *, int, struct sk_buff___18 *);
	int (*ndo_setup_tc)(struct net_device___16 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___16 *);
	int (*ndo_fcoe_disable)(struct net_device___16 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___16 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___16 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___16 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___16 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___16 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___16 *, const struct sk_buff___18 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___16 *, struct net_device___16 *);
	int (*ndo_del_slave)(struct net_device___16 *, struct net_device___16 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___12 *);
	void (*ndo_neigh_destroy)(struct neighbour___12 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___18 *, struct netlink_callback___15 *, struct net_device___16 *, int);
	int (*ndo_bridge_setlink)(struct net_device___16 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___18 *, u32, u32, struct net_device___16 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___16 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___16 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___16 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___16 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___16 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___16 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___18 *, struct net_device___16 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___16 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___16 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___16 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___12 {
	struct net___27 *net;
	struct net_device___16 *dev;
	struct neigh_parms___12 *next;
	int (*neigh_setup)(struct neighbour___12 *);
	void (*neigh_cleanup)(struct neighbour___12 *);
	struct neigh_table___12 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___12 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___16 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___27 *, struct net_device___16 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___16 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___16 *, struct list_head *);
	size_t (*get_size)(const struct net_device___16 *);
	int (*fill_info)(struct sk_buff___18 *, const struct net_device___16 *);
	size_t (*get_xstats_size)(const struct net_device___16 *);
	int (*fill_xstats)(struct sk_buff___18 *, const struct net_device___16 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___27 * (*get_link_net)(const struct net_device___16 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___16 *, struct net_device___16 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___16 *, const struct net_device___16 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___18 *, const struct net_device___16 *, const struct net_device___16 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___13 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___18 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___12;

struct neigh_hash_table___12;

struct neigh_table___12 {
	struct neigh_table___12 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___16 *, __u32 *);
	int (*constructor)(struct neighbour___12 *);
	int (*pconstructor)(struct pneigh_entry___12 *);
	void (*pdestructor)(struct pneigh_entry___12 *);
	void (*proxy_redo)(struct sk_buff___18 *);
	char *id;
	struct neigh_parms___12 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___15 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___12 *nht;
	struct pneigh_entry___12 **phash_buckets;
};

struct neigh_ops___12 {
	int family;
	void (*solicit)(struct neighbour___12 *, struct sk_buff___18 *);
	void (*error_report)(struct neighbour___12 *, struct sk_buff___18 *);
	int (*output)(struct neighbour___12 *, struct sk_buff___18 *);
	int (*connected_output)(struct neighbour___12 *, struct sk_buff___18 *);
};

struct pneigh_entry___12 {
	struct pneigh_entry___12 *next;
	struct net___27 *net;
	struct net_device___16 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___12 {
	struct neighbour___12 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___12 {
	void (*close)(struct sock___13 *, long int);
	int (*connect)(struct sock___13 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___13 *, int);
	struct sock___13 * (*accept)(struct sock___13 *, int, int *);
	int (*ioctl)(struct sock___13 *, int, long unsigned int);
	int (*init)(struct sock___13 *);
	void (*destroy)(struct sock___13 *);
	void (*shutdown)(struct sock___13 *, int);
	int (*setsockopt)(struct sock___13 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___13 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___13 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___13 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___13 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___19 *, struct sock___13 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___19 *, struct sock___13 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___13 *, struct page___157 *, int, size_t, int);
	int (*bind)(struct sock___13 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___13 *, struct sk_buff___18 *);
	void (*release_cb)(struct sock___13 *);
	void (*mtu_reduced)(struct sock___13 *);
	void (*hash)(struct sock___13 *);
	void (*unhash)(struct sock___13 *);
	void (*rehash)(struct sock___13 *);
	int (*get_port)(struct sock___13 *, short unsigned int);
	void (*clear_sk)(struct sock___13 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___13 *);
	void (*enter_memory_pressure)(struct sock___13 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___144 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___10 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___50 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___12 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___12 {
	void (*enter_memory_pressure)(struct sock___13 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___10 {
	int family;
	int obj_size;
	struct kmem_cache___144 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___13 *, struct request_sock___10 *);
	void (*send_ack)(struct sock___13 *, struct sk_buff___18 *, struct request_sock___10 *);
	void (*send_reset)(struct sock___13 *, struct sk_buff___18 *);
	void (*destructor)(struct request_sock___10 *);
	void (*syn_ack_timeout)(struct sock___13 *, struct request_sock___10 *);
};

struct perm_datum {
	u32 value;
};

struct filename_trans {
	u32 stype;
	u32 ttype;
	u16 tclass;
	const char *name;
};

struct filename_trans_datum {
	u32 otype;
};

struct type_datum {
	u32 value;
	u32 bounds;
	unsigned char primary;
	unsigned char attribute;
};

struct level_datum {
	struct mls_level *level;
	unsigned char isalias;
};

struct cat_datum {
	u32 value;
	unsigned char isalias;
};

struct range_trans {
	u32 source_type;
	u32 target_type;
	u32 target_class;
};

struct cond_expr;

struct cond_av_list;

struct cond_node {
	int cur_state;
	struct cond_expr *expr;
	struct cond_av_list *true_list;
	struct cond_av_list *false_list;
	struct cond_node *next;
};

struct policy_data {
	struct policydb *p;
	void *fp;
};

struct cond_expr {
	__u32 expr_type;
	__u32 bool;
	struct cond_expr *next;
};

struct cond_av_list {
	struct avtab_node *node;
	struct cond_av_list *next;
};

struct policydb_compat_info {
	int version;
	int sym_num;
	int ocon_num;
};

struct page___158;

typedef struct page___158 *pgtable_t___158;

struct address_space___159;

struct kmem_cache___145;

struct page___158 {
	long unsigned int flags;
	struct address_space___159 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___158 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___158 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___145 *slab_cache;
		struct page___158 *first_page;
	};
	long: 64;
};

struct task_struct___161;

struct pv_cpu_ops___161 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___161 *);
	void (*end_context_switch)(struct task_struct___161 *);
};

struct mutex___162 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___161 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___154 {
	struct page___158 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___166;

struct nsproxy___96;

struct signal_struct___161;

struct css_set___104;

struct task_struct___161 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___161 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___166 *mm;
	struct mm_struct___166 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___161 *real_parent;
	struct task_struct___161 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___161 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___161 = 0,
		VTIME_USER___161 = 1,
		VTIME_SYS___161 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___96 *nsproxy;
	struct signal_struct___161 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___104 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___162 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___154 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___166 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___166 *, struct mm_struct___166 *);
	void (*dup_mmap)(struct mm_struct___166 *, struct mm_struct___166 *);
	void (*exit_mmap)(struct mm_struct___166 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___166 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___166 *);
	void (*pgd_free)(struct mm_struct___166 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___166 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___166 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___166 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___166 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___166 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___166 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___166 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___166 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___166 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___166 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___166 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___162 lock;
	void *vdso;
} mm_context_t___162;

struct xol_area___158;

struct uprobes_state___158 {
	struct xol_area___158 *xol_area;
};

struct vm_area_struct___166;

struct file___159;

struct linux_binfmt___27;

struct core_state___161;

struct mm_struct___166 {
	struct vm_area_struct___166 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___166 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___166 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt___27 *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___162 context;
	long unsigned int flags;
	struct core_state___161 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___161 *owner;
	struct file___159 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___158 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___161;

struct lruvec___161 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___161 *zone;
};

struct pglist_data___161;

struct zone___161 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___161 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___161 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___161 {
	struct zone___161 *zone;
	int zone_idx;
};

struct zonelist___161 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___161 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___161 {
	struct zone___161 node_zones[4];
	struct zonelist___161 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___161 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___112;

struct x86_io_apic_ops___112 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___112 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___112;

struct irq_data___112 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___112 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___124;

struct dev_pm_ops___124 {
	int (*prepare)(struct device___124 *);
	void (*complete)(struct device___124 *);
	int (*suspend)(struct device___124 *);
	int (*resume)(struct device___124 *);
	int (*freeze)(struct device___124 *);
	int (*thaw)(struct device___124 *);
	int (*poweroff)(struct device___124 *);
	int (*restore)(struct device___124 *);
	int (*suspend_late)(struct device___124 *);
	int (*resume_early)(struct device___124 *);
	int (*freeze_late)(struct device___124 *);
	int (*thaw_early)(struct device___124 *);
	int (*poweroff_late)(struct device___124 *);
	int (*restore_early)(struct device___124 *);
	int (*suspend_noirq)(struct device___124 *);
	int (*resume_noirq)(struct device___124 *);
	int (*freeze_noirq)(struct device___124 *);
	int (*thaw_noirq)(struct device___124 *);
	int (*poweroff_noirq)(struct device___124 *);
	int (*restore_noirq)(struct device___124 *);
	int (*runtime_suspend)(struct device___124 *);
	int (*runtime_resume)(struct device___124 *);
	int (*runtime_idle)(struct device___124 *);
};

struct kset___16;

struct kobj_type___16;

struct kobject___16 {
	const char *name;
	struct list_head entry;
	struct kobject___16 *parent;
	struct kset___16 *kset;
	struct kobj_type___16 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___19;

struct dev_pm_info___19 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___19 *qos;
};

struct dma_map_ops___47;

struct dev_archdata___47 {
	struct dma_map_ops___47 *dma_ops;
	void *iommu;
};

struct device_type___124;

struct bus_type___124;

struct device_driver___124;

struct dev_pm_domain___124;

struct class___124;

struct attribute_group___116;

struct device_rh___124;

struct device___124 {
	struct device___124 *parent;
	struct device_private *p;
	struct kobject___16 kobj;
	const char *init_name;
	const struct device_type___124 *type;
	struct mutex___162 mutex;
	struct bus_type___124 *bus;
	struct device_driver___124 *driver;
	void *platform_data;
	struct dev_pm_info___19 power;
	struct dev_pm_domain___124 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___47 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___124 *class;
	const struct attribute_group___116 **groups;
	void (*release)(struct device___124 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___124 *device_rh;
};

struct dev_pm_qos_request___19;

struct dev_pm_qos___19 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___19 *latency_req;
	struct dev_pm_qos_request___19 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___19 *latency_tolerance_req;
};

struct dev_pm_info_rh___124 {
	void (*set_latency_tolerance)(struct device___124 *, s32);
};

struct dev_pm_domain___124 {
	struct dev_pm_ops___124 ops;
};

struct smp_ops___161 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___161 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___14;

struct kobj_ns_type_operations___13 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___14 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___13;

struct net___28;

struct sock_common___13 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___13 *skc_prot;
	struct net___28 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___19;

struct sk_buff_head___16 {
	struct sk_buff___19 *next;
	struct sk_buff___19 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___14;

struct socket_wq___13;

struct dst_entry___13;

struct socket___14;

struct cg_proto___13;

struct sock___14 {
	struct sock_common___13 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___16 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___19 *head;
		struct sk_buff___19 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___14 *sk_filter;
	struct socket_wq___13 *sk_wq;
	struct sk_buff_head___16 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___13 *sk_rx_dst;
	struct dst_entry___13 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___16 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___16 sk_error_queue;
	struct proto___13 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___14 *sk_socket;
	void *sk_user_data;
	struct page_frag___154 sk_frag;
	struct sk_buff___19 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___13 *sk_cgrp;
	void (*sk_state_change)(struct sock___14 *);
	void (*sk_data_ready)(struct sock___14 *, int);
	void (*sk_write_space)(struct sock___14 *);
	void (*sk_error_report)(struct sock___14 *);
	int (*sk_backlog_rcv)(struct sock___14 *, struct sk_buff___19 *);
	void (*sk_destruct)(struct sock___14 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___118;

struct attribute_group___116 {
	const char *name;
	umode_t (*is_visible)(struct kobject___16 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___118 **bin_attrs;
};

struct bin_attribute___118 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___159 *, struct kobject___16 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___159 *, struct kobject___16 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	int (*mmap)(struct file___159 *, struct kobject___16 *, struct bin_attribute___118 *, struct vm_area_struct___166 *);
};

struct dentry___159;

struct path___159 {
	struct vfsmount *mnt;
	struct dentry___159 *dentry;
};

struct inode___159;

struct file_operations___159;

struct file___159 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___159 f_path;
	struct inode___159 *f_inode;
	const struct file_operations___159 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___159 *f_mapping;
	struct mutex___162 f_pos_lock;
};

struct vm_operations_struct___139;

struct vm_area_struct___166 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___166 *vm_next;
	struct vm_area_struct___166 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___166 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___139 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___159 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___16 {
	ssize_t (*show)(struct kobject___16 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___16 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___16 *, const struct attribute *);
};

struct kset_uevent_ops___16;

struct kset___16 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___16 kobj;
	const struct kset_uevent_ops___16 *uevent_ops;
};

struct kobj_type___16 {
	void (*release)(struct kobject___16 *);
	const struct sysfs_ops___16 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___16 *);
	const void * (*namespace)(struct kobject___16 *);
};

struct kset_uevent_ops___16 {
	int (* const filter)(struct kset___16 *, struct kobject___16 *);
	const char * (* const name)(struct kset___16 *, struct kobject___16 *);
	int (* const uevent)(struct kset___16 *, struct kobject___16 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___144 {
	void **freelist;
	long unsigned int tid;
	struct page___158 *page;
	struct page___158 *partial;
};

struct memcg_cache_params___145;

struct kmem_cache___145 {
	struct kmem_cache_cpu___144 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___16 kobj;
	struct memcg_cache_params___145 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___145 {
	bool is_root_cache;
	union {
		struct kmem_cache___145 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___145 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___158 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___158 *page;
	long unsigned int vaddr;
};

struct address_space_operations___159;

struct address_space___159 {
	struct inode___159 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___162 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___159 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___136;

struct vm_operations_struct___139 {
	void (*open)(struct vm_area_struct___166 *);
	void (*close)(struct vm_area_struct___166 *);
	int (*fault)(struct vm_area_struct___166 *, struct vm_fault___136 *);
	int (*page_mkwrite)(struct vm_area_struct___166 *, struct vm_fault___136 *);
	int (*access)(struct vm_area_struct___166 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___166 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___166 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___166 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___166 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___161 {
	struct task_struct___161 *task;
	struct core_thread___161 *next;
};

struct core_state___161 {
	atomic_t nr_threads;
	struct core_thread___161 dumper;
	struct completion startup;
};

struct linux_binprm___28;

struct coredump_params___27;

struct linux_binfmt___27 {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm___28 *);
	int (*load_shlib)(struct file___159 *);
	int (*core_dump)(struct coredump_params___27 *);
	long unsigned int min_coredump;
};

struct ctl_table_header___29;

struct ctl_node___29 {
	struct rb_node node;
	struct ctl_table_header___29 *header;
};

struct ctl_table_root___29;

struct ctl_table_set___29;

struct ctl_dir___29;

struct ctl_table_header___29 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___29 *root;
	struct ctl_table_set___29 *set;
	struct ctl_dir___29 *parent;
	struct ctl_node___29 *node;
};

struct ctl_dir___29 {
	struct ctl_table_header___29 header;
	struct rb_root root;
};

struct ctl_table_set___29 {
	int (*is_seen)(struct ctl_table_set___29 *);
	struct ctl_dir___29 dir;
};

struct ctl_table_root___29 {
	struct ctl_table_set___29 default_set;
	struct ctl_table_set___29 * (*lookup)(struct ctl_table_root___29 *, struct nsproxy___96 *);
	int (*permissions)(struct ctl_table_header___29 *, struct ctl_table *);
};

struct nsproxy___96 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___28 *net_ns;
};

struct signal_struct___161 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___161 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___161 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___162 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___104;

struct css_set___104 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___104 *subsys[11];
	struct callback_head callback_head;
};

struct fasync_struct___159;

struct socket_wq___13 {
	wait_queue_head_t wait;
	struct fasync_struct___159 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___159 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___159 *fa_next;
	struct file___159 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___13;

struct socket___14 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___13 *wq;
	struct file___159 *file;
	struct sock___14 *sk;
	const struct proto_ops___13 *ops;
};

struct poll_table_struct___96;

struct kiocb___20;

struct proto_ops___13 {
	int family;
	struct module *owner;
	int (*release)(struct socket___14 *);
	int (*bind)(struct socket___14 *, struct sockaddr *, int);
	int (*connect)(struct socket___14 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___14 *, struct socket___14 *);
	int (*accept)(struct socket___14 *, struct socket___14 *, int);
	int (*getname)(struct socket___14 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___159 *, struct socket___14 *, struct poll_table_struct___96 *);
	int (*ioctl)(struct socket___14 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___14 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___14 *, int);
	int (*shutdown)(struct socket___14 *, int);
	int (*setsockopt)(struct socket___14 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___14 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___14 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___14 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___20 *, struct socket___14 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___20 *, struct socket___14 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___159 *, struct socket___14 *, struct vm_area_struct___166 *);
	ssize_t (*sendpage)(struct socket___14 *, struct page___158 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___14 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___14 *, int);
		struct {
			void (*set_peek_off)(struct sock___14 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___98)(struct file___159 *, wait_queue_head_t *, struct poll_table_struct___96 *);

struct poll_table_struct___96 {
	poll_queue_proc___98 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___20(struct kiocb___20 *, struct io_event *);

struct kiocb___20 {
	atomic_t ki_users;
	struct file___159 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___20 *ki_cancel;
	void (*ki_dtor)(struct kiocb___20 *);
	union {
		void *user;
		struct task_struct___161 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___26 {
	struct ctl_table_header___29 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___26 {
	struct mutex___162 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___26 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___29 *ctl;
};

struct netns_ipv4___26 {
	struct ctl_table_header___29 *forw_hdr;
	struct ctl_table_header___29 *frags_hdr;
	struct ctl_table_header___29 *ipv4_hdr;
	struct ctl_table_header___29 *route_hdr;
	struct ctl_table_header___29 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___14 *fibnl;
	struct sock___14 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___26 {
	struct ctl_table_header___29 *hdr;
	struct ctl_table_header___29 *route_hdr;
	struct ctl_table_header___29 *icmp_hdr;
	struct ctl_table_header___29 *frags_hdr;
	struct ctl_table_header___29 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___17;

struct neighbour___13;

struct dst_ops___27 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___27 *);
	struct dst_entry___13 * (*check)(struct dst_entry___13 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___13 *);
	unsigned int (*mtu)(const struct dst_entry___13 *);
	u32 * (*cow_metrics)(struct dst_entry___13 *, long unsigned int);
	void (*destroy)(struct dst_entry___13 *);
	void (*ifdown)(struct dst_entry___13 *, struct net_device___17 *, int);
	struct dst_entry___13 * (*negative_advice)(struct dst_entry___13 *);
	void (*link_failure)(struct sk_buff___19 *);
	void (*update_pmtu)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___19 *, u32);
	void (*redirect)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___19 *);
	int (*local_out)(struct sk_buff___19 *);
	struct neighbour___13 * (*neigh_lookup)(const struct dst_entry___13 *, struct sk_buff___19 *, const void *);
	struct kmem_cache___145 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___27 {
	struct netns_sysctl_ipv6___26 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___27 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___14 **icmp_sk;
	struct sock___14 *ndisc_sk;
	struct sock___14 *tcp_sk;
	struct sock___14 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___26 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___29 *sysctl_header;
	struct sock___14 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___13 {
	struct sock___14 *v4_ctl_sk;
	struct sock___14 *v6_ctl_sk;
};

struct netns_nf___26 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___29 *nf_log_dir_header;
};

struct nf_proto_net___26 {
	struct ctl_table_header___29 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___26 {
	struct nf_proto_net___26 pn;
	unsigned int timeout;
};

struct nf_tcp_net___26 {
	struct nf_proto_net___26 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___26 {
	struct nf_proto_net___26 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___26 {
	struct nf_proto_net___26 pn;
	unsigned int timeout;
};

struct nf_ip_net___26 {
	struct nf_generic_net___26 generic;
	struct nf_tcp_net___26 tcp;
	struct nf_udp_net___26 udp;
	struct nf_icmp_net___26 icmp;
	struct nf_icmp_net___26 icmpv6;
};

struct netns_ct___26 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___29 *sysctl_header;
	struct ctl_table_header___29 *acct_sysctl_header;
	struct ctl_table_header___29 *tstamp_sysctl_header;
	struct ctl_table_header___29 *event_sysctl_header;
	struct ctl_table_header___29 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___145 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___26 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___26 {
	struct netns_sysctl_ipv6___26 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___27 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___14 *nlsk;
	struct sock___14 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___29 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___27 xfrm4_dst_ops;
	struct dst_ops___27 xfrm6_dst_ops;
};

struct net___28 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___29 sysctls;
	struct sock___14 *rtnl;
	struct sock___14 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___17 *loopback_dev;
	struct netns_core___26 core;
	struct netns_mib___2 mib;
	struct netns_packet___26 packet;
	struct netns_unix___26 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___26 ipv4;
	struct netns_ipv6___27 ipv6;
	struct netns_sctp___26 sctp;
	struct netns_dccp___13 dccp;
	struct netns_nf___26 nf;
	struct netns_xt xt;
	struct netns_ct___26 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___26 nf_frag;
	struct sock___14 *nfnl;
	struct sock___14 *nfnl_stash;
	struct sk_buff_head___16 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___27 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___14 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___14 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___162 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___162 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___47 {
	void * (*alloc)(struct device___124 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___124 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___124 *, struct vm_area_struct___166 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___124 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___124 *, struct page___158 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___124 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___124 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___124 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___124 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___124 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___124 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___124 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___124 *, dma_addr_t);
	int (*dma_supported)(struct device___124 *, u64);
	int (*set_dma_mask)(struct device___124 *, u64);
	int is_phys;
};

struct bus_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___124 *, char *);
	ssize_t (*store)(struct bus_type___124 *, const char *, size_t);
};

struct device_attribute___124;

struct driver_attribute___124;

struct bus_type___124 {
	const char *name;
	const char *dev_name;
	struct device___124 *dev_root;
	struct bus_attribute___124 *bus_attrs;
	struct device_attribute___124 *dev_attrs;
	struct driver_attribute___124 *drv_attrs;
	const struct attribute_group___116 **bus_groups;
	const struct attribute_group___116 **dev_groups;
	const struct attribute_group___116 **drv_groups;
	int (*match)(struct device___124 *, struct device_driver___124 *);
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	int (*probe)(struct device___124 *);
	int (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*online)(struct device___124 *);
	int (*offline)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct device___124 *, struct device_attribute___124 *, char *);
	ssize_t (*store)(struct device___124 *, struct device_attribute___124 *, const char *, size_t);
};

struct driver_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___124 *, char *);
	ssize_t (*store)(struct device_driver___124 *, const char *, size_t);
};

struct device_driver___124 {
	const char *name;
	struct bus_type___124 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___124 *);
	int (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	const struct attribute_group___116 **groups;
	const struct dev_pm_ops___124 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___124 {
	const char *name;
	const struct attribute_group___116 **groups;
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
};

struct class_attribute___124;

struct class___124 {
	const char *name;
	struct module *owner;
	struct class_attribute___124 *class_attrs;
	struct device_attribute___124 *dev_attrs;
	const struct attribute_group___116 **dev_groups;
	struct bin_attribute___118 *dev_bin_attrs;
	struct kobject___16 *dev_kobj;
	int (*dev_uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *);
	void (*class_release)(struct class___124 *);
	void (*dev_release)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
	struct subsys_private *p;
};

struct class_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct class___124 *, struct class_attribute___124 *, char *);
	ssize_t (*store)(struct class___124 *, struct class_attribute___124 *, const char *, size_t);
	const void * (*namespace)(struct class___124 *, const struct class_attribute___124 *);
};

struct device_rh___124 {
	struct dev_pm_info_rh___124 power;
};

struct vm_fault___136 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___158 *page;
};

struct nf_bridge_info___15 {
	atomic_t use;
	unsigned int mask;
	struct net_device___17 *physindev;
	struct net_device___17 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___15(struct sk_buff___19 **);

struct net_device_ops___15;

struct ethtool_ops___15;

struct header_ops___15;

struct netdev_rx_queue___15;

struct netdev_queue___15;

struct rtnl_link_ops___13;

struct dcbnl_rtnl_ops___15;

struct net_device___17 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___15 *netdev_ops;
	const struct ethtool_ops___15 *ethtool_ops;
	const struct header_ops___15 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___16 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___15 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___15 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___15 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___15 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___15 = 0,
		NETREG_REGISTERED___15 = 1,
		NETREG_UNREGISTERING___15 = 2,
		NETREG_UNREGISTERED___15 = 3,
		NETREG_RELEASED___15 = 4,
		NETREG_DUMMY___15 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___15 = 0,
		RTNL_LINK_INITIALIZING___15 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___17 *);
	struct netpoll_info *npinfo;
	struct net___28 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___124 dev;
	const struct attribute_group___116 *sysfs_groups[4];
	const struct rtnl_link_ops___13 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___15 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___19 {
	struct sk_buff___19 *next;
	struct sk_buff___19 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___14 *sk;
	struct net_device___17 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___19 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___15 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct inode_operations___159;

struct super_block___159;

struct file_lock___159;

struct dquot___159;

struct block_device___159;

struct inode___159 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___159 *i_op;
	struct super_block___159 *i_sb;
	struct address_space___159 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___162 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___159 *i_fop;
	struct file_lock___159 *i_flock;
	struct address_space___159 i_data;
	struct dquot___159 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___159 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___159;

struct mem_dqinfo___159 {
	struct quota_format_type___159 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___159;

struct quota_info___159 {
	unsigned int flags;
	struct mutex___162 dqio_mutex;
	struct mutex___162 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___159 *files[2];
	struct mem_dqinfo___159 info[2];
	const struct quota_format_ops___159 *ops[2];
};

struct file_system_type___159;

struct super_operations___159;

struct dquot_operations___159;

struct quotactl_ops___159;

struct xattr_handler___105;

struct dentry_operations___159;

struct super_block___159 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___159 *s_type;
	const struct super_operations___159 *s_op;
	const struct dquot_operations___159 *dq_op;
	const struct quotactl_ops___159 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___159 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___105 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___159 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___159 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___162 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___159 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___159 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___159 *d_parent;
	struct qstr d_name;
	struct inode___159 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___159 *d_op;
	struct super_block___159 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct linux_binprm___28 {
	char buf[128];
	struct vm_area_struct___166 *vma;
	long unsigned int vma_pages;
	struct mm_struct___166 *mm;
	long unsigned int p;
	unsigned int cred_prepared: 1;
	unsigned int cap_effective: 1;
	unsigned int recursion_depth;
	struct file___159 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	char tcomm[16];
};

struct seq_operations___117;

struct seq_file___118 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___162 lock;
	const struct seq_operations___117 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct iattr___159 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___159 *ia_file;
};

struct request_sock___11 {
	struct sock_common___13 __req_common;
	struct request_sock___11 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___4 *rsk_ops;
	struct sock___14 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___16 {
	struct sk_buff___19 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___19 *, struct netlink_callback___16 *);
	int (*done)(struct netlink_callback___16 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct irq_chip___112 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___112 *);
	void (*irq_shutdown)(struct irq_data___112 *);
	void (*irq_enable)(struct irq_data___112 *);
	void (*irq_disable)(struct irq_data___112 *);
	void (*irq_ack)(struct irq_data___112 *);
	void (*irq_mask)(struct irq_data___112 *);
	void (*irq_mask_ack)(struct irq_data___112 *);
	void (*irq_unmask)(struct irq_data___112 *);
	void (*irq_eoi)(struct irq_data___112 *);
	int (*irq_set_affinity)(struct irq_data___112 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___112 *);
	int (*irq_set_type)(struct irq_data___112 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___112 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___112 *);
	void (*irq_bus_sync_unlock)(struct irq_data___112 *);
	void (*irq_cpu_online)(struct irq_data___112 *);
	void (*irq_cpu_offline)(struct irq_data___112 *);
	void (*irq_suspend)(struct irq_data___112 *);
	void (*irq_resume)(struct irq_data___112 *);
	void (*irq_pm_shutdown)(struct irq_data___112 *);
	void (*irq_print_chip)(struct irq_data___112 *, struct seq_file___118 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___112 *, void *);
	long unsigned int flags;
};

struct file_operations___159 {
	struct module *owner;
	loff_t (*llseek)(struct file___159 *, loff_t, int);
	ssize_t (*read)(struct file___159 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___159 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___20 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___20 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___159 *, void *, filldir_t);
	unsigned int (*poll)(struct file___159 *, struct poll_table_struct___96 *);
	long int (*unlocked_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___159 *, struct vm_area_struct___166 *);
	int (*open)(struct inode___159 *, struct file___159 *);
	int (*flush)(struct file___159 *, fl_owner_t);
	int (*release)(struct inode___159 *, struct file___159 *);
	int (*fsync)(struct file___159 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___20 *, int);
	int (*fasync)(int, struct file___159 *, int);
	int (*lock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*sendpage)(struct file___159 *, struct page___158 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___159 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___159 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___159 *, long int, struct file_lock___159 **, void **);
		struct {
			int (*setlease)(struct file___159 *, long int, struct file_lock___159 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___159 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___118 *, struct file___159 *);
};

struct dev_pm_qos_request___19 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___124 *dev;
};

struct dentry_operations___159 {
	int (*d_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_hash)(const struct dentry___159 *, struct qstr *);
	int (*d_compare)(const struct dentry___159 *, const struct dentry___159 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___159 *);
	void (*d_release)(struct dentry___159 *);
	void (*d_prune)(struct dentry___159 *);
	void (*d_iput)(struct dentry___159 *, struct inode___159 *);
	char * (*d_dname)(struct dentry___159 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___159 *);
	int (*d_manage)(struct dentry___159 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___159 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___159 *bd_inode;
	struct super_block___159 *bd_super;
	struct mutex___162 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___159 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___162 bd_fsfreeze_mutex;
};

struct cgroup___104;

struct cgroup_subsys_state___104 {
	struct cgroup___104 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___159 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___162 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___159 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___159 {
	int qf_fmt_id;
	const struct quota_format_ops___159 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___159 *qf_next;
};

struct quota_format_ops___159 {
	int (*check_quota_file)(struct super_block___159 *, int);
	int (*read_file_info)(struct super_block___159 *, int);
	int (*write_file_info)(struct super_block___159 *, int);
	int (*free_file_info)(struct super_block___159 *, int);
	int (*read_dqblk)(struct dquot___159 *);
	int (*commit_dqblk)(struct dquot___159 *);
	int (*release_dqblk)(struct dquot___159 *);
};

struct dquot_operations___159 {
	int (*write_dquot)(struct dquot___159 *);
	struct dquot___159 * (*alloc_dquot)(struct super_block___159 *, int);
	void (*destroy_dquot)(struct dquot___159 *);
	int (*acquire_dquot)(struct dquot___159 *);
	int (*release_dquot)(struct dquot___159 *);
	int (*mark_dirty)(struct dquot___159 *);
	int (*write_info)(struct super_block___159 *, int);
	qsize_t * (*get_reserved_space)(struct inode___159 *);
};

struct quotactl_ops___159 {
	int (*quota_on)(struct super_block___159 *, int, int, struct path___159 *);
	int (*quota_on_meta)(struct super_block___159 *, int, int);
	int (*quota_off)(struct super_block___159 *, int);
	int (*quota_sync)(struct super_block___159 *, int);
	int (*get_info)(struct super_block___159 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___159 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___159 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___159 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___159 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___159 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___159 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___159 *, unsigned int);
};

struct address_space_operations___159 {
	int (*writepage)(struct page___158 *, struct writeback_control *);
	int (*readpage)(struct file___159 *, struct page___158 *);
	int (*writepages)(struct address_space___159 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___158 *);
	int (*readpages)(struct file___159 *, struct address_space___159 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___159 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___158 **, void **);
	int (*write_end)(struct file___159 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___158 *, void *);
	sector_t (*bmap)(struct address_space___159 *, sector_t);
	void (*invalidatepage)(struct page___158 *, long unsigned int);
	int (*releasepage)(struct page___158 *, gfp_t);
	void (*freepage)(struct page___158 *);
	ssize_t (*direct_IO)(int, struct kiocb___20 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___159 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___159 *, struct page___158 *, struct page___158 *, enum migrate_mode);
	int (*launder_page)(struct page___158 *);
	int (*is_partially_uptodate)(struct page___158 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___158 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___159 *, struct page___158 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___159 *, sector_t *);
	void (*swap_deactivate)(struct file___159 *);
	void (*invalidatepage_range)(struct page___158 *, unsigned int, unsigned int);
};

struct inode_operations___159 {
	struct dentry___159 * (*lookup)(struct inode___159 *, struct dentry___159 *, unsigned int);
	void * (*follow_link)(struct dentry___159 *, struct nameidata *);
	int (*permission)(struct inode___159 *, int);
	struct posix_acl * (*get_acl)(struct inode___159 *, int);
	int (*readlink)(struct dentry___159 *, char *, int);
	void (*put_link)(struct dentry___159 *, struct nameidata *, void *);
	int (*create)(struct inode___159 *, struct dentry___159 *, umode_t, bool);
	int (*link)(struct dentry___159 *, struct inode___159 *, struct dentry___159 *);
	int (*unlink)(struct inode___159 *, struct dentry___159 *);
	int (*symlink)(struct inode___159 *, struct dentry___159 *, const char *);
	int (*mkdir)(struct inode___159 *, struct dentry___159 *, umode_t);
	int (*rmdir)(struct inode___159 *, struct dentry___159 *);
	int (*mknod)(struct inode___159 *, struct dentry___159 *, umode_t, dev_t);
	int (*rename)(struct inode___159 *, struct dentry___159 *, struct inode___159 *, struct dentry___159 *);
	int (*setattr)(struct dentry___159 *, struct iattr___159 *);
	int (*getattr)(struct vfsmount *, struct dentry___159 *, struct kstat *);
	int (*setxattr)(struct dentry___159 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___159 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___159 *, char *, size_t);
	int (*removexattr)(struct dentry___159 *, const char *);
	int (*fiemap)(struct inode___159 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___159 *, struct timespec *, int);
	int (*atomic_open)(struct inode___159 *, struct dentry___159 *, struct file___159 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___159;

struct lock_manager_operations___159;

struct file_lock___159 {
	struct file_lock___159 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___159 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___159 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___159 *fl_ops;
	const struct lock_manager_operations___159 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___159 {
	void (*fl_copy_lock)(struct file_lock___159 *, struct file_lock___159 *);
	void (*fl_release_private)(struct file_lock___159 *);
};

struct lock_manager_operations___159 {
	int (*lm_compare_owner)(struct file_lock___159 *, struct file_lock___159 *);
	long unsigned int (*lm_owner_key)(struct file_lock___159 *);
	void (*lm_notify)(struct file_lock___159 *);
	int (*lm_grant)(struct file_lock___159 *, struct file_lock___159 *, int);
	void (*lm_break)(struct file_lock___159 *);
	int (*lm_change)(struct file_lock___159 **, int);
};

struct file_system_type___159 {
	const char *name;
	int fs_flags;
	struct dentry___159 * (*mount)(struct file_system_type___159 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___159 *);
	struct module *owner;
	struct file_system_type___159 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___159 {
	struct inode___159 * (*alloc_inode)(struct super_block___159 *);
	void (*destroy_inode)(struct inode___159 *);
	void (*dirty_inode)(struct inode___159 *, int);
	int (*write_inode)(struct inode___159 *, struct writeback_control *);
	int (*drop_inode)(struct inode___159 *);
	void (*evict_inode)(struct inode___159 *);
	void (*put_super)(struct super_block___159 *);
	int (*sync_fs)(struct super_block___159 *, int);
	int (*freeze_fs)(struct super_block___159 *);
	int (*unfreeze_fs)(struct super_block___159 *);
	int (*statfs)(struct dentry___159 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___159 *, int *, char *);
	void (*umount_begin)(struct super_block___159 *);
	int (*show_options)(struct seq_file___118 *, struct dentry___159 *);
	int (*show_devname)(struct seq_file___118 *, struct dentry___159 *);
	int (*show_path)(struct seq_file___118 *, struct dentry___159 *);
	int (*show_stats)(struct seq_file___118 *, struct dentry___159 *);
	ssize_t (*quota_read)(struct super_block___159 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___159 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___159 *);
	int (*bdev_try_to_free_page)(struct super_block___159 *, struct page___158 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___159 *);
	void (*free_cached_objects)(struct super_block___159 *, int);
};

struct xattr_handler___105 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___159 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___159 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___159 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___15 {
	int (*get_settings)(struct net_device___17 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___17 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___17 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___17 *);
	void (*get_regs)(struct net_device___17 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___17 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___17 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___17 *);
	void (*set_msglevel)(struct net_device___17 *, u32);
	int (*nway_reset)(struct net_device___17 *);
	u32 (*get_link)(struct net_device___17 *);
	int (*get_eeprom_len)(struct net_device___17 *);
	int (*get_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___17 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___17 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___17 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___17 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___17 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___17 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___17 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___17 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___17 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___17 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___17 *);
	void (*complete)(struct net_device___17 *);
	u32 (*get_priv_flags)(struct net_device___17 *);
	int (*set_priv_flags)(struct net_device___17 *, u32);
	int (*get_sset_count)(struct net_device___17 *, int);
	int (*get_rxnfc)(struct net_device___17 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___17 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___17 *, struct ethtool_flash *);
	int (*reset)(struct net_device___17 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___17 *);
	int (*get_rxfh_indir)(struct net_device___17 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___17 *, const u32 *);
	void (*get_channels)(struct net_device___17 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___17 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___17 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___17 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___17 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___17 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___17 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___17 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___17 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___17 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___17 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___17 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___13 {
	struct callback_head callback_head;
	struct dst_entry___13 *child;
	struct net_device___17 *dev;
	struct dst_ops___27 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___13 *path;
	struct dst_entry___13 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___19 *);
	union {
		int (*output)(struct sock___14 *, struct sk_buff___19 *);
		struct {
			int (*output)(struct sk_buff___19 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___13 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___13;

struct neigh_parms___13;

struct neigh_ops___13;

struct neighbour___13 {
	struct neighbour___13 *next;
	struct neigh_table___13 *tbl;
	struct neigh_parms___13 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___16 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___13 *, struct sk_buff___19 *);
	const struct neigh_ops___13 *ops;
	struct callback_head rcu;
	struct net_device___17 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___27 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___19 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___19 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___28 *, struct dst_entry___13 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___19 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___19 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___117 {
	void * (*start)(struct seq_file___118 *, loff_t *);
	void (*stop)(struct seq_file___118 *, void *);
	void * (*next)(struct seq_file___118 *, void *, loff_t *);
	int (*show)(struct seq_file___118 *, void *);
};

struct dcbnl_rtnl_ops___15 {
	int (*ieee_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___17 *);
	u8 (*setstate)(struct net_device___17 *, u8);
	void (*getpermhwaddr)(struct net_device___17 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___17 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___17 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___17 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___17 *, int, u8 *);
	void (*setpfccfg)(struct net_device___17 *, int, u8);
	void (*getpfccfg)(struct net_device___17 *, int, u8 *);
	u8 (*setall)(struct net_device___17 *);
	u8 (*getcap)(struct net_device___17 *, int, u8 *);
	int (*getnumtcs)(struct net_device___17 *, int, u8 *);
	int (*setnumtcs)(struct net_device___17 *, int, u8);
	u8 (*getpfcstate)(struct net_device___17 *);
	void (*setpfcstate)(struct net_device___17 *, u8);
	void (*getbcncfg)(struct net_device___17 *, int, u32 *);
	void (*setbcncfg)(struct net_device___17 *, int, u32);
	void (*getbcnrp)(struct net_device___17 *, int, u8 *);
	void (*setbcnrp)(struct net_device___17 *, int, u8);
	u8 (*setapp)(struct net_device___17 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___17 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___17 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___17 *, int, u8);
	u8 (*getdcbx)(struct net_device___17 *);
	u8 (*setdcbx)(struct net_device___17 *, u8);
	int (*peer_getappinfo)(struct net_device___17 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___17 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___17 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___17 *, struct cee_pfc *);
};

struct cgroupfs_root___104;

struct cgroup___104 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___104 *parent;
	struct dentry___159 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___104 *subsys[11];
	struct cgroupfs_root___104 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___162 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___104 {
	struct super_block___159 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___104 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___53 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___159 *, struct file___159 *);
	ssize_t (*read)(struct cgroup___104 *, struct cftype___53 *, struct file___159 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___104 *, struct cftype___53 *);
	s64 (*read_s64)(struct cgroup___104 *, struct cftype___53 *);
	int (*read_map)(struct cgroup___104 *, struct cftype___53 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___104 *, struct cftype___53 *, struct seq_file___118 *);
	ssize_t (*write)(struct cgroup___104 *, struct cftype___53 *, struct file___159 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___104 *, struct cftype___53 *, u64);
	int (*write_s64)(struct cgroup___104 *, struct cftype___53 *, s64);
	int (*write_string)(struct cgroup___104 *, struct cftype___53 *, const char *);
	int (*trigger)(struct cgroup___104 *, unsigned int);
	int (*release)(struct inode___159 *, struct file___159 *);
	int (*register_event)(struct cgroup___104 *, struct cftype___53 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___104 *, struct cftype___53 *, struct eventfd_ctx *);
};

struct cftype_set___51 {
	struct list_head node;
	struct cftype___53 *cfts;
};

struct task_and_cgroup___51 {
	struct task_struct___161 *task;
	struct cgroup___104 *cgrp;
	struct css_set___104 *cg;
};

struct cgroup_taskset___51 {
	struct task_and_cgroup___51 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___104 *cur_cgrp;
};

struct cgroup_subsys___51 {
	struct cgroup_subsys_state___104 * (*css_alloc)(struct cgroup___104 *);
	int (*css_online)(struct cgroup___104 *);
	void (*css_offline)(struct cgroup___104 *);
	void (*css_free)(struct cgroup___104 *);
	int (*can_attach)(struct cgroup___104 *, struct cgroup_taskset___51 *);
	void (*cancel_attach)(struct cgroup___104 *, struct cgroup_taskset___51 *);
	void (*attach)(struct cgroup___104 *, struct cgroup_taskset___51 *);
	void (*fork)(struct task_struct___161 *);
	void (*exit)(struct cgroup___104 *, struct cgroup___104 *, struct task_struct___161 *);
	void (*bind)(struct cgroup___104 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___104 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___53 *base_cftypes;
	struct cftype_set___51 base_cftset;
	struct module *module;
};

struct header_ops___15 {
	int (*create)(struct sk_buff___19 *, struct net_device___17 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___19 *, unsigned char *);
	int (*rebuild)(struct sk_buff___19 *);
	int (*cache)(const struct neighbour___13 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___17 *, const unsigned char *);
};

struct napi_struct___15 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___15 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___17 *dev;
	struct sk_buff___19 *gro_list;
	struct sk_buff___19 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___15 {
	struct net_device___17 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___16 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___15 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___16 kobj;
	struct net_device___17 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___15 {
	int (*ndo_init)(struct net_device___17 *);
	void (*ndo_uninit)(struct net_device___17 *);
	int (*ndo_open)(struct net_device___17 *);
	int (*ndo_stop)(struct net_device___17 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___19 *, struct net_device___17 *);
	u16 (*ndo_select_queue)(struct net_device___17 *, struct sk_buff___19 *);
	void (*ndo_change_rx_flags)(struct net_device___17 *, int);
	void (*ndo_set_rx_mode)(struct net_device___17 *);
	int (*ndo_set_mac_address)(struct net_device___17 *, void *);
	int (*ndo_validate_addr)(struct net_device___17 *);
	int (*ndo_do_ioctl)(struct net_device___17 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___17 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___17 *, int);
	int (*ndo_neigh_setup)(struct net_device___17 *, struct neigh_parms___13 *);
	void (*ndo_tx_timeout)(struct net_device___17 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___17 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___17 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___17 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___17 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___17 *);
	int (*ndo_netpoll_setup)(struct net_device___17 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___17 *);
	int (*ndo_busy_poll)(struct napi_struct___15 *);
	int (*ndo_set_vf_mac)(struct net_device___17 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___17 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___17 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___17 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___17 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___17 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___17 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___17 *, int, struct sk_buff___19 *);
	int (*ndo_setup_tc)(struct net_device___17 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___17 *);
	int (*ndo_fcoe_disable)(struct net_device___17 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___17 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___17 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___17 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___17 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___17 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___17 *, const struct sk_buff___19 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___17 *, struct net_device___17 *);
	int (*ndo_del_slave)(struct net_device___17 *, struct net_device___17 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___13 *);
	void (*ndo_neigh_destroy)(struct neighbour___13 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___19 *, struct netlink_callback___16 *, struct net_device___17 *, int);
	int (*ndo_bridge_setlink)(struct net_device___17 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___19 *, u32, u32, struct net_device___17 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___17 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___17 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___17 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___17 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___17 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___17 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___19 *, struct net_device___17 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___17 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___17 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___17 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___13 {
	struct net___28 *net;
	struct net_device___17 *dev;
	struct neigh_parms___13 *next;
	int (*neigh_setup)(struct neighbour___13 *);
	void (*neigh_cleanup)(struct neighbour___13 *);
	struct neigh_table___13 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___13 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___17 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___28 *, struct net_device___17 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___17 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___17 *, struct list_head *);
	size_t (*get_size)(const struct net_device___17 *);
	int (*fill_info)(struct sk_buff___19 *, const struct net_device___17 *);
	size_t (*get_xstats_size)(const struct net_device___17 *);
	int (*fill_xstats)(struct sk_buff___19 *, const struct net_device___17 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___28 * (*get_link_net)(const struct net_device___17 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___17 *, struct net_device___17 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___17 *, const struct net_device___17 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___19 *, const struct net_device___17 *, const struct net_device___17 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___14 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___19 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___13;

struct neigh_hash_table___13;

struct neigh_table___13 {
	struct neigh_table___13 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___17 *, __u32 *);
	int (*constructor)(struct neighbour___13 *);
	int (*pconstructor)(struct pneigh_entry___13 *);
	void (*pdestructor)(struct pneigh_entry___13 *);
	void (*proxy_redo)(struct sk_buff___19 *);
	char *id;
	struct neigh_parms___13 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___16 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___13 *nht;
	struct pneigh_entry___13 **phash_buckets;
};

struct neigh_ops___13 {
	int family;
	void (*solicit)(struct neighbour___13 *, struct sk_buff___19 *);
	void (*error_report)(struct neighbour___13 *, struct sk_buff___19 *);
	int (*output)(struct neighbour___13 *, struct sk_buff___19 *);
	int (*connected_output)(struct neighbour___13 *, struct sk_buff___19 *);
};

struct pneigh_entry___13 {
	struct pneigh_entry___13 *next;
	struct net___28 *net;
	struct net_device___17 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___13 {
	struct neighbour___13 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___13 {
	void (*close)(struct sock___14 *, long int);
	int (*connect)(struct sock___14 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___14 *, int);
	struct sock___14 * (*accept)(struct sock___14 *, int, int *);
	int (*ioctl)(struct sock___14 *, int, long unsigned int);
	int (*init)(struct sock___14 *);
	void (*destroy)(struct sock___14 *);
	void (*shutdown)(struct sock___14 *, int);
	int (*setsockopt)(struct sock___14 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___14 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___14 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___14 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___14 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___20 *, struct sock___14 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___20 *, struct sock___14 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___14 *, struct page___158 *, int, size_t, int);
	int (*bind)(struct sock___14 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___14 *, struct sk_buff___19 *);
	void (*release_cb)(struct sock___14 *);
	void (*mtu_reduced)(struct sock___14 *);
	void (*hash)(struct sock___14 *);
	void (*unhash)(struct sock___14 *);
	void (*rehash)(struct sock___14 *);
	int (*get_port)(struct sock___14 *, short unsigned int);
	void (*clear_sk)(struct sock___14 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___14 *);
	void (*enter_memory_pressure)(struct sock___14 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___145 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___51 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___13 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___13 {
	void (*enter_memory_pressure)(struct sock___14 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___4 {
	int family;
	int obj_size;
	struct kmem_cache___145 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___14 *, struct request_sock___11 *);
	void (*send_ack)(struct sock___14 *, struct sk_buff___19 *, struct request_sock___11 *);
	void (*send_reset)(struct sock___14 *, struct sk_buff___19 *);
	void (*destructor)(struct request_sock___11 *);
	void (*syn_ack_timeout)(struct sock___14 *, struct request_sock___11 *);
};

struct coredump_params___27 {
	siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___159 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
};

struct selinux_mapping {
	u16 value;
	unsigned int num_perms;
	u32 perms[32];
};

struct convert_context_args {
	struct policydb *oldp;
	struct policydb *newp;
};

struct selinux_audit_rule {
	u32 au_seqno;
	struct context___2 au_ctxt;
};

struct cond_insertf_data {
	struct policydb *p;
	struct cond_av_list *other;
	struct cond_av_list *head;
	struct cond_av_list *tail;
};

struct selinux_kernel_status {
	u32 version;
	u32 sequence;
	u32 enforcing;
	u32 policyload;
	u32 deny_unknown;
};

typedef union {
	__be32 a4;
	__be32 a6[4];
	struct in6_addr in6;
} xfrm_address_t;

struct xfrm_id {
	xfrm_address_t daddr;
	__be32 spi;
	__u8 proto;
};

struct xfrm_selector {
	xfrm_address_t daddr;
	xfrm_address_t saddr;
	__be16 dport;
	__be16 dport_mask;
	__be16 sport;
	__be16 sport_mask;
	__u16 family;
	__u8 prefixlen_d;
	__u8 prefixlen_s;
	__u8 proto;
	int ifindex;
	__kernel_uid32_t user;
};

struct xfrm_mark {
	__u32 v;
	__u32 m;
};

struct xfrm_state_walk {
	struct list_head all;
	u8 state;
	union {
		u8 dying;
		u8 proto;
	};
	u32 seq;
};

struct xfrm_lifetime_cfg {
	__u64 soft_byte_limit;
	__u64 hard_byte_limit;
	__u64 soft_packet_limit;
	__u64 hard_packet_limit;
	__u64 soft_add_expires_seconds;
	__u64 hard_add_expires_seconds;
	__u64 soft_use_expires_seconds;
	__u64 hard_use_expires_seconds;
};

struct xfrm_replay_state {
	__u32 oseq;
	__u32 seq;
	__u32 bitmap;
};

struct xfrm_stats {
	__u32 replay_window;
	__u32 replay;
	__u32 integrity_failed;
};

struct xfrm_lifetime_cur {
	__u64 bytes;
	__u64 packets;
	__u64 add_time;
	__u64 use_time;
};

struct xfrm_algo_auth;

struct xfrm_algo;

struct xfrm_algo_aead;

struct xfrm_encap_tmpl;

struct xfrm_replay_state_esn;

struct xfrm_replay;

struct xfrm_type;

struct xfrm_mode;

struct xfrm_state {
	struct net___26 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type *type;
	struct xfrm_mode *inner_mode;
	struct xfrm_mode *inner_mode_iaf;
	struct xfrm_mode *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct flow_cache_ops;

struct flow_cache_object {
	const struct flow_cache_ops *ops;
};

struct xfrm_policy_walk_entry {
	struct list_head all;
	u8 dead;
};

struct xfrm_policy_queue {
	struct sk_buff_head___14 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_tmpl {
	struct xfrm_id id;
	xfrm_address_t saddr;
	short unsigned int encap_family;
	u32 reqid;
	u8 mode;
	u8 share;
	u8 optional;
	u8 allalgs;
	u32 aalgos;
	u32 ealgos;
	u32 calgos;
};

struct xfrm_policy {
	struct net___26 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct sec_path {
	atomic_t refcnt;
	int len;
	struct xfrm_state *xvec[6];
};

struct flow_cache_ops {
	struct flow_cache_object * (*get)(struct flow_cache_object *);
	int (*check)(struct flow_cache_object *);
	void (*delete)(struct flow_cache_object *);
};

struct nf_ipv6_ops___3 {
	int (*chk_addr)(struct net___26 *, const struct in6_addr *, const struct net_device___15 *, int);
};

struct rt6key {
	struct in6_addr addr;
	int plen;
};

struct fib6_node;

struct rt6_info {
	struct dst_entry___11 dst;
	struct fib6_table *rt6i_table;
	struct fib6_node *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___8 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_statistics {
	__u32 fib_nodes;
	__u32 fib_route_nodes;
	__u32 fib_rt_alloc;
	__u32 fib_rt_entries;
	__u32 fib_rt_cache;
	__u32 fib_discarded_routes;
};

struct fib6_node {
	struct fib6_node *parent;
	struct fib6_node *left;
	struct fib6_node *right;
	struct rt6_info *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info *rr_ptr;
};

struct fib6_table {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node tb6_root;
	struct inet_peer_base tb6_peers;
};

struct xfrm_replay_state_esn {
	unsigned int bmp_len;
	__u32 oseq;
	__u32 seq;
	__u32 oseq_hi;
	__u32 seq_hi;
	__u32 replay_window;
	__u32 bmp[0];
};

struct xfrm_algo {
	char alg_name[64];
	unsigned int alg_key_len;
	char alg_key[0];
};

struct xfrm_algo_auth {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_trunc_len;
	char alg_key[0];
};

struct xfrm_algo_aead {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_icv_len;
	char alg_key[0];
};

enum {
	XFRM_POLICY_TYPE_MAIN = 0,
	XFRM_POLICY_TYPE_SUB = 1,
	XFRM_POLICY_TYPE_MAX = 2,
	XFRM_POLICY_TYPE_ANY = 255,
};

struct xfrm_encap_tmpl {
	__u16 encap_type;
	__be16 encap_sport;
	__be16 encap_dport;
	xfrm_address_t encap_oa;
};

struct udp_hslot;

struct udp_table {
	struct udp_hslot *hash;
	struct udp_hslot *hash2;
	unsigned int mask;
	unsigned int log;
};

struct xfrm_replay {
	void (*advance)(struct xfrm_state *, __be32);
	int (*check)(struct xfrm_state *, struct sk_buff___17 *, __be32);
	int (*recheck)(struct xfrm_state *, struct sk_buff___17 *, __be32);
	void (*notify)(struct xfrm_state *, int);
	int (*overflow)(struct xfrm_state *, struct sk_buff___17 *);
};

struct xfrm_type {
	char *description;
	struct module *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state *);
	void (*destructor)(struct xfrm_state *);
	int (*input)(struct xfrm_state *, struct sk_buff___17 *);
	int (*output)(struct xfrm_state *, struct sk_buff___17 *);
	int (*reject)(struct xfrm_state *, struct sk_buff___17 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state *, struct sk_buff___17 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state *, int);
};

struct xfrm_state_afinfo;

struct xfrm_mode {
	int (*input2)(struct xfrm_state *, struct sk_buff___17 *);
	int (*input)(struct xfrm_state *, struct sk_buff___17 *);
	int (*output2)(struct xfrm_state *, struct sk_buff___17 *);
	int (*output)(struct xfrm_state *, struct sk_buff___17 *);
	struct xfrm_state_afinfo *afinfo;
	struct module *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module *owner;
	const struct xfrm_type *type_map[256];
	struct xfrm_mode *mode_map[5];
	int (*init_flags)(struct xfrm_state *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state **, struct xfrm_state **, int);
	union {
		int (*output)(struct sock___12 *, struct sk_buff___17 *);
		struct {
			int (*output)(struct sk_buff___17 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___12 *, struct sk_buff___17 *);
		struct {
			int (*output_finish)(struct sk_buff___17 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state *, struct sk_buff___17 *);
	int (*extract_output)(struct xfrm_state *, struct sk_buff___17 *);
	int (*transport_finish)(struct sk_buff___17 *, int);
};

struct udp_hslot {
	struct hlist_nulls_head head;
	int count;
	spinlock_t lock;
};

struct lsm_network_audit___3 {
	int netif;
	struct sock___12 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct common_audit_data___4 {
	char type;
	union {
		struct path___157 path;
		struct dentry___157 *dentry;
		struct inode___157 *inode;
		struct lsm_network_audit___3 *net;
		int cap;
		int ipc_id;
		struct task_struct___159 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct page___159;

typedef struct page___159 *pgtable_t___159;

struct address_space___160;

struct kmem_cache___146;

struct page___159 {
	long unsigned int flags;
	struct address_space___160 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___159 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___159 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___146 *slab_cache;
		struct page___159 *first_page;
	};
	long: 64;
};

struct task_struct___162;

struct pv_cpu_ops___162 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___162 *);
	void (*end_context_switch)(struct task_struct___162 *);
};

struct mutex___163 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___162 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___155 {
	struct page___159 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___167;

struct nsproxy___97;

struct signal_struct___162;

struct css_set___105;

struct task_struct___162 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___162 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___167 *mm;
	struct mm_struct___167 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___162 *real_parent;
	struct task_struct___162 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___162 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___162 = 0,
		VTIME_USER___162 = 1,
		VTIME_SYS___162 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___97 *nsproxy;
	struct signal_struct___162 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___105 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___163 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___155 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___167 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___167 *, struct mm_struct___167 *);
	void (*dup_mmap)(struct mm_struct___167 *, struct mm_struct___167 *);
	void (*exit_mmap)(struct mm_struct___167 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___167 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___167 *);
	void (*pgd_free)(struct mm_struct___167 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___167 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___167 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___167 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___167 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___167 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___167 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___167 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___167 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___167 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___167 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___167 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___163 lock;
	void *vdso;
} mm_context_t___163;

struct xol_area___159;

struct uprobes_state___159 {
	struct xol_area___159 *xol_area;
};

struct vm_area_struct___167;

struct file___160;

struct core_state___162;

struct mm_struct___167 {
	struct vm_area_struct___167 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___167 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___167 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___163 context;
	long unsigned int flags;
	struct core_state___162 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___162 *owner;
	struct file___160 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___159 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___162;

struct lruvec___162 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___162 *zone;
};

struct pglist_data___162;

struct zone___162 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___162 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___162 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___162 {
	struct zone___162 *zone;
	int zone_idx;
};

struct zonelist___162 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___162 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___162 {
	struct zone___162 node_zones[4];
	struct zonelist___162 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___162 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___113;

struct x86_io_apic_ops___113 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___113 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___113;

struct irq_data___113 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___113 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___125;

struct dev_pm_ops___125 {
	int (*prepare)(struct device___125 *);
	void (*complete)(struct device___125 *);
	int (*suspend)(struct device___125 *);
	int (*resume)(struct device___125 *);
	int (*freeze)(struct device___125 *);
	int (*thaw)(struct device___125 *);
	int (*poweroff)(struct device___125 *);
	int (*restore)(struct device___125 *);
	int (*suspend_late)(struct device___125 *);
	int (*resume_early)(struct device___125 *);
	int (*freeze_late)(struct device___125 *);
	int (*thaw_early)(struct device___125 *);
	int (*poweroff_late)(struct device___125 *);
	int (*restore_early)(struct device___125 *);
	int (*suspend_noirq)(struct device___125 *);
	int (*resume_noirq)(struct device___125 *);
	int (*freeze_noirq)(struct device___125 *);
	int (*thaw_noirq)(struct device___125 *);
	int (*poweroff_noirq)(struct device___125 *);
	int (*restore_noirq)(struct device___125 *);
	int (*runtime_suspend)(struct device___125 *);
	int (*runtime_resume)(struct device___125 *);
	int (*runtime_idle)(struct device___125 *);
};

struct kset___17;

struct kobj_type___17;

struct kobject___17 {
	const char *name;
	struct list_head entry;
	struct kobject___17 *parent;
	struct kset___17 *kset;
	struct kobj_type___17 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___20;

struct dev_pm_info___20 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___20 *qos;
};

struct dma_map_ops___48;

struct dev_archdata___48 {
	struct dma_map_ops___48 *dma_ops;
	void *iommu;
};

struct device_type___125;

struct bus_type___125;

struct device_driver___125;

struct dev_pm_domain___125;

struct class___125;

struct attribute_group___117;

struct device_rh___125;

struct device___125 {
	struct device___125 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___125 *type;
	struct mutex___163 mutex;
	struct bus_type___125 *bus;
	struct device_driver___125 *driver;
	void *platform_data;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___125 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___48 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___10 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___125 *class;
	const struct attribute_group___117 **groups;
	void (*release)(struct device___125 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___125 *device_rh;
};

struct dev_pm_qos_request___20;

struct dev_pm_qos___20 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___20 *latency_req;
	struct dev_pm_qos_request___20 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___20 *latency_tolerance_req;
};

struct dev_pm_info_rh___125 {
	void (*set_latency_tolerance)(struct device___125 *, s32);
};

struct dev_pm_domain___125 {
	struct dev_pm_ops___125 ops;
};

struct smp_ops___162 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___162 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct inode___160;

struct dentry_operations___160;

struct super_block___160;

struct dentry___160 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___160 *d_parent;
	struct qstr d_name;
	struct inode___160 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___160 *d_op;
	struct super_block___160 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___160;

struct address_space___160 {
	struct inode___160 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___163 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___160 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___160;

struct file_operations___160;

struct file_lock___160;

struct dquot___160;

struct block_device___160;

struct inode___160 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___160 *i_op;
	struct super_block___160 *i_sb;
	struct address_space___160 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___163 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___160 *i_fop;
	struct file_lock___160 *i_flock;
	struct address_space___160 i_data;
	struct dquot___160 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___160 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___160;

struct dentry_operations___160 {
	int (*d_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_hash)(const struct dentry___160 *, struct qstr *);
	int (*d_compare)(const struct dentry___160 *, const struct dentry___160 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___160 *);
	void (*d_release)(struct dentry___160 *);
	void (*d_prune)(struct dentry___160 *);
	void (*d_iput)(struct dentry___160 *, struct inode___160 *);
	char * (*d_dname)(struct dentry___160 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___160 *);
	int (*d_manage)(struct dentry___160 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___160;

struct mem_dqinfo___160 {
	struct quota_format_type___160 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___160;

struct quota_info___160 {
	unsigned int flags;
	struct mutex___163 dqio_mutex;
	struct mutex___163 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___160 *files[2];
	struct mem_dqinfo___160 info[2];
	const struct quota_format_ops___160 *ops[2];
};

struct file_system_type___160;

struct super_operations___160;

struct dquot_operations___160;

struct quotactl_ops___160;

struct xattr_handler___106;

struct super_block___160 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___160 *s_type;
	const struct super_operations___160 *s_op;
	const struct dquot_operations___160 *dq_op;
	const struct quotactl_ops___160 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___160 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___106 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___160 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___160 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___163 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___160 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___160 {
	struct vfsmount *mnt;
	struct dentry___160 *dentry;
};

struct block_device___160 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___160 *bd_inode;
	struct super_block___160 *bd_super;
	struct mutex___163 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___160 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___163 bd_fsfreeze_mutex;
};

struct cgroup___105;

struct cgroup_subsys_state___105 {
	struct cgroup___105 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___21;

typedef int kiocb_cancel_fn___21(struct kiocb___21 *, struct io_event *);

struct kiocb___21 {
	atomic_t ki_users;
	struct file___160 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___21 *ki_cancel;
	void (*ki_dtor)(struct kiocb___21 *);
	union {
		void *user;
		struct task_struct___162 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___160 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___160 *ia_file;
};

struct file___160 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___160 f_path;
	struct inode___160 *f_inode;
	const struct file_operations___160 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___160 *f_mapping;
	struct mutex___163 f_pos_lock;
};

struct dquot___160 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___163 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___160 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___160 {
	int qf_fmt_id;
	const struct quota_format_ops___160 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___160 *qf_next;
};

struct quota_format_ops___160 {
	int (*check_quota_file)(struct super_block___160 *, int);
	int (*read_file_info)(struct super_block___160 *, int);
	int (*write_file_info)(struct super_block___160 *, int);
	int (*free_file_info)(struct super_block___160 *, int);
	int (*read_dqblk)(struct dquot___160 *);
	int (*commit_dqblk)(struct dquot___160 *);
	int (*release_dqblk)(struct dquot___160 *);
};

struct dquot_operations___160 {
	int (*write_dquot)(struct dquot___160 *);
	struct dquot___160 * (*alloc_dquot)(struct super_block___160 *, int);
	void (*destroy_dquot)(struct dquot___160 *);
	int (*acquire_dquot)(struct dquot___160 *);
	int (*release_dquot)(struct dquot___160 *);
	int (*mark_dirty)(struct dquot___160 *);
	int (*write_info)(struct super_block___160 *, int);
	qsize_t * (*get_reserved_space)(struct inode___160 *);
};

struct quotactl_ops___160 {
	int (*quota_on)(struct super_block___160 *, int, int, struct path___160 *);
	int (*quota_on_meta)(struct super_block___160 *, int, int);
	int (*quota_off)(struct super_block___160 *, int);
	int (*quota_sync)(struct super_block___160 *, int);
	int (*get_info)(struct super_block___160 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___160 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___160 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___160 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___160 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___160 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___160 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___160 *, unsigned int);
};

struct address_space_operations___160 {
	int (*writepage)(struct page___159 *, struct writeback_control *);
	int (*readpage)(struct file___160 *, struct page___159 *);
	int (*writepages)(struct address_space___160 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___159 *);
	int (*readpages)(struct file___160 *, struct address_space___160 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___160 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___159 **, void **);
	int (*write_end)(struct file___160 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___159 *, void *);
	sector_t (*bmap)(struct address_space___160 *, sector_t);
	void (*invalidatepage)(struct page___159 *, long unsigned int);
	int (*releasepage)(struct page___159 *, gfp_t);
	void (*freepage)(struct page___159 *);
	ssize_t (*direct_IO)(int, struct kiocb___21 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___160 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___160 *, struct page___159 *, struct page___159 *, enum migrate_mode);
	int (*launder_page)(struct page___159 *);
	int (*is_partially_uptodate)(struct page___159 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___159 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___160 *, struct page___159 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___160 *, sector_t *);
	void (*swap_deactivate)(struct file___160 *);
	void (*invalidatepage_range)(struct page___159 *, unsigned int, unsigned int);
};

struct inode_operations___160 {
	struct dentry___160 * (*lookup)(struct inode___160 *, struct dentry___160 *, unsigned int);
	void * (*follow_link)(struct dentry___160 *, struct nameidata *);
	int (*permission)(struct inode___160 *, int);
	struct posix_acl * (*get_acl)(struct inode___160 *, int);
	int (*readlink)(struct dentry___160 *, char *, int);
	void (*put_link)(struct dentry___160 *, struct nameidata *, void *);
	int (*create)(struct inode___160 *, struct dentry___160 *, umode_t, bool);
	int (*link)(struct dentry___160 *, struct inode___160 *, struct dentry___160 *);
	int (*unlink)(struct inode___160 *, struct dentry___160 *);
	int (*symlink)(struct inode___160 *, struct dentry___160 *, const char *);
	int (*mkdir)(struct inode___160 *, struct dentry___160 *, umode_t);
	int (*rmdir)(struct inode___160 *, struct dentry___160 *);
	int (*mknod)(struct inode___160 *, struct dentry___160 *, umode_t, dev_t);
	int (*rename)(struct inode___160 *, struct dentry___160 *, struct inode___160 *, struct dentry___160 *);
	int (*setattr)(struct dentry___160 *, struct iattr___160 *);
	int (*getattr)(struct vfsmount *, struct dentry___160 *, struct kstat *);
	int (*setxattr)(struct dentry___160 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___160 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___160 *, char *, size_t);
	int (*removexattr)(struct dentry___160 *, const char *);
	int (*fiemap)(struct inode___160 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___160 *, struct timespec *, int);
	int (*atomic_open)(struct inode___160 *, struct dentry___160 *, struct file___160 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___97;

struct seq_file___119;

struct file_operations___160 {
	struct module *owner;
	loff_t (*llseek)(struct file___160 *, loff_t, int);
	ssize_t (*read)(struct file___160 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___160 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___21 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___21 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___160 *, void *, filldir_t);
	unsigned int (*poll)(struct file___160 *, struct poll_table_struct___97 *);
	long int (*unlocked_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___160 *, struct vm_area_struct___167 *);
	int (*open)(struct inode___160 *, struct file___160 *);
	int (*flush)(struct file___160 *, fl_owner_t);
	int (*release)(struct inode___160 *, struct file___160 *);
	int (*fsync)(struct file___160 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___21 *, int);
	int (*fasync)(int, struct file___160 *, int);
	int (*lock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*sendpage)(struct file___160 *, struct page___159 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___160 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___160 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___160 *, long int, struct file_lock___160 **, void **);
		struct {
			int (*setlease)(struct file___160 *, long int, struct file_lock___160 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___160 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___119 *, struct file___160 *);
};

struct fasync_struct___160;

struct file_lock_operations___160;

struct lock_manager_operations___160;

struct file_lock___160 {
	struct file_lock___160 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___160 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___160 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___160 *fl_ops;
	const struct lock_manager_operations___160 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___160 {
	void (*fl_copy_lock)(struct file_lock___160 *, struct file_lock___160 *);
	void (*fl_release_private)(struct file_lock___160 *);
};

struct lock_manager_operations___160 {
	int (*lm_compare_owner)(struct file_lock___160 *, struct file_lock___160 *);
	long unsigned int (*lm_owner_key)(struct file_lock___160 *);
	void (*lm_notify)(struct file_lock___160 *);
	int (*lm_grant)(struct file_lock___160 *, struct file_lock___160 *, int);
	void (*lm_break)(struct file_lock___160 *);
	int (*lm_change)(struct file_lock___160 **, int);
};

struct fasync_struct___160 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___160 *fa_next;
	struct file___160 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___160 {
	const char *name;
	int fs_flags;
	struct dentry___160 * (*mount)(struct file_system_type___160 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___160 *);
	struct module *owner;
	struct file_system_type___160 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___160 {
	struct inode___160 * (*alloc_inode)(struct super_block___160 *);
	void (*destroy_inode)(struct inode___160 *);
	void (*dirty_inode)(struct inode___160 *, int);
	int (*write_inode)(struct inode___160 *, struct writeback_control *);
	int (*drop_inode)(struct inode___160 *);
	void (*evict_inode)(struct inode___160 *);
	void (*put_super)(struct super_block___160 *);
	int (*sync_fs)(struct super_block___160 *, int);
	int (*freeze_fs)(struct super_block___160 *);
	int (*unfreeze_fs)(struct super_block___160 *);
	int (*statfs)(struct dentry___160 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___160 *, int *, char *);
	void (*umount_begin)(struct super_block___160 *);
	int (*show_options)(struct seq_file___119 *, struct dentry___160 *);
	int (*show_devname)(struct seq_file___119 *, struct dentry___160 *);
	int (*show_path)(struct seq_file___119 *, struct dentry___160 *);
	int (*show_stats)(struct seq_file___119 *, struct dentry___160 *);
	ssize_t (*quota_read)(struct super_block___160 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___160 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___160 *);
	int (*bdev_try_to_free_page)(struct super_block___160 *, struct page___159 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___160 *);
	void (*free_cached_objects)(struct super_block___160 *, int);
};

struct xattr_handler___106 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___160 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___160 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___160 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___99)(struct file___160 *, wait_queue_head_t *, struct poll_table_struct___97 *);

struct poll_table_struct___97 {
	poll_queue_proc___99 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___140;

struct vm_area_struct___167 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___167 *vm_next;
	struct vm_area_struct___167 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___167 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___140 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___160 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___118;

struct seq_file___119 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___163 lock;
	const struct seq_operations___118 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___113 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___113 *);
	void (*irq_shutdown)(struct irq_data___113 *);
	void (*irq_enable)(struct irq_data___113 *);
	void (*irq_disable)(struct irq_data___113 *);
	void (*irq_ack)(struct irq_data___113 *);
	void (*irq_mask)(struct irq_data___113 *);
	void (*irq_mask_ack)(struct irq_data___113 *);
	void (*irq_unmask)(struct irq_data___113 *);
	void (*irq_eoi)(struct irq_data___113 *);
	int (*irq_set_affinity)(struct irq_data___113 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___113 *);
	int (*irq_set_type)(struct irq_data___113 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___113 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___113 *);
	void (*irq_bus_sync_unlock)(struct irq_data___113 *);
	void (*irq_cpu_online)(struct irq_data___113 *);
	void (*irq_cpu_offline)(struct irq_data___113 *);
	void (*irq_suspend)(struct irq_data___113 *);
	void (*irq_resume)(struct irq_data___113 *);
	void (*irq_pm_shutdown)(struct irq_data___113 *);
	void (*irq_print_chip)(struct irq_data___113 *, struct seq_file___119 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___113 *, void *);
	long unsigned int flags;
};

struct sock___15;

struct kobj_ns_type_operations___14 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___15 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___14;

struct net___29;

struct sock_common___14 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___14 *skc_prot;
	struct net___29 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___20;

struct sk_buff_head___17 {
	struct sk_buff___20 *next;
	struct sk_buff___20 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___15;

struct socket_wq___14;

struct dst_entry___14;

struct socket___15;

struct cg_proto___14;

struct sock___15 {
	struct sock_common___14 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___17 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___20 *head;
		struct sk_buff___20 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___15 *sk_filter;
	struct socket_wq___14 *sk_wq;
	struct sk_buff_head___17 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___14 *sk_rx_dst;
	struct dst_entry___14 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___17 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___17 sk_error_queue;
	struct proto___14 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___15 *sk_socket;
	void *sk_user_data;
	struct page_frag___155 sk_frag;
	struct sk_buff___20 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___14 *sk_cgrp;
	void (*sk_state_change)(struct sock___15 *);
	void (*sk_data_ready)(struct sock___15 *, int);
	void (*sk_write_space)(struct sock___15 *);
	void (*sk_error_report)(struct sock___15 *);
	int (*sk_backlog_rcv)(struct sock___15 *, struct sk_buff___20 *);
	void (*sk_destruct)(struct sock___15 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___119;

struct attribute_group___117 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___119 **bin_attrs;
};

struct bin_attribute___119 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___160 *, struct kobject___17 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___160 *, struct kobject___17 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	int (*mmap)(struct file___160 *, struct kobject___17 *, struct bin_attribute___119 *, struct vm_area_struct___167 *);
};

struct sysfs_ops___17 {
	ssize_t (*show)(struct kobject___17 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___17 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___17 *, const struct attribute *);
};

struct kset_uevent_ops___17;

struct kset___17 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___17 kobj;
	const struct kset_uevent_ops___17 *uevent_ops;
};

struct kobj_type___17 {
	void (*release)(struct kobject___17 *);
	const struct sysfs_ops___17 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___17 *);
	const void * (*namespace)(struct kobject___17 *);
};

struct kset_uevent_ops___17 {
	int (* const filter)(struct kset___17 *, struct kobject___17 *);
	const char * (* const name)(struct kset___17 *, struct kobject___17 *);
	int (* const uevent)(struct kset___17 *, struct kobject___17 *, struct kobj_uevent_env *);
};

struct dma_map_ops___48 {
	void * (*alloc)(struct device___125 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___125 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___125 *, struct vm_area_struct___167 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___125 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___125 *, struct page___159 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___125 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___125 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___125 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___125 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___125 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___125 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___125 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___125 *, dma_addr_t);
	int (*dma_supported)(struct device___125 *, u64);
	int (*set_dma_mask)(struct device___125 *, u64);
	int is_phys;
};

struct bus_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___125 *, char *);
	ssize_t (*store)(struct bus_type___125 *, const char *, size_t);
};

struct device_attribute___125;

struct driver_attribute___125;

struct bus_type___125 {
	const char *name;
	const char *dev_name;
	struct device___125 *dev_root;
	struct bus_attribute___125 *bus_attrs;
	struct device_attribute___125 *dev_attrs;
	struct driver_attribute___125 *drv_attrs;
	const struct attribute_group___117 **bus_groups;
	const struct attribute_group___117 **dev_groups;
	const struct attribute_group___117 **drv_groups;
	int (*match)(struct device___125 *, struct device_driver___125 *);
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	int (*probe)(struct device___125 *);
	int (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*online)(struct device___125 *);
	int (*offline)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct device___125 *, struct device_attribute___125 *, char *);
	ssize_t (*store)(struct device___125 *, struct device_attribute___125 *, const char *, size_t);
};

struct driver_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___125 *, char *);
	ssize_t (*store)(struct device_driver___125 *, const char *, size_t);
};

struct device_driver___125 {
	const char *name;
	struct bus_type___125 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___125 *);
	int (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	const struct attribute_group___117 **groups;
	const struct dev_pm_ops___125 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___125 {
	const char *name;
	const struct attribute_group___117 **groups;
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
};

struct class_attribute___125;

struct class___125 {
	const char *name;
	struct module *owner;
	struct class_attribute___125 *class_attrs;
	struct device_attribute___125 *dev_attrs;
	const struct attribute_group___117 **dev_groups;
	struct bin_attribute___119 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *);
	void (*class_release)(struct class___125 *);
	void (*dev_release)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
	struct subsys_private *p;
};

struct class_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct class___125 *, struct class_attribute___125 *, char *);
	ssize_t (*store)(struct class___125 *, struct class_attribute___125 *, const char *, size_t);
	const void * (*namespace)(struct class___125 *, const struct class_attribute___125 *);
};

struct device_rh___125 {
	struct dev_pm_info_rh___125 power;
};

struct dev_pm_qos_request___20 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___125 *dev;
};

struct xol_area___159 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___159 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___145;

struct memcg_cache_params___146;

struct kmem_cache___146 {
	struct kmem_cache_cpu___145 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___146 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___137;

struct vm_operations_struct___140 {
	void (*open)(struct vm_area_struct___167 *);
	void (*close)(struct vm_area_struct___167 *);
	int (*fault)(struct vm_area_struct___167 *, struct vm_fault___137 *);
	int (*page_mkwrite)(struct vm_area_struct___167 *, struct vm_fault___137 *);
	int (*access)(struct vm_area_struct___167 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___167 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___167 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___167 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___167 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___162 {
	struct task_struct___162 *task;
	struct core_thread___162 *next;
};

struct core_state___162 {
	atomic_t nr_threads;
	struct core_thread___162 dumper;
	struct completion startup;
};

struct vm_fault___137 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___159 *page;
};

struct ctl_table_header___30;

struct ctl_node___30 {
	struct rb_node node;
	struct ctl_table_header___30 *header;
};

struct ctl_table_root___30;

struct ctl_table_set___30;

struct ctl_dir___30;

struct ctl_table_header___30 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___30 *root;
	struct ctl_table_set___30 *set;
	struct ctl_dir___30 *parent;
	struct ctl_node___30 *node;
};

struct ctl_dir___30 {
	struct ctl_table_header___30 header;
	struct rb_root root;
};

struct ctl_table_set___30 {
	int (*is_seen)(struct ctl_table_set___30 *);
	struct ctl_dir___30 dir;
};

struct ctl_table_root___30 {
	struct ctl_table_set___30 default_set;
	struct ctl_table_set___30 * (*lookup)(struct ctl_table_root___30 *, struct nsproxy___97 *);
	int (*permissions)(struct ctl_table_header___30 *, struct ctl_table *);
};

struct nsproxy___97 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___29 *net_ns;
};

struct signal_struct___162 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___162 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___162 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___163 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___105 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___105 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___14 {
	wait_queue_head_t wait;
	struct fasync_struct___160 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___14;

struct socket___15 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___14 *wq;
	struct file___160 *file;
	struct sock___15 *sk;
	const struct proto_ops___14 *ops;
};

struct proto_ops___14 {
	int family;
	struct module *owner;
	int (*release)(struct socket___15 *);
	int (*bind)(struct socket___15 *, struct sockaddr *, int);
	int (*connect)(struct socket___15 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___15 *, struct socket___15 *);
	int (*accept)(struct socket___15 *, struct socket___15 *, int);
	int (*getname)(struct socket___15 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___160 *, struct socket___15 *, struct poll_table_struct___97 *);
	int (*ioctl)(struct socket___15 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___15 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___15 *, int);
	int (*shutdown)(struct socket___15 *, int);
	int (*setsockopt)(struct socket___15 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___15 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___15 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___15 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___21 *, struct socket___15 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___21 *, struct socket___15 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___160 *, struct socket___15 *, struct vm_area_struct___167 *);
	ssize_t (*sendpage)(struct socket___15 *, struct page___159 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___15 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___15 *, int);
		struct {
			void (*set_peek_off)(struct sock___15 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___27 {
	struct ctl_table_header___30 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___27 {
	struct mutex___163 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___27 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___30 *ctl;
};

struct netns_ipv4___27 {
	struct ctl_table_header___30 *forw_hdr;
	struct ctl_table_header___30 *frags_hdr;
	struct ctl_table_header___30 *ipv4_hdr;
	struct ctl_table_header___30 *route_hdr;
	struct ctl_table_header___30 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___15 *fibnl;
	struct sock___15 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___27 {
	struct ctl_table_header___30 *hdr;
	struct ctl_table_header___30 *route_hdr;
	struct ctl_table_header___30 *icmp_hdr;
	struct ctl_table_header___30 *frags_hdr;
	struct ctl_table_header___30 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___18;

struct neighbour___14;

struct dst_ops___28 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___28 *);
	struct dst_entry___14 * (*check)(struct dst_entry___14 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___14 *);
	unsigned int (*mtu)(const struct dst_entry___14 *);
	u32 * (*cow_metrics)(struct dst_entry___14 *, long unsigned int);
	void (*destroy)(struct dst_entry___14 *);
	void (*ifdown)(struct dst_entry___14 *, struct net_device___18 *, int);
	struct dst_entry___14 * (*negative_advice)(struct dst_entry___14 *);
	void (*link_failure)(struct sk_buff___20 *);
	void (*update_pmtu)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___20 *, u32);
	void (*redirect)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___20 *);
	int (*local_out)(struct sk_buff___20 *);
	struct neighbour___14 * (*neigh_lookup)(const struct dst_entry___14 *, struct sk_buff___20 *, const void *);
	struct kmem_cache___146 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___28 {
	struct netns_sysctl_ipv6___27 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___28 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___15 **icmp_sk;
	struct sock___15 *ndisc_sk;
	struct sock___15 *tcp_sk;
	struct sock___15 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___27 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___30 *sysctl_header;
	struct sock___15 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___14 {
	struct sock___15 *v4_ctl_sk;
	struct sock___15 *v6_ctl_sk;
};

struct netns_nf___27 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___30 *nf_log_dir_header;
};

struct nf_proto_net___27 {
	struct ctl_table_header___30 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___27 {
	struct nf_proto_net___27 pn;
	unsigned int timeout;
};

struct nf_tcp_net___27 {
	struct nf_proto_net___27 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___27 {
	struct nf_proto_net___27 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___27 {
	struct nf_proto_net___27 pn;
	unsigned int timeout;
};

struct nf_ip_net___27 {
	struct nf_generic_net___27 generic;
	struct nf_tcp_net___27 tcp;
	struct nf_udp_net___27 udp;
	struct nf_icmp_net___27 icmp;
	struct nf_icmp_net___27 icmpv6;
};

struct netns_ct___27 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___30 *sysctl_header;
	struct ctl_table_header___30 *acct_sysctl_header;
	struct ctl_table_header___30 *tstamp_sysctl_header;
	struct ctl_table_header___30 *event_sysctl_header;
	struct ctl_table_header___30 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___146 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___27 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___27 {
	struct netns_sysctl_ipv6___27 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___28 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___15 *nlsk;
	struct sock___15 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___30 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___28 xfrm4_dst_ops;
	struct dst_ops___28 xfrm6_dst_ops;
};

struct net___29 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___30 sysctls;
	struct sock___15 *rtnl;
	struct sock___15 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___18 *loopback_dev;
	struct netns_core___27 core;
	struct netns_mib___2 mib;
	struct netns_packet___27 packet;
	struct netns_unix___27 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___27 ipv4;
	struct netns_ipv6___28 ipv6;
	struct netns_sctp___27 sctp;
	struct netns_dccp___14 dccp;
	struct netns_nf___27 nf;
	struct netns_xt xt;
	struct netns_ct___27 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___27 nf_frag;
	struct sock___15 *nfnl;
	struct sock___15 *nfnl_stash;
	struct sk_buff_head___17 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___28 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___15 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___15 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___163 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___163 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___145 {
	void **freelist;
	long unsigned int tid;
	struct page___159 *page;
	struct page___159 *partial;
};

struct memcg_cache_params___146 {
	bool is_root_cache;
	union {
		struct kmem_cache___146 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___146 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___16 {
	atomic_t use;
	unsigned int mask;
	struct net_device___18 *physindev;
	struct net_device___18 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___16(struct sk_buff___20 **);

struct net_device_ops___16;

struct ethtool_ops___16;

struct header_ops___16;

struct inet6_dev___9;

struct netdev_rx_queue___16;

struct netdev_queue___16;

struct rtnl_link_ops___14;

struct dcbnl_rtnl_ops___16;

struct net_device___18 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___16 *netdev_ops;
	const struct ethtool_ops___16 *ethtool_ops;
	const struct header_ops___16 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___17 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___9 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___16 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___16 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___16 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___16 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___16 = 0,
		NETREG_REGISTERED___16 = 1,
		NETREG_UNREGISTERING___16 = 2,
		NETREG_UNREGISTERED___16 = 3,
		NETREG_RELEASED___16 = 4,
		NETREG_DUMMY___16 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___16 = 0,
		RTNL_LINK_INITIALIZING___16 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___18 *);
	struct netpoll_info *npinfo;
	struct net___29 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___125 dev;
	const struct attribute_group___117 *sysfs_groups[4];
	const struct rtnl_link_ops___14 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___16 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___20 {
	struct sk_buff___20 *next;
	struct sk_buff___20 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___15 *sk;
	struct net_device___18 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___20 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___16 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___16 {
	int (*get_settings)(struct net_device___18 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___18 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___18 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___18 *);
	void (*get_regs)(struct net_device___18 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___18 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___18 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___18 *);
	void (*set_msglevel)(struct net_device___18 *, u32);
	int (*nway_reset)(struct net_device___18 *);
	u32 (*get_link)(struct net_device___18 *);
	int (*get_eeprom_len)(struct net_device___18 *);
	int (*get_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___18 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___18 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___18 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___18 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___18 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___18 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___18 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___18 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___18 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___18 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___18 *);
	void (*complete)(struct net_device___18 *);
	u32 (*get_priv_flags)(struct net_device___18 *);
	int (*set_priv_flags)(struct net_device___18 *, u32);
	int (*get_sset_count)(struct net_device___18 *, int);
	int (*get_rxnfc)(struct net_device___18 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___18 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___18 *, struct ethtool_flash *);
	int (*reset)(struct net_device___18 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___18 *);
	int (*get_rxfh_indir)(struct net_device___18 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___18 *, const u32 *);
	void (*get_channels)(struct net_device___18 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___18 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___18 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___18 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___18 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___18 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___18 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___18 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___18 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___18 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___18 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___18 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___5;

struct dst_entry___14 {
	struct callback_head callback_head;
	struct dst_entry___14 *child;
	struct net_device___18 *dev;
	struct dst_ops___28 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___14 *path;
	struct dst_entry___14 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___20 *);
	union {
		int (*output)(struct sock___15 *, struct sk_buff___20 *);
		struct {
			int (*output)(struct sk_buff___20 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___14 *next;
		struct rtable___5 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___14;

struct neigh_parms___14;

struct neigh_ops___14;

struct neighbour___14 {
	struct neighbour___14 *next;
	struct neigh_table___14 *tbl;
	struct neigh_parms___14 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___17 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___14 *, struct sk_buff___20 *);
	const struct neigh_ops___14 *ops;
	struct callback_head rcu;
	struct net_device___18 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___28 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___20 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___20 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___29 *, struct dst_entry___14 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___20 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___20 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___118 {
	void * (*start)(struct seq_file___119 *, loff_t *);
	void (*stop)(struct seq_file___119 *, void *);
	void * (*next)(struct seq_file___119 *, void *, loff_t *);
	int (*show)(struct seq_file___119 *, void *);
};

struct dcbnl_rtnl_ops___16 {
	int (*ieee_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___18 *);
	u8 (*setstate)(struct net_device___18 *, u8);
	void (*getpermhwaddr)(struct net_device___18 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___18 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___18 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___18 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___18 *, int, u8 *);
	void (*setpfccfg)(struct net_device___18 *, int, u8);
	void (*getpfccfg)(struct net_device___18 *, int, u8 *);
	u8 (*setall)(struct net_device___18 *);
	u8 (*getcap)(struct net_device___18 *, int, u8 *);
	int (*getnumtcs)(struct net_device___18 *, int, u8 *);
	int (*setnumtcs)(struct net_device___18 *, int, u8);
	u8 (*getpfcstate)(struct net_device___18 *);
	void (*setpfcstate)(struct net_device___18 *, u8);
	void (*getbcncfg)(struct net_device___18 *, int, u32 *);
	void (*setbcncfg)(struct net_device___18 *, int, u32);
	void (*getbcnrp)(struct net_device___18 *, int, u8 *);
	void (*setbcnrp)(struct net_device___18 *, int, u8);
	u8 (*setapp)(struct net_device___18 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___18 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___18 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___18 *, int, u8);
	u8 (*getdcbx)(struct net_device___18 *);
	u8 (*setdcbx)(struct net_device___18 *, u8);
	int (*peer_getappinfo)(struct net_device___18 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___18 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___18 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___18 *, struct cee_pfc *);
};

struct cgroupfs_root___105;

struct cgroup___105 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___105 *parent;
	struct dentry___160 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___105 *subsys[11];
	struct cgroupfs_root___105 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___163 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___105 {
	struct super_block___160 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___105 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___54 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___160 *, struct file___160 *);
	ssize_t (*read)(struct cgroup___105 *, struct cftype___54 *, struct file___160 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___105 *, struct cftype___54 *);
	s64 (*read_s64)(struct cgroup___105 *, struct cftype___54 *);
	int (*read_map)(struct cgroup___105 *, struct cftype___54 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___105 *, struct cftype___54 *, struct seq_file___119 *);
	ssize_t (*write)(struct cgroup___105 *, struct cftype___54 *, struct file___160 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___105 *, struct cftype___54 *, u64);
	int (*write_s64)(struct cgroup___105 *, struct cftype___54 *, s64);
	int (*write_string)(struct cgroup___105 *, struct cftype___54 *, const char *);
	int (*trigger)(struct cgroup___105 *, unsigned int);
	int (*release)(struct inode___160 *, struct file___160 *);
	int (*register_event)(struct cgroup___105 *, struct cftype___54 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___105 *, struct cftype___54 *, struct eventfd_ctx *);
};

struct cftype_set___52 {
	struct list_head node;
	struct cftype___54 *cfts;
};

struct task_and_cgroup___52 {
	struct task_struct___162 *task;
	struct cgroup___105 *cgrp;
	struct css_set___105 *cg;
};

struct cgroup_taskset___52 {
	struct task_and_cgroup___52 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___105 *cur_cgrp;
};

struct cgroup_subsys___52 {
	struct cgroup_subsys_state___105 * (*css_alloc)(struct cgroup___105 *);
	int (*css_online)(struct cgroup___105 *);
	void (*css_offline)(struct cgroup___105 *);
	void (*css_free)(struct cgroup___105 *);
	int (*can_attach)(struct cgroup___105 *, struct cgroup_taskset___52 *);
	void (*cancel_attach)(struct cgroup___105 *, struct cgroup_taskset___52 *);
	void (*attach)(struct cgroup___105 *, struct cgroup_taskset___52 *);
	void (*fork)(struct task_struct___162 *);
	void (*exit)(struct cgroup___105 *, struct cgroup___105 *, struct task_struct___162 *);
	void (*bind)(struct cgroup___105 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___105 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___54 *base_cftypes;
	struct cftype_set___52 base_cftset;
	struct module *module;
};

struct request_sock_ops___11;

struct request_sock___12 {
	struct sock_common___14 __req_common;
	struct request_sock___12 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___11 *rsk_ops;
	struct sock___15 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___17 {
	struct sk_buff___20 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___20 *, struct netlink_callback___17 *);
	int (*done)(struct netlink_callback___17 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___16 {
	int (*create)(struct sk_buff___20 *, struct net_device___18 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___20 *, unsigned char *);
	int (*rebuild)(struct sk_buff___20 *);
	int (*cache)(const struct neighbour___14 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___18 *, const unsigned char *);
};

struct napi_struct___16 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___16 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___18 *dev;
	struct sk_buff___20 *gro_list;
	struct sk_buff___20 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___16 {
	struct net_device___18 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___17 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___16 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___17 kobj;
	struct net_device___18 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___16 {
	int (*ndo_init)(struct net_device___18 *);
	void (*ndo_uninit)(struct net_device___18 *);
	int (*ndo_open)(struct net_device___18 *);
	int (*ndo_stop)(struct net_device___18 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___20 *, struct net_device___18 *);
	u16 (*ndo_select_queue)(struct net_device___18 *, struct sk_buff___20 *);
	void (*ndo_change_rx_flags)(struct net_device___18 *, int);
	void (*ndo_set_rx_mode)(struct net_device___18 *);
	int (*ndo_set_mac_address)(struct net_device___18 *, void *);
	int (*ndo_validate_addr)(struct net_device___18 *);
	int (*ndo_do_ioctl)(struct net_device___18 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___18 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___18 *, int);
	int (*ndo_neigh_setup)(struct net_device___18 *, struct neigh_parms___14 *);
	void (*ndo_tx_timeout)(struct net_device___18 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___18 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___18 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___18 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___18 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___18 *);
	int (*ndo_netpoll_setup)(struct net_device___18 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___18 *);
	int (*ndo_busy_poll)(struct napi_struct___16 *);
	int (*ndo_set_vf_mac)(struct net_device___18 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___18 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___18 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___18 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___18 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___18 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___18 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___18 *, int, struct sk_buff___20 *);
	int (*ndo_setup_tc)(struct net_device___18 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___18 *);
	int (*ndo_fcoe_disable)(struct net_device___18 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___18 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___18 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___18 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___18 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___18 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___18 *, const struct sk_buff___20 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___18 *, struct net_device___18 *);
	int (*ndo_del_slave)(struct net_device___18 *, struct net_device___18 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___14 *);
	void (*ndo_neigh_destroy)(struct neighbour___14 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___20 *, struct netlink_callback___17 *, struct net_device___18 *, int);
	int (*ndo_bridge_setlink)(struct net_device___18 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___20 *, u32, u32, struct net_device___18 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___18 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___18 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___18 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___18 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___18 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___18 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___20 *, struct net_device___18 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___18 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___18 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___18 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___14 {
	struct net___29 *net;
	struct net_device___18 *dev;
	struct neigh_parms___14 *next;
	int (*neigh_setup)(struct neighbour___14 *);
	void (*neigh_cleanup)(struct neighbour___14 *);
	struct neigh_table___14 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___9;

struct ifacaddr6___9;

struct inet6_dev___9 {
	struct net_device___18 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___9 *mc_list;
	struct ifmcaddr6___9 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___14 *nd_parms;
	struct inet6_dev___9 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___14 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___18 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___29 *, struct net_device___18 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___18 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___18 *, struct list_head *);
	size_t (*get_size)(const struct net_device___18 *);
	int (*fill_info)(struct sk_buff___20 *, const struct net_device___18 *);
	size_t (*get_xstats_size)(const struct net_device___18 *);
	int (*fill_xstats)(struct sk_buff___20 *, const struct net_device___18 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___29 * (*get_link_net)(const struct net_device___18 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___18 *, struct net_device___18 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___18 *, const struct net_device___18 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___20 *, const struct net_device___18 *, const struct net_device___18 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___15 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___20 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___14;

struct neigh_hash_table___14;

struct neigh_table___14 {
	struct neigh_table___14 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___18 *, __u32 *);
	int (*constructor)(struct neighbour___14 *);
	int (*pconstructor)(struct pneigh_entry___14 *);
	void (*pdestructor)(struct pneigh_entry___14 *);
	void (*proxy_redo)(struct sk_buff___20 *);
	char *id;
	struct neigh_parms___14 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___17 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___14 *nht;
	struct pneigh_entry___14 **phash_buckets;
};

struct neigh_ops___14 {
	int family;
	void (*solicit)(struct neighbour___14 *, struct sk_buff___20 *);
	void (*error_report)(struct neighbour___14 *, struct sk_buff___20 *);
	int (*output)(struct neighbour___14 *, struct sk_buff___20 *);
	int (*connected_output)(struct neighbour___14 *, struct sk_buff___20 *);
};

struct pneigh_entry___14 {
	struct pneigh_entry___14 *next;
	struct net___29 *net;
	struct net_device___18 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___14 {
	struct neighbour___14 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___5 {
	struct dst_entry___14 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___9;

struct proto___14 {
	void (*close)(struct sock___15 *, long int);
	int (*connect)(struct sock___15 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___15 *, int);
	struct sock___15 * (*accept)(struct sock___15 *, int, int *);
	int (*ioctl)(struct sock___15 *, int, long unsigned int);
	int (*init)(struct sock___15 *);
	void (*destroy)(struct sock___15 *);
	void (*shutdown)(struct sock___15 *, int);
	int (*setsockopt)(struct sock___15 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___15 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___15 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___15 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___15 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___21 *, struct sock___15 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___21 *, struct sock___15 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___15 *, struct page___159 *, int, size_t, int);
	int (*bind)(struct sock___15 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___15 *, struct sk_buff___20 *);
	void (*release_cb)(struct sock___15 *);
	void (*mtu_reduced)(struct sock___15 *);
	void (*hash)(struct sock___15 *);
	void (*unhash)(struct sock___15 *);
	void (*rehash)(struct sock___15 *);
	int (*get_port)(struct sock___15 *, short unsigned int);
	void (*clear_sk)(struct sock___15 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___15 *);
	void (*enter_memory_pressure)(struct sock___15 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___146 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___11 *rsk_prot;
	struct timewait_sock_ops___9 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___52 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___14 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___14 {
	void (*enter_memory_pressure)(struct sock___15 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___11 {
	int family;
	int obj_size;
	struct kmem_cache___146 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___15 *, struct request_sock___12 *);
	void (*send_ack)(struct sock___15 *, struct sk_buff___20 *, struct request_sock___12 *);
	void (*send_reset)(struct sock___15 *, struct sk_buff___20 *);
	void (*destructor)(struct request_sock___12 *);
	void (*syn_ack_timeout)(struct sock___15 *, struct request_sock___12 *);
};

struct timewait_sock_ops___9 {
	struct kmem_cache___146 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___15 *, struct sock___15 *, void *);
	void (*twsk_destructor)(struct sock___15 *);
};

struct sockaddr_un {
	__kernel_sa_family_t sun_family;
	char sun_path[108];
};

struct unix_address {
	atomic_t refcnt;
	int len;
	unsigned int hash;
	struct sockaddr_un name[0];
};

struct unix_sock {
	struct sock___15 sk;
	struct unix_address *addr;
	struct path___160 path;
	struct mutex___163 readlock;
	struct sock___15 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	unsigned char recursion_level;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___14 peer_wq;
};

struct in6_pktinfo {
	struct in6_addr ipi6_addr;
	int ipi6_ifindex;
};

struct ipv6_rt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
};

struct ipv6_opt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
};

struct ip_options_rcu {
	struct callback_head rcu;
	struct ip_options opt;
};

struct inet_cork {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___14 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full {
	struct inet_cork base;
	struct flowi fl;
};

struct ipv6_pinfo;

struct ip_mc_socklist;

struct inet_sock {
	struct sock___15 sk;
	struct ipv6_pinfo *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full cork;
};

struct ipv6_txoptions;

struct inet6_cork {
	struct ipv6_txoptions *opt;
	u8 hop_limit;
	u8 tclass;
};

struct ipv6_mc_socklist;

struct ipv6_ac_socklist;

struct ipv6_fl_socklist;

struct ipv6_pinfo {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___20 *pktoptions;
	struct sk_buff___20 *rxpmtu;
	struct inet6_cork cork;
};

struct ipv6_txoptions {
	int tot_len;
	__u16 opt_flen;
	__u16 opt_nflen;
	struct ipv6_opt_hdr *hopopt;
	struct ipv6_opt_hdr *dst0opt;
	struct ipv6_rt_hdr *srcrt;
	struct ipv6_opt_hdr *dst1opt;
};

struct ip6_sf_socklist;

struct ipv6_mc_socklist {
	struct in6_addr addr;
	int ifindex;
	struct ipv6_mc_socklist *next;
	rwlock_t sflock;
	unsigned int sfmode;
	struct ip6_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ipv6_ac_socklist {
	struct in6_addr acl_addr;
	int acl_ifindex;
	struct ipv6_ac_socklist *acl_next;
};

struct ip6_flowlabel;

struct ipv6_fl_socklist {
	struct ipv6_fl_socklist *next;
	struct ip6_flowlabel *fl;
	struct callback_head rcu;
};

struct ip6_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct in6_addr sl_addr[0];
};

struct ifmcaddr6___9 {
	struct in6_addr mca_addr;
	struct inet6_dev___9 *idev;
	struct ifmcaddr6___9 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___9 {
	struct in6_addr aca_addr;
	struct inet6_dev___9 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___9 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel {
	struct ip6_flowlabel *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___29 *fl_net;
};

struct sctphdr {
	__be16 source;
	__be16 dest;
	__be32 vtag;
	__le32 checksum;
};

struct lsm_network_audit___4 {
	int netif;
	struct sock___15 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct common_audit_data___5 {
	char type;
	union {
		struct path___160 path;
		struct dentry___160 *dentry;
		struct inode___160 *inode;
		struct lsm_network_audit___4 *net;
		int cap;
		int ipc_id;
		struct task_struct___162 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

enum devcg_behavior {
	DEVCG_DEFAULT_NONE = 0,
	DEVCG_DEFAULT_ALLOW = 1,
	DEVCG_DEFAULT_DENY = 2,
};

struct dev_exception_item {
	u32 major;
	u32 minor;
	short int type;
	short int access;
	struct list_head list;
	struct callback_head rcu;
};

struct dev_cgroup {
	struct cgroup_subsys_state___91 css;
	struct list_head exceptions;
	enum devcg_behavior behavior;
	struct list_head propagate_pending;
};

enum integrity_status {
	INTEGRITY_PASS = 0,
	INTEGRITY_FAIL = 1,
	INTEGRITY_NOLABEL = 2,
	INTEGRITY_NOXATTRS = 3,
	INTEGRITY_UNKNOWN = 4,
};

struct evm_ima_xattr_data {
	u8 type;
	u8 digest[20];
};

struct integrity_iint_cache {
	struct rb_node rb_node;
	struct inode___160 *inode;
	u64 version;
	long unsigned int flags;
	struct evm_ima_xattr_data ima_xattr;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_module_status: 4;
	enum integrity_status evm_status: 4;
};

struct signature_v2_hdr {
	uint8_t version;
	uint8_t hash_algo;
	uint32_t keyid;
	uint16_t sig_size;
	uint8_t sig[0];
} __attribute__((packed));

enum ima_show_type {
	IMA_SHOW_BINARY = 0,
	IMA_SHOW_ASCII = 1,
};

struct ima_template_data {
	u8 digest[20];
	char file_name[256];
};

struct ima_template_entry {
	u8 digest[20];
	const char *template_name;
	int template_len;
	struct ima_template_data template;
};

struct ima_queue_entry {
	struct hlist_node hnext;
	struct list_head later;
	struct ima_template_entry *entry;
};

struct ima_h_table {
	atomic_long_t len;
	atomic_long_t violations;
	struct hlist_head queue[512];
};

struct integrity_iint_cache___2 {
	struct rb_node rb_node;
	struct inode___59 *inode;
	u64 version;
	long unsigned int flags;
	struct evm_ima_xattr_data ima_xattr;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_module_status: 4;
	enum integrity_status evm_status: 4;
};

enum ima_hooks {
	FILE_CHECK = 1,
	MMAP_CHECK = 2,
	BPRM_CHECK = 3,
	MODULE_CHECK = 4,
	POST_SETATTR = 5,
};

enum tpm_pcrs {
	TPM_PCR0 = 0,
	TPM_PCR8 = 8,
};

enum evm_ima_xattr_type {
	IMA_XATTR_DIGEST = 1,
	EVM_XATTR_HMAC = 2,
	EVM_IMA_XATTR_DIGSIG = 3,
};

struct integrity_iint_cache___3 {
	struct rb_node rb_node;
	struct inode___152 *inode;
	u64 version;
	long unsigned int flags;
	struct evm_ima_xattr_data ima_xattr;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_module_status: 4;
	enum integrity_status evm_status: 4;
};

enum lsm_rule_types {
	LSM_OBJ_USER = 0,
	LSM_OBJ_ROLE = 1,
	LSM_OBJ_TYPE = 2,
	LSM_SUBJ_USER = 3,
	LSM_SUBJ_ROLE = 4,
	LSM_SUBJ_TYPE = 5,
};

struct ima_rule_entry {
	struct list_head list;
	int action;
	unsigned int flags;
	enum ima_hooks func;
	int mask;
	long unsigned int fsmagic;
	u8 fsuuid[16];
	kuid_t uid;
	kuid_t fowner;
	struct {
		void *rule;
		void *args_p;
		int type;
	} lsm[6];
};

enum {
	Opt_err___10 = 4294967295,
	Opt_measure = 1,
	Opt_dont_measure = 2,
	Opt_appraise = 3,
	Opt_dont_appraise = 4,
	Opt_audit = 5,
	Opt_obj_user = 6,
	Opt_obj_role = 7,
	Opt_obj_type = 8,
	Opt_subj_user = 9,
	Opt_subj_role = 10,
	Opt_subj_type = 11,
	Opt_func = 12,
	Opt_mask = 13,
	Opt_fsmagic = 14,
	Opt_uid___5 = 15,
	Opt_fowner = 16,
	Opt_appraise_type = 17,
	Opt_fsuuid = 18,
};

struct h_misc {
	long unsigned int ino;
	__u32 generation;
	uid_t uid;
	gid_t gid;
	umode_t mode;
};

struct page___160;

typedef struct page___160 *pgtable_t___160;

struct address_space___161;

struct kmem_cache___147;

struct page___160 {
	long unsigned int flags;
	struct address_space___161 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___160 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___160 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___147 *slab_cache;
		struct page___160 *first_page;
	};
	long: 64;
};

struct task_struct___163;

struct pv_cpu_ops___163 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___163 *);
	void (*end_context_switch)(struct task_struct___163 *);
};

struct mutex___164 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___163 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___156 {
	struct page___160 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___168;

struct signal_struct___163;

struct task_struct___163 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___163 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___168 *mm;
	struct mm_struct___168 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___163 *real_parent;
	struct task_struct___163 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___163 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___163 = 0,
		VTIME_USER___163 = 1,
		VTIME_SYS___163 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___163 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___164 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___156 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___168 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___168 *, struct mm_struct___168 *);
	void (*dup_mmap)(struct mm_struct___168 *, struct mm_struct___168 *);
	void (*exit_mmap)(struct mm_struct___168 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___168 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___168 *);
	void (*pgd_free)(struct mm_struct___168 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___168 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___168 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___168 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___168 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___168 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___168 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___168 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___168 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___168 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___168 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___168 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___164 lock;
	void *vdso;
} mm_context_t___164;

struct xol_area___160;

struct uprobes_state___160 {
	struct xol_area___160 *xol_area;
};

struct vm_area_struct___168;

struct file___161;

struct core_state___163;

struct mm_struct___168 {
	struct vm_area_struct___168 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___168 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___168 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___164 context;
	long unsigned int flags;
	struct core_state___163 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___163 *owner;
	struct file___161 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___160 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___80;

struct exec_domain___36 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___80 *module;
	struct exec_domain___36 *next;
};

struct module_kobject___79 {
	struct kobject___17 kobj;
	struct module___80 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___79;

struct module___80 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___79 mkobj;
	struct module_attribute___79 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___163 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___74 {
	struct task_struct___163 *task;
	struct exec_domain___36 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___163;

struct lruvec___163 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___163 *zone;
};

struct pglist_data___163;

struct zone___163 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___163 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___163 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___163 {
	struct zone___163 *zone;
	int zone_idx;
};

struct zonelist___163 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___163 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___163 {
	struct zone___163 node_zones[4];
	struct zonelist___163 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___163 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___126;

struct dev_pm_ops___126 {
	int (*prepare)(struct device___126 *);
	void (*complete)(struct device___126 *);
	int (*suspend)(struct device___126 *);
	int (*resume)(struct device___126 *);
	int (*freeze)(struct device___126 *);
	int (*thaw)(struct device___126 *);
	int (*poweroff)(struct device___126 *);
	int (*restore)(struct device___126 *);
	int (*suspend_late)(struct device___126 *);
	int (*resume_early)(struct device___126 *);
	int (*freeze_late)(struct device___126 *);
	int (*thaw_early)(struct device___126 *);
	int (*poweroff_late)(struct device___126 *);
	int (*restore_early)(struct device___126 *);
	int (*suspend_noirq)(struct device___126 *);
	int (*resume_noirq)(struct device___126 *);
	int (*freeze_noirq)(struct device___126 *);
	int (*thaw_noirq)(struct device___126 *);
	int (*poweroff_noirq)(struct device___126 *);
	int (*restore_noirq)(struct device___126 *);
	int (*runtime_suspend)(struct device___126 *);
	int (*runtime_resume)(struct device___126 *);
	int (*runtime_idle)(struct device___126 *);
};

struct dma_map_ops___49;

struct dev_archdata___49 {
	struct dma_map_ops___49 *dma_ops;
	void *iommu;
};

struct device_type___126;

struct bus_type___126;

struct device_driver___126;

struct dev_pm_domain___126;

struct class___126;

struct attribute_group___118;

struct device_rh___126;

struct device___126 {
	struct device___126 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___126 *type;
	struct mutex___164 mutex;
	struct bus_type___126 *bus;
	struct device_driver___126 *driver;
	void *platform_data;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___126 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___49 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___126 *class;
	const struct attribute_group___118 **groups;
	void (*release)(struct device___126 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___126 *device_rh;
};

struct dev_pm_info_rh___126 {
	void (*set_latency_tolerance)(struct device___126 *, s32);
};

struct dev_pm_domain___126 {
	struct dev_pm_ops___126 ops;
};

struct smp_ops___163 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___163 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___120;

struct attribute_group___118 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___120 **bin_attrs;
};

struct bin_attribute___120 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___161 *, struct kobject___17 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___161 *, struct kobject___17 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	int (*mmap)(struct file___161 *, struct kobject___17 *, struct bin_attribute___120 *, struct vm_area_struct___168 *);
};

struct dentry___161;

struct path___161 {
	struct vfsmount *mnt;
	struct dentry___161 *dentry;
};

struct inode___161;

struct file_operations___161;

struct file___161 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___161 f_path;
	struct inode___161 *f_inode;
	const struct file_operations___161 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___161 *f_mapping;
	struct mutex___164 f_pos_lock;
};

struct vm_operations_struct___141;

struct vm_area_struct___168 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___168 *vm_next;
	struct vm_area_struct___168 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___168 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___141 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___161 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___79 *, struct module_kobject___79 *, char *);
	ssize_t (*store)(struct module_attribute___79 *, struct module_kobject___79 *, const char *, size_t);
	void (*setup)(struct module___80 *, const char *);
	int (*test)(struct module___80 *);
	void (*free)(struct module___80 *);
};

struct xol_area___160 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___160 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___146;

struct memcg_cache_params___147;

struct kmem_cache___147 {
	struct kmem_cache_cpu___146 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___147 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___161;

struct address_space___161 {
	struct inode___161 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___164 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___161 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___138;

struct vm_operations_struct___141 {
	void (*open)(struct vm_area_struct___168 *);
	void (*close)(struct vm_area_struct___168 *);
	int (*fault)(struct vm_area_struct___168 *, struct vm_fault___138 *);
	int (*page_mkwrite)(struct vm_area_struct___168 *, struct vm_fault___138 *);
	int (*access)(struct vm_area_struct___168 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___168 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___168 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___168 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___168 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___163 {
	struct task_struct___163 *task;
	struct core_thread___163 *next;
};

struct core_state___163 {
	atomic_t nr_threads;
	struct core_thread___163 dumper;
	struct completion startup;
};

struct signal_struct___163 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___163 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___163 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___164 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___146 {
	void **freelist;
	long unsigned int tid;
	struct page___160 *page;
	struct page___160 *partial;
};

struct memcg_cache_params___147 {
	bool is_root_cache;
	union {
		struct kmem_cache___147 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___147 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct crypto_async_request___4;

typedef void (*crypto_completion_t___4)(struct crypto_async_request___4 *, int);

struct crypto_tfm___5;

struct crypto_async_request___4 {
	struct list_head list;
	crypto_completion_t___4 complete;
	void *data;
	struct crypto_tfm___5 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___4;

struct ablkcipher_request___4;

struct ablkcipher_tfm___4 {
	int (*setkey)(struct crypto_ablkcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___4 *);
	int (*decrypt)(struct ablkcipher_request___4 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___4 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___4;

struct aead_request___4;

struct aead_tfm___4 {
	int (*setkey)(struct crypto_aead___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___4 *);
	int (*decrypt)(struct aead_request___4 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___4 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___4;

struct blkcipher_tfm___4 {
	void *iv;
	int (*setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___4 {
	int (*cit_setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___5 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___5 *, u8 *, const u8 *);
};

struct hash_desc___4;

struct crypto_hash___4;

struct hash_tfm___4 {
	int (*init)(struct hash_desc___4 *);
	int (*update)(struct hash_desc___4 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___4 *, u8 *);
	int (*digest)(struct hash_desc___4 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___4 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___4 {
	int (*cot_compress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___4;

struct rng_tfm___4 {
	int (*rng_gen_random)(struct crypto_rng___4 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___4 *, u8 *, unsigned int);
};

struct crypto_alg___5;

struct crypto_tfm___5 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___4 ablkcipher;
		struct aead_tfm___4 aead;
		struct blkcipher_tfm___4 blkcipher;
		struct cipher_tfm___4 cipher;
		struct hash_tfm___4 hash;
		struct compress_tfm___4 compress;
		struct rng_tfm___4 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___5 *);
	struct crypto_alg___5 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___4 {
	struct crypto_async_request___4 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___4 {
	struct crypto_async_request___4 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___4;

struct blkcipher_desc___4 {
	struct crypto_blkcipher___4 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___4 {
	struct crypto_tfm___5 base;
};

struct hash_desc___4 {
	struct crypto_hash___4 *tfm;
	u32 flags;
};

struct crypto_hash___4 {
	struct crypto_tfm___5 base;
};

struct ablkcipher_alg___4 {
	int (*setkey)(struct crypto_ablkcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___4 *);
	int (*decrypt)(struct ablkcipher_request___4 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___4 {
	struct crypto_tfm___5 base;
};

struct aead_alg___4 {
	int (*setkey)(struct crypto_aead___4 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___4 *, unsigned int);
	int (*encrypt)(struct aead_request___4 *);
	int (*decrypt)(struct aead_request___4 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___4 {
	struct crypto_tfm___5 base;
};

struct blkcipher_alg___4 {
	int (*setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___4 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
};

struct compress_alg___4 {
	int (*coa_compress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___4 {
	int (*rng_make_random)(struct crypto_rng___4 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___4 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___4 {
	struct crypto_tfm___5 base;
};

struct crypto_type___2;

struct crypto_alg___5 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type___2 *cra_type;
	union {
		struct ablkcipher_alg___4 ablkcipher;
		struct aead_alg___4 aead;
		struct blkcipher_alg___4 blkcipher;
		struct cipher_alg___4 cipher;
		struct compress_alg___4 compress;
		struct rng_alg___4 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___5 *);
	void (*cra_exit)(struct crypto_tfm___5 *);
	void (*cra_destroy)(struct crypto_alg___5 *);
	struct module___80 *cra_module;
};

struct crypto_type___2 {
	unsigned int (*ctxsize)(struct crypto_alg___5 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___5 *);
	int (*init)(struct crypto_tfm___5 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___5 *);
	void (*show)(struct seq_file___5 *, struct crypto_alg___5 *);
	int (*report)(struct sk_buff___19 *, struct crypto_alg___5 *);
	struct crypto_alg___5 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct fasync_struct___161 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___161 *fa_next;
	struct file___161 *fa_file;
	struct callback_head fa_rcu;
};

struct dma_map_ops___49 {
	void * (*alloc)(struct device___126 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___126 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___126 *, struct vm_area_struct___168 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___126 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___126 *, struct page___160 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___126 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___126 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___126 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___126 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___126 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___126 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___126 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___126 *, dma_addr_t);
	int (*dma_supported)(struct device___126 *, u64);
	int (*set_dma_mask)(struct device___126 *, u64);
	int is_phys;
};

struct bus_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___126 *, char *);
	ssize_t (*store)(struct bus_type___126 *, const char *, size_t);
};

struct device_attribute___126;

struct driver_attribute___126;

struct bus_type___126 {
	const char *name;
	const char *dev_name;
	struct device___126 *dev_root;
	struct bus_attribute___126 *bus_attrs;
	struct device_attribute___126 *dev_attrs;
	struct driver_attribute___126 *drv_attrs;
	const struct attribute_group___118 **bus_groups;
	const struct attribute_group___118 **dev_groups;
	const struct attribute_group___118 **drv_groups;
	int (*match)(struct device___126 *, struct device_driver___126 *);
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	int (*probe)(struct device___126 *);
	int (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*online)(struct device___126 *);
	int (*offline)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct device___126 *, struct device_attribute___126 *, char *);
	ssize_t (*store)(struct device___126 *, struct device_attribute___126 *, const char *, size_t);
};

struct driver_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___126 *, char *);
	ssize_t (*store)(struct device_driver___126 *, const char *, size_t);
};

struct device_driver___126 {
	const char *name;
	struct bus_type___126 *bus;
	struct module___80 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___126 *);
	int (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	const struct attribute_group___118 **groups;
	const struct dev_pm_ops___126 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___126 {
	const char *name;
	const struct attribute_group___118 **groups;
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
};

struct class_attribute___126;

struct class___126 {
	const char *name;
	struct module___80 *owner;
	struct class_attribute___126 *class_attrs;
	struct device_attribute___126 *dev_attrs;
	const struct attribute_group___118 **dev_groups;
	struct bin_attribute___120 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *);
	void (*class_release)(struct class___126 *);
	void (*dev_release)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
	struct subsys_private *p;
};

struct class_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct class___126 *, struct class_attribute___126 *, char *);
	ssize_t (*store)(struct class___126 *, struct class_attribute___126 *, const char *, size_t);
	const void * (*namespace)(struct class___126 *, const struct class_attribute___126 *);
};

struct device_rh___126 {
	struct dev_pm_info_rh___126 power;
};

struct vm_fault___138 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___160 *page;
};

struct dentry_operations___161;

struct super_block___161;

struct dentry___161 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___161 *d_parent;
	struct qstr d_name;
	struct inode___161 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___161 *d_op;
	struct super_block___161 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___161;

struct file_lock___161;

struct dquot___161;

struct block_device___161;

struct inode___161 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___161 *i_op;
	struct super_block___161 *i_sb;
	struct address_space___161 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___164 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___161 *i_fop;
	struct file_lock___161 *i_flock;
	struct address_space___161 i_data;
	struct dquot___161 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___161 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___161 {
	int (*d_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_hash)(const struct dentry___161 *, struct qstr *);
	int (*d_compare)(const struct dentry___161 *, const struct dentry___161 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___161 *);
	void (*d_release)(struct dentry___161 *);
	void (*d_prune)(struct dentry___161 *);
	void (*d_iput)(struct dentry___161 *, struct inode___161 *);
	char * (*d_dname)(struct dentry___161 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___161 *);
	int (*d_manage)(struct dentry___161 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___161;

struct mem_dqinfo___161 {
	struct quota_format_type___161 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___161;

struct quota_info___161 {
	unsigned int flags;
	struct mutex___164 dqio_mutex;
	struct mutex___164 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___161 *files[2];
	struct mem_dqinfo___161 info[2];
	const struct quota_format_ops___161 *ops[2];
};

struct file_system_type___161;

struct super_operations___161;

struct dquot_operations___161;

struct quotactl_ops___161;

struct super_block___161 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___161 *s_type;
	const struct super_operations___161 *s_op;
	const struct dquot_operations___161 *dq_op;
	const struct quotactl_ops___161 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___161 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___161 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___161 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___164 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___161 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___161 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___161 *bd_inode;
	struct super_block___161 *bd_super;
	struct mutex___164 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___161 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___164 bd_fsfreeze_mutex;
};

struct iattr___161 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___161 *ia_file;
};

struct dquot___161 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___164 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___161 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___161 {
	int qf_fmt_id;
	const struct quota_format_ops___161 *qf_ops;
	struct module___80 *qf_owner;
	struct quota_format_type___161 *qf_next;
};

struct quota_format_ops___161 {
	int (*check_quota_file)(struct super_block___161 *, int);
	int (*read_file_info)(struct super_block___161 *, int);
	int (*write_file_info)(struct super_block___161 *, int);
	int (*free_file_info)(struct super_block___161 *, int);
	int (*read_dqblk)(struct dquot___161 *);
	int (*commit_dqblk)(struct dquot___161 *);
	int (*release_dqblk)(struct dquot___161 *);
};

struct dquot_operations___161 {
	int (*write_dquot)(struct dquot___161 *);
	struct dquot___161 * (*alloc_dquot)(struct super_block___161 *, int);
	void (*destroy_dquot)(struct dquot___161 *);
	int (*acquire_dquot)(struct dquot___161 *);
	int (*release_dquot)(struct dquot___161 *);
	int (*mark_dirty)(struct dquot___161 *);
	int (*write_info)(struct super_block___161 *, int);
	qsize_t * (*get_reserved_space)(struct inode___161 *);
};

struct quotactl_ops___161 {
	int (*quota_on)(struct super_block___161 *, int, int, struct path___161 *);
	int (*quota_on_meta)(struct super_block___161 *, int, int);
	int (*quota_off)(struct super_block___161 *, int);
	int (*quota_sync)(struct super_block___161 *, int);
	int (*get_info)(struct super_block___161 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___161 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___161 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___161 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___161 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___161 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___161 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___161 *, unsigned int);
};

struct address_space_operations___161 {
	int (*writepage)(struct page___160 *, struct writeback_control *);
	int (*readpage)(struct file___161 *, struct page___160 *);
	int (*writepages)(struct address_space___161 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___160 *);
	int (*readpages)(struct file___161 *, struct address_space___161 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___161 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___160 **, void **);
	int (*write_end)(struct file___161 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___160 *, void *);
	sector_t (*bmap)(struct address_space___161 *, sector_t);
	void (*invalidatepage)(struct page___160 *, long unsigned int);
	int (*releasepage)(struct page___160 *, gfp_t);
	void (*freepage)(struct page___160 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___161 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___161 *, struct page___160 *, struct page___160 *, enum migrate_mode);
	int (*launder_page)(struct page___160 *);
	int (*is_partially_uptodate)(struct page___160 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___160 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___161 *, struct page___160 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___161 *, sector_t *);
	void (*swap_deactivate)(struct file___161 *);
	void (*invalidatepage_range)(struct page___160 *, unsigned int, unsigned int);
};

struct inode_operations___161 {
	struct dentry___161 * (*lookup)(struct inode___161 *, struct dentry___161 *, unsigned int);
	void * (*follow_link)(struct dentry___161 *, struct nameidata *);
	int (*permission)(struct inode___161 *, int);
	struct posix_acl * (*get_acl)(struct inode___161 *, int);
	int (*readlink)(struct dentry___161 *, char *, int);
	void (*put_link)(struct dentry___161 *, struct nameidata *, void *);
	int (*create)(struct inode___161 *, struct dentry___161 *, umode_t, bool);
	int (*link)(struct dentry___161 *, struct inode___161 *, struct dentry___161 *);
	int (*unlink)(struct inode___161 *, struct dentry___161 *);
	int (*symlink)(struct inode___161 *, struct dentry___161 *, const char *);
	int (*mkdir)(struct inode___161 *, struct dentry___161 *, umode_t);
	int (*rmdir)(struct inode___161 *, struct dentry___161 *);
	int (*mknod)(struct inode___161 *, struct dentry___161 *, umode_t, dev_t);
	int (*rename)(struct inode___161 *, struct dentry___161 *, struct inode___161 *, struct dentry___161 *);
	int (*setattr)(struct dentry___161 *, struct iattr___161 *);
	int (*getattr)(struct vfsmount *, struct dentry___161 *, struct kstat *);
	int (*setxattr)(struct dentry___161 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___161 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___161 *, char *, size_t);
	int (*removexattr)(struct dentry___161 *, const char *);
	int (*fiemap)(struct inode___161 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___161 *, struct timespec *, int);
	int (*atomic_open)(struct inode___161 *, struct dentry___161 *, struct file___161 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___161 {
	struct module___80 *owner;
	loff_t (*llseek)(struct file___161 *, loff_t, int);
	ssize_t (*read)(struct file___161 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___161 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___161 *, void *, filldir_t);
	unsigned int (*poll)(struct file___161 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___161 *, struct vm_area_struct___168 *);
	int (*open)(struct inode___161 *, struct file___161 *);
	int (*flush)(struct file___161 *, fl_owner_t);
	int (*release)(struct inode___161 *, struct file___161 *);
	int (*fsync)(struct file___161 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___161 *, int);
	int (*lock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*sendpage)(struct file___161 *, struct page___160 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___161 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___161 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___161 *, long int, struct file_lock___161 **, void **);
		struct {
			int (*setlease)(struct file___161 *, long int, struct file_lock___161 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___161 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___161 *);
};

struct file_lock_operations___161;

struct lock_manager_operations___161;

struct file_lock___161 {
	struct file_lock___161 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___161 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___161 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___161 *fl_ops;
	const struct lock_manager_operations___161 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___161 {
	void (*fl_copy_lock)(struct file_lock___161 *, struct file_lock___161 *);
	void (*fl_release_private)(struct file_lock___161 *);
};

struct lock_manager_operations___161 {
	int (*lm_compare_owner)(struct file_lock___161 *, struct file_lock___161 *);
	long unsigned int (*lm_owner_key)(struct file_lock___161 *);
	void (*lm_notify)(struct file_lock___161 *);
	int (*lm_grant)(struct file_lock___161 *, struct file_lock___161 *, int);
	void (*lm_break)(struct file_lock___161 *);
	int (*lm_change)(struct file_lock___161 **, int);
};

struct file_system_type___161 {
	const char *name;
	int fs_flags;
	struct dentry___161 * (*mount)(struct file_system_type___161 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___161 *);
	struct module___80 *owner;
	struct file_system_type___161 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___161 {
	struct inode___161 * (*alloc_inode)(struct super_block___161 *);
	void (*destroy_inode)(struct inode___161 *);
	void (*dirty_inode)(struct inode___161 *, int);
	int (*write_inode)(struct inode___161 *, struct writeback_control *);
	int (*drop_inode)(struct inode___161 *);
	void (*evict_inode)(struct inode___161 *);
	void (*put_super)(struct super_block___161 *);
	int (*sync_fs)(struct super_block___161 *, int);
	int (*freeze_fs)(struct super_block___161 *);
	int (*unfreeze_fs)(struct super_block___161 *);
	int (*statfs)(struct dentry___161 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___161 *, int *, char *);
	void (*umount_begin)(struct super_block___161 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___161 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___161 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___161 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___161 *);
	ssize_t (*quota_read)(struct super_block___161 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___161 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___161 *);
	int (*bdev_try_to_free_page)(struct super_block___161 *, struct page___160 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___161 *);
	void (*free_cached_objects)(struct super_block___161 *, int);
};

enum {
	CRYPTO_MSG_ALG_REQUEST = 0,
	CRYPTO_MSG_ALG_REGISTER = 1,
	CRYPTO_MSG_ALG_UNREGISTER = 2,
	CRYPTO_MSG_TMPL_REGISTER = 3,
	CRYPTO_MSG_TMPL_UNREGISTER = 4,
};

struct crypto_larval {
	struct crypto_alg___5 alg;
	struct crypto_alg___5 *adult;
	struct completion completion;
	u32 mask;
};

struct page___161;

typedef struct page___161 *pgtable_t___161;

struct address_space___162;

struct kmem_cache___148;

struct page___161 {
	long unsigned int flags;
	struct address_space___162 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___161 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___161 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___148 *slab_cache;
		struct page___161 *first_page;
	};
	long: 64;
};

struct task_struct___164;

struct pv_cpu_ops___164 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___164 *);
	void (*end_context_switch)(struct task_struct___164 *);
};

struct mutex___165 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___164 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___157 {
	struct page___161 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___169;

struct signal_struct___164;

struct task_struct___164 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___164 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___169 *mm;
	struct mm_struct___169 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___164 *real_parent;
	struct task_struct___164 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___164 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___164 = 0,
		VTIME_USER___164 = 1,
		VTIME_SYS___164 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___164 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___165 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___157 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___169 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___169 *, struct mm_struct___169 *);
	void (*dup_mmap)(struct mm_struct___169 *, struct mm_struct___169 *);
	void (*exit_mmap)(struct mm_struct___169 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___169 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___169 *);
	void (*pgd_free)(struct mm_struct___169 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___169 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___169 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___169 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___169 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___169 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___169 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___169 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___169 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___169 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___169 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___169 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___165 lock;
	void *vdso;
} mm_context_t___165;

struct xol_area___161;

struct uprobes_state___161 {
	struct xol_area___161 *xol_area;
};

struct vm_area_struct___169;

struct file___162;

struct core_state___164;

struct mm_struct___169 {
	struct vm_area_struct___169 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___169 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___169 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___165 context;
	long unsigned int flags;
	struct core_state___164 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___164 *owner;
	struct file___162 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___161 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___81;

struct module_kobject___80 {
	struct kobject___17 kobj;
	struct module___81 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___80;

struct module___81 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___80 mkobj;
	struct module_attribute___80 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___164 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___164;

struct lruvec___164 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___164 *zone;
};

struct pglist_data___164;

struct zone___164 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___164 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___164 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___164 {
	struct zone___164 *zone;
	int zone_idx;
};

struct zonelist___164 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___164 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___164 {
	struct zone___164 node_zones[4];
	struct zonelist___164 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___164 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___127;

struct dev_pm_ops___127 {
	int (*prepare)(struct device___127 *);
	void (*complete)(struct device___127 *);
	int (*suspend)(struct device___127 *);
	int (*resume)(struct device___127 *);
	int (*freeze)(struct device___127 *);
	int (*thaw)(struct device___127 *);
	int (*poweroff)(struct device___127 *);
	int (*restore)(struct device___127 *);
	int (*suspend_late)(struct device___127 *);
	int (*resume_early)(struct device___127 *);
	int (*freeze_late)(struct device___127 *);
	int (*thaw_early)(struct device___127 *);
	int (*poweroff_late)(struct device___127 *);
	int (*restore_early)(struct device___127 *);
	int (*suspend_noirq)(struct device___127 *);
	int (*resume_noirq)(struct device___127 *);
	int (*freeze_noirq)(struct device___127 *);
	int (*thaw_noirq)(struct device___127 *);
	int (*poweroff_noirq)(struct device___127 *);
	int (*restore_noirq)(struct device___127 *);
	int (*runtime_suspend)(struct device___127 *);
	int (*runtime_resume)(struct device___127 *);
	int (*runtime_idle)(struct device___127 *);
};

struct dma_map_ops___50;

struct dev_archdata___50 {
	struct dma_map_ops___50 *dma_ops;
	void *iommu;
};

struct device_type___127;

struct bus_type___127;

struct device_driver___127;

struct dev_pm_domain___127;

struct class___127;

struct attribute_group___119;

struct device_rh___127;

struct device___127 {
	struct device___127 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___127 *type;
	struct mutex___165 mutex;
	struct bus_type___127 *bus;
	struct device_driver___127 *driver;
	void *platform_data;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___127 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___50 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___127 *class;
	const struct attribute_group___119 **groups;
	void (*release)(struct device___127 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___127 *device_rh;
};

struct dev_pm_info_rh___127 {
	void (*set_latency_tolerance)(struct device___127 *, s32);
};

struct dev_pm_domain___127 {
	struct dev_pm_ops___127 ops;
};

struct smp_ops___164 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___164 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___121;

struct attribute_group___119 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___121 **bin_attrs;
};

struct bin_attribute___121 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___162 *, struct kobject___17 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___162 *, struct kobject___17 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	int (*mmap)(struct file___162 *, struct kobject___17 *, struct bin_attribute___121 *, struct vm_area_struct___169 *);
};

struct dentry___162;

struct path___162 {
	struct vfsmount *mnt;
	struct dentry___162 *dentry;
};

struct inode___162;

struct file_operations___162;

struct file___162 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___162 f_path;
	struct inode___162 *f_inode;
	const struct file_operations___162 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___162 *f_mapping;
	struct mutex___165 f_pos_lock;
};

struct vm_operations_struct___142;

struct vm_area_struct___169 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___169 *vm_next;
	struct vm_area_struct___169 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___169 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___142 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___162 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___147 {
	void **freelist;
	long unsigned int tid;
	struct page___161 *page;
	struct page___161 *partial;
};

struct memcg_cache_params___148;

struct kmem_cache___148 {
	struct kmem_cache_cpu___147 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___148 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___148 {
	bool is_root_cache;
	union {
		struct kmem_cache___148 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___148 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct crypto_async_request___5;

typedef void (*crypto_completion_t___5)(struct crypto_async_request___5 *, int);

struct crypto_tfm___6;

struct crypto_async_request___5 {
	struct list_head list;
	crypto_completion_t___5 complete;
	void *data;
	struct crypto_tfm___6 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___5;

struct ablkcipher_request___5;

struct ablkcipher_tfm___5 {
	int (*setkey)(struct crypto_ablkcipher___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___5 *);
	int (*decrypt)(struct ablkcipher_request___5 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___5 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___5;

struct aead_request___5;

struct aead_tfm___5 {
	int (*setkey)(struct crypto_aead___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___5 *);
	int (*decrypt)(struct aead_request___5 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___5 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___5;

struct blkcipher_tfm___5 {
	void *iv;
	int (*setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___5 {
	int (*cit_setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___6 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___6 *, u8 *, const u8 *);
};

struct hash_desc___5;

struct crypto_hash___5;

struct hash_tfm___5 {
	int (*init)(struct hash_desc___5 *);
	int (*update)(struct hash_desc___5 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___5 *, u8 *);
	int (*digest)(struct hash_desc___5 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___5 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___5 {
	int (*cot_compress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___5;

struct rng_tfm___5 {
	int (*rng_gen_random)(struct crypto_rng___5 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___5 *, u8 *, unsigned int);
};

struct crypto_alg___6;

struct crypto_tfm___6 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___5 ablkcipher;
		struct aead_tfm___5 aead;
		struct blkcipher_tfm___5 blkcipher;
		struct cipher_tfm___5 cipher;
		struct hash_tfm___5 hash;
		struct compress_tfm___5 compress;
		struct rng_tfm___5 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___6 *);
	struct crypto_alg___6 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___5 {
	struct crypto_async_request___5 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___5 {
	struct crypto_async_request___5 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___5;

struct blkcipher_desc___5 {
	struct crypto_blkcipher___5 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___5 {
	struct crypto_tfm___6 base;
};

struct hash_desc___5 {
	struct crypto_hash___5 *tfm;
	u32 flags;
};

struct crypto_hash___5 {
	struct crypto_tfm___6 base;
};

struct ablkcipher_alg___5 {
	int (*setkey)(struct crypto_ablkcipher___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___5 *);
	int (*decrypt)(struct ablkcipher_request___5 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___5 {
	struct crypto_tfm___6 base;
};

struct aead_alg___5 {
	int (*setkey)(struct crypto_aead___5 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___5 *, unsigned int);
	int (*encrypt)(struct aead_request___5 *);
	int (*decrypt)(struct aead_request___5 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___5 {
	struct crypto_tfm___6 base;
};

struct blkcipher_alg___5 {
	int (*setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___5 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
};

struct compress_alg___5 {
	int (*coa_compress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___5 {
	int (*rng_make_random)(struct crypto_rng___5 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___5 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___5 {
	struct crypto_tfm___6 base;
};

struct crypto_type___3;

struct crypto_alg___6 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type___3 *cra_type;
	union {
		struct ablkcipher_alg___5 ablkcipher;
		struct aead_alg___5 aead;
		struct blkcipher_alg___5 blkcipher;
		struct cipher_alg___5 cipher;
		struct compress_alg___5 compress;
		struct rng_alg___5 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___6 *);
	void (*cra_exit)(struct crypto_tfm___6 *);
	void (*cra_destroy)(struct crypto_alg___6 *);
	struct module___81 *cra_module;
};

struct crypto_type___3 {
	unsigned int (*ctxsize)(struct crypto_alg___6 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___6 *);
	int (*init)(struct crypto_tfm___6 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___6 *);
	void (*show)(struct seq_file___5 *, struct crypto_alg___6 *);
	int (*report)(struct sk_buff___19 *, struct crypto_alg___6 *);
	struct crypto_alg___6 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct xol_area___161 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___161 *page;
	long unsigned int vaddr;
};

struct address_space_operations___162;

struct address_space___162 {
	struct inode___162 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___165 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___162 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___139;

struct vm_operations_struct___142 {
	void (*open)(struct vm_area_struct___169 *);
	void (*close)(struct vm_area_struct___169 *);
	int (*fault)(struct vm_area_struct___169 *, struct vm_fault___139 *);
	int (*page_mkwrite)(struct vm_area_struct___169 *, struct vm_fault___139 *);
	int (*access)(struct vm_area_struct___169 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___169 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___169 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___169 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___169 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___164 {
	struct task_struct___164 *task;
	struct core_thread___164 *next;
};

struct core_state___164 {
	atomic_t nr_threads;
	struct core_thread___164 dumper;
	struct completion startup;
};

struct fasync_struct___162 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___162 *fa_next;
	struct file___162 *fa_file;
	struct callback_head fa_rcu;
};

struct dma_map_ops___50 {
	void * (*alloc)(struct device___127 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___127 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___127 *, struct vm_area_struct___169 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___127 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___127 *, struct page___161 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___127 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___127 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___127 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___127 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___127 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___127 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___127 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___127 *, dma_addr_t);
	int (*dma_supported)(struct device___127 *, u64);
	int (*set_dma_mask)(struct device___127 *, u64);
	int is_phys;
};

struct bus_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___127 *, char *);
	ssize_t (*store)(struct bus_type___127 *, const char *, size_t);
};

struct device_attribute___127;

struct driver_attribute___127;

struct bus_type___127 {
	const char *name;
	const char *dev_name;
	struct device___127 *dev_root;
	struct bus_attribute___127 *bus_attrs;
	struct device_attribute___127 *dev_attrs;
	struct driver_attribute___127 *drv_attrs;
	const struct attribute_group___119 **bus_groups;
	const struct attribute_group___119 **dev_groups;
	const struct attribute_group___119 **drv_groups;
	int (*match)(struct device___127 *, struct device_driver___127 *);
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	int (*probe)(struct device___127 *);
	int (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*online)(struct device___127 *);
	int (*offline)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct device___127 *, struct device_attribute___127 *, char *);
	ssize_t (*store)(struct device___127 *, struct device_attribute___127 *, const char *, size_t);
};

struct driver_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___127 *, char *);
	ssize_t (*store)(struct device_driver___127 *, const char *, size_t);
};

struct device_driver___127 {
	const char *name;
	struct bus_type___127 *bus;
	struct module___81 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___127 *);
	int (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	const struct attribute_group___119 **groups;
	const struct dev_pm_ops___127 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___127 {
	const char *name;
	const struct attribute_group___119 **groups;
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
};

struct class_attribute___127;

struct class___127 {
	const char *name;
	struct module___81 *owner;
	struct class_attribute___127 *class_attrs;
	struct device_attribute___127 *dev_attrs;
	const struct attribute_group___119 **dev_groups;
	struct bin_attribute___121 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *);
	void (*class_release)(struct class___127 *);
	void (*dev_release)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
	struct subsys_private *p;
};

struct class_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct class___127 *, struct class_attribute___127 *, char *);
	ssize_t (*store)(struct class___127 *, struct class_attribute___127 *, const char *, size_t);
	const void * (*namespace)(struct class___127 *, const struct class_attribute___127 *);
};

struct device_rh___127 {
	struct dev_pm_info_rh___127 power;
};

struct vm_fault___139 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___161 *page;
};

struct signal_struct___164 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___164 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___164 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___165 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___162;

struct super_block___162;

struct dentry___162 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___162 *d_parent;
	struct qstr d_name;
	struct inode___162 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___162 *d_op;
	struct super_block___162 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___162;

struct file_lock___162;

struct dquot___162;

struct block_device___162;

struct inode___162 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___162 *i_op;
	struct super_block___162 *i_sb;
	struct address_space___162 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___165 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___162 *i_fop;
	struct file_lock___162 *i_flock;
	struct address_space___162 i_data;
	struct dquot___162 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___162 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___162 {
	int (*d_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_hash)(const struct dentry___162 *, struct qstr *);
	int (*d_compare)(const struct dentry___162 *, const struct dentry___162 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___162 *);
	void (*d_release)(struct dentry___162 *);
	void (*d_prune)(struct dentry___162 *);
	void (*d_iput)(struct dentry___162 *, struct inode___162 *);
	char * (*d_dname)(struct dentry___162 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___162 *);
	int (*d_manage)(struct dentry___162 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___162;

struct mem_dqinfo___162 {
	struct quota_format_type___162 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___162;

struct quota_info___162 {
	unsigned int flags;
	struct mutex___165 dqio_mutex;
	struct mutex___165 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___162 *files[2];
	struct mem_dqinfo___162 info[2];
	const struct quota_format_ops___162 *ops[2];
};

struct file_system_type___162;

struct super_operations___162;

struct dquot_operations___162;

struct quotactl_ops___162;

struct super_block___162 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___162 *s_type;
	const struct super_operations___162 *s_op;
	const struct dquot_operations___162 *dq_op;
	const struct quotactl_ops___162 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___162 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___162 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___162 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___165 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___162 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___162 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___162 *bd_inode;
	struct super_block___162 *bd_super;
	struct mutex___165 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___162 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___165 bd_fsfreeze_mutex;
};

struct iattr___162 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___162 *ia_file;
};

struct dquot___162 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___165 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___162 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___162 {
	int qf_fmt_id;
	const struct quota_format_ops___162 *qf_ops;
	struct module___81 *qf_owner;
	struct quota_format_type___162 *qf_next;
};

struct quota_format_ops___162 {
	int (*check_quota_file)(struct super_block___162 *, int);
	int (*read_file_info)(struct super_block___162 *, int);
	int (*write_file_info)(struct super_block___162 *, int);
	int (*free_file_info)(struct super_block___162 *, int);
	int (*read_dqblk)(struct dquot___162 *);
	int (*commit_dqblk)(struct dquot___162 *);
	int (*release_dqblk)(struct dquot___162 *);
};

struct dquot_operations___162 {
	int (*write_dquot)(struct dquot___162 *);
	struct dquot___162 * (*alloc_dquot)(struct super_block___162 *, int);
	void (*destroy_dquot)(struct dquot___162 *);
	int (*acquire_dquot)(struct dquot___162 *);
	int (*release_dquot)(struct dquot___162 *);
	int (*mark_dirty)(struct dquot___162 *);
	int (*write_info)(struct super_block___162 *, int);
	qsize_t * (*get_reserved_space)(struct inode___162 *);
};

struct quotactl_ops___162 {
	int (*quota_on)(struct super_block___162 *, int, int, struct path___162 *);
	int (*quota_on_meta)(struct super_block___162 *, int, int);
	int (*quota_off)(struct super_block___162 *, int);
	int (*quota_sync)(struct super_block___162 *, int);
	int (*get_info)(struct super_block___162 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___162 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___162 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___162 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___162 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___162 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___162 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___162 *, unsigned int);
};

struct address_space_operations___162 {
	int (*writepage)(struct page___161 *, struct writeback_control *);
	int (*readpage)(struct file___162 *, struct page___161 *);
	int (*writepages)(struct address_space___162 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___161 *);
	int (*readpages)(struct file___162 *, struct address_space___162 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___162 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___161 **, void **);
	int (*write_end)(struct file___162 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___161 *, void *);
	sector_t (*bmap)(struct address_space___162 *, sector_t);
	void (*invalidatepage)(struct page___161 *, long unsigned int);
	int (*releasepage)(struct page___161 *, gfp_t);
	void (*freepage)(struct page___161 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___162 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___162 *, struct page___161 *, struct page___161 *, enum migrate_mode);
	int (*launder_page)(struct page___161 *);
	int (*is_partially_uptodate)(struct page___161 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___161 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___162 *, struct page___161 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___162 *, sector_t *);
	void (*swap_deactivate)(struct file___162 *);
	void (*invalidatepage_range)(struct page___161 *, unsigned int, unsigned int);
};

struct inode_operations___162 {
	struct dentry___162 * (*lookup)(struct inode___162 *, struct dentry___162 *, unsigned int);
	void * (*follow_link)(struct dentry___162 *, struct nameidata *);
	int (*permission)(struct inode___162 *, int);
	struct posix_acl * (*get_acl)(struct inode___162 *, int);
	int (*readlink)(struct dentry___162 *, char *, int);
	void (*put_link)(struct dentry___162 *, struct nameidata *, void *);
	int (*create)(struct inode___162 *, struct dentry___162 *, umode_t, bool);
	int (*link)(struct dentry___162 *, struct inode___162 *, struct dentry___162 *);
	int (*unlink)(struct inode___162 *, struct dentry___162 *);
	int (*symlink)(struct inode___162 *, struct dentry___162 *, const char *);
	int (*mkdir)(struct inode___162 *, struct dentry___162 *, umode_t);
	int (*rmdir)(struct inode___162 *, struct dentry___162 *);
	int (*mknod)(struct inode___162 *, struct dentry___162 *, umode_t, dev_t);
	int (*rename)(struct inode___162 *, struct dentry___162 *, struct inode___162 *, struct dentry___162 *);
	int (*setattr)(struct dentry___162 *, struct iattr___162 *);
	int (*getattr)(struct vfsmount *, struct dentry___162 *, struct kstat *);
	int (*setxattr)(struct dentry___162 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___162 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___162 *, char *, size_t);
	int (*removexattr)(struct dentry___162 *, const char *);
	int (*fiemap)(struct inode___162 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___162 *, struct timespec *, int);
	int (*atomic_open)(struct inode___162 *, struct dentry___162 *, struct file___162 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___162 {
	struct module___81 *owner;
	loff_t (*llseek)(struct file___162 *, loff_t, int);
	ssize_t (*read)(struct file___162 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___162 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___162 *, void *, filldir_t);
	unsigned int (*poll)(struct file___162 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___162 *, struct vm_area_struct___169 *);
	int (*open)(struct inode___162 *, struct file___162 *);
	int (*flush)(struct file___162 *, fl_owner_t);
	int (*release)(struct inode___162 *, struct file___162 *);
	int (*fsync)(struct file___162 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___162 *, int);
	int (*lock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*sendpage)(struct file___162 *, struct page___161 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___162 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___162 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___162 *, long int, struct file_lock___162 **, void **);
		struct {
			int (*setlease)(struct file___162 *, long int, struct file_lock___162 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___162 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___162 *);
};

struct file_lock_operations___162;

struct lock_manager_operations___162;

struct file_lock___162 {
	struct file_lock___162 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___162 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___162 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___162 *fl_ops;
	const struct lock_manager_operations___162 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___162 {
	void (*fl_copy_lock)(struct file_lock___162 *, struct file_lock___162 *);
	void (*fl_release_private)(struct file_lock___162 *);
};

struct lock_manager_operations___162 {
	int (*lm_compare_owner)(struct file_lock___162 *, struct file_lock___162 *);
	long unsigned int (*lm_owner_key)(struct file_lock___162 *);
	void (*lm_notify)(struct file_lock___162 *);
	int (*lm_grant)(struct file_lock___162 *, struct file_lock___162 *, int);
	void (*lm_break)(struct file_lock___162 *);
	int (*lm_change)(struct file_lock___162 **, int);
};

struct file_system_type___162 {
	const char *name;
	int fs_flags;
	struct dentry___162 * (*mount)(struct file_system_type___162 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___162 *);
	struct module___81 *owner;
	struct file_system_type___162 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___162 {
	struct inode___162 * (*alloc_inode)(struct super_block___162 *);
	void (*destroy_inode)(struct inode___162 *);
	void (*dirty_inode)(struct inode___162 *, int);
	int (*write_inode)(struct inode___162 *, struct writeback_control *);
	int (*drop_inode)(struct inode___162 *);
	void (*evict_inode)(struct inode___162 *);
	void (*put_super)(struct super_block___162 *);
	int (*sync_fs)(struct super_block___162 *, int);
	int (*freeze_fs)(struct super_block___162 *);
	int (*unfreeze_fs)(struct super_block___162 *);
	int (*statfs)(struct dentry___162 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___162 *, int *, char *);
	void (*umount_begin)(struct super_block___162 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___162 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___162 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___162 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___162 *);
	ssize_t (*quota_read)(struct super_block___162 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___162 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___162 *);
	int (*bdev_try_to_free_page)(struct super_block___162 *, struct page___161 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___162 *);
	void (*free_cached_objects)(struct super_block___162 *, int);
};

struct module_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___80 *, struct module_kobject___80 *, char *);
	ssize_t (*store)(struct module_attribute___80 *, struct module_kobject___80 *, const char *, size_t);
	void (*setup)(struct module___81 *, const char *);
	int (*test)(struct module___81 *);
	void (*free)(struct module___81 *);
};

struct page___162;

typedef struct page___162 *pgtable_t___162;

struct address_space___163;

struct kmem_cache___149;

struct page___162 {
	long unsigned int flags;
	struct address_space___163 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___162 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___162 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___149 *slab_cache;
		struct page___162 *first_page;
	};
	long: 64;
};

struct task_struct___165;

struct pv_cpu_ops___165 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___165 *);
	void (*end_context_switch)(struct task_struct___165 *);
};

struct mutex___166 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___165 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___158 {
	struct page___162 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___170;

struct nsproxy___98;

struct signal_struct___165;

struct css_set___106;

struct task_struct___165 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___165 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___170 *mm;
	struct mm_struct___170 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___165 *real_parent;
	struct task_struct___165 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___165 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___165 = 0,
		VTIME_USER___165 = 1,
		VTIME_SYS___165 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___98 *nsproxy;
	struct signal_struct___165 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___106 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___166 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___158 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___170 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___170 *, struct mm_struct___170 *);
	void (*dup_mmap)(struct mm_struct___170 *, struct mm_struct___170 *);
	void (*exit_mmap)(struct mm_struct___170 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___170 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___170 *);
	void (*pgd_free)(struct mm_struct___170 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___170 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___170 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___170 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___170 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___170 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___170 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___170 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___170 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___170 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___170 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___170 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___166 lock;
	void *vdso;
} mm_context_t___166;

struct xol_area___162;

struct uprobes_state___162 {
	struct xol_area___162 *xol_area;
};

struct vm_area_struct___170;

struct file___163;

struct core_state___165;

struct mm_struct___170 {
	struct vm_area_struct___170 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___170 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___170 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___166 context;
	long unsigned int flags;
	struct core_state___165 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___165 *owner;
	struct file___163 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___162 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___82;

struct module_kobject___81 {
	struct kobject___17 kobj;
	struct module___82 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___81;

struct module___82 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___81 mkobj;
	struct module_attribute___81 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___165 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___165;

struct lruvec___165 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___165 *zone;
};

struct pglist_data___165;

struct zone___165 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___165 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___165 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___165 {
	struct zone___165 *zone;
	int zone_idx;
};

struct zonelist___165 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___165 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___165 {
	struct zone___165 node_zones[4];
	struct zonelist___165 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___165 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___114;

struct x86_io_apic_ops___114 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___114 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___114;

struct irq_data___114 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___114 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___128;

struct dev_pm_ops___128 {
	int (*prepare)(struct device___128 *);
	void (*complete)(struct device___128 *);
	int (*suspend)(struct device___128 *);
	int (*resume)(struct device___128 *);
	int (*freeze)(struct device___128 *);
	int (*thaw)(struct device___128 *);
	int (*poweroff)(struct device___128 *);
	int (*restore)(struct device___128 *);
	int (*suspend_late)(struct device___128 *);
	int (*resume_early)(struct device___128 *);
	int (*freeze_late)(struct device___128 *);
	int (*thaw_early)(struct device___128 *);
	int (*poweroff_late)(struct device___128 *);
	int (*restore_early)(struct device___128 *);
	int (*suspend_noirq)(struct device___128 *);
	int (*resume_noirq)(struct device___128 *);
	int (*freeze_noirq)(struct device___128 *);
	int (*thaw_noirq)(struct device___128 *);
	int (*poweroff_noirq)(struct device___128 *);
	int (*restore_noirq)(struct device___128 *);
	int (*runtime_suspend)(struct device___128 *);
	int (*runtime_resume)(struct device___128 *);
	int (*runtime_idle)(struct device___128 *);
};

struct dev_pm_qos___21;

struct dev_pm_info___21 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___21 *qos;
};

struct dma_map_ops___51;

struct dev_archdata___51 {
	struct dma_map_ops___51 *dma_ops;
	void *iommu;
};

struct device_type___128;

struct bus_type___128;

struct device_driver___128;

struct dev_pm_domain___128;

struct class___128;

struct attribute_group___120;

struct device_rh___128;

struct device___128 {
	struct device___128 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___128 *type;
	struct mutex___166 mutex;
	struct bus_type___128 *bus;
	struct device_driver___128 *driver;
	void *platform_data;
	struct dev_pm_info___21 power;
	struct dev_pm_domain___128 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___51 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___9 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___128 *class;
	const struct attribute_group___120 **groups;
	void (*release)(struct device___128 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___128 *device_rh;
};

struct dev_pm_qos_request___21;

struct dev_pm_qos___21 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___21 *latency_req;
	struct dev_pm_qos_request___21 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___21 *latency_tolerance_req;
};

struct dev_pm_info_rh___128 {
	void (*set_latency_tolerance)(struct device___128 *, s32);
};

struct dev_pm_domain___128 {
	struct dev_pm_ops___128 ops;
};

struct smp_ops___165 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___165 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___31;

struct ctl_node___31 {
	struct rb_node node;
	struct ctl_table_header___31 *header;
};

struct ctl_table_root___31;

struct ctl_table_set___31;

struct ctl_dir___31;

struct ctl_table_header___31 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___31 *root;
	struct ctl_table_set___31 *set;
	struct ctl_dir___31 *parent;
	struct ctl_node___31 *node;
};

struct ctl_dir___31 {
	struct ctl_table_header___31 header;
	struct rb_root root;
};

struct ctl_table_set___31 {
	int (*is_seen)(struct ctl_table_set___31 *);
	struct ctl_dir___31 dir;
};

struct ctl_table_root___31 {
	struct ctl_table_set___31 default_set;
	struct ctl_table_set___31 * (*lookup)(struct ctl_table_root___31 *, struct nsproxy___98 *);
	int (*permissions)(struct ctl_table_header___31 *, struct ctl_table *);
};

struct net___30;

struct nsproxy___98 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___30 *net_ns;
};

struct bin_attribute___122;

struct attribute_group___120 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___122 **bin_attrs;
};

struct bin_attribute___122 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___163 *, struct kobject___17 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___163 *, struct kobject___17 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	int (*mmap)(struct file___163 *, struct kobject___17 *, struct bin_attribute___122 *, struct vm_area_struct___170 *);
};

struct dentry___163;

struct path___163 {
	struct vfsmount *mnt;
	struct dentry___163 *dentry;
};

struct inode___163;

struct file_operations___163;

struct file___163 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___163 f_path;
	struct inode___163 *f_inode;
	const struct file_operations___163 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___163 *f_mapping;
	struct mutex___166 f_pos_lock;
};

struct vm_operations_struct___143;

struct vm_area_struct___170 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___170 *vm_next;
	struct vm_area_struct___170 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___170 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___143 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___163 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___81 *, struct module_kobject___81 *, char *);
	ssize_t (*store)(struct module_attribute___81 *, struct module_kobject___81 *, const char *, size_t);
	void (*setup)(struct module___82 *, const char *);
	int (*test)(struct module___82 *);
	void (*free)(struct module___82 *);
};

struct file_lock___163;

struct seq_file___120;

struct file_operations___163 {
	struct module___82 *owner;
	loff_t (*llseek)(struct file___163 *, loff_t, int);
	ssize_t (*read)(struct file___163 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___163 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___163 *, void *, filldir_t);
	unsigned int (*poll)(struct file___163 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___163 *, struct vm_area_struct___170 *);
	int (*open)(struct inode___163 *, struct file___163 *);
	int (*flush)(struct file___163 *, fl_owner_t);
	int (*release)(struct inode___163 *, struct file___163 *);
	int (*fsync)(struct file___163 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___163 *, int);
	int (*lock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*sendpage)(struct file___163 *, struct page___162 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___163 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___163 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___163 *, long int, struct file_lock___163 **, void **);
		struct {
			int (*setlease)(struct file___163 *, long int, struct file_lock___163 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___163 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___120 *, struct file___163 *);
};

struct dma_map_ops___51 {
	void * (*alloc)(struct device___128 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___128 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___128 *, struct vm_area_struct___170 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___128 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___128 *, struct page___162 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___128 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___128 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___128 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___128 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___128 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___128 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___128 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___128 *, dma_addr_t);
	int (*dma_supported)(struct device___128 *, u64);
	int (*set_dma_mask)(struct device___128 *, u64);
	int is_phys;
};

struct bus_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___128 *, char *);
	ssize_t (*store)(struct bus_type___128 *, const char *, size_t);
};

struct device_attribute___128;

struct driver_attribute___128;

struct bus_type___128 {
	const char *name;
	const char *dev_name;
	struct device___128 *dev_root;
	struct bus_attribute___128 *bus_attrs;
	struct device_attribute___128 *dev_attrs;
	struct driver_attribute___128 *drv_attrs;
	const struct attribute_group___120 **bus_groups;
	const struct attribute_group___120 **dev_groups;
	const struct attribute_group___120 **drv_groups;
	int (*match)(struct device___128 *, struct device_driver___128 *);
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	int (*probe)(struct device___128 *);
	int (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*online)(struct device___128 *);
	int (*offline)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct device___128 *, struct device_attribute___128 *, char *);
	ssize_t (*store)(struct device___128 *, struct device_attribute___128 *, const char *, size_t);
};

struct driver_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___128 *, char *);
	ssize_t (*store)(struct device_driver___128 *, const char *, size_t);
};

struct device_driver___128 {
	const char *name;
	struct bus_type___128 *bus;
	struct module___82 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___128 *);
	int (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	const struct attribute_group___120 **groups;
	const struct dev_pm_ops___128 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___128 {
	const char *name;
	const struct attribute_group___120 **groups;
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
};

struct class_attribute___128;

struct class___128 {
	const char *name;
	struct module___82 *owner;
	struct class_attribute___128 *class_attrs;
	struct device_attribute___128 *dev_attrs;
	const struct attribute_group___120 **dev_groups;
	struct bin_attribute___122 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *);
	void (*class_release)(struct class___128 *);
	void (*dev_release)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
	struct subsys_private *p;
};

struct class_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct class___128 *, struct class_attribute___128 *, char *);
	ssize_t (*store)(struct class___128 *, struct class_attribute___128 *, const char *, size_t);
	const void * (*namespace)(struct class___128 *, const struct class_attribute___128 *);
};

struct device_rh___128 {
	struct dev_pm_info_rh___128 power;
};

struct dev_pm_qos_request___21 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___128 *dev;
};

struct xol_area___162 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___162 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___148;

struct memcg_cache_params___149;

struct kmem_cache___149 {
	struct kmem_cache_cpu___148 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___149 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___163;

struct address_space___163 {
	struct inode___163 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___166 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___163 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___140;

struct vm_operations_struct___143 {
	void (*open)(struct vm_area_struct___170 *);
	void (*close)(struct vm_area_struct___170 *);
	int (*fault)(struct vm_area_struct___170 *, struct vm_fault___140 *);
	int (*page_mkwrite)(struct vm_area_struct___170 *, struct vm_fault___140 *);
	int (*access)(struct vm_area_struct___170 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___170 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___170 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___170 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___170 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___165 {
	struct task_struct___165 *task;
	struct core_thread___165 *next;
};

struct core_state___165 {
	atomic_t nr_threads;
	struct core_thread___165 dumper;
	struct completion startup;
};

struct vm_fault___140 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___162 *page;
};

struct dentry_operations___163;

struct super_block___163;

struct dentry___163 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___163 *d_parent;
	struct qstr d_name;
	struct inode___163 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___163 *d_op;
	struct super_block___163 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___163;

struct dquot___163;

struct block_device___163;

struct inode___163 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___163 *i_op;
	struct super_block___163 *i_sb;
	struct address_space___163 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___166 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___163 *i_fop;
	struct file_lock___163 *i_flock;
	struct address_space___163 i_data;
	struct dquot___163 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___163 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___163 {
	int (*d_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_hash)(const struct dentry___163 *, struct qstr *);
	int (*d_compare)(const struct dentry___163 *, const struct dentry___163 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___163 *);
	void (*d_release)(struct dentry___163 *);
	void (*d_prune)(struct dentry___163 *);
	void (*d_iput)(struct dentry___163 *, struct inode___163 *);
	char * (*d_dname)(struct dentry___163 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___163 *);
	int (*d_manage)(struct dentry___163 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___163;

struct mem_dqinfo___163 {
	struct quota_format_type___163 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___163;

struct quota_info___163 {
	unsigned int flags;
	struct mutex___166 dqio_mutex;
	struct mutex___166 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___163 *files[2];
	struct mem_dqinfo___163 info[2];
	const struct quota_format_ops___163 *ops[2];
};

struct file_system_type___163;

struct super_operations___163;

struct dquot_operations___163;

struct quotactl_ops___163;

struct xattr_handler___107;

struct super_block___163 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___163 *s_type;
	const struct super_operations___163 *s_op;
	const struct dquot_operations___163 *dq_op;
	const struct quotactl_ops___163 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___163 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___107 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___163 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___163 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___166 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___163 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___163 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___163 *bd_inode;
	struct super_block___163 *bd_super;
	struct mutex___166 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___163 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___166 bd_fsfreeze_mutex;
};

struct cgroup___106;

struct cgroup_subsys_state___106 {
	struct cgroup___106 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___163 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___163 *ia_file;
};

struct dquot___163 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___166 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___163 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___163 {
	int qf_fmt_id;
	const struct quota_format_ops___163 *qf_ops;
	struct module___82 *qf_owner;
	struct quota_format_type___163 *qf_next;
};

struct quota_format_ops___163 {
	int (*check_quota_file)(struct super_block___163 *, int);
	int (*read_file_info)(struct super_block___163 *, int);
	int (*write_file_info)(struct super_block___163 *, int);
	int (*free_file_info)(struct super_block___163 *, int);
	int (*read_dqblk)(struct dquot___163 *);
	int (*commit_dqblk)(struct dquot___163 *);
	int (*release_dqblk)(struct dquot___163 *);
};

struct dquot_operations___163 {
	int (*write_dquot)(struct dquot___163 *);
	struct dquot___163 * (*alloc_dquot)(struct super_block___163 *, int);
	void (*destroy_dquot)(struct dquot___163 *);
	int (*acquire_dquot)(struct dquot___163 *);
	int (*release_dquot)(struct dquot___163 *);
	int (*mark_dirty)(struct dquot___163 *);
	int (*write_info)(struct super_block___163 *, int);
	qsize_t * (*get_reserved_space)(struct inode___163 *);
};

struct quotactl_ops___163 {
	int (*quota_on)(struct super_block___163 *, int, int, struct path___163 *);
	int (*quota_on_meta)(struct super_block___163 *, int, int);
	int (*quota_off)(struct super_block___163 *, int);
	int (*quota_sync)(struct super_block___163 *, int);
	int (*get_info)(struct super_block___163 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___163 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___163 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___163 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___163 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___163 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___163 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___163 *, unsigned int);
};

struct address_space_operations___163 {
	int (*writepage)(struct page___162 *, struct writeback_control *);
	int (*readpage)(struct file___163 *, struct page___162 *);
	int (*writepages)(struct address_space___163 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___162 *);
	int (*readpages)(struct file___163 *, struct address_space___163 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___163 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___162 **, void **);
	int (*write_end)(struct file___163 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___162 *, void *);
	sector_t (*bmap)(struct address_space___163 *, sector_t);
	void (*invalidatepage)(struct page___162 *, long unsigned int);
	int (*releasepage)(struct page___162 *, gfp_t);
	void (*freepage)(struct page___162 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___163 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___163 *, struct page___162 *, struct page___162 *, enum migrate_mode);
	int (*launder_page)(struct page___162 *);
	int (*is_partially_uptodate)(struct page___162 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___162 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___163 *, struct page___162 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___163 *, sector_t *);
	void (*swap_deactivate)(struct file___163 *);
	void (*invalidatepage_range)(struct page___162 *, unsigned int, unsigned int);
};

struct inode_operations___163 {
	struct dentry___163 * (*lookup)(struct inode___163 *, struct dentry___163 *, unsigned int);
	void * (*follow_link)(struct dentry___163 *, struct nameidata *);
	int (*permission)(struct inode___163 *, int);
	struct posix_acl * (*get_acl)(struct inode___163 *, int);
	int (*readlink)(struct dentry___163 *, char *, int);
	void (*put_link)(struct dentry___163 *, struct nameidata *, void *);
	int (*create)(struct inode___163 *, struct dentry___163 *, umode_t, bool);
	int (*link)(struct dentry___163 *, struct inode___163 *, struct dentry___163 *);
	int (*unlink)(struct inode___163 *, struct dentry___163 *);
	int (*symlink)(struct inode___163 *, struct dentry___163 *, const char *);
	int (*mkdir)(struct inode___163 *, struct dentry___163 *, umode_t);
	int (*rmdir)(struct inode___163 *, struct dentry___163 *);
	int (*mknod)(struct inode___163 *, struct dentry___163 *, umode_t, dev_t);
	int (*rename)(struct inode___163 *, struct dentry___163 *, struct inode___163 *, struct dentry___163 *);
	int (*setattr)(struct dentry___163 *, struct iattr___163 *);
	int (*getattr)(struct vfsmount *, struct dentry___163 *, struct kstat *);
	int (*setxattr)(struct dentry___163 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___163 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___163 *, char *, size_t);
	int (*removexattr)(struct dentry___163 *, const char *);
	int (*fiemap)(struct inode___163 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___163 *, struct timespec *, int);
	int (*atomic_open)(struct inode___163 *, struct dentry___163 *, struct file___163 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___163;

struct file_lock_operations___163;

struct lock_manager_operations___163;

struct file_lock___163 {
	struct file_lock___163 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___163 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___163 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___163 *fl_ops;
	const struct lock_manager_operations___163 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___163 {
	void (*fl_copy_lock)(struct file_lock___163 *, struct file_lock___163 *);
	void (*fl_release_private)(struct file_lock___163 *);
};

struct lock_manager_operations___163 {
	int (*lm_compare_owner)(struct file_lock___163 *, struct file_lock___163 *);
	long unsigned int (*lm_owner_key)(struct file_lock___163 *);
	void (*lm_notify)(struct file_lock___163 *);
	int (*lm_grant)(struct file_lock___163 *, struct file_lock___163 *, int);
	void (*lm_break)(struct file_lock___163 *);
	int (*lm_change)(struct file_lock___163 **, int);
};

struct fasync_struct___163 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___163 *fa_next;
	struct file___163 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___163 {
	const char *name;
	int fs_flags;
	struct dentry___163 * (*mount)(struct file_system_type___163 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___163 *);
	struct module___82 *owner;
	struct file_system_type___163 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___163 {
	struct inode___163 * (*alloc_inode)(struct super_block___163 *);
	void (*destroy_inode)(struct inode___163 *);
	void (*dirty_inode)(struct inode___163 *, int);
	int (*write_inode)(struct inode___163 *, struct writeback_control *);
	int (*drop_inode)(struct inode___163 *);
	void (*evict_inode)(struct inode___163 *);
	void (*put_super)(struct super_block___163 *);
	int (*sync_fs)(struct super_block___163 *, int);
	int (*freeze_fs)(struct super_block___163 *);
	int (*unfreeze_fs)(struct super_block___163 *);
	int (*statfs)(struct dentry___163 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___163 *, int *, char *);
	void (*umount_begin)(struct super_block___163 *);
	int (*show_options)(struct seq_file___120 *, struct dentry___163 *);
	int (*show_devname)(struct seq_file___120 *, struct dentry___163 *);
	int (*show_path)(struct seq_file___120 *, struct dentry___163 *);
	int (*show_stats)(struct seq_file___120 *, struct dentry___163 *);
	ssize_t (*quota_read)(struct super_block___163 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___163 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___163 *);
	int (*bdev_try_to_free_page)(struct super_block___163 *, struct page___162 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___163 *);
	void (*free_cached_objects)(struct super_block___163 *, int);
};

struct xattr_handler___107 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___163 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___163 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___163 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___119;

struct seq_file___120 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___166 lock;
	const struct seq_operations___119 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___165 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___165 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___165 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___166 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___106 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___106 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___28 {
	struct ctl_table_header___31 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___28 {
	struct mutex___166 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___28 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___31 *ctl;
};

struct netns_ipv4___28 {
	struct ctl_table_header___31 *forw_hdr;
	struct ctl_table_header___31 *frags_hdr;
	struct ctl_table_header___31 *ipv4_hdr;
	struct ctl_table_header___31 *route_hdr;
	struct ctl_table_header___31 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___28 {
	struct ctl_table_header___31 *hdr;
	struct ctl_table_header___31 *route_hdr;
	struct ctl_table_header___31 *icmp_hdr;
	struct ctl_table_header___31 *frags_hdr;
	struct ctl_table_header___31 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___19;

struct sk_buff___21;

struct dst_ops___29 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___29 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___19 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___21 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___21 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___21 *);
	int (*local_out)(struct sk_buff___21 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___21 *, const void *);
	struct kmem_cache___149 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___29 {
	struct netns_sysctl_ipv6___28 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___29 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___28 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___31 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___28 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___31 *nf_log_dir_header;
};

struct nf_proto_net___28 {
	struct ctl_table_header___31 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___28 {
	struct nf_proto_net___28 pn;
	unsigned int timeout;
};

struct nf_tcp_net___28 {
	struct nf_proto_net___28 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___28 {
	struct nf_proto_net___28 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___28 {
	struct nf_proto_net___28 pn;
	unsigned int timeout;
};

struct nf_ip_net___28 {
	struct nf_generic_net___28 generic;
	struct nf_tcp_net___28 tcp;
	struct nf_udp_net___28 udp;
	struct nf_icmp_net___28 icmp;
	struct nf_icmp_net___28 icmpv6;
};

struct netns_ct___28 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___31 *sysctl_header;
	struct ctl_table_header___31 *acct_sysctl_header;
	struct ctl_table_header___31 *tstamp_sysctl_header;
	struct ctl_table_header___31 *event_sysctl_header;
	struct ctl_table_header___31 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___149 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___28 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___28 {
	struct netns_sysctl_ipv6___28 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___18 {
	struct sk_buff___21 *next;
	struct sk_buff___21 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___29 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___31 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___29 xfrm4_dst_ops;
	struct dst_ops___29 xfrm6_dst_ops;
};

struct net___30 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___31 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___19 *loopback_dev;
	struct netns_core___28 core;
	struct netns_mib___2 mib;
	struct netns_packet___28 packet;
	struct netns_unix___28 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___28 ipv4;
	struct netns_ipv6___29 ipv6;
	struct netns_sctp___28 sctp;
	struct netns_dccp___14 dccp;
	struct netns_nf___28 nf;
	struct netns_xt xt;
	struct netns_ct___28 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___28 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___18 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___29 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___166 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___166 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___148 {
	void **freelist;
	long unsigned int tid;
	struct page___162 *page;
	struct page___162 *partial;
};

struct memcg_cache_params___149 {
	bool is_root_cache;
	union {
		struct kmem_cache___149 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___149 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___17 {
	atomic_t use;
	unsigned int mask;
	struct net_device___19 *physindev;
	struct net_device___19 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___17(struct sk_buff___21 **);

struct net_device_ops___17;

struct ethtool_ops___17;

struct header_ops___17;

struct netdev_rx_queue___17;

struct netdev_queue___17;

struct dcbnl_rtnl_ops___17;

struct net_device___19 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___17 *netdev_ops;
	const struct ethtool_ops___17 *ethtool_ops;
	const struct header_ops___17 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___17 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___17 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___17 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___17 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___17 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___17 = 0,
		NETREG_REGISTERED___17 = 1,
		NETREG_UNREGISTERING___17 = 2,
		NETREG_UNREGISTERED___17 = 3,
		NETREG_RELEASED___17 = 4,
		NETREG_DUMMY___17 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___17 = 0,
		RTNL_LINK_INITIALIZING___17 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___19 *);
	struct netpoll_info *npinfo;
	struct net___30 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___128 dev;
	const struct attribute_group___120 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___17 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___21 {
	struct sk_buff___21 *next;
	struct sk_buff___21 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___19 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___21 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___17 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___17 {
	int (*get_settings)(struct net_device___19 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___19 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___19 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___19 *);
	void (*get_regs)(struct net_device___19 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___19 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___19 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___19 *);
	void (*set_msglevel)(struct net_device___19 *, u32);
	int (*nway_reset)(struct net_device___19 *);
	u32 (*get_link)(struct net_device___19 *);
	int (*get_eeprom_len)(struct net_device___19 *);
	int (*get_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___19 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___19 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___19 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___19 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___19 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___19 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___19 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___19 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___19 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___19 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___19 *);
	void (*complete)(struct net_device___19 *);
	u32 (*get_priv_flags)(struct net_device___19 *);
	int (*set_priv_flags)(struct net_device___19 *, u32);
	int (*get_sset_count)(struct net_device___19 *, int);
	int (*get_rxnfc)(struct net_device___19 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___19 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___19 *, struct ethtool_flash *);
	int (*reset)(struct net_device___19 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___19 *);
	int (*get_rxfh_indir)(struct net_device___19 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___19 *, const u32 *);
	void (*get_channels)(struct net_device___19 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___19 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___19 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___19 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___19 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___19 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___19 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___19 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___19 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___19 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___19 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___19 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___29 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___21 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___21 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___30 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___21 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___21 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___114 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___114 *);
	void (*irq_shutdown)(struct irq_data___114 *);
	void (*irq_enable)(struct irq_data___114 *);
	void (*irq_disable)(struct irq_data___114 *);
	void (*irq_ack)(struct irq_data___114 *);
	void (*irq_mask)(struct irq_data___114 *);
	void (*irq_mask_ack)(struct irq_data___114 *);
	void (*irq_unmask)(struct irq_data___114 *);
	void (*irq_eoi)(struct irq_data___114 *);
	int (*irq_set_affinity)(struct irq_data___114 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___114 *);
	int (*irq_set_type)(struct irq_data___114 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___114 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___114 *);
	void (*irq_bus_sync_unlock)(struct irq_data___114 *);
	void (*irq_cpu_online)(struct irq_data___114 *);
	void (*irq_cpu_offline)(struct irq_data___114 *);
	void (*irq_suspend)(struct irq_data___114 *);
	void (*irq_resume)(struct irq_data___114 *);
	void (*irq_pm_shutdown)(struct irq_data___114 *);
	void (*irq_print_chip)(struct irq_data___114 *, struct seq_file___120 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___114 *, void *);
	long unsigned int flags;
};

struct seq_operations___119 {
	void * (*start)(struct seq_file___120 *, loff_t *);
	void (*stop)(struct seq_file___120 *, void *);
	void * (*next)(struct seq_file___120 *, void *, loff_t *);
	int (*show)(struct seq_file___120 *, void *);
};

struct dcbnl_rtnl_ops___17 {
	int (*ieee_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___19 *);
	u8 (*setstate)(struct net_device___19 *, u8);
	void (*getpermhwaddr)(struct net_device___19 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___19 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___19 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___19 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___19 *, int, u8 *);
	void (*setpfccfg)(struct net_device___19 *, int, u8);
	void (*getpfccfg)(struct net_device___19 *, int, u8 *);
	u8 (*setall)(struct net_device___19 *);
	u8 (*getcap)(struct net_device___19 *, int, u8 *);
	int (*getnumtcs)(struct net_device___19 *, int, u8 *);
	int (*setnumtcs)(struct net_device___19 *, int, u8);
	u8 (*getpfcstate)(struct net_device___19 *);
	void (*setpfcstate)(struct net_device___19 *, u8);
	void (*getbcncfg)(struct net_device___19 *, int, u32 *);
	void (*setbcncfg)(struct net_device___19 *, int, u32);
	void (*getbcnrp)(struct net_device___19 *, int, u8 *);
	void (*setbcnrp)(struct net_device___19 *, int, u8);
	u8 (*setapp)(struct net_device___19 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___19 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___19 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___19 *, int, u8);
	u8 (*getdcbx)(struct net_device___19 *);
	u8 (*setdcbx)(struct net_device___19 *, u8);
	int (*peer_getappinfo)(struct net_device___19 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___19 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___19 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___19 *, struct cee_pfc *);
};

struct cgroupfs_root___106;

struct cgroup___106 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___106 *parent;
	struct dentry___163 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___106 *subsys[11];
	struct cgroupfs_root___106 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___166 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___106 {
	struct super_block___163 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___106 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___18 {
	struct sk_buff___21 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___21 *, struct netlink_callback___18 *);
	int (*done)(struct netlink_callback___18 *);
	void *data;
	struct module___82 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___17 {
	int (*create)(struct sk_buff___21 *, struct net_device___19 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___21 *, unsigned char *);
	int (*rebuild)(struct sk_buff___21 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___19 *, const unsigned char *);
};

struct napi_struct___17 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___17 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___19 *dev;
	struct sk_buff___21 *gro_list;
	struct sk_buff___21 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___17 {
	struct net_device___19 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___17 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___17 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___17 kobj;
	struct net_device___19 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___17 {
	int (*ndo_init)(struct net_device___19 *);
	void (*ndo_uninit)(struct net_device___19 *);
	int (*ndo_open)(struct net_device___19 *);
	int (*ndo_stop)(struct net_device___19 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___21 *, struct net_device___19 *);
	u16 (*ndo_select_queue)(struct net_device___19 *, struct sk_buff___21 *);
	void (*ndo_change_rx_flags)(struct net_device___19 *, int);
	void (*ndo_set_rx_mode)(struct net_device___19 *);
	int (*ndo_set_mac_address)(struct net_device___19 *, void *);
	int (*ndo_validate_addr)(struct net_device___19 *);
	int (*ndo_do_ioctl)(struct net_device___19 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___19 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___19 *, int);
	int (*ndo_neigh_setup)(struct net_device___19 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___19 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___19 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___19 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___19 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___19 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___19 *);
	int (*ndo_netpoll_setup)(struct net_device___19 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___19 *);
	int (*ndo_busy_poll)(struct napi_struct___17 *);
	int (*ndo_set_vf_mac)(struct net_device___19 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___19 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___19 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___19 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___19 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___19 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___19 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___19 *, int, struct sk_buff___21 *);
	int (*ndo_setup_tc)(struct net_device___19 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___19 *);
	int (*ndo_fcoe_disable)(struct net_device___19 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___19 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___19 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___19 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___19 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___19 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___19 *, const struct sk_buff___21 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___19 *, struct net_device___19 *);
	int (*ndo_del_slave)(struct net_device___19 *, struct net_device___19 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___21 *, struct netlink_callback___18 *, struct net_device___19 *, int);
	int (*ndo_bridge_setlink)(struct net_device___19 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___21 *, u32, u32, struct net_device___19 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___19 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___19 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___19 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___19 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___19 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___19 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___21 *, struct net_device___19 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___19 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___19 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___19 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtattr {
	short unsigned int rta_len;
	short unsigned int rta_type;
};

struct crypto_async_request___6;

typedef void (*crypto_completion_t___6)(struct crypto_async_request___6 *, int);

struct crypto_tfm___7;

struct crypto_async_request___6 {
	struct list_head list;
	crypto_completion_t___6 complete;
	void *data;
	struct crypto_tfm___7 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___6;

struct ablkcipher_request___6;

struct ablkcipher_tfm___6 {
	int (*setkey)(struct crypto_ablkcipher___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___6 *);
	int (*decrypt)(struct ablkcipher_request___6 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___6 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___6;

struct aead_request___6;

struct aead_tfm___6 {
	int (*setkey)(struct crypto_aead___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___6 *);
	int (*decrypt)(struct aead_request___6 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___6 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___6;

struct blkcipher_tfm___6 {
	void *iv;
	int (*setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___6 {
	int (*cit_setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___7 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___7 *, u8 *, const u8 *);
};

struct hash_desc___6;

struct crypto_hash___6;

struct hash_tfm___6 {
	int (*init)(struct hash_desc___6 *);
	int (*update)(struct hash_desc___6 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___6 *, u8 *);
	int (*digest)(struct hash_desc___6 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___6 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___6 {
	int (*cot_compress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___6;

struct rng_tfm___6 {
	int (*rng_gen_random)(struct crypto_rng___6 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___6 *, u8 *, unsigned int);
};

struct crypto_alg___7;

struct crypto_tfm___7 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___6 ablkcipher;
		struct aead_tfm___6 aead;
		struct blkcipher_tfm___6 blkcipher;
		struct cipher_tfm___6 cipher;
		struct hash_tfm___6 hash;
		struct compress_tfm___6 compress;
		struct rng_tfm___6 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___7 *);
	struct crypto_alg___7 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___6 {
	struct crypto_async_request___6 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___6 {
	struct crypto_async_request___6 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___6;

struct blkcipher_desc___6 {
	struct crypto_blkcipher___6 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___6 {
	struct crypto_tfm___7 base;
};

struct hash_desc___6 {
	struct crypto_hash___6 *tfm;
	u32 flags;
};

struct crypto_hash___6 {
	struct crypto_tfm___7 base;
};

struct ablkcipher_alg___6 {
	int (*setkey)(struct crypto_ablkcipher___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___6 *);
	int (*decrypt)(struct ablkcipher_request___6 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___6 {
	struct crypto_tfm___7 base;
};

struct aead_alg___6 {
	int (*setkey)(struct crypto_aead___6 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___6 *, unsigned int);
	int (*encrypt)(struct aead_request___6 *);
	int (*decrypt)(struct aead_request___6 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___6 {
	struct crypto_tfm___7 base;
};

struct blkcipher_alg___6 {
	int (*setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___6 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
};

struct compress_alg___6 {
	int (*coa_compress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___6 {
	int (*rng_make_random)(struct crypto_rng___6 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___6 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___6 {
	struct crypto_tfm___7 base;
};

struct crypto_type___4;

struct crypto_alg___7 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type___4 *cra_type;
	union {
		struct ablkcipher_alg___6 ablkcipher;
		struct aead_alg___6 aead;
		struct blkcipher_alg___6 blkcipher;
		struct cipher_alg___6 cipher;
		struct compress_alg___6 compress;
		struct rng_alg___6 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___7 *);
	void (*cra_exit)(struct crypto_tfm___7 *);
	void (*cra_destroy)(struct crypto_alg___7 *);
	struct module___82 *cra_module;
};

struct crypto_type___4 {
	unsigned int (*ctxsize)(struct crypto_alg___7 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___7 *);
	int (*init)(struct crypto_tfm___7 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___7 *);
	void (*show)(struct seq_file___120 *, struct crypto_alg___7 *);
	int (*report)(struct sk_buff___21 *, struct crypto_alg___7 *);
	struct crypto_alg___7 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

enum {
	CRYPTOA_UNSPEC = 0,
	CRYPTOA_ALG = 1,
	CRYPTOA_TYPE = 2,
	CRYPTOA_U32 = 3,
	__CRYPTOA_MAX = 4,
};

struct crypto_attr_alg {
	char name[64];
};

struct crypto_attr_type {
	u32 type;
	u32 mask;
};

struct crypto_attr_u32 {
	u32 num;
};

struct crypto_template;

struct crypto_instance {
	struct crypto_alg___7 alg;
	struct crypto_template *tmpl;
	struct hlist_node list;
	void *__ctx[0];
};

struct crypto_template {
	struct list_head list;
	struct hlist_head instances;
	struct module___82 *module;
	struct crypto_instance * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance *);
	int (*create)(struct crypto_template *, struct rtattr **);
	char name[64];
};

struct crypto_spawn {
	struct list_head list;
	struct crypto_alg___7 *alg;
	struct crypto_instance *inst;
	const struct crypto_type___4 *frontend;
	u32 mask;
};

struct crypto_queue {
	struct list_head list;
	struct list_head *backlog;
	unsigned int qlen;
	unsigned int max_qlen;
};

struct crypto_larval___2 {
	struct crypto_alg___7 alg;
	struct crypto_alg___7 *adult;
	struct completion completion;
	u32 mask;
};

struct exec_domain___37 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___81 *module;
	struct exec_domain___37 *next;
};

struct thread_info___75 {
	struct task_struct___164 *task;
	struct exec_domain___37 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct scatter_walk {
	struct scatterlist *sg;
	unsigned int offset;
};

struct page___163;

typedef struct page___163 *pgtable_t___163;

struct address_space___164;

struct kmem_cache___150;

struct page___163 {
	long unsigned int flags;
	struct address_space___164 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___163 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___163 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___150 *slab_cache;
		struct page___163 *first_page;
	};
	long: 64;
};

struct task_struct___166;

struct pv_cpu_ops___166 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___166 *);
	void (*end_context_switch)(struct task_struct___166 *);
};

struct mutex___167 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___166 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___159 {
	struct page___163 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___171;

struct signal_struct___166;

struct task_struct___166 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___166 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___171 *mm;
	struct mm_struct___171 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___166 *real_parent;
	struct task_struct___166 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___166 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___166 = 0,
		VTIME_USER___166 = 1,
		VTIME_SYS___166 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___166 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___167 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___159 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___171 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___171 *, struct mm_struct___171 *);
	void (*dup_mmap)(struct mm_struct___171 *, struct mm_struct___171 *);
	void (*exit_mmap)(struct mm_struct___171 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___171 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___171 *);
	void (*pgd_free)(struct mm_struct___171 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___171 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___171 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___171 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___171 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___171 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___171 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___171 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___171 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___171 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___171 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___171 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___167 lock;
	void *vdso;
} mm_context_t___167;

struct xol_area___163;

struct uprobes_state___163 {
	struct xol_area___163 *xol_area;
};

struct vm_area_struct___171;

struct file___164;

struct core_state___166;

struct mm_struct___171 {
	struct vm_area_struct___171 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___171 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___171 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___167 context;
	long unsigned int flags;
	struct core_state___166 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___166 *owner;
	struct file___164 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___163 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___83;

struct module_kobject___82 {
	struct kobject___17 kobj;
	struct module___83 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___82;

struct module___83 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___82 mkobj;
	struct module_attribute___82 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___166 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___166;

struct lruvec___166 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___166 *zone;
};

struct pglist_data___166;

struct zone___166 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___166 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___166 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___166 {
	struct zone___166 *zone;
	int zone_idx;
};

struct zonelist___166 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___166 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___166 {
	struct zone___166 node_zones[4];
	struct zonelist___166 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___166 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___115;

struct x86_io_apic_ops___115 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___115 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___115;

struct irq_data___115 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___115 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___129;

struct dev_pm_ops___129 {
	int (*prepare)(struct device___129 *);
	void (*complete)(struct device___129 *);
	int (*suspend)(struct device___129 *);
	int (*resume)(struct device___129 *);
	int (*freeze)(struct device___129 *);
	int (*thaw)(struct device___129 *);
	int (*poweroff)(struct device___129 *);
	int (*restore)(struct device___129 *);
	int (*suspend_late)(struct device___129 *);
	int (*resume_early)(struct device___129 *);
	int (*freeze_late)(struct device___129 *);
	int (*thaw_early)(struct device___129 *);
	int (*poweroff_late)(struct device___129 *);
	int (*restore_early)(struct device___129 *);
	int (*suspend_noirq)(struct device___129 *);
	int (*resume_noirq)(struct device___129 *);
	int (*freeze_noirq)(struct device___129 *);
	int (*thaw_noirq)(struct device___129 *);
	int (*poweroff_noirq)(struct device___129 *);
	int (*restore_noirq)(struct device___129 *);
	int (*runtime_suspend)(struct device___129 *);
	int (*runtime_resume)(struct device___129 *);
	int (*runtime_idle)(struct device___129 *);
};

struct dma_map_ops___52;

struct dev_archdata___52 {
	struct dma_map_ops___52 *dma_ops;
	void *iommu;
};

struct device_type___129;

struct bus_type___129;

struct device_driver___129;

struct dev_pm_domain___129;

struct class___129;

struct attribute_group___121;

struct device_rh___129;

struct device___129 {
	struct device___129 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___129 *type;
	struct mutex___167 mutex;
	struct bus_type___129 *bus;
	struct device_driver___129 *driver;
	void *platform_data;
	struct dev_pm_info___21 power;
	struct dev_pm_domain___129 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___52 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___129 *class;
	const struct attribute_group___121 **groups;
	void (*release)(struct device___129 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___129 *device_rh;
};

struct dev_pm_info_rh___129 {
	void (*set_latency_tolerance)(struct device___129 *, s32);
};

struct dev_pm_domain___129 {
	struct dev_pm_ops___129 ops;
};

struct smp_ops___166 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___166 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___123;

struct attribute_group___121 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___123 **bin_attrs;
};

struct bin_attribute___123 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___164 *, struct kobject___17 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___164 *, struct kobject___17 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	int (*mmap)(struct file___164 *, struct kobject___17 *, struct bin_attribute___123 *, struct vm_area_struct___171 *);
};

struct dentry___164;

struct path___164 {
	struct vfsmount *mnt;
	struct dentry___164 *dentry;
};

struct inode___164;

struct file_operations___164;

struct file___164 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___164 f_path;
	struct inode___164 *f_inode;
	const struct file_operations___164 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___164 *f_mapping;
	struct mutex___167 f_pos_lock;
};

struct vm_operations_struct___144;

struct vm_area_struct___171 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___171 *vm_next;
	struct vm_area_struct___171 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___171 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___144 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___164 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___149 {
	void **freelist;
	long unsigned int tid;
	struct page___163 *page;
	struct page___163 *partial;
};

struct memcg_cache_params___150;

struct kmem_cache___150 {
	struct kmem_cache_cpu___149 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___150 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___150 {
	bool is_root_cache;
	union {
		struct kmem_cache___150 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___150 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct crypto_async_request___7;

typedef void (*crypto_completion_t___7)(struct crypto_async_request___7 *, int);

struct crypto_tfm___8;

struct crypto_async_request___7 {
	struct list_head list;
	crypto_completion_t___7 complete;
	void *data;
	struct crypto_tfm___8 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___7;

struct ablkcipher_request___7;

struct ablkcipher_tfm___7 {
	int (*setkey)(struct crypto_ablkcipher___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___7 *);
	int (*decrypt)(struct ablkcipher_request___7 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___7 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___7;

struct aead_request___7;

struct aead_tfm___7 {
	int (*setkey)(struct crypto_aead___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___7 *);
	int (*decrypt)(struct aead_request___7 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___7 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___7;

struct blkcipher_tfm___7 {
	void *iv;
	int (*setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___7 {
	int (*cit_setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___8 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___8 *, u8 *, const u8 *);
};

struct hash_desc___7;

struct crypto_hash___7;

struct hash_tfm___7 {
	int (*init)(struct hash_desc___7 *);
	int (*update)(struct hash_desc___7 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___7 *, u8 *);
	int (*digest)(struct hash_desc___7 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___7 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___7 {
	int (*cot_compress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___7;

struct rng_tfm___7 {
	int (*rng_gen_random)(struct crypto_rng___7 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___7 *, u8 *, unsigned int);
};

struct crypto_alg___8;

struct crypto_tfm___8 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___7 ablkcipher;
		struct aead_tfm___7 aead;
		struct blkcipher_tfm___7 blkcipher;
		struct cipher_tfm___7 cipher;
		struct hash_tfm___7 hash;
		struct compress_tfm___7 compress;
		struct rng_tfm___7 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___8 *);
	struct crypto_alg___8 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___7 {
	struct crypto_async_request___7 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___7 {
	struct crypto_async_request___7 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___7;

struct blkcipher_desc___7 {
	struct crypto_blkcipher___7 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___7 {
	struct crypto_tfm___8 base;
};

struct hash_desc___7 {
	struct crypto_hash___7 *tfm;
	u32 flags;
};

struct crypto_hash___7 {
	struct crypto_tfm___8 base;
};

struct ablkcipher_alg___7 {
	int (*setkey)(struct crypto_ablkcipher___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___7 *);
	int (*decrypt)(struct ablkcipher_request___7 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___7 {
	struct crypto_tfm___8 base;
};

struct aead_alg___7 {
	int (*setkey)(struct crypto_aead___7 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___7 *, unsigned int);
	int (*encrypt)(struct aead_request___7 *);
	int (*decrypt)(struct aead_request___7 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___7 {
	struct crypto_tfm___8 base;
};

struct blkcipher_alg___7 {
	int (*setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___7 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
};

struct compress_alg___7 {
	int (*coa_compress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___7 {
	int (*rng_make_random)(struct crypto_rng___7 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___7 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___7 {
	struct crypto_tfm___8 base;
};

struct crypto_type___5;

struct crypto_alg___8 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type___5 *cra_type;
	union {
		struct ablkcipher_alg___7 ablkcipher;
		struct aead_alg___7 aead;
		struct blkcipher_alg___7 blkcipher;
		struct cipher_alg___7 cipher;
		struct compress_alg___7 compress;
		struct rng_alg___7 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___8 *);
	void (*cra_exit)(struct crypto_tfm___8 *);
	void (*cra_destroy)(struct crypto_alg___8 *);
	struct module___83 *cra_module;
};

struct seq_file___121;

struct crypto_type___5 {
	unsigned int (*ctxsize)(struct crypto_alg___8 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___8 *);
	int (*init)(struct crypto_tfm___8 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___8 *);
	void (*show)(struct seq_file___121 *, struct crypto_alg___8 *);
	int (*report)(struct sk_buff___21 *, struct crypto_alg___8 *);
	struct crypto_alg___8 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct module_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___82 *, struct module_kobject___82 *, char *);
	ssize_t (*store)(struct module_attribute___82 *, struct module_kobject___82 *, const char *, size_t);
	void (*setup)(struct module___83 *, const char *);
	int (*test)(struct module___83 *);
	void (*free)(struct module___83 *);
};

struct dentry_operations___164;

struct super_block___164;

struct dentry___164 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___164 *d_parent;
	struct qstr d_name;
	struct inode___164 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___164 *d_op;
	struct super_block___164 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___164;

struct address_space___164 {
	struct inode___164 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___167 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___164 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___164;

struct file_lock___164;

struct dquot___164;

struct block_device___164;

struct inode___164 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___164 *i_op;
	struct super_block___164 *i_sb;
	struct address_space___164 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___167 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___164 *i_fop;
	struct file_lock___164 *i_flock;
	struct address_space___164 i_data;
	struct dquot___164 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___164 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___164 {
	int (*d_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_hash)(const struct dentry___164 *, struct qstr *);
	int (*d_compare)(const struct dentry___164 *, const struct dentry___164 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___164 *);
	void (*d_release)(struct dentry___164 *);
	void (*d_prune)(struct dentry___164 *);
	void (*d_iput)(struct dentry___164 *, struct inode___164 *);
	char * (*d_dname)(struct dentry___164 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___164 *);
	int (*d_manage)(struct dentry___164 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___164;

struct mem_dqinfo___164 {
	struct quota_format_type___164 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___164;

struct quota_info___164 {
	unsigned int flags;
	struct mutex___167 dqio_mutex;
	struct mutex___167 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___164 *files[2];
	struct mem_dqinfo___164 info[2];
	const struct quota_format_ops___164 *ops[2];
};

struct file_system_type___164;

struct super_operations___164;

struct dquot_operations___164;

struct quotactl_ops___164;

struct super_block___164 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___164 *s_type;
	const struct super_operations___164 *s_op;
	const struct dquot_operations___164 *dq_op;
	const struct quotactl_ops___164 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___164 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___164 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___164 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___167 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___164 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___164 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___164 *bd_inode;
	struct super_block___164 *bd_super;
	struct mutex___167 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___164 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___167 bd_fsfreeze_mutex;
};

struct iattr___164 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___164 *ia_file;
};

struct dquot___164 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___167 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___164 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___164 {
	int qf_fmt_id;
	const struct quota_format_ops___164 *qf_ops;
	struct module___83 *qf_owner;
	struct quota_format_type___164 *qf_next;
};

struct quota_format_ops___164 {
	int (*check_quota_file)(struct super_block___164 *, int);
	int (*read_file_info)(struct super_block___164 *, int);
	int (*write_file_info)(struct super_block___164 *, int);
	int (*free_file_info)(struct super_block___164 *, int);
	int (*read_dqblk)(struct dquot___164 *);
	int (*commit_dqblk)(struct dquot___164 *);
	int (*release_dqblk)(struct dquot___164 *);
};

struct dquot_operations___164 {
	int (*write_dquot)(struct dquot___164 *);
	struct dquot___164 * (*alloc_dquot)(struct super_block___164 *, int);
	void (*destroy_dquot)(struct dquot___164 *);
	int (*acquire_dquot)(struct dquot___164 *);
	int (*release_dquot)(struct dquot___164 *);
	int (*mark_dirty)(struct dquot___164 *);
	int (*write_info)(struct super_block___164 *, int);
	qsize_t * (*get_reserved_space)(struct inode___164 *);
};

struct quotactl_ops___164 {
	int (*quota_on)(struct super_block___164 *, int, int, struct path___164 *);
	int (*quota_on_meta)(struct super_block___164 *, int, int);
	int (*quota_off)(struct super_block___164 *, int);
	int (*quota_sync)(struct super_block___164 *, int);
	int (*get_info)(struct super_block___164 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___164 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___164 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___164 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___164 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___164 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___164 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___164 *, unsigned int);
};

struct address_space_operations___164 {
	int (*writepage)(struct page___163 *, struct writeback_control *);
	int (*readpage)(struct file___164 *, struct page___163 *);
	int (*writepages)(struct address_space___164 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___163 *);
	int (*readpages)(struct file___164 *, struct address_space___164 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___164 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___163 **, void **);
	int (*write_end)(struct file___164 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___163 *, void *);
	sector_t (*bmap)(struct address_space___164 *, sector_t);
	void (*invalidatepage)(struct page___163 *, long unsigned int);
	int (*releasepage)(struct page___163 *, gfp_t);
	void (*freepage)(struct page___163 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___164 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___164 *, struct page___163 *, struct page___163 *, enum migrate_mode);
	int (*launder_page)(struct page___163 *);
	int (*is_partially_uptodate)(struct page___163 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___163 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___164 *, struct page___163 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___164 *, sector_t *);
	void (*swap_deactivate)(struct file___164 *);
	void (*invalidatepage_range)(struct page___163 *, unsigned int, unsigned int);
};

struct inode_operations___164 {
	struct dentry___164 * (*lookup)(struct inode___164 *, struct dentry___164 *, unsigned int);
	void * (*follow_link)(struct dentry___164 *, struct nameidata *);
	int (*permission)(struct inode___164 *, int);
	struct posix_acl * (*get_acl)(struct inode___164 *, int);
	int (*readlink)(struct dentry___164 *, char *, int);
	void (*put_link)(struct dentry___164 *, struct nameidata *, void *);
	int (*create)(struct inode___164 *, struct dentry___164 *, umode_t, bool);
	int (*link)(struct dentry___164 *, struct inode___164 *, struct dentry___164 *);
	int (*unlink)(struct inode___164 *, struct dentry___164 *);
	int (*symlink)(struct inode___164 *, struct dentry___164 *, const char *);
	int (*mkdir)(struct inode___164 *, struct dentry___164 *, umode_t);
	int (*rmdir)(struct inode___164 *, struct dentry___164 *);
	int (*mknod)(struct inode___164 *, struct dentry___164 *, umode_t, dev_t);
	int (*rename)(struct inode___164 *, struct dentry___164 *, struct inode___164 *, struct dentry___164 *);
	int (*setattr)(struct dentry___164 *, struct iattr___164 *);
	int (*getattr)(struct vfsmount *, struct dentry___164 *, struct kstat *);
	int (*setxattr)(struct dentry___164 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___164 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___164 *, char *, size_t);
	int (*removexattr)(struct dentry___164 *, const char *);
	int (*fiemap)(struct inode___164 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___164 *, struct timespec *, int);
	int (*atomic_open)(struct inode___164 *, struct dentry___164 *, struct file___164 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___164 {
	struct module___83 *owner;
	loff_t (*llseek)(struct file___164 *, loff_t, int);
	ssize_t (*read)(struct file___164 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___164 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___164 *, void *, filldir_t);
	unsigned int (*poll)(struct file___164 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___164 *, struct vm_area_struct___171 *);
	int (*open)(struct inode___164 *, struct file___164 *);
	int (*flush)(struct file___164 *, fl_owner_t);
	int (*release)(struct inode___164 *, struct file___164 *);
	int (*fsync)(struct file___164 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___164 *, int);
	int (*lock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*sendpage)(struct file___164 *, struct page___163 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___164 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___164 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___164 *, long int, struct file_lock___164 **, void **);
		struct {
			int (*setlease)(struct file___164 *, long int, struct file_lock___164 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___164 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___121 *, struct file___164 *);
};

struct fasync_struct___164;

struct file_lock_operations___164;

struct lock_manager_operations___164;

struct file_lock___164 {
	struct file_lock___164 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___164 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___164 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___164 *fl_ops;
	const struct lock_manager_operations___164 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___164 {
	void (*fl_copy_lock)(struct file_lock___164 *, struct file_lock___164 *);
	void (*fl_release_private)(struct file_lock___164 *);
};

struct lock_manager_operations___164 {
	int (*lm_compare_owner)(struct file_lock___164 *, struct file_lock___164 *);
	long unsigned int (*lm_owner_key)(struct file_lock___164 *);
	void (*lm_notify)(struct file_lock___164 *);
	int (*lm_grant)(struct file_lock___164 *, struct file_lock___164 *, int);
	void (*lm_break)(struct file_lock___164 *);
	int (*lm_change)(struct file_lock___164 **, int);
};

struct fasync_struct___164 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___164 *fa_next;
	struct file___164 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___164 {
	const char *name;
	int fs_flags;
	struct dentry___164 * (*mount)(struct file_system_type___164 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___164 *);
	struct module___83 *owner;
	struct file_system_type___164 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___164 {
	struct inode___164 * (*alloc_inode)(struct super_block___164 *);
	void (*destroy_inode)(struct inode___164 *);
	void (*dirty_inode)(struct inode___164 *, int);
	int (*write_inode)(struct inode___164 *, struct writeback_control *);
	int (*drop_inode)(struct inode___164 *);
	void (*evict_inode)(struct inode___164 *);
	void (*put_super)(struct super_block___164 *);
	int (*sync_fs)(struct super_block___164 *, int);
	int (*freeze_fs)(struct super_block___164 *);
	int (*unfreeze_fs)(struct super_block___164 *);
	int (*statfs)(struct dentry___164 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___164 *, int *, char *);
	void (*umount_begin)(struct super_block___164 *);
	int (*show_options)(struct seq_file___121 *, struct dentry___164 *);
	int (*show_devname)(struct seq_file___121 *, struct dentry___164 *);
	int (*show_path)(struct seq_file___121 *, struct dentry___164 *);
	int (*show_stats)(struct seq_file___121 *, struct dentry___164 *);
	ssize_t (*quota_read)(struct super_block___164 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___164 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___164 *);
	int (*bdev_try_to_free_page)(struct super_block___164 *, struct page___163 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___164 *);
	void (*free_cached_objects)(struct super_block___164 *, int);
};

struct seq_operations___120;

struct seq_file___121 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___167 lock;
	const struct seq_operations___120 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___120 {
	void * (*start)(struct seq_file___121 *, loff_t *);
	void (*stop)(struct seq_file___121 *, void *);
	void * (*next)(struct seq_file___121 *, void *, loff_t *);
	int (*show)(struct seq_file___121 *, void *);
};

struct xol_area___163 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___163 *page;
	long unsigned int vaddr;
};

struct vm_fault___141;

struct vm_operations_struct___144 {
	void (*open)(struct vm_area_struct___171 *);
	void (*close)(struct vm_area_struct___171 *);
	int (*fault)(struct vm_area_struct___171 *, struct vm_fault___141 *);
	int (*page_mkwrite)(struct vm_area_struct___171 *, struct vm_fault___141 *);
	int (*access)(struct vm_area_struct___171 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___171 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___171 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___171 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___171 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___166 {
	struct task_struct___166 *task;
	struct core_thread___166 *next;
};

struct core_state___166 {
	atomic_t nr_threads;
	struct core_thread___166 dumper;
	struct completion startup;
};

struct dma_map_ops___52 {
	void * (*alloc)(struct device___129 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___129 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___129 *, struct vm_area_struct___171 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___129 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___129 *, struct page___163 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___129 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___129 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___129 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___129 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___129 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___129 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___129 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___129 *, dma_addr_t);
	int (*dma_supported)(struct device___129 *, u64);
	int (*set_dma_mask)(struct device___129 *, u64);
	int is_phys;
};

struct bus_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___129 *, char *);
	ssize_t (*store)(struct bus_type___129 *, const char *, size_t);
};

struct device_attribute___129;

struct driver_attribute___129;

struct bus_type___129 {
	const char *name;
	const char *dev_name;
	struct device___129 *dev_root;
	struct bus_attribute___129 *bus_attrs;
	struct device_attribute___129 *dev_attrs;
	struct driver_attribute___129 *drv_attrs;
	const struct attribute_group___121 **bus_groups;
	const struct attribute_group___121 **dev_groups;
	const struct attribute_group___121 **drv_groups;
	int (*match)(struct device___129 *, struct device_driver___129 *);
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	int (*probe)(struct device___129 *);
	int (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*online)(struct device___129 *);
	int (*offline)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct device___129 *, struct device_attribute___129 *, char *);
	ssize_t (*store)(struct device___129 *, struct device_attribute___129 *, const char *, size_t);
};

struct driver_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___129 *, char *);
	ssize_t (*store)(struct device_driver___129 *, const char *, size_t);
};

struct device_driver___129 {
	const char *name;
	struct bus_type___129 *bus;
	struct module___83 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___129 *);
	int (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	const struct attribute_group___121 **groups;
	const struct dev_pm_ops___129 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___129 {
	const char *name;
	const struct attribute_group___121 **groups;
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
};

struct class_attribute___129;

struct class___129 {
	const char *name;
	struct module___83 *owner;
	struct class_attribute___129 *class_attrs;
	struct device_attribute___129 *dev_attrs;
	const struct attribute_group___121 **dev_groups;
	struct bin_attribute___123 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *);
	void (*class_release)(struct class___129 *);
	void (*dev_release)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
	struct subsys_private *p;
};

struct class_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct class___129 *, struct class_attribute___129 *, char *);
	ssize_t (*store)(struct class___129 *, struct class_attribute___129 *, const char *, size_t);
	const void * (*namespace)(struct class___129 *, const struct class_attribute___129 *);
};

struct device_rh___129 {
	struct dev_pm_info_rh___129 power;
};

struct vm_fault___141 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___163 *page;
};

struct signal_struct___166 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___166 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___166 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___167 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irq_chip___115 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___115 *);
	void (*irq_shutdown)(struct irq_data___115 *);
	void (*irq_enable)(struct irq_data___115 *);
	void (*irq_disable)(struct irq_data___115 *);
	void (*irq_ack)(struct irq_data___115 *);
	void (*irq_mask)(struct irq_data___115 *);
	void (*irq_mask_ack)(struct irq_data___115 *);
	void (*irq_unmask)(struct irq_data___115 *);
	void (*irq_eoi)(struct irq_data___115 *);
	int (*irq_set_affinity)(struct irq_data___115 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___115 *);
	int (*irq_set_type)(struct irq_data___115 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___115 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___115 *);
	void (*irq_bus_sync_unlock)(struct irq_data___115 *);
	void (*irq_cpu_online)(struct irq_data___115 *);
	void (*irq_cpu_offline)(struct irq_data___115 *);
	void (*irq_suspend)(struct irq_data___115 *);
	void (*irq_resume)(struct irq_data___115 *);
	void (*irq_pm_shutdown)(struct irq_data___115 *);
	void (*irq_print_chip)(struct irq_data___115 *, struct seq_file___121 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___115 *, void *);
	long unsigned int flags;
};

struct page___164;

typedef struct page___164 *pgtable_t___164;

struct address_space___165;

struct kmem_cache___151;

struct page___164 {
	long unsigned int flags;
	struct address_space___165 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___164 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___164 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___151 *slab_cache;
		struct page___164 *first_page;
	};
	long: 64;
};

struct task_struct___167;

struct pv_cpu_ops___167 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___167 *);
	void (*end_context_switch)(struct task_struct___167 *);
};

struct mutex___168 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___167 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___160 {
	struct page___164 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___172;

struct nsproxy___99;

struct signal_struct___167;

struct css_set___107;

struct task_struct___167 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___167 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___172 *mm;
	struct mm_struct___172 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___167 *real_parent;
	struct task_struct___167 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___167 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___167 = 0,
		VTIME_USER___167 = 1,
		VTIME_SYS___167 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___99 *nsproxy;
	struct signal_struct___167 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___107 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___168 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___160 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___172 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___172 *, struct mm_struct___172 *);
	void (*dup_mmap)(struct mm_struct___172 *, struct mm_struct___172 *);
	void (*exit_mmap)(struct mm_struct___172 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___172 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___172 *);
	void (*pgd_free)(struct mm_struct___172 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___172 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___172 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___172 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___172 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___172 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___172 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___172 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___172 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___172 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___172 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___172 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___168 lock;
	void *vdso;
} mm_context_t___168;

struct xol_area___164;

struct uprobes_state___164 {
	struct xol_area___164 *xol_area;
};

struct vm_area_struct___172;

struct file___165;

struct core_state___167;

struct mm_struct___172 {
	struct vm_area_struct___172 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___172 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___172 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___168 context;
	long unsigned int flags;
	struct core_state___167 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___167 *owner;
	struct file___165 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___164 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___84;

struct exec_domain___38 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___84 *module;
	struct exec_domain___38 *next;
};

struct module_kobject___83 {
	struct kobject___17 kobj;
	struct module___84 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___83;

struct module___84 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___83 mkobj;
	struct module_attribute___83 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___167 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___76 {
	struct task_struct___167 *task;
	struct exec_domain___38 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___167;

struct lruvec___167 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___167 *zone;
};

struct pglist_data___167;

struct zone___167 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___167 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___167 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___167 {
	struct zone___167 *zone;
	int zone_idx;
};

struct zonelist___167 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___167 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___167 {
	struct zone___167 node_zones[4];
	struct zonelist___167 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___167 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___116;

struct x86_io_apic_ops___116 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___116 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___116;

struct irq_data___116 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___116 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___130;

struct dev_pm_ops___130 {
	int (*prepare)(struct device___130 *);
	void (*complete)(struct device___130 *);
	int (*suspend)(struct device___130 *);
	int (*resume)(struct device___130 *);
	int (*freeze)(struct device___130 *);
	int (*thaw)(struct device___130 *);
	int (*poweroff)(struct device___130 *);
	int (*restore)(struct device___130 *);
	int (*suspend_late)(struct device___130 *);
	int (*resume_early)(struct device___130 *);
	int (*freeze_late)(struct device___130 *);
	int (*thaw_early)(struct device___130 *);
	int (*poweroff_late)(struct device___130 *);
	int (*restore_early)(struct device___130 *);
	int (*suspend_noirq)(struct device___130 *);
	int (*resume_noirq)(struct device___130 *);
	int (*freeze_noirq)(struct device___130 *);
	int (*thaw_noirq)(struct device___130 *);
	int (*poweroff_noirq)(struct device___130 *);
	int (*restore_noirq)(struct device___130 *);
	int (*runtime_suspend)(struct device___130 *);
	int (*runtime_resume)(struct device___130 *);
	int (*runtime_idle)(struct device___130 *);
};

struct dev_pm_qos___22;

struct dev_pm_info___22 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___22 *qos;
};

struct dma_map_ops___53;

struct dev_archdata___53 {
	struct dma_map_ops___53 *dma_ops;
	void *iommu;
};

struct device_type___130;

struct bus_type___130;

struct device_driver___130;

struct dev_pm_domain___130;

struct class___130;

struct attribute_group___122;

struct device_rh___130;

struct device___130 {
	struct device___130 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___130 *type;
	struct mutex___168 mutex;
	struct bus_type___130 *bus;
	struct device_driver___130 *driver;
	void *platform_data;
	struct dev_pm_info___22 power;
	struct dev_pm_domain___130 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___53 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___130 *class;
	const struct attribute_group___122 **groups;
	void (*release)(struct device___130 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___130 *device_rh;
};

struct dev_pm_qos_request___22;

struct dev_pm_qos___22 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___22 *latency_req;
	struct dev_pm_qos_request___22 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___22 *latency_tolerance_req;
};

struct dev_pm_info_rh___130 {
	void (*set_latency_tolerance)(struct device___130 *, s32);
};

struct dev_pm_domain___130 {
	struct dev_pm_ops___130 ops;
};

struct smp_ops___167 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___167 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___124;

struct attribute_group___122 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___124 **bin_attrs;
};

struct bin_attribute___124 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___165 *, struct kobject___17 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___165 *, struct kobject___17 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	int (*mmap)(struct file___165 *, struct kobject___17 *, struct bin_attribute___124 *, struct vm_area_struct___172 *);
};

struct dentry___165;

struct path___165 {
	struct vfsmount *mnt;
	struct dentry___165 *dentry;
};

struct inode___165;

struct file_operations___165;

struct file___165 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___165 f_path;
	struct inode___165 *f_inode;
	const struct file_operations___165 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___165 *f_mapping;
	struct mutex___168 f_pos_lock;
};

struct vm_operations_struct___145;

struct vm_area_struct___172 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___172 *vm_next;
	struct vm_area_struct___172 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___172 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___145 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___165 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___150 {
	void **freelist;
	long unsigned int tid;
	struct page___164 *page;
	struct page___164 *partial;
};

struct memcg_cache_params___151;

struct kmem_cache___151 {
	struct kmem_cache_cpu___150 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___17 kobj;
	struct memcg_cache_params___151 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___151 {
	bool is_root_cache;
	union {
		struct kmem_cache___151 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___151 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct crypto_async_request___8;

typedef void (*crypto_completion_t___8)(struct crypto_async_request___8 *, int);

struct crypto_async_request___8 {
	struct list_head list;
	crypto_completion_t___8 complete;
	void *data;
	struct crypto_tfm___2 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___8;

struct ablkcipher_request___8;

struct ablkcipher_tfm___8 {
	int (*setkey)(struct crypto_ablkcipher___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___8 *);
	int (*decrypt)(struct ablkcipher_request___8 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___8 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___8;

struct aead_request___8;

struct aead_tfm___8 {
	int (*setkey)(struct crypto_aead___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___8 *);
	int (*decrypt)(struct aead_request___8 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___8 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___8;

struct blkcipher_tfm___8 {
	void *iv;
	int (*setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___8 {
	int (*cit_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct hash_desc___8;

struct crypto_hash___8;

struct hash_tfm___8 {
	int (*init)(struct hash_desc___8 *);
	int (*update)(struct hash_desc___8 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___8 *, u8 *);
	int (*digest)(struct hash_desc___8 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___8 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___8 {
	int (*cot_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___8;

struct rng_tfm___8 {
	int (*rng_gen_random)(struct crypto_rng___8 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___8 *, u8 *, unsigned int);
};

struct crypto_tfm___2 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___8 ablkcipher;
		struct aead_tfm___8 aead;
		struct blkcipher_tfm___8 blkcipher;
		struct cipher_tfm___8 cipher;
		struct hash_tfm___8 hash;
		struct compress_tfm___8 compress;
		struct rng_tfm___8 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___2 *);
	struct crypto_alg___2 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___8 {
	struct crypto_async_request___8 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___8 {
	struct crypto_async_request___8 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___8;

struct blkcipher_desc___8 {
	struct crypto_blkcipher___8 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___8 {
	struct crypto_tfm___2 base;
};

struct hash_desc___8 {
	struct crypto_hash___8 *tfm;
	u32 flags;
};

struct crypto_hash___8 {
	struct crypto_tfm___2 base;
};

struct ablkcipher_alg___8 {
	int (*setkey)(struct crypto_ablkcipher___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___8 *);
	int (*decrypt)(struct ablkcipher_request___8 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___8 {
	struct crypto_tfm___2 base;
};

struct aead_alg___8 {
	int (*setkey)(struct crypto_aead___8 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___8 *, unsigned int);
	int (*encrypt)(struct aead_request___8 *);
	int (*decrypt)(struct aead_request___8 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___8 {
	struct crypto_tfm___2 base;
};

struct aead_givcrypt_request {
	u64 seq;
	u8 *giv;
	struct aead_request___8 areq;
};

struct blkcipher_alg___8 {
	int (*setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___8 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct compress_alg___8 {
	int (*coa_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___8 {
	int (*rng_make_random)(struct crypto_rng___8 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___8 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___8 {
	struct crypto_tfm___2 base;
};

struct crypto_alg___2 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___8 ablkcipher;
		struct aead_alg___8 aead;
		struct blkcipher_alg___8 blkcipher;
		struct cipher_alg___8 cipher;
		struct compress_alg___8 compress;
		struct rng_alg___8 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___2 *);
	void (*cra_exit)(struct crypto_tfm___2 *);
	void (*cra_destroy)(struct crypto_alg___2 *);
	struct module___84 *cra_module;
};

struct xol_area___164 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___164 *page;
	long unsigned int vaddr;
};

struct address_space_operations___165;

struct address_space___165 {
	struct inode___165 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___168 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___165 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___142;

struct vm_operations_struct___145 {
	void (*open)(struct vm_area_struct___172 *);
	void (*close)(struct vm_area_struct___172 *);
	int (*fault)(struct vm_area_struct___172 *, struct vm_fault___142 *);
	int (*page_mkwrite)(struct vm_area_struct___172 *, struct vm_fault___142 *);
	int (*access)(struct vm_area_struct___172 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___172 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___172 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___172 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___172 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___167 {
	struct task_struct___167 *task;
	struct core_thread___167 *next;
};

struct core_state___167 {
	atomic_t nr_threads;
	struct core_thread___167 dumper;
	struct completion startup;
};

struct fasync_struct___165 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___165 *fa_next;
	struct file___165 *fa_file;
	struct callback_head fa_rcu;
};

struct ctl_table_root___32;

struct ctl_table_set___32;

struct ctl_dir___32;

struct ctl_node___32;

struct ctl_table_header___32 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___32 *root;
	struct ctl_table_set___32 *set;
	struct ctl_dir___32 *parent;
	struct ctl_node___32 *node;
};

struct ctl_dir___32 {
	struct ctl_table_header___32 header;
	struct rb_root root;
};

struct ctl_table_set___32 {
	int (*is_seen)(struct ctl_table_set___32 *);
	struct ctl_dir___32 dir;
};

struct netns_core___29 {
	struct ctl_table_header___32 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___29 {
	struct mutex___168 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___29 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___32 *ctl;
};

struct netns_ipv4___29 {
	struct ctl_table_header___32 *forw_hdr;
	struct ctl_table_header___32 *frags_hdr;
	struct ctl_table_header___32 *ipv4_hdr;
	struct ctl_table_header___32 *route_hdr;
	struct ctl_table_header___32 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___29 {
	struct ctl_table_header___32 *hdr;
	struct ctl_table_header___32 *route_hdr;
	struct ctl_table_header___32 *icmp_hdr;
	struct ctl_table_header___32 *frags_hdr;
	struct ctl_table_header___32 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___20;

struct dst_ops___30 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___30 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___20 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *);
	int (*local_out)(struct sk_buff___4 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	struct kmem_cache___151 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___30 {
	struct netns_sysctl_ipv6___29 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___30 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___29 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___32 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___29 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___32 *nf_log_dir_header;
};

struct nf_proto_net___29 {
	struct ctl_table_header___32 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___29 {
	struct nf_proto_net___29 pn;
	unsigned int timeout;
};

struct nf_tcp_net___29 {
	struct nf_proto_net___29 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___29 {
	struct nf_proto_net___29 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___29 {
	struct nf_proto_net___29 pn;
	unsigned int timeout;
};

struct nf_ip_net___29 {
	struct nf_generic_net___29 generic;
	struct nf_tcp_net___29 tcp;
	struct nf_udp_net___29 udp;
	struct nf_icmp_net___29 icmp;
	struct nf_icmp_net___29 icmpv6;
};

struct netns_ct___29 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___32 *sysctl_header;
	struct ctl_table_header___32 *acct_sysctl_header;
	struct ctl_table_header___32 *tstamp_sysctl_header;
	struct ctl_table_header___32 *event_sysctl_header;
	struct ctl_table_header___32 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___151 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___29 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___29 {
	struct netns_sysctl_ipv6___29 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___19 {
	struct sk_buff___4 *next;
	struct sk_buff___4 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___30 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___32 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___30 xfrm4_dst_ops;
	struct dst_ops___30 xfrm6_dst_ops;
};

struct net___31 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___32 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___20 *loopback_dev;
	struct netns_core___29 core;
	struct netns_mib___2 mib;
	struct netns_packet___29 packet;
	struct netns_unix___29 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___29 ipv4;
	struct netns_ipv6___30 ipv6;
	struct netns_sctp___29 sctp;
	struct netns_dccp___14 dccp;
	struct netns_nf___29 nf;
	struct netns_xt xt;
	struct netns_ct___29 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___29 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___19 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___30 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___168 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___168 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___53 {
	void * (*alloc)(struct device___130 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___130 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___130 *, struct vm_area_struct___172 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___130 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___130 *, struct page___164 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___130 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___130 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___130 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___130 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___130 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___130 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___130 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___130 *, dma_addr_t);
	int (*dma_supported)(struct device___130 *, u64);
	int (*set_dma_mask)(struct device___130 *, u64);
	int is_phys;
};

struct bus_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___130 *, char *);
	ssize_t (*store)(struct bus_type___130 *, const char *, size_t);
};

struct device_attribute___130;

struct driver_attribute___130;

struct bus_type___130 {
	const char *name;
	const char *dev_name;
	struct device___130 *dev_root;
	struct bus_attribute___130 *bus_attrs;
	struct device_attribute___130 *dev_attrs;
	struct driver_attribute___130 *drv_attrs;
	const struct attribute_group___122 **bus_groups;
	const struct attribute_group___122 **dev_groups;
	const struct attribute_group___122 **drv_groups;
	int (*match)(struct device___130 *, struct device_driver___130 *);
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	int (*probe)(struct device___130 *);
	int (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*online)(struct device___130 *);
	int (*offline)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct device___130 *, struct device_attribute___130 *, char *);
	ssize_t (*store)(struct device___130 *, struct device_attribute___130 *, const char *, size_t);
};

struct driver_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___130 *, char *);
	ssize_t (*store)(struct device_driver___130 *, const char *, size_t);
};

struct device_driver___130 {
	const char *name;
	struct bus_type___130 *bus;
	struct module___84 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___130 *);
	int (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	const struct attribute_group___122 **groups;
	const struct dev_pm_ops___130 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___130 {
	const char *name;
	const struct attribute_group___122 **groups;
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
};

struct class_attribute___130;

struct class___130 {
	const char *name;
	struct module___84 *owner;
	struct class_attribute___130 *class_attrs;
	struct device_attribute___130 *dev_attrs;
	const struct attribute_group___122 **dev_groups;
	struct bin_attribute___124 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *);
	void (*class_release)(struct class___130 *);
	void (*dev_release)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
	struct subsys_private *p;
};

struct class_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct class___130 *, struct class_attribute___130 *, char *);
	ssize_t (*store)(struct class___130 *, struct class_attribute___130 *, const char *, size_t);
	const void * (*namespace)(struct class___130 *, const struct class_attribute___130 *);
};

struct device_rh___130 {
	struct dev_pm_info_rh___130 power;
};

struct vm_fault___142 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___164 *page;
};

struct ctl_node___32 {
	struct rb_node node;
	struct ctl_table_header___32 *header;
};

struct ctl_table_root___32 {
	struct ctl_table_set___32 default_set;
	struct ctl_table_set___32 * (*lookup)(struct ctl_table_root___32 *, struct nsproxy___99 *);
	int (*permissions)(struct ctl_table_header___32 *, struct ctl_table *);
};

struct nsproxy___99 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___31 *net_ns;
};

struct signal_struct___167 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___167 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___167 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___168 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___107;

struct css_set___107 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___107 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___18 {
	atomic_t use;
	unsigned int mask;
	struct net_device___20 *physindev;
	struct net_device___20 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___18(struct sk_buff___4 **);

struct net_device_ops___18;

struct ethtool_ops___18;

struct header_ops___18;

struct netdev_rx_queue___18;

struct netdev_queue___18;

struct dcbnl_rtnl_ops___18;

struct net_device___20 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___18 *netdev_ops;
	const struct ethtool_ops___18 *ethtool_ops;
	const struct header_ops___18 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___17 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___18 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___18 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___18 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___18 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___18 = 0,
		NETREG_REGISTERED___18 = 1,
		NETREG_UNREGISTERING___18 = 2,
		NETREG_UNREGISTERED___18 = 3,
		NETREG_RELEASED___18 = 4,
		NETREG_DUMMY___18 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___18 = 0,
		RTNL_LINK_INITIALIZING___18 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___20 *);
	struct netpoll_info *npinfo;
	struct net___31 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___130 dev;
	const struct attribute_group___122 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___18 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___4 {
	struct sk_buff___4 *next;
	struct sk_buff___4 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___20 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___4 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___18 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct seq_operations___121;

struct seq_file___30 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___168 lock;
	const struct seq_operations___121 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct crypto_template___2;

struct crypto_instance___2 {
	struct crypto_alg___2 alg;
	struct crypto_template___2 *tmpl;
	struct hlist_node list;
	void *__ctx[0];
};

struct crypto_template___2 {
	struct list_head list;
	struct hlist_head instances;
	struct module___84 *module;
	struct crypto_instance___2 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___2 *);
	int (*create)(struct crypto_template___2 *, struct rtattr **);
	char name[64];
};

struct crypto_spawn___2 {
	struct list_head list;
	struct crypto_alg___2 *alg;
	struct crypto_instance___2 *inst;
	const struct crypto_type *frontend;
	u32 mask;
};

struct crypto_aead_spawn {
	struct crypto_spawn___2 base;
};

struct module_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___83 *, struct module_kobject___83 *, char *);
	ssize_t (*store)(struct module_attribute___83 *, struct module_kobject___83 *, const char *, size_t);
	void (*setup)(struct module___84 *, const char *);
	int (*test)(struct module___84 *);
	void (*free)(struct module___84 *);
};

struct file_lock___165;

struct file_operations___165 {
	struct module___84 *owner;
	loff_t (*llseek)(struct file___165 *, loff_t, int);
	ssize_t (*read)(struct file___165 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___165 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___165 *, void *, filldir_t);
	unsigned int (*poll)(struct file___165 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___165 *, struct vm_area_struct___172 *);
	int (*open)(struct inode___165 *, struct file___165 *);
	int (*flush)(struct file___165 *, fl_owner_t);
	int (*release)(struct inode___165 *, struct file___165 *);
	int (*fsync)(struct file___165 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___165 *, int);
	int (*lock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*sendpage)(struct file___165 *, struct page___164 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___165 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___165 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___165 *, long int, struct file_lock___165 **, void **);
		struct {
			int (*setlease)(struct file___165 *, long int, struct file_lock___165 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___165 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___30 *, struct file___165 *);
};

struct dev_pm_qos_request___22 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___130 *dev;
};

struct dentry_operations___165;

struct super_block___165;

struct dentry___165 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___165 *d_parent;
	struct qstr d_name;
	struct inode___165 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___165 *d_op;
	struct super_block___165 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___165;

struct dquot___165;

struct block_device___165;

struct inode___165 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___165 *i_op;
	struct super_block___165 *i_sb;
	struct address_space___165 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___168 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___165 *i_fop;
	struct file_lock___165 *i_flock;
	struct address_space___165 i_data;
	struct dquot___165 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___165 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___165 {
	int (*d_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_hash)(const struct dentry___165 *, struct qstr *);
	int (*d_compare)(const struct dentry___165 *, const struct dentry___165 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___165 *);
	void (*d_release)(struct dentry___165 *);
	void (*d_prune)(struct dentry___165 *);
	void (*d_iput)(struct dentry___165 *, struct inode___165 *);
	char * (*d_dname)(struct dentry___165 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___165 *);
	int (*d_manage)(struct dentry___165 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___165;

struct mem_dqinfo___165 {
	struct quota_format_type___165 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___165;

struct quota_info___165 {
	unsigned int flags;
	struct mutex___168 dqio_mutex;
	struct mutex___168 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___165 *files[2];
	struct mem_dqinfo___165 info[2];
	const struct quota_format_ops___165 *ops[2];
};

struct file_system_type___165;

struct super_operations___165;

struct dquot_operations___165;

struct quotactl_ops___165;

struct xattr_handler___108;

struct super_block___165 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___165 *s_type;
	const struct super_operations___165 *s_op;
	const struct dquot_operations___165 *dq_op;
	const struct quotactl_ops___165 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___165 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___108 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___165 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___165 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___168 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___165 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___165 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___165 *bd_inode;
	struct super_block___165 *bd_super;
	struct mutex___168 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___165 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___168 bd_fsfreeze_mutex;
};

struct cgroup___107;

struct cgroup_subsys_state___107 {
	struct cgroup___107 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___165 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___165 *ia_file;
};

struct dquot___165 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___168 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___165 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___165 {
	int qf_fmt_id;
	const struct quota_format_ops___165 *qf_ops;
	struct module___84 *qf_owner;
	struct quota_format_type___165 *qf_next;
};

struct quota_format_ops___165 {
	int (*check_quota_file)(struct super_block___165 *, int);
	int (*read_file_info)(struct super_block___165 *, int);
	int (*write_file_info)(struct super_block___165 *, int);
	int (*free_file_info)(struct super_block___165 *, int);
	int (*read_dqblk)(struct dquot___165 *);
	int (*commit_dqblk)(struct dquot___165 *);
	int (*release_dqblk)(struct dquot___165 *);
};

struct dquot_operations___165 {
	int (*write_dquot)(struct dquot___165 *);
	struct dquot___165 * (*alloc_dquot)(struct super_block___165 *, int);
	void (*destroy_dquot)(struct dquot___165 *);
	int (*acquire_dquot)(struct dquot___165 *);
	int (*release_dquot)(struct dquot___165 *);
	int (*mark_dirty)(struct dquot___165 *);
	int (*write_info)(struct super_block___165 *, int);
	qsize_t * (*get_reserved_space)(struct inode___165 *);
};

struct quotactl_ops___165 {
	int (*quota_on)(struct super_block___165 *, int, int, struct path___165 *);
	int (*quota_on_meta)(struct super_block___165 *, int, int);
	int (*quota_off)(struct super_block___165 *, int);
	int (*quota_sync)(struct super_block___165 *, int);
	int (*get_info)(struct super_block___165 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___165 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___165 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___165 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___165 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___165 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___165 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___165 *, unsigned int);
};

struct address_space_operations___165 {
	int (*writepage)(struct page___164 *, struct writeback_control *);
	int (*readpage)(struct file___165 *, struct page___164 *);
	int (*writepages)(struct address_space___165 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___164 *);
	int (*readpages)(struct file___165 *, struct address_space___165 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___165 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___164 **, void **);
	int (*write_end)(struct file___165 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___164 *, void *);
	sector_t (*bmap)(struct address_space___165 *, sector_t);
	void (*invalidatepage)(struct page___164 *, long unsigned int);
	int (*releasepage)(struct page___164 *, gfp_t);
	void (*freepage)(struct page___164 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___165 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___165 *, struct page___164 *, struct page___164 *, enum migrate_mode);
	int (*launder_page)(struct page___164 *);
	int (*is_partially_uptodate)(struct page___164 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___164 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___165 *, struct page___164 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___165 *, sector_t *);
	void (*swap_deactivate)(struct file___165 *);
	void (*invalidatepage_range)(struct page___164 *, unsigned int, unsigned int);
};

struct inode_operations___165 {
	struct dentry___165 * (*lookup)(struct inode___165 *, struct dentry___165 *, unsigned int);
	void * (*follow_link)(struct dentry___165 *, struct nameidata *);
	int (*permission)(struct inode___165 *, int);
	struct posix_acl * (*get_acl)(struct inode___165 *, int);
	int (*readlink)(struct dentry___165 *, char *, int);
	void (*put_link)(struct dentry___165 *, struct nameidata *, void *);
	int (*create)(struct inode___165 *, struct dentry___165 *, umode_t, bool);
	int (*link)(struct dentry___165 *, struct inode___165 *, struct dentry___165 *);
	int (*unlink)(struct inode___165 *, struct dentry___165 *);
	int (*symlink)(struct inode___165 *, struct dentry___165 *, const char *);
	int (*mkdir)(struct inode___165 *, struct dentry___165 *, umode_t);
	int (*rmdir)(struct inode___165 *, struct dentry___165 *);
	int (*mknod)(struct inode___165 *, struct dentry___165 *, umode_t, dev_t);
	int (*rename)(struct inode___165 *, struct dentry___165 *, struct inode___165 *, struct dentry___165 *);
	int (*setattr)(struct dentry___165 *, struct iattr___165 *);
	int (*getattr)(struct vfsmount *, struct dentry___165 *, struct kstat *);
	int (*setxattr)(struct dentry___165 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___165 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___165 *, char *, size_t);
	int (*removexattr)(struct dentry___165 *, const char *);
	int (*fiemap)(struct inode___165 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___165 *, struct timespec *, int);
	int (*atomic_open)(struct inode___165 *, struct dentry___165 *, struct file___165 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___165;

struct lock_manager_operations___165;

struct file_lock___165 {
	struct file_lock___165 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___165 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___165 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___165 *fl_ops;
	const struct lock_manager_operations___165 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___165 {
	void (*fl_copy_lock)(struct file_lock___165 *, struct file_lock___165 *);
	void (*fl_release_private)(struct file_lock___165 *);
};

struct lock_manager_operations___165 {
	int (*lm_compare_owner)(struct file_lock___165 *, struct file_lock___165 *);
	long unsigned int (*lm_owner_key)(struct file_lock___165 *);
	void (*lm_notify)(struct file_lock___165 *);
	int (*lm_grant)(struct file_lock___165 *, struct file_lock___165 *, int);
	void (*lm_break)(struct file_lock___165 *);
	int (*lm_change)(struct file_lock___165 **, int);
};

struct file_system_type___165 {
	const char *name;
	int fs_flags;
	struct dentry___165 * (*mount)(struct file_system_type___165 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___165 *);
	struct module___84 *owner;
	struct file_system_type___165 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___165 {
	struct inode___165 * (*alloc_inode)(struct super_block___165 *);
	void (*destroy_inode)(struct inode___165 *);
	void (*dirty_inode)(struct inode___165 *, int);
	int (*write_inode)(struct inode___165 *, struct writeback_control *);
	int (*drop_inode)(struct inode___165 *);
	void (*evict_inode)(struct inode___165 *);
	void (*put_super)(struct super_block___165 *);
	int (*sync_fs)(struct super_block___165 *, int);
	int (*freeze_fs)(struct super_block___165 *);
	int (*unfreeze_fs)(struct super_block___165 *);
	int (*statfs)(struct dentry___165 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___165 *, int *, char *);
	void (*umount_begin)(struct super_block___165 *);
	int (*show_options)(struct seq_file___30 *, struct dentry___165 *);
	int (*show_devname)(struct seq_file___30 *, struct dentry___165 *);
	int (*show_path)(struct seq_file___30 *, struct dentry___165 *);
	int (*show_stats)(struct seq_file___30 *, struct dentry___165 *);
	ssize_t (*quota_read)(struct super_block___165 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___165 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___165 *);
	int (*bdev_try_to_free_page)(struct super_block___165 *, struct page___164 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___165 *);
	void (*free_cached_objects)(struct super_block___165 *, int);
};

struct xattr_handler___108 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___165 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___165 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___165 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___18 {
	int (*get_settings)(struct net_device___20 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___20 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___20 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___20 *);
	void (*get_regs)(struct net_device___20 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___20 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___20 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___20 *);
	void (*set_msglevel)(struct net_device___20 *, u32);
	int (*nway_reset)(struct net_device___20 *);
	u32 (*get_link)(struct net_device___20 *);
	int (*get_eeprom_len)(struct net_device___20 *);
	int (*get_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___20 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___20 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___20 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___20 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___20 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___20 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___20 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___20 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___20 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___20 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___20 *);
	void (*complete)(struct net_device___20 *);
	u32 (*get_priv_flags)(struct net_device___20 *);
	int (*set_priv_flags)(struct net_device___20 *, u32);
	int (*get_sset_count)(struct net_device___20 *, int);
	int (*get_rxnfc)(struct net_device___20 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___20 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___20 *, struct ethtool_flash *);
	int (*reset)(struct net_device___20 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___20 *);
	int (*get_rxfh_indir)(struct net_device___20 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___20 *, const u32 *);
	void (*get_channels)(struct net_device___20 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___20 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___20 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___20 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___20 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___20 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___20 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___20 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___20 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___20 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___20 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___20 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___30 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___4 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___4 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___31 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___4 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___4 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___116 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___116 *);
	void (*irq_shutdown)(struct irq_data___116 *);
	void (*irq_enable)(struct irq_data___116 *);
	void (*irq_disable)(struct irq_data___116 *);
	void (*irq_ack)(struct irq_data___116 *);
	void (*irq_mask)(struct irq_data___116 *);
	void (*irq_mask_ack)(struct irq_data___116 *);
	void (*irq_unmask)(struct irq_data___116 *);
	void (*irq_eoi)(struct irq_data___116 *);
	int (*irq_set_affinity)(struct irq_data___116 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___116 *);
	int (*irq_set_type)(struct irq_data___116 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___116 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___116 *);
	void (*irq_bus_sync_unlock)(struct irq_data___116 *);
	void (*irq_cpu_online)(struct irq_data___116 *);
	void (*irq_cpu_offline)(struct irq_data___116 *);
	void (*irq_suspend)(struct irq_data___116 *);
	void (*irq_resume)(struct irq_data___116 *);
	void (*irq_pm_shutdown)(struct irq_data___116 *);
	void (*irq_print_chip)(struct irq_data___116 *, struct seq_file___30 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___116 *, void *);
	long unsigned int flags;
};

struct seq_operations___121 {
	void * (*start)(struct seq_file___30 *, loff_t *);
	void (*stop)(struct seq_file___30 *, void *);
	void * (*next)(struct seq_file___30 *, void *, loff_t *);
	int (*show)(struct seq_file___30 *, void *);
};

struct dcbnl_rtnl_ops___18 {
	int (*ieee_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___20 *);
	u8 (*setstate)(struct net_device___20 *, u8);
	void (*getpermhwaddr)(struct net_device___20 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___20 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___20 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___20 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___20 *, int, u8 *);
	void (*setpfccfg)(struct net_device___20 *, int, u8);
	void (*getpfccfg)(struct net_device___20 *, int, u8 *);
	u8 (*setall)(struct net_device___20 *);
	u8 (*getcap)(struct net_device___20 *, int, u8 *);
	int (*getnumtcs)(struct net_device___20 *, int, u8 *);
	int (*setnumtcs)(struct net_device___20 *, int, u8);
	u8 (*getpfcstate)(struct net_device___20 *);
	void (*setpfcstate)(struct net_device___20 *, u8);
	void (*getbcncfg)(struct net_device___20 *, int, u32 *);
	void (*setbcncfg)(struct net_device___20 *, int, u32);
	void (*getbcnrp)(struct net_device___20 *, int, u8 *);
	void (*setbcnrp)(struct net_device___20 *, int, u8);
	u8 (*setapp)(struct net_device___20 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___20 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___20 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___20 *, int, u8);
	u8 (*getdcbx)(struct net_device___20 *);
	u8 (*setdcbx)(struct net_device___20 *, u8);
	int (*peer_getappinfo)(struct net_device___20 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___20 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___20 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___20 *, struct cee_pfc *);
};

struct cgroupfs_root___107;

struct cgroup___107 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___107 *parent;
	struct dentry___165 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___107 *subsys[11];
	struct cgroupfs_root___107 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___168 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___107 {
	struct super_block___165 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___107 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___19 {
	struct sk_buff___4 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___4 *, struct netlink_callback___19 *);
	int (*done)(struct netlink_callback___19 *);
	void *data;
	struct module___84 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___18 {
	int (*create)(struct sk_buff___4 *, struct net_device___20 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___4 *, unsigned char *);
	int (*rebuild)(struct sk_buff___4 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___20 *, const unsigned char *);
};

struct napi_struct___18 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___18 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___20 *dev;
	struct sk_buff___4 *gro_list;
	struct sk_buff___4 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___18 {
	struct net_device___20 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___17 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___18 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___17 kobj;
	struct net_device___20 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___18 {
	int (*ndo_init)(struct net_device___20 *);
	void (*ndo_uninit)(struct net_device___20 *);
	int (*ndo_open)(struct net_device___20 *);
	int (*ndo_stop)(struct net_device___20 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___4 *, struct net_device___20 *);
	u16 (*ndo_select_queue)(struct net_device___20 *, struct sk_buff___4 *);
	void (*ndo_change_rx_flags)(struct net_device___20 *, int);
	void (*ndo_set_rx_mode)(struct net_device___20 *);
	int (*ndo_set_mac_address)(struct net_device___20 *, void *);
	int (*ndo_validate_addr)(struct net_device___20 *);
	int (*ndo_do_ioctl)(struct net_device___20 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___20 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___20 *, int);
	int (*ndo_neigh_setup)(struct net_device___20 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___20 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___20 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___20 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___20 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___20 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___20 *);
	int (*ndo_netpoll_setup)(struct net_device___20 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___20 *);
	int (*ndo_busy_poll)(struct napi_struct___18 *);
	int (*ndo_set_vf_mac)(struct net_device___20 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___20 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___20 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___20 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___20 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___20 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___20 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___20 *, int, struct sk_buff___4 *);
	int (*ndo_setup_tc)(struct net_device___20 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___20 *);
	int (*ndo_fcoe_disable)(struct net_device___20 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___20 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___20 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___20 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___20 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___20 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___20 *, const struct sk_buff___4 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___20 *, struct net_device___20 *);
	int (*ndo_del_slave)(struct net_device___20 *, struct net_device___20 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___4 *, struct netlink_callback___19 *, struct net_device___20 *, int);
	int (*ndo_bridge_setlink)(struct net_device___20 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___4 *, u32, u32, struct net_device___20 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___20 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___20 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___20 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___20 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___20 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___20 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___4 *, struct net_device___20 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___20 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___20 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___20 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum crypto_attr_type_t {
	CRYPTOCFGA_UNSPEC = 0,
	CRYPTOCFGA_PRIORITY_VAL = 1,
	CRYPTOCFGA_REPORT_LARVAL = 2,
	CRYPTOCFGA_REPORT_HASH = 3,
	CRYPTOCFGA_REPORT_BLKCIPHER = 4,
	CRYPTOCFGA_REPORT_AEAD = 5,
	CRYPTOCFGA_REPORT_COMPRESS = 6,
	CRYPTOCFGA_REPORT_RNG = 7,
	CRYPTOCFGA_REPORT_CIPHER = 8,
	__CRYPTOCFGA_MAX = 9,
};

struct crypto_report_aead {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int maxauthsize;
	unsigned int ivsize;
};

struct skcipher_givcrypt_request {
	u64 seq;
	u8 *giv;
	struct ablkcipher_request___8 creq;
};

struct ablkcipher_walk {
	struct {
		struct page___164 *page;
		unsigned int offset;
	} src;
	struct {
		struct page___164 *page;
		unsigned int offset;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	struct list_head buffers;
	u8 *iv_buffer;
	u8 *iv;
	int flags;
	unsigned int blocksize;
};

struct crypto_skcipher_spawn {
	struct crypto_spawn___2 base;
};

struct crypto_report_blkcipher {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct ablkcipher_buffer {
	struct list_head entry;
	struct scatter_walk dst;
	unsigned int len;
	void *data;
};

enum {
	ABLKCIPHER_WALK_SLOW = 1,
};

struct blkcipher_walk {
	union {
		struct {
			struct page___164 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			u8 *addr;
		} virt;
	} src;
	union {
		struct {
			struct page___164 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			u8 *addr;
		} virt;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	void *page;
	u8 *buffer;
	u8 *iv;
	int flags;
	unsigned int blocksize;
};

enum {
	BLKCIPHER_WALK_PHYS = 1,
	BLKCIPHER_WALK_SLOW = 2,
	BLKCIPHER_WALK_COPY = 4,
	BLKCIPHER_WALK_DIFF = 8,
};

enum {
	CHAINIV_STATE_INUSE = 0,
};

struct chainiv_ctx {
	spinlock_t lock;
	char iv[0];
};

struct async_chainiv_ctx {
	long unsigned int state;
	spinlock_t lock;
	int err;
	struct crypto_queue queue;
	struct work_struct postponed;
	char iv[0];
};

struct eseqiv_request_ctx {
	struct scatterlist src[2];
	struct scatterlist dst[2];
	char tail[0];
};

struct eseqiv_ctx {
	spinlock_t lock;
	unsigned int reqoff;
	char salt[0];
};

struct seqiv_ctx {
	spinlock_t lock;
	u8 salt[0];
};

struct hash_alg_common {
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg___2 base;
};

struct ahash_request {
	struct crypto_async_request___8 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	void *__ctx[0];
};

struct crypto_ahash;

struct ahash_alg {
	int (*init)(struct ahash_request *);
	int (*update)(struct ahash_request *);
	int (*final)(struct ahash_request *);
	int (*finup)(struct ahash_request *);
	int (*digest)(struct ahash_request *);
	int (*export)(struct ahash_request *, void *);
	int (*import)(struct ahash_request *, const void *);
	int (*setkey)(struct crypto_ahash *, const u8 *, unsigned int);
	struct hash_alg_common halg;
};

struct crypto_ahash {
	int (*init)(struct ahash_request *);
	int (*update)(struct ahash_request *);
	int (*final)(struct ahash_request *);
	int (*finup)(struct ahash_request *);
	int (*digest)(struct ahash_request *);
	int (*export)(struct ahash_request *, void *);
	int (*import)(struct ahash_request *, const void *);
	int (*setkey)(struct crypto_ahash *, const u8 *, unsigned int);
	unsigned int reqsize;
	struct crypto_tfm___2 base;
};

struct crypto_hash_walk {
	char *data;
	unsigned int offset;
	unsigned int alignmask;
	struct page___164 *pg;
	unsigned int entrylen;
	unsigned int total;
	struct scatterlist *sg;
	unsigned int flags;
};

struct ahash_instance {
	struct ahash_alg alg;
};

struct crypto_ahash_spawn {
	struct crypto_spawn___2 base;
};

struct crypto_report_hash {
	char type[64];
	unsigned int blocksize;
	unsigned int digestsize;
};

struct ahash_request_priv {
	crypto_completion_t___8 complete;
	void *data;
	u8 *result;
	void *ubuf[0];
};

struct crypto_shash___3;

struct shash_desc___3 {
	struct crypto_shash___3 *tfm;
	u32 flags;
	void *__ctx[0];
};

struct crypto_shash___3 {
	unsigned int descsize;
	struct crypto_tfm___2 base;
};

struct shash_alg___3 {
	int (*init)(struct shash_desc___3 *);
	int (*update)(struct shash_desc___3 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___3 *, u8 *);
	int (*finup)(struct shash_desc___3 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___3 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___3 *, void *);
	int (*import)(struct shash_desc___3 *, const void *);
	int (*setkey)(struct crypto_shash___3 *, const u8 *, unsigned int);
	unsigned int descsize;
	int: 32;
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg___2 base;
};

struct shash_instance {
	struct shash_alg___3 alg;
};

struct crypto_shash_spawn {
	struct crypto_spawn___2 base;
};

struct crypto_report_comp {
	char type[64];
};

struct comp_request {
	const void *next_in;
	void *next_out;
	unsigned int avail_in;
	unsigned int avail_out;
};

struct crypto_pcomp {
	struct crypto_tfm___2 base;
};

struct pcomp_alg {
	int (*compress_setup)(struct crypto_pcomp *, void *, unsigned int);
	int (*compress_init)(struct crypto_pcomp *);
	int (*compress_update)(struct crypto_pcomp *, struct comp_request *);
	int (*compress_final)(struct crypto_pcomp *, struct comp_request *);
	int (*decompress_setup)(struct crypto_pcomp *, void *, unsigned int);
	int (*decompress_init)(struct crypto_pcomp *);
	int (*decompress_update)(struct crypto_pcomp *, struct comp_request *);
	int (*decompress_final)(struct crypto_pcomp *, struct comp_request *);
	struct crypto_alg___2 base;
};

struct crypto_larval___3 {
	struct crypto_alg___2 alg;
	struct crypto_alg___2 *adult;
	struct completion completion;
	u32 mask;
};

struct cryptomgr_param {
	struct rtattr *tb[34];
	struct {
		struct rtattr attr;
		struct crypto_attr_type data;
	} type;
	union {
		struct rtattr attr;
		struct {
			struct rtattr attr;
			struct crypto_attr_alg data;
		} alg;
		struct {
			struct rtattr attr;
			struct crypto_attr_u32 data;
		} nu32;
	} attrs[32];
	char template[64];
	struct crypto_larval___3 *larval;
	u32 otype;
	u32 omask;
};

struct crypto_test_param {
	char driver[64];
	char alg[64];
	u32 type;
};

struct crypto_cipher {
	struct crypto_tfm___2 base;
};

struct crypto_comp___2 {
	struct crypto_tfm___2 base;
};

struct drbg_string {
	const unsigned char *buf;
	size_t len;
	struct list_head list;
};

struct drbg_test_data {
	struct drbg_string *testentropy;
};

struct drbg_gen {
	unsigned char *outbuf;
	unsigned int outlen;
	struct drbg_string *addtl;
	struct drbg_test_data *test_data;
};

enum zlib_comp_params {
	ZLIB_COMP_LEVEL = 1,
	ZLIB_COMP_METHOD = 2,
	ZLIB_COMP_WINDOWBITS = 3,
	ZLIB_COMP_MEMLEVEL = 4,
	ZLIB_COMP_STRATEGY = 5,
	__ZLIB_COMP_MAX = 6,
};

enum zlib_decomp_params {
	ZLIB_DECOMP_WINDOWBITS = 1,
	__ZLIB_DECOMP_MAX = 2,
};

struct hash_testvec {
	char *key;
	char *plaintext;
	char *digest;
	unsigned char tap[8];
	short unsigned int psize;
	unsigned char np;
	unsigned char ksize;
};

struct cipher_testvec {
	char *key;
	char *iv;
	char *input;
	char *result;
	short unsigned int tap[8];
	int np;
	unsigned char also_non_np;
	unsigned char fail;
	unsigned char wk;
	unsigned char klen;
	short unsigned int ilen;
	short unsigned int rlen;
};

struct aead_testvec {
	char *key;
	char *iv;
	char *input;
	char *assoc;
	char *result;
	unsigned char tap[8];
	unsigned char atap[8];
	int np;
	int anp;
	unsigned char fail;
	unsigned char novrfy;
	unsigned char wk;
	unsigned char klen;
	short unsigned int ilen;
	short unsigned int alen;
	short unsigned int rlen;
};

struct cprng_testvec {
	char *key;
	char *dt;
	char *v;
	char *result;
	unsigned char klen;
	short unsigned int dtlen;
	short unsigned int vlen;
	short unsigned int rlen;
	short unsigned int loops;
};

struct drbg_testvec {
	unsigned char *entropy;
	size_t entropylen;
	unsigned char *entpra;
	unsigned char *entprb;
	size_t entprlen;
	unsigned char *addtla;
	unsigned char *addtlb;
	size_t addtllen;
	unsigned char *pers;
	size_t perslen;
	unsigned char *expected;
	size_t expectedlen;
};

struct comp_testvec {
	int inlen;
	int outlen;
	char input[512];
	char output[512];
};

struct pcomp_testvec {
	void *params;
	unsigned int paramsize;
	int inlen;
	int outlen;
	char input[512];
	char output[512];
};

struct tcrypt_result {
	struct completion completion;
	int err;
};

struct aead_test_suite {
	struct {
		struct aead_testvec *vecs;
		unsigned int count;
	} enc;
	struct {
		struct aead_testvec *vecs;
		unsigned int count;
	} dec;
};

struct cipher_test_suite {
	struct {
		struct cipher_testvec *vecs;
		unsigned int count;
	} enc;
	struct {
		struct cipher_testvec *vecs;
		unsigned int count;
	} dec;
};

struct comp_test_suite {
	struct {
		struct comp_testvec *vecs;
		unsigned int count;
	} comp;
	struct {
		struct comp_testvec *vecs;
		unsigned int count;
	} decomp;
};

struct pcomp_test_suite {
	struct {
		struct pcomp_testvec *vecs;
		unsigned int count;
	} comp;
	struct {
		struct pcomp_testvec *vecs;
		unsigned int count;
	} decomp;
};

struct hash_test_suite {
	struct hash_testvec *vecs;
	unsigned int count;
};

struct cprng_test_suite {
	struct cprng_testvec *vecs;
	unsigned int count;
};

struct drbg_test_suite {
	struct drbg_testvec *vecs;
	unsigned int count;
};

struct alg_test_desc {
	const char *alg;
	int (*test)(const struct alg_test_desc *, const char *, u32, u32);
	int fips_allowed;
	union {
		struct aead_test_suite aead;
		struct cipher_test_suite cipher;
		struct comp_test_suite comp;
		struct pcomp_test_suite pcomp;
		struct hash_test_suite hash;
		struct cprng_test_suite cprng;
		struct drbg_test_suite drbg;
	} suite;
};

struct hmac_ctx {
	struct crypto_shash___3 *hash;
};

struct md5_state {
	u32 hash[4];
	u32 block[16];
	u64 byte_count;
};

struct sha1_state {
	u64 count;
	u32 state[5];
	u8 buffer[64];
};

struct sha256_state {
	u64 count;
	u32 state[8];
	u8 buf[64];
};

struct crypto_ecb_ctx {
	struct crypto_cipher *child;
};

struct crypto_cbc_ctx {
	struct crypto_cipher *child;
};

struct crypto_ctr_ctx {
	struct crypto_cipher *child;
};

struct crypto_rfc3686_ctx {
	struct crypto_ablkcipher___8 *child;
	u8 nonce[4];
};

struct crypto_rfc3686_req_ctx {
	u8 iv[16];
	struct ablkcipher_request___8 subreq;
};

struct chksum_ctx {
	u32 key;
};

struct chksum_desc_ctx {
	u32 crc;
};

struct lzo_ctx {
	void *lzo_comp_mem;
};

struct crypto_report_rng {
	char type[64];
	unsigned int seedsize;
};

struct page___165;

typedef struct page___165 *pgtable_t___165;

struct address_space___166;

struct kmem_cache___152;

struct page___165 {
	long unsigned int flags;
	struct address_space___166 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___165 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___165 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___152 *slab_cache;
		struct page___165 *first_page;
	};
	long: 64;
};

struct task_struct___168;

struct pv_cpu_ops___168 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___168 *);
	void (*end_context_switch)(struct task_struct___168 *);
};

struct mutex___169 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___168 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___161 {
	struct page___165 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___173;

struct nsproxy___100;

struct signal_struct___168;

struct css_set___108;

struct task_struct___168 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___168 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___173 *mm;
	struct mm_struct___173 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___168 *real_parent;
	struct task_struct___168 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___168 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___168 = 0,
		VTIME_USER___168 = 1,
		VTIME_SYS___168 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___100 *nsproxy;
	struct signal_struct___168 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___108 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___169 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___161 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___173 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___173 *, struct mm_struct___173 *);
	void (*dup_mmap)(struct mm_struct___173 *, struct mm_struct___173 *);
	void (*exit_mmap)(struct mm_struct___173 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___173 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___173 *);
	void (*pgd_free)(struct mm_struct___173 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___173 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___173 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___173 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___173 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___173 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___173 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___173 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___173 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___173 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___173 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___173 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___169 lock;
	void *vdso;
} mm_context_t___169;

struct xol_area___165;

struct uprobes_state___165 {
	struct xol_area___165 *xol_area;
};

struct vm_area_struct___173;

struct file___166;

struct core_state___168;

struct mm_struct___173 {
	struct vm_area_struct___173 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___173 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___173 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___169 context;
	long unsigned int flags;
	struct core_state___168 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___168 *owner;
	struct file___166 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___165 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___85;

struct exec_domain___39 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___85 *module;
	struct exec_domain___39 *next;
};

struct kset___18;

struct kobj_type___18;

struct kobject___18 {
	const char *name;
	struct list_head entry;
	struct kobject___18 *parent;
	struct kset___18 *kset;
	struct kobj_type___18 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___84 {
	struct kobject___18 kobj;
	struct module___85 *mod;
	struct kobject___18 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___84;

struct module___85 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___84 mkobj;
	struct module_attribute___84 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___18 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___168 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___77 {
	struct task_struct___168 *task;
	struct exec_domain___39 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct sockaddr_alg {
	__u16 salg_family;
	__u8 salg_type[14];
	__u32 salg_feat;
	__u32 salg_mask;
	__u8 salg_name[64];
};

struct af_alg_iv {
	__u32 ivlen;
	__u8 iv[0];
};

struct zone___168;

struct lruvec___168 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___168 *zone;
};

struct pglist_data___168;

struct zone___168 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___168 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___168 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___168 {
	struct zone___168 *zone;
	int zone_idx;
};

struct zonelist___168 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___168 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___168 {
	struct zone___168 node_zones[4];
	struct zonelist___168 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___168 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___117;

struct x86_io_apic_ops___117 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___117 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___117;

struct irq_data___117 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___117 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___131;

struct dev_pm_ops___131 {
	int (*prepare)(struct device___131 *);
	void (*complete)(struct device___131 *);
	int (*suspend)(struct device___131 *);
	int (*resume)(struct device___131 *);
	int (*freeze)(struct device___131 *);
	int (*thaw)(struct device___131 *);
	int (*poweroff)(struct device___131 *);
	int (*restore)(struct device___131 *);
	int (*suspend_late)(struct device___131 *);
	int (*resume_early)(struct device___131 *);
	int (*freeze_late)(struct device___131 *);
	int (*thaw_early)(struct device___131 *);
	int (*poweroff_late)(struct device___131 *);
	int (*restore_early)(struct device___131 *);
	int (*suspend_noirq)(struct device___131 *);
	int (*resume_noirq)(struct device___131 *);
	int (*freeze_noirq)(struct device___131 *);
	int (*thaw_noirq)(struct device___131 *);
	int (*poweroff_noirq)(struct device___131 *);
	int (*restore_noirq)(struct device___131 *);
	int (*runtime_suspend)(struct device___131 *);
	int (*runtime_resume)(struct device___131 *);
	int (*runtime_idle)(struct device___131 *);
};

struct dev_pm_qos___23;

struct dev_pm_info___23 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___23 *qos;
};

struct dma_map_ops___54;

struct dev_archdata___54 {
	struct dma_map_ops___54 *dma_ops;
	void *iommu;
};

struct device_type___131;

struct bus_type___131;

struct device_driver___131;

struct dev_pm_domain___131;

struct class___131;

struct attribute_group___123;

struct device_rh___131;

struct device___131 {
	struct device___131 *parent;
	struct device_private *p;
	struct kobject___18 kobj;
	const char *init_name;
	const struct device_type___131 *type;
	struct mutex___169 mutex;
	struct bus_type___131 *bus;
	struct device_driver___131 *driver;
	void *platform_data;
	struct dev_pm_info___23 power;
	struct dev_pm_domain___131 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___54 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___10 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___131 *class;
	const struct attribute_group___123 **groups;
	void (*release)(struct device___131 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___131 *device_rh;
};

struct dev_pm_qos_request___23;

struct dev_pm_qos___23 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___23 *latency_req;
	struct dev_pm_qos_request___23 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___23 *latency_tolerance_req;
};

struct dev_pm_info_rh___131 {
	void (*set_latency_tolerance)(struct device___131 *, s32);
};

struct dev_pm_domain___131 {
	struct dev_pm_ops___131 ops;
};

struct smp_ops___168 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___168 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___165 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___165 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___151;

struct memcg_cache_params___152;

struct kmem_cache___152 {
	struct kmem_cache_cpu___151 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___18 kobj;
	struct memcg_cache_params___152 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___166;

struct address_space_operations___166;

struct address_space___166 {
	struct inode___166 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___169 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___166 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___166;

struct path___166 {
	struct vfsmount *mnt;
	struct dentry___166 *dentry;
};

struct file_operations___166;

struct file___166 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___166 f_path;
	struct inode___166 *f_inode;
	const struct file_operations___166 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___166 *f_mapping;
	struct mutex___169 f_pos_lock;
};

struct vm_operations_struct___146;

struct vm_area_struct___173 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___173 *vm_next;
	struct vm_area_struct___173 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___173 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___146 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___166 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___143;

struct vm_operations_struct___146 {
	void (*open)(struct vm_area_struct___173 *);
	void (*close)(struct vm_area_struct___173 *);
	int (*fault)(struct vm_area_struct___173 *, struct vm_fault___143 *);
	int (*page_mkwrite)(struct vm_area_struct___173 *, struct vm_fault___143 *);
	int (*access)(struct vm_area_struct___173 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___173 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___173 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___173 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___173 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___168 {
	struct task_struct___168 *task;
	struct core_thread___168 *next;
};

struct core_state___168 {
	atomic_t nr_threads;
	struct core_thread___168 dumper;
	struct completion startup;
};

struct vm_fault___143 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___165 *page;
};

struct seq_file___122;

struct irq_chip___117 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___117 *);
	void (*irq_shutdown)(struct irq_data___117 *);
	void (*irq_enable)(struct irq_data___117 *);
	void (*irq_disable)(struct irq_data___117 *);
	void (*irq_ack)(struct irq_data___117 *);
	void (*irq_mask)(struct irq_data___117 *);
	void (*irq_mask_ack)(struct irq_data___117 *);
	void (*irq_unmask)(struct irq_data___117 *);
	void (*irq_eoi)(struct irq_data___117 *);
	int (*irq_set_affinity)(struct irq_data___117 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___117 *);
	int (*irq_set_type)(struct irq_data___117 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___117 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___117 *);
	void (*irq_bus_sync_unlock)(struct irq_data___117 *);
	void (*irq_cpu_online)(struct irq_data___117 *);
	void (*irq_cpu_offline)(struct irq_data___117 *);
	void (*irq_suspend)(struct irq_data___117 *);
	void (*irq_resume)(struct irq_data___117 *);
	void (*irq_pm_shutdown)(struct irq_data___117 *);
	void (*irq_print_chip)(struct irq_data___117 *, struct seq_file___122 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___117 *, void *);
	long unsigned int flags;
};

struct seq_operations___122;

struct seq_file___122 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___169 lock;
	const struct seq_operations___122 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kiocb___22;

struct poll_table_struct___98;

struct file_lock___166;

struct file_operations___166 {
	struct module___85 *owner;
	loff_t (*llseek)(struct file___166 *, loff_t, int);
	ssize_t (*read)(struct file___166 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___166 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___22 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___22 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___166 *, void *, filldir_t);
	unsigned int (*poll)(struct file___166 *, struct poll_table_struct___98 *);
	long int (*unlocked_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___166 *, struct vm_area_struct___173 *);
	int (*open)(struct inode___166 *, struct file___166 *);
	int (*flush)(struct file___166 *, fl_owner_t);
	int (*release)(struct inode___166 *, struct file___166 *);
	int (*fsync)(struct file___166 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___22 *, int);
	int (*fasync)(int, struct file___166 *, int);
	int (*lock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*sendpage)(struct file___166 *, struct page___165 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___166 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___166 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___166 *, long int, struct file_lock___166 **, void **);
		struct {
			int (*setlease)(struct file___166 *, long int, struct file_lock___166 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___166 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___122 *, struct file___166 *);
};

struct sock___16;

struct kobj_ns_type_operations___15 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___16 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___15;

struct net___32;

struct sock_common___15 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___15 *skc_prot;
	struct net___32 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___22;

struct sk_buff_head___20 {
	struct sk_buff___22 *next;
	struct sk_buff___22 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___16;

struct socket_wq___15;

struct dst_entry___15;

struct socket___16;

struct cg_proto___15;

struct sock___16 {
	struct sock_common___15 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___20 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___22 *head;
		struct sk_buff___22 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___16 *sk_filter;
	struct socket_wq___15 *sk_wq;
	struct sk_buff_head___20 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___15 *sk_rx_dst;
	struct dst_entry___15 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___20 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___20 sk_error_queue;
	struct proto___15 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___16 *sk_socket;
	void *sk_user_data;
	struct page_frag___161 sk_frag;
	struct sk_buff___22 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___15 *sk_cgrp;
	void (*sk_state_change)(struct sock___16 *);
	void (*sk_data_ready)(struct sock___16 *, int);
	void (*sk_write_space)(struct sock___16 *);
	void (*sk_error_report)(struct sock___16 *);
	int (*sk_backlog_rcv)(struct sock___16 *, struct sk_buff___22 *);
	void (*sk_destruct)(struct sock___16 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___125;

struct attribute_group___123 {
	const char *name;
	umode_t (*is_visible)(struct kobject___18 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___125 **bin_attrs;
};

struct bin_attribute___125 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___166 *, struct kobject___18 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___166 *, struct kobject___18 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	int (*mmap)(struct file___166 *, struct kobject___18 *, struct bin_attribute___125 *, struct vm_area_struct___173 *);
};

struct sysfs_ops___18 {
	ssize_t (*show)(struct kobject___18 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___18 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___18 *, const struct attribute *);
};

struct kset_uevent_ops___18;

struct kset___18 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___18 kobj;
	const struct kset_uevent_ops___18 *uevent_ops;
};

struct kobj_type___18 {
	void (*release)(struct kobject___18 *);
	const struct sysfs_ops___18 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___18 *);
	const void * (*namespace)(struct kobject___18 *);
};

struct kset_uevent_ops___18 {
	int (* const filter)(struct kset___18 *, struct kobject___18 *);
	const char * (* const name)(struct kset___18 *, struct kobject___18 *);
	int (* const uevent)(struct kset___18 *, struct kobject___18 *, struct kobj_uevent_env *);
};

struct dma_map_ops___54 {
	void * (*alloc)(struct device___131 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___131 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___131 *, struct vm_area_struct___173 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___131 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___131 *, struct page___165 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___131 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___131 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___131 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___131 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___131 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___131 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___131 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___131 *, dma_addr_t);
	int (*dma_supported)(struct device___131 *, u64);
	int (*set_dma_mask)(struct device___131 *, u64);
	int is_phys;
};

struct bus_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___131 *, char *);
	ssize_t (*store)(struct bus_type___131 *, const char *, size_t);
};

struct device_attribute___131;

struct driver_attribute___131;

struct bus_type___131 {
	const char *name;
	const char *dev_name;
	struct device___131 *dev_root;
	struct bus_attribute___131 *bus_attrs;
	struct device_attribute___131 *dev_attrs;
	struct driver_attribute___131 *drv_attrs;
	const struct attribute_group___123 **bus_groups;
	const struct attribute_group___123 **dev_groups;
	const struct attribute_group___123 **drv_groups;
	int (*match)(struct device___131 *, struct device_driver___131 *);
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	int (*probe)(struct device___131 *);
	int (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*online)(struct device___131 *);
	int (*offline)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct device___131 *, struct device_attribute___131 *, char *);
	ssize_t (*store)(struct device___131 *, struct device_attribute___131 *, const char *, size_t);
};

struct driver_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___131 *, char *);
	ssize_t (*store)(struct device_driver___131 *, const char *, size_t);
};

struct device_driver___131 {
	const char *name;
	struct bus_type___131 *bus;
	struct module___85 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___131 *);
	int (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	const struct attribute_group___123 **groups;
	const struct dev_pm_ops___131 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___131 {
	const char *name;
	const struct attribute_group___123 **groups;
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
};

struct class_attribute___131;

struct class___131 {
	const char *name;
	struct module___85 *owner;
	struct class_attribute___131 *class_attrs;
	struct device_attribute___131 *dev_attrs;
	const struct attribute_group___123 **dev_groups;
	struct bin_attribute___125 *dev_bin_attrs;
	struct kobject___18 *dev_kobj;
	int (*dev_uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *);
	void (*class_release)(struct class___131 *);
	void (*dev_release)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
	struct subsys_private *p;
};

struct class_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct class___131 *, struct class_attribute___131 *, char *);
	ssize_t (*store)(struct class___131 *, struct class_attribute___131 *, const char *, size_t);
	const void * (*namespace)(struct class___131 *, const struct class_attribute___131 *);
};

struct device_rh___131 {
	struct dev_pm_info_rh___131 power;
};

struct dev_pm_qos_request___23 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___131 *dev;
};

struct cmsghdr {
	__kernel_size_t cmsg_len;
	int cmsg_level;
	int cmsg_type;
};

struct dentry_operations___166;

struct super_block___166;

struct dentry___166 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___166 *d_parent;
	struct qstr d_name;
	struct inode___166 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___166 *d_op;
	struct super_block___166 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___166;

struct dquot___166;

struct block_device___166;

struct inode___166 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___166 *i_op;
	struct super_block___166 *i_sb;
	struct address_space___166 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___169 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___166 *i_fop;
	struct file_lock___166 *i_flock;
	struct address_space___166 i_data;
	struct dquot___166 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___166 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___166 {
	int (*d_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_hash)(const struct dentry___166 *, struct qstr *);
	int (*d_compare)(const struct dentry___166 *, const struct dentry___166 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___166 *);
	void (*d_release)(struct dentry___166 *);
	void (*d_prune)(struct dentry___166 *);
	void (*d_iput)(struct dentry___166 *, struct inode___166 *);
	char * (*d_dname)(struct dentry___166 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___166 *);
	int (*d_manage)(struct dentry___166 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___166;

struct mem_dqinfo___166 {
	struct quota_format_type___166 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___166;

struct quota_info___166 {
	unsigned int flags;
	struct mutex___169 dqio_mutex;
	struct mutex___169 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___166 *files[2];
	struct mem_dqinfo___166 info[2];
	const struct quota_format_ops___166 *ops[2];
};

struct file_system_type___166;

struct super_operations___166;

struct dquot_operations___166;

struct quotactl_ops___166;

struct xattr_handler___109;

struct super_block___166 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___166 *s_type;
	const struct super_operations___166 *s_op;
	const struct dquot_operations___166 *dq_op;
	const struct quotactl_ops___166 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___166 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___109 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___166 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___166 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___169 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___166 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___166 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___166 *bd_inode;
	struct super_block___166 *bd_super;
	struct mutex___169 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___166 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___169 bd_fsfreeze_mutex;
};

struct cgroup___108;

struct cgroup_subsys_state___108 {
	struct cgroup___108 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___22(struct kiocb___22 *, struct io_event *);

struct kiocb___22 {
	atomic_t ki_users;
	struct file___166 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___22 *ki_cancel;
	void (*ki_dtor)(struct kiocb___22 *);
	union {
		void *user;
		struct task_struct___168 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___166 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___166 *ia_file;
};

struct dquot___166 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___169 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___166 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___166 {
	int qf_fmt_id;
	const struct quota_format_ops___166 *qf_ops;
	struct module___85 *qf_owner;
	struct quota_format_type___166 *qf_next;
};

struct quota_format_ops___166 {
	int (*check_quota_file)(struct super_block___166 *, int);
	int (*read_file_info)(struct super_block___166 *, int);
	int (*write_file_info)(struct super_block___166 *, int);
	int (*free_file_info)(struct super_block___166 *, int);
	int (*read_dqblk)(struct dquot___166 *);
	int (*commit_dqblk)(struct dquot___166 *);
	int (*release_dqblk)(struct dquot___166 *);
};

struct dquot_operations___166 {
	int (*write_dquot)(struct dquot___166 *);
	struct dquot___166 * (*alloc_dquot)(struct super_block___166 *, int);
	void (*destroy_dquot)(struct dquot___166 *);
	int (*acquire_dquot)(struct dquot___166 *);
	int (*release_dquot)(struct dquot___166 *);
	int (*mark_dirty)(struct dquot___166 *);
	int (*write_info)(struct super_block___166 *, int);
	qsize_t * (*get_reserved_space)(struct inode___166 *);
};

struct quotactl_ops___166 {
	int (*quota_on)(struct super_block___166 *, int, int, struct path___166 *);
	int (*quota_on_meta)(struct super_block___166 *, int, int);
	int (*quota_off)(struct super_block___166 *, int);
	int (*quota_sync)(struct super_block___166 *, int);
	int (*get_info)(struct super_block___166 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___166 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___166 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___166 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___166 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___166 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___166 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___166 *, unsigned int);
};

struct address_space_operations___166 {
	int (*writepage)(struct page___165 *, struct writeback_control *);
	int (*readpage)(struct file___166 *, struct page___165 *);
	int (*writepages)(struct address_space___166 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___165 *);
	int (*readpages)(struct file___166 *, struct address_space___166 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___166 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___165 **, void **);
	int (*write_end)(struct file___166 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___165 *, void *);
	sector_t (*bmap)(struct address_space___166 *, sector_t);
	void (*invalidatepage)(struct page___165 *, long unsigned int);
	int (*releasepage)(struct page___165 *, gfp_t);
	void (*freepage)(struct page___165 *);
	ssize_t (*direct_IO)(int, struct kiocb___22 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___166 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___166 *, struct page___165 *, struct page___165 *, enum migrate_mode);
	int (*launder_page)(struct page___165 *);
	int (*is_partially_uptodate)(struct page___165 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___165 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___166 *, struct page___165 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___166 *, sector_t *);
	void (*swap_deactivate)(struct file___166 *);
	void (*invalidatepage_range)(struct page___165 *, unsigned int, unsigned int);
};

struct inode_operations___166 {
	struct dentry___166 * (*lookup)(struct inode___166 *, struct dentry___166 *, unsigned int);
	void * (*follow_link)(struct dentry___166 *, struct nameidata *);
	int (*permission)(struct inode___166 *, int);
	struct posix_acl * (*get_acl)(struct inode___166 *, int);
	int (*readlink)(struct dentry___166 *, char *, int);
	void (*put_link)(struct dentry___166 *, struct nameidata *, void *);
	int (*create)(struct inode___166 *, struct dentry___166 *, umode_t, bool);
	int (*link)(struct dentry___166 *, struct inode___166 *, struct dentry___166 *);
	int (*unlink)(struct inode___166 *, struct dentry___166 *);
	int (*symlink)(struct inode___166 *, struct dentry___166 *, const char *);
	int (*mkdir)(struct inode___166 *, struct dentry___166 *, umode_t);
	int (*rmdir)(struct inode___166 *, struct dentry___166 *);
	int (*mknod)(struct inode___166 *, struct dentry___166 *, umode_t, dev_t);
	int (*rename)(struct inode___166 *, struct dentry___166 *, struct inode___166 *, struct dentry___166 *);
	int (*setattr)(struct dentry___166 *, struct iattr___166 *);
	int (*getattr)(struct vfsmount *, struct dentry___166 *, struct kstat *);
	int (*setxattr)(struct dentry___166 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___166 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___166 *, char *, size_t);
	int (*removexattr)(struct dentry___166 *, const char *);
	int (*fiemap)(struct inode___166 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___166 *, struct timespec *, int);
	int (*atomic_open)(struct inode___166 *, struct dentry___166 *, struct file___166 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___166;

struct file_lock_operations___166;

struct lock_manager_operations___166;

struct file_lock___166 {
	struct file_lock___166 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___166 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___166 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___166 *fl_ops;
	const struct lock_manager_operations___166 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___166 {
	void (*fl_copy_lock)(struct file_lock___166 *, struct file_lock___166 *);
	void (*fl_release_private)(struct file_lock___166 *);
};

struct lock_manager_operations___166 {
	int (*lm_compare_owner)(struct file_lock___166 *, struct file_lock___166 *);
	long unsigned int (*lm_owner_key)(struct file_lock___166 *);
	void (*lm_notify)(struct file_lock___166 *);
	int (*lm_grant)(struct file_lock___166 *, struct file_lock___166 *, int);
	void (*lm_break)(struct file_lock___166 *);
	int (*lm_change)(struct file_lock___166 **, int);
};

struct fasync_struct___166 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___166 *fa_next;
	struct file___166 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___166 {
	const char *name;
	int fs_flags;
	struct dentry___166 * (*mount)(struct file_system_type___166 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___166 *);
	struct module___85 *owner;
	struct file_system_type___166 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___166 {
	struct inode___166 * (*alloc_inode)(struct super_block___166 *);
	void (*destroy_inode)(struct inode___166 *);
	void (*dirty_inode)(struct inode___166 *, int);
	int (*write_inode)(struct inode___166 *, struct writeback_control *);
	int (*drop_inode)(struct inode___166 *);
	void (*evict_inode)(struct inode___166 *);
	void (*put_super)(struct super_block___166 *);
	int (*sync_fs)(struct super_block___166 *, int);
	int (*freeze_fs)(struct super_block___166 *);
	int (*unfreeze_fs)(struct super_block___166 *);
	int (*statfs)(struct dentry___166 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___166 *, int *, char *);
	void (*umount_begin)(struct super_block___166 *);
	int (*show_options)(struct seq_file___122 *, struct dentry___166 *);
	int (*show_devname)(struct seq_file___122 *, struct dentry___166 *);
	int (*show_path)(struct seq_file___122 *, struct dentry___166 *);
	int (*show_stats)(struct seq_file___122 *, struct dentry___166 *);
	ssize_t (*quota_read)(struct super_block___166 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___166 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___166 *);
	int (*bdev_try_to_free_page)(struct super_block___166 *, struct page___165 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___166 *);
	void (*free_cached_objects)(struct super_block___166 *, int);
};

struct xattr_handler___109 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___166 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___166 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___166 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___100)(struct file___166 *, wait_queue_head_t *, struct poll_table_struct___98 *);

struct poll_table_struct___98 {
	poll_queue_proc___100 _qproc;
	long unsigned int _key;
};

struct ctl_table_header___33;

struct ctl_node___33 {
	struct rb_node node;
	struct ctl_table_header___33 *header;
};

struct ctl_table_root___33;

struct ctl_table_set___33;

struct ctl_dir___33;

struct ctl_table_header___33 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___33 *root;
	struct ctl_table_set___33 *set;
	struct ctl_dir___33 *parent;
	struct ctl_node___33 *node;
};

struct ctl_dir___33 {
	struct ctl_table_header___33 header;
	struct rb_root root;
};

struct ctl_table_set___33 {
	int (*is_seen)(struct ctl_table_set___33 *);
	struct ctl_dir___33 dir;
};

struct ctl_table_root___33 {
	struct ctl_table_set___33 default_set;
	struct ctl_table_set___33 * (*lookup)(struct ctl_table_root___33 *, struct nsproxy___100 *);
	int (*permissions)(struct ctl_table_header___33 *, struct ctl_table *);
};

struct nsproxy___100 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___32 *net_ns;
};

struct signal_struct___168 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___168 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___168 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___169 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___108 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___108 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___15 {
	wait_queue_head_t wait;
	struct fasync_struct___166 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___15;

struct socket___16 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___15 *wq;
	struct file___166 *file;
	struct sock___16 *sk;
	const struct proto_ops___15 *ops;
};

struct proto_ops___15 {
	int family;
	struct module___85 *owner;
	int (*release)(struct socket___16 *);
	int (*bind)(struct socket___16 *, struct sockaddr *, int);
	int (*connect)(struct socket___16 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___16 *, struct socket___16 *);
	int (*accept)(struct socket___16 *, struct socket___16 *, int);
	int (*getname)(struct socket___16 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___166 *, struct socket___16 *, struct poll_table_struct___98 *);
	int (*ioctl)(struct socket___16 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___16 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___16 *, int);
	int (*shutdown)(struct socket___16 *, int);
	int (*setsockopt)(struct socket___16 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___16 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___16 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___16 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___22 *, struct socket___16 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___22 *, struct socket___16 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___166 *, struct socket___16 *, struct vm_area_struct___173 *);
	ssize_t (*sendpage)(struct socket___16 *, struct page___165 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___16 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___16 *, int);
		struct {
			void (*set_peek_off)(struct sock___16 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct net_proto_family {
	int family;
	int (*create)(struct net___32 *, struct socket___16 *, int, int);
	struct module___85 *owner;
};

struct netns_core___30 {
	struct ctl_table_header___33 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___30 {
	struct mutex___169 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___30 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___33 *ctl;
};

struct netns_ipv4___30 {
	struct ctl_table_header___33 *forw_hdr;
	struct ctl_table_header___33 *frags_hdr;
	struct ctl_table_header___33 *ipv4_hdr;
	struct ctl_table_header___33 *route_hdr;
	struct ctl_table_header___33 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___16 *fibnl;
	struct sock___16 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___30 {
	struct ctl_table_header___33 *hdr;
	struct ctl_table_header___33 *route_hdr;
	struct ctl_table_header___33 *icmp_hdr;
	struct ctl_table_header___33 *frags_hdr;
	struct ctl_table_header___33 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___21;

struct neighbour___15;

struct dst_ops___31 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___31 *);
	struct dst_entry___15 * (*check)(struct dst_entry___15 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___15 *);
	unsigned int (*mtu)(const struct dst_entry___15 *);
	u32 * (*cow_metrics)(struct dst_entry___15 *, long unsigned int);
	void (*destroy)(struct dst_entry___15 *);
	void (*ifdown)(struct dst_entry___15 *, struct net_device___21 *, int);
	struct dst_entry___15 * (*negative_advice)(struct dst_entry___15 *);
	void (*link_failure)(struct sk_buff___22 *);
	void (*update_pmtu)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___22 *, u32);
	void (*redirect)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___22 *);
	int (*local_out)(struct sk_buff___22 *);
	struct neighbour___15 * (*neigh_lookup)(const struct dst_entry___15 *, struct sk_buff___22 *, const void *);
	struct kmem_cache___152 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___31 {
	struct netns_sysctl_ipv6___30 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___31 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___16 **icmp_sk;
	struct sock___16 *ndisc_sk;
	struct sock___16 *tcp_sk;
	struct sock___16 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___30 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___33 *sysctl_header;
	struct sock___16 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___15 {
	struct sock___16 *v4_ctl_sk;
	struct sock___16 *v6_ctl_sk;
};

struct netns_nf___30 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___33 *nf_log_dir_header;
};

struct nf_proto_net___30 {
	struct ctl_table_header___33 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___30 {
	struct nf_proto_net___30 pn;
	unsigned int timeout;
};

struct nf_tcp_net___30 {
	struct nf_proto_net___30 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___30 {
	struct nf_proto_net___30 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___30 {
	struct nf_proto_net___30 pn;
	unsigned int timeout;
};

struct nf_ip_net___30 {
	struct nf_generic_net___30 generic;
	struct nf_tcp_net___30 tcp;
	struct nf_udp_net___30 udp;
	struct nf_icmp_net___30 icmp;
	struct nf_icmp_net___30 icmpv6;
};

struct netns_ct___30 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___33 *sysctl_header;
	struct ctl_table_header___33 *acct_sysctl_header;
	struct ctl_table_header___33 *tstamp_sysctl_header;
	struct ctl_table_header___33 *event_sysctl_header;
	struct ctl_table_header___33 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___152 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___30 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___30 {
	struct netns_sysctl_ipv6___30 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___31 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___16 *nlsk;
	struct sock___16 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___33 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___31 xfrm4_dst_ops;
	struct dst_ops___31 xfrm6_dst_ops;
};

struct net___32 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___33 sysctls;
	struct sock___16 *rtnl;
	struct sock___16 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___21 *loopback_dev;
	struct netns_core___30 core;
	struct netns_mib___2 mib;
	struct netns_packet___30 packet;
	struct netns_unix___30 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___30 ipv4;
	struct netns_ipv6___31 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_dccp___15 dccp;
	struct netns_nf___30 nf;
	struct netns_xt xt;
	struct netns_ct___30 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___30 nf_frag;
	struct sock___16 *nfnl;
	struct sock___16 *nfnl_stash;
	struct sk_buff_head___20 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___31 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___16 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___16 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___169 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___169 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___151 {
	void **freelist;
	long unsigned int tid;
	struct page___165 *page;
	struct page___165 *partial;
};

struct memcg_cache_params___152 {
	bool is_root_cache;
	union {
		struct kmem_cache___152 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___152 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___19 {
	atomic_t use;
	unsigned int mask;
	struct net_device___21 *physindev;
	struct net_device___21 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___19(struct sk_buff___22 **);

struct net_device_ops___19;

struct ethtool_ops___19;

struct header_ops___19;

struct netdev_rx_queue___19;

struct netdev_queue___19;

struct rtnl_link_ops___15;

struct dcbnl_rtnl_ops___19;

struct net_device___21 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___19 *netdev_ops;
	const struct ethtool_ops___19 *ethtool_ops;
	const struct header_ops___19 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___18 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___19 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___19 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___19 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___19 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___19 = 0,
		NETREG_REGISTERED___19 = 1,
		NETREG_UNREGISTERING___19 = 2,
		NETREG_UNREGISTERED___19 = 3,
		NETREG_RELEASED___19 = 4,
		NETREG_DUMMY___19 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___19 = 0,
		RTNL_LINK_INITIALIZING___19 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___21 *);
	struct netpoll_info *npinfo;
	struct net___32 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___131 dev;
	const struct attribute_group___123 *sysfs_groups[4];
	const struct rtnl_link_ops___15 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___19 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___22 {
	struct sk_buff___22 *next;
	struct sk_buff___22 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___16 *sk;
	struct net_device___21 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___22 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___19 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___19 {
	int (*get_settings)(struct net_device___21 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___21 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___21 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___21 *);
	void (*get_regs)(struct net_device___21 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___21 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___21 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___21 *);
	void (*set_msglevel)(struct net_device___21 *, u32);
	int (*nway_reset)(struct net_device___21 *);
	u32 (*get_link)(struct net_device___21 *);
	int (*get_eeprom_len)(struct net_device___21 *);
	int (*get_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___21 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___21 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___21 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___21 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___21 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___21 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___21 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___21 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___21 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___21 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___21 *);
	void (*complete)(struct net_device___21 *);
	u32 (*get_priv_flags)(struct net_device___21 *);
	int (*set_priv_flags)(struct net_device___21 *, u32);
	int (*get_sset_count)(struct net_device___21 *, int);
	int (*get_rxnfc)(struct net_device___21 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___21 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___21 *, struct ethtool_flash *);
	int (*reset)(struct net_device___21 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___21 *);
	int (*get_rxfh_indir)(struct net_device___21 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___21 *, const u32 *);
	void (*get_channels)(struct net_device___21 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___21 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___21 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___21 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___21 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___21 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___21 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___21 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___21 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___21 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___21 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___21 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___15 {
	struct callback_head callback_head;
	struct dst_entry___15 *child;
	struct net_device___21 *dev;
	struct dst_ops___31 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___15 *path;
	struct dst_entry___15 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___22 *);
	union {
		int (*output)(struct sock___16 *, struct sk_buff___22 *);
		struct {
			int (*output)(struct sk_buff___22 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___15 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___15;

struct neigh_parms___15;

struct neigh_ops___15;

struct neighbour___15 {
	struct neighbour___15 *next;
	struct neigh_table___15 *tbl;
	struct neigh_parms___15 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___20 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___15 *, struct sk_buff___22 *);
	const struct neigh_ops___15 *ops;
	struct callback_head rcu;
	struct net_device___21 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___31 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___22 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___22 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___32 *, struct dst_entry___15 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___22 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___22 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___122 {
	void * (*start)(struct seq_file___122 *, loff_t *);
	void (*stop)(struct seq_file___122 *, void *);
	void * (*next)(struct seq_file___122 *, void *, loff_t *);
	int (*show)(struct seq_file___122 *, void *);
};

struct dcbnl_rtnl_ops___19 {
	int (*ieee_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___21 *);
	u8 (*setstate)(struct net_device___21 *, u8);
	void (*getpermhwaddr)(struct net_device___21 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___21 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___21 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___21 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___21 *, int, u8 *);
	void (*setpfccfg)(struct net_device___21 *, int, u8);
	void (*getpfccfg)(struct net_device___21 *, int, u8 *);
	u8 (*setall)(struct net_device___21 *);
	u8 (*getcap)(struct net_device___21 *, int, u8 *);
	int (*getnumtcs)(struct net_device___21 *, int, u8 *);
	int (*setnumtcs)(struct net_device___21 *, int, u8);
	u8 (*getpfcstate)(struct net_device___21 *);
	void (*setpfcstate)(struct net_device___21 *, u8);
	void (*getbcncfg)(struct net_device___21 *, int, u32 *);
	void (*setbcncfg)(struct net_device___21 *, int, u32);
	void (*getbcnrp)(struct net_device___21 *, int, u8 *);
	void (*setbcnrp)(struct net_device___21 *, int, u8);
	u8 (*setapp)(struct net_device___21 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___21 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___21 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___21 *, int, u8);
	u8 (*getdcbx)(struct net_device___21 *);
	u8 (*setdcbx)(struct net_device___21 *, u8);
	int (*peer_getappinfo)(struct net_device___21 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___21 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___21 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___21 *, struct cee_pfc *);
};

struct cgroupfs_root___108;

struct cgroup___108 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___108 *parent;
	struct dentry___166 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___108 *subsys[11];
	struct cgroupfs_root___108 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___169 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___108 {
	struct super_block___166 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___108 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___55 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___166 *, struct file___166 *);
	ssize_t (*read)(struct cgroup___108 *, struct cftype___55 *, struct file___166 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___108 *, struct cftype___55 *);
	s64 (*read_s64)(struct cgroup___108 *, struct cftype___55 *);
	int (*read_map)(struct cgroup___108 *, struct cftype___55 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___108 *, struct cftype___55 *, struct seq_file___122 *);
	ssize_t (*write)(struct cgroup___108 *, struct cftype___55 *, struct file___166 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___108 *, struct cftype___55 *, u64);
	int (*write_s64)(struct cgroup___108 *, struct cftype___55 *, s64);
	int (*write_string)(struct cgroup___108 *, struct cftype___55 *, const char *);
	int (*trigger)(struct cgroup___108 *, unsigned int);
	int (*release)(struct inode___166 *, struct file___166 *);
	int (*register_event)(struct cgroup___108 *, struct cftype___55 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___108 *, struct cftype___55 *, struct eventfd_ctx *);
};

struct cftype_set___53 {
	struct list_head node;
	struct cftype___55 *cfts;
};

struct task_and_cgroup___53 {
	struct task_struct___168 *task;
	struct cgroup___108 *cgrp;
	struct css_set___108 *cg;
};

struct cgroup_taskset___53 {
	struct task_and_cgroup___53 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___108 *cur_cgrp;
};

struct cgroup_subsys___53 {
	struct cgroup_subsys_state___108 * (*css_alloc)(struct cgroup___108 *);
	int (*css_online)(struct cgroup___108 *);
	void (*css_offline)(struct cgroup___108 *);
	void (*css_free)(struct cgroup___108 *);
	int (*can_attach)(struct cgroup___108 *, struct cgroup_taskset___53 *);
	void (*cancel_attach)(struct cgroup___108 *, struct cgroup_taskset___53 *);
	void (*attach)(struct cgroup___108 *, struct cgroup_taskset___53 *);
	void (*fork)(struct task_struct___168 *);
	void (*exit)(struct cgroup___108 *, struct cgroup___108 *, struct task_struct___168 *);
	void (*bind)(struct cgroup___108 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___108 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___55 *base_cftypes;
	struct cftype_set___53 base_cftset;
	struct module___85 *module;
};

struct netlink_callback___20 {
	struct sk_buff___22 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___22 *, struct netlink_callback___20 *);
	int (*done)(struct netlink_callback___20 *);
	void *data;
	struct module___85 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___19 {
	int (*create)(struct sk_buff___22 *, struct net_device___21 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___22 *, unsigned char *);
	int (*rebuild)(struct sk_buff___22 *);
	int (*cache)(const struct neighbour___15 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___21 *, const unsigned char *);
};

struct napi_struct___19 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___19 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___21 *dev;
	struct sk_buff___22 *gro_list;
	struct sk_buff___22 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___19 {
	struct net_device___21 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___18 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___19 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___18 kobj;
	struct net_device___21 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___19 {
	int (*ndo_init)(struct net_device___21 *);
	void (*ndo_uninit)(struct net_device___21 *);
	int (*ndo_open)(struct net_device___21 *);
	int (*ndo_stop)(struct net_device___21 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___22 *, struct net_device___21 *);
	u16 (*ndo_select_queue)(struct net_device___21 *, struct sk_buff___22 *);
	void (*ndo_change_rx_flags)(struct net_device___21 *, int);
	void (*ndo_set_rx_mode)(struct net_device___21 *);
	int (*ndo_set_mac_address)(struct net_device___21 *, void *);
	int (*ndo_validate_addr)(struct net_device___21 *);
	int (*ndo_do_ioctl)(struct net_device___21 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___21 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___21 *, int);
	int (*ndo_neigh_setup)(struct net_device___21 *, struct neigh_parms___15 *);
	void (*ndo_tx_timeout)(struct net_device___21 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___21 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___21 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___21 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___21 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___21 *);
	int (*ndo_netpoll_setup)(struct net_device___21 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___21 *);
	int (*ndo_busy_poll)(struct napi_struct___19 *);
	int (*ndo_set_vf_mac)(struct net_device___21 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___21 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___21 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___21 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___21 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___21 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___21 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___21 *, int, struct sk_buff___22 *);
	int (*ndo_setup_tc)(struct net_device___21 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___21 *);
	int (*ndo_fcoe_disable)(struct net_device___21 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___21 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___21 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___21 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___21 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___21 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___21 *, const struct sk_buff___22 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___21 *, struct net_device___21 *);
	int (*ndo_del_slave)(struct net_device___21 *, struct net_device___21 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___15 *);
	void (*ndo_neigh_destroy)(struct neighbour___15 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___22 *, struct netlink_callback___20 *, struct net_device___21 *, int);
	int (*ndo_bridge_setlink)(struct net_device___21 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___22 *, u32, u32, struct net_device___21 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___21 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___21 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___21 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___21 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___21 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___21 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___22 *, struct net_device___21 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___21 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___21 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___21 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___15 {
	struct net___32 *net;
	struct net_device___21 *dev;
	struct neigh_parms___15 *next;
	int (*neigh_setup)(struct neighbour___15 *);
	void (*neigh_cleanup)(struct neighbour___15 *);
	struct neigh_table___15 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___15 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___21 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___32 *, struct net_device___21 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___21 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___21 *, struct list_head *);
	size_t (*get_size)(const struct net_device___21 *);
	int (*fill_info)(struct sk_buff___22 *, const struct net_device___21 *);
	size_t (*get_xstats_size)(const struct net_device___21 *);
	int (*fill_xstats)(struct sk_buff___22 *, const struct net_device___21 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___32 * (*get_link_net)(const struct net_device___21 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___21 *, struct net_device___21 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___21 *, const struct net_device___21 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___22 *, const struct net_device___21 *, const struct net_device___21 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___16 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___22 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___15;

struct neigh_hash_table___15;

struct neigh_table___15 {
	struct neigh_table___15 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___21 *, __u32 *);
	int (*constructor)(struct neighbour___15 *);
	int (*pconstructor)(struct pneigh_entry___15 *);
	void (*pdestructor)(struct pneigh_entry___15 *);
	void (*proxy_redo)(struct sk_buff___22 *);
	char *id;
	struct neigh_parms___15 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___20 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___15 *nht;
	struct pneigh_entry___15 **phash_buckets;
};

struct neigh_ops___15 {
	int family;
	void (*solicit)(struct neighbour___15 *, struct sk_buff___22 *);
	void (*error_report)(struct neighbour___15 *, struct sk_buff___22 *);
	int (*output)(struct neighbour___15 *, struct sk_buff___22 *);
	int (*connected_output)(struct neighbour___15 *, struct sk_buff___22 *);
};

struct pneigh_entry___15 {
	struct pneigh_entry___15 *next;
	struct net___32 *net;
	struct net_device___21 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___15 {
	struct neighbour___15 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___15 {
	void (*close)(struct sock___16 *, long int);
	int (*connect)(struct sock___16 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___16 *, int);
	struct sock___16 * (*accept)(struct sock___16 *, int, int *);
	int (*ioctl)(struct sock___16 *, int, long unsigned int);
	int (*init)(struct sock___16 *);
	void (*destroy)(struct sock___16 *);
	void (*shutdown)(struct sock___16 *, int);
	int (*setsockopt)(struct sock___16 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___16 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___16 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___16 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___16 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___22 *, struct sock___16 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___22 *, struct sock___16 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___16 *, struct page___165 *, int, size_t, int);
	int (*bind)(struct sock___16 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___16 *, struct sk_buff___22 *);
	void (*release_cb)(struct sock___16 *);
	void (*mtu_reduced)(struct sock___16 *);
	void (*hash)(struct sock___16 *);
	void (*unhash)(struct sock___16 *);
	void (*rehash)(struct sock___16 *);
	int (*get_port)(struct sock___16 *, short unsigned int);
	void (*clear_sk)(struct sock___16 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___16 *);
	void (*enter_memory_pressure)(struct sock___16 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___152 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___85 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___53 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___15 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___15 {
	void (*enter_memory_pressure)(struct sock___16 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct af_alg_type;

struct alg_sock {
	struct sock___16 sk;
	struct sock___16 *parent;
	const struct af_alg_type *type;
	void *private;
};

struct af_alg_type {
	void * (*bind)(const char *, u32, u32);
	void (*release)(void *);
	int (*setkey)(void *, const u8 *, unsigned int);
	int (*accept)(void *, struct sock___16 *);
	struct proto_ops___15 *ops;
	struct module___85 *owner;
	char name[14];
};

struct af_alg_completion {
	struct completion completion;
	int err;
};

struct af_alg_control {
	struct af_alg_iv *iv;
	int op;
};

struct af_alg_sgl {
	struct scatterlist sg[16];
	struct page___165 *pages[16];
};

struct crypto_async_request___9;

typedef void (*crypto_completion_t___9)(struct crypto_async_request___9 *, int);

struct crypto_tfm___9;

struct crypto_async_request___9 {
	struct list_head list;
	crypto_completion_t___9 complete;
	void *data;
	struct crypto_tfm___9 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___9;

struct ablkcipher_request___9;

struct ablkcipher_tfm___9 {
	int (*setkey)(struct crypto_ablkcipher___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___9 *);
	int (*decrypt)(struct ablkcipher_request___9 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___9 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___9;

struct aead_request___9;

struct aead_tfm___9 {
	int (*setkey)(struct crypto_aead___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___9 *);
	int (*decrypt)(struct aead_request___9 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___9 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___9;

struct blkcipher_tfm___9 {
	void *iv;
	int (*setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___9 {
	int (*cit_setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___9 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___9 *, u8 *, const u8 *);
};

struct hash_desc___9;

struct crypto_hash___9;

struct hash_tfm___9 {
	int (*init)(struct hash_desc___9 *);
	int (*update)(struct hash_desc___9 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___9 *, u8 *);
	int (*digest)(struct hash_desc___9 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___9 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___9 {
	int (*cot_compress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___9;

struct rng_tfm___9 {
	int (*rng_gen_random)(struct crypto_rng___9 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___9 *, u8 *, unsigned int);
};

struct crypto_alg___9;

struct crypto_tfm___9 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___9 ablkcipher;
		struct aead_tfm___9 aead;
		struct blkcipher_tfm___9 blkcipher;
		struct cipher_tfm___9 cipher;
		struct hash_tfm___9 hash;
		struct compress_tfm___9 compress;
		struct rng_tfm___9 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___9 *);
	struct crypto_alg___9 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___9 {
	struct crypto_async_request___9 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___9 {
	struct crypto_async_request___9 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___9;

struct blkcipher_desc___9 {
	struct crypto_blkcipher___9 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___9 {
	struct crypto_tfm___9 base;
};

struct hash_desc___9 {
	struct crypto_hash___9 *tfm;
	u32 flags;
};

struct crypto_hash___9 {
	struct crypto_tfm___9 base;
};

struct ablkcipher_alg___9 {
	int (*setkey)(struct crypto_ablkcipher___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___9 *);
	int (*decrypt)(struct ablkcipher_request___9 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___9 {
	struct crypto_tfm___9 base;
};

struct aead_alg___9 {
	int (*setkey)(struct crypto_aead___9 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___9 *, unsigned int);
	int (*encrypt)(struct aead_request___9 *);
	int (*decrypt)(struct aead_request___9 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___9 {
	struct crypto_tfm___9 base;
};

struct blkcipher_alg___9 {
	int (*setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___9 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
};

struct compress_alg___9 {
	int (*coa_compress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___9 {
	int (*rng_make_random)(struct crypto_rng___9 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___9 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___9 {
	struct crypto_tfm___9 base;
};

struct crypto_alg___9 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___9 ablkcipher;
		struct aead_alg___9 aead;
		struct blkcipher_alg___9 blkcipher;
		struct cipher_alg___9 cipher;
		struct compress_alg___9 compress;
		struct rng_alg___9 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___9 *);
	void (*cra_exit)(struct crypto_tfm___9 *);
	void (*cra_destroy)(struct crypto_alg___9 *);
	struct module___85 *cra_module;
};

struct module_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___84 *, struct module_kobject___84 *, char *);
	ssize_t (*store)(struct module_attribute___84 *, struct module_kobject___84 *, const char *, size_t);
	void (*setup)(struct module___85 *, const char *);
	int (*test)(struct module___85 *);
	void (*free)(struct module___85 *);
};

struct alg_type_list {
	const struct af_alg_type *type;
	struct list_head list;
};

struct hash_alg_common___2 {
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg___9 base;
};

struct ahash_request___2 {
	struct crypto_async_request___9 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	void *__ctx[0];
};

struct crypto_ahash___2 {
	int (*init)(struct ahash_request___2 *);
	int (*update)(struct ahash_request___2 *);
	int (*final)(struct ahash_request___2 *);
	int (*finup)(struct ahash_request___2 *);
	int (*digest)(struct ahash_request___2 *);
	int (*export)(struct ahash_request___2 *, void *);
	int (*import)(struct ahash_request___2 *, const void *);
	int (*setkey)(struct crypto_ahash___2 *, const u8 *, unsigned int);
	unsigned int reqsize;
	struct crypto_tfm___9 base;
};

enum sock_flags {
	SOCK_DEAD = 0,
	SOCK_DONE = 1,
	SOCK_URGINLINE = 2,
	SOCK_KEEPOPEN = 3,
	SOCK_LINGER = 4,
	SOCK_DESTROY = 5,
	SOCK_BROADCAST = 6,
	SOCK_TIMESTAMP = 7,
	SOCK_ZAPPED = 8,
	SOCK_USE_WRITE_QUEUE = 9,
	SOCK_DBG = 10,
	SOCK_RCVTSTAMP = 11,
	SOCK_RCVTSTAMPNS = 12,
	SOCK_LOCALROUTE = 13,
	SOCK_QUEUE_SHRUNK = 14,
	SOCK_MEMALLOC = 15,
	SOCK_TIMESTAMPING_TX_HARDWARE = 16,
	SOCK_TIMESTAMPING_TX_SOFTWARE = 17,
	SOCK_TIMESTAMPING_RX_HARDWARE = 18,
	SOCK_TIMESTAMPING_RX_SOFTWARE = 19,
	SOCK_TIMESTAMPING_SOFTWARE = 20,
	SOCK_TIMESTAMPING_RAW_HARDWARE = 21,
	SOCK_TIMESTAMPING_SYS_HARDWARE = 22,
	SOCK_FASYNC = 23,
	SOCK_RXQ_OVFL = 24,
	SOCK_ZEROCOPY = 25,
	SOCK_WIFI_STATUS = 26,
	SOCK_NOFCS = 27,
	SOCK_FILTER_LOCKED = 28,
	SOCK_SELECT_ERR_QUEUE = 29,
};

struct hash_ctx {
	struct af_alg_sgl sgl;
	u8 *result;
	struct af_alg_completion completion;
	unsigned int len;
	bool more;
	struct ahash_request___2 req;
};

struct page___166;

typedef struct page___166 *pgtable_t___166;

struct address_space___167;

struct kmem_cache___153;

struct page___166 {
	long unsigned int flags;
	struct address_space___167 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___166 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___166 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___153 *slab_cache;
		struct page___166 *first_page;
	};
	long: 64;
};

struct task_struct___169;

struct pv_cpu_ops___169 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___169 *);
	void (*end_context_switch)(struct task_struct___169 *);
};

struct mutex___170 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___169 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___162 {
	struct page___166 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___174;

struct nsproxy___101;

struct signal_struct___169;

struct css_set___109;

struct task_struct___169 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___169 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___174 *mm;
	struct mm_struct___174 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___169 *real_parent;
	struct task_struct___169 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___169 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___169 = 0,
		VTIME_USER___169 = 1,
		VTIME_SYS___169 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___101 *nsproxy;
	struct signal_struct___169 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___109 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___170 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___162 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___174 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___174 *, struct mm_struct___174 *);
	void (*dup_mmap)(struct mm_struct___174 *, struct mm_struct___174 *);
	void (*exit_mmap)(struct mm_struct___174 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___174 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___174 *);
	void (*pgd_free)(struct mm_struct___174 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___174 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___174 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___174 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___174 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___174 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___174 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___174 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___174 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___174 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___174 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___174 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___170 lock;
	void *vdso;
} mm_context_t___170;

struct xol_area___166;

struct uprobes_state___166 {
	struct xol_area___166 *xol_area;
};

struct vm_area_struct___174;

struct file___167;

struct core_state___169;

struct mm_struct___174 {
	struct vm_area_struct___174 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___174 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___174 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___170 context;
	long unsigned int flags;
	struct core_state___169 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___169 *owner;
	struct file___167 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___166 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___86;

struct exec_domain___40 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___86 *module;
	struct exec_domain___40 *next;
};

struct kset___19;

struct kobj_type___19;

struct kobject___19 {
	const char *name;
	struct list_head entry;
	struct kobject___19 *parent;
	struct kset___19 *kset;
	struct kobj_type___19 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___85 {
	struct kobject___19 kobj;
	struct module___86 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___85;

struct module___86 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___85 mkobj;
	struct module_attribute___85 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___169 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___78 {
	struct task_struct___169 *task;
	struct exec_domain___40 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___169;

struct lruvec___169 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___169 *zone;
};

struct pglist_data___169;

struct zone___169 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___169 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___169 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___169 {
	struct zone___169 *zone;
	int zone_idx;
};

struct zonelist___169 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___169 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___169 {
	struct zone___169 node_zones[4];
	struct zonelist___169 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___169 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___118;

struct x86_io_apic_ops___118 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___118 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___118;

struct irq_data___118 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___118 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___132;

struct dev_pm_ops___132 {
	int (*prepare)(struct device___132 *);
	void (*complete)(struct device___132 *);
	int (*suspend)(struct device___132 *);
	int (*resume)(struct device___132 *);
	int (*freeze)(struct device___132 *);
	int (*thaw)(struct device___132 *);
	int (*poweroff)(struct device___132 *);
	int (*restore)(struct device___132 *);
	int (*suspend_late)(struct device___132 *);
	int (*resume_early)(struct device___132 *);
	int (*freeze_late)(struct device___132 *);
	int (*thaw_early)(struct device___132 *);
	int (*poweroff_late)(struct device___132 *);
	int (*restore_early)(struct device___132 *);
	int (*suspend_noirq)(struct device___132 *);
	int (*resume_noirq)(struct device___132 *);
	int (*freeze_noirq)(struct device___132 *);
	int (*thaw_noirq)(struct device___132 *);
	int (*poweroff_noirq)(struct device___132 *);
	int (*restore_noirq)(struct device___132 *);
	int (*runtime_suspend)(struct device___132 *);
	int (*runtime_resume)(struct device___132 *);
	int (*runtime_idle)(struct device___132 *);
};

struct dev_pm_qos___24;

struct dev_pm_info___24 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___24 *qos;
};

struct dma_map_ops___55;

struct dev_archdata___55 {
	struct dma_map_ops___55 *dma_ops;
	void *iommu;
};

struct device_type___132;

struct bus_type___132;

struct device_driver___132;

struct dev_pm_domain___132;

struct class___132;

struct attribute_group___124;

struct device_rh___132;

struct device___132 {
	struct device___132 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___132 *type;
	struct mutex___170 mutex;
	struct bus_type___132 *bus;
	struct device_driver___132 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___132 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___55 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___132 *class;
	const struct attribute_group___124 **groups;
	void (*release)(struct device___132 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___132 *device_rh;
};

struct dev_pm_qos_request___24;

struct dev_pm_qos___24 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___24 *latency_req;
	struct dev_pm_qos_request___24 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___24 *latency_tolerance_req;
};

struct dev_pm_info_rh___132 {
	void (*set_latency_tolerance)(struct device___132 *, s32);
};

struct dev_pm_domain___132 {
	struct dev_pm_ops___132 ops;
};

struct smp_ops___169 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___169 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___17;

struct kobj_ns_type_operations___16 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___17 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___16;

struct net___33;

struct sock_common___16 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___16 *skc_prot;
	struct net___33 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___23;

struct sk_buff_head___21 {
	struct sk_buff___23 *next;
	struct sk_buff___23 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___17;

struct socket_wq___16;

struct dst_entry___16;

struct socket___17;

struct cg_proto___16;

struct sock___17 {
	struct sock_common___16 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___21 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___23 *head;
		struct sk_buff___23 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___17 *sk_filter;
	struct socket_wq___16 *sk_wq;
	struct sk_buff_head___21 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___16 *sk_rx_dst;
	struct dst_entry___16 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___21 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___21 sk_error_queue;
	struct proto___16 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___84 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___17 *sk_socket;
	void *sk_user_data;
	struct page_frag___162 sk_frag;
	struct sk_buff___23 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___16 *sk_cgrp;
	void (*sk_state_change)(struct sock___17 *);
	void (*sk_data_ready)(struct sock___17 *, int);
	void (*sk_write_space)(struct sock___17 *);
	void (*sk_error_report)(struct sock___17 *);
	int (*sk_backlog_rcv)(struct sock___17 *, struct sk_buff___23 *);
	void (*sk_destruct)(struct sock___17 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___126;

struct attribute_group___124 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___126 **bin_attrs;
};

struct bin_attribute___126 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___167 *, struct kobject___19 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___167 *, struct kobject___19 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	int (*mmap)(struct file___167 *, struct kobject___19 *, struct bin_attribute___126 *, struct vm_area_struct___174 *);
};

struct dentry___167;

struct path___167 {
	struct vfsmount *mnt;
	struct dentry___167 *dentry;
};

struct inode___167;

struct file_operations___167;

struct file___167 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___167 f_path;
	struct inode___167 *f_inode;
	const struct file_operations___167 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___167 *f_mapping;
	struct mutex___170 f_pos_lock;
};

struct vm_operations_struct___147;

struct vm_area_struct___174 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___174 *vm_next;
	struct vm_area_struct___174 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___174 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___147 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___167 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___19 {
	ssize_t (*show)(struct kobject___19 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___19 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___19 *, const struct attribute *);
};

struct kset_uevent_ops___19;

struct kset___19 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___19 kobj;
	const struct kset_uevent_ops___19 *uevent_ops;
};

struct kobj_type___19 {
	void (*release)(struct kobject___19 *);
	const struct sysfs_ops___19 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___16 * (*child_ns_type)(struct kobject___19 *);
	const void * (*namespace)(struct kobject___19 *);
};

struct kset_uevent_ops___19 {
	int (* const filter)(struct kset___19 *, struct kobject___19 *);
	const char * (* const name)(struct kset___19 *, struct kobject___19 *);
	int (* const uevent)(struct kset___19 *, struct kobject___19 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___152 {
	void **freelist;
	long unsigned int tid;
	struct page___166 *page;
	struct page___166 *partial;
};

struct memcg_cache_params___153;

struct kmem_cache___153 {
	struct kmem_cache_cpu___152 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___153 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___153 {
	bool is_root_cache;
	union {
		struct kmem_cache___153 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___153 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct crypto_async_request___10;

typedef void (*crypto_completion_t___10)(struct crypto_async_request___10 *, int);

struct crypto_tfm___10;

struct crypto_async_request___10 {
	struct list_head list;
	crypto_completion_t___10 complete;
	void *data;
	struct crypto_tfm___10 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___10;

struct ablkcipher_request___10;

struct skcipher_givcrypt_request___2;

struct ablkcipher_tfm___10 {
	int (*setkey)(struct crypto_ablkcipher___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___10 *);
	int (*decrypt)(struct ablkcipher_request___10 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___2 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___2 *);
	struct crypto_ablkcipher___10 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___10;

struct aead_request___10;

struct aead_tfm___10 {
	int (*setkey)(struct crypto_aead___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___10 *);
	int (*decrypt)(struct aead_request___10 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___10 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___10;

struct blkcipher_tfm___10 {
	void *iv;
	int (*setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___10 {
	int (*cit_setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___10 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___10 *, u8 *, const u8 *);
};

struct hash_desc___10;

struct crypto_hash___10;

struct hash_tfm___10 {
	int (*init)(struct hash_desc___10 *);
	int (*update)(struct hash_desc___10 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___10 *, u8 *);
	int (*digest)(struct hash_desc___10 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___10 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___10 {
	int (*cot_compress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___10;

struct rng_tfm___10 {
	int (*rng_gen_random)(struct crypto_rng___10 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___10 *, u8 *, unsigned int);
};

struct crypto_alg___10;

struct crypto_tfm___10 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___10 ablkcipher;
		struct aead_tfm___10 aead;
		struct blkcipher_tfm___10 blkcipher;
		struct cipher_tfm___10 cipher;
		struct hash_tfm___10 hash;
		struct compress_tfm___10 compress;
		struct rng_tfm___10 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___10 *);
	struct crypto_alg___10 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___10 {
	struct crypto_async_request___10 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___10 {
	struct crypto_async_request___10 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___10;

struct blkcipher_desc___10 {
	struct crypto_blkcipher___10 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___10 {
	struct crypto_tfm___10 base;
};

struct hash_desc___10 {
	struct crypto_hash___10 *tfm;
	u32 flags;
};

struct crypto_hash___10 {
	struct crypto_tfm___10 base;
};

struct ablkcipher_alg___10 {
	int (*setkey)(struct crypto_ablkcipher___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___10 *);
	int (*decrypt)(struct ablkcipher_request___10 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___2 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___2 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___10 {
	struct crypto_tfm___10 base;
};

struct skcipher_givcrypt_request___2 {
	u64 seq;
	u8 *giv;
	struct ablkcipher_request___10 creq;
};

struct aead_alg___10 {
	int (*setkey)(struct crypto_aead___10 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___10 *, unsigned int);
	int (*encrypt)(struct aead_request___10 *);
	int (*decrypt)(struct aead_request___10 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___10 {
	struct crypto_tfm___10 base;
};

struct blkcipher_alg___10 {
	int (*setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___10 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
};

struct compress_alg___10 {
	int (*coa_compress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___10 {
	int (*rng_make_random)(struct crypto_rng___10 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___10 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___10 {
	struct crypto_tfm___10 base;
};

struct crypto_type___6;

struct crypto_alg___10 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type___6 *cra_type;
	union {
		struct ablkcipher_alg___10 ablkcipher;
		struct aead_alg___10 aead;
		struct blkcipher_alg___10 blkcipher;
		struct cipher_alg___10 cipher;
		struct compress_alg___10 compress;
		struct rng_alg___10 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___10 *);
	void (*cra_exit)(struct crypto_tfm___10 *);
	void (*cra_destroy)(struct crypto_alg___10 *);
	struct module___86 *cra_module;
};

struct seq_file___123;

struct crypto_type___6 {
	unsigned int (*ctxsize)(struct crypto_alg___10 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___10 *);
	int (*init)(struct crypto_tfm___10 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___10 *);
	void (*show)(struct seq_file___123 *, struct crypto_alg___10 *);
	int (*report)(struct sk_buff___23 *, struct crypto_alg___10 *);
	struct crypto_alg___10 * (*lookup)(const char *, u32, u32);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct xol_area___166 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___166 *page;
	long unsigned int vaddr;
};

struct address_space_operations___167;

struct address_space___167 {
	struct inode___167 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___170 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___167 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___144;

struct vm_operations_struct___147 {
	void (*open)(struct vm_area_struct___174 *);
	void (*close)(struct vm_area_struct___174 *);
	int (*fault)(struct vm_area_struct___174 *, struct vm_fault___144 *);
	int (*page_mkwrite)(struct vm_area_struct___174 *, struct vm_fault___144 *);
	int (*access)(struct vm_area_struct___174 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___174 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___174 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___174 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___174 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___169 {
	struct task_struct___169 *task;
	struct core_thread___169 *next;
};

struct core_state___169 {
	atomic_t nr_threads;
	struct core_thread___169 dumper;
	struct completion startup;
};

struct fasync_struct___167;

struct socket_wq___16 {
	wait_queue_head_t wait;
	struct fasync_struct___167 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___167 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___167 *fa_next;
	struct file___167 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___16;

struct socket___17 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___16 *wq;
	struct file___167 *file;
	struct sock___17 *sk;
	const struct proto_ops___16 *ops;
};

struct poll_table_struct___99;

struct kiocb___23;

struct proto_ops___16 {
	int family;
	struct module___86 *owner;
	int (*release)(struct socket___17 *);
	int (*bind)(struct socket___17 *, struct sockaddr *, int);
	int (*connect)(struct socket___17 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___17 *, struct socket___17 *);
	int (*accept)(struct socket___17 *, struct socket___17 *, int);
	int (*getname)(struct socket___17 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___167 *, struct socket___17 *, struct poll_table_struct___99 *);
	int (*ioctl)(struct socket___17 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___17 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___17 *, int);
	int (*shutdown)(struct socket___17 *, int);
	int (*setsockopt)(struct socket___17 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___17 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___17 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___17 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___23 *, struct socket___17 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___23 *, struct socket___17 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___167 *, struct socket___17 *, struct vm_area_struct___174 *);
	ssize_t (*sendpage)(struct socket___17 *, struct page___166 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___17 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___17 *, int);
		struct {
			void (*set_peek_off)(struct sock___17 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___101)(struct file___167 *, wait_queue_head_t *, struct poll_table_struct___99 *);

struct poll_table_struct___99 {
	poll_queue_proc___101 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___23(struct kiocb___23 *, struct io_event *);

struct kiocb___23 {
	atomic_t ki_users;
	struct file___167 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___23 *ki_cancel;
	void (*ki_dtor)(struct kiocb___23 *);
	union {
		void *user;
		struct task_struct___169 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___34;

struct ctl_table_set___34;

struct ctl_dir___34;

struct ctl_node___34;

struct ctl_table_header___34 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___34 *root;
	struct ctl_table_set___34 *set;
	struct ctl_dir___34 *parent;
	struct ctl_node___34 *node;
};

struct ctl_dir___34 {
	struct ctl_table_header___34 header;
	struct rb_root root;
};

struct ctl_table_set___34 {
	int (*is_seen)(struct ctl_table_set___34 *);
	struct ctl_dir___34 dir;
};

struct netns_core___31 {
	struct ctl_table_header___34 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___31 {
	struct mutex___170 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___31 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___34 *ctl;
};

struct netns_ipv4___31 {
	struct ctl_table_header___34 *forw_hdr;
	struct ctl_table_header___34 *frags_hdr;
	struct ctl_table_header___34 *ipv4_hdr;
	struct ctl_table_header___34 *route_hdr;
	struct ctl_table_header___34 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___17 *fibnl;
	struct sock___17 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___31 {
	struct ctl_table_header___34 *hdr;
	struct ctl_table_header___34 *route_hdr;
	struct ctl_table_header___34 *icmp_hdr;
	struct ctl_table_header___34 *frags_hdr;
	struct ctl_table_header___34 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___22;

struct neighbour___16;

struct dst_ops___32 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___32 *);
	struct dst_entry___16 * (*check)(struct dst_entry___16 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___16 *);
	unsigned int (*mtu)(const struct dst_entry___16 *);
	u32 * (*cow_metrics)(struct dst_entry___16 *, long unsigned int);
	void (*destroy)(struct dst_entry___16 *);
	void (*ifdown)(struct dst_entry___16 *, struct net_device___22 *, int);
	struct dst_entry___16 * (*negative_advice)(struct dst_entry___16 *);
	void (*link_failure)(struct sk_buff___23 *);
	void (*update_pmtu)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___23 *, u32);
	void (*redirect)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___23 *);
	int (*local_out)(struct sk_buff___23 *);
	struct neighbour___16 * (*neigh_lookup)(const struct dst_entry___16 *, struct sk_buff___23 *, const void *);
	struct kmem_cache___153 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___32 {
	struct netns_sysctl_ipv6___31 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___32 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___17 **icmp_sk;
	struct sock___17 *ndisc_sk;
	struct sock___17 *tcp_sk;
	struct sock___17 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___31 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___34 *sysctl_header;
	struct sock___17 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___16 {
	struct sock___17 *v4_ctl_sk;
	struct sock___17 *v6_ctl_sk;
};

struct netns_nf___31 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___34 *nf_log_dir_header;
};

struct nf_proto_net___31 {
	struct ctl_table_header___34 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___31 {
	struct nf_proto_net___31 pn;
	unsigned int timeout;
};

struct nf_tcp_net___31 {
	struct nf_proto_net___31 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___31 {
	struct nf_proto_net___31 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___31 {
	struct nf_proto_net___31 pn;
	unsigned int timeout;
};

struct nf_ip_net___31 {
	struct nf_generic_net___31 generic;
	struct nf_tcp_net___31 tcp;
	struct nf_udp_net___31 udp;
	struct nf_icmp_net___31 icmp;
	struct nf_icmp_net___31 icmpv6;
};

struct netns_ct___31 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___34 *sysctl_header;
	struct ctl_table_header___34 *acct_sysctl_header;
	struct ctl_table_header___34 *tstamp_sysctl_header;
	struct ctl_table_header___34 *event_sysctl_header;
	struct ctl_table_header___34 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___153 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___31 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___31 {
	struct netns_sysctl_ipv6___31 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___32 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___17 *nlsk;
	struct sock___17 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___34 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___32 xfrm4_dst_ops;
	struct dst_ops___32 xfrm6_dst_ops;
};

struct net___33 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___34 sysctls;
	struct sock___17 *rtnl;
	struct sock___17 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___22 *loopback_dev;
	struct netns_core___31 core;
	struct netns_mib___2 mib;
	struct netns_packet___31 packet;
	struct netns_unix___31 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___31 ipv4;
	struct netns_ipv6___32 ipv6;
	struct netns_sctp___31 sctp;
	struct netns_dccp___16 dccp;
	struct netns_nf___31 nf;
	struct netns_xt xt;
	struct netns_ct___31 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___31 nf_frag;
	struct sock___17 *nfnl;
	struct sock___17 *nfnl_stash;
	struct sk_buff_head___21 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___32 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___17 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___17 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___170 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___170 flow_flush_sem;
	long: 64;
	long: 64;
};

enum {
	SOCK_WAKE_IO = 0,
	SOCK_WAKE_WAITD = 1,
	SOCK_WAKE_SPACE = 2,
	SOCK_WAKE_URG = 3,
};

struct dma_map_ops___55 {
	void * (*alloc)(struct device___132 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___132 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___132 *, struct vm_area_struct___174 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___132 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___132 *, struct page___166 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___132 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___132 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___132 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___132 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___132 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___132 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___132 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___132 *, dma_addr_t);
	int (*dma_supported)(struct device___132 *, u64);
	int (*set_dma_mask)(struct device___132 *, u64);
	int is_phys;
};

struct bus_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___132 *, char *);
	ssize_t (*store)(struct bus_type___132 *, const char *, size_t);
};

struct device_attribute___132;

struct driver_attribute___132;

struct bus_type___132 {
	const char *name;
	const char *dev_name;
	struct device___132 *dev_root;
	struct bus_attribute___132 *bus_attrs;
	struct device_attribute___132 *dev_attrs;
	struct driver_attribute___132 *drv_attrs;
	const struct attribute_group___124 **bus_groups;
	const struct attribute_group___124 **dev_groups;
	const struct attribute_group___124 **drv_groups;
	int (*match)(struct device___132 *, struct device_driver___132 *);
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	int (*probe)(struct device___132 *);
	int (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*online)(struct device___132 *);
	int (*offline)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct device___132 *, struct device_attribute___132 *, char *);
	ssize_t (*store)(struct device___132 *, struct device_attribute___132 *, const char *, size_t);
};

struct driver_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___132 *, char *);
	ssize_t (*store)(struct device_driver___132 *, const char *, size_t);
};

struct device_driver___132 {
	const char *name;
	struct bus_type___132 *bus;
	struct module___86 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___132 *);
	int (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	const struct attribute_group___124 **groups;
	const struct dev_pm_ops___132 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___132 {
	const char *name;
	const struct attribute_group___124 **groups;
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
};

struct class_attribute___132;

struct class___132 {
	const char *name;
	struct module___86 *owner;
	struct class_attribute___132 *class_attrs;
	struct device_attribute___132 *dev_attrs;
	const struct attribute_group___124 **dev_groups;
	struct bin_attribute___126 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *);
	void (*class_release)(struct class___132 *);
	void (*dev_release)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
	struct subsys_private *p;
};

struct class_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct class___132 *, struct class_attribute___132 *, char *);
	ssize_t (*store)(struct class___132 *, struct class_attribute___132 *, const char *, size_t);
	const void * (*namespace)(struct class___132 *, const struct class_attribute___132 *);
};

struct device_rh___132 {
	struct dev_pm_info_rh___132 power;
};

struct vm_fault___144 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___166 *page;
};

struct ctl_node___34 {
	struct rb_node node;
	struct ctl_table_header___34 *header;
};

struct ctl_table_root___34 {
	struct ctl_table_set___34 default_set;
	struct ctl_table_set___34 * (*lookup)(struct ctl_table_root___34 *, struct nsproxy___101 *);
	int (*permissions)(struct ctl_table_header___34 *, struct ctl_table *);
};

struct nsproxy___101 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___33 *net_ns;
};

struct signal_struct___169 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___169 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___169 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___170 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___109;

struct css_set___109 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___109 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___20 {
	atomic_t use;
	unsigned int mask;
	struct net_device___22 *physindev;
	struct net_device___22 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___20(struct sk_buff___23 **);

struct net_device_ops___20;

struct ethtool_ops___20;

struct header_ops___20;

struct netdev_rx_queue___20;

struct netdev_queue___20;

struct rtnl_link_ops___16;

struct dcbnl_rtnl_ops___20;

struct net_device___22 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___20 *netdev_ops;
	const struct ethtool_ops___20 *ethtool_ops;
	const struct header_ops___20 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___19 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___20 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___20 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___20 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___20 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___20 = 0,
		NETREG_REGISTERED___20 = 1,
		NETREG_UNREGISTERING___20 = 2,
		NETREG_UNREGISTERED___20 = 3,
		NETREG_RELEASED___20 = 4,
		NETREG_DUMMY___20 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___20 = 0,
		RTNL_LINK_INITIALIZING___20 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___22 *);
	struct netpoll_info *npinfo;
	struct net___33 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___132 dev;
	const struct attribute_group___124 *sysfs_groups[4];
	const struct rtnl_link_ops___16 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___20 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___23 {
	struct sk_buff___23 *next;
	struct sk_buff___23 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___17 *sk;
	struct net_device___22 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___23 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___20 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct seq_operations___123;

struct seq_file___123 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___170 lock;
	const struct seq_operations___123 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___118 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___118 *);
	void (*irq_shutdown)(struct irq_data___118 *);
	void (*irq_enable)(struct irq_data___118 *);
	void (*irq_disable)(struct irq_data___118 *);
	void (*irq_ack)(struct irq_data___118 *);
	void (*irq_mask)(struct irq_data___118 *);
	void (*irq_mask_ack)(struct irq_data___118 *);
	void (*irq_unmask)(struct irq_data___118 *);
	void (*irq_eoi)(struct irq_data___118 *);
	int (*irq_set_affinity)(struct irq_data___118 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___118 *);
	int (*irq_set_type)(struct irq_data___118 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___118 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___118 *);
	void (*irq_bus_sync_unlock)(struct irq_data___118 *);
	void (*irq_cpu_online)(struct irq_data___118 *);
	void (*irq_cpu_offline)(struct irq_data___118 *);
	void (*irq_suspend)(struct irq_data___118 *);
	void (*irq_resume)(struct irq_data___118 *);
	void (*irq_pm_shutdown)(struct irq_data___118 *);
	void (*irq_print_chip)(struct irq_data___118 *, struct seq_file___123 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___118 *, void *);
	long unsigned int flags;
};

struct dentry_operations___167;

struct super_block___167;

struct dentry___167 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___167 *d_parent;
	struct qstr d_name;
	struct inode___167 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___167 *d_op;
	struct super_block___167 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___167;

struct file_lock___167;

struct dquot___167;

struct block_device___167;

struct inode___167 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___167 *i_op;
	struct super_block___167 *i_sb;
	struct address_space___167 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___170 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___167 *i_fop;
	struct file_lock___167 *i_flock;
	struct address_space___167 i_data;
	struct dquot___167 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___167 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___167 {
	int (*d_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_hash)(const struct dentry___167 *, struct qstr *);
	int (*d_compare)(const struct dentry___167 *, const struct dentry___167 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___167 *);
	void (*d_release)(struct dentry___167 *);
	void (*d_prune)(struct dentry___167 *);
	void (*d_iput)(struct dentry___167 *, struct inode___167 *);
	char * (*d_dname)(struct dentry___167 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___167 *);
	int (*d_manage)(struct dentry___167 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___167;

struct mem_dqinfo___167 {
	struct quota_format_type___167 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___167;

struct quota_info___167 {
	unsigned int flags;
	struct mutex___170 dqio_mutex;
	struct mutex___170 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___167 *files[2];
	struct mem_dqinfo___167 info[2];
	const struct quota_format_ops___167 *ops[2];
};

struct file_system_type___167;

struct super_operations___167;

struct dquot_operations___167;

struct quotactl_ops___167;

struct xattr_handler___110;

struct super_block___167 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___167 *s_type;
	const struct super_operations___167 *s_op;
	const struct dquot_operations___167 *dq_op;
	const struct quotactl_ops___167 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___167 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___110 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___167 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___167 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___170 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___167 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___167 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___167 *bd_inode;
	struct super_block___167 *bd_super;
	struct mutex___170 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___167 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___170 bd_fsfreeze_mutex;
};

struct cgroup___109;

struct cgroup_subsys_state___109 {
	struct cgroup___109 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___167 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___167 *ia_file;
};

struct dquot___167 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___170 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___167 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___167 {
	int qf_fmt_id;
	const struct quota_format_ops___167 *qf_ops;
	struct module___86 *qf_owner;
	struct quota_format_type___167 *qf_next;
};

struct quota_format_ops___167 {
	int (*check_quota_file)(struct super_block___167 *, int);
	int (*read_file_info)(struct super_block___167 *, int);
	int (*write_file_info)(struct super_block___167 *, int);
	int (*free_file_info)(struct super_block___167 *, int);
	int (*read_dqblk)(struct dquot___167 *);
	int (*commit_dqblk)(struct dquot___167 *);
	int (*release_dqblk)(struct dquot___167 *);
};

struct dquot_operations___167 {
	int (*write_dquot)(struct dquot___167 *);
	struct dquot___167 * (*alloc_dquot)(struct super_block___167 *, int);
	void (*destroy_dquot)(struct dquot___167 *);
	int (*acquire_dquot)(struct dquot___167 *);
	int (*release_dquot)(struct dquot___167 *);
	int (*mark_dirty)(struct dquot___167 *);
	int (*write_info)(struct super_block___167 *, int);
	qsize_t * (*get_reserved_space)(struct inode___167 *);
};

struct quotactl_ops___167 {
	int (*quota_on)(struct super_block___167 *, int, int, struct path___167 *);
	int (*quota_on_meta)(struct super_block___167 *, int, int);
	int (*quota_off)(struct super_block___167 *, int);
	int (*quota_sync)(struct super_block___167 *, int);
	int (*get_info)(struct super_block___167 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___167 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___167 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___167 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___167 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___167 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___167 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___167 *, unsigned int);
};

struct address_space_operations___167 {
	int (*writepage)(struct page___166 *, struct writeback_control *);
	int (*readpage)(struct file___167 *, struct page___166 *);
	int (*writepages)(struct address_space___167 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___166 *);
	int (*readpages)(struct file___167 *, struct address_space___167 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___167 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___166 **, void **);
	int (*write_end)(struct file___167 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___166 *, void *);
	sector_t (*bmap)(struct address_space___167 *, sector_t);
	void (*invalidatepage)(struct page___166 *, long unsigned int);
	int (*releasepage)(struct page___166 *, gfp_t);
	void (*freepage)(struct page___166 *);
	ssize_t (*direct_IO)(int, struct kiocb___23 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___167 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___167 *, struct page___166 *, struct page___166 *, enum migrate_mode);
	int (*launder_page)(struct page___166 *);
	int (*is_partially_uptodate)(struct page___166 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___166 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___167 *, struct page___166 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___167 *, sector_t *);
	void (*swap_deactivate)(struct file___167 *);
	void (*invalidatepage_range)(struct page___166 *, unsigned int, unsigned int);
};

struct inode_operations___167 {
	struct dentry___167 * (*lookup)(struct inode___167 *, struct dentry___167 *, unsigned int);
	void * (*follow_link)(struct dentry___167 *, struct nameidata *);
	int (*permission)(struct inode___167 *, int);
	struct posix_acl * (*get_acl)(struct inode___167 *, int);
	int (*readlink)(struct dentry___167 *, char *, int);
	void (*put_link)(struct dentry___167 *, struct nameidata *, void *);
	int (*create)(struct inode___167 *, struct dentry___167 *, umode_t, bool);
	int (*link)(struct dentry___167 *, struct inode___167 *, struct dentry___167 *);
	int (*unlink)(struct inode___167 *, struct dentry___167 *);
	int (*symlink)(struct inode___167 *, struct dentry___167 *, const char *);
	int (*mkdir)(struct inode___167 *, struct dentry___167 *, umode_t);
	int (*rmdir)(struct inode___167 *, struct dentry___167 *);
	int (*mknod)(struct inode___167 *, struct dentry___167 *, umode_t, dev_t);
	int (*rename)(struct inode___167 *, struct dentry___167 *, struct inode___167 *, struct dentry___167 *);
	int (*setattr)(struct dentry___167 *, struct iattr___167 *);
	int (*getattr)(struct vfsmount *, struct dentry___167 *, struct kstat *);
	int (*setxattr)(struct dentry___167 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___167 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___167 *, char *, size_t);
	int (*removexattr)(struct dentry___167 *, const char *);
	int (*fiemap)(struct inode___167 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___167 *, struct timespec *, int);
	int (*atomic_open)(struct inode___167 *, struct dentry___167 *, struct file___167 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___167 {
	struct module___86 *owner;
	loff_t (*llseek)(struct file___167 *, loff_t, int);
	ssize_t (*read)(struct file___167 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___167 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___23 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___23 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___167 *, void *, filldir_t);
	unsigned int (*poll)(struct file___167 *, struct poll_table_struct___99 *);
	long int (*unlocked_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___167 *, struct vm_area_struct___174 *);
	int (*open)(struct inode___167 *, struct file___167 *);
	int (*flush)(struct file___167 *, fl_owner_t);
	int (*release)(struct inode___167 *, struct file___167 *);
	int (*fsync)(struct file___167 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___23 *, int);
	int (*fasync)(int, struct file___167 *, int);
	int (*lock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*sendpage)(struct file___167 *, struct page___166 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___167 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___167 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___167 *, long int, struct file_lock___167 **, void **);
		struct {
			int (*setlease)(struct file___167 *, long int, struct file_lock___167 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___167 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___123 *, struct file___167 *);
};

struct file_lock_operations___167;

struct lock_manager_operations___167;

struct file_lock___167 {
	struct file_lock___167 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___167 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___167 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___167 *fl_ops;
	const struct lock_manager_operations___167 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___167 {
	void (*fl_copy_lock)(struct file_lock___167 *, struct file_lock___167 *);
	void (*fl_release_private)(struct file_lock___167 *);
};

struct lock_manager_operations___167 {
	int (*lm_compare_owner)(struct file_lock___167 *, struct file_lock___167 *);
	long unsigned int (*lm_owner_key)(struct file_lock___167 *);
	void (*lm_notify)(struct file_lock___167 *);
	int (*lm_grant)(struct file_lock___167 *, struct file_lock___167 *, int);
	void (*lm_break)(struct file_lock___167 *);
	int (*lm_change)(struct file_lock___167 **, int);
};

struct file_system_type___167 {
	const char *name;
	int fs_flags;
	struct dentry___167 * (*mount)(struct file_system_type___167 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___167 *);
	struct module___86 *owner;
	struct file_system_type___167 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___167 {
	struct inode___167 * (*alloc_inode)(struct super_block___167 *);
	void (*destroy_inode)(struct inode___167 *);
	void (*dirty_inode)(struct inode___167 *, int);
	int (*write_inode)(struct inode___167 *, struct writeback_control *);
	int (*drop_inode)(struct inode___167 *);
	void (*evict_inode)(struct inode___167 *);
	void (*put_super)(struct super_block___167 *);
	int (*sync_fs)(struct super_block___167 *, int);
	int (*freeze_fs)(struct super_block___167 *);
	int (*unfreeze_fs)(struct super_block___167 *);
	int (*statfs)(struct dentry___167 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___167 *, int *, char *);
	void (*umount_begin)(struct super_block___167 *);
	int (*show_options)(struct seq_file___123 *, struct dentry___167 *);
	int (*show_devname)(struct seq_file___123 *, struct dentry___167 *);
	int (*show_path)(struct seq_file___123 *, struct dentry___167 *);
	int (*show_stats)(struct seq_file___123 *, struct dentry___167 *);
	ssize_t (*quota_read)(struct super_block___167 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___167 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___167 *);
	int (*bdev_try_to_free_page)(struct super_block___167 *, struct page___166 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___167 *);
	void (*free_cached_objects)(struct super_block___167 *, int);
};

struct xattr_handler___110 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___167 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___167 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___167 *, const char *, const void *, size_t, int, int);
};

struct dev_pm_qos_request___24 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___132 *dev;
};

struct ethtool_ops___20 {
	int (*get_settings)(struct net_device___22 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___22 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___22 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___22 *);
	void (*get_regs)(struct net_device___22 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___22 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___22 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___22 *);
	void (*set_msglevel)(struct net_device___22 *, u32);
	int (*nway_reset)(struct net_device___22 *);
	u32 (*get_link)(struct net_device___22 *);
	int (*get_eeprom_len)(struct net_device___22 *);
	int (*get_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___22 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___22 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___22 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___22 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___22 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___22 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___22 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___22 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___22 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___22 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___22 *);
	void (*complete)(struct net_device___22 *);
	u32 (*get_priv_flags)(struct net_device___22 *);
	int (*set_priv_flags)(struct net_device___22 *, u32);
	int (*get_sset_count)(struct net_device___22 *, int);
	int (*get_rxnfc)(struct net_device___22 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___22 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___22 *, struct ethtool_flash *);
	int (*reset)(struct net_device___22 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___22 *);
	int (*get_rxfh_indir)(struct net_device___22 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___22 *, const u32 *);
	void (*get_channels)(struct net_device___22 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___22 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___22 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___22 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___22 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___22 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___22 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___22 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___22 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___22 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___22 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___22 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___16 {
	struct callback_head callback_head;
	struct dst_entry___16 *child;
	struct net_device___22 *dev;
	struct dst_ops___32 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___16 *path;
	struct dst_entry___16 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___23 *);
	union {
		int (*output)(struct sock___17 *, struct sk_buff___23 *);
		struct {
			int (*output)(struct sk_buff___23 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___16 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___16;

struct neigh_parms___16;

struct neigh_ops___16;

struct neighbour___16 {
	struct neighbour___16 *next;
	struct neigh_table___16 *tbl;
	struct neigh_parms___16 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___21 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___16 *, struct sk_buff___23 *);
	const struct neigh_ops___16 *ops;
	struct callback_head rcu;
	struct net_device___22 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___32 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___23 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___23 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___33 *, struct dst_entry___16 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___23 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___23 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___123 {
	void * (*start)(struct seq_file___123 *, loff_t *);
	void (*stop)(struct seq_file___123 *, void *);
	void * (*next)(struct seq_file___123 *, void *, loff_t *);
	int (*show)(struct seq_file___123 *, void *);
};

struct dcbnl_rtnl_ops___20 {
	int (*ieee_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___22 *);
	u8 (*setstate)(struct net_device___22 *, u8);
	void (*getpermhwaddr)(struct net_device___22 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___22 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___22 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___22 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___22 *, int, u8 *);
	void (*setpfccfg)(struct net_device___22 *, int, u8);
	void (*getpfccfg)(struct net_device___22 *, int, u8 *);
	u8 (*setall)(struct net_device___22 *);
	u8 (*getcap)(struct net_device___22 *, int, u8 *);
	int (*getnumtcs)(struct net_device___22 *, int, u8 *);
	int (*setnumtcs)(struct net_device___22 *, int, u8);
	u8 (*getpfcstate)(struct net_device___22 *);
	void (*setpfcstate)(struct net_device___22 *, u8);
	void (*getbcncfg)(struct net_device___22 *, int, u32 *);
	void (*setbcncfg)(struct net_device___22 *, int, u32);
	void (*getbcnrp)(struct net_device___22 *, int, u8 *);
	void (*setbcnrp)(struct net_device___22 *, int, u8);
	u8 (*setapp)(struct net_device___22 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___22 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___22 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___22 *, int, u8);
	u8 (*getdcbx)(struct net_device___22 *);
	u8 (*setdcbx)(struct net_device___22 *, u8);
	int (*peer_getappinfo)(struct net_device___22 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___22 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___22 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___22 *, struct cee_pfc *);
};

struct cgroupfs_root___109;

struct cgroup___109 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___109 *parent;
	struct dentry___167 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___109 *subsys[11];
	struct cgroupfs_root___109 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___170 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___109 {
	struct super_block___167 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___109 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___56 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___167 *, struct file___167 *);
	ssize_t (*read)(struct cgroup___109 *, struct cftype___56 *, struct file___167 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___109 *, struct cftype___56 *);
	s64 (*read_s64)(struct cgroup___109 *, struct cftype___56 *);
	int (*read_map)(struct cgroup___109 *, struct cftype___56 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___109 *, struct cftype___56 *, struct seq_file___123 *);
	ssize_t (*write)(struct cgroup___109 *, struct cftype___56 *, struct file___167 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___109 *, struct cftype___56 *, u64);
	int (*write_s64)(struct cgroup___109 *, struct cftype___56 *, s64);
	int (*write_string)(struct cgroup___109 *, struct cftype___56 *, const char *);
	int (*trigger)(struct cgroup___109 *, unsigned int);
	int (*release)(struct inode___167 *, struct file___167 *);
	int (*register_event)(struct cgroup___109 *, struct cftype___56 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___109 *, struct cftype___56 *, struct eventfd_ctx *);
};

struct cftype_set___54 {
	struct list_head node;
	struct cftype___56 *cfts;
};

struct task_and_cgroup___54 {
	struct task_struct___169 *task;
	struct cgroup___109 *cgrp;
	struct css_set___109 *cg;
};

struct cgroup_taskset___54 {
	struct task_and_cgroup___54 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___109 *cur_cgrp;
};

struct cgroup_subsys___54 {
	struct cgroup_subsys_state___109 * (*css_alloc)(struct cgroup___109 *);
	int (*css_online)(struct cgroup___109 *);
	void (*css_offline)(struct cgroup___109 *);
	void (*css_free)(struct cgroup___109 *);
	int (*can_attach)(struct cgroup___109 *, struct cgroup_taskset___54 *);
	void (*cancel_attach)(struct cgroup___109 *, struct cgroup_taskset___54 *);
	void (*attach)(struct cgroup___109 *, struct cgroup_taskset___54 *);
	void (*fork)(struct task_struct___169 *);
	void (*exit)(struct cgroup___109 *, struct cgroup___109 *, struct task_struct___169 *);
	void (*bind)(struct cgroup___109 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___109 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___56 *base_cftypes;
	struct cftype_set___54 base_cftset;
	struct module___86 *module;
};

struct netlink_callback___21 {
	struct sk_buff___23 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___23 *, struct netlink_callback___21 *);
	int (*done)(struct netlink_callback___21 *);
	void *data;
	struct module___86 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___20 {
	int (*create)(struct sk_buff___23 *, struct net_device___22 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___23 *, unsigned char *);
	int (*rebuild)(struct sk_buff___23 *);
	int (*cache)(const struct neighbour___16 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___22 *, const unsigned char *);
};

struct napi_struct___20 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___20 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___22 *dev;
	struct sk_buff___23 *gro_list;
	struct sk_buff___23 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___20 {
	struct net_device___22 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___19 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___20 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___19 kobj;
	struct net_device___22 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___20 {
	int (*ndo_init)(struct net_device___22 *);
	void (*ndo_uninit)(struct net_device___22 *);
	int (*ndo_open)(struct net_device___22 *);
	int (*ndo_stop)(struct net_device___22 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___23 *, struct net_device___22 *);
	u16 (*ndo_select_queue)(struct net_device___22 *, struct sk_buff___23 *);
	void (*ndo_change_rx_flags)(struct net_device___22 *, int);
	void (*ndo_set_rx_mode)(struct net_device___22 *);
	int (*ndo_set_mac_address)(struct net_device___22 *, void *);
	int (*ndo_validate_addr)(struct net_device___22 *);
	int (*ndo_do_ioctl)(struct net_device___22 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___22 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___22 *, int);
	int (*ndo_neigh_setup)(struct net_device___22 *, struct neigh_parms___16 *);
	void (*ndo_tx_timeout)(struct net_device___22 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___22 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___22 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___22 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___22 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___22 *);
	int (*ndo_netpoll_setup)(struct net_device___22 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___22 *);
	int (*ndo_busy_poll)(struct napi_struct___20 *);
	int (*ndo_set_vf_mac)(struct net_device___22 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___22 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___22 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___22 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___22 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___22 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___22 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___22 *, int, struct sk_buff___23 *);
	int (*ndo_setup_tc)(struct net_device___22 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___22 *);
	int (*ndo_fcoe_disable)(struct net_device___22 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___22 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___22 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___22 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___22 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___22 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___22 *, const struct sk_buff___23 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___22 *, struct net_device___22 *);
	int (*ndo_del_slave)(struct net_device___22 *, struct net_device___22 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___16 *);
	void (*ndo_neigh_destroy)(struct neighbour___16 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___23 *, struct netlink_callback___21 *, struct net_device___22 *, int);
	int (*ndo_bridge_setlink)(struct net_device___22 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___23 *, u32, u32, struct net_device___22 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___22 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___22 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___22 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___22 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___22 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___22 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___23 *, struct net_device___22 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___22 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___22 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___22 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___16 {
	struct net___33 *net;
	struct net_device___22 *dev;
	struct neigh_parms___16 *next;
	int (*neigh_setup)(struct neighbour___16 *);
	void (*neigh_cleanup)(struct neighbour___16 *);
	struct neigh_table___16 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___16 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___22 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___33 *, struct net_device___22 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___22 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___22 *, struct list_head *);
	size_t (*get_size)(const struct net_device___22 *);
	int (*fill_info)(struct sk_buff___23 *, const struct net_device___22 *);
	size_t (*get_xstats_size)(const struct net_device___22 *);
	int (*fill_xstats)(struct sk_buff___23 *, const struct net_device___22 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___33 * (*get_link_net)(const struct net_device___22 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___22 *, struct net_device___22 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___22 *, const struct net_device___22 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___23 *, const struct net_device___22 *, const struct net_device___22 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___17 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___23 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef struct poll_table_struct___99 poll_table___19;

struct pneigh_entry___16;

struct neigh_hash_table___16;

struct neigh_table___16 {
	struct neigh_table___16 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___22 *, __u32 *);
	int (*constructor)(struct neighbour___16 *);
	int (*pconstructor)(struct pneigh_entry___16 *);
	void (*pdestructor)(struct pneigh_entry___16 *);
	void (*proxy_redo)(struct sk_buff___23 *);
	char *id;
	struct neigh_parms___16 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___21 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___16 *nht;
	struct pneigh_entry___16 **phash_buckets;
};

struct neigh_ops___16 {
	int family;
	void (*solicit)(struct neighbour___16 *, struct sk_buff___23 *);
	void (*error_report)(struct neighbour___16 *, struct sk_buff___23 *);
	int (*output)(struct neighbour___16 *, struct sk_buff___23 *);
	int (*connected_output)(struct neighbour___16 *, struct sk_buff___23 *);
};

struct pneigh_entry___16 {
	struct pneigh_entry___16 *next;
	struct net___33 *net;
	struct net_device___22 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___16 {
	struct neighbour___16 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___16 {
	void (*close)(struct sock___17 *, long int);
	int (*connect)(struct sock___17 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___17 *, int);
	struct sock___17 * (*accept)(struct sock___17 *, int, int *);
	int (*ioctl)(struct sock___17 *, int, long unsigned int);
	int (*init)(struct sock___17 *);
	void (*destroy)(struct sock___17 *);
	void (*shutdown)(struct sock___17 *, int);
	int (*setsockopt)(struct sock___17 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___17 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___17 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___17 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___17 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___23 *, struct sock___17 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___23 *, struct sock___17 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___17 *, struct page___166 *, int, size_t, int);
	int (*bind)(struct sock___17 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___17 *, struct sk_buff___23 *);
	void (*release_cb)(struct sock___17 *);
	void (*mtu_reduced)(struct sock___17 *);
	void (*hash)(struct sock___17 *);
	void (*unhash)(struct sock___17 *);
	void (*rehash)(struct sock___17 *);
	int (*get_port)(struct sock___17 *, short unsigned int);
	void (*clear_sk)(struct sock___17 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___17 *);
	void (*enter_memory_pressure)(struct sock___17 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___153 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___86 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___54 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___16 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___16 {
	void (*enter_memory_pressure)(struct sock___17 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct af_alg_type___2;

struct alg_sock___2 {
	struct sock___17 sk;
	struct sock___17 *parent;
	const struct af_alg_type___2 *type;
	void *private;
};

struct af_alg_type___2 {
	void * (*bind)(const char *, u32, u32);
	void (*release)(void *);
	int (*setkey)(void *, const u8 *, unsigned int);
	int (*accept)(void *, struct sock___17 *);
	struct proto_ops___16 *ops;
	struct module___86 *owner;
	char name[14];
};

struct af_alg_sgl___2 {
	struct scatterlist sg[16];
	struct page___166 *pages[16];
};

struct module_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___85 *, struct module_kobject___85 *, char *);
	ssize_t (*store)(struct module_attribute___85 *, struct module_kobject___85 *, const char *, size_t);
	void (*setup)(struct module___86 *, const char *);
	int (*test)(struct module___86 *);
	void (*free)(struct module___86 *);
};

struct skcipher_sg_list {
	struct list_head list;
	int cur;
	struct scatterlist sg[0];
};

struct skcipher_ctx {
	struct list_head tsgl;
	struct af_alg_sgl___2 rsgl;
	void *iv;
	struct af_alg_completion completion;
	unsigned int used;
	unsigned int len;
	bool more;
	bool merge;
	bool enc;
	struct ablkcipher_request___10 req;
};

struct asymmetric_key_subtype {
	struct module___86 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___10 *, struct seq_file___123 *);
	void (*destroy)(void *);
	int (*verify_signature)(const struct key___10 *, const struct public_key_signature *);
};

struct asymmetric_key_parser {
	struct list_head link;
	struct module___86 *owner;
	const char *name;
	int (*parse)(struct key_preparsed_payload *);
};

struct public_key_algorithm;

struct public_key {
	const struct public_key_algorithm *algo;
	u8 capabilities;
	enum pkey_algo pkey_algo: 8;
	enum pkey_id_type id_type: 8;
	union {
		MPI mpi[5];
		struct {
			MPI p;
			MPI q;
			MPI g;
			MPI y;
			MPI x;
		} dsa;
		struct {
			MPI n;
			MPI e;
			MPI d;
			MPI p;
			MPI q;
		} rsa;
	};
};

struct public_key_algorithm {
	const char *name;
	u8 n_pub_mpi;
	u8 n_sec_mpi;
	u8 n_sig_mpi;
	int (*verify_signature)(const struct public_key *, const struct public_key_signature *);
};

typedef struct {
	efi_guid_t signature_owner;
	u8 signature_data[0];
} efi_signature_data_t;

typedef struct {
	efi_guid_t signature_type;
	u32 signature_list_size;
	u32 signature_header_size;
	u32 signature_size;
	u8 signature_header[0];
} efi_signature_list_t;

enum asn1_class {
	ASN1_UNIV = 0,
	ASN1_APPL = 1,
	ASN1_CONT = 2,
	ASN1_PRIV = 3,
};

enum asn1_method {
	ASN1_PRIM = 0,
	ASN1_CONS = 1,
};

enum asn1_tag {
	ASN1_EOC = 0,
	ASN1_BOOL = 1,
	ASN1_INT = 2,
	ASN1_BTS = 3,
	ASN1_OTS = 4,
	ASN1_NULL = 5,
	ASN1_OID = 6,
	ASN1_ODE = 7,
	ASN1_EXT = 8,
	ASN1_REAL = 9,
	ASN1_ENUM = 10,
	ASN1_EPDV = 11,
	ASN1_UTF8STR = 12,
	ASN1_RELOID = 13,
	ASN1_SEQ = 16,
	ASN1_SET = 17,
	ASN1_NUMSTR = 18,
	ASN1_PRNSTR = 19,
	ASN1_TEXSTR = 20,
	ASN1_VIDSTR = 21,
	ASN1_IA5STR = 22,
	ASN1_UNITIM = 23,
	ASN1_GENTIM = 24,
	ASN1_GRASTR = 25,
	ASN1_VISSTR = 26,
	ASN1_GENSTR = 27,
	ASN1_UNISTR = 28,
	ASN1_CHRSTR = 29,
	ASN1_BMPSTR = 30,
	ASN1_LONG_TAG = 31,
};

typedef int (*asn1_action_t)(void *, size_t, unsigned char, const void *, size_t);

struct asn1_decoder {
	const unsigned char *machine;
	size_t machlen;
	const asn1_action_t *actions;
};

enum asn1_opcode {
	ASN1_OP_MATCH = 0,
	ASN1_OP_MATCH_OR_SKIP = 1,
	ASN1_OP_MATCH_ACT = 2,
	ASN1_OP_MATCH_ACT_OR_SKIP = 3,
	ASN1_OP_MATCH_JUMP = 4,
	ASN1_OP_MATCH_JUMP_OR_SKIP = 5,
	ASN1_OP_MATCH_ANY = 8,
	ASN1_OP_MATCH_ANY_ACT = 10,
	ASN1_OP_COND_MATCH_OR_SKIP = 17,
	ASN1_OP_COND_MATCH_ACT_OR_SKIP = 19,
	ASN1_OP_COND_MATCH_JUMP_OR_SKIP = 21,
	ASN1_OP_COND_MATCH_ANY = 24,
	ASN1_OP_COND_MATCH_ANY_ACT = 26,
	ASN1_OP_COND_FAIL = 27,
	ASN1_OP_COMPLETE = 28,
	ASN1_OP_ACT = 29,
	ASN1_OP_RETURN = 30,
	ASN1_OP_END_SEQ = 32,
	ASN1_OP_END_SET = 33,
	ASN1_OP_END_SEQ_OF = 34,
	ASN1_OP_END_SET_OF = 35,
	ASN1_OP_END_SEQ_ACT = 36,
	ASN1_OP_END_SET_ACT = 37,
	ASN1_OP_END_SEQ_OF_ACT = 38,
	ASN1_OP_END_SET_OF_ACT = 39,
	ASN1_OP__NR = 40,
};

enum x509_actions {
	ACT_x509_extract_key_data = 0,
	ACT_x509_extract_name_segment = 1,
	ACT_x509_note_OID = 2,
	ACT_x509_note_issuer = 3,
	ACT_x509_note_not_after = 4,
	ACT_x509_note_not_before = 5,
	ACT_x509_note_pkey_algo = 6,
	ACT_x509_note_serial = 7,
	ACT_x509_note_signature = 8,
	ACT_x509_note_subject = 9,
	ACT_x509_note_tbs_certificate = 10,
	ACT_x509_process_extension = 11,
	NR__x509_actions = 12,
};

enum x509_rsakey_actions {
	ACT_rsa_extract_mpi = 0,
	NR__x509_rsakey_actions = 1,
};

enum OID {
	OID_id_dsa_with_sha1 = 0,
	OID_id_dsa = 1,
	OID_id_ecdsa_with_sha1 = 2,
	OID_id_ecPublicKey = 3,
	OID_rsaEncryption = 4,
	OID_md2WithRSAEncryption = 5,
	OID_md3WithRSAEncryption = 6,
	OID_md4WithRSAEncryption = 7,
	OID_sha1WithRSAEncryption = 8,
	OID_sha256WithRSAEncryption = 9,
	OID_sha384WithRSAEncryption = 10,
	OID_sha512WithRSAEncryption = 11,
	OID_sha224WithRSAEncryption = 12,
	OID_data = 13,
	OID_signed_data = 14,
	OID_email_address = 15,
	OID_content_type = 16,
	OID_messageDigest = 17,
	OID_signingTime = 18,
	OID_smimeCapabilites = 19,
	OID_smimeAuthenticatedAttrs = 20,
	OID_md2 = 21,
	OID_md4 = 22,
	OID_md5 = 23,
	OID_msIndirectData = 24,
	OID_msPeImageDataObjId = 25,
	OID_msIndividualSPKeyPurpose = 26,
	OID_msOutlookExpress = 27,
	OID_certAuthInfoAccess = 28,
	OID_sha1 = 29,
	OID_sha256 = 30,
	OID_commonName = 31,
	OID_surname = 32,
	OID_countryName = 33,
	OID_locality = 34,
	OID_stateOrProvinceName = 35,
	OID_organizationName = 36,
	OID_organizationUnitName = 37,
	OID_title = 38,
	OID_description = 39,
	OID_name = 40,
	OID_givenName = 41,
	OID_initials = 42,
	OID_generationalQualifier = 43,
	OID_subjectKeyIdentifier = 44,
	OID_keyUsage = 45,
	OID_subjectAltName = 46,
	OID_issuerAltName = 47,
	OID_basicConstraints = 48,
	OID_crlDistributionPoints = 49,
	OID_certPolicies = 50,
	OID_authorityKeyIdentifier = 51,
	OID_extKeyUsage = 52,
	OID__NR = 53,
};

struct x509_certificate {
	struct x509_certificate *next;
	struct x509_certificate *signer;
	struct public_key *pub;
	struct public_key_signature sig;
	char *issuer;
	char *subject;
	char *fingerprint;
	char *authority;
	struct tm valid_from;
	struct tm valid_to;
	enum pkey_algo pkey_algo: 8;
	enum hash_algo sig_hash_algo: 8;
	const void *tbs;
	unsigned int tbs_size;
	unsigned int raw_sig_size;
	const void *raw_sig;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	const void *raw_subject;
	unsigned int raw_subject_size;
	unsigned int index;
	bool seen;
	bool verified;
	bool trusted;
};

struct x509_parse_context {
	struct x509_certificate *cert;
	long unsigned int data;
	const void *cert_start;
	const void *key;
	size_t key_size;
	enum OID last_oid;
	enum OID algo_oid;
	unsigned char nr_mpi;
	u8 o_size;
	u8 cn_size;
	u8 email_size;
	u16 o_offset;
	u16 cn_offset;
	u16 email_offset;
};

struct asn1_decoder___2;

enum pkcs7_actions {
	ACT_pkcs7_extract_cert = 0,
	ACT_pkcs7_note_OID = 1,
	ACT_pkcs7_note_certificate_list = 2,
	ACT_pkcs7_note_data = 3,
	ACT_pkcs7_note_signed_info = 4,
	ACT_pkcs7_sig_note_authenticated_attr = 5,
	ACT_pkcs7_sig_note_digest_algo = 6,
	ACT_pkcs7_sig_note_issuer = 7,
	ACT_pkcs7_sig_note_pkey_algo = 8,
	ACT_pkcs7_sig_note_serial = 9,
	ACT_pkcs7_sig_note_set_of_authattrs = 10,
	ACT_pkcs7_sig_note_signature = 11,
	NR__pkcs7_actions = 12,
};

struct pkcs7_signed_info {
	struct pkcs7_signed_info *next;
	struct x509_certificate *signer;
	unsigned int index;
	bool trusted;
	const void *msgdigest;
	unsigned int msgdigest_len;
	unsigned int authattrs_len;
	const void *authattrs;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	struct public_key_signature sig;
};

struct pkcs7_message {
	struct x509_certificate *certs;
	struct x509_certificate *crl;
	struct pkcs7_signed_info *signed_infos;
	enum OID data_type;
	size_t data_len;
	size_t data_hdrlen;
	const void *data;
};

struct pkcs7_parse_context {
	struct pkcs7_message *msg;
	struct pkcs7_signed_info *sinfo;
	struct pkcs7_signed_info **ppsinfo;
	struct x509_certificate *certs;
	struct x509_certificate **ppcerts;
	long unsigned int data;
	enum OID last_oid;
	unsigned int x509_index;
	unsigned int sinfo_index;
};

struct mz_hdr {
	uint16_t magic;
	uint16_t lbsize;
	uint16_t blocks;
	uint16_t relocs;
	uint16_t hdrsize;
	uint16_t min_extra_pps;
	uint16_t max_extra_pps;
	uint16_t ss;
	uint16_t sp;
	uint16_t checksum;
	uint16_t ip;
	uint16_t cs;
	uint16_t reloc_table_offset;
	uint16_t overlay_num;
	uint16_t reserved0[4];
	uint16_t oem_id;
	uint16_t oem_info;
	uint16_t reserved1[10];
	uint32_t peaddr;
	char message[64];
};

struct pe_hdr {
	uint32_t magic;
	uint16_t machine;
	uint16_t sections;
	uint32_t timestamp;
	uint32_t symbol_table;
	uint32_t symbols;
	uint16_t opt_hdr_size;
	uint16_t flags;
};

struct pe32_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint32_t data_base;
	uint32_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint32_t stack_size_req;
	uint32_t stack_size;
	uint32_t heap_size_req;
	uint32_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct pe32plus_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint64_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint64_t stack_size_req;
	uint64_t stack_size;
	uint64_t heap_size_req;
	uint64_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct data_dirent {
	uint32_t virtual_address;
	uint32_t size;
};

struct data_directory {
	struct data_dirent exports;
	struct data_dirent imports;
	struct data_dirent resources;
	struct data_dirent exceptions;
	struct data_dirent certs;
	struct data_dirent base_relocations;
	struct data_dirent debug;
	struct data_dirent arch;
	struct data_dirent global_ptr;
	struct data_dirent tls;
	struct data_dirent load_config;
	struct data_dirent bound_imports;
	struct data_dirent import_addrs;
	struct data_dirent delay_imports;
	struct data_dirent clr_runtime_hdr;
	struct data_dirent reserved;
};

struct section_header {
	char name[8];
	uint32_t virtual_size;
	uint32_t virtual_address;
	uint32_t raw_data_size;
	uint32_t data_addr;
	uint32_t relocs;
	uint32_t line_numbers;
	uint16_t num_relocs;
	uint16_t num_lin_numbers;
	uint32_t flags;
};

struct win_certificate {
	uint32_t length;
	uint16_t revision;
	uint16_t cert_type;
};

struct pkcs7_message___2;

struct pefile_context {
	unsigned int header_size;
	unsigned int image_checksum_offset;
	unsigned int cert_dirent_offset;
	unsigned int n_data_dirents;
	unsigned int n_sections;
	unsigned int certs_size;
	unsigned int sig_offset;
	unsigned int sig_len;
	const struct section_header *secs;
	struct pkcs7_message___2 *pkcs7;
	const void *digest;
	unsigned int digest_len;
	enum hash_algo digest_algo;
};

struct key___11;

enum mscode_actions {
	ACT_mscode_note_content_type = 0,
	ACT_mscode_note_digest = 1,
	ACT_mscode_note_digest_algo = 2,
	NR__mscode_actions = 3,
};

struct page___167;

typedef struct page___167 *pgtable_t___167;

struct address_space___168;

struct kmem_cache___154;

struct page___167 {
	long unsigned int flags;
	struct address_space___168 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___167 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___167 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___154 *slab_cache;
		struct page___167 *first_page;
	};
	long: 64;
};

struct task_struct___170;

struct pv_cpu_ops___170 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___75 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___75 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___170 *);
	void (*end_context_switch)(struct task_struct___170 *);
};

struct mutex___171 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___170 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___163 {
	struct page___167 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___175;

struct signal_struct___170;

struct bio_list___22;

struct backing_dev_info___32;

struct io_context___22;

struct css_set___110;

struct task_struct___170 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___170 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___175 *mm;
	struct mm_struct___175 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___170 *real_parent;
	struct task_struct___170 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___170 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___84 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___170 = 0,
		VTIME_USER___170 = 1,
		VTIME_SYS___170 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___75 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___170 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___22 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___32 *backing_dev_info;
	struct io_context___22 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___110 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___171 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___163 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___175 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___175 *, struct mm_struct___175 *);
	void (*dup_mmap)(struct mm_struct___175 *, struct mm_struct___175 *);
	void (*exit_mmap)(struct mm_struct___175 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___175 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___175 *);
	void (*pgd_free)(struct mm_struct___175 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___175 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___175 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___175 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___175 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___175 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___175 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___175 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___175 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___175 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___175 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___175 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___171 lock;
	void *vdso;
} mm_context_t___171;

struct xol_area___167;

struct uprobes_state___167 {
	struct xol_area___167 *xol_area;
};

struct vm_area_struct___175;

struct file___168;

struct core_state___170;

struct mm_struct___175 {
	struct vm_area_struct___175 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___175 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___175 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___171 context;
	long unsigned int flags;
	struct core_state___170 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___170 *owner;
	struct file___168 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___167 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___87;

struct module_kobject___86 {
	struct kobject___19 kobj;
	struct module___87 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___86;

struct module___87 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___86 mkobj;
	struct module_attribute___86 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___170 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___168;

struct dentry_operations___168;

struct super_block___168;

struct dentry___168 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___168 *d_parent;
	struct qstr d_name;
	struct inode___168 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___168 *d_op;
	struct super_block___168 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___168;

struct address_space___168 {
	struct inode___168 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___171 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___168 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___32 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___168;

struct file_operations___168;

struct file_lock___168;

struct dquot___168;

struct block_device___168;

struct inode___168 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___168 *i_op;
	struct super_block___168 *i_sb;
	struct address_space___168 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___171 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___168 *i_fop;
	struct file_lock___168 *i_flock;
	struct address_space___168 i_data;
	struct dquot___168 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___168 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___168;

struct dentry_operations___168 {
	int (*d_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_hash)(const struct dentry___168 *, struct qstr *);
	int (*d_compare)(const struct dentry___168 *, const struct dentry___168 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___168 *);
	void (*d_release)(struct dentry___168 *);
	void (*d_prune)(struct dentry___168 *);
	void (*d_iput)(struct dentry___168 *, struct inode___168 *);
	char * (*d_dname)(struct dentry___168 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___168 *);
	int (*d_manage)(struct dentry___168 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___168;

struct mem_dqinfo___168 {
	struct quota_format_type___168 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___168;

struct quota_info___168 {
	unsigned int flags;
	struct mutex___171 dqio_mutex;
	struct mutex___171 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___168 *files[2];
	struct mem_dqinfo___168 info[2];
	const struct quota_format_ops___168 *ops[2];
};

struct file_system_type___168;

struct super_operations___168;

struct dquot_operations___168;

struct quotactl_ops___168;

struct xattr_handler___111;

struct super_block___168 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___168 *s_type;
	const struct super_operations___168 *s_op;
	const struct dquot_operations___168 *dq_op;
	const struct quotactl_ops___168 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___168 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___111 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___168 *s_bdev;
	struct backing_dev_info___32 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___168 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___171 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___168 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___168 {
	struct vfsmount *mnt;
	struct dentry___168 *dentry;
};

struct irq_data___119;

struct x86_io_apic_ops___119 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___119 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___119;

struct irq_data___119 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___119 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___133;

struct dev_pm_ops___133 {
	int (*prepare)(struct device___133 *);
	void (*complete)(struct device___133 *);
	int (*suspend)(struct device___133 *);
	int (*resume)(struct device___133 *);
	int (*freeze)(struct device___133 *);
	int (*thaw)(struct device___133 *);
	int (*poweroff)(struct device___133 *);
	int (*restore)(struct device___133 *);
	int (*suspend_late)(struct device___133 *);
	int (*resume_early)(struct device___133 *);
	int (*freeze_late)(struct device___133 *);
	int (*thaw_early)(struct device___133 *);
	int (*poweroff_late)(struct device___133 *);
	int (*restore_early)(struct device___133 *);
	int (*suspend_noirq)(struct device___133 *);
	int (*resume_noirq)(struct device___133 *);
	int (*freeze_noirq)(struct device___133 *);
	int (*thaw_noirq)(struct device___133 *);
	int (*poweroff_noirq)(struct device___133 *);
	int (*restore_noirq)(struct device___133 *);
	int (*runtime_suspend)(struct device___133 *);
	int (*runtime_resume)(struct device___133 *);
	int (*runtime_idle)(struct device___133 *);
};

struct device_type___133;

struct bus_type___133;

struct device_driver___133;

struct dev_pm_domain___133;

struct class___133;

struct attribute_group___125;

struct device_rh___133;

struct device___133 {
	struct device___133 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___133 *type;
	struct mutex___171 mutex;
	struct bus_type___133 *bus;
	struct device_driver___133 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___133 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___55 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___133 *class;
	const struct attribute_group___125 **groups;
	void (*release)(struct device___133 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___133 *device_rh;
};

struct dev_pm_info_rh___133 {
	void (*set_latency_tolerance)(struct device___133 *, s32);
};

struct dev_pm_domain___133 {
	struct dev_pm_ops___133 ops;
};

struct smp_ops___170 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___170 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___23;

typedef void bio_end_io_t___23(struct bio___23 *, int);

struct bio_vec___23 {
	struct page___167 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___110;

struct bio_integrity_payload___23;

struct bio_set___23;

struct bio___23 {
	sector_t bi_sector;
	struct bio___23 *bi_next;
	struct block_device___168 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___23 *bi_end_io;
	void *bi_private;
	struct io_context___22 *bi_ioc;
	struct cgroup_subsys_state___110 *bi_css;
	struct bio_integrity_payload___23 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___23 *bi_io_vec;
	struct bio_set___23 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___23 bi_inline_vecs[0];
};

struct hd_struct___23;

struct gendisk___23;

struct request_queue___22;

struct block_device___168 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___168 *bd_inode;
	struct super_block___168 *bd_super;
	struct mutex___171 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___168 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___23 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___23 *bd_disk;
	struct request_queue___22 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___171 bd_fsfreeze_mutex;
};

struct io_cq___22;

struct io_context___22 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___22 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___110;

struct cgroup_subsys_state___110 {
	struct cgroup___110 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___23 {
	struct bio___23 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___23 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___23 *bip_vec;
	struct bio_vec___23 bip_inline_vecs[0];
};

struct bio_list___22 {
	struct bio___23 *head;
	struct bio___23 *tail;
};

struct bio_set___23 {
	struct kmem_cache___154 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___22 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___168 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___168 *ia_file;
};

struct file___168 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___168 f_path;
	struct inode___168 *f_inode;
	const struct file_operations___168 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___168 *f_mapping;
	struct mutex___171 f_pos_lock;
};

struct zone___170;

struct lruvec___170 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___170 *zone;
};

struct pglist_data___170;

struct zone___170 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___170 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___170 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___170 {
	struct zone___170 *zone;
	int zone_idx;
};

struct zonelist___170 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___170 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___170 {
	struct zone___170 node_zones[4];
	struct zonelist___170 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___170 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___168 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___171 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___168 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___168 {
	int qf_fmt_id;
	const struct quota_format_ops___168 *qf_ops;
	struct module___87 *qf_owner;
	struct quota_format_type___168 *qf_next;
};

struct quota_format_ops___168 {
	int (*check_quota_file)(struct super_block___168 *, int);
	int (*read_file_info)(struct super_block___168 *, int);
	int (*write_file_info)(struct super_block___168 *, int);
	int (*free_file_info)(struct super_block___168 *, int);
	int (*read_dqblk)(struct dquot___168 *);
	int (*commit_dqblk)(struct dquot___168 *);
	int (*release_dqblk)(struct dquot___168 *);
};

struct dquot_operations___168 {
	int (*write_dquot)(struct dquot___168 *);
	struct dquot___168 * (*alloc_dquot)(struct super_block___168 *, int);
	void (*destroy_dquot)(struct dquot___168 *);
	int (*acquire_dquot)(struct dquot___168 *);
	int (*release_dquot)(struct dquot___168 *);
	int (*mark_dirty)(struct dquot___168 *);
	int (*write_info)(struct super_block___168 *, int);
	qsize_t * (*get_reserved_space)(struct inode___168 *);
};

struct quotactl_ops___168 {
	int (*quota_on)(struct super_block___168 *, int, int, struct path___168 *);
	int (*quota_on_meta)(struct super_block___168 *, int, int);
	int (*quota_off)(struct super_block___168 *, int);
	int (*quota_sync)(struct super_block___168 *, int);
	int (*get_info)(struct super_block___168 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___168 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___168 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___168 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___168 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___168 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___168 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___168 *, unsigned int);
};

struct address_space_operations___168 {
	int (*writepage)(struct page___167 *, struct writeback_control *);
	int (*readpage)(struct file___168 *, struct page___167 *);
	int (*writepages)(struct address_space___168 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___167 *);
	int (*readpages)(struct file___168 *, struct address_space___168 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___168 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___167 **, void **);
	int (*write_end)(struct file___168 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___167 *, void *);
	sector_t (*bmap)(struct address_space___168 *, sector_t);
	void (*invalidatepage)(struct page___167 *, long unsigned int);
	int (*releasepage)(struct page___167 *, gfp_t);
	void (*freepage)(struct page___167 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___168 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___168 *, struct page___167 *, struct page___167 *, enum migrate_mode);
	int (*launder_page)(struct page___167 *);
	int (*is_partially_uptodate)(struct page___167 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___167 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___168 *, struct page___167 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___168 *, sector_t *);
	void (*swap_deactivate)(struct file___168 *);
	void (*invalidatepage_range)(struct page___167 *, unsigned int, unsigned int);
};

struct bdi_writeback___32 {
	struct backing_dev_info___32 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___32 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___32 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___133 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___168 *debug_dir;
	struct dentry___168 *debug_stats;
};

struct hd_struct___23 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___133 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___23;

struct block_device_operations___22;

struct gendisk___23 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___23 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___23 *part_tbl;
	struct hd_struct___23 part0;
	const struct block_device_operations___22 *fops;
	struct request_queue___22 *queue;
	void *private_data;
	int flags;
	struct device___133 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct blkcg_gq___2;

struct request_list___22 {
	struct request_queue___22 *q;
	struct blkcg_gq___2 *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___22(struct request_queue___22 *);

typedef void make_request_fn___22(struct request_queue___22 *, struct bio___23 *);

struct request___22;

typedef int prep_rq_fn___22(struct request_queue___22 *, struct request___22 *);

struct bvec_merge_data___22;

typedef int merge_bvec_fn___22(struct request_queue___22 *, struct bvec_merge_data___22 *, struct bio_vec___23 *);

typedef void softirq_done_fn___22(struct request___22 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___22(struct request___22 *);

typedef int dma_drain_needed_fn___22(struct request___22 *);

typedef int lld_busy_fn___22(struct request_queue___22 *);

struct bsg_class_device___22 {
	struct device___133 *class_dev;
	struct device___133 *parent;
	int minor;
	struct request_queue___22 *queue;
	struct kref ref;
	void (*release)(struct device___133 *);
};

typedef void unprep_rq_fn___22(struct request_queue___22 *, struct request___22 *);

struct elevator_queue___22;

struct blk_queue_tag___22;

struct blk_trace___4;

struct blk_mq_tag_set___2;

struct blk_flush_queue___2;

struct request_queue___22 {
	struct list_head queue_head;
	struct request___22 *last_merge;
	struct elevator_queue___22 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___22 root_rl;
	request_fn_proc___22 *request_fn;
	make_request_fn___22 *make_request_fn;
	prep_rq_fn___22 *prep_rq_fn;
	merge_bvec_fn___22 *merge_bvec_fn;
	softirq_done_fn___22 *softirq_done_fn;
	rq_timed_out_fn___22 *rq_timed_out_fn;
	dma_drain_needed_fn___22 *dma_drain_needed;
	lld_busy_fn___22 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___22 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___32 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___133 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___22 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___2 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___4 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___22 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___171 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___22 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___22 *unprep_rq_fn;
	struct blk_mq_tag_set___2 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___23 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___2 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___168 {
	struct dentry___168 * (*lookup)(struct inode___168 *, struct dentry___168 *, unsigned int);
	void * (*follow_link)(struct dentry___168 *, struct nameidata *);
	int (*permission)(struct inode___168 *, int);
	struct posix_acl * (*get_acl)(struct inode___168 *, int);
	int (*readlink)(struct dentry___168 *, char *, int);
	void (*put_link)(struct dentry___168 *, struct nameidata *, void *);
	int (*create)(struct inode___168 *, struct dentry___168 *, umode_t, bool);
	int (*link)(struct dentry___168 *, struct inode___168 *, struct dentry___168 *);
	int (*unlink)(struct inode___168 *, struct dentry___168 *);
	int (*symlink)(struct inode___168 *, struct dentry___168 *, const char *);
	int (*mkdir)(struct inode___168 *, struct dentry___168 *, umode_t);
	int (*rmdir)(struct inode___168 *, struct dentry___168 *);
	int (*mknod)(struct inode___168 *, struct dentry___168 *, umode_t, dev_t);
	int (*rename)(struct inode___168 *, struct dentry___168 *, struct inode___168 *, struct dentry___168 *);
	int (*setattr)(struct dentry___168 *, struct iattr___168 *);
	int (*getattr)(struct vfsmount *, struct dentry___168 *, struct kstat *);
	int (*setxattr)(struct dentry___168 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___168 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___168 *, char *, size_t);
	int (*removexattr)(struct dentry___168 *, const char *);
	int (*fiemap)(struct inode___168 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___168 *, struct timespec *, int);
	int (*atomic_open)(struct inode___168 *, struct dentry___168 *, struct file___168 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___100;

struct seq_file___124;

struct file_operations___168 {
	struct module___87 *owner;
	loff_t (*llseek)(struct file___168 *, loff_t, int);
	ssize_t (*read)(struct file___168 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___168 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___168 *, void *, filldir_t);
	unsigned int (*poll)(struct file___168 *, struct poll_table_struct___100 *);
	long int (*unlocked_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___168 *, struct vm_area_struct___175 *);
	int (*open)(struct inode___168 *, struct file___168 *);
	int (*flush)(struct file___168 *, fl_owner_t);
	int (*release)(struct inode___168 *, struct file___168 *);
	int (*fsync)(struct file___168 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___168 *, int);
	int (*lock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*sendpage)(struct file___168 *, struct page___167 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___168 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___168 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___168 *, long int, struct file_lock___168 **, void **);
		struct {
			int (*setlease)(struct file___168 *, long int, struct file_lock___168 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___168 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___124 *, struct file___168 *);
};

struct fasync_struct___168;

struct file_lock_operations___168;

struct lock_manager_operations___168;

struct file_lock___168 {
	struct file_lock___168 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___84 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___168 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___168 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___168 *fl_ops;
	const struct lock_manager_operations___168 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___168 {
	void (*fl_copy_lock)(struct file_lock___168 *, struct file_lock___168 *);
	void (*fl_release_private)(struct file_lock___168 *);
};

struct lock_manager_operations___168 {
	int (*lm_compare_owner)(struct file_lock___168 *, struct file_lock___168 *);
	long unsigned int (*lm_owner_key)(struct file_lock___168 *);
	void (*lm_notify)(struct file_lock___168 *);
	int (*lm_grant)(struct file_lock___168 *, struct file_lock___168 *, int);
	void (*lm_break)(struct file_lock___168 *);
	int (*lm_change)(struct file_lock___168 **, int);
};

struct fasync_struct___168 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___168 *fa_next;
	struct file___168 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___168 {
	const char *name;
	int fs_flags;
	struct dentry___168 * (*mount)(struct file_system_type___168 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___168 *);
	struct module___87 *owner;
	struct file_system_type___168 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___168 {
	struct inode___168 * (*alloc_inode)(struct super_block___168 *);
	void (*destroy_inode)(struct inode___168 *);
	void (*dirty_inode)(struct inode___168 *, int);
	int (*write_inode)(struct inode___168 *, struct writeback_control *);
	int (*drop_inode)(struct inode___168 *);
	void (*evict_inode)(struct inode___168 *);
	void (*put_super)(struct super_block___168 *);
	int (*sync_fs)(struct super_block___168 *, int);
	int (*freeze_fs)(struct super_block___168 *);
	int (*unfreeze_fs)(struct super_block___168 *);
	int (*statfs)(struct dentry___168 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___168 *, int *, char *);
	void (*umount_begin)(struct super_block___168 *);
	int (*show_options)(struct seq_file___124 *, struct dentry___168 *);
	int (*show_devname)(struct seq_file___124 *, struct dentry___168 *);
	int (*show_path)(struct seq_file___124 *, struct dentry___168 *);
	int (*show_stats)(struct seq_file___124 *, struct dentry___168 *);
	ssize_t (*quota_read)(struct super_block___168 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___168 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___168 *);
	int (*bdev_try_to_free_page)(struct super_block___168 *, struct page___167 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___168 *);
	void (*free_cached_objects)(struct super_block___168 *, int);
};

struct xattr_handler___111 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___168 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___168 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___168 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___102)(struct file___168 *, wait_queue_head_t *, struct poll_table_struct___100 *);

struct poll_table_struct___100 {
	poll_queue_proc___102 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___148;

struct vm_area_struct___175 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___175 *vm_next;
	struct vm_area_struct___175 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___175 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___148 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___168 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___124;

struct seq_file___124 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___171 lock;
	const struct seq_operations___124 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___167 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___167 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___153;

struct memcg_cache_params___154;

struct kmem_cache___154 {
	struct kmem_cache_cpu___153 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___154 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___145;

struct vm_operations_struct___148 {
	void (*open)(struct vm_area_struct___175 *);
	void (*close)(struct vm_area_struct___175 *);
	int (*fault)(struct vm_area_struct___175 *, struct vm_fault___145 *);
	int (*page_mkwrite)(struct vm_area_struct___175 *, struct vm_fault___145 *);
	int (*access)(struct vm_area_struct___175 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___175 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___175 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___175 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___175 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___170 {
	struct task_struct___170 *task;
	struct core_thread___170 *next;
};

struct core_state___170 {
	atomic_t nr_threads;
	struct core_thread___170 dumper;
	struct completion startup;
};

struct signal_struct___170 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___170 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___170 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___84 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___171 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___110 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___110 *subsys[11];
	struct callback_head callback_head;
};

struct bin_attribute___127;

struct attribute_group___125 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___127 **bin_attrs;
};

struct bin_attribute___127 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___168 *, struct kobject___19 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___168 *, struct kobject___19 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	int (*mmap)(struct file___168 *, struct kobject___19 *, struct bin_attribute___127 *, struct vm_area_struct___175 *);
};

struct kmem_cache_cpu___153 {
	void **freelist;
	long unsigned int tid;
	struct page___167 *page;
	struct page___167 *partial;
};

struct memcg_cache_params___154 {
	bool is_root_cache;
	union {
		struct kmem_cache___154 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___154 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___133 *, char *);
	ssize_t (*store)(struct bus_type___133 *, const char *, size_t);
};

struct device_attribute___133;

struct driver_attribute___133;

struct bus_type___133 {
	const char *name;
	const char *dev_name;
	struct device___133 *dev_root;
	struct bus_attribute___133 *bus_attrs;
	struct device_attribute___133 *dev_attrs;
	struct driver_attribute___133 *drv_attrs;
	const struct attribute_group___125 **bus_groups;
	const struct attribute_group___125 **dev_groups;
	const struct attribute_group___125 **drv_groups;
	int (*match)(struct device___133 *, struct device_driver___133 *);
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	int (*probe)(struct device___133 *);
	int (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*online)(struct device___133 *);
	int (*offline)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct device___133 *, struct device_attribute___133 *, char *);
	ssize_t (*store)(struct device___133 *, struct device_attribute___133 *, const char *, size_t);
};

struct driver_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___133 *, char *);
	ssize_t (*store)(struct device_driver___133 *, const char *, size_t);
};

struct device_driver___133 {
	const char *name;
	struct bus_type___133 *bus;
	struct module___87 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___133 *);
	int (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	const struct attribute_group___125 **groups;
	const struct dev_pm_ops___133 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___133 {
	const char *name;
	const struct attribute_group___125 **groups;
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
};

struct class_attribute___133;

struct class___133 {
	const char *name;
	struct module___87 *owner;
	struct class_attribute___133 *class_attrs;
	struct device_attribute___133 *dev_attrs;
	const struct attribute_group___125 **dev_groups;
	struct bin_attribute___127 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *);
	void (*class_release)(struct class___133 *);
	void (*dev_release)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
	struct subsys_private *p;
};

struct class_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct class___133 *, struct class_attribute___133 *, char *);
	ssize_t (*store)(struct class___133 *, struct class_attribute___133 *, const char *, size_t);
	const void * (*namespace)(struct class___133 *, const struct class_attribute___133 *);
};

struct device_rh___133 {
	struct dev_pm_info_rh___133 power;
};

struct disk_part_tbl___23 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___23 *last_lookup;
	struct hd_struct___23 *part[0];
};

struct block_device_operations___22 {
	int (*open)(struct block_device___168 *, fmode_t);
	void (*release)(struct gendisk___23 *, fmode_t);
	int (*ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___168 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___23 *, unsigned int);
	int (*media_changed)(struct gendisk___23 *);
	void (*unlock_native_capacity)(struct gendisk___23 *);
	int (*revalidate_disk)(struct gendisk___23 *);
	int (*getgeo)(struct block_device___168 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___168 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___87 *owner;
};

struct vm_fault___145 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___167 *page;
};

struct irq_chip___119 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___119 *);
	void (*irq_shutdown)(struct irq_data___119 *);
	void (*irq_enable)(struct irq_data___119 *);
	void (*irq_disable)(struct irq_data___119 *);
	void (*irq_ack)(struct irq_data___119 *);
	void (*irq_mask)(struct irq_data___119 *);
	void (*irq_mask_ack)(struct irq_data___119 *);
	void (*irq_unmask)(struct irq_data___119 *);
	void (*irq_eoi)(struct irq_data___119 *);
	int (*irq_set_affinity)(struct irq_data___119 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___119 *);
	int (*irq_set_type)(struct irq_data___119 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___119 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___119 *);
	void (*irq_bus_sync_unlock)(struct irq_data___119 *);
	void (*irq_cpu_online)(struct irq_data___119 *);
	void (*irq_cpu_offline)(struct irq_data___119 *);
	void (*irq_suspend)(struct irq_data___119 *);
	void (*irq_resume)(struct irq_data___119 *);
	void (*irq_pm_shutdown)(struct irq_data___119 *);
	void (*irq_print_chip)(struct irq_data___119 *, struct seq_file___124 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___119 *, void *);
	long unsigned int flags;
};

struct io_cq___22 {
	struct request_queue___22 *q;
	struct io_context___22 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___154 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___22(struct request___22 *, int);

struct request___22 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___22 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___23 *bio;
	struct bio___23 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___22 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___22 *saved_end_io;
		} flush;
	};
	struct gendisk___23 *rq_disk;
	struct hd_struct___23 *part;
	long unsigned int start_time;
	struct request_list___22 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___22 *end_io;
	void *end_io_data;
	struct request___22 *next_rq;
};

struct blkcg;

struct blkg_policy_data;

struct blkcg_gq___2 {
	struct request_queue___22 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg *blkcg;
	struct blkcg_gq___2 *parent;
	struct request_list___22 rl;
	union {
		atomic_t refcnt;
		struct {
			int refcnt;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	bool online;
	struct blkg_policy_data *pd[2];
	struct callback_head callback_head;
};

struct blk_mq_ctx {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___22 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___22(struct request_queue___22 *, struct request___22 **, struct bio___23 *);

typedef void elevator_merge_req_fn___22(struct request_queue___22 *, struct request___22 *, struct request___22 *);

typedef void elevator_merged_fn___22(struct request_queue___22 *, struct request___22 *, int);

typedef int elevator_allow_merge_fn___22(struct request_queue___22 *, struct request___22 *, struct bio___23 *);

typedef void elevator_bio_merged_fn___22(struct request_queue___22 *, struct request___22 *, struct bio___23 *);

typedef int elevator_dispatch_fn___22(struct request_queue___22 *, int);

typedef void elevator_add_req_fn___22(struct request_queue___22 *, struct request___22 *);

typedef struct request___22 *elevator_request_list_fn___22(struct request_queue___22 *, struct request___22 *);

typedef void elevator_completed_req_fn___22(struct request_queue___22 *, struct request___22 *);

typedef int elevator_may_queue_fn___22(struct request_queue___22 *, int);

typedef void elevator_init_icq_fn___22(struct io_cq___22 *);

typedef void elevator_exit_icq_fn___22(struct io_cq___22 *);

typedef int elevator_set_req_fn___22(struct request_queue___22 *, struct request___22 *, struct bio___23 *, gfp_t);

typedef void elevator_put_req_fn___22(struct request___22 *);

typedef void elevator_activate_req_fn___22(struct request_queue___22 *, struct request___22 *);

typedef void elevator_deactivate_req_fn___22(struct request_queue___22 *, struct request___22 *);

struct elevator_type___22;

typedef int elevator_init_fn___22(struct request_queue___22 *, struct elevator_type___22 *);

typedef void elevator_exit_fn___22(struct elevator_queue___22 *);

struct elevator_ops___22 {
	elevator_merge_fn___22 *elevator_merge_fn;
	elevator_merged_fn___22 *elevator_merged_fn;
	elevator_merge_req_fn___22 *elevator_merge_req_fn;
	elevator_allow_merge_fn___22 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___22 *elevator_bio_merged_fn;
	elevator_dispatch_fn___22 *elevator_dispatch_fn;
	elevator_add_req_fn___22 *elevator_add_req_fn;
	elevator_activate_req_fn___22 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___22 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___22 *elevator_completed_req_fn;
	elevator_request_list_fn___22 *elevator_former_req_fn;
	elevator_request_list_fn___22 *elevator_latter_req_fn;
	elevator_init_icq_fn___22 *elevator_init_icq_fn;
	elevator_exit_icq_fn___22 *elevator_exit_icq_fn;
	elevator_set_req_fn___22 *elevator_set_req_fn;
	elevator_put_req_fn___22 *elevator_put_req_fn;
	elevator_may_queue_fn___22 *elevator_may_queue_fn;
	elevator_init_fn___22 *elevator_init_fn;
	elevator_exit_fn___22 *elevator_exit_fn;
};

struct elv_fs_entry___22;

struct elevator_type___22 {
	struct kmem_cache___154 *icq_cache;
	struct elevator_ops___22 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___22 *elevator_attrs;
	char elevator_name[16];
	struct module___87 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___22 {
	struct elevator_type___22 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___171 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___22 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___22 *, char *);
	ssize_t (*store)(struct elevator_queue___22 *, const char *, size_t);
};

enum {
	ELV_MQUEUE_MAY = 0,
	ELV_MQUEUE_NO = 1,
	ELV_MQUEUE_MUST = 2,
};

struct bvec_merge_data___22 {
	struct block_device___168 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___22 {
	struct request___22 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data;

typedef int queue_rq_fn(struct blk_mq_hw_ctx *, const struct blk_mq_queue_data *);

typedef struct blk_mq_hw_ctx *map_queue_fn(struct request_queue___22 *, const int);

typedef enum blk_eh_timer_return timeout_fn(struct request___22 *, bool);

typedef int init_request_fn(void *, struct request___22 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn(void *, struct request___22 *, unsigned int, unsigned int);

typedef int init_hctx_fn(struct blk_mq_hw_ctx *, void *, unsigned int);

typedef void exit_hctx_fn(struct blk_mq_hw_ctx *, unsigned int);

struct blk_mq_ops {
	queue_rq_fn *queue_rq;
	map_queue_fn *map_queue;
	union {
		timeout_fn *timeout;
		struct {
			rq_timed_out_fn___22 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___22 *complete;
	init_request_fn *init_request;
	exit_request_fn *exit_request;
	init_hctx_fn *init_hctx;
	exit_hctx_fn *exit_hctx;
};

struct blk_mq_cpu_notifier {
	struct list_head list;
	void *data;
	union {
		int (*notify)(void *, long unsigned int, unsigned int);
		struct {
			void (*notify)(void *, long unsigned int, unsigned int);
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
};

struct blk_align_bitmap;

struct blk_mq_ctxmap {
	unsigned int map_size;
	unsigned int bits_per_word;
	struct blk_align_bitmap *map;
};

struct blk_mq_tags;

struct blk_mq_hw_ctx {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___22 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___22 **padding2;
		struct {
			struct request___22 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___2 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan___5;

struct blk_trace___4 {
	int trace_state;
	struct rchan___5 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___168 *dir;
	struct dentry___168 *dropped_file;
	struct dentry___168 *msg_file;
	atomic_t dropped;
};

struct blk_mq_tag_set___2 {
	struct blk_mq_ops *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___171 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___2 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___22 *flush_rq;
	struct request___22 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct module_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___86 *, struct module_kobject___86 *, char *);
	ssize_t (*store)(struct module_attribute___86 *, struct module_kobject___86 *, const char *, size_t);
	void (*setup)(struct module___87 *, const char *);
	int (*test)(struct module___87 *);
	void (*free)(struct module___87 *);
};

struct rchan_buf___5 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___5 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___168 *dentry;
	struct kref kref;
	struct page___167 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___5;

struct rchan___5 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___5 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___5 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___168 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___5 {
	int (*subbuf_start)(struct rchan_buf___5 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___5 *, struct file___168 *);
	void (*buf_unmapped)(struct rchan_buf___5 *, struct file___168 *);
	struct dentry___168 * (*create_buf_file)(const char *, struct dentry___168 *, umode_t, struct rchan_buf___5 *, int *);
	int (*remove_buf_file)(struct dentry___168 *);
};

struct blk_align_bitmap {
	long unsigned int word;
	long unsigned int depth;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_queue_data {
	struct request___22 *rq;
	struct list_head *list;
	bool last;
};

struct cgroupfs_root___110;

struct cgroup___110 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___110 *parent;
	struct dentry___168 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___110 *subsys[11];
	struct cgroupfs_root___110 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___171 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___110 {
	struct super_block___168 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___110 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct seq_operations___124 {
	void * (*start)(struct seq_file___124 *, loff_t *);
	void (*stop)(struct seq_file___124 *, void *);
	void * (*next)(struct seq_file___124 *, void *, loff_t *);
	int (*show)(struct seq_file___124 *, void *);
};

enum blkg_rwstat_type {
	BLKG_RWSTAT_READ = 0,
	BLKG_RWSTAT_WRITE = 1,
	BLKG_RWSTAT_SYNC = 2,
	BLKG_RWSTAT_ASYNC = 3,
	BLKG_RWSTAT_NR = 4,
	BLKG_RWSTAT_TOTAL = 4,
};

struct blkcg {
	struct cgroup_subsys_state___110 css;
	spinlock_t lock;
	struct radix_tree_root blkg_tree;
	struct blkcg_gq___2 *blkg_hint;
	struct hlist_head blkg_list;
	uint64_t id;
	unsigned int cfq_weight;
	unsigned int cfq_leaf_weight;
};

struct blkg_policy_data {
	struct blkcg_gq___2 *blkg;
	int plid;
	struct list_head alloc_node;
};

struct page___168;

typedef struct page___168 *pgtable_t___168;

struct address_space___169;

struct kmem_cache___155;

struct page___168 {
	long unsigned int flags;
	struct address_space___169 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___168 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___168 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___155 *slab_cache;
		struct page___168 *first_page;
	};
	long: 64;
};

struct thread_struct___76;

struct task_struct___171;

struct pv_cpu_ops___171 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___76 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___76 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___171 *);
	void (*end_context_switch)(struct task_struct___171 *);
};

struct perf_event___76;

struct thread_struct___76 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___76 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___85;

struct pid_link___85 {
	struct hlist_node node;
	struct pid___85 *pid;
};

struct mutex___172 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___171 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___164 {
	struct page___168 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___176;

struct nsproxy___102;

struct signal_struct___171;

struct bio_list___23;

struct backing_dev_info___33;

struct io_context___23;

struct css_set___111;

struct perf_event_context___76;

struct task_struct___171 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___171 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___176 *mm;
	struct mm_struct___176 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___171 *real_parent;
	struct task_struct___171 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___171 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___85 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___171 = 0,
		VTIME_USER___171 = 1,
		VTIME_SYS___171 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___76 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___102 *nsproxy;
	struct signal_struct___171 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___23 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___33 *backing_dev_info;
	struct io_context___23 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___111 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___76 *perf_event_ctxp[2];
	struct mutex___172 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___164 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___176 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___176 *, struct mm_struct___176 *);
	void (*dup_mmap)(struct mm_struct___176 *, struct mm_struct___176 *);
	void (*exit_mmap)(struct mm_struct___176 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___176 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___176 *);
	void (*pgd_free)(struct mm_struct___176 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___176 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___176 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___176 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___176 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___176 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___176 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___176 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___176 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___176 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___176 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___176 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___172 lock;
	void *vdso;
} mm_context_t___172;

struct xol_area___168;

struct uprobes_state___168 {
	struct xol_area___168 *xol_area;
};

struct vm_area_struct___176;

struct file___169;

struct core_state___171;

struct mm_struct___176 {
	struct vm_area_struct___176 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___176 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___176 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___172 context;
	long unsigned int flags;
	struct core_state___171 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___171 *owner;
	struct file___169 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___168 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___88;

struct exec_domain___41 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___88 *module;
	struct exec_domain___41 *next;
};

struct module_kobject___87 {
	struct kobject___19 kobj;
	struct module___88 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___87;

struct ftrace_event_call___66;

struct module___88 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___87 mkobj;
	struct module_attribute___87 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___66 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___171 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___76 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___171 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___171 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___171 *target;
};

struct perf_sample_data___7;

typedef void (*perf_overflow_handler_t___76)(struct perf_event___76 *, struct perf_sample_data___7 *, struct pt_regs *);

struct ftrace_ops___76;

typedef void (*ftrace_func_t___76)(long unsigned int, long unsigned int, struct ftrace_ops___76 *, struct pt_regs *);

struct ftrace_ops___76 {
	ftrace_func_t___76 func;
	struct ftrace_ops___76 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___172 regex_lock;
};

struct pmu___76;

struct fasync_struct___169;

struct pid_namespace___85;

struct perf_cgroup___76;

struct perf_event___76 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___76 *group_leader;
	struct pmu___76 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___76 hw;
	struct perf_event_context___76 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___172 child_mutex;
	struct list_head child_list;
	struct perf_event___76 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___171 *owner;
	struct mutex___172 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___169 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___76 *);
	struct callback_head callback_head;
	struct pid_namespace___85 *ns;
	u64 id;
	perf_overflow_handler_t___76 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___66 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___76 ftrace_ops;
	struct perf_cgroup___76 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___79 {
	struct task_struct___171 *task;
	struct exec_domain___41 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___171;

struct lruvec___171 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___171 *zone;
};

struct pglist_data___171;

struct zone___171 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___171 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___171 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___171 {
	struct zone___171 *zone;
	int zone_idx;
};

struct zonelist___171 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___171 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___171 {
	struct zone___171 node_zones[4];
	struct zonelist___171 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___171 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___120;

struct x86_io_apic_ops___120 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___120 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___120;

struct irq_data___120 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___120 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___134;

struct dev_pm_ops___134 {
	int (*prepare)(struct device___134 *);
	void (*complete)(struct device___134 *);
	int (*suspend)(struct device___134 *);
	int (*resume)(struct device___134 *);
	int (*freeze)(struct device___134 *);
	int (*thaw)(struct device___134 *);
	int (*poweroff)(struct device___134 *);
	int (*restore)(struct device___134 *);
	int (*suspend_late)(struct device___134 *);
	int (*resume_early)(struct device___134 *);
	int (*freeze_late)(struct device___134 *);
	int (*thaw_early)(struct device___134 *);
	int (*poweroff_late)(struct device___134 *);
	int (*restore_early)(struct device___134 *);
	int (*suspend_noirq)(struct device___134 *);
	int (*resume_noirq)(struct device___134 *);
	int (*freeze_noirq)(struct device___134 *);
	int (*thaw_noirq)(struct device___134 *);
	int (*poweroff_noirq)(struct device___134 *);
	int (*restore_noirq)(struct device___134 *);
	int (*runtime_suspend)(struct device___134 *);
	int (*runtime_resume)(struct device___134 *);
	int (*runtime_idle)(struct device___134 *);
};

struct device_type___134;

struct bus_type___134;

struct device_driver___134;

struct dev_pm_domain___134;

struct class___134;

struct attribute_group___126;

struct device_rh___134;

struct device___134 {
	struct device___134 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___134 *type;
	struct mutex___172 mutex;
	struct bus_type___134 *bus;
	struct device_driver___134 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___134 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___55 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___134 *class;
	const struct attribute_group___126 **groups;
	void (*release)(struct device___134 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___134 *device_rh;
};

struct dev_pm_info_rh___134 {
	void (*set_latency_tolerance)(struct device___134 *, s32);
};

struct dev_pm_domain___134 {
	struct dev_pm_ops___134 ops;
};

struct smp_ops___171 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___171 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___102 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___85 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___128;

struct attribute_group___126 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___128 **bin_attrs;
};

struct bin_attribute___128 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___169 *, struct kobject___19 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___169 *, struct kobject___19 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	int (*mmap)(struct file___169 *, struct kobject___19 *, struct bin_attribute___128 *, struct vm_area_struct___176 *);
};

struct dentry___169;

struct path___169 {
	struct vfsmount *mnt;
	struct dentry___169 *dentry;
};

struct fown_struct___85 {
	rwlock_t lock;
	struct pid___85 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___169;

struct file_operations___169;

struct file___169 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___169 f_path;
	struct inode___169 *f_inode;
	const struct file_operations___169 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___169 *f_mapping;
	struct mutex___172 f_pos_lock;
};

struct vm_operations_struct___149;

struct vm_area_struct___176 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___176 *vm_next;
	struct vm_area_struct___176 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___176 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___149 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___169 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___87 *, struct module_kobject___87 *, char *);
	ssize_t (*store)(struct module_attribute___87 *, struct module_kobject___87 *, const char *, size_t);
	void (*setup)(struct module___88 *, const char *);
	int (*test)(struct module___88 *);
	void (*free)(struct module___88 *);
};

struct trace_event_functions___66;

struct trace_event___66 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___66 *funcs;
};

struct ftrace_event_class___66;

struct ftrace_event_call___66 {
	struct list_head list;
	struct ftrace_event_class___66 *class;
	char *name;
	struct trace_event___66 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct dentry_operations___169;

struct super_block___169;

struct dentry___169 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___169 *d_parent;
	struct qstr d_name;
	struct inode___169 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___169 *d_op;
	struct super_block___169 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___169;

struct address_space___169 {
	struct inode___169 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___172 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___169 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___33 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___169;

struct file_lock___169;

struct dquot___169;

struct block_device___169;

struct inode___169 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___169 *i_op;
	struct super_block___169 *i_sb;
	struct address_space___169 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___172 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___169 *i_fop;
	struct file_lock___169 *i_flock;
	struct address_space___169 i_data;
	struct dquot___169 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___169 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___169 {
	int (*d_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_hash)(const struct dentry___169 *, struct qstr *);
	int (*d_compare)(const struct dentry___169 *, const struct dentry___169 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___169 *);
	void (*d_release)(struct dentry___169 *);
	void (*d_prune)(struct dentry___169 *);
	void (*d_iput)(struct dentry___169 *, struct inode___169 *);
	char * (*d_dname)(struct dentry___169 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___169 *);
	int (*d_manage)(struct dentry___169 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___169;

struct mem_dqinfo___169 {
	struct quota_format_type___169 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___169;

struct quota_info___169 {
	unsigned int flags;
	struct mutex___172 dqio_mutex;
	struct mutex___172 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___169 *files[2];
	struct mem_dqinfo___169 info[2];
	const struct quota_format_ops___169 *ops[2];
};

struct file_system_type___169;

struct super_operations___169;

struct dquot_operations___169;

struct quotactl_ops___169;

struct xattr_handler___112;

struct super_block___169 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___169 *s_type;
	const struct super_operations___169 *s_op;
	const struct dquot_operations___169 *dq_op;
	const struct quotactl_ops___169 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___169 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___112 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___169 *s_bdev;
	struct backing_dev_info___33 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___169 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___172 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___169 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___85 {
	int nr;
	struct pid_namespace___85 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___85 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___171 *child_reaper;
	struct kmem_cache___155 *pid_cachep;
	unsigned int level;
	struct pid_namespace___85 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___169 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___85 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___85 numbers[1];
};

struct bio___24;

typedef void bio_end_io_t___24(struct bio___24 *, int);

struct bio_vec___24 {
	struct page___168 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___111;

struct bio_integrity_payload___24;

struct bio_set___24;

struct bio___24 {
	sector_t bi_sector;
	struct bio___24 *bi_next;
	struct block_device___169 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___24 *bi_end_io;
	void *bi_private;
	struct io_context___23 *bi_ioc;
	struct cgroup_subsys_state___111 *bi_css;
	struct bio_integrity_payload___24 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___24 *bi_io_vec;
	struct bio_set___24 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___24 bi_inline_vecs[0];
};

struct hd_struct___24;

struct gendisk___24;

struct request_queue___23;

struct block_device___169 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___169 *bd_inode;
	struct super_block___169 *bd_super;
	struct mutex___172 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___169 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___24 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___24 *bd_disk;
	struct request_queue___23 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___172 bd_fsfreeze_mutex;
};

struct io_cq___23;

struct io_context___23 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___23 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___111;

struct cgroup_subsys_state___111 {
	struct cgroup___111 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___24 {
	struct bio___24 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___24 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___24 *bip_vec;
	struct bio_vec___24 bip_inline_vecs[0];
};

struct bio_list___23 {
	struct bio___24 *head;
	struct bio___24 *tail;
};

struct bio_set___24 {
	struct kmem_cache___155 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___23 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct buffer_head___6;

typedef void bh_end_io_t___5(struct buffer_head___6 *, int);

struct buffer_head___6 {
	long unsigned int b_state;
	struct buffer_head___6 *b_this_page;
	struct page___168 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___169 *b_bdev;
	bh_end_io_t___5 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___169 *b_assoc_map;
	atomic_t b_count;
};

struct iattr___169 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___169 *ia_file;
};

struct dquot___169 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___172 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___169 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___169 {
	int qf_fmt_id;
	const struct quota_format_ops___169 *qf_ops;
	struct module___88 *qf_owner;
	struct quota_format_type___169 *qf_next;
};

struct quota_format_ops___169 {
	int (*check_quota_file)(struct super_block___169 *, int);
	int (*read_file_info)(struct super_block___169 *, int);
	int (*write_file_info)(struct super_block___169 *, int);
	int (*free_file_info)(struct super_block___169 *, int);
	int (*read_dqblk)(struct dquot___169 *);
	int (*commit_dqblk)(struct dquot___169 *);
	int (*release_dqblk)(struct dquot___169 *);
};

struct dquot_operations___169 {
	int (*write_dquot)(struct dquot___169 *);
	struct dquot___169 * (*alloc_dquot)(struct super_block___169 *, int);
	void (*destroy_dquot)(struct dquot___169 *);
	int (*acquire_dquot)(struct dquot___169 *);
	int (*release_dquot)(struct dquot___169 *);
	int (*mark_dirty)(struct dquot___169 *);
	int (*write_info)(struct super_block___169 *, int);
	qsize_t * (*get_reserved_space)(struct inode___169 *);
};

struct quotactl_ops___169 {
	int (*quota_on)(struct super_block___169 *, int, int, struct path___169 *);
	int (*quota_on_meta)(struct super_block___169 *, int, int);
	int (*quota_off)(struct super_block___169 *, int);
	int (*quota_sync)(struct super_block___169 *, int);
	int (*get_info)(struct super_block___169 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___169 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___169 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___169 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___169 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___169 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___169 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___169 *, unsigned int);
};

struct swap_info_struct___38;

struct address_space_operations___169 {
	int (*writepage)(struct page___168 *, struct writeback_control *);
	int (*readpage)(struct file___169 *, struct page___168 *);
	int (*writepages)(struct address_space___169 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___168 *);
	int (*readpages)(struct file___169 *, struct address_space___169 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___169 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___168 **, void **);
	int (*write_end)(struct file___169 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___168 *, void *);
	sector_t (*bmap)(struct address_space___169 *, sector_t);
	void (*invalidatepage)(struct page___168 *, long unsigned int);
	int (*releasepage)(struct page___168 *, gfp_t);
	void (*freepage)(struct page___168 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___169 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___169 *, struct page___168 *, struct page___168 *, enum migrate_mode);
	int (*launder_page)(struct page___168 *);
	int (*is_partially_uptodate)(struct page___168 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___168 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___169 *, struct page___168 *);
	int (*swap_activate)(struct swap_info_struct___38 *, struct file___169 *, sector_t *);
	void (*swap_deactivate)(struct file___169 *);
	void (*invalidatepage_range)(struct page___168 *, unsigned int, unsigned int);
};

struct swap_info_struct___38 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___169 *bdev;
	struct file___169 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct bdi_writeback___33 {
	struct backing_dev_info___33 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___33 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___33 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___134 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___169 *debug_dir;
	struct dentry___169 *debug_stats;
};

struct hd_struct___24 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___134 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___24;

struct block_device_operations___23;

struct gendisk___24 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___24 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___24 *part_tbl;
	struct hd_struct___24 part0;
	const struct block_device_operations___23 *fops;
	struct request_queue___23 *queue;
	void *private_data;
	int flags;
	struct device___134 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___23 {
	struct request_queue___23 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___23(struct request_queue___23 *);

typedef void make_request_fn___23(struct request_queue___23 *, struct bio___24 *);

struct request___23;

typedef int prep_rq_fn___23(struct request_queue___23 *, struct request___23 *);

struct bvec_merge_data___23;

typedef int merge_bvec_fn___23(struct request_queue___23 *, struct bvec_merge_data___23 *, struct bio_vec___24 *);

typedef void softirq_done_fn___23(struct request___23 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___23(struct request___23 *);

typedef int dma_drain_needed_fn___23(struct request___23 *);

typedef int lld_busy_fn___23(struct request_queue___23 *);

struct bsg_class_device___23 {
	struct device___134 *class_dev;
	struct device___134 *parent;
	int minor;
	struct request_queue___23 *queue;
	struct kref ref;
	void (*release)(struct device___134 *);
};

typedef void unprep_rq_fn___23(struct request_queue___23 *, struct request___23 *);

struct elevator_queue___23;

struct blk_mq_ops___2;

struct blk_mq_ctx___2;

struct blk_mq_hw_ctx___2;

struct blk_queue_tag___23;

struct blk_trace___5;

struct request_queue___23 {
	struct list_head queue_head;
	struct request___23 *last_merge;
	struct elevator_queue___23 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___23 root_rl;
	request_fn_proc___23 *request_fn;
	make_request_fn___23 *make_request_fn;
	prep_rq_fn___23 *prep_rq_fn;
	merge_bvec_fn___23 *merge_bvec_fn;
	softirq_done_fn___23 *softirq_done_fn;
	rq_timed_out_fn___23 *rq_timed_out_fn;
	dma_drain_needed_fn___23 *dma_drain_needed;
	lld_busy_fn___23 *lld_busy_fn;
	struct blk_mq_ops___2 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___2 *queue_ctx;
		struct {
			struct blk_mq_ctx___2 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___2 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___23 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___33 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___134 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___23 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___5 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___23 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___172 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___23 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___23 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___24 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___169 {
	struct dentry___169 * (*lookup)(struct inode___169 *, struct dentry___169 *, unsigned int);
	void * (*follow_link)(struct dentry___169 *, struct nameidata *);
	int (*permission)(struct inode___169 *, int);
	struct posix_acl * (*get_acl)(struct inode___169 *, int);
	int (*readlink)(struct dentry___169 *, char *, int);
	void (*put_link)(struct dentry___169 *, struct nameidata *, void *);
	int (*create)(struct inode___169 *, struct dentry___169 *, umode_t, bool);
	int (*link)(struct dentry___169 *, struct inode___169 *, struct dentry___169 *);
	int (*unlink)(struct inode___169 *, struct dentry___169 *);
	int (*symlink)(struct inode___169 *, struct dentry___169 *, const char *);
	int (*mkdir)(struct inode___169 *, struct dentry___169 *, umode_t);
	int (*rmdir)(struct inode___169 *, struct dentry___169 *);
	int (*mknod)(struct inode___169 *, struct dentry___169 *, umode_t, dev_t);
	int (*rename)(struct inode___169 *, struct dentry___169 *, struct inode___169 *, struct dentry___169 *);
	int (*setattr)(struct dentry___169 *, struct iattr___169 *);
	int (*getattr)(struct vfsmount *, struct dentry___169 *, struct kstat *);
	int (*setxattr)(struct dentry___169 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___169 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___169 *, char *, size_t);
	int (*removexattr)(struct dentry___169 *, const char *);
	int (*fiemap)(struct inode___169 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___169 *, struct timespec *, int);
	int (*atomic_open)(struct inode___169 *, struct dentry___169 *, struct file___169 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___101;

struct seq_file___125;

struct file_operations___169 {
	struct module___88 *owner;
	loff_t (*llseek)(struct file___169 *, loff_t, int);
	ssize_t (*read)(struct file___169 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___169 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___169 *, void *, filldir_t);
	unsigned int (*poll)(struct file___169 *, struct poll_table_struct___101 *);
	long int (*unlocked_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___169 *, struct vm_area_struct___176 *);
	int (*open)(struct inode___169 *, struct file___169 *);
	int (*flush)(struct file___169 *, fl_owner_t);
	int (*release)(struct inode___169 *, struct file___169 *);
	int (*fsync)(struct file___169 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___169 *, int);
	int (*lock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*sendpage)(struct file___169 *, struct page___168 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___169 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___169 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___169 *, long int, struct file_lock___169 **, void **);
		struct {
			int (*setlease)(struct file___169 *, long int, struct file_lock___169 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___169 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___125 *, struct file___169 *);
};

struct file_lock_operations___169;

struct lock_manager_operations___169;

struct file_lock___169 {
	struct file_lock___169 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___85 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___169 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___169 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___169 *fl_ops;
	const struct lock_manager_operations___169 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___169 {
	void (*fl_copy_lock)(struct file_lock___169 *, struct file_lock___169 *);
	void (*fl_release_private)(struct file_lock___169 *);
};

struct lock_manager_operations___169 {
	int (*lm_compare_owner)(struct file_lock___169 *, struct file_lock___169 *);
	long unsigned int (*lm_owner_key)(struct file_lock___169 *);
	void (*lm_notify)(struct file_lock___169 *);
	int (*lm_grant)(struct file_lock___169 *, struct file_lock___169 *, int);
	void (*lm_break)(struct file_lock___169 *);
	int (*lm_change)(struct file_lock___169 **, int);
};

struct fasync_struct___169 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___169 *fa_next;
	struct file___169 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___169 {
	const char *name;
	int fs_flags;
	struct dentry___169 * (*mount)(struct file_system_type___169 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___169 *);
	struct module___88 *owner;
	struct file_system_type___169 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___169 {
	struct inode___169 * (*alloc_inode)(struct super_block___169 *);
	void (*destroy_inode)(struct inode___169 *);
	void (*dirty_inode)(struct inode___169 *, int);
	int (*write_inode)(struct inode___169 *, struct writeback_control *);
	int (*drop_inode)(struct inode___169 *);
	void (*evict_inode)(struct inode___169 *);
	void (*put_super)(struct super_block___169 *);
	int (*sync_fs)(struct super_block___169 *, int);
	int (*freeze_fs)(struct super_block___169 *);
	int (*unfreeze_fs)(struct super_block___169 *);
	int (*statfs)(struct dentry___169 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___169 *, int *, char *);
	void (*umount_begin)(struct super_block___169 *);
	int (*show_options)(struct seq_file___125 *, struct dentry___169 *);
	int (*show_devname)(struct seq_file___125 *, struct dentry___169 *);
	int (*show_path)(struct seq_file___125 *, struct dentry___169 *);
	int (*show_stats)(struct seq_file___125 *, struct dentry___169 *);
	ssize_t (*quota_read)(struct super_block___169 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___169 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___169 *);
	int (*bdev_try_to_free_page)(struct super_block___169 *, struct page___168 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___169 *);
	void (*free_cached_objects)(struct super_block___169 *, int);
};

struct xattr_handler___112 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___169 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___169 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___169 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___103)(struct file___169 *, wait_queue_head_t *, struct poll_table_struct___101 *);

struct poll_table_struct___101 {
	poll_queue_proc___103 _qproc;
	long unsigned int _key;
};

struct seq_operations___125;

struct seq_file___125 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___172 lock;
	const struct seq_operations___125 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___168 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___168 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___154;

struct memcg_cache_params___155;

struct kmem_cache___155 {
	struct kmem_cache_cpu___154 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___155 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___146;

struct vm_operations_struct___149 {
	void (*open)(struct vm_area_struct___176 *);
	void (*close)(struct vm_area_struct___176 *);
	int (*fault)(struct vm_area_struct___176 *, struct vm_fault___146 *);
	int (*page_mkwrite)(struct vm_area_struct___176 *, struct vm_fault___146 *);
	int (*access)(struct vm_area_struct___176 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___176 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___176 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___176 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___176 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___171 {
	struct task_struct___171 *task;
	struct core_thread___171 *next;
};

struct core_state___171 {
	atomic_t nr_threads;
	struct core_thread___171 dumper;
	struct completion startup;
};

struct signal_struct___171 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___171 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___171 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___85 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___172 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___111 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___111 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___76 {
	struct pmu___76 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___172 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___171 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___76 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___146 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___168 *page;
};

struct irq_chip___120 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___120 *);
	void (*irq_shutdown)(struct irq_data___120 *);
	void (*irq_enable)(struct irq_data___120 *);
	void (*irq_disable)(struct irq_data___120 *);
	void (*irq_ack)(struct irq_data___120 *);
	void (*irq_mask)(struct irq_data___120 *);
	void (*irq_mask_ack)(struct irq_data___120 *);
	void (*irq_unmask)(struct irq_data___120 *);
	void (*irq_eoi)(struct irq_data___120 *);
	int (*irq_set_affinity)(struct irq_data___120 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___120 *);
	int (*irq_set_type)(struct irq_data___120 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___120 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___120 *);
	void (*irq_bus_sync_unlock)(struct irq_data___120 *);
	void (*irq_cpu_online)(struct irq_data___120 *);
	void (*irq_cpu_offline)(struct irq_data___120 *);
	void (*irq_suspend)(struct irq_data___120 *);
	void (*irq_resume)(struct irq_data___120 *);
	void (*irq_pm_shutdown)(struct irq_data___120 *);
	void (*irq_print_chip)(struct irq_data___120 *, struct seq_file___125 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___120 *, void *);
	long unsigned int flags;
};

struct io_cq___23 {
	struct request_queue___23 *q;
	struct io_context___23 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___155 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kmem_cache_cpu___154 {
	void **freelist;
	long unsigned int tid;
	struct page___168 *page;
	struct page___168 *partial;
};

struct memcg_cache_params___155 {
	bool is_root_cache;
	union {
		struct kmem_cache___155 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___155 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___134 *, char *);
	ssize_t (*store)(struct bus_type___134 *, const char *, size_t);
};

struct device_attribute___134;

struct driver_attribute___134;

struct bus_type___134 {
	const char *name;
	const char *dev_name;
	struct device___134 *dev_root;
	struct bus_attribute___134 *bus_attrs;
	struct device_attribute___134 *dev_attrs;
	struct driver_attribute___134 *drv_attrs;
	const struct attribute_group___126 **bus_groups;
	const struct attribute_group___126 **dev_groups;
	const struct attribute_group___126 **drv_groups;
	int (*match)(struct device___134 *, struct device_driver___134 *);
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	int (*probe)(struct device___134 *);
	int (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*online)(struct device___134 *);
	int (*offline)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct device___134 *, struct device_attribute___134 *, char *);
	ssize_t (*store)(struct device___134 *, struct device_attribute___134 *, const char *, size_t);
};

struct driver_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___134 *, char *);
	ssize_t (*store)(struct device_driver___134 *, const char *, size_t);
};

struct device_driver___134 {
	const char *name;
	struct bus_type___134 *bus;
	struct module___88 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___134 *);
	int (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	const struct attribute_group___126 **groups;
	const struct dev_pm_ops___134 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___134 {
	const char *name;
	const struct attribute_group___126 **groups;
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
};

struct class_attribute___134;

struct class___134 {
	const char *name;
	struct module___88 *owner;
	struct class_attribute___134 *class_attrs;
	struct device_attribute___134 *dev_attrs;
	const struct attribute_group___126 **dev_groups;
	struct bin_attribute___128 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *);
	void (*class_release)(struct class___134 *);
	void (*dev_release)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
	struct subsys_private *p;
};

struct class_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct class___134 *, struct class_attribute___134 *, char *);
	ssize_t (*store)(struct class___134 *, struct class_attribute___134 *, const char *, size_t);
	const void * (*namespace)(struct class___134 *, const struct class_attribute___134 *);
};

struct device_rh___134 {
	struct dev_pm_info_rh___134 power;
};

struct disk_part_tbl___24 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___24 *last_lookup;
	struct hd_struct___24 *part[0];
};

struct block_device_operations___23 {
	int (*open)(struct block_device___169 *, fmode_t);
	void (*release)(struct gendisk___24 *, fmode_t);
	int (*ioctl)(struct block_device___169 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___169 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___169 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___24 *, unsigned int);
	int (*media_changed)(struct gendisk___24 *);
	void (*unlock_native_capacity)(struct gendisk___24 *);
	int (*revalidate_disk)(struct gendisk___24 *);
	int (*getgeo)(struct block_device___169 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___169 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___88 *owner;
};

typedef void rq_end_io_fn___23(struct request___23 *, int);

struct request___23 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___23 *q;
	struct blk_mq_ctx___2 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___24 *bio;
	struct bio___24 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___23 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___23 *saved_end_io;
		} flush;
	};
	struct gendisk___24 *rq_disk;
	struct hd_struct___24 *part;
	long unsigned int start_time;
	struct request_list___23 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___23 *end_io;
	void *end_io_data;
	struct request___23 *next_rq;
};

struct blkcg___2;

struct blkg_policy_data___2;

struct blkcg_gq {
	struct request_queue___23 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___2 *blkcg;
	struct blkcg_gq *parent;
	struct request_list___23 rl;
	union {
		atomic_t refcnt;
		struct {
			int refcnt;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	bool online;
	struct blkg_policy_data___2 *pd[2];
	struct callback_head callback_head;
};

struct blk_mq_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___23 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___23(struct request_queue___23 *, struct request___23 **, struct bio___24 *);

typedef void elevator_merge_req_fn___23(struct request_queue___23 *, struct request___23 *, struct request___23 *);

typedef void elevator_merged_fn___23(struct request_queue___23 *, struct request___23 *, int);

typedef int elevator_allow_merge_fn___23(struct request_queue___23 *, struct request___23 *, struct bio___24 *);

typedef void elevator_bio_merged_fn___23(struct request_queue___23 *, struct request___23 *, struct bio___24 *);

typedef int elevator_dispatch_fn___23(struct request_queue___23 *, int);

typedef void elevator_add_req_fn___23(struct request_queue___23 *, struct request___23 *);

typedef struct request___23 *elevator_request_list_fn___23(struct request_queue___23 *, struct request___23 *);

typedef void elevator_completed_req_fn___23(struct request_queue___23 *, struct request___23 *);

typedef int elevator_may_queue_fn___23(struct request_queue___23 *, int);

typedef void elevator_init_icq_fn___23(struct io_cq___23 *);

typedef void elevator_exit_icq_fn___23(struct io_cq___23 *);

typedef int elevator_set_req_fn___23(struct request_queue___23 *, struct request___23 *, struct bio___24 *, gfp_t);

typedef void elevator_put_req_fn___23(struct request___23 *);

typedef void elevator_activate_req_fn___23(struct request_queue___23 *, struct request___23 *);

typedef void elevator_deactivate_req_fn___23(struct request_queue___23 *, struct request___23 *);

struct elevator_type___23;

typedef int elevator_init_fn___23(struct request_queue___23 *, struct elevator_type___23 *);

typedef void elevator_exit_fn___23(struct elevator_queue___23 *);

struct elevator_ops___23 {
	elevator_merge_fn___23 *elevator_merge_fn;
	elevator_merged_fn___23 *elevator_merged_fn;
	elevator_merge_req_fn___23 *elevator_merge_req_fn;
	elevator_allow_merge_fn___23 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___23 *elevator_bio_merged_fn;
	elevator_dispatch_fn___23 *elevator_dispatch_fn;
	elevator_add_req_fn___23 *elevator_add_req_fn;
	elevator_activate_req_fn___23 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___23 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___23 *elevator_completed_req_fn;
	elevator_request_list_fn___23 *elevator_former_req_fn;
	elevator_request_list_fn___23 *elevator_latter_req_fn;
	elevator_init_icq_fn___23 *elevator_init_icq_fn;
	elevator_exit_icq_fn___23 *elevator_exit_icq_fn;
	elevator_set_req_fn___23 *elevator_set_req_fn;
	elevator_put_req_fn___23 *elevator_put_req_fn;
	elevator_may_queue_fn___23 *elevator_may_queue_fn;
	elevator_init_fn___23 *elevator_init_fn;
	elevator_exit_fn___23 *elevator_exit_fn;
};

struct elv_fs_entry___23;

struct elevator_type___23 {
	struct kmem_cache___155 *icq_cache;
	struct elevator_ops___23 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___23 *elevator_attrs;
	char elevator_name[16];
	struct module___88 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___23 {
	struct elevator_type___23 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___172 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___23 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___23 *, char *);
	ssize_t (*store)(struct elevator_queue___23 *, const char *, size_t);
};

struct bvec_merge_data___23 {
	struct block_device___169 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___23 {
	struct request___23 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___2;

typedef int queue_rq_fn___2(struct blk_mq_hw_ctx___2 *, const struct blk_mq_queue_data___2 *);

typedef struct blk_mq_hw_ctx___2 *map_queue_fn___2(struct request_queue___23 *, const int);

typedef enum blk_eh_timer_return timeout_fn___2(struct request___23 *, bool);

typedef int init_request_fn___2(void *, struct request___23 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___2(void *, struct request___23 *, unsigned int, unsigned int);

typedef int init_hctx_fn___2(struct blk_mq_hw_ctx___2 *, void *, unsigned int);

typedef void exit_hctx_fn___2(struct blk_mq_hw_ctx___2 *, unsigned int);

struct blk_mq_ops___2 {
	queue_rq_fn___2 *queue_rq;
	map_queue_fn___2 *map_queue;
	union {
		timeout_fn___2 *timeout;
		struct {
			rq_timed_out_fn___23 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___23 *complete;
	init_request_fn___2 *init_request;
	exit_request_fn___2 *exit_request;
	init_hctx_fn___2 *init_hctx;
	exit_hctx_fn___2 *exit_hctx;
};

struct blk_mq_hw_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___23 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___2 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___23 **padding2;
		struct {
			struct request___23 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan___6;

struct blk_trace___5 {
	int trace_state;
	struct rchan___6 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___169 *dir;
	struct dentry___169 *dropped_file;
	struct dentry___169 *msg_file;
	atomic_t dropped;
};

struct blk_mq_tag_set {
	struct blk_mq_ops___2 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___172 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___23 *flush_rq;
	struct request___23 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_plug_cb;

typedef void (*blk_plug_cb_fn)(struct blk_plug_cb *, bool);

struct blk_plug_cb {
	struct list_head list;
	blk_plug_cb_fn callback;
	void *data;
};

struct blk_mq_queue_data___2 {
	struct request___23 *rq;
	struct list_head *list;
	bool last;
};

struct cgroupfs_root___111;

struct cgroup___111 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___111 *parent;
	struct dentry___169 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___111 *subsys[11];
	struct cgroupfs_root___111 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___172 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___111 {
	struct super_block___169 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___111 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___57 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___169 *, struct file___169 *);
	ssize_t (*read)(struct cgroup___111 *, struct cftype___57 *, struct file___169 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___111 *, struct cftype___57 *);
	s64 (*read_s64)(struct cgroup___111 *, struct cftype___57 *);
	int (*read_map)(struct cgroup___111 *, struct cftype___57 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___111 *, struct cftype___57 *, struct seq_file___125 *);
	ssize_t (*write)(struct cgroup___111 *, struct cftype___57 *, struct file___169 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___111 *, struct cftype___57 *, u64);
	int (*write_s64)(struct cgroup___111 *, struct cftype___57 *, s64);
	int (*write_string)(struct cgroup___111 *, struct cftype___57 *, const char *);
	int (*trigger)(struct cgroup___111 *, unsigned int);
	int (*release)(struct inode___169 *, struct file___169 *);
	int (*register_event)(struct cgroup___111 *, struct cftype___57 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___111 *, struct cftype___57 *, struct eventfd_ctx *);
};

struct cftype_set___55 {
	struct list_head node;
	struct cftype___57 *cfts;
};

struct task_and_cgroup___55 {
	struct task_struct___171 *task;
	struct cgroup___111 *cgrp;
	struct css_set___111 *cg;
};

struct cgroup_taskset___55 {
	struct task_and_cgroup___55 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___111 *cur_cgrp;
};

struct cgroup_subsys___55 {
	struct cgroup_subsys_state___111 * (*css_alloc)(struct cgroup___111 *);
	int (*css_online)(struct cgroup___111 *);
	void (*css_offline)(struct cgroup___111 *);
	void (*css_free)(struct cgroup___111 *);
	int (*can_attach)(struct cgroup___111 *, struct cgroup_taskset___55 *);
	void (*cancel_attach)(struct cgroup___111 *, struct cgroup_taskset___55 *);
	void (*attach)(struct cgroup___111 *, struct cgroup_taskset___55 *);
	void (*fork)(struct task_struct___171 *);
	void (*exit)(struct cgroup___111 *, struct cgroup___111 *, struct task_struct___171 *);
	void (*bind)(struct cgroup___111 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___111 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___57 *base_cftypes;
	struct cftype_set___55 base_cftset;
	struct module___88 *module;
};

struct rchan_buf___6 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___6 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___169 *dentry;
	struct kref kref;
	struct page___168 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___6;

struct rchan___6 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___6 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___6 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___169 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___6 {
	int (*subbuf_start)(struct rchan_buf___6 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___6 *, struct file___169 *);
	void (*buf_unmapped)(struct rchan_buf___6 *, struct file___169 *);
	struct dentry___169 * (*create_buf_file)(const char *, struct dentry___169 *, umode_t, struct rchan_buf___6 *, int *);
	int (*remove_buf_file)(struct dentry___169 *);
};

struct seq_operations___125 {
	void * (*start)(struct seq_file___125 *, loff_t *);
	void (*stop)(struct seq_file___125 *, void *);
	void * (*next)(struct seq_file___125 *, void *, loff_t *);
	int (*show)(struct seq_file___125 *, void *);
};

struct perf_cpu_context___76;

struct pmu___76 {
	struct list_head entry;
	struct device___134 *dev;
	const struct attribute_group___126 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___76 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___76 *);
	void (*pmu_disable)(struct pmu___76 *);
	int (*event_init)(struct perf_event___76 *);
	int (*add)(struct perf_event___76 *, int);
	void (*del)(struct perf_event___76 *, int);
	void (*start)(struct perf_event___76 *, int);
	void (*stop)(struct perf_event___76 *, int);
	void (*read)(struct perf_event___76 *);
	void (*start_txn)(struct pmu___76 *);
	int (*commit_txn)(struct pmu___76 *);
	void (*cancel_txn)(struct pmu___76 *);
	int (*event_idx)(struct perf_event___76 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___88 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___76 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___76 *);
};

struct perf_cpu_context___76 {
	struct perf_event_context___76 ctx;
	struct perf_event_context___76 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___76 *unique_pmu;
	struct perf_cgroup___76 *cgrp;
};

struct perf_sample_data___7 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___76 {
	struct cgroup_subsys_state___111 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___66 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___172 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___66)(struct trace_iterator___66 *, int, struct trace_event___66 *);

struct trace_event_functions___66 {
	trace_print_func___66 trace;
	trace_print_func___66 raw;
	trace_print_func___66 hex;
	trace_print_func___66 binary;
};

struct ftrace_event_class___66 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___66 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___66 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___66 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___66 *);
};

struct ftrace_event_file___22 {
	struct list_head list;
	struct ftrace_event_call___66 *event_call;
	struct dentry___169 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_block_buffer {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	size_t size;
	char __data[0];
};

struct ftrace_raw_block_rq_with_error {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int errors;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct ftrace_raw_block_rq_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int errors;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct ftrace_raw_block_rq {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	unsigned int bytes;
	char rwbs[8];
	char comm[16];
	u32 __data_loc_cmd;
	char __data[0];
};

struct ftrace_raw_block_bio_bounce {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_bio_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int error;
	char rwbs[8];
	char __data[0];
};

struct ftrace_raw_block_bio_merge {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_bio_queue {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_get_rq {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_plug {
	struct trace_entry ent;
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_unplug {
	struct trace_entry ent;
	int nr_rq;
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_split {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	sector_t new_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct ftrace_raw_block_bio_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	char rwbs[8];
	char __data[0];
};

struct ftrace_raw_block_rq_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	unsigned int nr_bios;
	char rwbs[8];
	char __data[0];
};

struct ftrace_data_offsets_block_buffer {};

struct ftrace_data_offsets_block_rq_with_error {
	u32 cmd;
};

struct ftrace_data_offsets_block_rq_complete {
	u32 cmd;
};

struct ftrace_data_offsets_block_rq {
	u32 cmd;
};

struct ftrace_data_offsets_block_bio_bounce {};

struct ftrace_data_offsets_block_bio_complete {};

struct ftrace_data_offsets_block_bio_merge {};

struct ftrace_data_offsets_block_bio_queue {};

struct ftrace_data_offsets_block_get_rq {};

struct ftrace_data_offsets_block_plug {};

struct ftrace_data_offsets_block_unplug {};

struct ftrace_data_offsets_block_split {};

struct ftrace_data_offsets_block_bio_remap {};

struct ftrace_data_offsets_block_rq_remap {};

enum rq_atomic_flags {
	REQ_ATOM_COMPLETE = 0,
	REQ_ATOM_STARTED = 1,
};

struct blkcg___2 {
	struct cgroup_subsys_state___111 css;
	spinlock_t lock;
	struct radix_tree_root blkg_tree;
	struct blkcg_gq *blkg_hint;
	struct hlist_head blkg_list;
	uint64_t id;
	unsigned int cfq_weight;
	unsigned int cfq_leaf_weight;
};

struct blkg_policy_data___2 {
	struct blkcg_gq *blkg;
	int plid;
	struct list_head alloc_node;
};

struct queue_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct request_queue___22 *, char *);
	ssize_t (*store)(struct request_queue___22 *, const char *, size_t);
};

struct bt_wait_state;

struct blk_mq_bitmap_tags {
	unsigned int depth;
	unsigned int wake_cnt;
	unsigned int bits_per_word;
	unsigned int map_nr;
	struct blk_align_bitmap *map;
	atomic_t wake_index;
	struct bt_wait_state *bs;
};

struct blk_mq_tags {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct blk_mq_bitmap_tags bitmap_tags;
	struct blk_mq_bitmap_tags breserved_tags;
	struct request___23 **rqs;
	struct list_head page_list;
	cpumask_var_t cpumask;
};

struct bt_wait_state {
	atomic_t wait_cnt;
	wait_queue_head_t wait;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	BLK_MQ_TAG_CACHE_MIN = 1,
	BLK_MQ_TAG_CACHE_MAX = 64,
};

enum {
	REQ_FSEQ_PREFLUSH = 1,
	REQ_FSEQ_DATA = 2,
	REQ_FSEQ_POSTFLUSH = 4,
	REQ_FSEQ_DONE = 8,
	REQ_FSEQ_ACTIONS = 7,
	FLUSH_PENDING_TIMEOUT = 5000,
};

enum blk_default_limits {
	BLK_MAX_SEGMENTS = 128,
	BLK_SAFE_MAX_SECTORS = 255,
	BLK_DEF_MAX_SECTORS = 1024,
	BLK_MAX_SEGMENT_SIZE = 65536,
	BLK_SEG_BOUNDARY_MASK = 4294967295,
};

enum {
	ICQ_EXITED = 4,
};

struct rq_map_data___2 {
	struct page___168 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct page___169;

typedef struct page___169 *pgtable_t___169;

struct address_space___170;

struct kmem_cache___156;

struct page___169 {
	long unsigned int flags;
	struct address_space___170 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___169 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___169 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___156 *slab_cache;
		struct page___169 *first_page;
	};
	long: 64;
};

struct task_struct___172;

struct pv_cpu_ops___172 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___76 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___76 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___172 *);
	void (*end_context_switch)(struct task_struct___172 *);
};

struct mutex___173 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___172 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___165 {
	struct page___169 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___177;

struct signal_struct___172;

struct bio_list___24;

struct backing_dev_info___34;

struct io_context___24;

struct task_struct___172 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___172 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___177 *mm;
	struct mm_struct___177 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___172 *real_parent;
	struct task_struct___172 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___172 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___85 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___172 = 0,
		VTIME_USER___172 = 1,
		VTIME_SYS___172 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___76 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___172 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___24 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___34 *backing_dev_info;
	struct io_context___24 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___173 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___165 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___177 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___177 *, struct mm_struct___177 *);
	void (*dup_mmap)(struct mm_struct___177 *, struct mm_struct___177 *);
	void (*exit_mmap)(struct mm_struct___177 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___177 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___177 *);
	void (*pgd_free)(struct mm_struct___177 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___177 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___177 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___177 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___177 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___177 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___177 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___177 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___177 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___177 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___177 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___177 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___173 lock;
	void *vdso;
} mm_context_t___173;

struct xol_area___169;

struct uprobes_state___169 {
	struct xol_area___169 *xol_area;
};

struct vm_area_struct___177;

struct file___170;

struct core_state___172;

struct mm_struct___177 {
	struct vm_area_struct___177 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___177 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___177 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___173 context;
	long unsigned int flags;
	struct core_state___172 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___172 *owner;
	struct file___170 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___169 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___89;

struct module_kobject___88 {
	struct kobject___19 kobj;
	struct module___89 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___88;

struct module___89 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___88 mkobj;
	struct module_attribute___88 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___172 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___172;

struct lruvec___172 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___172 *zone;
};

struct pglist_data___172;

struct zone___172 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___172 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___172 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___172 {
	struct zone___172 *zone;
	int zone_idx;
};

struct zonelist___172 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___172 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___172 {
	struct zone___172 node_zones[4];
	struct zonelist___172 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___172 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___135;

struct dev_pm_ops___135 {
	int (*prepare)(struct device___135 *);
	void (*complete)(struct device___135 *);
	int (*suspend)(struct device___135 *);
	int (*resume)(struct device___135 *);
	int (*freeze)(struct device___135 *);
	int (*thaw)(struct device___135 *);
	int (*poweroff)(struct device___135 *);
	int (*restore)(struct device___135 *);
	int (*suspend_late)(struct device___135 *);
	int (*resume_early)(struct device___135 *);
	int (*freeze_late)(struct device___135 *);
	int (*thaw_early)(struct device___135 *);
	int (*poweroff_late)(struct device___135 *);
	int (*restore_early)(struct device___135 *);
	int (*suspend_noirq)(struct device___135 *);
	int (*resume_noirq)(struct device___135 *);
	int (*freeze_noirq)(struct device___135 *);
	int (*thaw_noirq)(struct device___135 *);
	int (*poweroff_noirq)(struct device___135 *);
	int (*restore_noirq)(struct device___135 *);
	int (*runtime_suspend)(struct device___135 *);
	int (*runtime_resume)(struct device___135 *);
	int (*runtime_idle)(struct device___135 *);
};

struct dma_map_ops___56;

struct dev_archdata___56 {
	struct dma_map_ops___56 *dma_ops;
	void *iommu;
};

struct device_type___135;

struct bus_type___135;

struct device_driver___135;

struct dev_pm_domain___135;

struct class___135;

struct attribute_group___127;

struct device_rh___135;

struct device___135 {
	struct device___135 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___135 *type;
	struct mutex___173 mutex;
	struct bus_type___135 *bus;
	struct device_driver___135 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___135 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___56 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___135 *class;
	const struct attribute_group___127 **groups;
	void (*release)(struct device___135 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___135 *device_rh;
};

struct dev_pm_info_rh___135 {
	void (*set_latency_tolerance)(struct device___135 *, s32);
};

struct dev_pm_domain___135 {
	struct dev_pm_ops___135 ops;
};

struct smp_ops___172 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___172 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___129;

struct attribute_group___127 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___129 **bin_attrs;
};

struct bin_attribute___129 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___170 *, struct kobject___19 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___170 *, struct kobject___19 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	int (*mmap)(struct file___170 *, struct kobject___19 *, struct bin_attribute___129 *, struct vm_area_struct___177 *);
};

struct dentry___170;

struct path___170 {
	struct vfsmount *mnt;
	struct dentry___170 *dentry;
};

struct inode___170;

struct file_operations___170;

struct file___170 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___170 f_path;
	struct inode___170 *f_inode;
	const struct file_operations___170 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___170 *f_mapping;
	struct mutex___173 f_pos_lock;
};

struct vm_operations_struct___150;

struct vm_area_struct___177 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___177 *vm_next;
	struct vm_area_struct___177 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___177 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___150 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___170 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___88 *, struct module_kobject___88 *, char *);
	ssize_t (*store)(struct module_attribute___88 *, struct module_kobject___88 *, const char *, size_t);
	void (*setup)(struct module___89 *, const char *);
	int (*test)(struct module___89 *);
	void (*free)(struct module___89 *);
};

struct dentry_operations___170;

struct super_block___170;

struct dentry___170 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___170 *d_parent;
	struct qstr d_name;
	struct inode___170 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___170 *d_op;
	struct super_block___170 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___170;

struct address_space___170 {
	struct inode___170 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___173 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___170 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___34 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___170;

struct file_lock___170;

struct dquot___170;

struct block_device___170;

struct inode___170 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___170 *i_op;
	struct super_block___170 *i_sb;
	struct address_space___170 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___173 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___170 *i_fop;
	struct file_lock___170 *i_flock;
	struct address_space___170 i_data;
	struct dquot___170 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___170 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___170 {
	int (*d_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_hash)(const struct dentry___170 *, struct qstr *);
	int (*d_compare)(const struct dentry___170 *, const struct dentry___170 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___170 *);
	void (*d_release)(struct dentry___170 *);
	void (*d_prune)(struct dentry___170 *);
	void (*d_iput)(struct dentry___170 *, struct inode___170 *);
	char * (*d_dname)(struct dentry___170 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___170 *);
	int (*d_manage)(struct dentry___170 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___170;

struct mem_dqinfo___170 {
	struct quota_format_type___170 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___170;

struct quota_info___170 {
	unsigned int flags;
	struct mutex___173 dqio_mutex;
	struct mutex___173 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___170 *files[2];
	struct mem_dqinfo___170 info[2];
	const struct quota_format_ops___170 *ops[2];
};

struct file_system_type___170;

struct super_operations___170;

struct dquot_operations___170;

struct quotactl_ops___170;

struct super_block___170 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___170 *s_type;
	const struct super_operations___170 *s_op;
	const struct dquot_operations___170 *dq_op;
	const struct quotactl_ops___170 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___170 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___170 *s_bdev;
	struct backing_dev_info___34 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___170 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___173 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___170 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___25;

typedef void bio_end_io_t___25(struct bio___25 *, int);

struct bio_vec___25 {
	struct page___169 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___25;

struct bio_set___25;

struct bio___25 {
	sector_t bi_sector;
	struct bio___25 *bi_next;
	struct block_device___170 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___25 *bi_end_io;
	void *bi_private;
	struct io_context___24 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___25 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___25 *bi_io_vec;
	struct bio_set___25 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___25 bi_inline_vecs[0];
};

struct hd_struct___25;

struct gendisk___25;

struct request_queue___24;

struct block_device___170 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___170 *bd_inode;
	struct super_block___170 *bd_super;
	struct mutex___173 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___170 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___25 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___25 *bd_disk;
	struct request_queue___24 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___173 bd_fsfreeze_mutex;
};

struct io_cq___24;

struct io_context___24 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___24 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___25 {
	struct bio___25 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___25 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___25 *bip_vec;
	struct bio_vec___25 bip_inline_vecs[0];
};

struct bio_list___24 {
	struct bio___25 *head;
	struct bio___25 *tail;
};

struct bio_set___25 {
	struct kmem_cache___156 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___24 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___170 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___170 *ia_file;
};

struct dquot___170 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___173 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___170 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___170 {
	int qf_fmt_id;
	const struct quota_format_ops___170 *qf_ops;
	struct module___89 *qf_owner;
	struct quota_format_type___170 *qf_next;
};

struct quota_format_ops___170 {
	int (*check_quota_file)(struct super_block___170 *, int);
	int (*read_file_info)(struct super_block___170 *, int);
	int (*write_file_info)(struct super_block___170 *, int);
	int (*free_file_info)(struct super_block___170 *, int);
	int (*read_dqblk)(struct dquot___170 *);
	int (*commit_dqblk)(struct dquot___170 *);
	int (*release_dqblk)(struct dquot___170 *);
};

struct dquot_operations___170 {
	int (*write_dquot)(struct dquot___170 *);
	struct dquot___170 * (*alloc_dquot)(struct super_block___170 *, int);
	void (*destroy_dquot)(struct dquot___170 *);
	int (*acquire_dquot)(struct dquot___170 *);
	int (*release_dquot)(struct dquot___170 *);
	int (*mark_dirty)(struct dquot___170 *);
	int (*write_info)(struct super_block___170 *, int);
	qsize_t * (*get_reserved_space)(struct inode___170 *);
};

struct quotactl_ops___170 {
	int (*quota_on)(struct super_block___170 *, int, int, struct path___170 *);
	int (*quota_on_meta)(struct super_block___170 *, int, int);
	int (*quota_off)(struct super_block___170 *, int);
	int (*quota_sync)(struct super_block___170 *, int);
	int (*get_info)(struct super_block___170 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___170 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___170 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___170 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___170 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___170 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___170 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___170 *, unsigned int);
};

struct address_space_operations___170 {
	int (*writepage)(struct page___169 *, struct writeback_control *);
	int (*readpage)(struct file___170 *, struct page___169 *);
	int (*writepages)(struct address_space___170 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___169 *);
	int (*readpages)(struct file___170 *, struct address_space___170 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___170 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___169 **, void **);
	int (*write_end)(struct file___170 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___169 *, void *);
	sector_t (*bmap)(struct address_space___170 *, sector_t);
	void (*invalidatepage)(struct page___169 *, long unsigned int);
	int (*releasepage)(struct page___169 *, gfp_t);
	void (*freepage)(struct page___169 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___170 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___170 *, struct page___169 *, struct page___169 *, enum migrate_mode);
	int (*launder_page)(struct page___169 *);
	int (*is_partially_uptodate)(struct page___169 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___169 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___170 *, struct page___169 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___170 *, sector_t *);
	void (*swap_deactivate)(struct file___170 *);
	void (*invalidatepage_range)(struct page___169 *, unsigned int, unsigned int);
};

struct bdi_writeback___34 {
	struct backing_dev_info___34 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___34 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___34 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___135 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___170 *debug_dir;
	struct dentry___170 *debug_stats;
};

struct hd_struct___25 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___135 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___25;

struct block_device_operations___24;

struct gendisk___25 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___25 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___25 *part_tbl;
	struct hd_struct___25 part0;
	const struct block_device_operations___24 *fops;
	struct request_queue___24 *queue;
	void *private_data;
	int flags;
	struct device___135 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___24 {
	struct request_queue___24 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___24(struct request_queue___24 *);

typedef void make_request_fn___24(struct request_queue___24 *, struct bio___25 *);

struct request___24;

typedef int prep_rq_fn___24(struct request_queue___24 *, struct request___24 *);

struct bvec_merge_data___24;

typedef int merge_bvec_fn___24(struct request_queue___24 *, struct bvec_merge_data___24 *, struct bio_vec___25 *);

typedef void softirq_done_fn___24(struct request___24 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___24(struct request___24 *);

typedef int dma_drain_needed_fn___24(struct request___24 *);

typedef int lld_busy_fn___24(struct request_queue___24 *);

struct bsg_class_device___24 {
	struct device___135 *class_dev;
	struct device___135 *parent;
	int minor;
	struct request_queue___24 *queue;
	struct kref ref;
	void (*release)(struct device___135 *);
};

typedef void unprep_rq_fn___24(struct request_queue___24 *, struct request___24 *);

struct elevator_queue___24;

struct blk_mq_ops___3;

struct blk_mq_ctx___3;

struct blk_mq_hw_ctx___3;

struct blk_queue_tag___24;

struct blk_mq_tag_set___3;

struct blk_flush_queue___3;

struct request_queue___24 {
	struct list_head queue_head;
	struct request___24 *last_merge;
	struct elevator_queue___24 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___24 root_rl;
	request_fn_proc___24 *request_fn;
	make_request_fn___24 *make_request_fn;
	prep_rq_fn___24 *prep_rq_fn;
	merge_bvec_fn___24 *merge_bvec_fn;
	softirq_done_fn___24 *softirq_done_fn;
	rq_timed_out_fn___24 *rq_timed_out_fn;
	dma_drain_needed_fn___24 *dma_drain_needed;
	lld_busy_fn___24 *lld_busy_fn;
	struct blk_mq_ops___3 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___3 *queue_ctx;
		struct {
			struct blk_mq_ctx___3 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___24 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___34 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___135 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___24 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___24 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___173 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___24 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___24 *unprep_rq_fn;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___25 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___3 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___170 {
	struct dentry___170 * (*lookup)(struct inode___170 *, struct dentry___170 *, unsigned int);
	void * (*follow_link)(struct dentry___170 *, struct nameidata *);
	int (*permission)(struct inode___170 *, int);
	struct posix_acl * (*get_acl)(struct inode___170 *, int);
	int (*readlink)(struct dentry___170 *, char *, int);
	void (*put_link)(struct dentry___170 *, struct nameidata *, void *);
	int (*create)(struct inode___170 *, struct dentry___170 *, umode_t, bool);
	int (*link)(struct dentry___170 *, struct inode___170 *, struct dentry___170 *);
	int (*unlink)(struct inode___170 *, struct dentry___170 *);
	int (*symlink)(struct inode___170 *, struct dentry___170 *, const char *);
	int (*mkdir)(struct inode___170 *, struct dentry___170 *, umode_t);
	int (*rmdir)(struct inode___170 *, struct dentry___170 *);
	int (*mknod)(struct inode___170 *, struct dentry___170 *, umode_t, dev_t);
	int (*rename)(struct inode___170 *, struct dentry___170 *, struct inode___170 *, struct dentry___170 *);
	int (*setattr)(struct dentry___170 *, struct iattr___170 *);
	int (*getattr)(struct vfsmount *, struct dentry___170 *, struct kstat *);
	int (*setxattr)(struct dentry___170 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___170 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___170 *, char *, size_t);
	int (*removexattr)(struct dentry___170 *, const char *);
	int (*fiemap)(struct inode___170 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___170 *, struct timespec *, int);
	int (*atomic_open)(struct inode___170 *, struct dentry___170 *, struct file___170 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___170 {
	struct module___89 *owner;
	loff_t (*llseek)(struct file___170 *, loff_t, int);
	ssize_t (*read)(struct file___170 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___170 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___170 *, void *, filldir_t);
	unsigned int (*poll)(struct file___170 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___170 *, struct vm_area_struct___177 *);
	int (*open)(struct inode___170 *, struct file___170 *);
	int (*flush)(struct file___170 *, fl_owner_t);
	int (*release)(struct inode___170 *, struct file___170 *);
	int (*fsync)(struct file___170 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___170 *, int);
	int (*lock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*sendpage)(struct file___170 *, struct page___169 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___170 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___170 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___170 *, long int, struct file_lock___170 **, void **);
		struct {
			int (*setlease)(struct file___170 *, long int, struct file_lock___170 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___170 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___170 *);
};

struct fasync_struct___170;

struct file_lock_operations___170;

struct lock_manager_operations___170;

struct file_lock___170 {
	struct file_lock___170 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___85 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___170 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___170 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___170 *fl_ops;
	const struct lock_manager_operations___170 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___170 {
	void (*fl_copy_lock)(struct file_lock___170 *, struct file_lock___170 *);
	void (*fl_release_private)(struct file_lock___170 *);
};

struct lock_manager_operations___170 {
	int (*lm_compare_owner)(struct file_lock___170 *, struct file_lock___170 *);
	long unsigned int (*lm_owner_key)(struct file_lock___170 *);
	void (*lm_notify)(struct file_lock___170 *);
	int (*lm_grant)(struct file_lock___170 *, struct file_lock___170 *, int);
	void (*lm_break)(struct file_lock___170 *);
	int (*lm_change)(struct file_lock___170 **, int);
};

struct fasync_struct___170 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___170 *fa_next;
	struct file___170 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___170 {
	const char *name;
	int fs_flags;
	struct dentry___170 * (*mount)(struct file_system_type___170 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___170 *);
	struct module___89 *owner;
	struct file_system_type___170 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___170 {
	struct inode___170 * (*alloc_inode)(struct super_block___170 *);
	void (*destroy_inode)(struct inode___170 *);
	void (*dirty_inode)(struct inode___170 *, int);
	int (*write_inode)(struct inode___170 *, struct writeback_control *);
	int (*drop_inode)(struct inode___170 *);
	void (*evict_inode)(struct inode___170 *);
	void (*put_super)(struct super_block___170 *);
	int (*sync_fs)(struct super_block___170 *, int);
	int (*freeze_fs)(struct super_block___170 *);
	int (*unfreeze_fs)(struct super_block___170 *);
	int (*statfs)(struct dentry___170 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___170 *, int *, char *);
	void (*umount_begin)(struct super_block___170 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___170 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___170 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___170 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___170 *);
	ssize_t (*quota_read)(struct super_block___170 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___170 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___170 *);
	int (*bdev_try_to_free_page)(struct super_block___170 *, struct page___169 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___170 *);
	void (*free_cached_objects)(struct super_block___170 *, int);
};

struct xol_area___169 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___169 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___155;

struct memcg_cache_params___156;

struct kmem_cache___156 {
	struct kmem_cache_cpu___155 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___156 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___147;

struct vm_operations_struct___150 {
	void (*open)(struct vm_area_struct___177 *);
	void (*close)(struct vm_area_struct___177 *);
	int (*fault)(struct vm_area_struct___177 *, struct vm_fault___147 *);
	int (*page_mkwrite)(struct vm_area_struct___177 *, struct vm_fault___147 *);
	int (*access)(struct vm_area_struct___177 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___177 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___177 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___177 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___177 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___172 {
	struct task_struct___172 *task;
	struct core_thread___172 *next;
};

struct core_state___172 {
	atomic_t nr_threads;
	struct core_thread___172 dumper;
	struct completion startup;
};

struct vm_fault___147 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___169 *page;
};

struct signal_struct___172 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___172 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___172 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___85 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___173 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___24 {
	struct request_queue___24 *q;
	struct io_context___24 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___156 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kmem_cache_cpu___155 {
	void **freelist;
	long unsigned int tid;
	struct page___169 *page;
	struct page___169 *partial;
};

struct memcg_cache_params___156 {
	bool is_root_cache;
	union {
		struct kmem_cache___156 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___156 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___56 {
	void * (*alloc)(struct device___135 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___135 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___135 *, struct vm_area_struct___177 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___135 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___135 *, struct page___169 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___135 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___135 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___135 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___135 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___135 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___135 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___135 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___135 *, dma_addr_t);
	int (*dma_supported)(struct device___135 *, u64);
	int (*set_dma_mask)(struct device___135 *, u64);
	int is_phys;
};

struct bus_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___135 *, char *);
	ssize_t (*store)(struct bus_type___135 *, const char *, size_t);
};

struct device_attribute___135;

struct driver_attribute___135;

struct bus_type___135 {
	const char *name;
	const char *dev_name;
	struct device___135 *dev_root;
	struct bus_attribute___135 *bus_attrs;
	struct device_attribute___135 *dev_attrs;
	struct driver_attribute___135 *drv_attrs;
	const struct attribute_group___127 **bus_groups;
	const struct attribute_group___127 **dev_groups;
	const struct attribute_group___127 **drv_groups;
	int (*match)(struct device___135 *, struct device_driver___135 *);
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	int (*probe)(struct device___135 *);
	int (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*online)(struct device___135 *);
	int (*offline)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct device___135 *, struct device_attribute___135 *, char *);
	ssize_t (*store)(struct device___135 *, struct device_attribute___135 *, const char *, size_t);
};

struct driver_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___135 *, char *);
	ssize_t (*store)(struct device_driver___135 *, const char *, size_t);
};

struct device_driver___135 {
	const char *name;
	struct bus_type___135 *bus;
	struct module___89 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___135 *);
	int (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	const struct attribute_group___127 **groups;
	const struct dev_pm_ops___135 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___135 {
	const char *name;
	const struct attribute_group___127 **groups;
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
};

struct class_attribute___135;

struct class___135 {
	const char *name;
	struct module___89 *owner;
	struct class_attribute___135 *class_attrs;
	struct device_attribute___135 *dev_attrs;
	const struct attribute_group___127 **dev_groups;
	struct bin_attribute___129 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *);
	void (*class_release)(struct class___135 *);
	void (*dev_release)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
	struct subsys_private *p;
};

struct class_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct class___135 *, struct class_attribute___135 *, char *);
	ssize_t (*store)(struct class___135 *, struct class_attribute___135 *, const char *, size_t);
	const void * (*namespace)(struct class___135 *, const struct class_attribute___135 *);
};

struct device_rh___135 {
	struct dev_pm_info_rh___135 power;
};

struct disk_part_tbl___25 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___25 *last_lookup;
	struct hd_struct___25 *part[0];
};

struct block_device_operations___24 {
	int (*open)(struct block_device___170 *, fmode_t);
	void (*release)(struct gendisk___25 *, fmode_t);
	int (*ioctl)(struct block_device___170 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___170 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___170 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___25 *, unsigned int);
	int (*media_changed)(struct gendisk___25 *);
	void (*unlock_native_capacity)(struct gendisk___25 *);
	int (*revalidate_disk)(struct gendisk___25 *);
	int (*getgeo)(struct block_device___170 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___170 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___89 *owner;
};

typedef void rq_end_io_fn___24(struct request___24 *, int);

struct request___24 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___24 *q;
	struct blk_mq_ctx___3 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___25 *bio;
	struct bio___25 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___24 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___24 *saved_end_io;
		} flush;
	};
	struct gendisk___25 *rq_disk;
	struct hd_struct___25 *part;
	long unsigned int start_time;
	struct request_list___24 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___24 *end_io;
	void *end_io_data;
	struct request___24 *next_rq;
};

struct blk_mq_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___24 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___24(struct request_queue___24 *, struct request___24 **, struct bio___25 *);

typedef void elevator_merge_req_fn___24(struct request_queue___24 *, struct request___24 *, struct request___24 *);

typedef void elevator_merged_fn___24(struct request_queue___24 *, struct request___24 *, int);

typedef int elevator_allow_merge_fn___24(struct request_queue___24 *, struct request___24 *, struct bio___25 *);

typedef void elevator_bio_merged_fn___24(struct request_queue___24 *, struct request___24 *, struct bio___25 *);

typedef int elevator_dispatch_fn___24(struct request_queue___24 *, int);

typedef void elevator_add_req_fn___24(struct request_queue___24 *, struct request___24 *);

typedef struct request___24 *elevator_request_list_fn___24(struct request_queue___24 *, struct request___24 *);

typedef void elevator_completed_req_fn___24(struct request_queue___24 *, struct request___24 *);

typedef int elevator_may_queue_fn___24(struct request_queue___24 *, int);

typedef void elevator_init_icq_fn___24(struct io_cq___24 *);

typedef void elevator_exit_icq_fn___24(struct io_cq___24 *);

typedef int elevator_set_req_fn___24(struct request_queue___24 *, struct request___24 *, struct bio___25 *, gfp_t);

typedef void elevator_put_req_fn___24(struct request___24 *);

typedef void elevator_activate_req_fn___24(struct request_queue___24 *, struct request___24 *);

typedef void elevator_deactivate_req_fn___24(struct request_queue___24 *, struct request___24 *);

struct elevator_type___24;

typedef int elevator_init_fn___24(struct request_queue___24 *, struct elevator_type___24 *);

typedef void elevator_exit_fn___24(struct elevator_queue___24 *);

struct elevator_ops___24 {
	elevator_merge_fn___24 *elevator_merge_fn;
	elevator_merged_fn___24 *elevator_merged_fn;
	elevator_merge_req_fn___24 *elevator_merge_req_fn;
	elevator_allow_merge_fn___24 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___24 *elevator_bio_merged_fn;
	elevator_dispatch_fn___24 *elevator_dispatch_fn;
	elevator_add_req_fn___24 *elevator_add_req_fn;
	elevator_activate_req_fn___24 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___24 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___24 *elevator_completed_req_fn;
	elevator_request_list_fn___24 *elevator_former_req_fn;
	elevator_request_list_fn___24 *elevator_latter_req_fn;
	elevator_init_icq_fn___24 *elevator_init_icq_fn;
	elevator_exit_icq_fn___24 *elevator_exit_icq_fn;
	elevator_set_req_fn___24 *elevator_set_req_fn;
	elevator_put_req_fn___24 *elevator_put_req_fn;
	elevator_may_queue_fn___24 *elevator_may_queue_fn;
	elevator_init_fn___24 *elevator_init_fn;
	elevator_exit_fn___24 *elevator_exit_fn;
};

struct elv_fs_entry___24;

struct elevator_type___24 {
	struct kmem_cache___156 *icq_cache;
	struct elevator_ops___24 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___24 *elevator_attrs;
	char elevator_name[16];
	struct module___89 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___24 {
	struct elevator_type___24 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___173 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___24 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___24 *, char *);
	ssize_t (*store)(struct elevator_queue___24 *, const char *, size_t);
};

struct bvec_merge_data___24 {
	struct block_device___170 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___24 {
	struct request___24 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___3;

typedef int queue_rq_fn___3(struct blk_mq_hw_ctx___3 *, const struct blk_mq_queue_data___3 *);

typedef struct blk_mq_hw_ctx___3 *map_queue_fn___3(struct request_queue___24 *, const int);

typedef enum blk_eh_timer_return timeout_fn___3(struct request___24 *, bool);

typedef int init_request_fn___3(void *, struct request___24 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___3(void *, struct request___24 *, unsigned int, unsigned int);

typedef int init_hctx_fn___3(struct blk_mq_hw_ctx___3 *, void *, unsigned int);

typedef void exit_hctx_fn___3(struct blk_mq_hw_ctx___3 *, unsigned int);

struct blk_mq_ops___3 {
	queue_rq_fn___3 *queue_rq;
	map_queue_fn___3 *map_queue;
	union {
		timeout_fn___3 *timeout;
		struct {
			rq_timed_out_fn___24 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___24 *complete;
	init_request_fn___3 *init_request;
	exit_request_fn___3 *exit_request;
	init_hctx_fn___3 *init_hctx;
	exit_hctx_fn___3 *exit_hctx;
};

struct blk_mq_hw_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___24 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___3 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___24 **padding2;
		struct {
			struct request___24 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___3 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___3 {
	struct blk_mq_ops___3 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___173 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___3 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___24 *flush_rq;
	struct request___24 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_queue_data___3 {
	struct request___24 *rq;
	struct list_head *list;
	bool last;
};

enum scsi_device_event {
	SDEV_EVT_MEDIA_CHANGE = 1,
	SDEV_EVT_INQUIRY_CHANGE_REPORTED = 2,
	SDEV_EVT_CAPACITY_CHANGE_REPORTED = 3,
	SDEV_EVT_SOFT_THRESHOLD_REACHED_REPORTED = 4,
	SDEV_EVT_MODE_PARAMETER_CHANGE_REPORTED = 5,
	SDEV_EVT_LUN_CHANGE_REPORTED = 6,
	SDEV_EVT_FIRST = 1,
	SDEV_EVT_LAST = 6,
	SDEV_EVT_MAXBITS = 7,
};

struct bio_pair___3 {
	struct bio___25 bio1;
	struct bio___25 bio2;
	struct bio_vec___25 bv1;
	struct bio_vec___25 bv2;
	struct bio_integrity_payload___25 bip1;
	struct bio_integrity_payload___25 bip2;
	struct bio_vec___25 iv1;
	struct bio_vec___25 iv2;
	atomic_t cnt;
	int error;
};

struct req_iterator {
	int i;
	struct bio___25 *bio;
};

struct page___170;

typedef struct page___170 *pgtable_t___170;

struct address_space___171;

struct kmem_cache___157;

struct page___170 {
	long unsigned int flags;
	struct address_space___171 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___170 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___170 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___157 *slab_cache;
		struct page___170 *first_page;
	};
	long: 64;
};

struct task_struct___173;

struct pv_cpu_ops___173 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___76 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___76 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___173 *);
	void (*end_context_switch)(struct task_struct___173 *);
};

struct mutex___174 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___173 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___166 {
	struct page___170 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___178;

struct signal_struct___173;

struct bio_list___25;

struct backing_dev_info___35;

struct io_context___25;

struct task_struct___173 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___173 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___178 *mm;
	struct mm_struct___178 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___173 *real_parent;
	struct task_struct___173 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___173 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___85 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___173 = 0,
		VTIME_USER___173 = 1,
		VTIME_SYS___173 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___76 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___173 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___25 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___35 *backing_dev_info;
	struct io_context___25 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___174 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___166 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___178 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___178 *, struct mm_struct___178 *);
	void (*dup_mmap)(struct mm_struct___178 *, struct mm_struct___178 *);
	void (*exit_mmap)(struct mm_struct___178 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___178 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___178 *);
	void (*pgd_free)(struct mm_struct___178 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___178 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___178 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___178 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___178 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___178 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___178 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___178 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___178 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___178 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___178 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___178 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___174 lock;
	void *vdso;
} mm_context_t___174;

struct xol_area___170;

struct uprobes_state___170 {
	struct xol_area___170 *xol_area;
};

struct vm_area_struct___178;

struct file___171;

struct core_state___173;

struct mm_struct___178 {
	struct vm_area_struct___178 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___178 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___178 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___174 context;
	long unsigned int flags;
	struct core_state___173 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___173 *owner;
	struct file___171 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___170 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___90;

struct module_kobject___89 {
	struct kobject___19 kobj;
	struct module___90 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___89;

struct module___90 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___89 mkobj;
	struct module_attribute___89 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___173 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___173;

struct lruvec___173 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___173 *zone;
};

struct pglist_data___173;

struct zone___173 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___173 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___173 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___173 {
	struct zone___173 *zone;
	int zone_idx;
};

struct zonelist___173 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___173 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___173 {
	struct zone___173 node_zones[4];
	struct zonelist___173 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___173 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___136;

struct dev_pm_ops___136 {
	int (*prepare)(struct device___136 *);
	void (*complete)(struct device___136 *);
	int (*suspend)(struct device___136 *);
	int (*resume)(struct device___136 *);
	int (*freeze)(struct device___136 *);
	int (*thaw)(struct device___136 *);
	int (*poweroff)(struct device___136 *);
	int (*restore)(struct device___136 *);
	int (*suspend_late)(struct device___136 *);
	int (*resume_early)(struct device___136 *);
	int (*freeze_late)(struct device___136 *);
	int (*thaw_early)(struct device___136 *);
	int (*poweroff_late)(struct device___136 *);
	int (*restore_early)(struct device___136 *);
	int (*suspend_noirq)(struct device___136 *);
	int (*resume_noirq)(struct device___136 *);
	int (*freeze_noirq)(struct device___136 *);
	int (*thaw_noirq)(struct device___136 *);
	int (*poweroff_noirq)(struct device___136 *);
	int (*restore_noirq)(struct device___136 *);
	int (*runtime_suspend)(struct device___136 *);
	int (*runtime_resume)(struct device___136 *);
	int (*runtime_idle)(struct device___136 *);
};

struct device_type___136;

struct bus_type___136;

struct device_driver___136;

struct dev_pm_domain___136;

struct class___136;

struct attribute_group___128;

struct device_rh___136;

struct device___136 {
	struct device___136 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___136 *type;
	struct mutex___174 mutex;
	struct bus_type___136 *bus;
	struct device_driver___136 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___136 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___56 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___136 *class;
	const struct attribute_group___128 **groups;
	void (*release)(struct device___136 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___136 *device_rh;
};

struct dev_pm_info_rh___136 {
	void (*set_latency_tolerance)(struct device___136 *, s32);
};

struct dev_pm_domain___136 {
	struct dev_pm_ops___136 ops;
};

struct smp_ops___173 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___173 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___130;

struct attribute_group___128 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___130 **bin_attrs;
};

struct bin_attribute___130 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___171 *, struct kobject___19 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___171 *, struct kobject___19 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	int (*mmap)(struct file___171 *, struct kobject___19 *, struct bin_attribute___130 *, struct vm_area_struct___178 *);
};

struct dentry___171;

struct path___171 {
	struct vfsmount *mnt;
	struct dentry___171 *dentry;
};

struct inode___171;

struct file_operations___171;

struct file___171 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___171 f_path;
	struct inode___171 *f_inode;
	const struct file_operations___171 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___171 *f_mapping;
	struct mutex___174 f_pos_lock;
};

struct vm_operations_struct___151;

struct vm_area_struct___178 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___178 *vm_next;
	struct vm_area_struct___178 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___178 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___151 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___171 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___89 *, struct module_kobject___89 *, char *);
	ssize_t (*store)(struct module_attribute___89 *, struct module_kobject___89 *, const char *, size_t);
	void (*setup)(struct module___90 *, const char *);
	int (*test)(struct module___90 *);
	void (*free)(struct module___90 *);
};

struct xol_area___170 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___170 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___156;

struct memcg_cache_params___157;

struct kmem_cache___157 {
	struct kmem_cache_cpu___156 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___157 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___171;

struct address_space___171 {
	struct inode___171 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___174 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___171 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___35 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___148;

struct vm_operations_struct___151 {
	void (*open)(struct vm_area_struct___178 *);
	void (*close)(struct vm_area_struct___178 *);
	int (*fault)(struct vm_area_struct___178 *, struct vm_fault___148 *);
	int (*page_mkwrite)(struct vm_area_struct___178 *, struct vm_fault___148 *);
	int (*access)(struct vm_area_struct___178 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___178 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___178 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___178 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___178 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___173 {
	struct task_struct___173 *task;
	struct core_thread___173 *next;
};

struct core_state___173 {
	atomic_t nr_threads;
	struct core_thread___173 dumper;
	struct completion startup;
};

struct signal_struct___173 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___173 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___173 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___85 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___174 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___26;

struct bio_list___25 {
	struct bio___26 *head;
	struct bio___26 *tail;
};

struct bdi_writeback___35 {
	struct backing_dev_info___35 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___35 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___35 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___136 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___171 *debug_dir;
	struct dentry___171 *debug_stats;
};

struct io_cq___25;

struct io_context___25 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___25 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___156 {
	void **freelist;
	long unsigned int tid;
	struct page___170 *page;
	struct page___170 *partial;
};

struct memcg_cache_params___157 {
	bool is_root_cache;
	union {
		struct kmem_cache___157 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___157 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___136 *, char *);
	ssize_t (*store)(struct bus_type___136 *, const char *, size_t);
};

struct device_attribute___136;

struct driver_attribute___136;

struct bus_type___136 {
	const char *name;
	const char *dev_name;
	struct device___136 *dev_root;
	struct bus_attribute___136 *bus_attrs;
	struct device_attribute___136 *dev_attrs;
	struct driver_attribute___136 *drv_attrs;
	const struct attribute_group___128 **bus_groups;
	const struct attribute_group___128 **dev_groups;
	const struct attribute_group___128 **drv_groups;
	int (*match)(struct device___136 *, struct device_driver___136 *);
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	int (*probe)(struct device___136 *);
	int (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*online)(struct device___136 *);
	int (*offline)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct device___136 *, struct device_attribute___136 *, char *);
	ssize_t (*store)(struct device___136 *, struct device_attribute___136 *, const char *, size_t);
};

struct driver_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___136 *, char *);
	ssize_t (*store)(struct device_driver___136 *, const char *, size_t);
};

struct device_driver___136 {
	const char *name;
	struct bus_type___136 *bus;
	struct module___90 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___136 *);
	int (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	const struct attribute_group___128 **groups;
	const struct dev_pm_ops___136 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___136 {
	const char *name;
	const struct attribute_group___128 **groups;
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
};

struct class_attribute___136;

struct class___136 {
	const char *name;
	struct module___90 *owner;
	struct class_attribute___136 *class_attrs;
	struct device_attribute___136 *dev_attrs;
	const struct attribute_group___128 **dev_groups;
	struct bin_attribute___130 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *);
	void (*class_release)(struct class___136 *);
	void (*dev_release)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
	struct subsys_private *p;
};

struct class_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct class___136 *, struct class_attribute___136 *, char *);
	ssize_t (*store)(struct class___136 *, struct class_attribute___136 *, const char *, size_t);
	const void * (*namespace)(struct class___136 *, const struct class_attribute___136 *);
};

struct device_rh___136 {
	struct dev_pm_info_rh___136 power;
};

struct dentry_operations___171;

struct super_block___171;

struct dentry___171 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___171 *d_parent;
	struct qstr d_name;
	struct inode___171 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___171 *d_op;
	struct super_block___171 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___171;

struct file_lock___171;

struct dquot___171;

struct block_device___171;

struct inode___171 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___171 *i_op;
	struct super_block___171 *i_sb;
	struct address_space___171 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___174 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___171 *i_fop;
	struct file_lock___171 *i_flock;
	struct address_space___171 i_data;
	struct dquot___171 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___171 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___171 {
	int (*d_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_hash)(const struct dentry___171 *, struct qstr *);
	int (*d_compare)(const struct dentry___171 *, const struct dentry___171 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___171 *);
	void (*d_release)(struct dentry___171 *);
	void (*d_prune)(struct dentry___171 *);
	void (*d_iput)(struct dentry___171 *, struct inode___171 *);
	char * (*d_dname)(struct dentry___171 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___171 *);
	int (*d_manage)(struct dentry___171 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___171;

struct mem_dqinfo___171 {
	struct quota_format_type___171 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___171;

struct quota_info___171 {
	unsigned int flags;
	struct mutex___174 dqio_mutex;
	struct mutex___174 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___171 *files[2];
	struct mem_dqinfo___171 info[2];
	const struct quota_format_ops___171 *ops[2];
};

struct file_system_type___171;

struct super_operations___171;

struct dquot_operations___171;

struct quotactl_ops___171;

struct super_block___171 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___171 *s_type;
	const struct super_operations___171 *s_op;
	const struct dquot_operations___171 *dq_op;
	const struct quotactl_ops___171 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___171 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___171 *s_bdev;
	struct backing_dev_info___35 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___171 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___174 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___171 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___26(struct bio___26 *, int);

struct bio_vec___26 {
	struct page___170 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___26;

struct bio_set___26;

struct bio___26 {
	sector_t bi_sector;
	struct bio___26 *bi_next;
	struct block_device___171 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___26 *bi_end_io;
	void *bi_private;
	struct io_context___25 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___26 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___26 *bi_io_vec;
	struct bio_set___26 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___26 bi_inline_vecs[0];
};

struct hd_struct___26;

struct gendisk___26;

struct request_queue___25;

struct block_device___171 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___171 *bd_inode;
	struct super_block___171 *bd_super;
	struct mutex___174 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___171 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___26 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___26 *bd_disk;
	struct request_queue___25 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___174 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___26 {
	struct bio___26 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___26 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___26 *bip_vec;
	struct bio_vec___26 bip_inline_vecs[0];
};

struct bio_set___26 {
	struct kmem_cache___157 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___25 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___171 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___171 *ia_file;
};

struct dquot___171 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___174 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___171 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___171 {
	int qf_fmt_id;
	const struct quota_format_ops___171 *qf_ops;
	struct module___90 *qf_owner;
	struct quota_format_type___171 *qf_next;
};

struct quota_format_ops___171 {
	int (*check_quota_file)(struct super_block___171 *, int);
	int (*read_file_info)(struct super_block___171 *, int);
	int (*write_file_info)(struct super_block___171 *, int);
	int (*free_file_info)(struct super_block___171 *, int);
	int (*read_dqblk)(struct dquot___171 *);
	int (*commit_dqblk)(struct dquot___171 *);
	int (*release_dqblk)(struct dquot___171 *);
};

struct dquot_operations___171 {
	int (*write_dquot)(struct dquot___171 *);
	struct dquot___171 * (*alloc_dquot)(struct super_block___171 *, int);
	void (*destroy_dquot)(struct dquot___171 *);
	int (*acquire_dquot)(struct dquot___171 *);
	int (*release_dquot)(struct dquot___171 *);
	int (*mark_dirty)(struct dquot___171 *);
	int (*write_info)(struct super_block___171 *, int);
	qsize_t * (*get_reserved_space)(struct inode___171 *);
};

struct quotactl_ops___171 {
	int (*quota_on)(struct super_block___171 *, int, int, struct path___171 *);
	int (*quota_on_meta)(struct super_block___171 *, int, int);
	int (*quota_off)(struct super_block___171 *, int);
	int (*quota_sync)(struct super_block___171 *, int);
	int (*get_info)(struct super_block___171 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___171 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___171 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___171 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___171 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___171 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___171 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___171 *, unsigned int);
};

struct address_space_operations___171 {
	int (*writepage)(struct page___170 *, struct writeback_control *);
	int (*readpage)(struct file___171 *, struct page___170 *);
	int (*writepages)(struct address_space___171 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___170 *);
	int (*readpages)(struct file___171 *, struct address_space___171 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___171 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___170 **, void **);
	int (*write_end)(struct file___171 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___170 *, void *);
	sector_t (*bmap)(struct address_space___171 *, sector_t);
	void (*invalidatepage)(struct page___170 *, long unsigned int);
	int (*releasepage)(struct page___170 *, gfp_t);
	void (*freepage)(struct page___170 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___171 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___171 *, struct page___170 *, struct page___170 *, enum migrate_mode);
	int (*launder_page)(struct page___170 *);
	int (*is_partially_uptodate)(struct page___170 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___170 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___171 *, struct page___170 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___171 *, sector_t *);
	void (*swap_deactivate)(struct file___171 *);
	void (*invalidatepage_range)(struct page___170 *, unsigned int, unsigned int);
};

struct hd_struct___26 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___136 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___26;

struct block_device_operations___25;

struct gendisk___26 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___26 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___26 *part_tbl;
	struct hd_struct___26 part0;
	const struct block_device_operations___25 *fops;
	struct request_queue___25 *queue;
	void *private_data;
	int flags;
	struct device___136 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___25 {
	struct request_queue___25 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___25(struct request_queue___25 *);

typedef void make_request_fn___25(struct request_queue___25 *, struct bio___26 *);

struct request___25;

typedef int prep_rq_fn___25(struct request_queue___25 *, struct request___25 *);

struct bvec_merge_data___25;

typedef int merge_bvec_fn___25(struct request_queue___25 *, struct bvec_merge_data___25 *, struct bio_vec___26 *);

typedef void softirq_done_fn___25(struct request___25 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___25(struct request___25 *);

typedef int dma_drain_needed_fn___25(struct request___25 *);

typedef int lld_busy_fn___25(struct request_queue___25 *);

struct bsg_class_device___25 {
	struct device___136 *class_dev;
	struct device___136 *parent;
	int minor;
	struct request_queue___25 *queue;
	struct kref ref;
	void (*release)(struct device___136 *);
};

typedef void unprep_rq_fn___25(struct request_queue___25 *, struct request___25 *);

struct elevator_queue___25;

struct blk_mq_ops___4;

struct blk_mq_ctx___4;

struct blk_mq_hw_ctx___4;

struct blk_queue_tag___25;

struct blk_mq_tag_set___4;

struct blk_flush_queue___4;

struct request_queue___25 {
	struct list_head queue_head;
	struct request___25 *last_merge;
	struct elevator_queue___25 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___25 root_rl;
	request_fn_proc___25 *request_fn;
	make_request_fn___25 *make_request_fn;
	prep_rq_fn___25 *prep_rq_fn;
	merge_bvec_fn___25 *merge_bvec_fn;
	softirq_done_fn___25 *softirq_done_fn;
	rq_timed_out_fn___25 *rq_timed_out_fn;
	dma_drain_needed_fn___25 *dma_drain_needed;
	lld_busy_fn___25 *lld_busy_fn;
	struct blk_mq_ops___4 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___4 *queue_ctx;
		struct {
			struct blk_mq_ctx___4 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___4 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___25 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___35 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___136 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___25 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___25 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___174 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___25 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___25 *unprep_rq_fn;
	struct blk_mq_tag_set___4 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___26 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___4 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___171 {
	struct dentry___171 * (*lookup)(struct inode___171 *, struct dentry___171 *, unsigned int);
	void * (*follow_link)(struct dentry___171 *, struct nameidata *);
	int (*permission)(struct inode___171 *, int);
	struct posix_acl * (*get_acl)(struct inode___171 *, int);
	int (*readlink)(struct dentry___171 *, char *, int);
	void (*put_link)(struct dentry___171 *, struct nameidata *, void *);
	int (*create)(struct inode___171 *, struct dentry___171 *, umode_t, bool);
	int (*link)(struct dentry___171 *, struct inode___171 *, struct dentry___171 *);
	int (*unlink)(struct inode___171 *, struct dentry___171 *);
	int (*symlink)(struct inode___171 *, struct dentry___171 *, const char *);
	int (*mkdir)(struct inode___171 *, struct dentry___171 *, umode_t);
	int (*rmdir)(struct inode___171 *, struct dentry___171 *);
	int (*mknod)(struct inode___171 *, struct dentry___171 *, umode_t, dev_t);
	int (*rename)(struct inode___171 *, struct dentry___171 *, struct inode___171 *, struct dentry___171 *);
	int (*setattr)(struct dentry___171 *, struct iattr___171 *);
	int (*getattr)(struct vfsmount *, struct dentry___171 *, struct kstat *);
	int (*setxattr)(struct dentry___171 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___171 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___171 *, char *, size_t);
	int (*removexattr)(struct dentry___171 *, const char *);
	int (*fiemap)(struct inode___171 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___171 *, struct timespec *, int);
	int (*atomic_open)(struct inode___171 *, struct dentry___171 *, struct file___171 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___171 {
	struct module___90 *owner;
	loff_t (*llseek)(struct file___171 *, loff_t, int);
	ssize_t (*read)(struct file___171 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___171 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___171 *, void *, filldir_t);
	unsigned int (*poll)(struct file___171 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___171 *, struct vm_area_struct___178 *);
	int (*open)(struct inode___171 *, struct file___171 *);
	int (*flush)(struct file___171 *, fl_owner_t);
	int (*release)(struct inode___171 *, struct file___171 *);
	int (*fsync)(struct file___171 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___171 *, int);
	int (*lock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*sendpage)(struct file___171 *, struct page___170 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___171 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___171 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___171 *, long int, struct file_lock___171 **, void **);
		struct {
			int (*setlease)(struct file___171 *, long int, struct file_lock___171 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___171 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___171 *);
};

struct fasync_struct___171;

struct file_lock_operations___171;

struct lock_manager_operations___171;

struct file_lock___171 {
	struct file_lock___171 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___85 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___171 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___171 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___171 *fl_ops;
	const struct lock_manager_operations___171 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___171 {
	void (*fl_copy_lock)(struct file_lock___171 *, struct file_lock___171 *);
	void (*fl_release_private)(struct file_lock___171 *);
};

struct lock_manager_operations___171 {
	int (*lm_compare_owner)(struct file_lock___171 *, struct file_lock___171 *);
	long unsigned int (*lm_owner_key)(struct file_lock___171 *);
	void (*lm_notify)(struct file_lock___171 *);
	int (*lm_grant)(struct file_lock___171 *, struct file_lock___171 *, int);
	void (*lm_break)(struct file_lock___171 *);
	int (*lm_change)(struct file_lock___171 **, int);
};

struct fasync_struct___171 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___171 *fa_next;
	struct file___171 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___171 {
	const char *name;
	int fs_flags;
	struct dentry___171 * (*mount)(struct file_system_type___171 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___171 *);
	struct module___90 *owner;
	struct file_system_type___171 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___171 {
	struct inode___171 * (*alloc_inode)(struct super_block___171 *);
	void (*destroy_inode)(struct inode___171 *);
	void (*dirty_inode)(struct inode___171 *, int);
	int (*write_inode)(struct inode___171 *, struct writeback_control *);
	int (*drop_inode)(struct inode___171 *);
	void (*evict_inode)(struct inode___171 *);
	void (*put_super)(struct super_block___171 *);
	int (*sync_fs)(struct super_block___171 *, int);
	int (*freeze_fs)(struct super_block___171 *);
	int (*unfreeze_fs)(struct super_block___171 *);
	int (*statfs)(struct dentry___171 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___171 *, int *, char *);
	void (*umount_begin)(struct super_block___171 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___171 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___171 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___171 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___171 *);
	ssize_t (*quota_read)(struct super_block___171 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___171 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___171 *);
	int (*bdev_try_to_free_page)(struct super_block___171 *, struct page___170 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___171 *);
	void (*free_cached_objects)(struct super_block___171 *, int);
};

struct disk_part_tbl___26 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___26 *last_lookup;
	struct hd_struct___26 *part[0];
};

struct block_device_operations___25 {
	int (*open)(struct block_device___171 *, fmode_t);
	void (*release)(struct gendisk___26 *, fmode_t);
	int (*ioctl)(struct block_device___171 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___171 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___171 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___26 *, unsigned int);
	int (*media_changed)(struct gendisk___26 *);
	void (*unlock_native_capacity)(struct gendisk___26 *);
	int (*revalidate_disk)(struct gendisk___26 *);
	int (*getgeo)(struct block_device___171 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___171 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___90 *owner;
};

struct vm_fault___148 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___170 *page;
};

struct io_cq___25 {
	struct request_queue___25 *q;
	struct io_context___25 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___157 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___25(struct request___25 *, int);

struct request___25 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___25 *q;
	struct blk_mq_ctx___4 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___26 *bio;
	struct bio___26 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___25 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___25 *saved_end_io;
		} flush;
	};
	struct gendisk___26 *rq_disk;
	struct hd_struct___26 *part;
	long unsigned int start_time;
	struct request_list___25 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___25 *end_io;
	void *end_io_data;
	struct request___25 *next_rq;
};

struct blk_mq_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___25 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___25(struct request_queue___25 *, struct request___25 **, struct bio___26 *);

typedef void elevator_merge_req_fn___25(struct request_queue___25 *, struct request___25 *, struct request___25 *);

typedef void elevator_merged_fn___25(struct request_queue___25 *, struct request___25 *, int);

typedef int elevator_allow_merge_fn___25(struct request_queue___25 *, struct request___25 *, struct bio___26 *);

typedef void elevator_bio_merged_fn___25(struct request_queue___25 *, struct request___25 *, struct bio___26 *);

typedef int elevator_dispatch_fn___25(struct request_queue___25 *, int);

typedef void elevator_add_req_fn___25(struct request_queue___25 *, struct request___25 *);

typedef struct request___25 *elevator_request_list_fn___25(struct request_queue___25 *, struct request___25 *);

typedef void elevator_completed_req_fn___25(struct request_queue___25 *, struct request___25 *);

typedef int elevator_may_queue_fn___25(struct request_queue___25 *, int);

typedef void elevator_init_icq_fn___25(struct io_cq___25 *);

typedef void elevator_exit_icq_fn___25(struct io_cq___25 *);

typedef int elevator_set_req_fn___25(struct request_queue___25 *, struct request___25 *, struct bio___26 *, gfp_t);

typedef void elevator_put_req_fn___25(struct request___25 *);

typedef void elevator_activate_req_fn___25(struct request_queue___25 *, struct request___25 *);

typedef void elevator_deactivate_req_fn___25(struct request_queue___25 *, struct request___25 *);

struct elevator_type___25;

typedef int elevator_init_fn___25(struct request_queue___25 *, struct elevator_type___25 *);

typedef void elevator_exit_fn___25(struct elevator_queue___25 *);

struct elevator_ops___25 {
	elevator_merge_fn___25 *elevator_merge_fn;
	elevator_merged_fn___25 *elevator_merged_fn;
	elevator_merge_req_fn___25 *elevator_merge_req_fn;
	elevator_allow_merge_fn___25 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___25 *elevator_bio_merged_fn;
	elevator_dispatch_fn___25 *elevator_dispatch_fn;
	elevator_add_req_fn___25 *elevator_add_req_fn;
	elevator_activate_req_fn___25 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___25 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___25 *elevator_completed_req_fn;
	elevator_request_list_fn___25 *elevator_former_req_fn;
	elevator_request_list_fn___25 *elevator_latter_req_fn;
	elevator_init_icq_fn___25 *elevator_init_icq_fn;
	elevator_exit_icq_fn___25 *elevator_exit_icq_fn;
	elevator_set_req_fn___25 *elevator_set_req_fn;
	elevator_put_req_fn___25 *elevator_put_req_fn;
	elevator_may_queue_fn___25 *elevator_may_queue_fn;
	elevator_init_fn___25 *elevator_init_fn;
	elevator_exit_fn___25 *elevator_exit_fn;
};

struct elv_fs_entry___25;

struct elevator_type___25 {
	struct kmem_cache___157 *icq_cache;
	struct elevator_ops___25 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___25 *elevator_attrs;
	char elevator_name[16];
	struct module___90 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___25 {
	struct elevator_type___25 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___174 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___25 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___25 *, char *);
	ssize_t (*store)(struct elevator_queue___25 *, const char *, size_t);
};

struct bvec_merge_data___25 {
	struct block_device___171 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___25 {
	struct request___25 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___4;

typedef int queue_rq_fn___4(struct blk_mq_hw_ctx___4 *, const struct blk_mq_queue_data___4 *);

typedef struct blk_mq_hw_ctx___4 *map_queue_fn___4(struct request_queue___25 *, const int);

typedef enum blk_eh_timer_return timeout_fn___4(struct request___25 *, bool);

typedef int init_request_fn___4(void *, struct request___25 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___4(void *, struct request___25 *, unsigned int, unsigned int);

typedef int init_hctx_fn___4(struct blk_mq_hw_ctx___4 *, void *, unsigned int);

typedef void exit_hctx_fn___4(struct blk_mq_hw_ctx___4 *, unsigned int);

struct blk_mq_ops___4 {
	queue_rq_fn___4 *queue_rq;
	map_queue_fn___4 *map_queue;
	union {
		timeout_fn___4 *timeout;
		struct {
			rq_timed_out_fn___25 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___25 *complete;
	init_request_fn___4 *init_request;
	exit_request_fn___4 *exit_request;
	init_hctx_fn___4 *init_hctx;
	exit_hctx_fn___4 *exit_hctx;
};

struct blk_mq_hw_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___25 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___4 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___25 **padding2;
		struct {
			struct request___25 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___4 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___4 {
	struct blk_mq_ops___4 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___174 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___4 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___25 *flush_rq;
	struct request___25 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_queue_data___4 {
	struct request___25 *rq;
	struct list_head *list;
	bool last;
};

struct blk_iopoll;

typedef int blk_iopoll_fn(struct blk_iopoll *, int);

struct blk_iopoll {
	struct list_head list;
	long unsigned int state;
	long unsigned int data;
	int weight;
	int max;
	blk_iopoll_fn *poll;
};

enum {
	IOPOLL_F_SCHED = 0,
	IOPOLL_F_DISABLE = 1,
};

struct bio_batch {
	atomic_t done;
	long unsigned int flags;
	struct completion *wait;
};

struct page___171;

typedef struct page___171 *pgtable_t___171;

struct address_space___172;

struct kmem_cache___158;

struct page___171 {
	long unsigned int flags;
	struct address_space___172 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___171 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___171 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___158 *slab_cache;
		struct page___171 *first_page;
	};
	long: 64;
};

struct task_struct___174;

struct pv_cpu_ops___174 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___76 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___76 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___174 *);
	void (*end_context_switch)(struct task_struct___174 *);
};

struct mutex___175 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___174 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___167 {
	struct page___171 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___179;

struct signal_struct___174;

struct bio_list___26;

struct backing_dev_info___36;

struct io_context___26;

struct task_struct___174 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___174 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___179 *mm;
	struct mm_struct___179 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___174 *real_parent;
	struct task_struct___174 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___174 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___85 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___174 = 0,
		VTIME_USER___174 = 1,
		VTIME_SYS___174 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___76 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___174 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___26 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___36 *backing_dev_info;
	struct io_context___26 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___175 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___167 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___179 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___179 *, struct mm_struct___179 *);
	void (*dup_mmap)(struct mm_struct___179 *, struct mm_struct___179 *);
	void (*exit_mmap)(struct mm_struct___179 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___179 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___179 *);
	void (*pgd_free)(struct mm_struct___179 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___179 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___179 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___179 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___179 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___179 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___179 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___179 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___179 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___179 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___179 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___179 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___175 lock;
	void *vdso;
} mm_context_t___175;

struct xol_area___171;

struct uprobes_state___171 {
	struct xol_area___171 *xol_area;
};

struct vm_area_struct___179;

struct file___172;

struct core_state___174;

struct mm_struct___179 {
	struct vm_area_struct___179 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___179 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___179 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___175 context;
	long unsigned int flags;
	struct core_state___174 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___174 *owner;
	struct file___172 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___171 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___91;

struct exec_domain___42 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___91 *module;
	struct exec_domain___42 *next;
};

struct module_kobject___90 {
	struct kobject___19 kobj;
	struct module___91 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___90;

struct module___91 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___90 mkobj;
	struct module_attribute___90 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___174 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___80 {
	struct task_struct___174 *task;
	struct exec_domain___42 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___174;

struct lruvec___174 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___174 *zone;
};

struct pglist_data___174;

struct zone___174 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___174 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___174 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___174 {
	struct zone___174 *zone;
	int zone_idx;
};

struct zonelist___174 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___174 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___174 {
	struct zone___174 node_zones[4];
	struct zonelist___174 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___174 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___137;

struct dev_pm_ops___137 {
	int (*prepare)(struct device___137 *);
	void (*complete)(struct device___137 *);
	int (*suspend)(struct device___137 *);
	int (*resume)(struct device___137 *);
	int (*freeze)(struct device___137 *);
	int (*thaw)(struct device___137 *);
	int (*poweroff)(struct device___137 *);
	int (*restore)(struct device___137 *);
	int (*suspend_late)(struct device___137 *);
	int (*resume_early)(struct device___137 *);
	int (*freeze_late)(struct device___137 *);
	int (*thaw_early)(struct device___137 *);
	int (*poweroff_late)(struct device___137 *);
	int (*restore_early)(struct device___137 *);
	int (*suspend_noirq)(struct device___137 *);
	int (*resume_noirq)(struct device___137 *);
	int (*freeze_noirq)(struct device___137 *);
	int (*thaw_noirq)(struct device___137 *);
	int (*poweroff_noirq)(struct device___137 *);
	int (*restore_noirq)(struct device___137 *);
	int (*runtime_suspend)(struct device___137 *);
	int (*runtime_resume)(struct device___137 *);
	int (*runtime_idle)(struct device___137 *);
};

struct device_type___137;

struct bus_type___137;

struct device_driver___137;

struct dev_pm_domain___137;

struct class___137;

struct attribute_group___129;

struct device_rh___137;

struct device___137 {
	struct device___137 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___137 *type;
	struct mutex___175 mutex;
	struct bus_type___137 *bus;
	struct device_driver___137 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___137 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___56 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___12 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___137 *class;
	const struct attribute_group___129 **groups;
	void (*release)(struct device___137 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___137 *device_rh;
};

struct dev_pm_info_rh___137 {
	void (*set_latency_tolerance)(struct device___137 *, s32);
};

struct dev_pm_domain___137 {
	struct dev_pm_ops___137 ops;
};

struct smp_ops___174 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___174 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___131;

struct attribute_group___129 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___131 **bin_attrs;
};

struct bin_attribute___131 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___172 *, struct kobject___19 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___172 *, struct kobject___19 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	int (*mmap)(struct file___172 *, struct kobject___19 *, struct bin_attribute___131 *, struct vm_area_struct___179 *);
};

struct dentry___172;

struct path___172 {
	struct vfsmount *mnt;
	struct dentry___172 *dentry;
};

struct inode___172;

struct file_operations___172;

struct file___172 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___172 f_path;
	struct inode___172 *f_inode;
	const struct file_operations___172 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___172 *f_mapping;
	struct mutex___175 f_pos_lock;
};

struct vm_operations_struct___152;

struct vm_area_struct___179 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___179 *vm_next;
	struct vm_area_struct___179 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___179 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___152 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___172 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___90 *, struct module_kobject___90 *, char *);
	ssize_t (*store)(struct module_attribute___90 *, struct module_kobject___90 *, const char *, size_t);
	void (*setup)(struct module___91 *, const char *);
	int (*test)(struct module___91 *);
	void (*free)(struct module___91 *);
};

struct dentry_operations___172;

struct super_block___172;

struct dentry___172 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___172 *d_parent;
	struct qstr d_name;
	struct inode___172 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___172 *d_op;
	struct super_block___172 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___172;

struct address_space___172 {
	struct inode___172 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___175 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___172 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___36 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___172;

struct file_lock___172;

struct dquot___172;

struct block_device___172;

struct inode___172 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___172 *i_op;
	struct super_block___172 *i_sb;
	struct address_space___172 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___175 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___172 *i_fop;
	struct file_lock___172 *i_flock;
	struct address_space___172 i_data;
	struct dquot___172 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___172 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___172 {
	int (*d_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_hash)(const struct dentry___172 *, struct qstr *);
	int (*d_compare)(const struct dentry___172 *, const struct dentry___172 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___172 *);
	void (*d_release)(struct dentry___172 *);
	void (*d_prune)(struct dentry___172 *);
	void (*d_iput)(struct dentry___172 *, struct inode___172 *);
	char * (*d_dname)(struct dentry___172 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___172 *);
	int (*d_manage)(struct dentry___172 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___172;

struct mem_dqinfo___172 {
	struct quota_format_type___172 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___172;

struct quota_info___172 {
	unsigned int flags;
	struct mutex___175 dqio_mutex;
	struct mutex___175 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___172 *files[2];
	struct mem_dqinfo___172 info[2];
	const struct quota_format_ops___172 *ops[2];
};

struct file_system_type___172;

struct super_operations___172;

struct dquot_operations___172;

struct quotactl_ops___172;

struct super_block___172 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___172 *s_type;
	const struct super_operations___172 *s_op;
	const struct dquot_operations___172 *dq_op;
	const struct quotactl_ops___172 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___172 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___172 *s_bdev;
	struct backing_dev_info___36 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___172 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___175 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___172 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___27;

typedef void bio_end_io_t___27(struct bio___27 *, int);

struct bio_vec___27 {
	struct page___171 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___27;

struct bio_set___27;

struct bio___27 {
	sector_t bi_sector;
	struct bio___27 *bi_next;
	struct block_device___172 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___27 *bi_end_io;
	void *bi_private;
	struct io_context___26 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___27 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___27 *bi_io_vec;
	struct bio_set___27 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___27 bi_inline_vecs[0];
};

struct hd_struct___27;

struct gendisk___27;

struct request_queue___26;

struct block_device___172 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___172 *bd_inode;
	struct super_block___172 *bd_super;
	struct mutex___175 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___172 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___27 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___27 *bd_disk;
	struct request_queue___26 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___175 bd_fsfreeze_mutex;
};

struct io_cq___26;

struct io_context___26 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___26 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___27 {
	struct bio___27 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___27 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___27 *bip_vec;
	struct bio_vec___27 bip_inline_vecs[0];
};

struct bio_list___26 {
	struct bio___27 *head;
	struct bio___27 *tail;
};

struct bio_set___27 {
	struct kmem_cache___158 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___26 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___172 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___172 *ia_file;
};

struct dquot___172 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___175 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___172 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___172 {
	int qf_fmt_id;
	const struct quota_format_ops___172 *qf_ops;
	struct module___91 *qf_owner;
	struct quota_format_type___172 *qf_next;
};

struct quota_format_ops___172 {
	int (*check_quota_file)(struct super_block___172 *, int);
	int (*read_file_info)(struct super_block___172 *, int);
	int (*write_file_info)(struct super_block___172 *, int);
	int (*free_file_info)(struct super_block___172 *, int);
	int (*read_dqblk)(struct dquot___172 *);
	int (*commit_dqblk)(struct dquot___172 *);
	int (*release_dqblk)(struct dquot___172 *);
};

struct dquot_operations___172 {
	int (*write_dquot)(struct dquot___172 *);
	struct dquot___172 * (*alloc_dquot)(struct super_block___172 *, int);
	void (*destroy_dquot)(struct dquot___172 *);
	int (*acquire_dquot)(struct dquot___172 *);
	int (*release_dquot)(struct dquot___172 *);
	int (*mark_dirty)(struct dquot___172 *);
	int (*write_info)(struct super_block___172 *, int);
	qsize_t * (*get_reserved_space)(struct inode___172 *);
};

struct quotactl_ops___172 {
	int (*quota_on)(struct super_block___172 *, int, int, struct path___172 *);
	int (*quota_on_meta)(struct super_block___172 *, int, int);
	int (*quota_off)(struct super_block___172 *, int);
	int (*quota_sync)(struct super_block___172 *, int);
	int (*get_info)(struct super_block___172 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___172 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___172 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___172 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___172 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___172 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___172 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___172 *, unsigned int);
};

struct address_space_operations___172 {
	int (*writepage)(struct page___171 *, struct writeback_control *);
	int (*readpage)(struct file___172 *, struct page___171 *);
	int (*writepages)(struct address_space___172 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___171 *);
	int (*readpages)(struct file___172 *, struct address_space___172 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___172 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___171 **, void **);
	int (*write_end)(struct file___172 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___171 *, void *);
	sector_t (*bmap)(struct address_space___172 *, sector_t);
	void (*invalidatepage)(struct page___171 *, long unsigned int);
	int (*releasepage)(struct page___171 *, gfp_t);
	void (*freepage)(struct page___171 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___172 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___172 *, struct page___171 *, struct page___171 *, enum migrate_mode);
	int (*launder_page)(struct page___171 *);
	int (*is_partially_uptodate)(struct page___171 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___171 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___172 *, struct page___171 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___172 *, sector_t *);
	void (*swap_deactivate)(struct file___172 *);
	void (*invalidatepage_range)(struct page___171 *, unsigned int, unsigned int);
};

struct bdi_writeback___36 {
	struct backing_dev_info___36 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___36 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___36 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___137 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___172 *debug_dir;
	struct dentry___172 *debug_stats;
};

struct hd_struct___27 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___137 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___27;

struct block_device_operations___26;

struct gendisk___27 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___27 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___27 *part_tbl;
	struct hd_struct___27 part0;
	const struct block_device_operations___26 *fops;
	struct request_queue___26 *queue;
	void *private_data;
	int flags;
	struct device___137 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___26 {
	struct request_queue___26 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___26(struct request_queue___26 *);

typedef void make_request_fn___26(struct request_queue___26 *, struct bio___27 *);

struct request___26;

typedef int prep_rq_fn___26(struct request_queue___26 *, struct request___26 *);

struct bvec_merge_data___26;

typedef int merge_bvec_fn___26(struct request_queue___26 *, struct bvec_merge_data___26 *, struct bio_vec___27 *);

typedef void softirq_done_fn___26(struct request___26 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___26(struct request___26 *);

typedef int dma_drain_needed_fn___26(struct request___26 *);

typedef int lld_busy_fn___26(struct request_queue___26 *);

struct bsg_class_device___26 {
	struct device___137 *class_dev;
	struct device___137 *parent;
	int minor;
	struct request_queue___26 *queue;
	struct kref ref;
	void (*release)(struct device___137 *);
};

typedef void unprep_rq_fn___26(struct request_queue___26 *, struct request___26 *);

struct elevator_queue___26;

struct blk_mq_ops___5;

struct blk_mq_ctx___5;

struct blk_mq_hw_ctx___5;

struct blk_queue_tag___26;

struct blk_trace___6;

struct blk_mq_tag_set___5;

struct blk_flush_queue___5;

struct request_queue___26 {
	struct list_head queue_head;
	struct request___26 *last_merge;
	struct elevator_queue___26 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___26 root_rl;
	request_fn_proc___26 *request_fn;
	make_request_fn___26 *make_request_fn;
	prep_rq_fn___26 *prep_rq_fn;
	merge_bvec_fn___26 *merge_bvec_fn;
	softirq_done_fn___26 *softirq_done_fn;
	rq_timed_out_fn___26 *rq_timed_out_fn;
	dma_drain_needed_fn___26 *dma_drain_needed;
	lld_busy_fn___26 *lld_busy_fn;
	struct blk_mq_ops___5 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___5 *queue_ctx;
		struct {
			struct blk_mq_ctx___5 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___5 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___26 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___36 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___137 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___26 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___6 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___26 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___175 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___26 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___26 *unprep_rq_fn;
	struct blk_mq_tag_set___5 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___27 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___5 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___172 {
	struct dentry___172 * (*lookup)(struct inode___172 *, struct dentry___172 *, unsigned int);
	void * (*follow_link)(struct dentry___172 *, struct nameidata *);
	int (*permission)(struct inode___172 *, int);
	struct posix_acl * (*get_acl)(struct inode___172 *, int);
	int (*readlink)(struct dentry___172 *, char *, int);
	void (*put_link)(struct dentry___172 *, struct nameidata *, void *);
	int (*create)(struct inode___172 *, struct dentry___172 *, umode_t, bool);
	int (*link)(struct dentry___172 *, struct inode___172 *, struct dentry___172 *);
	int (*unlink)(struct inode___172 *, struct dentry___172 *);
	int (*symlink)(struct inode___172 *, struct dentry___172 *, const char *);
	int (*mkdir)(struct inode___172 *, struct dentry___172 *, umode_t);
	int (*rmdir)(struct inode___172 *, struct dentry___172 *);
	int (*mknod)(struct inode___172 *, struct dentry___172 *, umode_t, dev_t);
	int (*rename)(struct inode___172 *, struct dentry___172 *, struct inode___172 *, struct dentry___172 *);
	int (*setattr)(struct dentry___172 *, struct iattr___172 *);
	int (*getattr)(struct vfsmount *, struct dentry___172 *, struct kstat *);
	int (*setxattr)(struct dentry___172 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___172 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___172 *, char *, size_t);
	int (*removexattr)(struct dentry___172 *, const char *);
	int (*fiemap)(struct inode___172 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___172 *, struct timespec *, int);
	int (*atomic_open)(struct inode___172 *, struct dentry___172 *, struct file___172 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___102;

struct file_operations___172 {
	struct module___91 *owner;
	loff_t (*llseek)(struct file___172 *, loff_t, int);
	ssize_t (*read)(struct file___172 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___172 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___172 *, void *, filldir_t);
	unsigned int (*poll)(struct file___172 *, struct poll_table_struct___102 *);
	long int (*unlocked_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___172 *, struct vm_area_struct___179 *);
	int (*open)(struct inode___172 *, struct file___172 *);
	int (*flush)(struct file___172 *, fl_owner_t);
	int (*release)(struct inode___172 *, struct file___172 *);
	int (*fsync)(struct file___172 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___172 *, int);
	int (*lock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*sendpage)(struct file___172 *, struct page___171 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___172 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___172 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___172 *, long int, struct file_lock___172 **, void **);
		struct {
			int (*setlease)(struct file___172 *, long int, struct file_lock___172 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___172 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___172 *);
};

struct fasync_struct___172;

struct file_lock_operations___172;

struct lock_manager_operations___172;

struct file_lock___172 {
	struct file_lock___172 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___85 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___172 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___172 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___172 *fl_ops;
	const struct lock_manager_operations___172 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___172 {
	void (*fl_copy_lock)(struct file_lock___172 *, struct file_lock___172 *);
	void (*fl_release_private)(struct file_lock___172 *);
};

struct lock_manager_operations___172 {
	int (*lm_compare_owner)(struct file_lock___172 *, struct file_lock___172 *);
	long unsigned int (*lm_owner_key)(struct file_lock___172 *);
	void (*lm_notify)(struct file_lock___172 *);
	int (*lm_grant)(struct file_lock___172 *, struct file_lock___172 *, int);
	void (*lm_break)(struct file_lock___172 *);
	int (*lm_change)(struct file_lock___172 **, int);
};

struct fasync_struct___172 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___172 *fa_next;
	struct file___172 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___172 {
	const char *name;
	int fs_flags;
	struct dentry___172 * (*mount)(struct file_system_type___172 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___172 *);
	struct module___91 *owner;
	struct file_system_type___172 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___172 {
	struct inode___172 * (*alloc_inode)(struct super_block___172 *);
	void (*destroy_inode)(struct inode___172 *);
	void (*dirty_inode)(struct inode___172 *, int);
	int (*write_inode)(struct inode___172 *, struct writeback_control *);
	int (*drop_inode)(struct inode___172 *);
	void (*evict_inode)(struct inode___172 *);
	void (*put_super)(struct super_block___172 *);
	int (*sync_fs)(struct super_block___172 *, int);
	int (*freeze_fs)(struct super_block___172 *);
	int (*unfreeze_fs)(struct super_block___172 *);
	int (*statfs)(struct dentry___172 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___172 *, int *, char *);
	void (*umount_begin)(struct super_block___172 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___172 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___172 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___172 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___172 *);
	ssize_t (*quota_read)(struct super_block___172 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___172 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___172 *);
	int (*bdev_try_to_free_page)(struct super_block___172 *, struct page___171 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___172 *);
	void (*free_cached_objects)(struct super_block___172 *, int);
};

typedef void (*poll_queue_proc___104)(struct file___172 *, wait_queue_head_t *, struct poll_table_struct___102 *);

struct poll_table_struct___102 {
	poll_queue_proc___104 _qproc;
	long unsigned int _key;
};

struct xol_area___171 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___171 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___157;

struct memcg_cache_params___158;

struct kmem_cache___158 {
	struct kmem_cache_cpu___157 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___158 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___149;

struct vm_operations_struct___152 {
	void (*open)(struct vm_area_struct___179 *);
	void (*close)(struct vm_area_struct___179 *);
	int (*fault)(struct vm_area_struct___179 *, struct vm_fault___149 *);
	int (*page_mkwrite)(struct vm_area_struct___179 *, struct vm_fault___149 *);
	int (*access)(struct vm_area_struct___179 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___179 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___179 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___179 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___179 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___174 {
	struct task_struct___174 *task;
	struct core_thread___174 *next;
};

struct core_state___174 {
	atomic_t nr_threads;
	struct core_thread___174 dumper;
	struct completion startup;
};

struct signal_struct___174 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___174 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___174 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___85 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___175 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___149 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___171 *page;
};

struct io_cq___26 {
	struct request_queue___26 *q;
	struct io_context___26 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___158 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kmem_cache_cpu___157 {
	void **freelist;
	long unsigned int tid;
	struct page___171 *page;
	struct page___171 *partial;
};

struct memcg_cache_params___158 {
	bool is_root_cache;
	union {
		struct kmem_cache___158 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___158 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___137 *, char *);
	ssize_t (*store)(struct bus_type___137 *, const char *, size_t);
};

struct device_attribute___137;

struct driver_attribute___137;

struct bus_type___137 {
	const char *name;
	const char *dev_name;
	struct device___137 *dev_root;
	struct bus_attribute___137 *bus_attrs;
	struct device_attribute___137 *dev_attrs;
	struct driver_attribute___137 *drv_attrs;
	const struct attribute_group___129 **bus_groups;
	const struct attribute_group___129 **dev_groups;
	const struct attribute_group___129 **drv_groups;
	int (*match)(struct device___137 *, struct device_driver___137 *);
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	int (*probe)(struct device___137 *);
	int (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*online)(struct device___137 *);
	int (*offline)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct device___137 *, struct device_attribute___137 *, char *);
	ssize_t (*store)(struct device___137 *, struct device_attribute___137 *, const char *, size_t);
};

struct driver_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___137 *, char *);
	ssize_t (*store)(struct device_driver___137 *, const char *, size_t);
};

struct device_driver___137 {
	const char *name;
	struct bus_type___137 *bus;
	struct module___91 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___137 *);
	int (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	const struct attribute_group___129 **groups;
	const struct dev_pm_ops___137 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___137 {
	const char *name;
	const struct attribute_group___129 **groups;
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
};

struct class_attribute___137;

struct class___137 {
	const char *name;
	struct module___91 *owner;
	struct class_attribute___137 *class_attrs;
	struct device_attribute___137 *dev_attrs;
	const struct attribute_group___129 **dev_groups;
	struct bin_attribute___131 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *);
	void (*class_release)(struct class___137 *);
	void (*dev_release)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
	struct subsys_private *p;
};

struct class_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct class___137 *, struct class_attribute___137 *, char *);
	ssize_t (*store)(struct class___137 *, struct class_attribute___137 *, const char *, size_t);
	const void * (*namespace)(struct class___137 *, const struct class_attribute___137 *);
};

struct device_rh___137 {
	struct dev_pm_info_rh___137 power;
};

struct disk_part_tbl___27 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___27 *last_lookup;
	struct hd_struct___27 *part[0];
};

struct block_device_operations___26 {
	int (*open)(struct block_device___172 *, fmode_t);
	void (*release)(struct gendisk___27 *, fmode_t);
	int (*ioctl)(struct block_device___172 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___172 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___172 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___27 *, unsigned int);
	int (*media_changed)(struct gendisk___27 *);
	void (*unlock_native_capacity)(struct gendisk___27 *);
	int (*revalidate_disk)(struct gendisk___27 *);
	int (*getgeo)(struct block_device___172 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___172 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___91 *owner;
};

enum {
	__PERCPU_REF_ATOMIC = 1,
	__PERCPU_REF_DEAD = 2,
	__PERCPU_REF_ATOMIC_DEAD = 3,
	__PERCPU_REF_FLAG_BITS = 2,
};

enum {
	PERCPU_REF_INIT_ATOMIC = 1,
	PERCPU_REF_INIT_DEAD = 2,
};

typedef void rq_end_io_fn___26(struct request___26 *, int);

struct request___26 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___26 *q;
	struct blk_mq_ctx___5 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___27 *bio;
	struct bio___27 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___26 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___26 *saved_end_io;
		} flush;
	};
	struct gendisk___27 *rq_disk;
	struct hd_struct___27 *part;
	long unsigned int start_time;
	struct request_list___26 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___26 *end_io;
	void *end_io_data;
	struct request___26 *next_rq;
};

struct blk_mq_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___26 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___26(struct request_queue___26 *, struct request___26 **, struct bio___27 *);

typedef void elevator_merge_req_fn___26(struct request_queue___26 *, struct request___26 *, struct request___26 *);

typedef void elevator_merged_fn___26(struct request_queue___26 *, struct request___26 *, int);

typedef int elevator_allow_merge_fn___26(struct request_queue___26 *, struct request___26 *, struct bio___27 *);

typedef void elevator_bio_merged_fn___26(struct request_queue___26 *, struct request___26 *, struct bio___27 *);

typedef int elevator_dispatch_fn___26(struct request_queue___26 *, int);

typedef void elevator_add_req_fn___26(struct request_queue___26 *, struct request___26 *);

typedef struct request___26 *elevator_request_list_fn___26(struct request_queue___26 *, struct request___26 *);

typedef void elevator_completed_req_fn___26(struct request_queue___26 *, struct request___26 *);

typedef int elevator_may_queue_fn___26(struct request_queue___26 *, int);

typedef void elevator_init_icq_fn___26(struct io_cq___26 *);

typedef void elevator_exit_icq_fn___26(struct io_cq___26 *);

typedef int elevator_set_req_fn___26(struct request_queue___26 *, struct request___26 *, struct bio___27 *, gfp_t);

typedef void elevator_put_req_fn___26(struct request___26 *);

typedef void elevator_activate_req_fn___26(struct request_queue___26 *, struct request___26 *);

typedef void elevator_deactivate_req_fn___26(struct request_queue___26 *, struct request___26 *);

struct elevator_type___26;

typedef int elevator_init_fn___26(struct request_queue___26 *, struct elevator_type___26 *);

typedef void elevator_exit_fn___26(struct elevator_queue___26 *);

struct elevator_ops___26 {
	elevator_merge_fn___26 *elevator_merge_fn;
	elevator_merged_fn___26 *elevator_merged_fn;
	elevator_merge_req_fn___26 *elevator_merge_req_fn;
	elevator_allow_merge_fn___26 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___26 *elevator_bio_merged_fn;
	elevator_dispatch_fn___26 *elevator_dispatch_fn;
	elevator_add_req_fn___26 *elevator_add_req_fn;
	elevator_activate_req_fn___26 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___26 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___26 *elevator_completed_req_fn;
	elevator_request_list_fn___26 *elevator_former_req_fn;
	elevator_request_list_fn___26 *elevator_latter_req_fn;
	elevator_init_icq_fn___26 *elevator_init_icq_fn;
	elevator_exit_icq_fn___26 *elevator_exit_icq_fn;
	elevator_set_req_fn___26 *elevator_set_req_fn;
	elevator_put_req_fn___26 *elevator_put_req_fn;
	elevator_may_queue_fn___26 *elevator_may_queue_fn;
	elevator_init_fn___26 *elevator_init_fn;
	elevator_exit_fn___26 *elevator_exit_fn;
};

struct elv_fs_entry___26;

struct elevator_type___26 {
	struct kmem_cache___158 *icq_cache;
	struct elevator_ops___26 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___26 *elevator_attrs;
	char elevator_name[16];
	struct module___91 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___26 {
	struct elevator_type___26 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___175 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___26 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___26 *, char *);
	ssize_t (*store)(struct elevator_queue___26 *, const char *, size_t);
};

struct bvec_merge_data___26 {
	struct block_device___172 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___26 {
	struct request___26 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___5;

typedef int queue_rq_fn___5(struct blk_mq_hw_ctx___5 *, const struct blk_mq_queue_data___5 *);

typedef struct blk_mq_hw_ctx___5 *map_queue_fn___5(struct request_queue___26 *, const int);

typedef enum blk_eh_timer_return timeout_fn___5(struct request___26 *, bool);

typedef int init_request_fn___5(void *, struct request___26 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___5(void *, struct request___26 *, unsigned int, unsigned int);

typedef int init_hctx_fn___5(struct blk_mq_hw_ctx___5 *, void *, unsigned int);

typedef void exit_hctx_fn___5(struct blk_mq_hw_ctx___5 *, unsigned int);

struct blk_mq_ops___5 {
	queue_rq_fn___5 *queue_rq;
	map_queue_fn___5 *map_queue;
	union {
		timeout_fn___5 *timeout;
		struct {
			rq_timed_out_fn___26 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___26 *complete;
	init_request_fn___5 *init_request;
	exit_request_fn___5 *exit_request;
	init_hctx_fn___5 *init_hctx;
	exit_hctx_fn___5 *exit_hctx;
};

struct blk_mq_tags___2;

struct blk_mq_hw_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___26 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___5 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___26 **padding2;
		struct {
			struct request___26 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags___2 *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___5 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan___7;

struct blk_trace___6 {
	int trace_state;
	struct rchan___7 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___172 *dir;
	struct dentry___172 *dropped_file;
	struct dentry___172 *msg_file;
	atomic_t dropped;
};

struct blk_mq_tag_set___5 {
	struct blk_mq_ops___5 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___2 **tags;
	struct mutex___175 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___5 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___26 *flush_rq;
	struct request___26 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct rchan_buf___7 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___7 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___172 *dentry;
	struct kref kref;
	struct page___171 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___7;

struct rchan___7 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___7 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___7 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___172 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___7 {
	int (*subbuf_start)(struct rchan_buf___7 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___7 *, struct file___172 *);
	void (*buf_unmapped)(struct rchan_buf___7 *, struct file___172 *);
	struct dentry___172 * (*create_buf_file)(const char *, struct dentry___172 *, umode_t, struct rchan_buf___7 *, int *);
	int (*remove_buf_file)(struct dentry___172 *);
};

struct blk_mq_tags___2 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct blk_mq_bitmap_tags bitmap_tags;
	struct blk_mq_bitmap_tags breserved_tags;
	struct request___26 **rqs;
	struct list_head page_list;
	cpumask_var_t cpumask;
};

struct blk_mq_queue_data___5 {
	struct request___26 *rq;
	struct list_head *list;
	bool last;
};

typedef void busy_iter_fn(struct blk_mq_hw_ctx___5 *, struct request___26 *, void *, bool);

enum {
	BLK_MQ_RQ_QUEUE_OK = 0,
	BLK_MQ_RQ_QUEUE_BUSY = 1,
	BLK_MQ_RQ_QUEUE_ERROR = 2,
	BLK_MQ_F_SHOULD_MERGE = 1,
	BLK_MQ_F_SHOULD_SORT = 2,
	BLK_MQ_F_TAG_SHARED = 4,
	BLK_MQ_F_SG_MERGE = 8,
	BLK_MQ_F_DEFER_ISSUE = 32,
	BLK_MQ_S_STOPPED = 0,
	BLK_MQ_S_TAG_ACTIVE = 1,
	BLK_MQ_MAX_DEPTH = 10240,
	BLK_MQ_CPU_WORK_BATCH = 8,
};

enum {
	BLK_MQ_UNIQUE_TAG_BITS = 16,
	BLK_MQ_UNIQUE_TAG_MASK = 65535,
};

struct blk_mq_alloc_data {
	struct request_queue___26 *q;
	gfp_t gfp;
	bool reserved;
	struct blk_mq_ctx___5 *ctx;
	struct blk_mq_hw_ctx___5 *hctx;
};

enum {
	BLK_MQ_TAG_FAIL = 4294967295,
	BLK_MQ_TAG_MIN = 1,
	BLK_MQ_TAG_MAX = 4294967294,
};

struct blk_mq_timeout_data {
	long unsigned int next;
	unsigned int next_set;
};

struct blk_map_ctx {
	struct blk_mq_hw_ctx___5 *hctx;
	struct blk_mq_ctx___5 *ctx;
};

struct page___172;

typedef struct page___172 *pgtable_t___172;

struct address_space___173;

struct kmem_cache___159;

struct page___172 {
	long unsigned int flags;
	struct address_space___173 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___172 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___172 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___159 *slab_cache;
		struct page___172 *first_page;
	};
	long: 64;
};

struct task_struct___175;

struct pv_cpu_ops___175 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___76 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___76 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___175 *);
	void (*end_context_switch)(struct task_struct___175 *);
};

struct mutex___176 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___175 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___168 {
	struct page___172 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___180;

struct signal_struct___175;

struct bio_list___27;

struct backing_dev_info___37;

struct io_context___27;

struct task_struct___175 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___175 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___180 *mm;
	struct mm_struct___180 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___175 *real_parent;
	struct task_struct___175 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___175 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___85 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___175 = 0,
		VTIME_USER___175 = 1,
		VTIME_SYS___175 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___76 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___175 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___27 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___37 *backing_dev_info;
	struct io_context___27 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___176 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___168 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___180 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___180 *, struct mm_struct___180 *);
	void (*dup_mmap)(struct mm_struct___180 *, struct mm_struct___180 *);
	void (*exit_mmap)(struct mm_struct___180 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___180 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___180 *);
	void (*pgd_free)(struct mm_struct___180 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___180 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___180 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___180 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___180 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___180 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___180 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___180 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___180 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___180 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___180 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___180 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___176 lock;
	void *vdso;
} mm_context_t___176;

struct xol_area___172;

struct uprobes_state___172 {
	struct xol_area___172 *xol_area;
};

struct vm_area_struct___180;

struct file___173;

struct core_state___175;

struct mm_struct___180 {
	struct vm_area_struct___180 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___180 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___180 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___176 context;
	long unsigned int flags;
	struct core_state___175 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___175 *owner;
	struct file___173 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___172 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___92;

struct module_kobject___91 {
	struct kobject___19 kobj;
	struct module___92 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___91;

struct module___92 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___91 mkobj;
	struct module_attribute___91 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___175 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___175;

struct lruvec___175 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___175 *zone;
};

struct pglist_data___175;

struct zone___175 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___175 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___175 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___175 {
	struct zone___175 *zone;
	int zone_idx;
};

struct zonelist___175 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___175 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___175 {
	struct zone___175 node_zones[4];
	struct zonelist___175 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___175 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___138;

struct dev_pm_ops___138 {
	int (*prepare)(struct device___138 *);
	void (*complete)(struct device___138 *);
	int (*suspend)(struct device___138 *);
	int (*resume)(struct device___138 *);
	int (*freeze)(struct device___138 *);
	int (*thaw)(struct device___138 *);
	int (*poweroff)(struct device___138 *);
	int (*restore)(struct device___138 *);
	int (*suspend_late)(struct device___138 *);
	int (*resume_early)(struct device___138 *);
	int (*freeze_late)(struct device___138 *);
	int (*thaw_early)(struct device___138 *);
	int (*poweroff_late)(struct device___138 *);
	int (*restore_early)(struct device___138 *);
	int (*suspend_noirq)(struct device___138 *);
	int (*resume_noirq)(struct device___138 *);
	int (*freeze_noirq)(struct device___138 *);
	int (*thaw_noirq)(struct device___138 *);
	int (*poweroff_noirq)(struct device___138 *);
	int (*restore_noirq)(struct device___138 *);
	int (*runtime_suspend)(struct device___138 *);
	int (*runtime_resume)(struct device___138 *);
	int (*runtime_idle)(struct device___138 *);
};

struct device_type___138;

struct bus_type___138;

struct device_driver___138;

struct dev_pm_domain___138;

struct class___138;

struct attribute_group___130;

struct device_rh___138;

struct device___138 {
	struct device___138 *parent;
	struct device_private *p;
	struct kobject___19 kobj;
	const char *init_name;
	const struct device_type___138 *type;
	struct mutex___176 mutex;
	struct bus_type___138 *bus;
	struct device_driver___138 *driver;
	void *platform_data;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___138 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___56 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___11 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___138 *class;
	const struct attribute_group___130 **groups;
	void (*release)(struct device___138 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___138 *device_rh;
};

struct dev_pm_info_rh___138 {
	void (*set_latency_tolerance)(struct device___138 *, s32);
};

struct dev_pm_domain___138 {
	struct dev_pm_ops___138 ops;
};

struct smp_ops___175 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___175 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___132;

struct attribute_group___130 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___132 **bin_attrs;
};

struct bin_attribute___132 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___173 *, struct kobject___19 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___173 *, struct kobject___19 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	int (*mmap)(struct file___173 *, struct kobject___19 *, struct bin_attribute___132 *, struct vm_area_struct___180 *);
};

struct dentry___173;

struct path___173 {
	struct vfsmount *mnt;
	struct dentry___173 *dentry;
};

struct inode___173;

struct file_operations___173;

struct file___173 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___173 f_path;
	struct inode___173 *f_inode;
	const struct file_operations___173 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___173 *f_mapping;
	struct mutex___176 f_pos_lock;
};

struct vm_operations_struct___153;

struct vm_area_struct___180 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___180 *vm_next;
	struct vm_area_struct___180 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___180 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___153 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___173 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___91 *, struct module_kobject___91 *, char *);
	ssize_t (*store)(struct module_attribute___91 *, struct module_kobject___91 *, const char *, size_t);
	void (*setup)(struct module___92 *, const char *);
	int (*test)(struct module___92 *);
	void (*free)(struct module___92 *);
};

struct xol_area___172 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___172 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___158;

struct memcg_cache_params___159;

struct kmem_cache___159 {
	struct kmem_cache_cpu___158 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___19 kobj;
	struct memcg_cache_params___159 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___173;

struct address_space___173 {
	struct inode___173 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___176 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___173 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___37 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___150;

struct vm_operations_struct___153 {
	void (*open)(struct vm_area_struct___180 *);
	void (*close)(struct vm_area_struct___180 *);
	int (*fault)(struct vm_area_struct___180 *, struct vm_fault___150 *);
	int (*page_mkwrite)(struct vm_area_struct___180 *, struct vm_fault___150 *);
	int (*access)(struct vm_area_struct___180 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___180 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___180 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___180 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___180 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___175 {
	struct task_struct___175 *task;
	struct core_thread___175 *next;
};

struct core_state___175 {
	atomic_t nr_threads;
	struct core_thread___175 dumper;
	struct completion startup;
};

struct signal_struct___175 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___175 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___175 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___85 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___176 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___28;

struct bio_list___27 {
	struct bio___28 *head;
	struct bio___28 *tail;
};

struct bdi_writeback___37 {
	struct backing_dev_info___37 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___37 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___37 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___138 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___173 *debug_dir;
	struct dentry___173 *debug_stats;
};

struct io_cq___27;

struct io_context___27 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___27 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___158 {
	void **freelist;
	long unsigned int tid;
	struct page___172 *page;
	struct page___172 *partial;
};

struct memcg_cache_params___159 {
	bool is_root_cache;
	union {
		struct kmem_cache___159 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___159 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___138 *, char *);
	ssize_t (*store)(struct bus_type___138 *, const char *, size_t);
};

struct device_attribute___138;

struct driver_attribute___138;

struct bus_type___138 {
	const char *name;
	const char *dev_name;
	struct device___138 *dev_root;
	struct bus_attribute___138 *bus_attrs;
	struct device_attribute___138 *dev_attrs;
	struct driver_attribute___138 *drv_attrs;
	const struct attribute_group___130 **bus_groups;
	const struct attribute_group___130 **dev_groups;
	const struct attribute_group___130 **drv_groups;
	int (*match)(struct device___138 *, struct device_driver___138 *);
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	int (*probe)(struct device___138 *);
	int (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*online)(struct device___138 *);
	int (*offline)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct device___138 *, struct device_attribute___138 *, char *);
	ssize_t (*store)(struct device___138 *, struct device_attribute___138 *, const char *, size_t);
};

struct driver_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___138 *, char *);
	ssize_t (*store)(struct device_driver___138 *, const char *, size_t);
};

struct device_driver___138 {
	const char *name;
	struct bus_type___138 *bus;
	struct module___92 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___138 *);
	int (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	const struct attribute_group___130 **groups;
	const struct dev_pm_ops___138 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___138 {
	const char *name;
	const struct attribute_group___130 **groups;
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
};

struct class_attribute___138;

struct class___138 {
	const char *name;
	struct module___92 *owner;
	struct class_attribute___138 *class_attrs;
	struct device_attribute___138 *dev_attrs;
	const struct attribute_group___130 **dev_groups;
	struct bin_attribute___132 *dev_bin_attrs;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *);
	void (*class_release)(struct class___138 *);
	void (*dev_release)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
	struct subsys_private *p;
};

struct class_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct class___138 *, struct class_attribute___138 *, char *);
	ssize_t (*store)(struct class___138 *, struct class_attribute___138 *, const char *, size_t);
	const void * (*namespace)(struct class___138 *, const struct class_attribute___138 *);
};

struct device_rh___138 {
	struct dev_pm_info_rh___138 power;
};

struct dentry_operations___173;

struct super_block___173;

struct dentry___173 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___173 *d_parent;
	struct qstr d_name;
	struct inode___173 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___173 *d_op;
	struct super_block___173 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___173;

struct file_lock___173;

struct dquot___173;

struct block_device___173;

struct inode___173 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___173 *i_op;
	struct super_block___173 *i_sb;
	struct address_space___173 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___176 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___173 *i_fop;
	struct file_lock___173 *i_flock;
	struct address_space___173 i_data;
	struct dquot___173 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___173 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___173 {
	int (*d_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_hash)(const struct dentry___173 *, struct qstr *);
	int (*d_compare)(const struct dentry___173 *, const struct dentry___173 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___173 *);
	void (*d_release)(struct dentry___173 *);
	void (*d_prune)(struct dentry___173 *);
	void (*d_iput)(struct dentry___173 *, struct inode___173 *);
	char * (*d_dname)(struct dentry___173 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___173 *);
	int (*d_manage)(struct dentry___173 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___173;

struct mem_dqinfo___173 {
	struct quota_format_type___173 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___173;

struct quota_info___173 {
	unsigned int flags;
	struct mutex___176 dqio_mutex;
	struct mutex___176 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___173 *files[2];
	struct mem_dqinfo___173 info[2];
	const struct quota_format_ops___173 *ops[2];
};

struct file_system_type___173;

struct super_operations___173;

struct dquot_operations___173;

struct quotactl_ops___173;

struct super_block___173 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___173 *s_type;
	const struct super_operations___173 *s_op;
	const struct dquot_operations___173 *dq_op;
	const struct quotactl_ops___173 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___173 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___173 *s_bdev;
	struct backing_dev_info___37 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___173 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___176 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___173 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___28(struct bio___28 *, int);

struct bio_vec___28 {
	struct page___172 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___28;

struct bio_set___28;

struct bio___28 {
	sector_t bi_sector;
	struct bio___28 *bi_next;
	struct block_device___173 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___28 *bi_end_io;
	void *bi_private;
	struct io_context___27 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___28 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___28 *bi_io_vec;
	struct bio_set___28 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___28 bi_inline_vecs[0];
};

struct hd_struct___28;

struct gendisk___28;

struct request_queue___27;

struct block_device___173 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___173 *bd_inode;
	struct super_block___173 *bd_super;
	struct mutex___176 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___173 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___28 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___28 *bd_disk;
	struct request_queue___27 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___176 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___28 {
	struct bio___28 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___28 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___28 *bip_vec;
	struct bio_vec___28 bip_inline_vecs[0];
};

struct bio_set___28 {
	struct kmem_cache___159 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___27 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___173 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___173 *ia_file;
};

struct dquot___173 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___176 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___173 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___173 {
	int qf_fmt_id;
	const struct quota_format_ops___173 *qf_ops;
	struct module___92 *qf_owner;
	struct quota_format_type___173 *qf_next;
};

struct quota_format_ops___173 {
	int (*check_quota_file)(struct super_block___173 *, int);
	int (*read_file_info)(struct super_block___173 *, int);
	int (*write_file_info)(struct super_block___173 *, int);
	int (*free_file_info)(struct super_block___173 *, int);
	int (*read_dqblk)(struct dquot___173 *);
	int (*commit_dqblk)(struct dquot___173 *);
	int (*release_dqblk)(struct dquot___173 *);
};

struct dquot_operations___173 {
	int (*write_dquot)(struct dquot___173 *);
	struct dquot___173 * (*alloc_dquot)(struct super_block___173 *, int);
	void (*destroy_dquot)(struct dquot___173 *);
	int (*acquire_dquot)(struct dquot___173 *);
	int (*release_dquot)(struct dquot___173 *);
	int (*mark_dirty)(struct dquot___173 *);
	int (*write_info)(struct super_block___173 *, int);
	qsize_t * (*get_reserved_space)(struct inode___173 *);
};

struct quotactl_ops___173 {
	int (*quota_on)(struct super_block___173 *, int, int, struct path___173 *);
	int (*quota_on_meta)(struct super_block___173 *, int, int);
	int (*quota_off)(struct super_block___173 *, int);
	int (*quota_sync)(struct super_block___173 *, int);
	int (*get_info)(struct super_block___173 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___173 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___173 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___173 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___173 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___173 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___173 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___173 *, unsigned int);
};

struct address_space_operations___173 {
	int (*writepage)(struct page___172 *, struct writeback_control *);
	int (*readpage)(struct file___173 *, struct page___172 *);
	int (*writepages)(struct address_space___173 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___172 *);
	int (*readpages)(struct file___173 *, struct address_space___173 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___173 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___172 **, void **);
	int (*write_end)(struct file___173 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___172 *, void *);
	sector_t (*bmap)(struct address_space___173 *, sector_t);
	void (*invalidatepage)(struct page___172 *, long unsigned int);
	int (*releasepage)(struct page___172 *, gfp_t);
	void (*freepage)(struct page___172 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___173 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___173 *, struct page___172 *, struct page___172 *, enum migrate_mode);
	int (*launder_page)(struct page___172 *);
	int (*is_partially_uptodate)(struct page___172 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___172 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___173 *, struct page___172 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___173 *, sector_t *);
	void (*swap_deactivate)(struct file___173 *);
	void (*invalidatepage_range)(struct page___172 *, unsigned int, unsigned int);
};

struct hd_struct___28 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___138 __dev;
	struct kobject___19 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___28;

struct block_device_operations___27;

struct gendisk___28 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___28 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___28 *part_tbl;
	struct hd_struct___28 part0;
	const struct block_device_operations___27 *fops;
	struct request_queue___27 *queue;
	void *private_data;
	int flags;
	struct device___138 *driverfs_dev;
	struct kobject___19 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___3 *integrity;
	int node_id;
};

struct request_list___27 {
	struct request_queue___27 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___27(struct request_queue___27 *);

typedef void make_request_fn___27(struct request_queue___27 *, struct bio___28 *);

struct request___27;

typedef int prep_rq_fn___27(struct request_queue___27 *, struct request___27 *);

struct bvec_merge_data___27;

typedef int merge_bvec_fn___27(struct request_queue___27 *, struct bvec_merge_data___27 *, struct bio_vec___28 *);

typedef void softirq_done_fn___27(struct request___27 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___27(struct request___27 *);

typedef int dma_drain_needed_fn___27(struct request___27 *);

typedef int lld_busy_fn___27(struct request_queue___27 *);

struct bsg_class_device___27 {
	struct device___138 *class_dev;
	struct device___138 *parent;
	int minor;
	struct request_queue___27 *queue;
	struct kref ref;
	void (*release)(struct device___138 *);
};

typedef void unprep_rq_fn___27(struct request_queue___27 *, struct request___27 *);

struct elevator_queue___27;

struct blk_mq_ops___6;

struct blk_mq_ctx___6;

struct blk_mq_hw_ctx___6;

struct blk_queue_tag___27;

struct blk_mq_tag_set___6;

struct blk_flush_queue___6;

struct request_queue___27 {
	struct list_head queue_head;
	struct request___27 *last_merge;
	struct elevator_queue___27 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___27 root_rl;
	request_fn_proc___27 *request_fn;
	make_request_fn___27 *make_request_fn;
	prep_rq_fn___27 *prep_rq_fn;
	merge_bvec_fn___27 *merge_bvec_fn;
	softirq_done_fn___27 *softirq_done_fn;
	rq_timed_out_fn___27 *rq_timed_out_fn;
	dma_drain_needed_fn___27 *dma_drain_needed;
	lld_busy_fn___27 *lld_busy_fn;
	struct blk_mq_ops___6 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___6 *queue_ctx;
		struct {
			struct blk_mq_ctx___6 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___6 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___27 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___37 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___19 kobj;
	struct kobject___19 mq_kobj;
	struct device___138 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___27 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___27 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___176 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___27 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___27 *unprep_rq_fn;
	struct blk_mq_tag_set___6 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___28 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___6 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___173 {
	struct dentry___173 * (*lookup)(struct inode___173 *, struct dentry___173 *, unsigned int);
	void * (*follow_link)(struct dentry___173 *, struct nameidata *);
	int (*permission)(struct inode___173 *, int);
	struct posix_acl * (*get_acl)(struct inode___173 *, int);
	int (*readlink)(struct dentry___173 *, char *, int);
	void (*put_link)(struct dentry___173 *, struct nameidata *, void *);
	int (*create)(struct inode___173 *, struct dentry___173 *, umode_t, bool);
	int (*link)(struct dentry___173 *, struct inode___173 *, struct dentry___173 *);
	int (*unlink)(struct inode___173 *, struct dentry___173 *);
	int (*symlink)(struct inode___173 *, struct dentry___173 *, const char *);
	int (*mkdir)(struct inode___173 *, struct dentry___173 *, umode_t);
	int (*rmdir)(struct inode___173 *, struct dentry___173 *);
	int (*mknod)(struct inode___173 *, struct dentry___173 *, umode_t, dev_t);
	int (*rename)(struct inode___173 *, struct dentry___173 *, struct inode___173 *, struct dentry___173 *);
	int (*setattr)(struct dentry___173 *, struct iattr___173 *);
	int (*getattr)(struct vfsmount *, struct dentry___173 *, struct kstat *);
	int (*setxattr)(struct dentry___173 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___173 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___173 *, char *, size_t);
	int (*removexattr)(struct dentry___173 *, const char *);
	int (*fiemap)(struct inode___173 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___173 *, struct timespec *, int);
	int (*atomic_open)(struct inode___173 *, struct dentry___173 *, struct file___173 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___173 {
	struct module___92 *owner;
	loff_t (*llseek)(struct file___173 *, loff_t, int);
	ssize_t (*read)(struct file___173 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___173 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___173 *, void *, filldir_t);
	unsigned int (*poll)(struct file___173 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___173 *, struct vm_area_struct___180 *);
	int (*open)(struct inode___173 *, struct file___173 *);
	int (*flush)(struct file___173 *, fl_owner_t);
	int (*release)(struct inode___173 *, struct file___173 *);
	int (*fsync)(struct file___173 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___173 *, int);
	int (*lock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*sendpage)(struct file___173 *, struct page___172 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___173 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___173 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___173 *, long int, struct file_lock___173 **, void **);
		struct {
			int (*setlease)(struct file___173 *, long int, struct file_lock___173 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___173 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___173 *);
};

struct fasync_struct___173;

struct file_lock_operations___173;

struct lock_manager_operations___173;

struct file_lock___173 {
	struct file_lock___173 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___85 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___173 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___173 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___173 *fl_ops;
	const struct lock_manager_operations___173 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___173 {
	void (*fl_copy_lock)(struct file_lock___173 *, struct file_lock___173 *);
	void (*fl_release_private)(struct file_lock___173 *);
};

struct lock_manager_operations___173 {
	int (*lm_compare_owner)(struct file_lock___173 *, struct file_lock___173 *);
	long unsigned int (*lm_owner_key)(struct file_lock___173 *);
	void (*lm_notify)(struct file_lock___173 *);
	int (*lm_grant)(struct file_lock___173 *, struct file_lock___173 *, int);
	void (*lm_break)(struct file_lock___173 *);
	int (*lm_change)(struct file_lock___173 **, int);
};

struct fasync_struct___173 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___173 *fa_next;
	struct file___173 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___173 {
	const char *name;
	int fs_flags;
	struct dentry___173 * (*mount)(struct file_system_type___173 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___173 *);
	struct module___92 *owner;
	struct file_system_type___173 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___173 {
	struct inode___173 * (*alloc_inode)(struct super_block___173 *);
	void (*destroy_inode)(struct inode___173 *);
	void (*dirty_inode)(struct inode___173 *, int);
	int (*write_inode)(struct inode___173 *, struct writeback_control *);
	int (*drop_inode)(struct inode___173 *);
	void (*evict_inode)(struct inode___173 *);
	void (*put_super)(struct super_block___173 *);
	int (*sync_fs)(struct super_block___173 *, int);
	int (*freeze_fs)(struct super_block___173 *);
	int (*unfreeze_fs)(struct super_block___173 *);
	int (*statfs)(struct dentry___173 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___173 *, int *, char *);
	void (*umount_begin)(struct super_block___173 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___173 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___173 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___173 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___173 *);
	ssize_t (*quota_read)(struct super_block___173 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___173 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___173 *);
	int (*bdev_try_to_free_page)(struct super_block___173 *, struct page___172 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___173 *);
	void (*free_cached_objects)(struct super_block___173 *, int);
};

struct disk_part_tbl___28 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___28 *last_lookup;
	struct hd_struct___28 *part[0];
};

struct block_device_operations___27 {
	int (*open)(struct block_device___173 *, fmode_t);
	void (*release)(struct gendisk___28 *, fmode_t);
	int (*ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___173 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___28 *, unsigned int);
	int (*media_changed)(struct gendisk___28 *);
	void (*unlock_native_capacity)(struct gendisk___28 *);
	int (*revalidate_disk)(struct gendisk___28 *);
	int (*getgeo)(struct block_device___173 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___173 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___92 *owner;
};

struct vm_fault___150 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___172 *page;
};

struct io_cq___27 {
	struct request_queue___27 *q;
	struct io_context___27 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___159 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___27(struct request___27 *, int);

struct request___27 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___27 *q;
	struct blk_mq_ctx___6 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___28 *bio;
	struct bio___28 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___27 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___27 *saved_end_io;
		} flush;
	};
	struct gendisk___28 *rq_disk;
	struct hd_struct___28 *part;
	long unsigned int start_time;
	struct request_list___27 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___27 *end_io;
	void *end_io_data;
	struct request___27 *next_rq;
};

struct blk_mq_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___27 *queue;
	struct kobject___19 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___27(struct request_queue___27 *, struct request___27 **, struct bio___28 *);

typedef void elevator_merge_req_fn___27(struct request_queue___27 *, struct request___27 *, struct request___27 *);

typedef void elevator_merged_fn___27(struct request_queue___27 *, struct request___27 *, int);

typedef int elevator_allow_merge_fn___27(struct request_queue___27 *, struct request___27 *, struct bio___28 *);

typedef void elevator_bio_merged_fn___27(struct request_queue___27 *, struct request___27 *, struct bio___28 *);

typedef int elevator_dispatch_fn___27(struct request_queue___27 *, int);

typedef void elevator_add_req_fn___27(struct request_queue___27 *, struct request___27 *);

typedef struct request___27 *elevator_request_list_fn___27(struct request_queue___27 *, struct request___27 *);

typedef void elevator_completed_req_fn___27(struct request_queue___27 *, struct request___27 *);

typedef int elevator_may_queue_fn___27(struct request_queue___27 *, int);

typedef void elevator_init_icq_fn___27(struct io_cq___27 *);

typedef void elevator_exit_icq_fn___27(struct io_cq___27 *);

typedef int elevator_set_req_fn___27(struct request_queue___27 *, struct request___27 *, struct bio___28 *, gfp_t);

typedef void elevator_put_req_fn___27(struct request___27 *);

typedef void elevator_activate_req_fn___27(struct request_queue___27 *, struct request___27 *);

typedef void elevator_deactivate_req_fn___27(struct request_queue___27 *, struct request___27 *);

struct elevator_type___27;

typedef int elevator_init_fn___27(struct request_queue___27 *, struct elevator_type___27 *);

typedef void elevator_exit_fn___27(struct elevator_queue___27 *);

struct elevator_ops___27 {
	elevator_merge_fn___27 *elevator_merge_fn;
	elevator_merged_fn___27 *elevator_merged_fn;
	elevator_merge_req_fn___27 *elevator_merge_req_fn;
	elevator_allow_merge_fn___27 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___27 *elevator_bio_merged_fn;
	elevator_dispatch_fn___27 *elevator_dispatch_fn;
	elevator_add_req_fn___27 *elevator_add_req_fn;
	elevator_activate_req_fn___27 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___27 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___27 *elevator_completed_req_fn;
	elevator_request_list_fn___27 *elevator_former_req_fn;
	elevator_request_list_fn___27 *elevator_latter_req_fn;
	elevator_init_icq_fn___27 *elevator_init_icq_fn;
	elevator_exit_icq_fn___27 *elevator_exit_icq_fn;
	elevator_set_req_fn___27 *elevator_set_req_fn;
	elevator_put_req_fn___27 *elevator_put_req_fn;
	elevator_may_queue_fn___27 *elevator_may_queue_fn;
	elevator_init_fn___27 *elevator_init_fn;
	elevator_exit_fn___27 *elevator_exit_fn;
};

struct elv_fs_entry___27;

struct elevator_type___27 {
	struct kmem_cache___159 *icq_cache;
	struct elevator_ops___27 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___27 *elevator_attrs;
	char elevator_name[16];
	struct module___92 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___27 {
	struct elevator_type___27 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex___176 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___27 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___27 *, char *);
	ssize_t (*store)(struct elevator_queue___27 *, const char *, size_t);
};

struct bvec_merge_data___27 {
	struct block_device___173 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___27 {
	struct request___27 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___6;

typedef int queue_rq_fn___6(struct blk_mq_hw_ctx___6 *, const struct blk_mq_queue_data___6 *);

typedef struct blk_mq_hw_ctx___6 *map_queue_fn___6(struct request_queue___27 *, const int);

typedef enum blk_eh_timer_return timeout_fn___6(struct request___27 *, bool);

typedef int init_request_fn___6(void *, struct request___27 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___6(void *, struct request___27 *, unsigned int, unsigned int);

typedef int init_hctx_fn___6(struct blk_mq_hw_ctx___6 *, void *, unsigned int);

typedef void exit_hctx_fn___6(struct blk_mq_hw_ctx___6 *, unsigned int);

struct blk_mq_ops___6 {
	queue_rq_fn___6 *queue_rq;
	map_queue_fn___6 *map_queue;
	union {
		timeout_fn___6 *timeout;
		struct {
			rq_timed_out_fn___27 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___27 *complete;
	init_request_fn___6 *init_request;
	exit_request_fn___6 *exit_request;
	init_hctx_fn___6 *init_hctx;
	exit_hctx_fn___6 *exit_hctx;
};

struct blk_mq_tags___3;

struct blk_mq_hw_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___27 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___6 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___27 **padding2;
		struct {
			struct request___27 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags___3 *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___19 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___6 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___6 {
	struct blk_mq_ops___6 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___3 **tags;
	struct mutex___176 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___6 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___27 *flush_rq;
	struct request___27 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tags___3 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct blk_mq_bitmap_tags bitmap_tags;
	struct blk_mq_bitmap_tags breserved_tags;
	struct request___27 **rqs;
	struct list_head page_list;
	cpumask_var_t cpumask;
};

struct blk_mq_queue_data___6 {
	struct request___27 *rq;
	struct list_head *list;
	bool last;
};

typedef void busy_iter_fn___2(struct blk_mq_hw_ctx___6 *, struct request___27 *, void *, bool);

typedef void busy_tag_iter_fn(struct request___27 *, void *, bool);

struct blk_mq_alloc_data___2 {
	struct request_queue___27 *q;
	gfp_t gfp;
	bool reserved;
	struct blk_mq_ctx___6 *ctx;
	struct blk_mq_hw_ctx___6 *hctx;
};

enum {
	BT_WAIT_QUEUES = 8,
	BT_WAIT_BATCH = 8,
};

typedef int elevator_init_fn___28(struct request_queue___19 *, struct elevator_type___22 *);

typedef int merge_bvec_fn___28(struct request_queue___19 *, struct bvec_merge_data___22 *, struct bio_vec___23 *);

typedef int queue_rq_fn___7(struct blk_mq_hw_ctx *, const struct blk_mq_queue_data___2 *);

typedef struct blk_mq_hw_ctx *map_queue_fn___7(struct request_queue___19 *, const int);

typedef enum blk_eh_timer_return timeout_fn___7(struct request___19 *, bool);

typedef int init_request_fn___7(void *, struct request___19 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___7(void *, struct request___19 *, unsigned int, unsigned int);

struct blk_mq_ctx_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_mq_ctx *, char *);
	ssize_t (*store)(struct blk_mq_ctx *, const char *, size_t);
};

struct blk_mq_hw_ctx_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_mq_hw_ctx *, char *);
	ssize_t (*store)(struct blk_mq_hw_ctx *, const char *, size_t);
};

struct page___173;

typedef struct page___173 *pgtable_t___173;

struct address_space___174;

struct kmem_cache___160;

struct page___173 {
	long unsigned int flags;
	struct address_space___174 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___173 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___173 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___160 *slab_cache;
		struct page___173 *first_page;
	};
	long: 64;
};

struct task_struct___176;

struct pv_cpu_ops___176 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___176 *);
	void (*end_context_switch)(struct task_struct___176 *);
};

struct mutex___177 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___176 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___169 {
	struct page___173 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___181;

struct signal_struct___176;

struct bio_list___28;

struct backing_dev_info___38;

struct io_context___28;

struct task_struct___176 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___176 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___181 *mm;
	struct mm_struct___181 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___176 *real_parent;
	struct task_struct___176 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___176 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___176 = 0,
		VTIME_USER___176 = 1,
		VTIME_SYS___176 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___176 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___28 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___38 *backing_dev_info;
	struct io_context___28 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___177 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___169 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___181 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___181 *, struct mm_struct___181 *);
	void (*dup_mmap)(struct mm_struct___181 *, struct mm_struct___181 *);
	void (*exit_mmap)(struct mm_struct___181 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___181 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___181 *);
	void (*pgd_free)(struct mm_struct___181 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___181 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___181 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___181 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___181 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___181 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___181 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___181 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___181 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___181 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___181 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___181 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___177 lock;
	void *vdso;
} mm_context_t___177;

struct xol_area___173;

struct uprobes_state___173 {
	struct xol_area___173 *xol_area;
};

struct vm_area_struct___181;

struct file___174;

struct core_state___176;

struct mm_struct___181 {
	struct vm_area_struct___181 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___181 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___181 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___177 context;
	long unsigned int flags;
	struct core_state___176 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___176 *owner;
	struct file___174 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___173 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___93;

struct module_kobject___92 {
	struct kobject___4 kobj;
	struct module___93 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___92;

struct module___93 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___92 mkobj;
	struct module_attribute___92 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___176 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___176;

struct lruvec___176 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___176 *zone;
};

struct pglist_data___176;

struct zone___176 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___176 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___176 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___176 {
	struct zone___176 *zone;
	int zone_idx;
};

struct zonelist___176 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___176 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___176 {
	struct zone___176 node_zones[4];
	struct zonelist___176 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___176 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___139;

struct dev_pm_ops___139 {
	int (*prepare)(struct device___139 *);
	void (*complete)(struct device___139 *);
	int (*suspend)(struct device___139 *);
	int (*resume)(struct device___139 *);
	int (*freeze)(struct device___139 *);
	int (*thaw)(struct device___139 *);
	int (*poweroff)(struct device___139 *);
	int (*restore)(struct device___139 *);
	int (*suspend_late)(struct device___139 *);
	int (*resume_early)(struct device___139 *);
	int (*freeze_late)(struct device___139 *);
	int (*thaw_early)(struct device___139 *);
	int (*poweroff_late)(struct device___139 *);
	int (*restore_early)(struct device___139 *);
	int (*suspend_noirq)(struct device___139 *);
	int (*resume_noirq)(struct device___139 *);
	int (*freeze_noirq)(struct device___139 *);
	int (*thaw_noirq)(struct device___139 *);
	int (*poweroff_noirq)(struct device___139 *);
	int (*restore_noirq)(struct device___139 *);
	int (*runtime_suspend)(struct device___139 *);
	int (*runtime_resume)(struct device___139 *);
	int (*runtime_idle)(struct device___139 *);
};

struct device_type___139;

struct bus_type___139;

struct device_driver___139;

struct dev_pm_domain___139;

struct class___139;

struct attribute_group___131;

struct device_rh___139;

struct device___139 {
	struct device___139 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___139 *type;
	struct mutex___177 mutex;
	struct bus_type___139 *bus;
	struct device_driver___139 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___139 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___30 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___139 *class;
	const struct attribute_group___131 **groups;
	void (*release)(struct device___139 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___139 *device_rh;
};

struct dev_pm_info_rh___139 {
	void (*set_latency_tolerance)(struct device___139 *, s32);
};

struct dev_pm_domain___139 {
	struct dev_pm_ops___139 ops;
};

struct smp_ops___176 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___176 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___133;

struct attribute_group___131 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___133 **bin_attrs;
};

struct bin_attribute___133 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___174 *, struct kobject___4 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___174 *, struct kobject___4 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	int (*mmap)(struct file___174 *, struct kobject___4 *, struct bin_attribute___133 *, struct vm_area_struct___181 *);
};

struct dentry___174;

struct path___174 {
	struct vfsmount *mnt;
	struct dentry___174 *dentry;
};

struct inode___174;

struct file_operations___174;

struct file___174 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___174 f_path;
	struct inode___174 *f_inode;
	const struct file_operations___174 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___174 *f_mapping;
	struct mutex___177 f_pos_lock;
};

struct vm_operations_struct___154;

struct vm_area_struct___181 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___181 *vm_next;
	struct vm_area_struct___181 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___181 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___154 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___174 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___92 *, struct module_kobject___92 *, char *);
	ssize_t (*store)(struct module_attribute___92 *, struct module_kobject___92 *, const char *, size_t);
	void (*setup)(struct module___93 *, const char *);
	int (*test)(struct module___93 *);
	void (*free)(struct module___93 *);
};

struct xol_area___173 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___173 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___159;

struct memcg_cache_params___160;

struct kmem_cache___160 {
	struct kmem_cache_cpu___159 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___160 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___174;

struct address_space___174 {
	struct inode___174 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___177 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___174 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___38 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___151;

struct vm_operations_struct___154 {
	void (*open)(struct vm_area_struct___181 *);
	void (*close)(struct vm_area_struct___181 *);
	int (*fault)(struct vm_area_struct___181 *, struct vm_fault___151 *);
	int (*page_mkwrite)(struct vm_area_struct___181 *, struct vm_fault___151 *);
	int (*access)(struct vm_area_struct___181 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___181 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___181 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___181 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___181 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___176 {
	struct task_struct___176 *task;
	struct core_thread___176 *next;
};

struct core_state___176 {
	atomic_t nr_threads;
	struct core_thread___176 dumper;
	struct completion startup;
};

struct vm_fault___151 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___173 *page;
};

struct bus_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___139 *, char *);
	ssize_t (*store)(struct bus_type___139 *, const char *, size_t);
};

struct device_attribute___139;

struct driver_attribute___139;

struct bus_type___139 {
	const char *name;
	const char *dev_name;
	struct device___139 *dev_root;
	struct bus_attribute___139 *bus_attrs;
	struct device_attribute___139 *dev_attrs;
	struct driver_attribute___139 *drv_attrs;
	const struct attribute_group___131 **bus_groups;
	const struct attribute_group___131 **dev_groups;
	const struct attribute_group___131 **drv_groups;
	int (*match)(struct device___139 *, struct device_driver___139 *);
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	int (*probe)(struct device___139 *);
	int (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*online)(struct device___139 *);
	int (*offline)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct device___139 *, struct device_attribute___139 *, char *);
	ssize_t (*store)(struct device___139 *, struct device_attribute___139 *, const char *, size_t);
};

struct driver_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___139 *, char *);
	ssize_t (*store)(struct device_driver___139 *, const char *, size_t);
};

struct device_driver___139 {
	const char *name;
	struct bus_type___139 *bus;
	struct module___93 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___139 *);
	int (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	const struct attribute_group___131 **groups;
	const struct dev_pm_ops___139 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___139 {
	const char *name;
	const struct attribute_group___131 **groups;
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
};

struct class_attribute___139;

struct class___139 {
	const char *name;
	struct module___93 *owner;
	struct class_attribute___139 *class_attrs;
	struct device_attribute___139 *dev_attrs;
	const struct attribute_group___131 **dev_groups;
	struct bin_attribute___133 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *);
	void (*class_release)(struct class___139 *);
	void (*dev_release)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
	struct subsys_private *p;
};

struct class_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct class___139 *, struct class_attribute___139 *, char *);
	ssize_t (*store)(struct class___139 *, struct class_attribute___139 *, const char *, size_t);
	const void * (*namespace)(struct class___139 *, const struct class_attribute___139 *);
};

struct device_rh___139 {
	struct dev_pm_info_rh___139 power;
};

struct signal_struct___176 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___176 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___176 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___177 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___29;

struct bio_list___28 {
	struct bio___29 *head;
	struct bio___29 *tail;
};

struct bdi_writeback___38 {
	struct backing_dev_info___38 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___38 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___38 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___139 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___174 *debug_dir;
	struct dentry___174 *debug_stats;
};

struct io_cq___28;

struct io_context___28 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___28 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___159 {
	void **freelist;
	long unsigned int tid;
	struct page___173 *page;
	struct page___173 *partial;
};

struct memcg_cache_params___160 {
	bool is_root_cache;
	union {
		struct kmem_cache___160 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___160 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___174;

struct super_block___174;

struct dentry___174 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___174 *d_parent;
	struct qstr d_name;
	struct inode___174 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___174 *d_op;
	struct super_block___174 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___174;

struct file_lock___174;

struct dquot___174;

struct block_device___174;

struct inode___174 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___174 *i_op;
	struct super_block___174 *i_sb;
	struct address_space___174 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___177 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___174 *i_fop;
	struct file_lock___174 *i_flock;
	struct address_space___174 i_data;
	struct dquot___174 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___174 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___174 {
	int (*d_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_hash)(const struct dentry___174 *, struct qstr *);
	int (*d_compare)(const struct dentry___174 *, const struct dentry___174 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___174 *);
	void (*d_release)(struct dentry___174 *);
	void (*d_prune)(struct dentry___174 *);
	void (*d_iput)(struct dentry___174 *, struct inode___174 *);
	char * (*d_dname)(struct dentry___174 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___174 *);
	int (*d_manage)(struct dentry___174 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___174;

struct mem_dqinfo___174 {
	struct quota_format_type___174 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___174;

struct quota_info___174 {
	unsigned int flags;
	struct mutex___177 dqio_mutex;
	struct mutex___177 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___174 *files[2];
	struct mem_dqinfo___174 info[2];
	const struct quota_format_ops___174 *ops[2];
};

struct file_system_type___174;

struct super_operations___174;

struct dquot_operations___174;

struct quotactl_ops___174;

struct super_block___174 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___174 *s_type;
	const struct super_operations___174 *s_op;
	const struct dquot_operations___174 *dq_op;
	const struct quotactl_ops___174 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___174 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___174 *s_bdev;
	struct backing_dev_info___38 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___174 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___177 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___174 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___29(struct bio___29 *, int);

struct bio_vec___29 {
	struct page___173 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___29;

struct bio_set___29;

struct bio___29 {
	sector_t bi_sector;
	struct bio___29 *bi_next;
	struct block_device___174 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___29 *bi_end_io;
	void *bi_private;
	struct io_context___28 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___29 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___29 *bi_io_vec;
	struct bio_set___29 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___29 bi_inline_vecs[0];
};

struct hd_struct___29;

struct gendisk___29;

struct request_queue___28;

struct block_device___174 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___174 *bd_inode;
	struct super_block___174 *bd_super;
	struct mutex___177 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___174 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___29 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___29 *bd_disk;
	struct request_queue___28 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___177 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___29 {
	struct bio___29 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___29 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___29 *bip_vec;
	struct bio_vec___29 bip_inline_vecs[0];
};

struct bio_set___29 {
	struct kmem_cache___160 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___28 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___174 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___174 *ia_file;
};

struct dquot___174 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___177 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___174 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___174 {
	int qf_fmt_id;
	const struct quota_format_ops___174 *qf_ops;
	struct module___93 *qf_owner;
	struct quota_format_type___174 *qf_next;
};

struct quota_format_ops___174 {
	int (*check_quota_file)(struct super_block___174 *, int);
	int (*read_file_info)(struct super_block___174 *, int);
	int (*write_file_info)(struct super_block___174 *, int);
	int (*free_file_info)(struct super_block___174 *, int);
	int (*read_dqblk)(struct dquot___174 *);
	int (*commit_dqblk)(struct dquot___174 *);
	int (*release_dqblk)(struct dquot___174 *);
};

struct dquot_operations___174 {
	int (*write_dquot)(struct dquot___174 *);
	struct dquot___174 * (*alloc_dquot)(struct super_block___174 *, int);
	void (*destroy_dquot)(struct dquot___174 *);
	int (*acquire_dquot)(struct dquot___174 *);
	int (*release_dquot)(struct dquot___174 *);
	int (*mark_dirty)(struct dquot___174 *);
	int (*write_info)(struct super_block___174 *, int);
	qsize_t * (*get_reserved_space)(struct inode___174 *);
};

struct quotactl_ops___174 {
	int (*quota_on)(struct super_block___174 *, int, int, struct path___174 *);
	int (*quota_on_meta)(struct super_block___174 *, int, int);
	int (*quota_off)(struct super_block___174 *, int);
	int (*quota_sync)(struct super_block___174 *, int);
	int (*get_info)(struct super_block___174 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___174 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___174 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___174 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___174 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___174 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___174 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___174 *, unsigned int);
};

struct address_space_operations___174 {
	int (*writepage)(struct page___173 *, struct writeback_control *);
	int (*readpage)(struct file___174 *, struct page___173 *);
	int (*writepages)(struct address_space___174 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___173 *);
	int (*readpages)(struct file___174 *, struct address_space___174 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___174 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___173 **, void **);
	int (*write_end)(struct file___174 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___173 *, void *);
	sector_t (*bmap)(struct address_space___174 *, sector_t);
	void (*invalidatepage)(struct page___173 *, long unsigned int);
	int (*releasepage)(struct page___173 *, gfp_t);
	void (*freepage)(struct page___173 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___174 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___174 *, struct page___173 *, struct page___173 *, enum migrate_mode);
	int (*launder_page)(struct page___173 *);
	int (*is_partially_uptodate)(struct page___173 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___173 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___174 *, struct page___173 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___174 *, sector_t *);
	void (*swap_deactivate)(struct file___174 *);
	void (*invalidatepage_range)(struct page___173 *, unsigned int, unsigned int);
};

struct hd_struct___29 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___139 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___29;

struct block_device_operations___28;

struct gendisk___29 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___29 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___29 *part_tbl;
	struct hd_struct___29 part0;
	const struct block_device_operations___28 *fops;
	struct request_queue___28 *queue;
	void *private_data;
	int flags;
	struct device___139 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___28 {
	struct request_queue___28 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___28(struct request_queue___28 *);

typedef void make_request_fn___28(struct request_queue___28 *, struct bio___29 *);

struct request___28;

typedef int prep_rq_fn___28(struct request_queue___28 *, struct request___28 *);

struct bvec_merge_data___28;

typedef int merge_bvec_fn___29(struct request_queue___28 *, struct bvec_merge_data___28 *, struct bio_vec___29 *);

typedef void softirq_done_fn___28(struct request___28 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___28(struct request___28 *);

typedef int dma_drain_needed_fn___28(struct request___28 *);

typedef int lld_busy_fn___28(struct request_queue___28 *);

struct bsg_class_device___28 {
	struct device___139 *class_dev;
	struct device___139 *parent;
	int minor;
	struct request_queue___28 *queue;
	struct kref ref;
	void (*release)(struct device___139 *);
};

typedef void unprep_rq_fn___28(struct request_queue___28 *, struct request___28 *);

struct elevator_queue___28;

struct blk_mq_ops___7;

struct blk_mq_ctx___7;

struct blk_mq_hw_ctx___7;

struct blk_queue_tag___28;

struct blk_mq_tag_set___7;

struct blk_flush_queue___7;

struct request_queue___28 {
	struct list_head queue_head;
	struct request___28 *last_merge;
	struct elevator_queue___28 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___28 root_rl;
	request_fn_proc___28 *request_fn;
	make_request_fn___28 *make_request_fn;
	prep_rq_fn___28 *prep_rq_fn;
	merge_bvec_fn___29 *merge_bvec_fn;
	softirq_done_fn___28 *softirq_done_fn;
	rq_timed_out_fn___28 *rq_timed_out_fn;
	dma_drain_needed_fn___28 *dma_drain_needed;
	lld_busy_fn___28 *lld_busy_fn;
	struct blk_mq_ops___7 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___7 *queue_ctx;
		struct {
			struct blk_mq_ctx___7 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___7 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___28 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___38 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___139 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___28 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___28 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___177 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___28 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___28 *unprep_rq_fn;
	struct blk_mq_tag_set___7 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___29 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___7 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___174 {
	struct dentry___174 * (*lookup)(struct inode___174 *, struct dentry___174 *, unsigned int);
	void * (*follow_link)(struct dentry___174 *, struct nameidata *);
	int (*permission)(struct inode___174 *, int);
	struct posix_acl * (*get_acl)(struct inode___174 *, int);
	int (*readlink)(struct dentry___174 *, char *, int);
	void (*put_link)(struct dentry___174 *, struct nameidata *, void *);
	int (*create)(struct inode___174 *, struct dentry___174 *, umode_t, bool);
	int (*link)(struct dentry___174 *, struct inode___174 *, struct dentry___174 *);
	int (*unlink)(struct inode___174 *, struct dentry___174 *);
	int (*symlink)(struct inode___174 *, struct dentry___174 *, const char *);
	int (*mkdir)(struct inode___174 *, struct dentry___174 *, umode_t);
	int (*rmdir)(struct inode___174 *, struct dentry___174 *);
	int (*mknod)(struct inode___174 *, struct dentry___174 *, umode_t, dev_t);
	int (*rename)(struct inode___174 *, struct dentry___174 *, struct inode___174 *, struct dentry___174 *);
	int (*setattr)(struct dentry___174 *, struct iattr___174 *);
	int (*getattr)(struct vfsmount *, struct dentry___174 *, struct kstat *);
	int (*setxattr)(struct dentry___174 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___174 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___174 *, char *, size_t);
	int (*removexattr)(struct dentry___174 *, const char *);
	int (*fiemap)(struct inode___174 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___174 *, struct timespec *, int);
	int (*atomic_open)(struct inode___174 *, struct dentry___174 *, struct file___174 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___174 {
	struct module___93 *owner;
	loff_t (*llseek)(struct file___174 *, loff_t, int);
	ssize_t (*read)(struct file___174 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___174 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___174 *, void *, filldir_t);
	unsigned int (*poll)(struct file___174 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___174 *, struct vm_area_struct___181 *);
	int (*open)(struct inode___174 *, struct file___174 *);
	int (*flush)(struct file___174 *, fl_owner_t);
	int (*release)(struct inode___174 *, struct file___174 *);
	int (*fsync)(struct file___174 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___174 *, int);
	int (*lock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*sendpage)(struct file___174 *, struct page___173 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___174 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___174 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___174 *, long int, struct file_lock___174 **, void **);
		struct {
			int (*setlease)(struct file___174 *, long int, struct file_lock___174 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___174 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___174 *);
};

struct fasync_struct___174;

struct file_lock_operations___174;

struct lock_manager_operations___174;

struct file_lock___174 {
	struct file_lock___174 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___174 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___174 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___174 *fl_ops;
	const struct lock_manager_operations___174 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___174 {
	void (*fl_copy_lock)(struct file_lock___174 *, struct file_lock___174 *);
	void (*fl_release_private)(struct file_lock___174 *);
};

struct lock_manager_operations___174 {
	int (*lm_compare_owner)(struct file_lock___174 *, struct file_lock___174 *);
	long unsigned int (*lm_owner_key)(struct file_lock___174 *);
	void (*lm_notify)(struct file_lock___174 *);
	int (*lm_grant)(struct file_lock___174 *, struct file_lock___174 *, int);
	void (*lm_break)(struct file_lock___174 *);
	int (*lm_change)(struct file_lock___174 **, int);
};

struct fasync_struct___174 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___174 *fa_next;
	struct file___174 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___174 {
	const char *name;
	int fs_flags;
	struct dentry___174 * (*mount)(struct file_system_type___174 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___174 *);
	struct module___93 *owner;
	struct file_system_type___174 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___174 {
	struct inode___174 * (*alloc_inode)(struct super_block___174 *);
	void (*destroy_inode)(struct inode___174 *);
	void (*dirty_inode)(struct inode___174 *, int);
	int (*write_inode)(struct inode___174 *, struct writeback_control *);
	int (*drop_inode)(struct inode___174 *);
	void (*evict_inode)(struct inode___174 *);
	void (*put_super)(struct super_block___174 *);
	int (*sync_fs)(struct super_block___174 *, int);
	int (*freeze_fs)(struct super_block___174 *);
	int (*unfreeze_fs)(struct super_block___174 *);
	int (*statfs)(struct dentry___174 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___174 *, int *, char *);
	void (*umount_begin)(struct super_block___174 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___174 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___174 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___174 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___174 *);
	ssize_t (*quota_read)(struct super_block___174 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___174 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___174 *);
	int (*bdev_try_to_free_page)(struct super_block___174 *, struct page___173 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___174 *);
	void (*free_cached_objects)(struct super_block___174 *, int);
};

struct disk_part_tbl___29 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___29 *last_lookup;
	struct hd_struct___29 *part[0];
};

struct block_device_operations___28 {
	int (*open)(struct block_device___174 *, fmode_t);
	void (*release)(struct gendisk___29 *, fmode_t);
	int (*ioctl)(struct block_device___174 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___174 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___174 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___29 *, unsigned int);
	int (*media_changed)(struct gendisk___29 *);
	void (*unlock_native_capacity)(struct gendisk___29 *);
	int (*revalidate_disk)(struct gendisk___29 *);
	int (*getgeo)(struct block_device___174 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___174 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___93 *owner;
};

struct io_cq___28 {
	struct request_queue___28 *q;
	struct io_context___28 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___160 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___28(struct request___28 *, int);

struct request___28 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___28 *q;
	struct blk_mq_ctx___7 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___29 *bio;
	struct bio___29 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___28 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___28 *saved_end_io;
		} flush;
	};
	struct gendisk___29 *rq_disk;
	struct hd_struct___29 *part;
	long unsigned int start_time;
	struct request_list___28 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___28 *end_io;
	void *end_io_data;
	struct request___28 *next_rq;
};

struct blk_mq_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___28 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___28(struct request_queue___28 *, struct request___28 **, struct bio___29 *);

typedef void elevator_merge_req_fn___28(struct request_queue___28 *, struct request___28 *, struct request___28 *);

typedef void elevator_merged_fn___28(struct request_queue___28 *, struct request___28 *, int);

typedef int elevator_allow_merge_fn___28(struct request_queue___28 *, struct request___28 *, struct bio___29 *);

typedef void elevator_bio_merged_fn___28(struct request_queue___28 *, struct request___28 *, struct bio___29 *);

typedef int elevator_dispatch_fn___28(struct request_queue___28 *, int);

typedef void elevator_add_req_fn___28(struct request_queue___28 *, struct request___28 *);

typedef struct request___28 *elevator_request_list_fn___28(struct request_queue___28 *, struct request___28 *);

typedef void elevator_completed_req_fn___28(struct request_queue___28 *, struct request___28 *);

typedef int elevator_may_queue_fn___28(struct request_queue___28 *, int);

typedef void elevator_init_icq_fn___28(struct io_cq___28 *);

typedef void elevator_exit_icq_fn___28(struct io_cq___28 *);

typedef int elevator_set_req_fn___28(struct request_queue___28 *, struct request___28 *, struct bio___29 *, gfp_t);

typedef void elevator_put_req_fn___28(struct request___28 *);

typedef void elevator_activate_req_fn___28(struct request_queue___28 *, struct request___28 *);

typedef void elevator_deactivate_req_fn___28(struct request_queue___28 *, struct request___28 *);

struct elevator_type___28;

typedef int elevator_init_fn___29(struct request_queue___28 *, struct elevator_type___28 *);

typedef void elevator_exit_fn___28(struct elevator_queue___28 *);

struct elevator_ops___28 {
	elevator_merge_fn___28 *elevator_merge_fn;
	elevator_merged_fn___28 *elevator_merged_fn;
	elevator_merge_req_fn___28 *elevator_merge_req_fn;
	elevator_allow_merge_fn___28 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___28 *elevator_bio_merged_fn;
	elevator_dispatch_fn___28 *elevator_dispatch_fn;
	elevator_add_req_fn___28 *elevator_add_req_fn;
	elevator_activate_req_fn___28 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___28 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___28 *elevator_completed_req_fn;
	elevator_request_list_fn___28 *elevator_former_req_fn;
	elevator_request_list_fn___28 *elevator_latter_req_fn;
	elevator_init_icq_fn___28 *elevator_init_icq_fn;
	elevator_exit_icq_fn___28 *elevator_exit_icq_fn;
	elevator_set_req_fn___28 *elevator_set_req_fn;
	elevator_put_req_fn___28 *elevator_put_req_fn;
	elevator_may_queue_fn___28 *elevator_may_queue_fn;
	elevator_init_fn___29 *elevator_init_fn;
	elevator_exit_fn___28 *elevator_exit_fn;
};

struct elv_fs_entry___28;

struct elevator_type___28 {
	struct kmem_cache___160 *icq_cache;
	struct elevator_ops___28 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___28 *elevator_attrs;
	char elevator_name[16];
	struct module___93 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___28 {
	struct elevator_type___28 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___177 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___28 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___28 *, char *);
	ssize_t (*store)(struct elevator_queue___28 *, const char *, size_t);
};

struct bvec_merge_data___28 {
	struct block_device___174 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___28 {
	struct request___28 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___7;

typedef int queue_rq_fn___8(struct blk_mq_hw_ctx___7 *, const struct blk_mq_queue_data___7 *);

typedef struct blk_mq_hw_ctx___7 *map_queue_fn___8(struct request_queue___28 *, const int);

typedef enum blk_eh_timer_return timeout_fn___8(struct request___28 *, bool);

typedef int init_request_fn___8(void *, struct request___28 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___8(void *, struct request___28 *, unsigned int, unsigned int);

typedef int init_hctx_fn___7(struct blk_mq_hw_ctx___7 *, void *, unsigned int);

typedef void exit_hctx_fn___7(struct blk_mq_hw_ctx___7 *, unsigned int);

struct blk_mq_ops___7 {
	queue_rq_fn___8 *queue_rq;
	map_queue_fn___8 *map_queue;
	union {
		timeout_fn___8 *timeout;
		struct {
			rq_timed_out_fn___28 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___28 *complete;
	init_request_fn___8 *init_request;
	exit_request_fn___8 *exit_request;
	init_hctx_fn___7 *init_hctx;
	exit_hctx_fn___7 *exit_hctx;
};

struct blk_mq_hw_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___28 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___7 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___28 **padding2;
		struct {
			struct request___28 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___7 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___7 {
	struct blk_mq_ops___7 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___177 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___7 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___28 *flush_rq;
	struct request___28 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_queue_data___7 {
	struct request___28 *rq;
	struct list_head *list;
	bool last;
};

struct disk_part_iter {
	struct gendisk___10 *disk;
	struct hd_struct___10 *part;
	int idx;
	unsigned int flags;
};

struct hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	short unsigned int cylinders;
	long unsigned int start;
};

struct blkpg_ioctl_arg {
	int op;
	int flags;
	int datalen;
	void *data;
};

struct blkpg_partition {
	long long int start;
	long long int length;
	int pno;
	char devname[64];
	char volname[64];
};

struct page___174;

typedef struct page___174 *pgtable_t___174;

struct address_space___175;

struct kmem_cache___161;

struct page___174 {
	long unsigned int flags;
	struct address_space___175 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___174 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___174 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___161 *slab_cache;
		struct page___174 *first_page;
	};
	long: 64;
};

struct task_struct___177;

struct pv_cpu_ops___177 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___177 *);
	void (*end_context_switch)(struct task_struct___177 *);
};

struct mutex___178 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___177 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___170 {
	struct page___174 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___182;

struct signal_struct___177;

struct bio_list___29;

struct backing_dev_info___39;

struct io_context___29;

struct task_struct___177 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___177 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___182 *mm;
	struct mm_struct___182 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___177 *real_parent;
	struct task_struct___177 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___177 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___177 = 0,
		VTIME_USER___177 = 1,
		VTIME_SYS___177 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___177 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___29 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___39 *backing_dev_info;
	struct io_context___29 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___178 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___170 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___182 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___182 *, struct mm_struct___182 *);
	void (*dup_mmap)(struct mm_struct___182 *, struct mm_struct___182 *);
	void (*exit_mmap)(struct mm_struct___182 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___182 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___182 *);
	void (*pgd_free)(struct mm_struct___182 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___182 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___182 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___182 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___182 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___182 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___182 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___182 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___182 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___182 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___182 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___182 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___178 lock;
	void *vdso;
} mm_context_t___178;

struct xol_area___174;

struct uprobes_state___174 {
	struct xol_area___174 *xol_area;
};

struct vm_area_struct___182;

struct file___175;

struct core_state___177;

struct mm_struct___182 {
	struct vm_area_struct___182 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___182 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___182 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___178 context;
	long unsigned int flags;
	struct core_state___177 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___177 *owner;
	struct file___175 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___174 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___94;

struct module_kobject___93 {
	struct kobject___4 kobj;
	struct module___94 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___93;

struct module___94 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___93 mkobj;
	struct module_attribute___93 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___177 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___177;

struct lruvec___177 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___177 *zone;
};

struct pglist_data___177;

struct zone___177 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___177 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___177 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___177 {
	struct zone___177 *zone;
	int zone_idx;
};

struct zonelist___177 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___177 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___177 {
	struct zone___177 node_zones[4];
	struct zonelist___177 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___177 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___121;

struct x86_io_apic_ops___121 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___121 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___121;

struct irq_data___121 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___121 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___140;

struct dev_pm_ops___140 {
	int (*prepare)(struct device___140 *);
	void (*complete)(struct device___140 *);
	int (*suspend)(struct device___140 *);
	int (*resume)(struct device___140 *);
	int (*freeze)(struct device___140 *);
	int (*thaw)(struct device___140 *);
	int (*poweroff)(struct device___140 *);
	int (*restore)(struct device___140 *);
	int (*suspend_late)(struct device___140 *);
	int (*resume_early)(struct device___140 *);
	int (*freeze_late)(struct device___140 *);
	int (*thaw_early)(struct device___140 *);
	int (*poweroff_late)(struct device___140 *);
	int (*restore_early)(struct device___140 *);
	int (*suspend_noirq)(struct device___140 *);
	int (*resume_noirq)(struct device___140 *);
	int (*freeze_noirq)(struct device___140 *);
	int (*thaw_noirq)(struct device___140 *);
	int (*poweroff_noirq)(struct device___140 *);
	int (*restore_noirq)(struct device___140 *);
	int (*runtime_suspend)(struct device___140 *);
	int (*runtime_resume)(struct device___140 *);
	int (*runtime_idle)(struct device___140 *);
};

struct device_type___140;

struct bus_type___140;

struct device_driver___140;

struct dev_pm_domain___140;

struct class___140;

struct attribute_group___132;

struct device_rh___140;

struct device___140 {
	struct device___140 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___140 *type;
	struct mutex___178 mutex;
	struct bus_type___140 *bus;
	struct device_driver___140 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___140 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___30 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___140 *class;
	const struct attribute_group___132 **groups;
	void (*release)(struct device___140 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___140 *device_rh;
};

struct dev_pm_info_rh___140 {
	void (*set_latency_tolerance)(struct device___140 *, s32);
};

struct dev_pm_domain___140 {
	struct dev_pm_ops___140 ops;
};

struct smp_ops___177 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___177 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___134;

struct attribute_group___132 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___134 **bin_attrs;
};

struct bin_attribute___134 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___175 *, struct kobject___4 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___175 *, struct kobject___4 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	int (*mmap)(struct file___175 *, struct kobject___4 *, struct bin_attribute___134 *, struct vm_area_struct___182 *);
};

struct dentry___175;

struct path___175 {
	struct vfsmount *mnt;
	struct dentry___175 *dentry;
};

struct inode___175;

struct file_operations___175;

struct file___175 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___175 f_path;
	struct inode___175 *f_inode;
	const struct file_operations___175 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___175 *f_mapping;
	struct mutex___178 f_pos_lock;
};

struct vm_operations_struct___155;

struct vm_area_struct___182 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___182 *vm_next;
	struct vm_area_struct___182 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___182 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___155 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___175 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___93 *, struct module_kobject___93 *, char *);
	ssize_t (*store)(struct module_attribute___93 *, struct module_kobject___93 *, const char *, size_t);
	void (*setup)(struct module___94 *, const char *);
	int (*test)(struct module___94 *);
	void (*free)(struct module___94 *);
};

struct dentry_operations___175;

struct super_block___175;

struct dentry___175 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___175 *d_parent;
	struct qstr d_name;
	struct inode___175 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___175 *d_op;
	struct super_block___175 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___175;

struct address_space___175 {
	struct inode___175 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___178 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___175 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___39 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___175;

struct file_lock___175;

struct dquot___175;

struct block_device___175;

struct inode___175 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___175 *i_op;
	struct super_block___175 *i_sb;
	struct address_space___175 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___178 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___175 *i_fop;
	struct file_lock___175 *i_flock;
	struct address_space___175 i_data;
	struct dquot___175 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___175 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___175 {
	int (*d_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_hash)(const struct dentry___175 *, struct qstr *);
	int (*d_compare)(const struct dentry___175 *, const struct dentry___175 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___175 *);
	void (*d_release)(struct dentry___175 *);
	void (*d_prune)(struct dentry___175 *);
	void (*d_iput)(struct dentry___175 *, struct inode___175 *);
	char * (*d_dname)(struct dentry___175 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___175 *);
	int (*d_manage)(struct dentry___175 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___175;

struct mem_dqinfo___175 {
	struct quota_format_type___175 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___175;

struct quota_info___175 {
	unsigned int flags;
	struct mutex___178 dqio_mutex;
	struct mutex___178 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___175 *files[2];
	struct mem_dqinfo___175 info[2];
	const struct quota_format_ops___175 *ops[2];
};

struct file_system_type___175;

struct super_operations___175;

struct dquot_operations___175;

struct quotactl_ops___175;

struct super_block___175 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___175 *s_type;
	const struct super_operations___175 *s_op;
	const struct dquot_operations___175 *dq_op;
	const struct quotactl_ops___175 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___175 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___175 *s_bdev;
	struct backing_dev_info___39 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___175 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___178 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___175 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___30;

typedef void bio_end_io_t___30(struct bio___30 *, int);

struct bio_vec___30 {
	struct page___174 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___30;

struct bio_set___30;

struct bio___30 {
	sector_t bi_sector;
	struct bio___30 *bi_next;
	struct block_device___175 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___30 *bi_end_io;
	void *bi_private;
	struct io_context___29 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___30 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___30 *bi_io_vec;
	struct bio_set___30 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___30 bi_inline_vecs[0];
};

struct hd_struct___30;

struct gendisk___30;

struct request_queue___29;

struct block_device___175 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___175 *bd_inode;
	struct super_block___175 *bd_super;
	struct mutex___178 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___175 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___30 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___30 *bd_disk;
	struct request_queue___29 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___178 bd_fsfreeze_mutex;
};

struct io_cq___29;

struct io_context___29 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___29 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___30 {
	struct bio___30 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___30 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___30 *bip_vec;
	struct bio_vec___30 bip_inline_vecs[0];
};

struct bio_list___29 {
	struct bio___30 *head;
	struct bio___30 *tail;
};

struct bio_set___30 {
	struct kmem_cache___161 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___29 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___175 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___175 *ia_file;
};

struct dquot___175 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___178 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___175 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___175 {
	int qf_fmt_id;
	const struct quota_format_ops___175 *qf_ops;
	struct module___94 *qf_owner;
	struct quota_format_type___175 *qf_next;
};

struct quota_format_ops___175 {
	int (*check_quota_file)(struct super_block___175 *, int);
	int (*read_file_info)(struct super_block___175 *, int);
	int (*write_file_info)(struct super_block___175 *, int);
	int (*free_file_info)(struct super_block___175 *, int);
	int (*read_dqblk)(struct dquot___175 *);
	int (*commit_dqblk)(struct dquot___175 *);
	int (*release_dqblk)(struct dquot___175 *);
};

struct dquot_operations___175 {
	int (*write_dquot)(struct dquot___175 *);
	struct dquot___175 * (*alloc_dquot)(struct super_block___175 *, int);
	void (*destroy_dquot)(struct dquot___175 *);
	int (*acquire_dquot)(struct dquot___175 *);
	int (*release_dquot)(struct dquot___175 *);
	int (*mark_dirty)(struct dquot___175 *);
	int (*write_info)(struct super_block___175 *, int);
	qsize_t * (*get_reserved_space)(struct inode___175 *);
};

struct quotactl_ops___175 {
	int (*quota_on)(struct super_block___175 *, int, int, struct path___175 *);
	int (*quota_on_meta)(struct super_block___175 *, int, int);
	int (*quota_off)(struct super_block___175 *, int);
	int (*quota_sync)(struct super_block___175 *, int);
	int (*get_info)(struct super_block___175 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___175 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___175 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___175 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___175 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___175 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___175 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___175 *, unsigned int);
};

struct address_space_operations___175 {
	int (*writepage)(struct page___174 *, struct writeback_control *);
	int (*readpage)(struct file___175 *, struct page___174 *);
	int (*writepages)(struct address_space___175 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___174 *);
	int (*readpages)(struct file___175 *, struct address_space___175 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___175 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___174 **, void **);
	int (*write_end)(struct file___175 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___174 *, void *);
	sector_t (*bmap)(struct address_space___175 *, sector_t);
	void (*invalidatepage)(struct page___174 *, long unsigned int);
	int (*releasepage)(struct page___174 *, gfp_t);
	void (*freepage)(struct page___174 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___175 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___175 *, struct page___174 *, struct page___174 *, enum migrate_mode);
	int (*launder_page)(struct page___174 *);
	int (*is_partially_uptodate)(struct page___174 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___174 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___175 *, struct page___174 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___175 *, sector_t *);
	void (*swap_deactivate)(struct file___175 *);
	void (*invalidatepage_range)(struct page___174 *, unsigned int, unsigned int);
};

struct bdi_writeback___39 {
	struct backing_dev_info___39 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___39 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___39 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___140 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___175 *debug_dir;
	struct dentry___175 *debug_stats;
};

struct hd_struct___30 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___140 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___30;

struct block_device_operations___29;

struct disk_events___2;

struct gendisk___30 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___30 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___30 *part_tbl;
	struct hd_struct___30 part0;
	const struct block_device_operations___29 *fops;
	struct request_queue___29 *queue;
	void *private_data;
	int flags;
	struct device___140 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events___2 *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___29 {
	struct request_queue___29 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___29(struct request_queue___29 *);

typedef void make_request_fn___29(struct request_queue___29 *, struct bio___30 *);

struct request___29;

typedef int prep_rq_fn___29(struct request_queue___29 *, struct request___29 *);

struct bvec_merge_data___29;

typedef int merge_bvec_fn___30(struct request_queue___29 *, struct bvec_merge_data___29 *, struct bio_vec___30 *);

typedef void softirq_done_fn___29(struct request___29 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___29(struct request___29 *);

typedef int dma_drain_needed_fn___29(struct request___29 *);

typedef int lld_busy_fn___29(struct request_queue___29 *);

struct bsg_class_device___29 {
	struct device___140 *class_dev;
	struct device___140 *parent;
	int minor;
	struct request_queue___29 *queue;
	struct kref ref;
	void (*release)(struct device___140 *);
};

typedef void unprep_rq_fn___29(struct request_queue___29 *, struct request___29 *);

struct elevator_queue___29;

struct blk_mq_ops___8;

struct blk_mq_ctx___8;

struct blk_mq_hw_ctx___8;

struct blk_queue_tag___29;

struct blk_mq_tag_set___8;

struct blk_flush_queue___8;

struct request_queue___29 {
	struct list_head queue_head;
	struct request___29 *last_merge;
	struct elevator_queue___29 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___29 root_rl;
	request_fn_proc___29 *request_fn;
	make_request_fn___29 *make_request_fn;
	prep_rq_fn___29 *prep_rq_fn;
	merge_bvec_fn___30 *merge_bvec_fn;
	softirq_done_fn___29 *softirq_done_fn;
	rq_timed_out_fn___29 *rq_timed_out_fn;
	dma_drain_needed_fn___29 *dma_drain_needed;
	lld_busy_fn___29 *lld_busy_fn;
	struct blk_mq_ops___8 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___8 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___29 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___39 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___140 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___29 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___29 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___178 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___29 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___29 *unprep_rq_fn;
	struct blk_mq_tag_set___8 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___30 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___8 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___175 {
	struct dentry___175 * (*lookup)(struct inode___175 *, struct dentry___175 *, unsigned int);
	void * (*follow_link)(struct dentry___175 *, struct nameidata *);
	int (*permission)(struct inode___175 *, int);
	struct posix_acl * (*get_acl)(struct inode___175 *, int);
	int (*readlink)(struct dentry___175 *, char *, int);
	void (*put_link)(struct dentry___175 *, struct nameidata *, void *);
	int (*create)(struct inode___175 *, struct dentry___175 *, umode_t, bool);
	int (*link)(struct dentry___175 *, struct inode___175 *, struct dentry___175 *);
	int (*unlink)(struct inode___175 *, struct dentry___175 *);
	int (*symlink)(struct inode___175 *, struct dentry___175 *, const char *);
	int (*mkdir)(struct inode___175 *, struct dentry___175 *, umode_t);
	int (*rmdir)(struct inode___175 *, struct dentry___175 *);
	int (*mknod)(struct inode___175 *, struct dentry___175 *, umode_t, dev_t);
	int (*rename)(struct inode___175 *, struct dentry___175 *, struct inode___175 *, struct dentry___175 *);
	int (*setattr)(struct dentry___175 *, struct iattr___175 *);
	int (*getattr)(struct vfsmount *, struct dentry___175 *, struct kstat *);
	int (*setxattr)(struct dentry___175 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___175 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___175 *, char *, size_t);
	int (*removexattr)(struct dentry___175 *, const char *);
	int (*fiemap)(struct inode___175 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___175 *, struct timespec *, int);
	int (*atomic_open)(struct inode___175 *, struct dentry___175 *, struct file___175 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___126;

struct file_operations___175 {
	struct module___94 *owner;
	loff_t (*llseek)(struct file___175 *, loff_t, int);
	ssize_t (*read)(struct file___175 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___175 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___175 *, void *, filldir_t);
	unsigned int (*poll)(struct file___175 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___175 *, struct vm_area_struct___182 *);
	int (*open)(struct inode___175 *, struct file___175 *);
	int (*flush)(struct file___175 *, fl_owner_t);
	int (*release)(struct inode___175 *, struct file___175 *);
	int (*fsync)(struct file___175 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___175 *, int);
	int (*lock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*sendpage)(struct file___175 *, struct page___174 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___175 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___175 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___175 *, long int, struct file_lock___175 **, void **);
		struct {
			int (*setlease)(struct file___175 *, long int, struct file_lock___175 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___175 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___126 *, struct file___175 *);
};

struct fasync_struct___175;

struct file_lock_operations___175;

struct lock_manager_operations___175;

struct file_lock___175 {
	struct file_lock___175 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___175 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___175 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___175 *fl_ops;
	const struct lock_manager_operations___175 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___175 {
	void (*fl_copy_lock)(struct file_lock___175 *, struct file_lock___175 *);
	void (*fl_release_private)(struct file_lock___175 *);
};

struct lock_manager_operations___175 {
	int (*lm_compare_owner)(struct file_lock___175 *, struct file_lock___175 *);
	long unsigned int (*lm_owner_key)(struct file_lock___175 *);
	void (*lm_notify)(struct file_lock___175 *);
	int (*lm_grant)(struct file_lock___175 *, struct file_lock___175 *, int);
	void (*lm_break)(struct file_lock___175 *);
	int (*lm_change)(struct file_lock___175 **, int);
};

struct fasync_struct___175 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___175 *fa_next;
	struct file___175 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___175 {
	const char *name;
	int fs_flags;
	struct dentry___175 * (*mount)(struct file_system_type___175 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___175 *);
	struct module___94 *owner;
	struct file_system_type___175 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___175 {
	struct inode___175 * (*alloc_inode)(struct super_block___175 *);
	void (*destroy_inode)(struct inode___175 *);
	void (*dirty_inode)(struct inode___175 *, int);
	int (*write_inode)(struct inode___175 *, struct writeback_control *);
	int (*drop_inode)(struct inode___175 *);
	void (*evict_inode)(struct inode___175 *);
	void (*put_super)(struct super_block___175 *);
	int (*sync_fs)(struct super_block___175 *, int);
	int (*freeze_fs)(struct super_block___175 *);
	int (*unfreeze_fs)(struct super_block___175 *);
	int (*statfs)(struct dentry___175 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___175 *, int *, char *);
	void (*umount_begin)(struct super_block___175 *);
	int (*show_options)(struct seq_file___126 *, struct dentry___175 *);
	int (*show_devname)(struct seq_file___126 *, struct dentry___175 *);
	int (*show_path)(struct seq_file___126 *, struct dentry___175 *);
	int (*show_stats)(struct seq_file___126 *, struct dentry___175 *);
	ssize_t (*quota_read)(struct super_block___175 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___175 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___175 *);
	int (*bdev_try_to_free_page)(struct super_block___175 *, struct page___174 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___175 *);
	void (*free_cached_objects)(struct super_block___175 *, int);
};

struct seq_operations___126;

struct seq_file___126 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___178 lock;
	const struct seq_operations___126 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kmem_cache_cpu___160 {
	void **freelist;
	long unsigned int tid;
	struct page___174 *page;
	struct page___174 *partial;
};

struct memcg_cache_params___161;

struct kmem_cache___161 {
	struct kmem_cache_cpu___160 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___161 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___161 {
	bool is_root_cache;
	union {
		struct kmem_cache___161 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___161 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct klist {
	spinlock_t k_lock;
	struct list_head k_list;
	void (*get)(struct klist_node *);
	void (*put)(struct klist_node *);
};

struct klist_iter {
	struct klist *i_klist;
	struct klist_node *i_cur;
};

struct bus_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___140 *, char *);
	ssize_t (*store)(struct bus_type___140 *, const char *, size_t);
};

struct device_attribute___140;

struct driver_attribute___140;

struct bus_type___140 {
	const char *name;
	const char *dev_name;
	struct device___140 *dev_root;
	struct bus_attribute___140 *bus_attrs;
	struct device_attribute___140 *dev_attrs;
	struct driver_attribute___140 *drv_attrs;
	const struct attribute_group___132 **bus_groups;
	const struct attribute_group___132 **dev_groups;
	const struct attribute_group___132 **drv_groups;
	int (*match)(struct device___140 *, struct device_driver___140 *);
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	int (*probe)(struct device___140 *);
	int (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*online)(struct device___140 *);
	int (*offline)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct device___140 *, struct device_attribute___140 *, char *);
	ssize_t (*store)(struct device___140 *, struct device_attribute___140 *, const char *, size_t);
};

struct driver_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___140 *, char *);
	ssize_t (*store)(struct device_driver___140 *, const char *, size_t);
};

struct device_driver___140 {
	const char *name;
	struct bus_type___140 *bus;
	struct module___94 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___140 *);
	int (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	const struct attribute_group___132 **groups;
	const struct dev_pm_ops___140 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___140 {
	const char *name;
	const struct attribute_group___132 **groups;
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
};

struct class_attribute___140;

struct class___140 {
	const char *name;
	struct module___94 *owner;
	struct class_attribute___140 *class_attrs;
	struct device_attribute___140 *dev_attrs;
	const struct attribute_group___132 **dev_groups;
	struct bin_attribute___134 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *);
	void (*class_release)(struct class___140 *);
	void (*dev_release)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
	struct subsys_private *p;
};

struct class_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct class___140 *, struct class_attribute___140 *, char *);
	ssize_t (*store)(struct class___140 *, struct class_attribute___140 *, const char *, size_t);
	const void * (*namespace)(struct class___140 *, const struct class_attribute___140 *);
};

struct class_dev_iter {
	struct klist_iter ki;
	const struct device_type___140 *type;
};

struct device_rh___140 {
	struct dev_pm_info_rh___140 power;
};

struct disk_part_tbl___30 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___30 *last_lookup;
	struct hd_struct___30 *part[0];
};

struct block_device_operations___29 {
	int (*open)(struct block_device___175 *, fmode_t);
	void (*release)(struct gendisk___30 *, fmode_t);
	int (*ioctl)(struct block_device___175 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___175 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___175 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___30 *, unsigned int);
	int (*media_changed)(struct gendisk___30 *);
	void (*unlock_native_capacity)(struct gendisk___30 *);
	int (*revalidate_disk)(struct gendisk___30 *);
	int (*getgeo)(struct block_device___175 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___175 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___94 *owner;
};

struct disk_events___2 {
	struct list_head node;
	struct gendisk___30 *disk;
	spinlock_t lock;
	struct mutex___178 block_mutex;
	int block;
	unsigned int pending;
	unsigned int clearing;
	long int poll_msecs;
	struct delayed_work dwork;
};

struct disk_part_iter___2 {
	struct gendisk___30 *disk;
	struct hd_struct___30 *part;
	int idx;
	unsigned int flags;
};

struct xol_area___174 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___174 *page;
	long unsigned int vaddr;
};

struct vm_fault___152;

struct vm_operations_struct___155 {
	void (*open)(struct vm_area_struct___182 *);
	void (*close)(struct vm_area_struct___182 *);
	int (*fault)(struct vm_area_struct___182 *, struct vm_fault___152 *);
	int (*page_mkwrite)(struct vm_area_struct___182 *, struct vm_fault___152 *);
	int (*access)(struct vm_area_struct___182 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___182 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___182 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___182 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___182 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___177 {
	struct task_struct___177 *task;
	struct core_thread___177 *next;
};

struct core_state___177 {
	atomic_t nr_threads;
	struct core_thread___177 dumper;
	struct completion startup;
};

struct signal_struct___177 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___177 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___177 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___178 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___152 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___174 *page;
};

struct irq_chip___121 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___121 *);
	void (*irq_shutdown)(struct irq_data___121 *);
	void (*irq_enable)(struct irq_data___121 *);
	void (*irq_disable)(struct irq_data___121 *);
	void (*irq_ack)(struct irq_data___121 *);
	void (*irq_mask)(struct irq_data___121 *);
	void (*irq_mask_ack)(struct irq_data___121 *);
	void (*irq_unmask)(struct irq_data___121 *);
	void (*irq_eoi)(struct irq_data___121 *);
	int (*irq_set_affinity)(struct irq_data___121 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___121 *);
	int (*irq_set_type)(struct irq_data___121 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___121 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___121 *);
	void (*irq_bus_sync_unlock)(struct irq_data___121 *);
	void (*irq_cpu_online)(struct irq_data___121 *);
	void (*irq_cpu_offline)(struct irq_data___121 *);
	void (*irq_suspend)(struct irq_data___121 *);
	void (*irq_resume)(struct irq_data___121 *);
	void (*irq_pm_shutdown)(struct irq_data___121 *);
	void (*irq_print_chip)(struct irq_data___121 *, struct seq_file___126 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___121 *, void *);
	long unsigned int flags;
};

struct io_cq___29 {
	struct request_queue___29 *q;
	struct io_context___29 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___161 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___29(struct request___29 *, int);

struct request___29 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___29 *q;
	struct blk_mq_ctx___8 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___30 *bio;
	struct bio___30 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___29 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___29 *saved_end_io;
		} flush;
	};
	struct gendisk___30 *rq_disk;
	struct hd_struct___30 *part;
	long unsigned int start_time;
	struct request_list___29 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___29 *end_io;
	void *end_io_data;
	struct request___29 *next_rq;
};

struct blk_mq_ctx___8 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___29 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___29(struct request_queue___29 *, struct request___29 **, struct bio___30 *);

typedef void elevator_merge_req_fn___29(struct request_queue___29 *, struct request___29 *, struct request___29 *);

typedef void elevator_merged_fn___29(struct request_queue___29 *, struct request___29 *, int);

typedef int elevator_allow_merge_fn___29(struct request_queue___29 *, struct request___29 *, struct bio___30 *);

typedef void elevator_bio_merged_fn___29(struct request_queue___29 *, struct request___29 *, struct bio___30 *);

typedef int elevator_dispatch_fn___29(struct request_queue___29 *, int);

typedef void elevator_add_req_fn___29(struct request_queue___29 *, struct request___29 *);

typedef struct request___29 *elevator_request_list_fn___29(struct request_queue___29 *, struct request___29 *);

typedef void elevator_completed_req_fn___29(struct request_queue___29 *, struct request___29 *);

typedef int elevator_may_queue_fn___29(struct request_queue___29 *, int);

typedef void elevator_init_icq_fn___29(struct io_cq___29 *);

typedef void elevator_exit_icq_fn___29(struct io_cq___29 *);

typedef int elevator_set_req_fn___29(struct request_queue___29 *, struct request___29 *, struct bio___30 *, gfp_t);

typedef void elevator_put_req_fn___29(struct request___29 *);

typedef void elevator_activate_req_fn___29(struct request_queue___29 *, struct request___29 *);

typedef void elevator_deactivate_req_fn___29(struct request_queue___29 *, struct request___29 *);

struct elevator_type___29;

typedef int elevator_init_fn___30(struct request_queue___29 *, struct elevator_type___29 *);

typedef void elevator_exit_fn___29(struct elevator_queue___29 *);

struct elevator_ops___29 {
	elevator_merge_fn___29 *elevator_merge_fn;
	elevator_merged_fn___29 *elevator_merged_fn;
	elevator_merge_req_fn___29 *elevator_merge_req_fn;
	elevator_allow_merge_fn___29 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___29 *elevator_bio_merged_fn;
	elevator_dispatch_fn___29 *elevator_dispatch_fn;
	elevator_add_req_fn___29 *elevator_add_req_fn;
	elevator_activate_req_fn___29 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___29 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___29 *elevator_completed_req_fn;
	elevator_request_list_fn___29 *elevator_former_req_fn;
	elevator_request_list_fn___29 *elevator_latter_req_fn;
	elevator_init_icq_fn___29 *elevator_init_icq_fn;
	elevator_exit_icq_fn___29 *elevator_exit_icq_fn;
	elevator_set_req_fn___29 *elevator_set_req_fn;
	elevator_put_req_fn___29 *elevator_put_req_fn;
	elevator_may_queue_fn___29 *elevator_may_queue_fn;
	elevator_init_fn___30 *elevator_init_fn;
	elevator_exit_fn___29 *elevator_exit_fn;
};

struct elv_fs_entry___29;

struct elevator_type___29 {
	struct kmem_cache___161 *icq_cache;
	struct elevator_ops___29 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___29 *elevator_attrs;
	char elevator_name[16];
	struct module___94 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___29 {
	struct elevator_type___29 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___178 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___29 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___29 *, char *);
	ssize_t (*store)(struct elevator_queue___29 *, const char *, size_t);
};

struct bvec_merge_data___29 {
	struct block_device___175 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___29 {
	struct request___29 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___8;

typedef int queue_rq_fn___9(struct blk_mq_hw_ctx___8 *, const struct blk_mq_queue_data___8 *);

typedef struct blk_mq_hw_ctx___8 *map_queue_fn___9(struct request_queue___29 *, const int);

typedef enum blk_eh_timer_return timeout_fn___9(struct request___29 *, bool);

typedef int init_request_fn___9(void *, struct request___29 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___9(void *, struct request___29 *, unsigned int, unsigned int);

typedef int init_hctx_fn___8(struct blk_mq_hw_ctx___8 *, void *, unsigned int);

typedef void exit_hctx_fn___8(struct blk_mq_hw_ctx___8 *, unsigned int);

struct blk_mq_ops___8 {
	queue_rq_fn___9 *queue_rq;
	map_queue_fn___9 *map_queue;
	union {
		timeout_fn___9 *timeout;
		struct {
			rq_timed_out_fn___29 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___29 *complete;
	init_request_fn___9 *init_request;
	exit_request_fn___9 *exit_request;
	init_hctx_fn___8 *init_hctx;
	exit_hctx_fn___8 *exit_hctx;
};

struct blk_mq_hw_ctx___8 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___29 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___8 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___29 **padding2;
		struct {
			struct request___29 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___8 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___8 {
	struct blk_mq_ops___8 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___178 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___8 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___29 *flush_rq;
	struct request___29 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct seq_operations___126 {
	void * (*start)(struct seq_file___126 *, loff_t *);
	void (*stop)(struct seq_file___126 *, void *);
	void * (*next)(struct seq_file___126 *, void *, loff_t *);
	int (*show)(struct seq_file___126 *, void *);
};

typedef struct kobject___4 *kobj_probe_t___2(dev_t, int *, void *);

struct blk_mq_queue_data___8 {
	struct request___29 *rq;
	struct list_head *list;
	bool last;
};

struct blk_major_name {
	struct blk_major_name *next;
	int major;
	char name[16];
};

struct page___175;

typedef struct page___175 *pgtable_t___175;

struct address_space___176;

struct kmem_cache___162;

struct page___175 {
	long unsigned int flags;
	struct address_space___176 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___175 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___175 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___162 *slab_cache;
		struct page___175 *first_page;
	};
	long: 64;
};

struct task_struct___178;

struct pv_cpu_ops___178 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___178 *);
	void (*end_context_switch)(struct task_struct___178 *);
};

struct mutex___179 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___178 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___171 {
	struct page___175 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___183;

struct signal_struct___178;

struct bio_list___30;

struct backing_dev_info___40;

struct io_context___30;

struct task_struct___178 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___178 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___183 *mm;
	struct mm_struct___183 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___178 *real_parent;
	struct task_struct___178 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___178 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___178 = 0,
		VTIME_USER___178 = 1,
		VTIME_SYS___178 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___178 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___30 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___40 *backing_dev_info;
	struct io_context___30 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___179 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___171 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___183 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___183 *, struct mm_struct___183 *);
	void (*dup_mmap)(struct mm_struct___183 *, struct mm_struct___183 *);
	void (*exit_mmap)(struct mm_struct___183 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___183 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___183 *);
	void (*pgd_free)(struct mm_struct___183 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___183 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___183 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___183 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___183 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___183 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___183 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___183 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___183 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___183 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___183 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___183 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___179 lock;
	void *vdso;
} mm_context_t___179;

struct xol_area___175;

struct uprobes_state___175 {
	struct xol_area___175 *xol_area;
};

struct vm_area_struct___183;

struct file___176;

struct core_state___178;

struct mm_struct___183 {
	struct vm_area_struct___183 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___183 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___183 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___179 context;
	long unsigned int flags;
	struct core_state___178 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___178 *owner;
	struct file___176 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___175 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___95;

struct module_kobject___94 {
	struct kobject___4 kobj;
	struct module___95 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___94;

struct module___95 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___94 mkobj;
	struct module_attribute___94 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___178 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___178;

struct lruvec___178 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___178 *zone;
};

struct pglist_data___178;

struct zone___178 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___178 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___178 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___178 {
	struct zone___178 *zone;
	int zone_idx;
};

struct zonelist___178 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___178 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___178 {
	struct zone___178 node_zones[4];
	struct zonelist___178 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___178 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___141;

struct dev_pm_ops___141 {
	int (*prepare)(struct device___141 *);
	void (*complete)(struct device___141 *);
	int (*suspend)(struct device___141 *);
	int (*resume)(struct device___141 *);
	int (*freeze)(struct device___141 *);
	int (*thaw)(struct device___141 *);
	int (*poweroff)(struct device___141 *);
	int (*restore)(struct device___141 *);
	int (*suspend_late)(struct device___141 *);
	int (*resume_early)(struct device___141 *);
	int (*freeze_late)(struct device___141 *);
	int (*thaw_early)(struct device___141 *);
	int (*poweroff_late)(struct device___141 *);
	int (*restore_early)(struct device___141 *);
	int (*suspend_noirq)(struct device___141 *);
	int (*resume_noirq)(struct device___141 *);
	int (*freeze_noirq)(struct device___141 *);
	int (*thaw_noirq)(struct device___141 *);
	int (*poweroff_noirq)(struct device___141 *);
	int (*restore_noirq)(struct device___141 *);
	int (*runtime_suspend)(struct device___141 *);
	int (*runtime_resume)(struct device___141 *);
	int (*runtime_idle)(struct device___141 *);
};

struct dma_map_ops___57;

struct dev_archdata___57 {
	struct dma_map_ops___57 *dma_ops;
	void *iommu;
};

struct device_type___141;

struct bus_type___141;

struct device_driver___141;

struct dev_pm_domain___141;

struct class___141;

struct attribute_group___133;

struct device_rh___141;

struct device___141 {
	struct device___141 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___141 *type;
	struct mutex___179 mutex;
	struct bus_type___141 *bus;
	struct device_driver___141 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___141 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___57 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___141 *class;
	const struct attribute_group___133 **groups;
	void (*release)(struct device___141 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___141 *device_rh;
};

struct dev_pm_info_rh___141 {
	void (*set_latency_tolerance)(struct device___141 *, s32);
};

struct dev_pm_domain___141 {
	struct dev_pm_ops___141 ops;
};

struct smp_ops___178 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___178 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___135;

struct attribute_group___133 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___135 **bin_attrs;
};

struct bin_attribute___135 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___176 *, struct kobject___4 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___176 *, struct kobject___4 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	int (*mmap)(struct file___176 *, struct kobject___4 *, struct bin_attribute___135 *, struct vm_area_struct___183 *);
};

struct dentry___176;

struct path___176 {
	struct vfsmount *mnt;
	struct dentry___176 *dentry;
};

struct inode___176;

struct file_operations___176;

struct file___176 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___176 f_path;
	struct inode___176 *f_inode;
	const struct file_operations___176 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___176 *f_mapping;
	struct mutex___179 f_pos_lock;
};

struct vm_operations_struct___156;

struct vm_area_struct___183 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___183 *vm_next;
	struct vm_area_struct___183 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___183 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___156 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___176 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___94 *, struct module_kobject___94 *, char *);
	ssize_t (*store)(struct module_attribute___94 *, struct module_kobject___94 *, const char *, size_t);
	void (*setup)(struct module___95 *, const char *);
	int (*test)(struct module___95 *);
	void (*free)(struct module___95 *);
};

struct xol_area___175 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___175 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___161;

struct memcg_cache_params___162;

struct kmem_cache___162 {
	struct kmem_cache_cpu___161 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___162 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___176;

struct address_space___176 {
	struct inode___176 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___179 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___176 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___40 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___153;

struct vm_operations_struct___156 {
	void (*open)(struct vm_area_struct___183 *);
	void (*close)(struct vm_area_struct___183 *);
	int (*fault)(struct vm_area_struct___183 *, struct vm_fault___153 *);
	int (*page_mkwrite)(struct vm_area_struct___183 *, struct vm_fault___153 *);
	int (*access)(struct vm_area_struct___183 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___183 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___183 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___183 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___183 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___178 {
	struct task_struct___178 *task;
	struct core_thread___178 *next;
};

struct core_state___178 {
	atomic_t nr_threads;
	struct core_thread___178 dumper;
	struct completion startup;
};

struct signal_struct___178 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___178 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___178 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___179 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___31;

struct bio_list___30 {
	struct bio___31 *head;
	struct bio___31 *tail;
};

struct bdi_writeback___40 {
	struct backing_dev_info___40 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___40 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___40 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___141 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___176 *debug_dir;
	struct dentry___176 *debug_stats;
};

struct io_cq___30;

struct io_context___30 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___30 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___161 {
	void **freelist;
	long unsigned int tid;
	struct page___175 *page;
	struct page___175 *partial;
};

struct memcg_cache_params___162 {
	bool is_root_cache;
	union {
		struct kmem_cache___162 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___162 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___57 {
	void * (*alloc)(struct device___141 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___141 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___141 *, struct vm_area_struct___183 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___141 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___141 *, struct page___175 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___141 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___141 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___141 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___141 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___141 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___141 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___141 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___141 *, dma_addr_t);
	int (*dma_supported)(struct device___141 *, u64);
	int (*set_dma_mask)(struct device___141 *, u64);
	int is_phys;
};

struct bus_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___141 *, char *);
	ssize_t (*store)(struct bus_type___141 *, const char *, size_t);
};

struct device_attribute___141;

struct driver_attribute___141;

struct bus_type___141 {
	const char *name;
	const char *dev_name;
	struct device___141 *dev_root;
	struct bus_attribute___141 *bus_attrs;
	struct device_attribute___141 *dev_attrs;
	struct driver_attribute___141 *drv_attrs;
	const struct attribute_group___133 **bus_groups;
	const struct attribute_group___133 **dev_groups;
	const struct attribute_group___133 **drv_groups;
	int (*match)(struct device___141 *, struct device_driver___141 *);
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	int (*probe)(struct device___141 *);
	int (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*online)(struct device___141 *);
	int (*offline)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct device___141 *, struct device_attribute___141 *, char *);
	ssize_t (*store)(struct device___141 *, struct device_attribute___141 *, const char *, size_t);
};

struct driver_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___141 *, char *);
	ssize_t (*store)(struct device_driver___141 *, const char *, size_t);
};

struct device_driver___141 {
	const char *name;
	struct bus_type___141 *bus;
	struct module___95 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___141 *);
	int (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	const struct attribute_group___133 **groups;
	const struct dev_pm_ops___141 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___141 {
	const char *name;
	const struct attribute_group___133 **groups;
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
};

struct class_attribute___141;

struct class___141 {
	const char *name;
	struct module___95 *owner;
	struct class_attribute___141 *class_attrs;
	struct device_attribute___141 *dev_attrs;
	const struct attribute_group___133 **dev_groups;
	struct bin_attribute___135 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *);
	void (*class_release)(struct class___141 *);
	void (*dev_release)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
	struct subsys_private *p;
};

struct class_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct class___141 *, struct class_attribute___141 *, char *);
	ssize_t (*store)(struct class___141 *, struct class_attribute___141 *, const char *, size_t);
	const void * (*namespace)(struct class___141 *, const struct class_attribute___141 *);
};

struct device_rh___141 {
	struct dev_pm_info_rh___141 power;
};

struct dentry_operations___176;

struct super_block___176;

struct dentry___176 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___176 *d_parent;
	struct qstr d_name;
	struct inode___176 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___176 *d_op;
	struct super_block___176 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___176;

struct file_lock___176;

struct dquot___176;

struct block_device___176;

struct inode___176 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___176 *i_op;
	struct super_block___176 *i_sb;
	struct address_space___176 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___179 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___176 *i_fop;
	struct file_lock___176 *i_flock;
	struct address_space___176 i_data;
	struct dquot___176 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___176 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___176 {
	int (*d_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_hash)(const struct dentry___176 *, struct qstr *);
	int (*d_compare)(const struct dentry___176 *, const struct dentry___176 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___176 *);
	void (*d_release)(struct dentry___176 *);
	void (*d_prune)(struct dentry___176 *);
	void (*d_iput)(struct dentry___176 *, struct inode___176 *);
	char * (*d_dname)(struct dentry___176 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___176 *);
	int (*d_manage)(struct dentry___176 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___176;

struct mem_dqinfo___176 {
	struct quota_format_type___176 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___176;

struct quota_info___176 {
	unsigned int flags;
	struct mutex___179 dqio_mutex;
	struct mutex___179 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___176 *files[2];
	struct mem_dqinfo___176 info[2];
	const struct quota_format_ops___176 *ops[2];
};

struct file_system_type___176;

struct super_operations___176;

struct dquot_operations___176;

struct quotactl_ops___176;

struct super_block___176 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___176 *s_type;
	const struct super_operations___176 *s_op;
	const struct dquot_operations___176 *dq_op;
	const struct quotactl_ops___176 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___176 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___176 *s_bdev;
	struct backing_dev_info___40 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___176 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___179 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___176 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___31(struct bio___31 *, int);

struct bio_vec___31 {
	struct page___175 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___31;

struct bio_set___31;

struct bio___31 {
	sector_t bi_sector;
	struct bio___31 *bi_next;
	struct block_device___176 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___31 *bi_end_io;
	void *bi_private;
	struct io_context___30 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___31 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___31 *bi_io_vec;
	struct bio_set___31 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___31 bi_inline_vecs[0];
};

struct hd_struct___31;

struct gendisk___31;

struct request_queue___30;

struct block_device___176 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___176 *bd_inode;
	struct super_block___176 *bd_super;
	struct mutex___179 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___176 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___31 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___31 *bd_disk;
	struct request_queue___30 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___179 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___31 {
	struct bio___31 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___31 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___31 *bip_vec;
	struct bio_vec___31 bip_inline_vecs[0];
};

struct bio_set___31 {
	struct kmem_cache___162 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___30 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___176 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___176 *ia_file;
};

struct dquot___176 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___179 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___176 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___176 {
	int qf_fmt_id;
	const struct quota_format_ops___176 *qf_ops;
	struct module___95 *qf_owner;
	struct quota_format_type___176 *qf_next;
};

struct quota_format_ops___176 {
	int (*check_quota_file)(struct super_block___176 *, int);
	int (*read_file_info)(struct super_block___176 *, int);
	int (*write_file_info)(struct super_block___176 *, int);
	int (*free_file_info)(struct super_block___176 *, int);
	int (*read_dqblk)(struct dquot___176 *);
	int (*commit_dqblk)(struct dquot___176 *);
	int (*release_dqblk)(struct dquot___176 *);
};

struct dquot_operations___176 {
	int (*write_dquot)(struct dquot___176 *);
	struct dquot___176 * (*alloc_dquot)(struct super_block___176 *, int);
	void (*destroy_dquot)(struct dquot___176 *);
	int (*acquire_dquot)(struct dquot___176 *);
	int (*release_dquot)(struct dquot___176 *);
	int (*mark_dirty)(struct dquot___176 *);
	int (*write_info)(struct super_block___176 *, int);
	qsize_t * (*get_reserved_space)(struct inode___176 *);
};

struct quotactl_ops___176 {
	int (*quota_on)(struct super_block___176 *, int, int, struct path___176 *);
	int (*quota_on_meta)(struct super_block___176 *, int, int);
	int (*quota_off)(struct super_block___176 *, int);
	int (*quota_sync)(struct super_block___176 *, int);
	int (*get_info)(struct super_block___176 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___176 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___176 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___176 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___176 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___176 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___176 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___176 *, unsigned int);
};

struct address_space_operations___176 {
	int (*writepage)(struct page___175 *, struct writeback_control *);
	int (*readpage)(struct file___176 *, struct page___175 *);
	int (*writepages)(struct address_space___176 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___175 *);
	int (*readpages)(struct file___176 *, struct address_space___176 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___176 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___175 **, void **);
	int (*write_end)(struct file___176 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___175 *, void *);
	sector_t (*bmap)(struct address_space___176 *, sector_t);
	void (*invalidatepage)(struct page___175 *, long unsigned int);
	int (*releasepage)(struct page___175 *, gfp_t);
	void (*freepage)(struct page___175 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___176 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___176 *, struct page___175 *, struct page___175 *, enum migrate_mode);
	int (*launder_page)(struct page___175 *);
	int (*is_partially_uptodate)(struct page___175 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___175 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___176 *, struct page___175 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___176 *, sector_t *);
	void (*swap_deactivate)(struct file___176 *);
	void (*invalidatepage_range)(struct page___175 *, unsigned int, unsigned int);
};

struct hd_struct___31 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___141 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___31;

struct block_device_operations___30;

struct gendisk___31 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___31 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___31 *part_tbl;
	struct hd_struct___31 part0;
	const struct block_device_operations___30 *fops;
	struct request_queue___30 *queue;
	void *private_data;
	int flags;
	struct device___141 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___30 {
	struct request_queue___30 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___30(struct request_queue___30 *);

typedef void make_request_fn___30(struct request_queue___30 *, struct bio___31 *);

struct request___30;

typedef int prep_rq_fn___30(struct request_queue___30 *, struct request___30 *);

struct bvec_merge_data___30;

typedef int merge_bvec_fn___31(struct request_queue___30 *, struct bvec_merge_data___30 *, struct bio_vec___31 *);

typedef void softirq_done_fn___30(struct request___30 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___30(struct request___30 *);

typedef int dma_drain_needed_fn___30(struct request___30 *);

typedef int lld_busy_fn___30(struct request_queue___30 *);

struct bsg_class_device___30 {
	struct device___141 *class_dev;
	struct device___141 *parent;
	int minor;
	struct request_queue___30 *queue;
	struct kref ref;
	void (*release)(struct device___141 *);
};

typedef void unprep_rq_fn___30(struct request_queue___30 *, struct request___30 *);

struct elevator_queue___30;

struct blk_queue_tag___30;

struct request_queue___30 {
	struct list_head queue_head;
	struct request___30 *last_merge;
	struct elevator_queue___30 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___30 root_rl;
	request_fn_proc___30 *request_fn;
	make_request_fn___30 *make_request_fn;
	prep_rq_fn___30 *prep_rq_fn;
	merge_bvec_fn___31 *merge_bvec_fn;
	softirq_done_fn___30 *softirq_done_fn;
	rq_timed_out_fn___30 *rq_timed_out_fn;
	dma_drain_needed_fn___30 *dma_drain_needed;
	lld_busy_fn___30 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___30 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___40 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___141 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___30 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___30 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___179 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___30 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___30 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___31 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___176 {
	struct dentry___176 * (*lookup)(struct inode___176 *, struct dentry___176 *, unsigned int);
	void * (*follow_link)(struct dentry___176 *, struct nameidata *);
	int (*permission)(struct inode___176 *, int);
	struct posix_acl * (*get_acl)(struct inode___176 *, int);
	int (*readlink)(struct dentry___176 *, char *, int);
	void (*put_link)(struct dentry___176 *, struct nameidata *, void *);
	int (*create)(struct inode___176 *, struct dentry___176 *, umode_t, bool);
	int (*link)(struct dentry___176 *, struct inode___176 *, struct dentry___176 *);
	int (*unlink)(struct inode___176 *, struct dentry___176 *);
	int (*symlink)(struct inode___176 *, struct dentry___176 *, const char *);
	int (*mkdir)(struct inode___176 *, struct dentry___176 *, umode_t);
	int (*rmdir)(struct inode___176 *, struct dentry___176 *);
	int (*mknod)(struct inode___176 *, struct dentry___176 *, umode_t, dev_t);
	int (*rename)(struct inode___176 *, struct dentry___176 *, struct inode___176 *, struct dentry___176 *);
	int (*setattr)(struct dentry___176 *, struct iattr___176 *);
	int (*getattr)(struct vfsmount *, struct dentry___176 *, struct kstat *);
	int (*setxattr)(struct dentry___176 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___176 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___176 *, char *, size_t);
	int (*removexattr)(struct dentry___176 *, const char *);
	int (*fiemap)(struct inode___176 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___176 *, struct timespec *, int);
	int (*atomic_open)(struct inode___176 *, struct dentry___176 *, struct file___176 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___176 {
	struct module___95 *owner;
	loff_t (*llseek)(struct file___176 *, loff_t, int);
	ssize_t (*read)(struct file___176 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___176 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___176 *, void *, filldir_t);
	unsigned int (*poll)(struct file___176 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___176 *, struct vm_area_struct___183 *);
	int (*open)(struct inode___176 *, struct file___176 *);
	int (*flush)(struct file___176 *, fl_owner_t);
	int (*release)(struct inode___176 *, struct file___176 *);
	int (*fsync)(struct file___176 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___176 *, int);
	int (*lock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*sendpage)(struct file___176 *, struct page___175 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___176 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___176 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___176 *, long int, struct file_lock___176 **, void **);
		struct {
			int (*setlease)(struct file___176 *, long int, struct file_lock___176 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___176 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___176 *);
};

struct fasync_struct___176;

struct file_lock_operations___176;

struct lock_manager_operations___176;

struct file_lock___176 {
	struct file_lock___176 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___176 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___176 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___176 *fl_ops;
	const struct lock_manager_operations___176 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___176 {
	void (*fl_copy_lock)(struct file_lock___176 *, struct file_lock___176 *);
	void (*fl_release_private)(struct file_lock___176 *);
};

struct lock_manager_operations___176 {
	int (*lm_compare_owner)(struct file_lock___176 *, struct file_lock___176 *);
	long unsigned int (*lm_owner_key)(struct file_lock___176 *);
	void (*lm_notify)(struct file_lock___176 *);
	int (*lm_grant)(struct file_lock___176 *, struct file_lock___176 *, int);
	void (*lm_break)(struct file_lock___176 *);
	int (*lm_change)(struct file_lock___176 **, int);
};

struct fasync_struct___176 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___176 *fa_next;
	struct file___176 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___176 {
	const char *name;
	int fs_flags;
	struct dentry___176 * (*mount)(struct file_system_type___176 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___176 *);
	struct module___95 *owner;
	struct file_system_type___176 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___176 {
	struct inode___176 * (*alloc_inode)(struct super_block___176 *);
	void (*destroy_inode)(struct inode___176 *);
	void (*dirty_inode)(struct inode___176 *, int);
	int (*write_inode)(struct inode___176 *, struct writeback_control *);
	int (*drop_inode)(struct inode___176 *);
	void (*evict_inode)(struct inode___176 *);
	void (*put_super)(struct super_block___176 *);
	int (*sync_fs)(struct super_block___176 *, int);
	int (*freeze_fs)(struct super_block___176 *);
	int (*unfreeze_fs)(struct super_block___176 *);
	int (*statfs)(struct dentry___176 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___176 *, int *, char *);
	void (*umount_begin)(struct super_block___176 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___176 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___176 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___176 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___176 *);
	ssize_t (*quota_read)(struct super_block___176 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___176 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___176 *);
	int (*bdev_try_to_free_page)(struct super_block___176 *, struct page___175 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___176 *);
	void (*free_cached_objects)(struct super_block___176 *, int);
};

struct disk_part_tbl___31 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___31 *last_lookup;
	struct hd_struct___31 *part[0];
};

struct block_device_operations___30 {
	int (*open)(struct block_device___176 *, fmode_t);
	void (*release)(struct gendisk___31 *, fmode_t);
	int (*ioctl)(struct block_device___176 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___176 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___176 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___31 *, unsigned int);
	int (*media_changed)(struct gendisk___31 *);
	void (*unlock_native_capacity)(struct gendisk___31 *);
	int (*revalidate_disk)(struct gendisk___31 *);
	int (*getgeo)(struct block_device___176 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___176 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___95 *owner;
};

struct vm_fault___153 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___175 *page;
};

struct io_cq___30 {
	struct request_queue___30 *q;
	struct io_context___30 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___162 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___30(struct request___30 *, int);

struct request___30 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___30 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___31 *bio;
	struct bio___31 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___30 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___30 *saved_end_io;
		} flush;
	};
	struct gendisk___31 *rq_disk;
	struct hd_struct___31 *part;
	long unsigned int start_time;
	struct request_list___30 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___30 *end_io;
	void *end_io_data;
	struct request___30 *next_rq;
};

typedef int elevator_merge_fn___30(struct request_queue___30 *, struct request___30 **, struct bio___31 *);

typedef void elevator_merge_req_fn___30(struct request_queue___30 *, struct request___30 *, struct request___30 *);

typedef void elevator_merged_fn___30(struct request_queue___30 *, struct request___30 *, int);

typedef int elevator_allow_merge_fn___30(struct request_queue___30 *, struct request___30 *, struct bio___31 *);

typedef void elevator_bio_merged_fn___30(struct request_queue___30 *, struct request___30 *, struct bio___31 *);

typedef int elevator_dispatch_fn___30(struct request_queue___30 *, int);

typedef void elevator_add_req_fn___30(struct request_queue___30 *, struct request___30 *);

typedef struct request___30 *elevator_request_list_fn___30(struct request_queue___30 *, struct request___30 *);

typedef void elevator_completed_req_fn___30(struct request_queue___30 *, struct request___30 *);

typedef int elevator_may_queue_fn___30(struct request_queue___30 *, int);

typedef void elevator_init_icq_fn___30(struct io_cq___30 *);

typedef void elevator_exit_icq_fn___30(struct io_cq___30 *);

typedef int elevator_set_req_fn___30(struct request_queue___30 *, struct request___30 *, struct bio___31 *, gfp_t);

typedef void elevator_put_req_fn___30(struct request___30 *);

typedef void elevator_activate_req_fn___30(struct request_queue___30 *, struct request___30 *);

typedef void elevator_deactivate_req_fn___30(struct request_queue___30 *, struct request___30 *);

struct elevator_type___30;

typedef int elevator_init_fn___31(struct request_queue___30 *, struct elevator_type___30 *);

typedef void elevator_exit_fn___30(struct elevator_queue___30 *);

struct elevator_ops___30 {
	elevator_merge_fn___30 *elevator_merge_fn;
	elevator_merged_fn___30 *elevator_merged_fn;
	elevator_merge_req_fn___30 *elevator_merge_req_fn;
	elevator_allow_merge_fn___30 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___30 *elevator_bio_merged_fn;
	elevator_dispatch_fn___30 *elevator_dispatch_fn;
	elevator_add_req_fn___30 *elevator_add_req_fn;
	elevator_activate_req_fn___30 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___30 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___30 *elevator_completed_req_fn;
	elevator_request_list_fn___30 *elevator_former_req_fn;
	elevator_request_list_fn___30 *elevator_latter_req_fn;
	elevator_init_icq_fn___30 *elevator_init_icq_fn;
	elevator_exit_icq_fn___30 *elevator_exit_icq_fn;
	elevator_set_req_fn___30 *elevator_set_req_fn;
	elevator_put_req_fn___30 *elevator_put_req_fn;
	elevator_may_queue_fn___30 *elevator_may_queue_fn;
	elevator_init_fn___31 *elevator_init_fn;
	elevator_exit_fn___30 *elevator_exit_fn;
};

struct elv_fs_entry___30;

struct elevator_type___30 {
	struct kmem_cache___162 *icq_cache;
	struct elevator_ops___30 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___30 *elevator_attrs;
	char elevator_name[16];
	struct module___95 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___30 {
	struct elevator_type___30 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___179 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___30 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___30 *, char *);
	ssize_t (*store)(struct elevator_queue___30 *, const char *, size_t);
};

struct bvec_merge_data___30 {
	struct block_device___176 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___30 {
	struct request___30 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct rq_map_data___3 {
	struct page___175 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct request_sense;

struct cdrom_generic_command {
	unsigned char cmd[12];
	unsigned char *buffer;
	unsigned int buflen;
	int stat;
	struct request_sense *sense;
	unsigned char data_direction;
	int quiet;
	int timeout;
	void *reserved[1];
};

struct request_sense {
	__u8 error_code: 7;
	__u8 valid: 1;
	__u8 segment_number;
	__u8 sense_key: 4;
	__u8 reserved2: 1;
	__u8 ili: 1;
	__u8 reserved1: 2;
	__u8 information[4];
	__u8 add_sense_len;
	__u8 command_info[4];
	__u8 asc;
	__u8 ascq;
	__u8 fruc;
	__u8 sks[3];
	__u8 asb[46];
};

struct scsi_ioctl_command {
	unsigned int inlen;
	unsigned int outlen;
	unsigned char data[0];
};

struct blk_cmd_filter {
	long unsigned int read_ok[4];
	long unsigned int write_ok[4];
};

struct page___176;

typedef struct page___176 *pgtable_t___176;

struct address_space___177;

struct kmem_cache___163;

struct page___176 {
	long unsigned int flags;
	struct address_space___177 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___176 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___176 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___163 *slab_cache;
		struct page___176 *first_page;
	};
	long: 64;
};

struct task_struct___179;

struct pv_cpu_ops___179 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___179 *);
	void (*end_context_switch)(struct task_struct___179 *);
};

struct mutex___180 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___179 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___172 {
	struct page___176 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___184;

struct signal_struct___179;

struct bio_list___31;

struct backing_dev_info___41;

struct io_context___31;

struct task_struct___179 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___179 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___184 *mm;
	struct mm_struct___184 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___179 *real_parent;
	struct task_struct___179 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___179 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___179 = 0,
		VTIME_USER___179 = 1,
		VTIME_SYS___179 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___179 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___31 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___41 *backing_dev_info;
	struct io_context___31 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___180 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___172 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___184 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___184 *, struct mm_struct___184 *);
	void (*dup_mmap)(struct mm_struct___184 *, struct mm_struct___184 *);
	void (*exit_mmap)(struct mm_struct___184 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___184 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___184 *);
	void (*pgd_free)(struct mm_struct___184 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___184 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___184 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___184 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___184 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___184 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___184 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___184 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___184 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___184 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___184 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___184 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___180 lock;
	void *vdso;
} mm_context_t___180;

struct xol_area___176;

struct uprobes_state___176 {
	struct xol_area___176 *xol_area;
};

struct vm_area_struct___184;

struct file___177;

struct core_state___179;

struct mm_struct___184 {
	struct vm_area_struct___184 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___184 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___184 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___180 context;
	long unsigned int flags;
	struct core_state___179 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___179 *owner;
	struct file___177 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___176 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___96;

struct module_kobject___95 {
	struct kobject___4 kobj;
	struct module___96 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___95;

struct module___96 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___95 mkobj;
	struct module_attribute___95 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___179 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___179;

struct lruvec___179 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___179 *zone;
};

struct pglist_data___179;

struct zone___179 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___179 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___179 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___179 {
	struct zone___179 *zone;
	int zone_idx;
};

struct zonelist___179 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___179 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___179 {
	struct zone___179 node_zones[4];
	struct zonelist___179 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___179 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___142;

struct dev_pm_ops___142 {
	int (*prepare)(struct device___142 *);
	void (*complete)(struct device___142 *);
	int (*suspend)(struct device___142 *);
	int (*resume)(struct device___142 *);
	int (*freeze)(struct device___142 *);
	int (*thaw)(struct device___142 *);
	int (*poweroff)(struct device___142 *);
	int (*restore)(struct device___142 *);
	int (*suspend_late)(struct device___142 *);
	int (*resume_early)(struct device___142 *);
	int (*freeze_late)(struct device___142 *);
	int (*thaw_early)(struct device___142 *);
	int (*poweroff_late)(struct device___142 *);
	int (*restore_early)(struct device___142 *);
	int (*suspend_noirq)(struct device___142 *);
	int (*resume_noirq)(struct device___142 *);
	int (*freeze_noirq)(struct device___142 *);
	int (*thaw_noirq)(struct device___142 *);
	int (*poweroff_noirq)(struct device___142 *);
	int (*restore_noirq)(struct device___142 *);
	int (*runtime_suspend)(struct device___142 *);
	int (*runtime_resume)(struct device___142 *);
	int (*runtime_idle)(struct device___142 *);
};

struct device_type___142;

struct bus_type___142;

struct device_driver___142;

struct dev_pm_domain___142;

struct class___142;

struct attribute_group___134;

struct device_rh___142;

struct device___142 {
	struct device___142 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___142 *type;
	struct mutex___180 mutex;
	struct bus_type___142 *bus;
	struct device_driver___142 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___142 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___57 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___142 *class;
	const struct attribute_group___134 **groups;
	void (*release)(struct device___142 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___142 *device_rh;
};

struct dev_pm_info_rh___142 {
	void (*set_latency_tolerance)(struct device___142 *, s32);
};

struct dev_pm_domain___142 {
	struct dev_pm_ops___142 ops;
};

struct smp_ops___179 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___179 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___136;

struct attribute_group___134 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___136 **bin_attrs;
};

struct bin_attribute___136 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___177 *, struct kobject___4 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___177 *, struct kobject___4 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	int (*mmap)(struct file___177 *, struct kobject___4 *, struct bin_attribute___136 *, struct vm_area_struct___184 *);
};

struct dentry___177;

struct path___177 {
	struct vfsmount *mnt;
	struct dentry___177 *dentry;
};

struct inode___177;

struct file_operations___177;

struct file___177 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___177 f_path;
	struct inode___177 *f_inode;
	const struct file_operations___177 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___177 *f_mapping;
	struct mutex___180 f_pos_lock;
};

struct vm_operations_struct___157;

struct vm_area_struct___184 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___184 *vm_next;
	struct vm_area_struct___184 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___184 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___157 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___177 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___95 *, struct module_kobject___95 *, char *);
	ssize_t (*store)(struct module_attribute___95 *, struct module_kobject___95 *, const char *, size_t);
	void (*setup)(struct module___96 *, const char *);
	int (*test)(struct module___96 *);
	void (*free)(struct module___96 *);
};

struct dentry_operations___177;

struct super_block___177;

struct dentry___177 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___177 *d_parent;
	struct qstr d_name;
	struct inode___177 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___177 *d_op;
	struct super_block___177 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___177;

struct address_space___177 {
	struct inode___177 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___180 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___177 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___41 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___177;

struct file_lock___177;

struct dquot___177;

struct block_device___177;

struct inode___177 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___177 *i_op;
	struct super_block___177 *i_sb;
	struct address_space___177 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___180 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___177 *i_fop;
	struct file_lock___177 *i_flock;
	struct address_space___177 i_data;
	struct dquot___177 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___177 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___177 {
	int (*d_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_hash)(const struct dentry___177 *, struct qstr *);
	int (*d_compare)(const struct dentry___177 *, const struct dentry___177 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___177 *);
	void (*d_release)(struct dentry___177 *);
	void (*d_prune)(struct dentry___177 *);
	void (*d_iput)(struct dentry___177 *, struct inode___177 *);
	char * (*d_dname)(struct dentry___177 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___177 *);
	int (*d_manage)(struct dentry___177 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___177;

struct mem_dqinfo___177 {
	struct quota_format_type___177 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___177;

struct quota_info___177 {
	unsigned int flags;
	struct mutex___180 dqio_mutex;
	struct mutex___180 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___177 *files[2];
	struct mem_dqinfo___177 info[2];
	const struct quota_format_ops___177 *ops[2];
};

struct file_system_type___177;

struct super_operations___177;

struct dquot_operations___177;

struct quotactl_ops___177;

struct super_block___177 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___177 *s_type;
	const struct super_operations___177 *s_op;
	const struct dquot_operations___177 *dq_op;
	const struct quotactl_ops___177 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___177 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___177 *s_bdev;
	struct backing_dev_info___41 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___177 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___180 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___177 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___32;

typedef void bio_end_io_t___32(struct bio___32 *, int);

struct bio_vec___32 {
	struct page___176 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___32;

struct bio_set___32;

struct bio___32 {
	sector_t bi_sector;
	struct bio___32 *bi_next;
	struct block_device___177 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___32 *bi_end_io;
	void *bi_private;
	struct io_context___31 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___32 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___32 *bi_io_vec;
	struct bio_set___32 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___32 bi_inline_vecs[0];
};

struct hd_struct___32;

struct gendisk___32;

struct request_queue___31;

struct block_device___177 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___177 *bd_inode;
	struct super_block___177 *bd_super;
	struct mutex___180 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___177 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___32 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___32 *bd_disk;
	struct request_queue___31 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___180 bd_fsfreeze_mutex;
};

struct io_cq___31;

struct io_context___31 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___31 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___32 {
	struct bio___32 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___32 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___32 *bip_vec;
	struct bio_vec___32 bip_inline_vecs[0];
};

struct bio_list___31 {
	struct bio___32 *head;
	struct bio___32 *tail;
};

struct bio_set___32 {
	struct kmem_cache___163 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___31 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___177 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___177 *ia_file;
};

struct dquot___177 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___180 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___177 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___177 {
	int qf_fmt_id;
	const struct quota_format_ops___177 *qf_ops;
	struct module___96 *qf_owner;
	struct quota_format_type___177 *qf_next;
};

struct quota_format_ops___177 {
	int (*check_quota_file)(struct super_block___177 *, int);
	int (*read_file_info)(struct super_block___177 *, int);
	int (*write_file_info)(struct super_block___177 *, int);
	int (*free_file_info)(struct super_block___177 *, int);
	int (*read_dqblk)(struct dquot___177 *);
	int (*commit_dqblk)(struct dquot___177 *);
	int (*release_dqblk)(struct dquot___177 *);
};

struct dquot_operations___177 {
	int (*write_dquot)(struct dquot___177 *);
	struct dquot___177 * (*alloc_dquot)(struct super_block___177 *, int);
	void (*destroy_dquot)(struct dquot___177 *);
	int (*acquire_dquot)(struct dquot___177 *);
	int (*release_dquot)(struct dquot___177 *);
	int (*mark_dirty)(struct dquot___177 *);
	int (*write_info)(struct super_block___177 *, int);
	qsize_t * (*get_reserved_space)(struct inode___177 *);
};

struct quotactl_ops___177 {
	int (*quota_on)(struct super_block___177 *, int, int, struct path___177 *);
	int (*quota_on_meta)(struct super_block___177 *, int, int);
	int (*quota_off)(struct super_block___177 *, int);
	int (*quota_sync)(struct super_block___177 *, int);
	int (*get_info)(struct super_block___177 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___177 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___177 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___177 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___177 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___177 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___177 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___177 *, unsigned int);
};

struct address_space_operations___177 {
	int (*writepage)(struct page___176 *, struct writeback_control *);
	int (*readpage)(struct file___177 *, struct page___176 *);
	int (*writepages)(struct address_space___177 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___176 *);
	int (*readpages)(struct file___177 *, struct address_space___177 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___177 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___176 **, void **);
	int (*write_end)(struct file___177 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___176 *, void *);
	sector_t (*bmap)(struct address_space___177 *, sector_t);
	void (*invalidatepage)(struct page___176 *, long unsigned int);
	int (*releasepage)(struct page___176 *, gfp_t);
	void (*freepage)(struct page___176 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___177 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___177 *, struct page___176 *, struct page___176 *, enum migrate_mode);
	int (*launder_page)(struct page___176 *);
	int (*is_partially_uptodate)(struct page___176 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___176 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___177 *, struct page___176 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___177 *, sector_t *);
	void (*swap_deactivate)(struct file___177 *);
	void (*invalidatepage_range)(struct page___176 *, unsigned int, unsigned int);
};

struct bdi_writeback___41 {
	struct backing_dev_info___41 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___41 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___41 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___142 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___177 *debug_dir;
	struct dentry___177 *debug_stats;
};

struct hd_struct___32 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___142 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___32;

struct block_device_operations___31;

struct gendisk___32 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___32 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___32 *part_tbl;
	struct hd_struct___32 part0;
	const struct block_device_operations___31 *fops;
	struct request_queue___31 *queue;
	void *private_data;
	int flags;
	struct device___142 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___31 {
	struct request_queue___31 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___31(struct request_queue___31 *);

typedef void make_request_fn___31(struct request_queue___31 *, struct bio___32 *);

struct request___31;

typedef int prep_rq_fn___31(struct request_queue___31 *, struct request___31 *);

struct bvec_merge_data___31;

typedef int merge_bvec_fn___32(struct request_queue___31 *, struct bvec_merge_data___31 *, struct bio_vec___32 *);

typedef void softirq_done_fn___31(struct request___31 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___31(struct request___31 *);

typedef int dma_drain_needed_fn___31(struct request___31 *);

typedef int lld_busy_fn___31(struct request_queue___31 *);

struct bsg_class_device___31 {
	struct device___142 *class_dev;
	struct device___142 *parent;
	int minor;
	struct request_queue___31 *queue;
	struct kref ref;
	void (*release)(struct device___142 *);
};

typedef void unprep_rq_fn___31(struct request_queue___31 *, struct request___31 *);

struct elevator_queue___31;

struct blk_queue_tag___31;

struct blk_trace___7;

struct request_queue___31 {
	struct list_head queue_head;
	struct request___31 *last_merge;
	struct elevator_queue___31 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___31 root_rl;
	request_fn_proc___31 *request_fn;
	make_request_fn___31 *make_request_fn;
	prep_rq_fn___31 *prep_rq_fn;
	merge_bvec_fn___32 *merge_bvec_fn;
	softirq_done_fn___31 *softirq_done_fn;
	rq_timed_out_fn___31 *rq_timed_out_fn;
	dma_drain_needed_fn___31 *dma_drain_needed;
	lld_busy_fn___31 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___31 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___41 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___142 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___31 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___7 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___31 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___180 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___31 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___31 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___32 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___177 {
	struct dentry___177 * (*lookup)(struct inode___177 *, struct dentry___177 *, unsigned int);
	void * (*follow_link)(struct dentry___177 *, struct nameidata *);
	int (*permission)(struct inode___177 *, int);
	struct posix_acl * (*get_acl)(struct inode___177 *, int);
	int (*readlink)(struct dentry___177 *, char *, int);
	void (*put_link)(struct dentry___177 *, struct nameidata *, void *);
	int (*create)(struct inode___177 *, struct dentry___177 *, umode_t, bool);
	int (*link)(struct dentry___177 *, struct inode___177 *, struct dentry___177 *);
	int (*unlink)(struct inode___177 *, struct dentry___177 *);
	int (*symlink)(struct inode___177 *, struct dentry___177 *, const char *);
	int (*mkdir)(struct inode___177 *, struct dentry___177 *, umode_t);
	int (*rmdir)(struct inode___177 *, struct dentry___177 *);
	int (*mknod)(struct inode___177 *, struct dentry___177 *, umode_t, dev_t);
	int (*rename)(struct inode___177 *, struct dentry___177 *, struct inode___177 *, struct dentry___177 *);
	int (*setattr)(struct dentry___177 *, struct iattr___177 *);
	int (*getattr)(struct vfsmount *, struct dentry___177 *, struct kstat *);
	int (*setxattr)(struct dentry___177 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___177 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___177 *, char *, size_t);
	int (*removexattr)(struct dentry___177 *, const char *);
	int (*fiemap)(struct inode___177 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___177 *, struct timespec *, int);
	int (*atomic_open)(struct inode___177 *, struct dentry___177 *, struct file___177 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___103;

struct file_operations___177 {
	struct module___96 *owner;
	loff_t (*llseek)(struct file___177 *, loff_t, int);
	ssize_t (*read)(struct file___177 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___177 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___177 *, void *, filldir_t);
	unsigned int (*poll)(struct file___177 *, struct poll_table_struct___103 *);
	long int (*unlocked_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___177 *, struct vm_area_struct___184 *);
	int (*open)(struct inode___177 *, struct file___177 *);
	int (*flush)(struct file___177 *, fl_owner_t);
	int (*release)(struct inode___177 *, struct file___177 *);
	int (*fsync)(struct file___177 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___177 *, int);
	int (*lock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*sendpage)(struct file___177 *, struct page___176 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___177 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___177 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___177 *, long int, struct file_lock___177 **, void **);
		struct {
			int (*setlease)(struct file___177 *, long int, struct file_lock___177 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___177 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___177 *);
};

struct fasync_struct___177;

struct file_lock_operations___177;

struct lock_manager_operations___177;

struct file_lock___177 {
	struct file_lock___177 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___177 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___177 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___177 *fl_ops;
	const struct lock_manager_operations___177 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___177 {
	void (*fl_copy_lock)(struct file_lock___177 *, struct file_lock___177 *);
	void (*fl_release_private)(struct file_lock___177 *);
};

struct lock_manager_operations___177 {
	int (*lm_compare_owner)(struct file_lock___177 *, struct file_lock___177 *);
	long unsigned int (*lm_owner_key)(struct file_lock___177 *);
	void (*lm_notify)(struct file_lock___177 *);
	int (*lm_grant)(struct file_lock___177 *, struct file_lock___177 *, int);
	void (*lm_break)(struct file_lock___177 *);
	int (*lm_change)(struct file_lock___177 **, int);
};

struct fasync_struct___177 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___177 *fa_next;
	struct file___177 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___177 {
	const char *name;
	int fs_flags;
	struct dentry___177 * (*mount)(struct file_system_type___177 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___177 *);
	struct module___96 *owner;
	struct file_system_type___177 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___177 {
	struct inode___177 * (*alloc_inode)(struct super_block___177 *);
	void (*destroy_inode)(struct inode___177 *);
	void (*dirty_inode)(struct inode___177 *, int);
	int (*write_inode)(struct inode___177 *, struct writeback_control *);
	int (*drop_inode)(struct inode___177 *);
	void (*evict_inode)(struct inode___177 *);
	void (*put_super)(struct super_block___177 *);
	int (*sync_fs)(struct super_block___177 *, int);
	int (*freeze_fs)(struct super_block___177 *);
	int (*unfreeze_fs)(struct super_block___177 *);
	int (*statfs)(struct dentry___177 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___177 *, int *, char *);
	void (*umount_begin)(struct super_block___177 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___177 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___177 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___177 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___177 *);
	ssize_t (*quota_read)(struct super_block___177 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___177 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___177 *);
	int (*bdev_try_to_free_page)(struct super_block___177 *, struct page___176 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___177 *);
	void (*free_cached_objects)(struct super_block___177 *, int);
};

typedef void (*poll_queue_proc___105)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___103 *);

struct poll_table_struct___103 {
	poll_queue_proc___105 _qproc;
	long unsigned int _key;
};

struct kmem_cache_cpu___162 {
	void **freelist;
	long unsigned int tid;
	struct page___176 *page;
	struct page___176 *partial;
};

struct memcg_cache_params___163;

struct kmem_cache___163 {
	struct kmem_cache_cpu___162 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___163 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___163 {
	bool is_root_cache;
	union {
		struct kmem_cache___163 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___163 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___142 *, char *);
	ssize_t (*store)(struct bus_type___142 *, const char *, size_t);
};

struct device_attribute___142;

struct driver_attribute___142;

struct bus_type___142 {
	const char *name;
	const char *dev_name;
	struct device___142 *dev_root;
	struct bus_attribute___142 *bus_attrs;
	struct device_attribute___142 *dev_attrs;
	struct driver_attribute___142 *drv_attrs;
	const struct attribute_group___134 **bus_groups;
	const struct attribute_group___134 **dev_groups;
	const struct attribute_group___134 **drv_groups;
	int (*match)(struct device___142 *, struct device_driver___142 *);
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	int (*probe)(struct device___142 *);
	int (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*online)(struct device___142 *);
	int (*offline)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct device___142 *, struct device_attribute___142 *, char *);
	ssize_t (*store)(struct device___142 *, struct device_attribute___142 *, const char *, size_t);
};

struct driver_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___142 *, char *);
	ssize_t (*store)(struct device_driver___142 *, const char *, size_t);
};

struct device_driver___142 {
	const char *name;
	struct bus_type___142 *bus;
	struct module___96 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___142 *);
	int (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	const struct attribute_group___134 **groups;
	const struct dev_pm_ops___142 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___142 {
	const char *name;
	const struct attribute_group___134 **groups;
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
};

struct class_attribute___142;

struct class___142 {
	const char *name;
	struct module___96 *owner;
	struct class_attribute___142 *class_attrs;
	struct device_attribute___142 *dev_attrs;
	const struct attribute_group___134 **dev_groups;
	struct bin_attribute___136 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *);
	void (*class_release)(struct class___142 *);
	void (*dev_release)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
	struct subsys_private *p;
};

struct class_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct class___142 *, struct class_attribute___142 *, char *);
	ssize_t (*store)(struct class___142 *, struct class_attribute___142 *, const char *, size_t);
	const void * (*namespace)(struct class___142 *, const struct class_attribute___142 *);
};

struct device_rh___142 {
	struct dev_pm_info_rh___142 power;
};

struct disk_part_tbl___32 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___32 *last_lookup;
	struct hd_struct___32 *part[0];
};

struct block_device_operations___31 {
	int (*open)(struct block_device___177 *, fmode_t);
	void (*release)(struct gendisk___32 *, fmode_t);
	int (*ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___177 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___32 *, unsigned int);
	int (*media_changed)(struct gendisk___32 *);
	void (*unlock_native_capacity)(struct gendisk___32 *);
	int (*revalidate_disk)(struct gendisk___32 *);
	int (*getgeo)(struct block_device___177 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___177 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___96 *owner;
};

struct disk_part_iter___3 {
	struct gendisk___32 *disk;
	struct hd_struct___32 *part;
	int idx;
	unsigned int flags;
};

struct xol_area___176 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___176 *page;
	long unsigned int vaddr;
};

struct vm_fault___154;

struct vm_operations_struct___157 {
	void (*open)(struct vm_area_struct___184 *);
	void (*close)(struct vm_area_struct___184 *);
	int (*fault)(struct vm_area_struct___184 *, struct vm_fault___154 *);
	int (*page_mkwrite)(struct vm_area_struct___184 *, struct vm_fault___154 *);
	int (*access)(struct vm_area_struct___184 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___184 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___184 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___184 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___184 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___179 {
	struct task_struct___179 *task;
	struct core_thread___179 *next;
};

struct core_state___179 {
	atomic_t nr_threads;
	struct core_thread___179 dumper;
	struct completion startup;
};

struct signal_struct___179 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___179 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___179 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___180 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___154 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___176 *page;
};

typedef int filler_t___5(void *, struct page___176 *);

struct io_cq___31 {
	struct request_queue___31 *q;
	struct io_context___31 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___163 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___31(struct request___31 *, int);

struct request___31 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___31 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___32 *bio;
	struct bio___32 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___31 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___31 *saved_end_io;
		} flush;
	};
	struct gendisk___32 *rq_disk;
	struct hd_struct___32 *part;
	long unsigned int start_time;
	struct request_list___31 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___31 *end_io;
	void *end_io_data;
	struct request___31 *next_rq;
};

typedef int elevator_merge_fn___31(struct request_queue___31 *, struct request___31 **, struct bio___32 *);

typedef void elevator_merge_req_fn___31(struct request_queue___31 *, struct request___31 *, struct request___31 *);

typedef void elevator_merged_fn___31(struct request_queue___31 *, struct request___31 *, int);

typedef int elevator_allow_merge_fn___31(struct request_queue___31 *, struct request___31 *, struct bio___32 *);

typedef void elevator_bio_merged_fn___31(struct request_queue___31 *, struct request___31 *, struct bio___32 *);

typedef int elevator_dispatch_fn___31(struct request_queue___31 *, int);

typedef void elevator_add_req_fn___31(struct request_queue___31 *, struct request___31 *);

typedef struct request___31 *elevator_request_list_fn___31(struct request_queue___31 *, struct request___31 *);

typedef void elevator_completed_req_fn___31(struct request_queue___31 *, struct request___31 *);

typedef int elevator_may_queue_fn___31(struct request_queue___31 *, int);

typedef void elevator_init_icq_fn___31(struct io_cq___31 *);

typedef void elevator_exit_icq_fn___31(struct io_cq___31 *);

typedef int elevator_set_req_fn___31(struct request_queue___31 *, struct request___31 *, struct bio___32 *, gfp_t);

typedef void elevator_put_req_fn___31(struct request___31 *);

typedef void elevator_activate_req_fn___31(struct request_queue___31 *, struct request___31 *);

typedef void elevator_deactivate_req_fn___31(struct request_queue___31 *, struct request___31 *);

struct elevator_type___31;

typedef int elevator_init_fn___32(struct request_queue___31 *, struct elevator_type___31 *);

typedef void elevator_exit_fn___31(struct elevator_queue___31 *);

struct elevator_ops___31 {
	elevator_merge_fn___31 *elevator_merge_fn;
	elevator_merged_fn___31 *elevator_merged_fn;
	elevator_merge_req_fn___31 *elevator_merge_req_fn;
	elevator_allow_merge_fn___31 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___31 *elevator_bio_merged_fn;
	elevator_dispatch_fn___31 *elevator_dispatch_fn;
	elevator_add_req_fn___31 *elevator_add_req_fn;
	elevator_activate_req_fn___31 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___31 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___31 *elevator_completed_req_fn;
	elevator_request_list_fn___31 *elevator_former_req_fn;
	elevator_request_list_fn___31 *elevator_latter_req_fn;
	elevator_init_icq_fn___31 *elevator_init_icq_fn;
	elevator_exit_icq_fn___31 *elevator_exit_icq_fn;
	elevator_set_req_fn___31 *elevator_set_req_fn;
	elevator_put_req_fn___31 *elevator_put_req_fn;
	elevator_may_queue_fn___31 *elevator_may_queue_fn;
	elevator_init_fn___32 *elevator_init_fn;
	elevator_exit_fn___31 *elevator_exit_fn;
};

struct elv_fs_entry___31;

struct elevator_type___31 {
	struct kmem_cache___163 *icq_cache;
	struct elevator_ops___31 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___31 *elevator_attrs;
	char elevator_name[16];
	struct module___96 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___31 {
	struct elevator_type___31 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___180 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___31 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___31 *, char *);
	ssize_t (*store)(struct elevator_queue___31 *, const char *, size_t);
};

struct bvec_merge_data___31 {
	struct block_device___177 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___31 {
	struct request___31 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct rchan___8;

struct blk_trace___7 {
	int trace_state;
	struct rchan___8 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___177 *dir;
	struct dentry___177 *dropped_file;
	struct dentry___177 *msg_file;
	atomic_t dropped;
};

typedef struct {
	struct page___176 *v;
} Sector;

struct rchan_buf___8 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___8 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___177 *dentry;
	struct kref kref;
	struct page___176 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___8;

struct rchan___8 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___8 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___8 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___177 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___8 {
	int (*subbuf_start)(struct rchan_buf___8 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___8 *, struct file___177 *);
	void (*buf_unmapped)(struct rchan_buf___8 *, struct file___177 *);
	struct dentry___177 * (*create_buf_file)(const char *, struct dentry___177 *, umode_t, struct rchan_buf___8 *, int *);
	int (*remove_buf_file)(struct dentry___177 *);
};

struct parsed_partitions {
	struct block_device___177 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

struct page___177;

typedef struct page___177 *pgtable_t___177;

struct address_space___178;

struct kmem_cache___164;

struct page___177 {
	long unsigned int flags;
	struct address_space___178 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___177 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___177 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___164 *slab_cache;
		struct page___177 *first_page;
	};
	long: 64;
};

struct task_struct___180;

struct pv_cpu_ops___180 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___180 *);
	void (*end_context_switch)(struct task_struct___180 *);
};

struct mutex___181 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___180 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___173 {
	struct page___177 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___185;

struct signal_struct___180;

struct bio_list___32;

struct backing_dev_info___42;

struct io_context___32;

struct task_struct___180 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___180 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___185 *mm;
	struct mm_struct___185 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___180 *real_parent;
	struct task_struct___180 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___180 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___180 = 0,
		VTIME_USER___180 = 1,
		VTIME_SYS___180 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___180 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___32 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___42 *backing_dev_info;
	struct io_context___32 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___181 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___173 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___185 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___185 *, struct mm_struct___185 *);
	void (*dup_mmap)(struct mm_struct___185 *, struct mm_struct___185 *);
	void (*exit_mmap)(struct mm_struct___185 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___185 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___185 *);
	void (*pgd_free)(struct mm_struct___185 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___185 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___185 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___185 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___185 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___185 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___185 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___185 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___185 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___185 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___185 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___185 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___181 lock;
	void *vdso;
} mm_context_t___181;

struct xol_area___177;

struct uprobes_state___177 {
	struct xol_area___177 *xol_area;
};

struct vm_area_struct___185;

struct file___178;

struct core_state___180;

struct mm_struct___185 {
	struct vm_area_struct___185 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___185 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___185 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___181 context;
	long unsigned int flags;
	struct core_state___180 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___180 *owner;
	struct file___178 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___177 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___180;

struct lruvec___180 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___180 *zone;
};

struct pglist_data___180;

struct zone___180 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___180 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___180 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___180 {
	struct zone___180 *zone;
	int zone_idx;
};

struct zonelist___180 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___180 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___180 {
	struct zone___180 node_zones[4];
	struct zonelist___180 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___180 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___122;

struct x86_io_apic_ops___122 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___122 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___122;

struct irq_data___122 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___122 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___143;

struct dev_pm_ops___143 {
	int (*prepare)(struct device___143 *);
	void (*complete)(struct device___143 *);
	int (*suspend)(struct device___143 *);
	int (*resume)(struct device___143 *);
	int (*freeze)(struct device___143 *);
	int (*thaw)(struct device___143 *);
	int (*poweroff)(struct device___143 *);
	int (*restore)(struct device___143 *);
	int (*suspend_late)(struct device___143 *);
	int (*resume_early)(struct device___143 *);
	int (*freeze_late)(struct device___143 *);
	int (*thaw_early)(struct device___143 *);
	int (*poweroff_late)(struct device___143 *);
	int (*restore_early)(struct device___143 *);
	int (*suspend_noirq)(struct device___143 *);
	int (*resume_noirq)(struct device___143 *);
	int (*freeze_noirq)(struct device___143 *);
	int (*thaw_noirq)(struct device___143 *);
	int (*poweroff_noirq)(struct device___143 *);
	int (*restore_noirq)(struct device___143 *);
	int (*runtime_suspend)(struct device___143 *);
	int (*runtime_resume)(struct device___143 *);
	int (*runtime_idle)(struct device___143 *);
};

struct device_type___143;

struct bus_type___143;

struct device_driver___143;

struct dev_pm_domain___143;

struct class___143;

struct attribute_group___135;

struct device_rh___143;

struct device___143 {
	struct device___143 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___143 *type;
	struct mutex___181 mutex;
	struct bus_type___143 *bus;
	struct device_driver___143 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___143 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___57 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___143 *class;
	const struct attribute_group___135 **groups;
	void (*release)(struct device___143 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___143 *device_rh;
};

struct dev_pm_info_rh___143 {
	void (*set_latency_tolerance)(struct device___143 *, s32);
};

struct dev_pm_domain___143 {
	struct dev_pm_ops___143 ops;
};

struct smp_ops___180 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___180 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___137;

struct attribute_group___135 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___137 **bin_attrs;
};

struct bin_attribute___137 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___178 *, struct kobject___4 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___178 *, struct kobject___4 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	int (*mmap)(struct file___178 *, struct kobject___4 *, struct bin_attribute___137 *, struct vm_area_struct___185 *);
};

struct dentry___178;

struct path___178 {
	struct vfsmount *mnt;
	struct dentry___178 *dentry;
};

struct inode___178;

struct file_operations___178;

struct file___178 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___178 f_path;
	struct inode___178 *f_inode;
	const struct file_operations___178 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___178 *f_mapping;
	struct mutex___181 f_pos_lock;
};

struct vm_operations_struct___158;

struct vm_area_struct___185 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___185 *vm_next;
	struct vm_area_struct___185 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___185 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___158 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___178 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___163 {
	void **freelist;
	long unsigned int tid;
	struct page___177 *page;
	struct page___177 *partial;
};

struct memcg_cache_params___164;

struct kmem_cache___164 {
	struct kmem_cache_cpu___163 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___164 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___164 {
	bool is_root_cache;
	union {
		struct kmem_cache___164 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___164 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___143 *, char *);
	ssize_t (*store)(struct bus_type___143 *, const char *, size_t);
};

struct device_attribute___143;

struct driver_attribute___143;

struct bus_type___143 {
	const char *name;
	const char *dev_name;
	struct device___143 *dev_root;
	struct bus_attribute___143 *bus_attrs;
	struct device_attribute___143 *dev_attrs;
	struct driver_attribute___143 *drv_attrs;
	const struct attribute_group___135 **bus_groups;
	const struct attribute_group___135 **dev_groups;
	const struct attribute_group___135 **drv_groups;
	int (*match)(struct device___143 *, struct device_driver___143 *);
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	int (*probe)(struct device___143 *);
	int (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*online)(struct device___143 *);
	int (*offline)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct device___143 *, struct device_attribute___143 *, char *);
	ssize_t (*store)(struct device___143 *, struct device_attribute___143 *, const char *, size_t);
};

struct driver_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___143 *, char *);
	ssize_t (*store)(struct device_driver___143 *, const char *, size_t);
};

struct device_driver___143 {
	const char *name;
	struct bus_type___143 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___143 *);
	int (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	const struct attribute_group___135 **groups;
	const struct dev_pm_ops___143 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___143 {
	const char *name;
	const struct attribute_group___135 **groups;
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
};

struct class_attribute___143;

struct class___143 {
	const char *name;
	struct module *owner;
	struct class_attribute___143 *class_attrs;
	struct device_attribute___143 *dev_attrs;
	const struct attribute_group___135 **dev_groups;
	struct bin_attribute___137 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *);
	void (*class_release)(struct class___143 *);
	void (*dev_release)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
	struct subsys_private *p;
};

struct class_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct class___143 *, struct class_attribute___143 *, char *);
	ssize_t (*store)(struct class___143 *, struct class_attribute___143 *, const char *, size_t);
	const void * (*namespace)(struct class___143 *, const struct class_attribute___143 *);
};

struct device_rh___143 {
	struct dev_pm_info_rh___143 power;
};

struct dentry_operations___178;

struct super_block___178;

struct dentry___178 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___178 *d_parent;
	struct qstr d_name;
	struct inode___178 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___178 *d_op;
	struct super_block___178 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___178;

struct address_space___178 {
	struct inode___178 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___181 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___178 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___42 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___178;

struct file_lock___178;

struct dquot___178;

struct block_device___178;

struct cdev___42;

struct inode___178 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___178 *i_op;
	struct super_block___178 *i_sb;
	struct address_space___178 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___181 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___178 *i_fop;
	struct file_lock___178 *i_flock;
	struct address_space___178 i_data;
	struct dquot___178 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___178 *i_bdev;
		struct cdev___42 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___178 {
	int (*d_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_hash)(const struct dentry___178 *, struct qstr *);
	int (*d_compare)(const struct dentry___178 *, const struct dentry___178 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___178 *);
	void (*d_release)(struct dentry___178 *);
	void (*d_prune)(struct dentry___178 *);
	void (*d_iput)(struct dentry___178 *, struct inode___178 *);
	char * (*d_dname)(struct dentry___178 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___178 *);
	int (*d_manage)(struct dentry___178 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___178;

struct mem_dqinfo___178 {
	struct quota_format_type___178 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___178;

struct quota_info___178 {
	unsigned int flags;
	struct mutex___181 dqio_mutex;
	struct mutex___181 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___178 *files[2];
	struct mem_dqinfo___178 info[2];
	const struct quota_format_ops___178 *ops[2];
};

struct file_system_type___178;

struct super_operations___178;

struct dquot_operations___178;

struct quotactl_ops___178;

struct super_block___178 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___178 *s_type;
	const struct super_operations___178 *s_op;
	const struct dquot_operations___178 *dq_op;
	const struct quotactl_ops___178 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___178 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___178 *s_bdev;
	struct backing_dev_info___42 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___178 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___181 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___178 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___33;

typedef void bio_end_io_t___33(struct bio___33 *, int);

struct bio_vec___33 {
	struct page___177 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___33;

struct bio_set___33;

struct bio___33 {
	sector_t bi_sector;
	struct bio___33 *bi_next;
	struct block_device___178 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___33 *bi_end_io;
	void *bi_private;
	struct io_context___32 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___33 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___33 *bi_io_vec;
	struct bio_set___33 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	struct bio_vec___33 bi_inline_vecs[0];
};

struct hd_struct___33;

struct gendisk___33;

struct request_queue___32;

struct block_device___178 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___178 *bd_inode;
	struct super_block___178 *bd_super;
	struct mutex___181 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___178 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___33 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___33 *bd_disk;
	struct request_queue___32 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___181 bd_fsfreeze_mutex;
};

struct io_cq___32;

struct io_context___32 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___32 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___33 {
	struct bio___33 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___33 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___33 *bip_vec;
	struct bio_vec___33 bip_inline_vecs[0];
};

struct bio_list___32 {
	struct bio___33 *head;
	struct bio___33 *tail;
};

struct bio_set___33 {
	struct kmem_cache___164 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___32 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___178 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___178 *ia_file;
};

struct dquot___178 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___181 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___178 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___178 {
	int qf_fmt_id;
	const struct quota_format_ops___178 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___178 *qf_next;
};

struct quota_format_ops___178 {
	int (*check_quota_file)(struct super_block___178 *, int);
	int (*read_file_info)(struct super_block___178 *, int);
	int (*write_file_info)(struct super_block___178 *, int);
	int (*free_file_info)(struct super_block___178 *, int);
	int (*read_dqblk)(struct dquot___178 *);
	int (*commit_dqblk)(struct dquot___178 *);
	int (*release_dqblk)(struct dquot___178 *);
};

struct dquot_operations___178 {
	int (*write_dquot)(struct dquot___178 *);
	struct dquot___178 * (*alloc_dquot)(struct super_block___178 *, int);
	void (*destroy_dquot)(struct dquot___178 *);
	int (*acquire_dquot)(struct dquot___178 *);
	int (*release_dquot)(struct dquot___178 *);
	int (*mark_dirty)(struct dquot___178 *);
	int (*write_info)(struct super_block___178 *, int);
	qsize_t * (*get_reserved_space)(struct inode___178 *);
};

struct quotactl_ops___178 {
	int (*quota_on)(struct super_block___178 *, int, int, struct path___178 *);
	int (*quota_on_meta)(struct super_block___178 *, int, int);
	int (*quota_off)(struct super_block___178 *, int);
	int (*quota_sync)(struct super_block___178 *, int);
	int (*get_info)(struct super_block___178 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___178 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___178 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___178 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___178 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___178 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___178 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___178 *, unsigned int);
};

struct address_space_operations___178 {
	int (*writepage)(struct page___177 *, struct writeback_control *);
	int (*readpage)(struct file___178 *, struct page___177 *);
	int (*writepages)(struct address_space___178 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___177 *);
	int (*readpages)(struct file___178 *, struct address_space___178 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___178 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___177 **, void **);
	int (*write_end)(struct file___178 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___177 *, void *);
	sector_t (*bmap)(struct address_space___178 *, sector_t);
	void (*invalidatepage)(struct page___177 *, long unsigned int);
	int (*releasepage)(struct page___177 *, gfp_t);
	void (*freepage)(struct page___177 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___178 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___178 *, struct page___177 *, struct page___177 *, enum migrate_mode);
	int (*launder_page)(struct page___177 *);
	int (*is_partially_uptodate)(struct page___177 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___177 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___178 *, struct page___177 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___178 *, sector_t *);
	void (*swap_deactivate)(struct file___178 *);
	void (*invalidatepage_range)(struct page___177 *, unsigned int, unsigned int);
};

struct bdi_writeback___42 {
	struct backing_dev_info___42 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___42 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___42 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___143 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___178 *debug_dir;
	struct dentry___178 *debug_stats;
};

struct hd_struct___33 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___143 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___33;

struct block_device_operations___32;

struct gendisk___33 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___33 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___33 *part_tbl;
	struct hd_struct___33 part0;
	const struct block_device_operations___32 *fops;
	struct request_queue___32 *queue;
	void *private_data;
	int flags;
	struct device___143 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___32 {
	struct request_queue___32 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___32(struct request_queue___32 *);

typedef void make_request_fn___32(struct request_queue___32 *, struct bio___33 *);

struct request___32;

typedef int prep_rq_fn___32(struct request_queue___32 *, struct request___32 *);

struct bvec_merge_data___32;

typedef int merge_bvec_fn___33(struct request_queue___32 *, struct bvec_merge_data___32 *, struct bio_vec___33 *);

typedef void softirq_done_fn___32(struct request___32 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___32(struct request___32 *);

typedef int dma_drain_needed_fn___32(struct request___32 *);

typedef int lld_busy_fn___32(struct request_queue___32 *);

struct bsg_class_device___32 {
	struct device___143 *class_dev;
	struct device___143 *parent;
	int minor;
	struct request_queue___32 *queue;
	struct kref ref;
	void (*release)(struct device___143 *);
};

typedef void unprep_rq_fn___32(struct request_queue___32 *, struct request___32 *);

struct elevator_queue___32;

struct blk_queue_tag___32;

struct request_queue___32 {
	struct list_head queue_head;
	struct request___32 *last_merge;
	struct elevator_queue___32 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___32 root_rl;
	request_fn_proc___32 *request_fn;
	make_request_fn___32 *make_request_fn;
	prep_rq_fn___32 *prep_rq_fn;
	merge_bvec_fn___33 *merge_bvec_fn;
	softirq_done_fn___32 *softirq_done_fn;
	rq_timed_out_fn___32 *rq_timed_out_fn;
	dma_drain_needed_fn___32 *dma_drain_needed;
	lld_busy_fn___32 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___32 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___42 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___143 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___32 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___32 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___181 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___32 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___32 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___33 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___42 {
	struct kobject___4 kobj;
	struct module *owner;
	const struct file_operations___178 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___178 {
	struct dentry___178 * (*lookup)(struct inode___178 *, struct dentry___178 *, unsigned int);
	void * (*follow_link)(struct dentry___178 *, struct nameidata *);
	int (*permission)(struct inode___178 *, int);
	struct posix_acl * (*get_acl)(struct inode___178 *, int);
	int (*readlink)(struct dentry___178 *, char *, int);
	void (*put_link)(struct dentry___178 *, struct nameidata *, void *);
	int (*create)(struct inode___178 *, struct dentry___178 *, umode_t, bool);
	int (*link)(struct dentry___178 *, struct inode___178 *, struct dentry___178 *);
	int (*unlink)(struct inode___178 *, struct dentry___178 *);
	int (*symlink)(struct inode___178 *, struct dentry___178 *, const char *);
	int (*mkdir)(struct inode___178 *, struct dentry___178 *, umode_t);
	int (*rmdir)(struct inode___178 *, struct dentry___178 *);
	int (*mknod)(struct inode___178 *, struct dentry___178 *, umode_t, dev_t);
	int (*rename)(struct inode___178 *, struct dentry___178 *, struct inode___178 *, struct dentry___178 *);
	int (*setattr)(struct dentry___178 *, struct iattr___178 *);
	int (*getattr)(struct vfsmount *, struct dentry___178 *, struct kstat *);
	int (*setxattr)(struct dentry___178 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___178 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___178 *, char *, size_t);
	int (*removexattr)(struct dentry___178 *, const char *);
	int (*fiemap)(struct inode___178 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___178 *, struct timespec *, int);
	int (*atomic_open)(struct inode___178 *, struct dentry___178 *, struct file___178 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___104;

struct seq_file___127;

struct file_operations___178 {
	struct module *owner;
	loff_t (*llseek)(struct file___178 *, loff_t, int);
	ssize_t (*read)(struct file___178 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___178 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___178 *, void *, filldir_t);
	unsigned int (*poll)(struct file___178 *, struct poll_table_struct___104 *);
	long int (*unlocked_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___178 *, struct vm_area_struct___185 *);
	int (*open)(struct inode___178 *, struct file___178 *);
	int (*flush)(struct file___178 *, fl_owner_t);
	int (*release)(struct inode___178 *, struct file___178 *);
	int (*fsync)(struct file___178 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___178 *, int);
	int (*lock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*sendpage)(struct file___178 *, struct page___177 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___178 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___178 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___178 *, long int, struct file_lock___178 **, void **);
		struct {
			int (*setlease)(struct file___178 *, long int, struct file_lock___178 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___178 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___127 *, struct file___178 *);
};

struct fasync_struct___178;

struct file_lock_operations___178;

struct lock_manager_operations___178;

struct file_lock___178 {
	struct file_lock___178 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___178 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___178 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___178 *fl_ops;
	const struct lock_manager_operations___178 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___178 {
	void (*fl_copy_lock)(struct file_lock___178 *, struct file_lock___178 *);
	void (*fl_release_private)(struct file_lock___178 *);
};

struct lock_manager_operations___178 {
	int (*lm_compare_owner)(struct file_lock___178 *, struct file_lock___178 *);
	long unsigned int (*lm_owner_key)(struct file_lock___178 *);
	void (*lm_notify)(struct file_lock___178 *);
	int (*lm_grant)(struct file_lock___178 *, struct file_lock___178 *, int);
	void (*lm_break)(struct file_lock___178 *);
	int (*lm_change)(struct file_lock___178 **, int);
};

struct fasync_struct___178 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___178 *fa_next;
	struct file___178 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___178 {
	const char *name;
	int fs_flags;
	struct dentry___178 * (*mount)(struct file_system_type___178 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___178 *);
	struct module *owner;
	struct file_system_type___178 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___178 {
	struct inode___178 * (*alloc_inode)(struct super_block___178 *);
	void (*destroy_inode)(struct inode___178 *);
	void (*dirty_inode)(struct inode___178 *, int);
	int (*write_inode)(struct inode___178 *, struct writeback_control *);
	int (*drop_inode)(struct inode___178 *);
	void (*evict_inode)(struct inode___178 *);
	void (*put_super)(struct super_block___178 *);
	int (*sync_fs)(struct super_block___178 *, int);
	int (*freeze_fs)(struct super_block___178 *);
	int (*unfreeze_fs)(struct super_block___178 *);
	int (*statfs)(struct dentry___178 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___178 *, int *, char *);
	void (*umount_begin)(struct super_block___178 *);
	int (*show_options)(struct seq_file___127 *, struct dentry___178 *);
	int (*show_devname)(struct seq_file___127 *, struct dentry___178 *);
	int (*show_path)(struct seq_file___127 *, struct dentry___178 *);
	int (*show_stats)(struct seq_file___127 *, struct dentry___178 *);
	ssize_t (*quota_read)(struct super_block___178 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___178 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___178 *);
	int (*bdev_try_to_free_page)(struct super_block___178 *, struct page___177 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___178 *);
	void (*free_cached_objects)(struct super_block___178 *, int);
};

typedef void (*poll_queue_proc___106)(struct file___178 *, wait_queue_head_t *, struct poll_table_struct___104 *);

struct poll_table_struct___104 {
	poll_queue_proc___106 _qproc;
	long unsigned int _key;
};

struct seq_operations___127;

struct seq_file___127 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___181 lock;
	const struct seq_operations___127 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___33 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___33 *last_lookup;
	struct hd_struct___33 *part[0];
};

struct block_device_operations___32 {
	int (*open)(struct block_device___178 *, fmode_t);
	void (*release)(struct gendisk___33 *, fmode_t);
	int (*ioctl)(struct block_device___178 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___178 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___178 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___33 *, unsigned int);
	int (*media_changed)(struct gendisk___33 *);
	void (*unlock_native_capacity)(struct gendisk___33 *);
	int (*revalidate_disk)(struct gendisk___33 *);
	int (*getgeo)(struct block_device___178 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___178 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct xol_area___177 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___177 *page;
	long unsigned int vaddr;
};

struct vm_fault___155;

struct vm_operations_struct___158 {
	void (*open)(struct vm_area_struct___185 *);
	void (*close)(struct vm_area_struct___185 *);
	int (*fault)(struct vm_area_struct___185 *, struct vm_fault___155 *);
	int (*page_mkwrite)(struct vm_area_struct___185 *, struct vm_fault___155 *);
	int (*access)(struct vm_area_struct___185 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___185 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___185 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___185 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___185 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___180 {
	struct task_struct___180 *task;
	struct core_thread___180 *next;
};

struct core_state___180 {
	atomic_t nr_threads;
	struct core_thread___180 dumper;
	struct completion startup;
};

struct vm_fault___155 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___177 *page;
};

struct irq_chip___122 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___122 *);
	void (*irq_shutdown)(struct irq_data___122 *);
	void (*irq_enable)(struct irq_data___122 *);
	void (*irq_disable)(struct irq_data___122 *);
	void (*irq_ack)(struct irq_data___122 *);
	void (*irq_mask)(struct irq_data___122 *);
	void (*irq_mask_ack)(struct irq_data___122 *);
	void (*irq_unmask)(struct irq_data___122 *);
	void (*irq_eoi)(struct irq_data___122 *);
	int (*irq_set_affinity)(struct irq_data___122 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___122 *);
	int (*irq_set_type)(struct irq_data___122 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___122 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___122 *);
	void (*irq_bus_sync_unlock)(struct irq_data___122 *);
	void (*irq_cpu_online)(struct irq_data___122 *);
	void (*irq_cpu_offline)(struct irq_data___122 *);
	void (*irq_suspend)(struct irq_data___122 *);
	void (*irq_resume)(struct irq_data___122 *);
	void (*irq_pm_shutdown)(struct irq_data___122 *);
	void (*irq_print_chip)(struct irq_data___122 *, struct seq_file___127 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___122 *, void *);
	long unsigned int flags;
};

struct signal_struct___180 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___180 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___180 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___181 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___32 {
	struct request_queue___32 *q;
	struct io_context___32 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___164 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___32(struct request___32 *, int);

struct request___32 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___32 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___33 *bio;
	struct bio___33 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___32 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___32 *saved_end_io;
		} flush;
	};
	struct gendisk___33 *rq_disk;
	struct hd_struct___33 *part;
	long unsigned int start_time;
	struct request_list___32 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___32 *end_io;
	void *end_io_data;
	struct request___32 *next_rq;
};

typedef int elevator_merge_fn___32(struct request_queue___32 *, struct request___32 **, struct bio___33 *);

typedef void elevator_merge_req_fn___32(struct request_queue___32 *, struct request___32 *, struct request___32 *);

typedef void elevator_merged_fn___32(struct request_queue___32 *, struct request___32 *, int);

typedef int elevator_allow_merge_fn___32(struct request_queue___32 *, struct request___32 *, struct bio___33 *);

typedef void elevator_bio_merged_fn___32(struct request_queue___32 *, struct request___32 *, struct bio___33 *);

typedef int elevator_dispatch_fn___32(struct request_queue___32 *, int);

typedef void elevator_add_req_fn___32(struct request_queue___32 *, struct request___32 *);

typedef struct request___32 *elevator_request_list_fn___32(struct request_queue___32 *, struct request___32 *);

typedef void elevator_completed_req_fn___32(struct request_queue___32 *, struct request___32 *);

typedef int elevator_may_queue_fn___32(struct request_queue___32 *, int);

typedef void elevator_init_icq_fn___32(struct io_cq___32 *);

typedef void elevator_exit_icq_fn___32(struct io_cq___32 *);

typedef int elevator_set_req_fn___32(struct request_queue___32 *, struct request___32 *, struct bio___33 *, gfp_t);

typedef void elevator_put_req_fn___32(struct request___32 *);

typedef void elevator_activate_req_fn___32(struct request_queue___32 *, struct request___32 *);

typedef void elevator_deactivate_req_fn___32(struct request_queue___32 *, struct request___32 *);

struct elevator_type___32;

typedef int elevator_init_fn___33(struct request_queue___32 *, struct elevator_type___32 *);

typedef void elevator_exit_fn___32(struct elevator_queue___32 *);

struct elevator_ops___32 {
	elevator_merge_fn___32 *elevator_merge_fn;
	elevator_merged_fn___32 *elevator_merged_fn;
	elevator_merge_req_fn___32 *elevator_merge_req_fn;
	elevator_allow_merge_fn___32 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___32 *elevator_bio_merged_fn;
	elevator_dispatch_fn___32 *elevator_dispatch_fn;
	elevator_add_req_fn___32 *elevator_add_req_fn;
	elevator_activate_req_fn___32 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___32 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___32 *elevator_completed_req_fn;
	elevator_request_list_fn___32 *elevator_former_req_fn;
	elevator_request_list_fn___32 *elevator_latter_req_fn;
	elevator_init_icq_fn___32 *elevator_init_icq_fn;
	elevator_exit_icq_fn___32 *elevator_exit_icq_fn;
	elevator_set_req_fn___32 *elevator_set_req_fn;
	elevator_put_req_fn___32 *elevator_put_req_fn;
	elevator_may_queue_fn___32 *elevator_may_queue_fn;
	elevator_init_fn___33 *elevator_init_fn;
	elevator_exit_fn___32 *elevator_exit_fn;
};

struct elv_fs_entry___32;

struct elevator_type___32 {
	struct kmem_cache___164 *icq_cache;
	struct elevator_ops___32 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___32 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___32 {
	struct elevator_type___32 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___181 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___32 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___32 *, char *);
	ssize_t (*store)(struct elevator_queue___32 *, const char *, size_t);
};

struct bvec_merge_data___32 {
	struct block_device___178 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___32 {
	struct request___32 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct parsed_partitions___2 {
	struct block_device___178 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

struct seq_operations___127 {
	void * (*start)(struct seq_file___127 *, loff_t *);
	void (*stop)(struct seq_file___127 *, void *);
	void * (*next)(struct seq_file___127 *, void *, loff_t *);
	int (*show)(struct seq_file___127 *, void *);
};

struct RigidDiskBlock {
	__u32 rdb_ID;
	__be32 rdb_SummedLongs;
	__s32 rdb_ChkSum;
	__u32 rdb_HostID;
	__be32 rdb_BlockBytes;
	__u32 rdb_Flags;
	__u32 rdb_BadBlockList;
	__be32 rdb_PartitionList;
	__u32 rdb_FileSysHeaderList;
	__u32 rdb_DriveInit;
	__u32 rdb_Reserved1[6];
	__u32 rdb_Cylinders;
	__u32 rdb_Sectors;
	__u32 rdb_Heads;
	__u32 rdb_Interleave;
	__u32 rdb_Park;
	__u32 rdb_Reserved2[3];
	__u32 rdb_WritePreComp;
	__u32 rdb_ReducedWrite;
	__u32 rdb_StepRate;
	__u32 rdb_Reserved3[5];
	__u32 rdb_RDBBlocksLo;
	__u32 rdb_RDBBlocksHi;
	__u32 rdb_LoCylinder;
	__u32 rdb_HiCylinder;
	__u32 rdb_CylBlocks;
	__u32 rdb_AutoParkSeconds;
	__u32 rdb_HighRDSKBlock;
	__u32 rdb_Reserved4;
	char rdb_DiskVendor[8];
	char rdb_DiskProduct[16];
	char rdb_DiskRevision[4];
	char rdb_ControllerVendor[8];
	char rdb_ControllerProduct[16];
	char rdb_ControllerRevision[4];
	__u32 rdb_Reserved5[10];
};

struct PartitionBlock {
	__be32 pb_ID;
	__be32 pb_SummedLongs;
	__s32 pb_ChkSum;
	__u32 pb_HostID;
	__be32 pb_Next;
	__u32 pb_Flags;
	__u32 pb_Reserved1[2];
	__u32 pb_DevFlags;
	__u8 pb_DriveName[32];
	__u32 pb_Reserved2[15];
	__be32 pb_Environment[17];
	__u32 pb_EReserved[15];
};

typedef struct {
	struct page___109 *v;
} Sector___2;

struct parsed_partitions___3 {
	struct block_device___109 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

struct mac_partition {
	__be16 signature;
	__be16 res1;
	__be32 map_count;
	__be32 start_block;
	__be32 block_count;
	char name[32];
	char type[32];
	__be32 data_start;
	__be32 data_count;
	__be32 status;
	__be32 boot_start;
	__be32 boot_size;
	__be32 boot_load;
	__be32 boot_load2;
	__be32 boot_entry;
	__be32 boot_entry2;
	__be32 boot_cksum;
	char processor[16];
};

struct mac_driver_desc {
	__be16 signature;
	__be16 block_size;
	__be32 block_count;
};

struct fat_boot_sector {
	__u8 ignored[3];
	__u8 system_id[8];
	__u8 sector_size[2];
	__u8 sec_per_clus;
	__le16 reserved;
	__u8 fats;
	__u8 dir_entries[2];
	__u8 sectors[2];
	__u8 media;
	__le16 fat_length;
	__le16 secs_track;
	__le16 heads;
	__le32 hidden;
	__le32 total_sect;
	union {
		struct {
			__u8 drive_number;
			__u8 state;
		} fat16;
		struct {
			__le32 length;
			__le16 flags;
			__u8 version[2];
			__le32 root_cluster;
			__le16 info_sector;
			__le16 backup_boot;
			__le16 reserved2[6];
			__u8 drive_number;
			__u8 state;
		} fat32;
	};
};

struct page___178;

typedef struct page___178 *pgtable_t___178;

struct address_space___179;

struct kmem_cache___165;

struct page___178 {
	long unsigned int flags;
	struct address_space___179 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___178 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___178 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___165 *slab_cache;
		struct page___178 *first_page;
	};
	long: 64;
};

struct task_struct___181;

struct pv_cpu_ops___181 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___181 *);
	void (*end_context_switch)(struct task_struct___181 *);
};

struct mutex___182 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___181 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___174 {
	struct page___178 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___186;

struct signal_struct___181;

struct bio_list___33;

struct backing_dev_info___43;

struct io_context___33;

struct task_struct___181 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___181 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___186 *mm;
	struct mm_struct___186 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___181 *real_parent;
	struct task_struct___181 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___181 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___181 = 0,
		VTIME_USER___181 = 1,
		VTIME_SYS___181 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___181 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___33 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___43 *backing_dev_info;
	struct io_context___33 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___182 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___174 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___186 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___186 *, struct mm_struct___186 *);
	void (*dup_mmap)(struct mm_struct___186 *, struct mm_struct___186 *);
	void (*exit_mmap)(struct mm_struct___186 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___186 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___186 *);
	void (*pgd_free)(struct mm_struct___186 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___186 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___186 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___186 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___186 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___186 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___186 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___186 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___186 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___186 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___186 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___186 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___182 lock;
	void *vdso;
} mm_context_t___182;

struct xol_area___178;

struct uprobes_state___178 {
	struct xol_area___178 *xol_area;
};

struct vm_area_struct___186;

struct file___179;

struct core_state___181;

struct mm_struct___186 {
	struct vm_area_struct___186 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___186 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___186 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___182 context;
	long unsigned int flags;
	struct core_state___181 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___181 *owner;
	struct file___179 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___178 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___181;

struct lruvec___181 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___181 *zone;
};

struct pglist_data___181;

struct zone___181 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___181 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___181 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___181 {
	struct zone___181 *zone;
	int zone_idx;
};

struct zonelist___181 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___181 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___181 {
	struct zone___181 node_zones[4];
	struct zonelist___181 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___181 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___123;

struct x86_io_apic_ops___123 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___123 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___123;

struct irq_data___123 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___123 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___144;

struct dev_pm_ops___144 {
	int (*prepare)(struct device___144 *);
	void (*complete)(struct device___144 *);
	int (*suspend)(struct device___144 *);
	int (*resume)(struct device___144 *);
	int (*freeze)(struct device___144 *);
	int (*thaw)(struct device___144 *);
	int (*poweroff)(struct device___144 *);
	int (*restore)(struct device___144 *);
	int (*suspend_late)(struct device___144 *);
	int (*resume_early)(struct device___144 *);
	int (*freeze_late)(struct device___144 *);
	int (*thaw_early)(struct device___144 *);
	int (*poweroff_late)(struct device___144 *);
	int (*restore_early)(struct device___144 *);
	int (*suspend_noirq)(struct device___144 *);
	int (*resume_noirq)(struct device___144 *);
	int (*freeze_noirq)(struct device___144 *);
	int (*thaw_noirq)(struct device___144 *);
	int (*poweroff_noirq)(struct device___144 *);
	int (*restore_noirq)(struct device___144 *);
	int (*runtime_suspend)(struct device___144 *);
	int (*runtime_resume)(struct device___144 *);
	int (*runtime_idle)(struct device___144 *);
};

struct device_type___144;

struct bus_type___144;

struct device_driver___144;

struct dev_pm_domain___144;

struct class___144;

struct attribute_group___136;

struct device_rh___144;

struct device___144 {
	struct device___144 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___144 *type;
	struct mutex___182 mutex;
	struct bus_type___144 *bus;
	struct device_driver___144 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___144 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___57 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___144 *class;
	const struct attribute_group___136 **groups;
	void (*release)(struct device___144 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___144 *device_rh;
};

struct dev_pm_info_rh___144 {
	void (*set_latency_tolerance)(struct device___144 *, s32);
};

struct dev_pm_domain___144 {
	struct dev_pm_ops___144 ops;
};

struct smp_ops___181 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___181 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___178 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___178 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___164;

struct memcg_cache_params___165;

struct kmem_cache___165 {
	struct kmem_cache_cpu___164 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___165 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___179;

struct address_space_operations___179;

struct address_space___179 {
	struct inode___179 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___182 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___179 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___43 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___179;

struct path___179 {
	struct vfsmount *mnt;
	struct dentry___179 *dentry;
};

struct file_operations___179;

struct file___179 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___179 f_path;
	struct inode___179 *f_inode;
	const struct file_operations___179 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___179 *f_mapping;
	struct mutex___182 f_pos_lock;
};

struct vm_operations_struct___159;

struct vm_area_struct___186 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___186 *vm_next;
	struct vm_area_struct___186 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___186 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___159 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___179 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___156;

struct vm_operations_struct___159 {
	void (*open)(struct vm_area_struct___186 *);
	void (*close)(struct vm_area_struct___186 *);
	int (*fault)(struct vm_area_struct___186 *, struct vm_fault___156 *);
	int (*page_mkwrite)(struct vm_area_struct___186 *, struct vm_fault___156 *);
	int (*access)(struct vm_area_struct___186 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___186 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___186 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___186 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___186 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___181 {
	struct task_struct___181 *task;
	struct core_thread___181 *next;
};

struct core_state___181 {
	atomic_t nr_threads;
	struct core_thread___181 dumper;
	struct completion startup;
};

struct vm_fault___156 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___178 *page;
};

struct dentry_operations___179;

struct super_block___179;

struct dentry___179 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___179 *d_parent;
	struct qstr d_name;
	struct inode___179 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___179 *d_op;
	struct super_block___179 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___179;

struct file_lock___179;

struct dquot___179;

struct block_device___179;

struct cdev___43;

struct inode___179 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___179 *i_op;
	struct super_block___179 *i_sb;
	struct address_space___179 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___182 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___179 *i_fop;
	struct file_lock___179 *i_flock;
	struct address_space___179 i_data;
	struct dquot___179 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___179 *i_bdev;
		struct cdev___43 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___179 {
	int (*d_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_hash)(const struct dentry___179 *, struct qstr *);
	int (*d_compare)(const struct dentry___179 *, const struct dentry___179 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___179 *);
	void (*d_release)(struct dentry___179 *);
	void (*d_prune)(struct dentry___179 *);
	void (*d_iput)(struct dentry___179 *, struct inode___179 *);
	char * (*d_dname)(struct dentry___179 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___179 *);
	int (*d_manage)(struct dentry___179 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___179;

struct mem_dqinfo___179 {
	struct quota_format_type___179 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___179;

struct quota_info___179 {
	unsigned int flags;
	struct mutex___182 dqio_mutex;
	struct mutex___182 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___179 *files[2];
	struct mem_dqinfo___179 info[2];
	const struct quota_format_ops___179 *ops[2];
};

struct file_system_type___179;

struct super_operations___179;

struct dquot_operations___179;

struct quotactl_ops___179;

struct super_block___179 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___179 *s_type;
	const struct super_operations___179 *s_op;
	const struct dquot_operations___179 *dq_op;
	const struct quotactl_ops___179 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___179 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___179 *s_bdev;
	struct backing_dev_info___43 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___179 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___182 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___179 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___34;

typedef void bio_end_io_t___34(struct bio___34 *, int);

struct bio_vec___34 {
	struct page___178 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___34;

struct bio_set___34;

struct bio___34 {
	sector_t bi_sector;
	struct bio___34 *bi_next;
	struct block_device___179 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___34 *bi_end_io;
	void *bi_private;
	struct io_context___33 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___34 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___34 *bi_io_vec;
	struct bio_set___34 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___34 bi_inline_vecs[0];
};

struct hd_struct___34;

struct gendisk___34;

struct request_queue___33;

struct block_device___179 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___179 *bd_inode;
	struct super_block___179 *bd_super;
	struct mutex___182 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___179 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___34 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___34 *bd_disk;
	struct request_queue___33 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___182 bd_fsfreeze_mutex;
};

struct io_cq___33;

struct io_context___33 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___33 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___34 {
	struct bio___34 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___34 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___34 *bip_vec;
	struct bio_vec___34 bip_inline_vecs[0];
};

struct bio_list___33 {
	struct bio___34 *head;
	struct bio___34 *tail;
};

struct bio_set___34 {
	struct kmem_cache___165 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___33 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___179 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___179 *ia_file;
};

struct dquot___179 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___182 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___179 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___179 {
	int qf_fmt_id;
	const struct quota_format_ops___179 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___179 *qf_next;
};

struct quota_format_ops___179 {
	int (*check_quota_file)(struct super_block___179 *, int);
	int (*read_file_info)(struct super_block___179 *, int);
	int (*write_file_info)(struct super_block___179 *, int);
	int (*free_file_info)(struct super_block___179 *, int);
	int (*read_dqblk)(struct dquot___179 *);
	int (*commit_dqblk)(struct dquot___179 *);
	int (*release_dqblk)(struct dquot___179 *);
};

struct dquot_operations___179 {
	int (*write_dquot)(struct dquot___179 *);
	struct dquot___179 * (*alloc_dquot)(struct super_block___179 *, int);
	void (*destroy_dquot)(struct dquot___179 *);
	int (*acquire_dquot)(struct dquot___179 *);
	int (*release_dquot)(struct dquot___179 *);
	int (*mark_dirty)(struct dquot___179 *);
	int (*write_info)(struct super_block___179 *, int);
	qsize_t * (*get_reserved_space)(struct inode___179 *);
};

struct quotactl_ops___179 {
	int (*quota_on)(struct super_block___179 *, int, int, struct path___179 *);
	int (*quota_on_meta)(struct super_block___179 *, int, int);
	int (*quota_off)(struct super_block___179 *, int);
	int (*quota_sync)(struct super_block___179 *, int);
	int (*get_info)(struct super_block___179 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___179 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___179 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___179 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___179 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___179 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___179 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___179 *, unsigned int);
};

struct address_space_operations___179 {
	int (*writepage)(struct page___178 *, struct writeback_control *);
	int (*readpage)(struct file___179 *, struct page___178 *);
	int (*writepages)(struct address_space___179 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___178 *);
	int (*readpages)(struct file___179 *, struct address_space___179 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___179 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___178 **, void **);
	int (*write_end)(struct file___179 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___178 *, void *);
	sector_t (*bmap)(struct address_space___179 *, sector_t);
	void (*invalidatepage)(struct page___178 *, long unsigned int);
	int (*releasepage)(struct page___178 *, gfp_t);
	void (*freepage)(struct page___178 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___179 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___179 *, struct page___178 *, struct page___178 *, enum migrate_mode);
	int (*launder_page)(struct page___178 *);
	int (*is_partially_uptodate)(struct page___178 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___178 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___179 *, struct page___178 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___179 *, sector_t *);
	void (*swap_deactivate)(struct file___179 *);
	void (*invalidatepage_range)(struct page___178 *, unsigned int, unsigned int);
};

struct bdi_writeback___43 {
	struct backing_dev_info___43 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___43 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___43 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___144 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___179 *debug_dir;
	struct dentry___179 *debug_stats;
};

struct hd_struct___34 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___144 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___34;

struct block_device_operations___33;

struct gendisk___34 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___34 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___34 *part_tbl;
	struct hd_struct___34 part0;
	const struct block_device_operations___33 *fops;
	struct request_queue___33 *queue;
	void *private_data;
	int flags;
	struct device___144 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___33 {
	struct request_queue___33 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___33(struct request_queue___33 *);

typedef void make_request_fn___33(struct request_queue___33 *, struct bio___34 *);

struct request___33;

typedef int prep_rq_fn___33(struct request_queue___33 *, struct request___33 *);

struct bvec_merge_data___33;

typedef int merge_bvec_fn___34(struct request_queue___33 *, struct bvec_merge_data___33 *, struct bio_vec___34 *);

typedef void softirq_done_fn___33(struct request___33 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___33(struct request___33 *);

typedef int dma_drain_needed_fn___33(struct request___33 *);

typedef int lld_busy_fn___33(struct request_queue___33 *);

struct bsg_class_device___33 {
	struct device___144 *class_dev;
	struct device___144 *parent;
	int minor;
	struct request_queue___33 *queue;
	struct kref ref;
	void (*release)(struct device___144 *);
};

typedef void unprep_rq_fn___33(struct request_queue___33 *, struct request___33 *);

struct elevator_queue___33;

struct blk_queue_tag___33;

struct request_queue___33 {
	struct list_head queue_head;
	struct request___33 *last_merge;
	struct elevator_queue___33 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___33 root_rl;
	request_fn_proc___33 *request_fn;
	make_request_fn___33 *make_request_fn;
	prep_rq_fn___33 *prep_rq_fn;
	merge_bvec_fn___34 *merge_bvec_fn;
	softirq_done_fn___33 *softirq_done_fn;
	rq_timed_out_fn___33 *rq_timed_out_fn;
	dma_drain_needed_fn___33 *dma_drain_needed;
	lld_busy_fn___33 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___33 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___43 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___144 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___33 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___33 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___182 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___33 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___33 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___34 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___43 {
	struct kobject___4 kobj;
	struct module *owner;
	const struct file_operations___179 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___179 {
	struct dentry___179 * (*lookup)(struct inode___179 *, struct dentry___179 *, unsigned int);
	void * (*follow_link)(struct dentry___179 *, struct nameidata *);
	int (*permission)(struct inode___179 *, int);
	struct posix_acl * (*get_acl)(struct inode___179 *, int);
	int (*readlink)(struct dentry___179 *, char *, int);
	void (*put_link)(struct dentry___179 *, struct nameidata *, void *);
	int (*create)(struct inode___179 *, struct dentry___179 *, umode_t, bool);
	int (*link)(struct dentry___179 *, struct inode___179 *, struct dentry___179 *);
	int (*unlink)(struct inode___179 *, struct dentry___179 *);
	int (*symlink)(struct inode___179 *, struct dentry___179 *, const char *);
	int (*mkdir)(struct inode___179 *, struct dentry___179 *, umode_t);
	int (*rmdir)(struct inode___179 *, struct dentry___179 *);
	int (*mknod)(struct inode___179 *, struct dentry___179 *, umode_t, dev_t);
	int (*rename)(struct inode___179 *, struct dentry___179 *, struct inode___179 *, struct dentry___179 *);
	int (*setattr)(struct dentry___179 *, struct iattr___179 *);
	int (*getattr)(struct vfsmount *, struct dentry___179 *, struct kstat *);
	int (*setxattr)(struct dentry___179 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___179 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___179 *, char *, size_t);
	int (*removexattr)(struct dentry___179 *, const char *);
	int (*fiemap)(struct inode___179 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___179 *, struct timespec *, int);
	int (*atomic_open)(struct inode___179 *, struct dentry___179 *, struct file___179 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___105;

struct seq_file___128;

struct file_operations___179 {
	struct module *owner;
	loff_t (*llseek)(struct file___179 *, loff_t, int);
	ssize_t (*read)(struct file___179 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___179 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___179 *, void *, filldir_t);
	unsigned int (*poll)(struct file___179 *, struct poll_table_struct___105 *);
	long int (*unlocked_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___179 *, struct vm_area_struct___186 *);
	int (*open)(struct inode___179 *, struct file___179 *);
	int (*flush)(struct file___179 *, fl_owner_t);
	int (*release)(struct inode___179 *, struct file___179 *);
	int (*fsync)(struct file___179 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___179 *, int);
	int (*lock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*sendpage)(struct file___179 *, struct page___178 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___179 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___179 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___179 *, long int, struct file_lock___179 **, void **);
		struct {
			int (*setlease)(struct file___179 *, long int, struct file_lock___179 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___179 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___128 *, struct file___179 *);
};

struct fasync_struct___179;

struct file_lock_operations___179;

struct lock_manager_operations___179;

struct file_lock___179 {
	struct file_lock___179 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___179 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___179 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___179 *fl_ops;
	const struct lock_manager_operations___179 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___179 {
	void (*fl_copy_lock)(struct file_lock___179 *, struct file_lock___179 *);
	void (*fl_release_private)(struct file_lock___179 *);
};

struct lock_manager_operations___179 {
	int (*lm_compare_owner)(struct file_lock___179 *, struct file_lock___179 *);
	long unsigned int (*lm_owner_key)(struct file_lock___179 *);
	void (*lm_notify)(struct file_lock___179 *);
	int (*lm_grant)(struct file_lock___179 *, struct file_lock___179 *, int);
	void (*lm_break)(struct file_lock___179 *);
	int (*lm_change)(struct file_lock___179 **, int);
};

struct fasync_struct___179 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___179 *fa_next;
	struct file___179 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___179 {
	const char *name;
	int fs_flags;
	struct dentry___179 * (*mount)(struct file_system_type___179 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___179 *);
	struct module *owner;
	struct file_system_type___179 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___179 {
	struct inode___179 * (*alloc_inode)(struct super_block___179 *);
	void (*destroy_inode)(struct inode___179 *);
	void (*dirty_inode)(struct inode___179 *, int);
	int (*write_inode)(struct inode___179 *, struct writeback_control *);
	int (*drop_inode)(struct inode___179 *);
	void (*evict_inode)(struct inode___179 *);
	void (*put_super)(struct super_block___179 *);
	int (*sync_fs)(struct super_block___179 *, int);
	int (*freeze_fs)(struct super_block___179 *);
	int (*unfreeze_fs)(struct super_block___179 *);
	int (*statfs)(struct dentry___179 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___179 *, int *, char *);
	void (*umount_begin)(struct super_block___179 *);
	int (*show_options)(struct seq_file___128 *, struct dentry___179 *);
	int (*show_devname)(struct seq_file___128 *, struct dentry___179 *);
	int (*show_path)(struct seq_file___128 *, struct dentry___179 *);
	int (*show_stats)(struct seq_file___128 *, struct dentry___179 *);
	ssize_t (*quota_read)(struct super_block___179 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___179 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___179 *);
	int (*bdev_try_to_free_page)(struct super_block___179 *, struct page___178 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___179 *);
	void (*free_cached_objects)(struct super_block___179 *, int);
};

typedef void (*poll_queue_proc___107)(struct file___179 *, wait_queue_head_t *, struct poll_table_struct___105 *);

struct poll_table_struct___105 {
	poll_queue_proc___107 _qproc;
	long unsigned int _key;
};

struct seq_operations___128;

struct seq_file___128 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___182 lock;
	const struct seq_operations___128 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___123 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___123 *);
	void (*irq_shutdown)(struct irq_data___123 *);
	void (*irq_enable)(struct irq_data___123 *);
	void (*irq_disable)(struct irq_data___123 *);
	void (*irq_ack)(struct irq_data___123 *);
	void (*irq_mask)(struct irq_data___123 *);
	void (*irq_mask_ack)(struct irq_data___123 *);
	void (*irq_unmask)(struct irq_data___123 *);
	void (*irq_eoi)(struct irq_data___123 *);
	int (*irq_set_affinity)(struct irq_data___123 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___123 *);
	int (*irq_set_type)(struct irq_data___123 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___123 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___123 *);
	void (*irq_bus_sync_unlock)(struct irq_data___123 *);
	void (*irq_cpu_online)(struct irq_data___123 *);
	void (*irq_cpu_offline)(struct irq_data___123 *);
	void (*irq_suspend)(struct irq_data___123 *);
	void (*irq_resume)(struct irq_data___123 *);
	void (*irq_pm_shutdown)(struct irq_data___123 *);
	void (*irq_print_chip)(struct irq_data___123 *, struct seq_file___128 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___123 *, void *);
	long unsigned int flags;
};

struct signal_struct___181 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___181 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___181 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___182 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___138;

struct attribute_group___136 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___138 **bin_attrs;
};

struct bin_attribute___138 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___179 *, struct kobject___4 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___179 *, struct kobject___4 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	int (*mmap)(struct file___179 *, struct kobject___4 *, struct bin_attribute___138 *, struct vm_area_struct___186 *);
};

struct kmem_cache_cpu___164 {
	void **freelist;
	long unsigned int tid;
	struct page___178 *page;
	struct page___178 *partial;
};

struct memcg_cache_params___165 {
	bool is_root_cache;
	union {
		struct kmem_cache___165 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___165 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

enum {
	DOS_EXTENDED_PARTITION = 5,
	LINUX_EXTENDED_PARTITION = 133,
	WIN98_EXTENDED_PARTITION = 15,
	SUN_WHOLE_DISK = 5,
	LINUX_SWAP_PARTITION = 130,
	LINUX_DATA_PARTITION = 131,
	LINUX_LVM_PARTITION = 142,
	LINUX_RAID_PARTITION = 253,
	SOLARIS_X86_PARTITION = 130,
	NEW_SOLARIS_X86_PARTITION = 191,
	DM6_AUX1PARTITION = 81,
	DM6_AUX3PARTITION = 83,
	DM6_PARTITION = 84,
	EZD_PARTITION = 85,
	FREEBSD_PARTITION = 165,
	OPENBSD_PARTITION = 166,
	NETBSD_PARTITION = 169,
	BSDI_PARTITION = 183,
	MINIX_PARTITION = 129,
	UNIXWARE_PARTITION = 99,
};

struct bus_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___144 *, char *);
	ssize_t (*store)(struct bus_type___144 *, const char *, size_t);
};

struct device_attribute___144;

struct driver_attribute___144;

struct bus_type___144 {
	const char *name;
	const char *dev_name;
	struct device___144 *dev_root;
	struct bus_attribute___144 *bus_attrs;
	struct device_attribute___144 *dev_attrs;
	struct driver_attribute___144 *drv_attrs;
	const struct attribute_group___136 **bus_groups;
	const struct attribute_group___136 **dev_groups;
	const struct attribute_group___136 **drv_groups;
	int (*match)(struct device___144 *, struct device_driver___144 *);
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	int (*probe)(struct device___144 *);
	int (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*online)(struct device___144 *);
	int (*offline)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct device___144 *, struct device_attribute___144 *, char *);
	ssize_t (*store)(struct device___144 *, struct device_attribute___144 *, const char *, size_t);
};

struct driver_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___144 *, char *);
	ssize_t (*store)(struct device_driver___144 *, const char *, size_t);
};

struct device_driver___144 {
	const char *name;
	struct bus_type___144 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___144 *);
	int (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	const struct attribute_group___136 **groups;
	const struct dev_pm_ops___144 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___144 {
	const char *name;
	const struct attribute_group___136 **groups;
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
};

struct class_attribute___144;

struct class___144 {
	const char *name;
	struct module *owner;
	struct class_attribute___144 *class_attrs;
	struct device_attribute___144 *dev_attrs;
	const struct attribute_group___136 **dev_groups;
	struct bin_attribute___138 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *);
	void (*class_release)(struct class___144 *);
	void (*dev_release)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
	struct subsys_private *p;
};

struct class_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct class___144 *, struct class_attribute___144 *, char *);
	ssize_t (*store)(struct class___144 *, struct class_attribute___144 *, const char *, size_t);
	const void * (*namespace)(struct class___144 *, const struct class_attribute___144 *);
};

struct device_rh___144 {
	struct dev_pm_info_rh___144 power;
};

struct partition {
	unsigned char boot_ind;
	unsigned char head;
	unsigned char sector;
	unsigned char cyl;
	unsigned char sys_ind;
	unsigned char end_head;
	unsigned char end_sector;
	unsigned char end_cyl;
	__le32 start_sect;
	__le32 nr_sects;
};

struct disk_part_tbl___34 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___34 *last_lookup;
	struct hd_struct___34 *part[0];
};

struct block_device_operations___33 {
	int (*open)(struct block_device___179 *, fmode_t);
	void (*release)(struct gendisk___34 *, fmode_t);
	int (*ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___179 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___34 *, unsigned int);
	int (*media_changed)(struct gendisk___34 *);
	void (*unlock_native_capacity)(struct gendisk___34 *);
	int (*revalidate_disk)(struct gendisk___34 *);
	int (*getgeo)(struct block_device___179 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___179 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct solaris_x86_slice {
	__le16 s_tag;
	__le16 s_flag;
	__le32 s_start;
	__le32 s_size;
};

struct solaris_x86_vtoc {
	unsigned int v_bootinfo[3];
	__le32 v_sanity;
	__le32 v_version;
	char v_volume[8];
	__le16 v_sectorsz;
	__le16 v_nparts;
	unsigned int v_reserved[10];
	struct solaris_x86_slice v_slice[16];
	unsigned int timestamp[16];
	char v_asciilabel[128];
};

struct bsd_partition {
	__le32 p_size;
	__le32 p_offset;
	__le32 p_fsize;
	__u8 p_fstype;
	__u8 p_frag;
	__le16 p_cpg;
};

struct bsd_disklabel {
	__le32 d_magic;
	__s16 d_type;
	__s16 d_subtype;
	char d_typename[16];
	char d_packname[16];
	__u32 d_secsize;
	__u32 d_nsectors;
	__u32 d_ntracks;
	__u32 d_ncylinders;
	__u32 d_secpercyl;
	__u32 d_secperunit;
	__u16 d_sparespertrack;
	__u16 d_sparespercyl;
	__u32 d_acylinders;
	__u16 d_rpm;
	__u16 d_interleave;
	__u16 d_trackskew;
	__u16 d_cylskew;
	__u32 d_headswitch;
	__u32 d_trkseek;
	__u32 d_flags;
	__u32 d_drivedata[5];
	__u32 d_spare[5];
	__le32 d_magic2;
	__le16 d_checksum;
	__le16 d_npartitions;
	__le32 d_bbsize;
	__le32 d_sbsize;
	struct bsd_partition d_partitions[16];
};

struct unixware_slice {
	__le16 s_label;
	__le16 s_flags;
	__le32 start_sect;
	__le32 nr_sects;
};

struct unixware_vtoc {
	__le32 v_magic;
	__le32 v_version;
	char v_name[8];
	__le16 v_nslices;
	__le16 v_unknown1;
	__le32 v_reserved[10];
	struct unixware_slice v_slice[16];
};

struct unixware_disklabel {
	__le32 d_type;
	__le32 d_magic;
	__le32 d_version;
	char d_serial[12];
	__le32 d_ncylinders;
	__le32 d_ntracks;
	__le32 d_nsectors;
	__le32 d_secsize;
	__le32 d_part_start;
	__le32 d_unknown1[12];
	__le32 d_alt_tbl;
	__le32 d_alt_len;
	__le32 d_phys_cyl;
	__le32 d_phys_trk;
	__le32 d_phys_sec;
	__le32 d_phys_bytes;
	__le32 d_unknown2;
	__le32 d_unknown3;
	__le32 d_pad[8];
	struct unixware_vtoc vtoc;
};

struct io_cq___33 {
	struct request_queue___33 *q;
	struct io_context___33 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___165 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___33(struct request___33 *, int);

struct request___33 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___33 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___34 *bio;
	struct bio___34 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___33 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___33 *saved_end_io;
		} flush;
	};
	struct gendisk___34 *rq_disk;
	struct hd_struct___34 *part;
	long unsigned int start_time;
	struct request_list___33 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___33 *end_io;
	void *end_io_data;
	struct request___33 *next_rq;
};

typedef int elevator_merge_fn___33(struct request_queue___33 *, struct request___33 **, struct bio___34 *);

typedef void elevator_merge_req_fn___33(struct request_queue___33 *, struct request___33 *, struct request___33 *);

typedef void elevator_merged_fn___33(struct request_queue___33 *, struct request___33 *, int);

typedef int elevator_allow_merge_fn___33(struct request_queue___33 *, struct request___33 *, struct bio___34 *);

typedef void elevator_bio_merged_fn___33(struct request_queue___33 *, struct request___33 *, struct bio___34 *);

typedef int elevator_dispatch_fn___33(struct request_queue___33 *, int);

typedef void elevator_add_req_fn___33(struct request_queue___33 *, struct request___33 *);

typedef struct request___33 *elevator_request_list_fn___33(struct request_queue___33 *, struct request___33 *);

typedef void elevator_completed_req_fn___33(struct request_queue___33 *, struct request___33 *);

typedef int elevator_may_queue_fn___33(struct request_queue___33 *, int);

typedef void elevator_init_icq_fn___33(struct io_cq___33 *);

typedef void elevator_exit_icq_fn___33(struct io_cq___33 *);

typedef int elevator_set_req_fn___33(struct request_queue___33 *, struct request___33 *, struct bio___34 *, gfp_t);

typedef void elevator_put_req_fn___33(struct request___33 *);

typedef void elevator_activate_req_fn___33(struct request_queue___33 *, struct request___33 *);

typedef void elevator_deactivate_req_fn___33(struct request_queue___33 *, struct request___33 *);

struct elevator_type___33;

typedef int elevator_init_fn___34(struct request_queue___33 *, struct elevator_type___33 *);

typedef void elevator_exit_fn___33(struct elevator_queue___33 *);

struct elevator_ops___33 {
	elevator_merge_fn___33 *elevator_merge_fn;
	elevator_merged_fn___33 *elevator_merged_fn;
	elevator_merge_req_fn___33 *elevator_merge_req_fn;
	elevator_allow_merge_fn___33 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___33 *elevator_bio_merged_fn;
	elevator_dispatch_fn___33 *elevator_dispatch_fn;
	elevator_add_req_fn___33 *elevator_add_req_fn;
	elevator_activate_req_fn___33 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___33 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___33 *elevator_completed_req_fn;
	elevator_request_list_fn___33 *elevator_former_req_fn;
	elevator_request_list_fn___33 *elevator_latter_req_fn;
	elevator_init_icq_fn___33 *elevator_init_icq_fn;
	elevator_exit_icq_fn___33 *elevator_exit_icq_fn;
	elevator_set_req_fn___33 *elevator_set_req_fn;
	elevator_put_req_fn___33 *elevator_put_req_fn;
	elevator_may_queue_fn___33 *elevator_may_queue_fn;
	elevator_init_fn___34 *elevator_init_fn;
	elevator_exit_fn___33 *elevator_exit_fn;
};

struct elv_fs_entry___33;

struct elevator_type___33 {
	struct kmem_cache___165 *icq_cache;
	struct elevator_ops___33 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___33 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___33 {
	struct elevator_type___33 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___182 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___33 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___33 *, char *);
	ssize_t (*store)(struct elevator_queue___33 *, const char *, size_t);
};

struct bvec_merge_data___33 {
	struct block_device___179 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___33 {
	struct request___33 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

typedef struct {
	struct page___178 *v;
} Sector___3;

struct parsed_partitions___4 {
	struct block_device___179 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

struct seq_operations___128 {
	void * (*start)(struct seq_file___128 *, loff_t *);
	void (*stop)(struct seq_file___128 *, void *);
	void * (*next)(struct seq_file___128 *, void *, loff_t *);
	int (*show)(struct seq_file___128 *, void *);
};

struct d_partition {
	__le32 p_size;
	__le32 p_offset;
	__le32 p_fsize;
	u8 p_fstype;
	u8 p_frag;
	__le16 p_cpg;
};

struct disklabel {
	__le32 d_magic;
	__le16 d_type;
	__le16 d_subtype;
	u8 d_typename[16];
	u8 d_packname[16];
	__le32 d_secsize;
	__le32 d_nsectors;
	__le32 d_ntracks;
	__le32 d_ncylinders;
	__le32 d_secpercyl;
	__le32 d_secprtunit;
	__le16 d_sparespertrack;
	__le16 d_sparespercyl;
	__le32 d_acylinders;
	__le16 d_rpm;
	__le16 d_interleave;
	__le16 d_trackskew;
	__le16 d_cylskew;
	__le32 d_headswitch;
	__le32 d_trkseek;
	__le32 d_flags;
	__le32 d_drivedata[5];
	__le32 d_spare[5];
	__le32 d_magic2;
	__le16 d_checksum;
	__le16 d_npartitions;
	__le32 d_bbsize;
	__le32 d_sbsize;
	struct d_partition d_partitions[18];
};

struct sgi_volume {
	s8 name[8];
	__be32 block_num;
	__be32 num_bytes;
};

struct sgi_partition {
	__be32 num_blocks;
	__be32 first_block;
	__be32 type;
};

struct sgi_disklabel {
	__be32 magic_mushroom;
	__be16 root_part_num;
	__be16 swap_part_num;
	s8 boot_file[16];
	u8 _unused0[48];
	struct sgi_volume volume[15];
	struct sgi_partition partitions[16];
	__be32 csum;
	__be32 _unused1;
};

struct sun_info {
	__be16 id;
	__be16 flags;
};

struct sun_vtoc {
	__be32 version;
	char volume[8];
	__be16 nparts;
	struct sun_info infos[8];
	__be16 padding;
	__be32 bootinfo[3];
	__be32 sanity;
	__be32 reserved[10];
	__be32 timestamp[8];
};

struct sun_partition {
	__be32 start_cylinder;
	__be32 num_sectors;
};

struct sun_disklabel {
	unsigned char info[128];
	struct sun_vtoc vtoc;
	__be32 write_reinstruct;
	__be32 read_reinstruct;
	unsigned char spare[148];
	__be16 rspeed;
	__be16 pcylcount;
	__be16 sparecyl;
	__be16 obs1;
	__be16 obs2;
	__be16 ilfact;
	__be16 ncyl;
	__be16 nacyl;
	__be16 ntrks;
	__be16 nsect;
	__be16 obs3;
	__be16 obs4;
	struct sun_partition partitions[8];
	__be16 magic;
	__be16 csum;
};

struct _gpt_header {
	__le64 signature;
	__le32 revision;
	__le32 header_size;
	__le32 header_crc32;
	__le32 reserved1;
	__le64 my_lba;
	__le64 alternate_lba;
	__le64 first_usable_lba;
	__le64 last_usable_lba;
	efi_guid_t disk_guid;
	__le64 partition_entry_lba;
	__le32 num_partition_entries;
	__le32 sizeof_partition_entry;
	__le32 partition_entry_array_crc32;
} __attribute__((packed));

typedef struct _gpt_header gpt_header;

struct _gpt_entry_attributes {
	u64 required_to_function: 1;
	u64 reserved: 47;
	u64 type_guid_specific: 16;
};

typedef struct _gpt_entry_attributes gpt_entry_attributes;

struct _gpt_entry {
	efi_guid_t partition_type_guid;
	efi_guid_t unique_partition_guid;
	__le64 starting_lba;
	__le64 ending_lba;
	gpt_entry_attributes attributes;
	efi_char16_t partition_name[36];
};

typedef struct _gpt_entry gpt_entry;

struct _legacy_mbr {
	u8 boot_code[440];
	__le32 unique_mbr_signature;
	__le16 unknown;
	struct partition partition_record[4];
	__le16 signature;
} __attribute__((packed));

typedef struct _legacy_mbr legacy_mbr;

struct d_partition___2 {
	__le32 p_res;
	u8 p_fstype;
	u8 p_res2[3];
	__le32 p_offset;
	__le32 p_size;
};

struct disklabel___2 {
	u8 d_reserved[270];
	struct d_partition___2 d_partitions[2];
	u8 d_blank[208];
	__le16 d_magic;
} __attribute__((packed));

struct page___179;

typedef struct page___179 *pgtable_t___179;

struct address_space___180;

struct kmem_cache___166;

struct page___179 {
	long unsigned int flags;
	struct address_space___180 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___179 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___179 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___166 *slab_cache;
		struct page___179 *first_page;
	};
	long: 64;
};

struct task_struct___182;

struct pv_cpu_ops___182 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___182 *);
	void (*end_context_switch)(struct task_struct___182 *);
};

struct mutex___183 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___182 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___175 {
	struct page___179 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___187;

struct signal_struct___182;

struct bio_list___34;

struct backing_dev_info___44;

struct io_context___34;

struct task_struct___182 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___182 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___187 *mm;
	struct mm_struct___187 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___182 *real_parent;
	struct task_struct___182 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___182 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___182 = 0,
		VTIME_USER___182 = 1,
		VTIME_SYS___182 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___182 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___34 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___44 *backing_dev_info;
	struct io_context___34 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___183 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___175 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___187 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___187 *, struct mm_struct___187 *);
	void (*dup_mmap)(struct mm_struct___187 *, struct mm_struct___187 *);
	void (*exit_mmap)(struct mm_struct___187 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___187 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___187 *);
	void (*pgd_free)(struct mm_struct___187 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___187 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___187 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___187 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___187 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___187 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___187 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___187 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___187 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___187 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___187 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___187 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___183 lock;
	void *vdso;
} mm_context_t___183;

struct xol_area___179;

struct uprobes_state___179 {
	struct xol_area___179 *xol_area;
};

struct vm_area_struct___187;

struct file___180;

struct core_state___182;

struct mm_struct___187 {
	struct vm_area_struct___187 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___187 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___187 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___183 context;
	long unsigned int flags;
	struct core_state___182 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___182 *owner;
	struct file___180 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___179 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___97;

struct exec_domain___43 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___97 *module;
	struct exec_domain___43 *next;
};

struct module_kobject___96 {
	struct kobject___4 kobj;
	struct module___97 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___96;

struct module___97 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___96 mkobj;
	struct module_attribute___96 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___182 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___81 {
	struct task_struct___182 *task;
	struct exec_domain___43 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___182;

struct lruvec___182 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___182 *zone;
};

struct pglist_data___182;

struct zone___182 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___182 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___182 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___182 {
	struct zone___182 *zone;
	int zone_idx;
};

struct zonelist___182 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___182 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___182 {
	struct zone___182 node_zones[4];
	struct zonelist___182 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___182 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___145;

struct dev_pm_ops___145 {
	int (*prepare)(struct device___145 *);
	void (*complete)(struct device___145 *);
	int (*suspend)(struct device___145 *);
	int (*resume)(struct device___145 *);
	int (*freeze)(struct device___145 *);
	int (*thaw)(struct device___145 *);
	int (*poweroff)(struct device___145 *);
	int (*restore)(struct device___145 *);
	int (*suspend_late)(struct device___145 *);
	int (*resume_early)(struct device___145 *);
	int (*freeze_late)(struct device___145 *);
	int (*thaw_early)(struct device___145 *);
	int (*poweroff_late)(struct device___145 *);
	int (*restore_early)(struct device___145 *);
	int (*suspend_noirq)(struct device___145 *);
	int (*resume_noirq)(struct device___145 *);
	int (*freeze_noirq)(struct device___145 *);
	int (*thaw_noirq)(struct device___145 *);
	int (*poweroff_noirq)(struct device___145 *);
	int (*restore_noirq)(struct device___145 *);
	int (*runtime_suspend)(struct device___145 *);
	int (*runtime_resume)(struct device___145 *);
	int (*runtime_idle)(struct device___145 *);
};

struct dma_map_ops___58;

struct dev_archdata___58 {
	struct dma_map_ops___58 *dma_ops;
	void *iommu;
};

struct device_type___145;

struct bus_type___145;

struct device_driver___145;

struct dev_pm_domain___145;

struct class___145;

struct attribute_group___137;

struct device_rh___145;

struct device___145 {
	struct device___145 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___145 *type;
	struct mutex___183 mutex;
	struct bus_type___145 *bus;
	struct device_driver___145 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___145 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___58 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___145 *class;
	const struct attribute_group___137 **groups;
	void (*release)(struct device___145 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___145 *device_rh;
};

struct dev_pm_info_rh___145 {
	void (*set_latency_tolerance)(struct device___145 *, s32);
};

struct dev_pm_domain___145 {
	struct dev_pm_ops___145 ops;
};

struct smp_ops___182 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___182 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___139;

struct attribute_group___137 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___139 **bin_attrs;
};

struct bin_attribute___139 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___180 *, struct kobject___4 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___180 *, struct kobject___4 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	int (*mmap)(struct file___180 *, struct kobject___4 *, struct bin_attribute___139 *, struct vm_area_struct___187 *);
};

struct dentry___180;

struct path___180 {
	struct vfsmount *mnt;
	struct dentry___180 *dentry;
};

struct inode___180;

struct file_operations___180;

struct file___180 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___180 f_path;
	struct inode___180 *f_inode;
	const struct file_operations___180 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___180 *f_mapping;
	struct mutex___183 f_pos_lock;
};

struct vm_operations_struct___160;

struct vm_area_struct___187 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___187 *vm_next;
	struct vm_area_struct___187 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___187 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___160 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___180 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___96 *, struct module_kobject___96 *, char *);
	ssize_t (*store)(struct module_attribute___96 *, struct module_kobject___96 *, const char *, size_t);
	void (*setup)(struct module___97 *, const char *);
	int (*test)(struct module___97 *);
	void (*free)(struct module___97 *);
};

struct xol_area___179 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___179 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___165;

struct memcg_cache_params___166;

struct kmem_cache___166 {
	struct kmem_cache_cpu___165 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___166 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___180;

struct address_space___180 {
	struct inode___180 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___183 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___180 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___44 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___157;

struct vm_operations_struct___160 {
	void (*open)(struct vm_area_struct___187 *);
	void (*close)(struct vm_area_struct___187 *);
	int (*fault)(struct vm_area_struct___187 *, struct vm_fault___157 *);
	int (*page_mkwrite)(struct vm_area_struct___187 *, struct vm_fault___157 *);
	int (*access)(struct vm_area_struct___187 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___187 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___187 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___187 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___187 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___182 {
	struct task_struct___182 *task;
	struct core_thread___182 *next;
};

struct core_state___182 {
	atomic_t nr_threads;
	struct core_thread___182 dumper;
	struct completion startup;
};

struct signal_struct___182 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___182 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___182 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___183 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___35;

struct bio_list___34 {
	struct bio___35 *head;
	struct bio___35 *tail;
};

struct bdi_writeback___44 {
	struct backing_dev_info___44 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___44 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___44 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___145 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___180 *debug_dir;
	struct dentry___180 *debug_stats;
};

struct io_cq___34;

struct io_context___34 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___34 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___165 {
	void **freelist;
	long unsigned int tid;
	struct page___179 *page;
	struct page___179 *partial;
};

struct memcg_cache_params___166 {
	bool is_root_cache;
	union {
		struct kmem_cache___166 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___166 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___58 {
	void * (*alloc)(struct device___145 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___145 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___145 *, struct vm_area_struct___187 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___145 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___145 *, struct page___179 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___145 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___145 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___145 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___145 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___145 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___145 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___145 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___145 *, dma_addr_t);
	int (*dma_supported)(struct device___145 *, u64);
	int (*set_dma_mask)(struct device___145 *, u64);
	int is_phys;
};

struct bus_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___145 *, char *);
	ssize_t (*store)(struct bus_type___145 *, const char *, size_t);
};

struct device_attribute___145;

struct driver_attribute___145;

struct bus_type___145 {
	const char *name;
	const char *dev_name;
	struct device___145 *dev_root;
	struct bus_attribute___145 *bus_attrs;
	struct device_attribute___145 *dev_attrs;
	struct driver_attribute___145 *drv_attrs;
	const struct attribute_group___137 **bus_groups;
	const struct attribute_group___137 **dev_groups;
	const struct attribute_group___137 **drv_groups;
	int (*match)(struct device___145 *, struct device_driver___145 *);
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	int (*probe)(struct device___145 *);
	int (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*online)(struct device___145 *);
	int (*offline)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct device___145 *, struct device_attribute___145 *, char *);
	ssize_t (*store)(struct device___145 *, struct device_attribute___145 *, const char *, size_t);
};

struct driver_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___145 *, char *);
	ssize_t (*store)(struct device_driver___145 *, const char *, size_t);
};

struct device_driver___145 {
	const char *name;
	struct bus_type___145 *bus;
	struct module___97 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___145 *);
	int (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	const struct attribute_group___137 **groups;
	const struct dev_pm_ops___145 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___145 {
	const char *name;
	const struct attribute_group___137 **groups;
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
};

struct class_attribute___145;

struct class___145 {
	const char *name;
	struct module___97 *owner;
	struct class_attribute___145 *class_attrs;
	struct device_attribute___145 *dev_attrs;
	const struct attribute_group___137 **dev_groups;
	struct bin_attribute___139 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *);
	void (*class_release)(struct class___145 *);
	void (*dev_release)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
	struct subsys_private *p;
};

struct class_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct class___145 *, struct class_attribute___145 *, char *);
	ssize_t (*store)(struct class___145 *, struct class_attribute___145 *, const char *, size_t);
	const void * (*namespace)(struct class___145 *, const struct class_attribute___145 *);
};

struct device_rh___145 {
	struct dev_pm_info_rh___145 power;
};

struct dentry_operations___180;

struct super_block___180;

struct dentry___180 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___180 *d_parent;
	struct qstr d_name;
	struct inode___180 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___180 *d_op;
	struct super_block___180 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___180;

struct file_lock___180;

struct dquot___180;

struct block_device___180;

struct cdev___44;

struct inode___180 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___180 *i_op;
	struct super_block___180 *i_sb;
	struct address_space___180 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___183 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___180 *i_fop;
	struct file_lock___180 *i_flock;
	struct address_space___180 i_data;
	struct dquot___180 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___180 *i_bdev;
		struct cdev___44 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___180 {
	int (*d_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_hash)(const struct dentry___180 *, struct qstr *);
	int (*d_compare)(const struct dentry___180 *, const struct dentry___180 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___180 *);
	void (*d_release)(struct dentry___180 *);
	void (*d_prune)(struct dentry___180 *);
	void (*d_iput)(struct dentry___180 *, struct inode___180 *);
	char * (*d_dname)(struct dentry___180 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___180 *);
	int (*d_manage)(struct dentry___180 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___180;

struct mem_dqinfo___180 {
	struct quota_format_type___180 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___180;

struct quota_info___180 {
	unsigned int flags;
	struct mutex___183 dqio_mutex;
	struct mutex___183 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___180 *files[2];
	struct mem_dqinfo___180 info[2];
	const struct quota_format_ops___180 *ops[2];
};

struct file_system_type___180;

struct super_operations___180;

struct dquot_operations___180;

struct quotactl_ops___180;

struct super_block___180 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___180 *s_type;
	const struct super_operations___180 *s_op;
	const struct dquot_operations___180 *dq_op;
	const struct quotactl_ops___180 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___180 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___180 *s_bdev;
	struct backing_dev_info___44 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___180 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___183 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___180 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___35(struct bio___35 *, int);

struct bio_vec___35 {
	struct page___179 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___35;

struct bio_set___35;

struct bio___35 {
	sector_t bi_sector;
	struct bio___35 *bi_next;
	struct block_device___180 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___35 *bi_end_io;
	void *bi_private;
	struct io_context___34 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___35 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___35 *bi_io_vec;
	struct bio_set___35 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___35 bi_inline_vecs[0];
};

struct hd_struct___35;

struct gendisk___35;

struct request_queue___34;

struct block_device___180 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___180 *bd_inode;
	struct super_block___180 *bd_super;
	struct mutex___183 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___180 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___35 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___35 *bd_disk;
	struct request_queue___34 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___183 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___35 {
	struct bio___35 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___35 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___35 *bip_vec;
	struct bio_vec___35 bip_inline_vecs[0];
};

struct bio_set___35 {
	struct kmem_cache___166 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___34 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___180 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___180 *ia_file;
};

struct dquot___180 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___183 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___180 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___180 {
	int qf_fmt_id;
	const struct quota_format_ops___180 *qf_ops;
	struct module___97 *qf_owner;
	struct quota_format_type___180 *qf_next;
};

struct quota_format_ops___180 {
	int (*check_quota_file)(struct super_block___180 *, int);
	int (*read_file_info)(struct super_block___180 *, int);
	int (*write_file_info)(struct super_block___180 *, int);
	int (*free_file_info)(struct super_block___180 *, int);
	int (*read_dqblk)(struct dquot___180 *);
	int (*commit_dqblk)(struct dquot___180 *);
	int (*release_dqblk)(struct dquot___180 *);
};

struct dquot_operations___180 {
	int (*write_dquot)(struct dquot___180 *);
	struct dquot___180 * (*alloc_dquot)(struct super_block___180 *, int);
	void (*destroy_dquot)(struct dquot___180 *);
	int (*acquire_dquot)(struct dquot___180 *);
	int (*release_dquot)(struct dquot___180 *);
	int (*mark_dirty)(struct dquot___180 *);
	int (*write_info)(struct super_block___180 *, int);
	qsize_t * (*get_reserved_space)(struct inode___180 *);
};

struct quotactl_ops___180 {
	int (*quota_on)(struct super_block___180 *, int, int, struct path___180 *);
	int (*quota_on_meta)(struct super_block___180 *, int, int);
	int (*quota_off)(struct super_block___180 *, int);
	int (*quota_sync)(struct super_block___180 *, int);
	int (*get_info)(struct super_block___180 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___180 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___180 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___180 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___180 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___180 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___180 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___180 *, unsigned int);
};

struct address_space_operations___180 {
	int (*writepage)(struct page___179 *, struct writeback_control *);
	int (*readpage)(struct file___180 *, struct page___179 *);
	int (*writepages)(struct address_space___180 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___179 *);
	int (*readpages)(struct file___180 *, struct address_space___180 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___180 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___179 **, void **);
	int (*write_end)(struct file___180 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___179 *, void *);
	sector_t (*bmap)(struct address_space___180 *, sector_t);
	void (*invalidatepage)(struct page___179 *, long unsigned int);
	int (*releasepage)(struct page___179 *, gfp_t);
	void (*freepage)(struct page___179 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___180 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___180 *, struct page___179 *, struct page___179 *, enum migrate_mode);
	int (*launder_page)(struct page___179 *);
	int (*is_partially_uptodate)(struct page___179 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___179 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___180 *, struct page___179 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___180 *, sector_t *);
	void (*swap_deactivate)(struct file___180 *);
	void (*invalidatepage_range)(struct page___179 *, unsigned int, unsigned int);
};

struct hd_struct___35 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___145 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___35;

struct block_device_operations___34;

struct gendisk___35 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___35 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___35 *part_tbl;
	struct hd_struct___35 part0;
	const struct block_device_operations___34 *fops;
	struct request_queue___34 *queue;
	void *private_data;
	int flags;
	struct device___145 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___34 {
	struct request_queue___34 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___34(struct request_queue___34 *);

typedef void make_request_fn___34(struct request_queue___34 *, struct bio___35 *);

struct request___34;

typedef int prep_rq_fn___34(struct request_queue___34 *, struct request___34 *);

struct bvec_merge_data___34;

typedef int merge_bvec_fn___35(struct request_queue___34 *, struct bvec_merge_data___34 *, struct bio_vec___35 *);

typedef void softirq_done_fn___34(struct request___34 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___34(struct request___34 *);

typedef int dma_drain_needed_fn___34(struct request___34 *);

typedef int lld_busy_fn___34(struct request_queue___34 *);

struct bsg_class_device___34 {
	struct device___145 *class_dev;
	struct device___145 *parent;
	int minor;
	struct request_queue___34 *queue;
	struct kref ref;
	void (*release)(struct device___145 *);
};

typedef void unprep_rq_fn___34(struct request_queue___34 *, struct request___34 *);

struct elevator_queue___34;

struct blk_queue_tag___34;

struct request_queue___34 {
	struct list_head queue_head;
	struct request___34 *last_merge;
	struct elevator_queue___34 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___34 root_rl;
	request_fn_proc___34 *request_fn;
	make_request_fn___34 *make_request_fn;
	prep_rq_fn___34 *prep_rq_fn;
	merge_bvec_fn___35 *merge_bvec_fn;
	softirq_done_fn___34 *softirq_done_fn;
	rq_timed_out_fn___34 *rq_timed_out_fn;
	dma_drain_needed_fn___34 *dma_drain_needed;
	lld_busy_fn___34 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___8 *queue_ctx;
		struct {
			struct blk_mq_ctx___8 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___34 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___44 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___145 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___34 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___34 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___183 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___34 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___34 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___35 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___44 {
	struct kobject___4 kobj;
	struct module___97 *owner;
	const struct file_operations___180 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___180 {
	struct dentry___180 * (*lookup)(struct inode___180 *, struct dentry___180 *, unsigned int);
	void * (*follow_link)(struct dentry___180 *, struct nameidata *);
	int (*permission)(struct inode___180 *, int);
	struct posix_acl * (*get_acl)(struct inode___180 *, int);
	int (*readlink)(struct dentry___180 *, char *, int);
	void (*put_link)(struct dentry___180 *, struct nameidata *, void *);
	int (*create)(struct inode___180 *, struct dentry___180 *, umode_t, bool);
	int (*link)(struct dentry___180 *, struct inode___180 *, struct dentry___180 *);
	int (*unlink)(struct inode___180 *, struct dentry___180 *);
	int (*symlink)(struct inode___180 *, struct dentry___180 *, const char *);
	int (*mkdir)(struct inode___180 *, struct dentry___180 *, umode_t);
	int (*rmdir)(struct inode___180 *, struct dentry___180 *);
	int (*mknod)(struct inode___180 *, struct dentry___180 *, umode_t, dev_t);
	int (*rename)(struct inode___180 *, struct dentry___180 *, struct inode___180 *, struct dentry___180 *);
	int (*setattr)(struct dentry___180 *, struct iattr___180 *);
	int (*getattr)(struct vfsmount *, struct dentry___180 *, struct kstat *);
	int (*setxattr)(struct dentry___180 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___180 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___180 *, char *, size_t);
	int (*removexattr)(struct dentry___180 *, const char *);
	int (*fiemap)(struct inode___180 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___180 *, struct timespec *, int);
	int (*atomic_open)(struct inode___180 *, struct dentry___180 *, struct file___180 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___106;

struct file_operations___180 {
	struct module___97 *owner;
	loff_t (*llseek)(struct file___180 *, loff_t, int);
	ssize_t (*read)(struct file___180 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___180 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___180 *, void *, filldir_t);
	unsigned int (*poll)(struct file___180 *, struct poll_table_struct___106 *);
	long int (*unlocked_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___180 *, struct vm_area_struct___187 *);
	int (*open)(struct inode___180 *, struct file___180 *);
	int (*flush)(struct file___180 *, fl_owner_t);
	int (*release)(struct inode___180 *, struct file___180 *);
	int (*fsync)(struct file___180 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___180 *, int);
	int (*lock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*sendpage)(struct file___180 *, struct page___179 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___180 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___180 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___180 *, long int, struct file_lock___180 **, void **);
		struct {
			int (*setlease)(struct file___180 *, long int, struct file_lock___180 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___180 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___180 *);
};

struct fasync_struct___180;

struct file_lock_operations___180;

struct lock_manager_operations___180;

struct file_lock___180 {
	struct file_lock___180 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___180 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___180 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___180 *fl_ops;
	const struct lock_manager_operations___180 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___180 {
	void (*fl_copy_lock)(struct file_lock___180 *, struct file_lock___180 *);
	void (*fl_release_private)(struct file_lock___180 *);
};

struct lock_manager_operations___180 {
	int (*lm_compare_owner)(struct file_lock___180 *, struct file_lock___180 *);
	long unsigned int (*lm_owner_key)(struct file_lock___180 *);
	void (*lm_notify)(struct file_lock___180 *);
	int (*lm_grant)(struct file_lock___180 *, struct file_lock___180 *, int);
	void (*lm_break)(struct file_lock___180 *);
	int (*lm_change)(struct file_lock___180 **, int);
};

struct fasync_struct___180 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___180 *fa_next;
	struct file___180 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___180 {
	const char *name;
	int fs_flags;
	struct dentry___180 * (*mount)(struct file_system_type___180 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___180 *);
	struct module___97 *owner;
	struct file_system_type___180 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___180 {
	struct inode___180 * (*alloc_inode)(struct super_block___180 *);
	void (*destroy_inode)(struct inode___180 *);
	void (*dirty_inode)(struct inode___180 *, int);
	int (*write_inode)(struct inode___180 *, struct writeback_control *);
	int (*drop_inode)(struct inode___180 *);
	void (*evict_inode)(struct inode___180 *);
	void (*put_super)(struct super_block___180 *);
	int (*sync_fs)(struct super_block___180 *, int);
	int (*freeze_fs)(struct super_block___180 *);
	int (*unfreeze_fs)(struct super_block___180 *);
	int (*statfs)(struct dentry___180 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___180 *, int *, char *);
	void (*umount_begin)(struct super_block___180 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___180 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___180 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___180 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___180 *);
	ssize_t (*quota_read)(struct super_block___180 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___180 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___180 *);
	int (*bdev_try_to_free_page)(struct super_block___180 *, struct page___179 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___180 *);
	void (*free_cached_objects)(struct super_block___180 *, int);
};

typedef void (*poll_queue_proc___108)(struct file___180 *, wait_queue_head_t *, struct poll_table_struct___106 *);

struct poll_table_struct___106 {
	poll_queue_proc___108 _qproc;
	long unsigned int _key;
};

struct disk_part_tbl___35 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___35 *last_lookup;
	struct hd_struct___35 *part[0];
};

struct block_device_operations___34 {
	int (*open)(struct block_device___180 *, fmode_t);
	void (*release)(struct gendisk___35 *, fmode_t);
	int (*ioctl)(struct block_device___180 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___180 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___180 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___35 *, unsigned int);
	int (*media_changed)(struct gendisk___35 *);
	void (*unlock_native_capacity)(struct gendisk___35 *);
	int (*revalidate_disk)(struct gendisk___35 *);
	int (*getgeo)(struct block_device___180 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___180 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___97 *owner;
};

struct vm_fault___157 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___179 *page;
};

struct io_cq___34 {
	struct request_queue___34 *q;
	struct io_context___34 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___166 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct sg_io_v4 {
	__s32 guard;
	__u32 protocol;
	__u32 subprotocol;
	__u32 request_len;
	__u64 request;
	__u64 request_tag;
	__u32 request_attr;
	__u32 request_priority;
	__u32 request_extra;
	__u32 max_response_len;
	__u64 response;
	__u32 dout_iovec_count;
	__u32 dout_xfer_len;
	__u32 din_iovec_count;
	__u32 din_xfer_len;
	__u64 dout_xferp;
	__u64 din_xferp;
	__u32 timeout;
	__u32 flags;
	__u64 usr_ptr;
	__u32 spare_in;
	__u32 driver_status;
	__u32 transport_status;
	__u32 device_status;
	__u32 retry_delay;
	__u32 info;
	__u32 duration;
	__u32 response_len;
	__s32 din_resid;
	__s32 dout_resid;
	__u64 generated_tag;
	__u32 spare_out;
	__u32 padding;
};

typedef void rq_end_io_fn___34(struct request___34 *, int);

struct request___34 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___34 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___35 *bio;
	struct bio___35 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___34 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___34 *saved_end_io;
		} flush;
	};
	struct gendisk___35 *rq_disk;
	struct hd_struct___35 *part;
	long unsigned int start_time;
	struct request_list___34 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___34 *end_io;
	void *end_io_data;
	struct request___34 *next_rq;
};

typedef int elevator_merge_fn___34(struct request_queue___34 *, struct request___34 **, struct bio___35 *);

typedef void elevator_merge_req_fn___34(struct request_queue___34 *, struct request___34 *, struct request___34 *);

typedef void elevator_merged_fn___34(struct request_queue___34 *, struct request___34 *, int);

typedef int elevator_allow_merge_fn___34(struct request_queue___34 *, struct request___34 *, struct bio___35 *);

typedef void elevator_bio_merged_fn___34(struct request_queue___34 *, struct request___34 *, struct bio___35 *);

typedef int elevator_dispatch_fn___34(struct request_queue___34 *, int);

typedef void elevator_add_req_fn___34(struct request_queue___34 *, struct request___34 *);

typedef struct request___34 *elevator_request_list_fn___34(struct request_queue___34 *, struct request___34 *);

typedef void elevator_completed_req_fn___34(struct request_queue___34 *, struct request___34 *);

typedef int elevator_may_queue_fn___34(struct request_queue___34 *, int);

typedef void elevator_init_icq_fn___34(struct io_cq___34 *);

typedef void elevator_exit_icq_fn___34(struct io_cq___34 *);

typedef int elevator_set_req_fn___34(struct request_queue___34 *, struct request___34 *, struct bio___35 *, gfp_t);

typedef void elevator_put_req_fn___34(struct request___34 *);

typedef void elevator_activate_req_fn___34(struct request_queue___34 *, struct request___34 *);

typedef void elevator_deactivate_req_fn___34(struct request_queue___34 *, struct request___34 *);

struct elevator_type___34;

typedef int elevator_init_fn___35(struct request_queue___34 *, struct elevator_type___34 *);

typedef void elevator_exit_fn___34(struct elevator_queue___34 *);

struct elevator_ops___34 {
	elevator_merge_fn___34 *elevator_merge_fn;
	elevator_merged_fn___34 *elevator_merged_fn;
	elevator_merge_req_fn___34 *elevator_merge_req_fn;
	elevator_allow_merge_fn___34 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___34 *elevator_bio_merged_fn;
	elevator_dispatch_fn___34 *elevator_dispatch_fn;
	elevator_add_req_fn___34 *elevator_add_req_fn;
	elevator_activate_req_fn___34 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___34 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___34 *elevator_completed_req_fn;
	elevator_request_list_fn___34 *elevator_former_req_fn;
	elevator_request_list_fn___34 *elevator_latter_req_fn;
	elevator_init_icq_fn___34 *elevator_init_icq_fn;
	elevator_exit_icq_fn___34 *elevator_exit_icq_fn;
	elevator_set_req_fn___34 *elevator_set_req_fn;
	elevator_put_req_fn___34 *elevator_put_req_fn;
	elevator_may_queue_fn___34 *elevator_may_queue_fn;
	elevator_init_fn___35 *elevator_init_fn;
	elevator_exit_fn___34 *elevator_exit_fn;
};

struct elv_fs_entry___34;

struct elevator_type___34 {
	struct kmem_cache___166 *icq_cache;
	struct elevator_ops___34 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___34 *elevator_attrs;
	char elevator_name[16];
	struct module___97 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___34 {
	struct elevator_type___34 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___183 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___34 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___34 *, char *);
	ssize_t (*store)(struct elevator_queue___34 *, const char *, size_t);
};

struct bvec_merge_data___34 {
	struct block_device___180 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___34 {
	struct request___34 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct rq_map_data___4 {
	struct page___179 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

typedef struct poll_table_struct___106 poll_table___20;

struct bsg_device {
	struct request_queue___34 *queue;
	spinlock_t lock;
	struct list_head busy_list;
	struct list_head done_list;
	struct hlist_node dev_list;
	atomic_t ref_count;
	int queued_cmds;
	int done_cmds;
	wait_queue_head_t wq_done;
	wait_queue_head_t wq_free;
	char name[20];
	int max_queue;
	long unsigned int flags;
};

enum {
	BSG_F_BLOCK = 1,
};

struct bsg_command {
	struct bsg_device *bd;
	struct list_head list;
	struct request___34 *rq;
	struct bio___35 *bio;
	struct bio___35 *bidi_bio;
	int err;
	struct sg_io_v4 hdr;
	char sense[96];
};

struct bsg_buffer {
	unsigned int payload_len;
	int sg_cnt;
	struct scatterlist *sg_list;
};

struct bsg_job {
	struct device___145 *dev;
	struct request___34 *req;
	void *request;
	void *reply;
	unsigned int request_len;
	unsigned int reply_len;
	struct bsg_buffer request_payload;
	struct bsg_buffer reply_payload;
	void *dd_data;
};

struct page___180;

typedef struct page___180 *pgtable_t___180;

struct address_space___181;

struct kmem_cache___167;

struct page___180 {
	long unsigned int flags;
	struct address_space___181 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___180 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___180 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___167 *slab_cache;
		struct page___180 *first_page;
	};
	long: 64;
};

struct task_struct___183;

struct pv_cpu_ops___183 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___183 *);
	void (*end_context_switch)(struct task_struct___183 *);
};

struct mutex___184 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___183 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___176 {
	struct page___180 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___188;

struct signal_struct___183;

struct bio_list___35;

struct backing_dev_info___45;

struct io_context___35;

struct css_set___112;

struct task_struct___183 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___183 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___188 *mm;
	struct mm_struct___188 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___183 *real_parent;
	struct task_struct___183 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___183 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___183 = 0,
		VTIME_USER___183 = 1,
		VTIME_SYS___183 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___183 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___35 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___45 *backing_dev_info;
	struct io_context___35 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___112 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___184 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___176 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___188 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___188 *, struct mm_struct___188 *);
	void (*dup_mmap)(struct mm_struct___188 *, struct mm_struct___188 *);
	void (*exit_mmap)(struct mm_struct___188 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___188 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___188 *);
	void (*pgd_free)(struct mm_struct___188 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___188 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___188 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___188 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___188 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___188 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___188 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___188 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___188 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___188 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___188 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___188 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___184 lock;
	void *vdso;
} mm_context_t___184;

struct xol_area___180;

struct uprobes_state___180 {
	struct xol_area___180 *xol_area;
};

struct vm_area_struct___188;

struct file___181;

struct core_state___183;

struct mm_struct___188 {
	struct vm_area_struct___188 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___188 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___188 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___184 context;
	long unsigned int flags;
	struct core_state___183 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___183 *owner;
	struct file___181 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___180 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___98;

struct exec_domain___44 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___98 *module;
	struct exec_domain___44 *next;
};

struct module_kobject___97 {
	struct kobject___4 kobj;
	struct module___98 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___97;

struct module___98 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___97 mkobj;
	struct module_attribute___97 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___183 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___82 {
	struct task_struct___183 *task;
	struct exec_domain___44 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___180 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___180 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___166;

struct memcg_cache_params___167;

struct kmem_cache___167 {
	struct kmem_cache_cpu___166 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___167 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___181;

struct address_space_operations___181;

struct address_space___181 {
	struct inode___181 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___184 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___181 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___45 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___181;

struct path___181 {
	struct vfsmount *mnt;
	struct dentry___181 *dentry;
};

struct file_operations___181;

struct file___181 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___181 f_path;
	struct inode___181 *f_inode;
	const struct file_operations___181 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___181 *f_mapping;
	struct mutex___184 f_pos_lock;
};

struct vm_operations_struct___161;

struct vm_area_struct___188 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___188 *vm_next;
	struct vm_area_struct___188 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___188 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___161 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___181 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___158;

struct vm_operations_struct___161 {
	void (*open)(struct vm_area_struct___188 *);
	void (*close)(struct vm_area_struct___188 *);
	int (*fault)(struct vm_area_struct___188 *, struct vm_fault___158 *);
	int (*page_mkwrite)(struct vm_area_struct___188 *, struct vm_fault___158 *);
	int (*access)(struct vm_area_struct___188 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___188 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___188 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___188 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___188 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___183 {
	struct task_struct___183 *task;
	struct core_thread___183 *next;
};

struct core_state___183 {
	atomic_t nr_threads;
	struct core_thread___183 dumper;
	struct completion startup;
};

struct irq_data___124;

struct x86_io_apic_ops___124 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___124 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___124;

struct irq_data___124 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___124 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___146;

struct dev_pm_ops___146 {
	int (*prepare)(struct device___146 *);
	void (*complete)(struct device___146 *);
	int (*suspend)(struct device___146 *);
	int (*resume)(struct device___146 *);
	int (*freeze)(struct device___146 *);
	int (*thaw)(struct device___146 *);
	int (*poweroff)(struct device___146 *);
	int (*restore)(struct device___146 *);
	int (*suspend_late)(struct device___146 *);
	int (*resume_early)(struct device___146 *);
	int (*freeze_late)(struct device___146 *);
	int (*thaw_early)(struct device___146 *);
	int (*poweroff_late)(struct device___146 *);
	int (*restore_early)(struct device___146 *);
	int (*suspend_noirq)(struct device___146 *);
	int (*resume_noirq)(struct device___146 *);
	int (*freeze_noirq)(struct device___146 *);
	int (*thaw_noirq)(struct device___146 *);
	int (*poweroff_noirq)(struct device___146 *);
	int (*restore_noirq)(struct device___146 *);
	int (*runtime_suspend)(struct device___146 *);
	int (*runtime_resume)(struct device___146 *);
	int (*runtime_idle)(struct device___146 *);
};

struct device_type___146;

struct bus_type___146;

struct device_driver___146;

struct dev_pm_domain___146;

struct class___146;

struct attribute_group___138;

struct device_rh___146;

struct device___146 {
	struct device___146 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___146 *type;
	struct mutex___184 mutex;
	struct bus_type___146 *bus;
	struct device_driver___146 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___146 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___58 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___146 *class;
	const struct attribute_group___138 **groups;
	void (*release)(struct device___146 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___146 *device_rh;
};

struct dev_pm_info_rh___146 {
	void (*set_latency_tolerance)(struct device___146 *, s32);
};

struct dev_pm_domain___146 {
	struct dev_pm_ops___146 ops;
};

struct smp_ops___183 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___183 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___183;

struct lruvec___183 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___183 *zone;
};

struct pglist_data___183;

struct zone___183 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___183 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___183 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___183 {
	struct zone___183 *zone;
	int zone_idx;
};

struct zonelist___183 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___183 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___183 {
	struct zone___183 node_zones[4];
	struct zonelist___183 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___183 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___183 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___183 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___183 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___184 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___36;

struct bio_list___35 {
	struct bio___36 *head;
	struct bio___36 *tail;
};

struct bdi_writeback___45 {
	struct backing_dev_info___45 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___45 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___45 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___146 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___181 *debug_dir;
	struct dentry___181 *debug_stats;
};

struct io_cq___35;

struct io_context___35 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___35 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___112;

struct css_set___112 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___112 *subsys[11];
	struct callback_head callback_head;
};

struct request_queue___35;

struct io_cq___35 {
	struct request_queue___35 *q;
	struct io_context___35 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___167 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct blkcg_gq___3;

struct request_list___35 {
	struct request_queue___35 *q;
	struct blkcg_gq___3 *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___35(struct request_queue___35 *);

typedef void make_request_fn___35(struct request_queue___35 *, struct bio___36 *);

struct request___35;

typedef int prep_rq_fn___35(struct request_queue___35 *, struct request___35 *);

struct bvec_merge_data___35;

struct bio_vec___36;

typedef int merge_bvec_fn___36(struct request_queue___35 *, struct bvec_merge_data___35 *, struct bio_vec___36 *);

typedef void softirq_done_fn___35(struct request___35 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___35(struct request___35 *);

typedef int dma_drain_needed_fn___35(struct request___35 *);

typedef int lld_busy_fn___35(struct request_queue___35 *);

struct bsg_class_device___35 {
	struct device___146 *class_dev;
	struct device___146 *parent;
	int minor;
	struct request_queue___35 *queue;
	struct kref ref;
	void (*release)(struct device___146 *);
};

typedef void unprep_rq_fn___35(struct request_queue___35 *, struct request___35 *);

struct elevator_queue___35;

struct blk_mq_ops___9;

struct blk_mq_ctx___9;

struct blk_mq_hw_ctx___9;

struct blk_queue_tag___35;

struct blk_mq_tag_set___9;

struct bio_set___36;

struct blk_flush_queue___9;

struct request_queue___35 {
	struct list_head queue_head;
	struct request___35 *last_merge;
	struct elevator_queue___35 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___35 root_rl;
	request_fn_proc___35 *request_fn;
	make_request_fn___35 *make_request_fn;
	prep_rq_fn___35 *prep_rq_fn;
	merge_bvec_fn___36 *merge_bvec_fn;
	softirq_done_fn___35 *softirq_done_fn;
	rq_timed_out_fn___35 *rq_timed_out_fn;
	dma_drain_needed_fn___35 *dma_drain_needed;
	lld_busy_fn___35 *lld_busy_fn;
	struct blk_mq_ops___9 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___9 *queue_ctx;
		struct {
			struct blk_mq_ctx___9 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___9 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___35 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___45 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___146 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___35 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___35 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___184 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___35 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___35 *unprep_rq_fn;
	struct blk_mq_tag_set___9 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___36 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___9 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct bin_attribute___140;

struct attribute_group___138 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___140 **bin_attrs;
};

struct bin_attribute___140 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___181 *, struct kobject___4 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___181 *, struct kobject___4 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	int (*mmap)(struct file___181 *, struct kobject___4 *, struct bin_attribute___140 *, struct vm_area_struct___188 *);
};

struct module_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___97 *, struct module_kobject___97 *, char *);
	ssize_t (*store)(struct module_attribute___97 *, struct module_kobject___97 *, const char *, size_t);
	void (*setup)(struct module___98 *, const char *);
	int (*test)(struct module___98 *);
	void (*free)(struct module___98 *);
};

struct kmem_cache_cpu___166 {
	void **freelist;
	long unsigned int tid;
	struct page___180 *page;
	struct page___180 *partial;
};

struct memcg_cache_params___167 {
	bool is_root_cache;
	union {
		struct kmem_cache___167 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___167 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___146 *, char *);
	ssize_t (*store)(struct bus_type___146 *, const char *, size_t);
};

struct device_attribute___146;

struct driver_attribute___146;

struct bus_type___146 {
	const char *name;
	const char *dev_name;
	struct device___146 *dev_root;
	struct bus_attribute___146 *bus_attrs;
	struct device_attribute___146 *dev_attrs;
	struct driver_attribute___146 *drv_attrs;
	const struct attribute_group___138 **bus_groups;
	const struct attribute_group___138 **dev_groups;
	const struct attribute_group___138 **drv_groups;
	int (*match)(struct device___146 *, struct device_driver___146 *);
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	int (*probe)(struct device___146 *);
	int (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*online)(struct device___146 *);
	int (*offline)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct device___146 *, struct device_attribute___146 *, char *);
	ssize_t (*store)(struct device___146 *, struct device_attribute___146 *, const char *, size_t);
};

struct driver_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___146 *, char *);
	ssize_t (*store)(struct device_driver___146 *, const char *, size_t);
};

struct device_driver___146 {
	const char *name;
	struct bus_type___146 *bus;
	struct module___98 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___146 *);
	int (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	const struct attribute_group___138 **groups;
	const struct dev_pm_ops___146 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___146 {
	const char *name;
	const struct attribute_group___138 **groups;
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
};

struct class_attribute___146;

struct class___146 {
	const char *name;
	struct module___98 *owner;
	struct class_attribute___146 *class_attrs;
	struct device_attribute___146 *dev_attrs;
	const struct attribute_group___138 **dev_groups;
	struct bin_attribute___140 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *);
	void (*class_release)(struct class___146 *);
	void (*dev_release)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
	struct subsys_private *p;
};

struct class_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct class___146 *, struct class_attribute___146 *, char *);
	ssize_t (*store)(struct class___146 *, struct class_attribute___146 *, const char *, size_t);
	const void * (*namespace)(struct class___146 *, const struct class_attribute___146 *);
};

struct device_rh___146 {
	struct dev_pm_info_rh___146 power;
};

struct dentry_operations___181;

struct super_block___181;

struct dentry___181 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___181 *d_parent;
	struct qstr d_name;
	struct inode___181 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___181 *d_op;
	struct super_block___181 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___181;

struct file_lock___181;

struct dquot___181;

struct block_device___181;

struct inode___181 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___181 *i_op;
	struct super_block___181 *i_sb;
	struct address_space___181 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___184 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___181 *i_fop;
	struct file_lock___181 *i_flock;
	struct address_space___181 i_data;
	struct dquot___181 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___181 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___181 {
	int (*d_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_hash)(const struct dentry___181 *, struct qstr *);
	int (*d_compare)(const struct dentry___181 *, const struct dentry___181 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___181 *);
	void (*d_release)(struct dentry___181 *);
	void (*d_prune)(struct dentry___181 *);
	void (*d_iput)(struct dentry___181 *, struct inode___181 *);
	char * (*d_dname)(struct dentry___181 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___181 *);
	int (*d_manage)(struct dentry___181 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___181;

struct mem_dqinfo___181 {
	struct quota_format_type___181 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___181;

struct quota_info___181 {
	unsigned int flags;
	struct mutex___184 dqio_mutex;
	struct mutex___184 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___181 *files[2];
	struct mem_dqinfo___181 info[2];
	const struct quota_format_ops___181 *ops[2];
};

struct file_system_type___181;

struct super_operations___181;

struct dquot_operations___181;

struct quotactl_ops___181;

struct xattr_handler___113;

struct super_block___181 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___181 *s_type;
	const struct super_operations___181 *s_op;
	const struct dquot_operations___181 *dq_op;
	const struct quotactl_ops___181 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___181 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___113 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___181 *s_bdev;
	struct backing_dev_info___45 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___181 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___184 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___181 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___36(struct bio___36 *, int);

struct bio_vec___36 {
	struct page___180 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___36;

struct bio___36 {
	sector_t bi_sector;
	struct bio___36 *bi_next;
	struct block_device___181 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___36 *bi_end_io;
	void *bi_private;
	struct io_context___35 *bi_ioc;
	struct cgroup_subsys_state___112 *bi_css;
	struct bio_integrity_payload___36 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___36 *bi_io_vec;
	struct bio_set___36 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___36 bi_inline_vecs[0];
};

struct hd_struct___36;

struct gendisk___36;

struct block_device___181 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___181 *bd_inode;
	struct super_block___181 *bd_super;
	struct mutex___184 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___181 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___36 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___36 *bd_disk;
	struct request_queue___35 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___184 bd_fsfreeze_mutex;
};

struct cgroup___112;

struct cgroup_subsys_state___112 {
	struct cgroup___112 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___36 {
	struct bio___36 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___36 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___36 *bip_vec;
	struct bio_vec___36 bip_inline_vecs[0];
};

struct bio_set___36 {
	struct kmem_cache___167 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___35 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___181 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___181 *ia_file;
};

struct dquot___181 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___184 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___181 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___181 {
	int qf_fmt_id;
	const struct quota_format_ops___181 *qf_ops;
	struct module___98 *qf_owner;
	struct quota_format_type___181 *qf_next;
};

struct quota_format_ops___181 {
	int (*check_quota_file)(struct super_block___181 *, int);
	int (*read_file_info)(struct super_block___181 *, int);
	int (*write_file_info)(struct super_block___181 *, int);
	int (*free_file_info)(struct super_block___181 *, int);
	int (*read_dqblk)(struct dquot___181 *);
	int (*commit_dqblk)(struct dquot___181 *);
	int (*release_dqblk)(struct dquot___181 *);
};

struct dquot_operations___181 {
	int (*write_dquot)(struct dquot___181 *);
	struct dquot___181 * (*alloc_dquot)(struct super_block___181 *, int);
	void (*destroy_dquot)(struct dquot___181 *);
	int (*acquire_dquot)(struct dquot___181 *);
	int (*release_dquot)(struct dquot___181 *);
	int (*mark_dirty)(struct dquot___181 *);
	int (*write_info)(struct super_block___181 *, int);
	qsize_t * (*get_reserved_space)(struct inode___181 *);
};

struct quotactl_ops___181 {
	int (*quota_on)(struct super_block___181 *, int, int, struct path___181 *);
	int (*quota_on_meta)(struct super_block___181 *, int, int);
	int (*quota_off)(struct super_block___181 *, int);
	int (*quota_sync)(struct super_block___181 *, int);
	int (*get_info)(struct super_block___181 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___181 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___181 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___181 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___181 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___181 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___181 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___181 *, unsigned int);
};

struct address_space_operations___181 {
	int (*writepage)(struct page___180 *, struct writeback_control *);
	int (*readpage)(struct file___181 *, struct page___180 *);
	int (*writepages)(struct address_space___181 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___180 *);
	int (*readpages)(struct file___181 *, struct address_space___181 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___181 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___180 **, void **);
	int (*write_end)(struct file___181 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___180 *, void *);
	sector_t (*bmap)(struct address_space___181 *, sector_t);
	void (*invalidatepage)(struct page___180 *, long unsigned int);
	int (*releasepage)(struct page___180 *, gfp_t);
	void (*freepage)(struct page___180 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___181 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___181 *, struct page___180 *, struct page___180 *, enum migrate_mode);
	int (*launder_page)(struct page___180 *);
	int (*is_partially_uptodate)(struct page___180 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___180 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___181 *, struct page___180 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___181 *, sector_t *);
	void (*swap_deactivate)(struct file___181 *);
	void (*invalidatepage_range)(struct page___180 *, unsigned int, unsigned int);
};

struct hd_struct___36 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___146 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___36;

struct block_device_operations___35;

struct gendisk___36 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___36 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___36 *part_tbl;
	struct hd_struct___36 part0;
	const struct block_device_operations___35 *fops;
	struct request_queue___35 *queue;
	void *private_data;
	int flags;
	struct device___146 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct inode_operations___181 {
	struct dentry___181 * (*lookup)(struct inode___181 *, struct dentry___181 *, unsigned int);
	void * (*follow_link)(struct dentry___181 *, struct nameidata *);
	int (*permission)(struct inode___181 *, int);
	struct posix_acl * (*get_acl)(struct inode___181 *, int);
	int (*readlink)(struct dentry___181 *, char *, int);
	void (*put_link)(struct dentry___181 *, struct nameidata *, void *);
	int (*create)(struct inode___181 *, struct dentry___181 *, umode_t, bool);
	int (*link)(struct dentry___181 *, struct inode___181 *, struct dentry___181 *);
	int (*unlink)(struct inode___181 *, struct dentry___181 *);
	int (*symlink)(struct inode___181 *, struct dentry___181 *, const char *);
	int (*mkdir)(struct inode___181 *, struct dentry___181 *, umode_t);
	int (*rmdir)(struct inode___181 *, struct dentry___181 *);
	int (*mknod)(struct inode___181 *, struct dentry___181 *, umode_t, dev_t);
	int (*rename)(struct inode___181 *, struct dentry___181 *, struct inode___181 *, struct dentry___181 *);
	int (*setattr)(struct dentry___181 *, struct iattr___181 *);
	int (*getattr)(struct vfsmount *, struct dentry___181 *, struct kstat *);
	int (*setxattr)(struct dentry___181 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___181 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___181 *, char *, size_t);
	int (*removexattr)(struct dentry___181 *, const char *);
	int (*fiemap)(struct inode___181 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___181 *, struct timespec *, int);
	int (*atomic_open)(struct inode___181 *, struct dentry___181 *, struct file___181 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___129;

struct file_operations___181 {
	struct module___98 *owner;
	loff_t (*llseek)(struct file___181 *, loff_t, int);
	ssize_t (*read)(struct file___181 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___181 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___181 *, void *, filldir_t);
	unsigned int (*poll)(struct file___181 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___181 *, struct vm_area_struct___188 *);
	int (*open)(struct inode___181 *, struct file___181 *);
	int (*flush)(struct file___181 *, fl_owner_t);
	int (*release)(struct inode___181 *, struct file___181 *);
	int (*fsync)(struct file___181 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___181 *, int);
	int (*lock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*sendpage)(struct file___181 *, struct page___180 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___181 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___181 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___181 *, long int, struct file_lock___181 **, void **);
		struct {
			int (*setlease)(struct file___181 *, long int, struct file_lock___181 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___181 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___129 *, struct file___181 *);
};

struct fasync_struct___181;

struct file_lock_operations___181;

struct lock_manager_operations___181;

struct file_lock___181 {
	struct file_lock___181 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___181 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___181 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___181 *fl_ops;
	const struct lock_manager_operations___181 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___181 {
	void (*fl_copy_lock)(struct file_lock___181 *, struct file_lock___181 *);
	void (*fl_release_private)(struct file_lock___181 *);
};

struct lock_manager_operations___181 {
	int (*lm_compare_owner)(struct file_lock___181 *, struct file_lock___181 *);
	long unsigned int (*lm_owner_key)(struct file_lock___181 *);
	void (*lm_notify)(struct file_lock___181 *);
	int (*lm_grant)(struct file_lock___181 *, struct file_lock___181 *, int);
	void (*lm_break)(struct file_lock___181 *);
	int (*lm_change)(struct file_lock___181 **, int);
};

struct fasync_struct___181 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___181 *fa_next;
	struct file___181 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___181 {
	const char *name;
	int fs_flags;
	struct dentry___181 * (*mount)(struct file_system_type___181 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___181 *);
	struct module___98 *owner;
	struct file_system_type___181 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___181 {
	struct inode___181 * (*alloc_inode)(struct super_block___181 *);
	void (*destroy_inode)(struct inode___181 *);
	void (*dirty_inode)(struct inode___181 *, int);
	int (*write_inode)(struct inode___181 *, struct writeback_control *);
	int (*drop_inode)(struct inode___181 *);
	void (*evict_inode)(struct inode___181 *);
	void (*put_super)(struct super_block___181 *);
	int (*sync_fs)(struct super_block___181 *, int);
	int (*freeze_fs)(struct super_block___181 *);
	int (*unfreeze_fs)(struct super_block___181 *);
	int (*statfs)(struct dentry___181 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___181 *, int *, char *);
	void (*umount_begin)(struct super_block___181 *);
	int (*show_options)(struct seq_file___129 *, struct dentry___181 *);
	int (*show_devname)(struct seq_file___129 *, struct dentry___181 *);
	int (*show_path)(struct seq_file___129 *, struct dentry___181 *);
	int (*show_stats)(struct seq_file___129 *, struct dentry___181 *);
	ssize_t (*quota_read)(struct super_block___181 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___181 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___181 *);
	int (*bdev_try_to_free_page)(struct super_block___181 *, struct page___180 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___181 *);
	void (*free_cached_objects)(struct super_block___181 *, int);
};

struct xattr_handler___113 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___181 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___181 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___181 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___129;

struct seq_file___129 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___184 lock;
	const struct seq_operations___129 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___36 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___36 *last_lookup;
	struct hd_struct___36 *part[0];
};

struct block_device_operations___35 {
	int (*open)(struct block_device___181 *, fmode_t);
	void (*release)(struct gendisk___36 *, fmode_t);
	int (*ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___181 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___36 *, unsigned int);
	int (*media_changed)(struct gendisk___36 *);
	void (*unlock_native_capacity)(struct gendisk___36 *);
	int (*revalidate_disk)(struct gendisk___36 *);
	int (*getgeo)(struct block_device___181 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___181 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___98 *owner;
};

struct vm_fault___158 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___180 *page;
};

struct irq_chip___124 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___124 *);
	void (*irq_shutdown)(struct irq_data___124 *);
	void (*irq_enable)(struct irq_data___124 *);
	void (*irq_disable)(struct irq_data___124 *);
	void (*irq_ack)(struct irq_data___124 *);
	void (*irq_mask)(struct irq_data___124 *);
	void (*irq_mask_ack)(struct irq_data___124 *);
	void (*irq_unmask)(struct irq_data___124 *);
	void (*irq_eoi)(struct irq_data___124 *);
	int (*irq_set_affinity)(struct irq_data___124 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___124 *);
	int (*irq_set_type)(struct irq_data___124 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___124 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___124 *);
	void (*irq_bus_sync_unlock)(struct irq_data___124 *);
	void (*irq_cpu_online)(struct irq_data___124 *);
	void (*irq_cpu_offline)(struct irq_data___124 *);
	void (*irq_suspend)(struct irq_data___124 *);
	void (*irq_resume)(struct irq_data___124 *);
	void (*irq_pm_shutdown)(struct irq_data___124 *);
	void (*irq_print_chip)(struct irq_data___124 *, struct seq_file___129 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___124 *, void *);
	long unsigned int flags;
};

typedef void rq_end_io_fn___35(struct request___35 *, int);

struct request___35 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___35 *q;
	struct blk_mq_ctx___9 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___36 *bio;
	struct bio___36 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___35 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___35 *saved_end_io;
		} flush;
	};
	struct gendisk___36 *rq_disk;
	struct hd_struct___36 *part;
	long unsigned int start_time;
	struct request_list___35 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___35 *end_io;
	void *end_io_data;
	struct request___35 *next_rq;
};

struct blkcg___3;

struct blkg_policy_data___3;

struct blkcg_gq___3 {
	struct request_queue___35 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___3 *blkcg;
	struct blkcg_gq___3 *parent;
	struct request_list___35 rl;
	union {
		atomic_t refcnt;
		struct {
			int refcnt;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	bool online;
	struct blkg_policy_data___3 *pd[2];
	struct callback_head callback_head;
};

struct blk_mq_ctx___9 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___35 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___35(struct request_queue___35 *, struct request___35 **, struct bio___36 *);

typedef void elevator_merge_req_fn___35(struct request_queue___35 *, struct request___35 *, struct request___35 *);

typedef void elevator_merged_fn___35(struct request_queue___35 *, struct request___35 *, int);

typedef int elevator_allow_merge_fn___35(struct request_queue___35 *, struct request___35 *, struct bio___36 *);

typedef void elevator_bio_merged_fn___35(struct request_queue___35 *, struct request___35 *, struct bio___36 *);

typedef int elevator_dispatch_fn___35(struct request_queue___35 *, int);

typedef void elevator_add_req_fn___35(struct request_queue___35 *, struct request___35 *);

typedef struct request___35 *elevator_request_list_fn___35(struct request_queue___35 *, struct request___35 *);

typedef void elevator_completed_req_fn___35(struct request_queue___35 *, struct request___35 *);

typedef int elevator_may_queue_fn___35(struct request_queue___35 *, int);

typedef void elevator_init_icq_fn___35(struct io_cq___35 *);

typedef void elevator_exit_icq_fn___35(struct io_cq___35 *);

typedef int elevator_set_req_fn___35(struct request_queue___35 *, struct request___35 *, struct bio___36 *, gfp_t);

typedef void elevator_put_req_fn___35(struct request___35 *);

typedef void elevator_activate_req_fn___35(struct request_queue___35 *, struct request___35 *);

typedef void elevator_deactivate_req_fn___35(struct request_queue___35 *, struct request___35 *);

struct elevator_type___35;

typedef int elevator_init_fn___36(struct request_queue___35 *, struct elevator_type___35 *);

typedef void elevator_exit_fn___35(struct elevator_queue___35 *);

struct elevator_ops___35 {
	elevator_merge_fn___35 *elevator_merge_fn;
	elevator_merged_fn___35 *elevator_merged_fn;
	elevator_merge_req_fn___35 *elevator_merge_req_fn;
	elevator_allow_merge_fn___35 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___35 *elevator_bio_merged_fn;
	elevator_dispatch_fn___35 *elevator_dispatch_fn;
	elevator_add_req_fn___35 *elevator_add_req_fn;
	elevator_activate_req_fn___35 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___35 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___35 *elevator_completed_req_fn;
	elevator_request_list_fn___35 *elevator_former_req_fn;
	elevator_request_list_fn___35 *elevator_latter_req_fn;
	elevator_init_icq_fn___35 *elevator_init_icq_fn;
	elevator_exit_icq_fn___35 *elevator_exit_icq_fn;
	elevator_set_req_fn___35 *elevator_set_req_fn;
	elevator_put_req_fn___35 *elevator_put_req_fn;
	elevator_may_queue_fn___35 *elevator_may_queue_fn;
	elevator_init_fn___36 *elevator_init_fn;
	elevator_exit_fn___35 *elevator_exit_fn;
};

struct elv_fs_entry___35;

struct elevator_type___35 {
	struct kmem_cache___167 *icq_cache;
	struct elevator_ops___35 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___35 *elevator_attrs;
	char elevator_name[16];
	struct module___98 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___35 {
	struct elevator_type___35 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___184 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___35 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___35 *, char *);
	ssize_t (*store)(struct elevator_queue___35 *, const char *, size_t);
};

struct bvec_merge_data___35 {
	struct block_device___181 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___35 {
	struct request___35 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___9;

typedef int queue_rq_fn___10(struct blk_mq_hw_ctx___9 *, const struct blk_mq_queue_data___9 *);

typedef struct blk_mq_hw_ctx___9 *map_queue_fn___10(struct request_queue___35 *, const int);

typedef enum blk_eh_timer_return timeout_fn___10(struct request___35 *, bool);

typedef int init_request_fn___10(void *, struct request___35 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___10(void *, struct request___35 *, unsigned int, unsigned int);

typedef int init_hctx_fn___9(struct blk_mq_hw_ctx___9 *, void *, unsigned int);

typedef void exit_hctx_fn___9(struct blk_mq_hw_ctx___9 *, unsigned int);

struct blk_mq_ops___9 {
	queue_rq_fn___10 *queue_rq;
	map_queue_fn___10 *map_queue;
	union {
		timeout_fn___10 *timeout;
		struct {
			rq_timed_out_fn___35 *timeout;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	softirq_done_fn___35 *complete;
	init_request_fn___10 *init_request;
	exit_request_fn___10 *exit_request;
	init_hctx_fn___9 *init_hctx;
	exit_hctx_fn___9 *exit_hctx;
};

struct blk_mq_cpu_notifier___2 {
	struct list_head list;
	void *data;
	union {
		int (*notify)(void *, long unsigned int, unsigned int);
		struct {
			void (*notify)(void *, long unsigned int, unsigned int);
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
};

struct blk_mq_hw_ctx___9 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___35 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___9 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct request___35 **padding2;
		struct {
			struct request___35 **rqs;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___2 cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___9 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___9 {
	struct blk_mq_ops___9 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___184 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___9 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___35 *flush_rq;
	struct request___35 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct cgroupfs_root___112;

struct cgroup___112 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___112 *parent;
	struct dentry___181 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___112 *subsys[11];
	struct cgroupfs_root___112 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___184 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___112 {
	struct super_block___181 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___112 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___58 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___181 *, struct file___181 *);
	ssize_t (*read)(struct cgroup___112 *, struct cftype___58 *, struct file___181 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___112 *, struct cftype___58 *);
	s64 (*read_s64)(struct cgroup___112 *, struct cftype___58 *);
	int (*read_map)(struct cgroup___112 *, struct cftype___58 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___112 *, struct cftype___58 *, struct seq_file___129 *);
	ssize_t (*write)(struct cgroup___112 *, struct cftype___58 *, struct file___181 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___112 *, struct cftype___58 *, u64);
	int (*write_s64)(struct cgroup___112 *, struct cftype___58 *, s64);
	int (*write_string)(struct cgroup___112 *, struct cftype___58 *, const char *);
	int (*trigger)(struct cgroup___112 *, unsigned int);
	int (*release)(struct inode___181 *, struct file___181 *);
	int (*register_event)(struct cgroup___112 *, struct cftype___58 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___112 *, struct cftype___58 *, struct eventfd_ctx *);
};

struct cftype_set___56 {
	struct list_head node;
	struct cftype___58 *cfts;
};

struct task_and_cgroup___56 {
	struct task_struct___183 *task;
	struct cgroup___112 *cgrp;
	struct css_set___112 *cg;
};

struct cgroup_taskset___56 {
	struct task_and_cgroup___56 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___112 *cur_cgrp;
};

struct cgroup_subsys___56 {
	struct cgroup_subsys_state___112 * (*css_alloc)(struct cgroup___112 *);
	int (*css_online)(struct cgroup___112 *);
	void (*css_offline)(struct cgroup___112 *);
	void (*css_free)(struct cgroup___112 *);
	int (*can_attach)(struct cgroup___112 *, struct cgroup_taskset___56 *);
	void (*cancel_attach)(struct cgroup___112 *, struct cgroup_taskset___56 *);
	void (*attach)(struct cgroup___112 *, struct cgroup_taskset___56 *);
	void (*fork)(struct task_struct___183 *);
	void (*exit)(struct cgroup___112 *, struct cgroup___112 *, struct task_struct___183 *);
	void (*bind)(struct cgroup___112 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___112 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___58 *base_cftypes;
	struct cftype_set___56 base_cftset;
	struct module___98 *module;
};

struct seq_operations___129 {
	void * (*start)(struct seq_file___129 *, loff_t *);
	void (*stop)(struct seq_file___129 *, void *);
	void * (*next)(struct seq_file___129 *, void *, loff_t *);
	int (*show)(struct seq_file___129 *, void *);
};

struct blkcg___3 {
	struct cgroup_subsys_state___112 css;
	spinlock_t lock;
	struct radix_tree_root blkg_tree;
	struct blkcg_gq___3 *blkg_hint;
	struct hlist_head blkg_list;
	uint64_t id;
	unsigned int cfq_weight;
	unsigned int cfq_leaf_weight;
};

struct blkg_stat {
	struct u64_stats_sync syncp;
	uint64_t cnt;
};

struct blkg_rwstat {
	struct u64_stats_sync syncp;
	uint64_t cnt[4];
};

struct blkg_policy_data___3 {
	struct blkcg_gq___3 *blkg;
	int plid;
	struct list_head alloc_node;
};

typedef void blkcg_pol_init_pd_fn(struct blkcg_gq___3 *);

typedef void blkcg_pol_online_pd_fn(struct blkcg_gq___3 *);

typedef void blkcg_pol_offline_pd_fn(struct blkcg_gq___3 *);

typedef void blkcg_pol_exit_pd_fn(struct blkcg_gq___3 *);

typedef void blkcg_pol_reset_pd_stats_fn(struct blkcg_gq___3 *);

struct blkcg_policy {
	int plid;
	size_t pd_size;
	struct cftype___58 *cftypes;
	blkcg_pol_init_pd_fn *pd_init_fn;
	blkcg_pol_online_pd_fn *pd_online_fn;
	blkcg_pol_offline_pd_fn *pd_offline_fn;
	blkcg_pol_exit_pd_fn *pd_exit_fn;
	blkcg_pol_reset_pd_stats_fn *pd_reset_stats_fn;
};

struct blkg_conf_ctx {
	struct gendisk___36 *disk;
	struct blkcg_gq___3 *blkg;
	u64 v;
};

struct blk_mq_queue_data___9 {
	struct request___35 *rq;
	struct list_head *list;
	bool last;
};

struct page___181;

typedef struct page___181 *pgtable_t___181;

struct address_space___182;

struct kmem_cache___168;

struct page___181 {
	long unsigned int flags;
	struct address_space___182 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___181 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___181 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___168 *slab_cache;
		struct page___181 *first_page;
	};
	long: 64;
};

struct task_struct___184;

struct pv_cpu_ops___184 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___184 *);
	void (*end_context_switch)(struct task_struct___184 *);
};

struct mutex___185 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___184 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___177 {
	struct page___181 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___189;

struct signal_struct___184;

struct bio_list___36;

struct backing_dev_info___46;

struct io_context___36;

struct css_set___113;

struct task_struct___184 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___184 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___189 *mm;
	struct mm_struct___189 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___184 *real_parent;
	struct task_struct___184 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___184 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___184 = 0,
		VTIME_USER___184 = 1,
		VTIME_SYS___184 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___184 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___36 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___46 *backing_dev_info;
	struct io_context___36 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___113 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___185 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___177 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___189 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___189 *, struct mm_struct___189 *);
	void (*dup_mmap)(struct mm_struct___189 *, struct mm_struct___189 *);
	void (*exit_mmap)(struct mm_struct___189 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___189 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___189 *);
	void (*pgd_free)(struct mm_struct___189 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___189 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___189 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___189 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___189 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___189 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___189 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___189 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___189 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___189 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___189 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___189 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___185 lock;
	void *vdso;
} mm_context_t___185;

struct xol_area___181;

struct uprobes_state___181 {
	struct xol_area___181 *xol_area;
};

struct vm_area_struct___189;

struct file___182;

struct core_state___184;

struct mm_struct___189 {
	struct vm_area_struct___189 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___189 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___189 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___185 context;
	long unsigned int flags;
	struct core_state___184 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___184 *owner;
	struct file___182 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___181 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___99;

struct module_kobject___98 {
	struct kobject___4 kobj;
	struct module___99 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___98;

struct module___99 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___98 mkobj;
	struct module_attribute___98 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___184 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___184;

struct lruvec___184 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___184 *zone;
};

struct pglist_data___184;

struct zone___184 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___184 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___184 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___184 {
	struct zone___184 *zone;
	int zone_idx;
};

struct zonelist___184 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___184 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___184 {
	struct zone___184 node_zones[4];
	struct zonelist___184 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___184 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___125;

struct x86_io_apic_ops___125 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___125 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___125;

struct irq_data___125 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___125 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___147;

struct dev_pm_ops___147 {
	int (*prepare)(struct device___147 *);
	void (*complete)(struct device___147 *);
	int (*suspend)(struct device___147 *);
	int (*resume)(struct device___147 *);
	int (*freeze)(struct device___147 *);
	int (*thaw)(struct device___147 *);
	int (*poweroff)(struct device___147 *);
	int (*restore)(struct device___147 *);
	int (*suspend_late)(struct device___147 *);
	int (*resume_early)(struct device___147 *);
	int (*freeze_late)(struct device___147 *);
	int (*thaw_early)(struct device___147 *);
	int (*poweroff_late)(struct device___147 *);
	int (*restore_early)(struct device___147 *);
	int (*suspend_noirq)(struct device___147 *);
	int (*resume_noirq)(struct device___147 *);
	int (*freeze_noirq)(struct device___147 *);
	int (*thaw_noirq)(struct device___147 *);
	int (*poweroff_noirq)(struct device___147 *);
	int (*restore_noirq)(struct device___147 *);
	int (*runtime_suspend)(struct device___147 *);
	int (*runtime_resume)(struct device___147 *);
	int (*runtime_idle)(struct device___147 *);
};

struct device_type___147;

struct bus_type___147;

struct device_driver___147;

struct dev_pm_domain___147;

struct class___147;

struct attribute_group___139;

struct device_rh___147;

struct device___147 {
	struct device___147 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___147 *type;
	struct mutex___185 mutex;
	struct bus_type___147 *bus;
	struct device_driver___147 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___147 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___58 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___147 *class;
	const struct attribute_group___139 **groups;
	void (*release)(struct device___147 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___147 *device_rh;
};

struct dev_pm_info_rh___147 {
	void (*set_latency_tolerance)(struct device___147 *, s32);
};

struct dev_pm_domain___147 {
	struct dev_pm_ops___147 ops;
};

struct smp_ops___184 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___184 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___141;

struct attribute_group___139 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___141 **bin_attrs;
};

struct bin_attribute___141 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___182 *, struct kobject___4 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___182 *, struct kobject___4 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	int (*mmap)(struct file___182 *, struct kobject___4 *, struct bin_attribute___141 *, struct vm_area_struct___189 *);
};

struct dentry___182;

struct path___182 {
	struct vfsmount *mnt;
	struct dentry___182 *dentry;
};

struct inode___182;

struct file_operations___182;

struct file___182 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___182 f_path;
	struct inode___182 *f_inode;
	const struct file_operations___182 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___182 *f_mapping;
	struct mutex___185 f_pos_lock;
};

struct vm_operations_struct___162;

struct vm_area_struct___189 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___189 *vm_next;
	struct vm_area_struct___189 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___189 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___162 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___182 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___98 *, struct module_kobject___98 *, char *);
	ssize_t (*store)(struct module_attribute___98 *, struct module_kobject___98 *, const char *, size_t);
	void (*setup)(struct module___99 *, const char *);
	int (*test)(struct module___99 *);
	void (*free)(struct module___99 *);
};

struct kmem_cache_cpu___167 {
	void **freelist;
	long unsigned int tid;
	struct page___181 *page;
	struct page___181 *partial;
};

struct memcg_cache_params___168;

struct kmem_cache___168 {
	struct kmem_cache_cpu___167 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___168 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___168 {
	bool is_root_cache;
	union {
		struct kmem_cache___168 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___168 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___181 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___181 *page;
	long unsigned int vaddr;
};

struct address_space_operations___182;

struct address_space___182 {
	struct inode___182 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___185 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___182 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___46 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___159;

struct vm_operations_struct___162 {
	void (*open)(struct vm_area_struct___189 *);
	void (*close)(struct vm_area_struct___189 *);
	int (*fault)(struct vm_area_struct___189 *, struct vm_fault___159 *);
	int (*page_mkwrite)(struct vm_area_struct___189 *, struct vm_fault___159 *);
	int (*access)(struct vm_area_struct___189 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___189 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___189 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___189 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___189 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___184 {
	struct task_struct___184 *task;
	struct core_thread___184 *next;
};

struct core_state___184 {
	atomic_t nr_threads;
	struct core_thread___184 dumper;
	struct completion startup;
};

struct signal_struct___184 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___184 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___184 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___185 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___37;

struct bio_list___36 {
	struct bio___37 *head;
	struct bio___37 *tail;
};

struct bdi_writeback___46 {
	struct backing_dev_info___46 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___46 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___46 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___147 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___182 *debug_dir;
	struct dentry___182 *debug_stats;
};

struct io_cq___36;

struct io_context___36 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___36 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___113;

struct css_set___113 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___113 *subsys[11];
	struct callback_head callback_head;
};

struct bus_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___147 *, char *);
	ssize_t (*store)(struct bus_type___147 *, const char *, size_t);
};

struct device_attribute___147;

struct driver_attribute___147;

struct bus_type___147 {
	const char *name;
	const char *dev_name;
	struct device___147 *dev_root;
	struct bus_attribute___147 *bus_attrs;
	struct device_attribute___147 *dev_attrs;
	struct driver_attribute___147 *drv_attrs;
	const struct attribute_group___139 **bus_groups;
	const struct attribute_group___139 **dev_groups;
	const struct attribute_group___139 **drv_groups;
	int (*match)(struct device___147 *, struct device_driver___147 *);
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	int (*probe)(struct device___147 *);
	int (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*online)(struct device___147 *);
	int (*offline)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct device___147 *, struct device_attribute___147 *, char *);
	ssize_t (*store)(struct device___147 *, struct device_attribute___147 *, const char *, size_t);
};

struct driver_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___147 *, char *);
	ssize_t (*store)(struct device_driver___147 *, const char *, size_t);
};

struct device_driver___147 {
	const char *name;
	struct bus_type___147 *bus;
	struct module___99 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___147 *);
	int (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	const struct attribute_group___139 **groups;
	const struct dev_pm_ops___147 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___147 {
	const char *name;
	const struct attribute_group___139 **groups;
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
};

struct class_attribute___147;

struct class___147 {
	const char *name;
	struct module___99 *owner;
	struct class_attribute___147 *class_attrs;
	struct device_attribute___147 *dev_attrs;
	const struct attribute_group___139 **dev_groups;
	struct bin_attribute___141 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *);
	void (*class_release)(struct class___147 *);
	void (*dev_release)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
	struct subsys_private *p;
};

struct class_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct class___147 *, struct class_attribute___147 *, char *);
	ssize_t (*store)(struct class___147 *, struct class_attribute___147 *, const char *, size_t);
	const void * (*namespace)(struct class___147 *, const struct class_attribute___147 *);
};

struct device_rh___147 {
	struct dev_pm_info_rh___147 power;
};

struct dentry_operations___182;

struct super_block___182;

struct dentry___182 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___182 *d_parent;
	struct qstr d_name;
	struct inode___182 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___182 *d_op;
	struct super_block___182 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___182;

struct file_lock___182;

struct dquot___182;

struct block_device___182;

struct inode___182 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___182 *i_op;
	struct super_block___182 *i_sb;
	struct address_space___182 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___185 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___182 *i_fop;
	struct file_lock___182 *i_flock;
	struct address_space___182 i_data;
	struct dquot___182 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___182 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___182 {
	int (*d_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_hash)(const struct dentry___182 *, struct qstr *);
	int (*d_compare)(const struct dentry___182 *, const struct dentry___182 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___182 *);
	void (*d_release)(struct dentry___182 *);
	void (*d_prune)(struct dentry___182 *);
	void (*d_iput)(struct dentry___182 *, struct inode___182 *);
	char * (*d_dname)(struct dentry___182 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___182 *);
	int (*d_manage)(struct dentry___182 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___182;

struct mem_dqinfo___182 {
	struct quota_format_type___182 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___182;

struct quota_info___182 {
	unsigned int flags;
	struct mutex___185 dqio_mutex;
	struct mutex___185 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___182 *files[2];
	struct mem_dqinfo___182 info[2];
	const struct quota_format_ops___182 *ops[2];
};

struct file_system_type___182;

struct super_operations___182;

struct dquot_operations___182;

struct quotactl_ops___182;

struct xattr_handler___114;

struct super_block___182 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___182 *s_type;
	const struct super_operations___182 *s_op;
	const struct dquot_operations___182 *dq_op;
	const struct quotactl_ops___182 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___182 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___114 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___182 *s_bdev;
	struct backing_dev_info___46 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___182 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___185 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___182 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___37(struct bio___37 *, int);

struct bio_vec___37 {
	struct page___181 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___37;

struct bio_set___37;

struct bio___37 {
	sector_t bi_sector;
	struct bio___37 *bi_next;
	struct block_device___182 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___37 *bi_end_io;
	void *bi_private;
	struct io_context___36 *bi_ioc;
	struct cgroup_subsys_state___113 *bi_css;
	struct bio_integrity_payload___37 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___37 *bi_io_vec;
	struct bio_set___37 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___37 bi_inline_vecs[0];
};

struct hd_struct___37;

struct gendisk___37;

struct request_queue___36;

struct block_device___182 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___182 *bd_inode;
	struct super_block___182 *bd_super;
	struct mutex___185 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___182 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___37 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___37 *bd_disk;
	struct request_queue___36 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___185 bd_fsfreeze_mutex;
};

struct cgroup___113;

struct cgroup_subsys_state___113 {
	struct cgroup___113 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___37 {
	struct bio___37 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___37 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___37 *bip_vec;
	struct bio_vec___37 bip_inline_vecs[0];
};

struct bio_set___37 {
	struct kmem_cache___168 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___36 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___182 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___182 *ia_file;
};

struct dquot___182 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___185 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___182 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___182 {
	int qf_fmt_id;
	const struct quota_format_ops___182 *qf_ops;
	struct module___99 *qf_owner;
	struct quota_format_type___182 *qf_next;
};

struct quota_format_ops___182 {
	int (*check_quota_file)(struct super_block___182 *, int);
	int (*read_file_info)(struct super_block___182 *, int);
	int (*write_file_info)(struct super_block___182 *, int);
	int (*free_file_info)(struct super_block___182 *, int);
	int (*read_dqblk)(struct dquot___182 *);
	int (*commit_dqblk)(struct dquot___182 *);
	int (*release_dqblk)(struct dquot___182 *);
};

struct dquot_operations___182 {
	int (*write_dquot)(struct dquot___182 *);
	struct dquot___182 * (*alloc_dquot)(struct super_block___182 *, int);
	void (*destroy_dquot)(struct dquot___182 *);
	int (*acquire_dquot)(struct dquot___182 *);
	int (*release_dquot)(struct dquot___182 *);
	int (*mark_dirty)(struct dquot___182 *);
	int (*write_info)(struct super_block___182 *, int);
	qsize_t * (*get_reserved_space)(struct inode___182 *);
};

struct quotactl_ops___182 {
	int (*quota_on)(struct super_block___182 *, int, int, struct path___182 *);
	int (*quota_on_meta)(struct super_block___182 *, int, int);
	int (*quota_off)(struct super_block___182 *, int);
	int (*quota_sync)(struct super_block___182 *, int);
	int (*get_info)(struct super_block___182 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___182 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___182 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___182 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___182 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___182 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___182 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___182 *, unsigned int);
};

struct address_space_operations___182 {
	int (*writepage)(struct page___181 *, struct writeback_control *);
	int (*readpage)(struct file___182 *, struct page___181 *);
	int (*writepages)(struct address_space___182 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___181 *);
	int (*readpages)(struct file___182 *, struct address_space___182 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___182 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___181 **, void **);
	int (*write_end)(struct file___182 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___181 *, void *);
	sector_t (*bmap)(struct address_space___182 *, sector_t);
	void (*invalidatepage)(struct page___181 *, long unsigned int);
	int (*releasepage)(struct page___181 *, gfp_t);
	void (*freepage)(struct page___181 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___182 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___182 *, struct page___181 *, struct page___181 *, enum migrate_mode);
	int (*launder_page)(struct page___181 *);
	int (*is_partially_uptodate)(struct page___181 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___181 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___182 *, struct page___181 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___182 *, sector_t *);
	void (*swap_deactivate)(struct file___182 *);
	void (*invalidatepage_range)(struct page___181 *, unsigned int, unsigned int);
};

struct hd_struct___37 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___147 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___37;

struct block_device_operations___36;

struct gendisk___37 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___37 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___37 *part_tbl;
	struct hd_struct___37 part0;
	const struct block_device_operations___36 *fops;
	struct request_queue___36 *queue;
	void *private_data;
	int flags;
	struct device___147 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct blkcg_gq___4;

struct request_list___36 {
	struct request_queue___36 *q;
	struct blkcg_gq___4 *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___36(struct request_queue___36 *);

typedef void make_request_fn___36(struct request_queue___36 *, struct bio___37 *);

struct request___36;

typedef int prep_rq_fn___36(struct request_queue___36 *, struct request___36 *);

struct bvec_merge_data___36;

typedef int merge_bvec_fn___37(struct request_queue___36 *, struct bvec_merge_data___36 *, struct bio_vec___37 *);

typedef void softirq_done_fn___36(struct request___36 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___36(struct request___36 *);

typedef int dma_drain_needed_fn___36(struct request___36 *);

typedef int lld_busy_fn___36(struct request_queue___36 *);

struct bsg_class_device___36 {
	struct device___147 *class_dev;
	struct device___147 *parent;
	int minor;
	struct request_queue___36 *queue;
	struct kref ref;
	void (*release)(struct device___147 *);
};

typedef void unprep_rq_fn___36(struct request_queue___36 *, struct request___36 *);

struct elevator_queue___36;

struct blk_mq_ops___10;

struct blk_mq_ctx___10;

struct blk_mq_hw_ctx___10;

struct blk_queue_tag___36;

struct blk_trace___8;

struct throtl_data___2;

struct blk_mq_tag_set___10;

struct blk_flush_queue___10;

struct request_queue___36 {
	struct list_head queue_head;
	struct request___36 *last_merge;
	struct elevator_queue___36 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___36 root_rl;
	request_fn_proc___36 *request_fn;
	make_request_fn___36 *make_request_fn;
	prep_rq_fn___36 *prep_rq_fn;
	merge_bvec_fn___37 *merge_bvec_fn;
	softirq_done_fn___36 *softirq_done_fn;
	rq_timed_out_fn___36 *rq_timed_out_fn;
	dma_drain_needed_fn___36 *dma_drain_needed;
	lld_busy_fn___36 *lld_busy_fn;
	struct blk_mq_ops___10 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___10 *queue_ctx;
		struct {
			struct blk_mq_ctx___10 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___10 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___36 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___46 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___147 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___36 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___4 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___8 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___36 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___185 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___36 bsg_dev;
	struct throtl_data___2 *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___36 *unprep_rq_fn;
	struct blk_mq_tag_set___10 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___37 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___10 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___182 {
	struct dentry___182 * (*lookup)(struct inode___182 *, struct dentry___182 *, unsigned int);
	void * (*follow_link)(struct dentry___182 *, struct nameidata *);
	int (*permission)(struct inode___182 *, int);
	struct posix_acl * (*get_acl)(struct inode___182 *, int);
	int (*readlink)(struct dentry___182 *, char *, int);
	void (*put_link)(struct dentry___182 *, struct nameidata *, void *);
	int (*create)(struct inode___182 *, struct dentry___182 *, umode_t, bool);
	int (*link)(struct dentry___182 *, struct inode___182 *, struct dentry___182 *);
	int (*unlink)(struct inode___182 *, struct dentry___182 *);
	int (*symlink)(struct inode___182 *, struct dentry___182 *, const char *);
	int (*mkdir)(struct inode___182 *, struct dentry___182 *, umode_t);
	int (*rmdir)(struct inode___182 *, struct dentry___182 *);
	int (*mknod)(struct inode___182 *, struct dentry___182 *, umode_t, dev_t);
	int (*rename)(struct inode___182 *, struct dentry___182 *, struct inode___182 *, struct dentry___182 *);
	int (*setattr)(struct dentry___182 *, struct iattr___182 *);
	int (*getattr)(struct vfsmount *, struct dentry___182 *, struct kstat *);
	int (*setxattr)(struct dentry___182 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___182 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___182 *, char *, size_t);
	int (*removexattr)(struct dentry___182 *, const char *);
	int (*fiemap)(struct inode___182 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___182 *, struct timespec *, int);
	int (*atomic_open)(struct inode___182 *, struct dentry___182 *, struct file___182 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___107;

struct seq_file___130;

struct file_operations___182 {
	struct module___99 *owner;
	loff_t (*llseek)(struct file___182 *, loff_t, int);
	ssize_t (*read)(struct file___182 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___182 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___182 *, void *, filldir_t);
	unsigned int (*poll)(struct file___182 *, struct poll_table_struct___107 *);
	long int (*unlocked_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___182 *, struct vm_area_struct___189 *);
	int (*open)(struct inode___182 *, struct file___182 *);
	int (*flush)(struct file___182 *, fl_owner_t);
	int (*release)(struct inode___182 *, struct file___182 *);
	int (*fsync)(struct file___182 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___182 *, int);
	int (*lock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*sendpage)(struct file___182 *, struct page___181 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___182 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___182 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___182 *, long int, struct file_lock___182 **, void **);
		struct {
			int (*setlease)(struct file___182 *, long int, struct file_lock___182 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___182 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___130 *, struct file___182 *);
};

struct fasync_struct___182;

struct file_lock_operations___182;

struct lock_manager_operations___182;

struct file_lock___182 {
	struct file_lock___182 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___182 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___182 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___182 *fl_ops;
	const struct lock_manager_operations___182 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___182 {
	void (*fl_copy_lock)(struct file_lock___182 *, struct file_lock___182 *);
	void (*fl_release_private)(struct file_lock___182 *);
};

struct lock_manager_operations___182 {
	int (*lm_compare_owner)(struct file_lock___182 *, struct file_lock___182 *);
	long unsigned int (*lm_owner_key)(struct file_lock___182 *);
	void (*lm_notify)(struct file_lock___182 *);
	int (*lm_grant)(struct file_lock___182 *, struct file_lock___182 *, int);
	void (*lm_break)(struct file_lock___182 *);
	int (*lm_change)(struct file_lock___182 **, int);
};

struct fasync_struct___182 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___182 *fa_next;
	struct file___182 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___182 {
	const char *name;
	int fs_flags;
	struct dentry___182 * (*mount)(struct file_system_type___182 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___182 *);
	struct module___99 *owner;
	struct file_system_type___182 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___182 {
	struct inode___182 * (*alloc_inode)(struct super_block___182 *);
	void (*destroy_inode)(struct inode___182 *);
	void (*dirty_inode)(struct inode___182 *, int);
	int (*write_inode)(struct inode___182 *, struct writeback_control *);
	int (*drop_inode)(struct inode___182 *);
	void (*evict_inode)(struct inode___182 *);
	void (*put_super)(struct super_block___182 *);
	int (*sync_fs)(struct super_block___182 *, int);
	int (*freeze_fs)(struct super_block___182 *);
	int (*unfreeze_fs)(struct super_block___182 *);
	int (*statfs)(struct dentry___182 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___182 *, int *, char *);
	void (*umount_begin)(struct super_block___182 *);
	int (*show_options)(struct seq_file___130 *, struct dentry___182 *);
	int (*show_devname)(struct seq_file___130 *, struct dentry___182 *);
	int (*show_path)(struct seq_file___130 *, struct dentry___182 *);
	int (*show_stats)(struct seq_file___130 *, struct dentry___182 *);
	ssize_t (*quota_read)(struct super_block___182 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___182 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___182 *);
	int (*bdev_try_to_free_page)(struct super_block___182 *, struct page___181 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___182 *);
	void (*free_cached_objects)(struct super_block___182 *, int);
};

struct xattr_handler___114 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___182 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___182 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___182 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___109)(struct file___182 *, wait_queue_head_t *, struct poll_table_struct___107 *);

struct poll_table_struct___107 {
	poll_queue_proc___109 _qproc;
	long unsigned int _key;
};

struct seq_operations___130;

struct seq_file___130 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___185 lock;
	const struct seq_operations___130 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___37 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___37 *last_lookup;
	struct hd_struct___37 *part[0];
};

struct block_device_operations___36 {
	int (*open)(struct block_device___182 *, fmode_t);
	void (*release)(struct gendisk___37 *, fmode_t);
	int (*ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___182 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___37 *, unsigned int);
	int (*media_changed)(struct gendisk___37 *);
	void (*unlock_native_capacity)(struct gendisk___37 *);
	int (*revalidate_disk)(struct gendisk___37 *);
	int (*getgeo)(struct block_device___182 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___182 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___99 *owner;
};

struct vm_fault___159 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___181 *page;
};

struct irq_chip___125 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___125 *);
	void (*irq_shutdown)(struct irq_data___125 *);
	void (*irq_enable)(struct irq_data___125 *);
	void (*irq_disable)(struct irq_data___125 *);
	void (*irq_ack)(struct irq_data___125 *);
	void (*irq_mask)(struct irq_data___125 *);
	void (*irq_mask_ack)(struct irq_data___125 *);
	void (*irq_unmask)(struct irq_data___125 *);
	void (*irq_eoi)(struct irq_data___125 *);
	int (*irq_set_affinity)(struct irq_data___125 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___125 *);
	int (*irq_set_type)(struct irq_data___125 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___125 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___125 *);
	void (*irq_bus_sync_unlock)(struct irq_data___125 *);
	void (*irq_cpu_online)(struct irq_data___125 *);
	void (*irq_cpu_offline)(struct irq_data___125 *);
	void (*irq_suspend)(struct irq_data___125 *);
	void (*irq_resume)(struct irq_data___125 *);
	void (*irq_pm_shutdown)(struct irq_data___125 *);
	void (*irq_print_chip)(struct irq_data___125 *, struct seq_file___130 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___125 *, void *);
	long unsigned int flags;
};

struct io_cq___36 {
	struct request_queue___36 *q;
	struct io_context___36 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___168 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___36(struct request___36 *, int);

struct request___36 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___36 *q;
	struct blk_mq_ctx___10 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___37 *bio;
	struct bio___37 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___36 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___36 *saved_end_io;
		} flush;
	};
	struct gendisk___37 *rq_disk;
	struct hd_struct___37 *part;
	long unsigned int start_time;
	struct request_list___36 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___36 *end_io;
	void *end_io_data;
	struct request___36 *next_rq;
};

struct blkcg___4;

struct blkg_policy_data___4;

struct blkcg_gq___4 {
	struct request_queue___36 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___4 *blkcg;
	struct blkcg_gq___4 *parent;
	struct request_list___36 rl;
	union {
		atomic_t refcnt;
		struct {
			int refcnt;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	bool online;
	struct blkg_policy_data___4 *pd[2];
	struct callback_head callback_head;
};

struct blk_mq_ctx___10 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___36 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___36(struct request_queue___36 *, struct request___36 **, struct bio___37 *);

typedef void elevator_merge_req_fn___36(struct request_queue___36 *, struct request___36 *, struct request___36 *);

typedef void elevator_merged_fn___36(struct request_queue___36 *, struct request___36 *, int);

typedef int elevator_allow_merge_fn___36(struct request_queue___36 *, struct request___36 *, struct bio___37 *);

typedef void elevator_bio_merged_fn___36(struct request_queue___36 *, struct request___36 *, struct bio___37 *);

typedef int elevator_dispatch_fn___36(struct request_queue___36 *, int);

typedef void elevator_add_req_fn___36(struct request_queue___36 *, struct request___36 *);

typedef struct request___36 *elevator_request_list_fn___36(struct request_queue___36 *, struct request___36 *);

typedef void elevator_completed_req_fn___36(struct request_queue___36 *, struct request___36 *);

typedef int elevator_may_queue_fn___36(struct request_queue___36 *, int);

typedef void elevator_init_icq_fn___36(struct io_cq___36 *);

typedef void elevator_exit_icq_fn___36(struct io_cq___36 *);

typedef int elevator_set_req_fn___36(struct request_queue___36 *, struct request___36 *, struct bio___37 *, gfp_t);

typedef void elevator_put_req_fn___36(struct request___36 *);

typedef void elevator_activate_req_fn___36(struct request_queue___36 *, struct request___36 *);

typedef void elevator_deactivate_req_fn___36(struct request_queue___36 *, struct request___36 *);

struct elevator_type___36;

typedef int elevator_init_fn___37(struct request_queue___36 *, struct elevator_type___36 *);

typedef void elevator_exit_fn___36(struct elevator_queue___36 *);

struct elevator_ops___36 {
	elevator_merge_fn___36 *elevator_merge_fn;
	elevator_merged_fn___36 *elevator_merged_fn;
	elevator_merge_req_fn___36 *elevator_merge_req_fn;
	elevator_allow_merge_fn___36 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___36 *elevator_bio_merged_fn;
	elevator_dispatch_fn___36 *elevator_dispatch_fn;
	elevator_add_req_fn___36 *elevator_add_req_fn;
	elevator_activate_req_fn___36 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___36 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___36 *elevator_completed_req_fn;
	elevator_request_list_fn___36 *elevator_former_req_fn;
	elevator_request_list_fn___36 *elevator_latter_req_fn;
	elevator_init_icq_fn___36 *elevator_init_icq_fn;
	elevator_exit_icq_fn___36 *elevator_exit_icq_fn;
	elevator_set_req_fn___36 *elevator_set_req_fn;
	elevator_put_req_fn___36 *elevator_put_req_fn;
	elevator_may_queue_fn___36 *elevator_may_queue_fn;
	elevator_init_fn___37 *elevator_init_fn;
	elevator_exit_fn___36 *elevator_exit_fn;
};

struct elv_fs_entry___36;

struct elevator_type___36 {
	struct kmem_cache___168 *icq_cache;
	struct elevator_ops___36 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___36 *elevator_attrs;
	char elevator_name[16];
	struct module___99 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___36 {
	struct elevator_type___36 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___185 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___36 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___36 *, char *);
	ssize_t (*store)(struct elevator_queue___36 *, const char *, size_t);
};

struct bvec_merge_data___36 {
	struct block_device___182 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___36 {
	struct request___36 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___10;

typedef int queue_rq_fn___11(struct blk_mq_hw_ctx___10 *, const struct blk_mq_queue_data___10 *);

typedef struct blk_mq_hw_ctx___10 *map_queue_fn___11(struct request_queue___36 *, const int);

typedef enum blk_eh_timer_return timeout_fn___11(struct request___36 *, bool);

typedef int init_request_fn___11(void *, struct request___36 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___11(void *, struct request___36 *, unsigned int, unsigned int);

typedef int init_hctx_fn___10(struct blk_mq_hw_ctx___10 *, void *, unsigned int);

typedef void exit_hctx_fn___10(struct blk_mq_hw_ctx___10 *, unsigned int);

struct blk_mq_ops___10 {
	queue_rq_fn___11 *queue_rq;
	map_queue_fn___11 *map_queue;
	union {
		timeout_fn___11 *timeout;
		struct {
			rq_timed_out_fn___36 *timeout;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	softirq_done_fn___36 *complete;
	init_request_fn___11 *init_request;
	exit_request_fn___11 *exit_request;
	init_hctx_fn___10 *init_hctx;
	exit_hctx_fn___10 *exit_hctx;
};

struct blk_mq_hw_ctx___10 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___36 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___10 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct request___36 **padding2;
		struct {
			struct request___36 **rqs;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___2 cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___10 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan___9;

struct blk_trace___8 {
	int trace_state;
	struct rchan___9 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___182 *dir;
	struct dentry___182 *dropped_file;
	struct dentry___182 *msg_file;
	atomic_t dropped;
};

struct throtl_service_queue {
	struct throtl_service_queue *parent_sq;
	struct list_head queued[2];
	unsigned int nr_queued[2];
	struct rb_root pending_tree;
	struct rb_node *first_pending;
	unsigned int nr_pending;
	long unsigned int first_pending_disptime;
	struct timer_list pending_timer;
};

struct throtl_data___2 {
	struct throtl_service_queue service_queue;
	struct request_queue___36 *queue;
	unsigned int nr_queued[2];
	unsigned int nr_undestroyed_grps;
	struct work_struct dispatch_work;
};

struct blk_mq_tag_set___10 {
	struct blk_mq_ops___10 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___185 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___10 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___36 *flush_rq;
	struct request___36 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct rchan_buf___9 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___9 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___182 *dentry;
	struct kref kref;
	struct page___181 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___9;

struct rchan___9 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___9 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___9 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___182 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___9 {
	int (*subbuf_start)(struct rchan_buf___9 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___9 *, struct file___182 *);
	void (*buf_unmapped)(struct rchan_buf___9 *, struct file___182 *);
	struct dentry___182 * (*create_buf_file)(const char *, struct dentry___182 *, umode_t, struct rchan_buf___9 *, int *);
	int (*remove_buf_file)(struct dentry___182 *);
};

struct cgroupfs_root___113;

struct cgroup___113 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___113 *parent;
	struct dentry___182 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___113 *subsys[11];
	struct cgroupfs_root___113 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___185 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___113 {
	struct super_block___182 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___113 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___59 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___182 *, struct file___182 *);
	ssize_t (*read)(struct cgroup___113 *, struct cftype___59 *, struct file___182 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___113 *, struct cftype___59 *);
	s64 (*read_s64)(struct cgroup___113 *, struct cftype___59 *);
	int (*read_map)(struct cgroup___113 *, struct cftype___59 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___113 *, struct cftype___59 *, struct seq_file___130 *);
	ssize_t (*write)(struct cgroup___113 *, struct cftype___59 *, struct file___182 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___113 *, struct cftype___59 *, u64);
	int (*write_s64)(struct cgroup___113 *, struct cftype___59 *, s64);
	int (*write_string)(struct cgroup___113 *, struct cftype___59 *, const char *);
	int (*trigger)(struct cgroup___113 *, unsigned int);
	int (*release)(struct inode___182 *, struct file___182 *);
	int (*register_event)(struct cgroup___113 *, struct cftype___59 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___113 *, struct cftype___59 *, struct eventfd_ctx *);
};

struct seq_operations___130 {
	void * (*start)(struct seq_file___130 *, loff_t *);
	void (*stop)(struct seq_file___130 *, void *);
	void * (*next)(struct seq_file___130 *, void *, loff_t *);
	int (*show)(struct seq_file___130 *, void *);
};

struct blkcg___4 {
	struct cgroup_subsys_state___113 css;
	spinlock_t lock;
	struct radix_tree_root blkg_tree;
	struct blkcg_gq___4 *blkg_hint;
	struct hlist_head blkg_list;
	uint64_t id;
	unsigned int cfq_weight;
	unsigned int cfq_leaf_weight;
};

struct blkg_policy_data___4 {
	struct blkcg_gq___4 *blkg;
	int plid;
	struct list_head alloc_node;
};

typedef void blkcg_pol_init_pd_fn___2(struct blkcg_gq___4 *);

typedef void blkcg_pol_online_pd_fn___2(struct blkcg_gq___4 *);

typedef void blkcg_pol_offline_pd_fn___2(struct blkcg_gq___4 *);

typedef void blkcg_pol_exit_pd_fn___2(struct blkcg_gq___4 *);

typedef void blkcg_pol_reset_pd_stats_fn___2(struct blkcg_gq___4 *);

struct blkcg_policy___2 {
	int plid;
	size_t pd_size;
	struct cftype___59 *cftypes;
	blkcg_pol_init_pd_fn___2 *pd_init_fn;
	blkcg_pol_online_pd_fn___2 *pd_online_fn;
	blkcg_pol_offline_pd_fn___2 *pd_offline_fn;
	blkcg_pol_exit_pd_fn___2 *pd_exit_fn;
	blkcg_pol_reset_pd_stats_fn___2 *pd_reset_stats_fn;
};

struct blkg_conf_ctx___2 {
	struct gendisk___37 *disk;
	struct blkcg_gq___4 *blkg;
	u64 v;
};

struct blk_mq_queue_data___10 {
	struct request___36 *rq;
	struct list_head *list;
	bool last;
};

struct throtl_grp;

struct throtl_qnode {
	struct list_head node;
	struct bio_list___36 bios;
	struct throtl_grp *tg;
};

struct tg_stats_cpu;

struct throtl_grp {
	struct blkg_policy_data___4 pd;
	struct rb_node rb_node;
	struct throtl_data___2 *td;
	struct throtl_service_queue service_queue;
	struct throtl_qnode qnode_on_self[2];
	struct throtl_qnode qnode_on_parent[2];
	long unsigned int disptime;
	unsigned int flags;
	bool has_rules[2];
	uint64_t bps[2];
	unsigned int iops[2];
	uint64_t bytes_disp[2];
	unsigned int io_disp[2];
	long unsigned int slice_start[2];
	long unsigned int slice_end[2];
	struct tg_stats_cpu *stats_cpu;
	struct list_head stats_alloc_node;
};

enum tg_state_flags {
	THROTL_TG_PENDING = 1,
	THROTL_TG_WAS_EMPTY = 2,
};

struct tg_stats_cpu {
	struct blkg_rwstat service_bytes;
	struct blkg_rwstat serviced;
};

struct noop_data {
	struct list_head queue;
};

struct deadline_data {
	struct rb_root sort_list[2];
	struct list_head fifo_list[2];
	struct request___19 *next_rq[2];
	unsigned int batching;
	sector_t last_sector;
	unsigned int starved;
	int fifo_expire[2];
	int fifo_batch;
	int writes_starved;
	int front_merges;
};

struct page___182;

typedef struct page___182 *pgtable_t___182;

struct address_space___183;

struct kmem_cache___169;

struct page___182 {
	long unsigned int flags;
	struct address_space___183 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___182 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___182 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___169 *slab_cache;
		struct page___182 *first_page;
	};
	long: 64;
};

struct task_struct___185;

struct pv_cpu_ops___185 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___185 *);
	void (*end_context_switch)(struct task_struct___185 *);
};

struct mutex___186 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___185 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___178 {
	struct page___182 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___190;

struct signal_struct___185;

struct bio_list___37;

struct backing_dev_info___47;

struct io_context___37;

struct css_set___114;

struct task_struct___185 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___185 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___190 *mm;
	struct mm_struct___190 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___185 *real_parent;
	struct task_struct___185 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___185 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___185 = 0,
		VTIME_USER___185 = 1,
		VTIME_SYS___185 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___185 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___37 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___47 *backing_dev_info;
	struct io_context___37 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___114 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___186 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___178 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___190 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___190 *, struct mm_struct___190 *);
	void (*dup_mmap)(struct mm_struct___190 *, struct mm_struct___190 *);
	void (*exit_mmap)(struct mm_struct___190 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___190 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___190 *);
	void (*pgd_free)(struct mm_struct___190 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___190 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___190 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___190 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___190 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___190 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___190 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___190 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___190 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___190 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___190 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___190 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___186 lock;
	void *vdso;
} mm_context_t___186;

struct xol_area___182;

struct uprobes_state___182 {
	struct xol_area___182 *xol_area;
};

struct vm_area_struct___190;

struct file___183;

struct core_state___185;

struct mm_struct___190 {
	struct vm_area_struct___190 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___190 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___190 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___186 context;
	long unsigned int flags;
	struct core_state___185 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___185 *owner;
	struct file___183 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___182 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___100;

struct module_kobject___99 {
	struct kobject___4 kobj;
	struct module___100 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___99;

struct module___100 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___99 mkobj;
	struct module_attribute___99 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___185 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___185;

struct lruvec___185 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___185 *zone;
};

struct pglist_data___185;

struct zone___185 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___185 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___185 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___185 {
	struct zone___185 *zone;
	int zone_idx;
};

struct zonelist___185 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___185 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___185 {
	struct zone___185 node_zones[4];
	struct zonelist___185 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___185 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___126;

struct x86_io_apic_ops___126 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___126 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___126;

struct irq_data___126 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___126 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___148;

struct dev_pm_ops___148 {
	int (*prepare)(struct device___148 *);
	void (*complete)(struct device___148 *);
	int (*suspend)(struct device___148 *);
	int (*resume)(struct device___148 *);
	int (*freeze)(struct device___148 *);
	int (*thaw)(struct device___148 *);
	int (*poweroff)(struct device___148 *);
	int (*restore)(struct device___148 *);
	int (*suspend_late)(struct device___148 *);
	int (*resume_early)(struct device___148 *);
	int (*freeze_late)(struct device___148 *);
	int (*thaw_early)(struct device___148 *);
	int (*poweroff_late)(struct device___148 *);
	int (*restore_early)(struct device___148 *);
	int (*suspend_noirq)(struct device___148 *);
	int (*resume_noirq)(struct device___148 *);
	int (*freeze_noirq)(struct device___148 *);
	int (*thaw_noirq)(struct device___148 *);
	int (*poweroff_noirq)(struct device___148 *);
	int (*restore_noirq)(struct device___148 *);
	int (*runtime_suspend)(struct device___148 *);
	int (*runtime_resume)(struct device___148 *);
	int (*runtime_idle)(struct device___148 *);
};

struct device_type___148;

struct bus_type___148;

struct device_driver___148;

struct dev_pm_domain___148;

struct class___148;

struct attribute_group___140;

struct device_rh___148;

struct device___148 {
	struct device___148 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___148 *type;
	struct mutex___186 mutex;
	struct bus_type___148 *bus;
	struct device_driver___148 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___148 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___58 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___148 *class;
	const struct attribute_group___140 **groups;
	void (*release)(struct device___148 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___148 *device_rh;
};

struct dev_pm_info_rh___148 {
	void (*set_latency_tolerance)(struct device___148 *, s32);
};

struct dev_pm_domain___148 {
	struct dev_pm_ops___148 ops;
};

struct smp_ops___185 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___185 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___142;

struct attribute_group___140 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___142 **bin_attrs;
};

struct bin_attribute___142 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___183 *, struct kobject___4 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___183 *, struct kobject___4 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	int (*mmap)(struct file___183 *, struct kobject___4 *, struct bin_attribute___142 *, struct vm_area_struct___190 *);
};

struct dentry___183;

struct path___183 {
	struct vfsmount *mnt;
	struct dentry___183 *dentry;
};

struct inode___183;

struct file_operations___183;

struct file___183 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___183 f_path;
	struct inode___183 *f_inode;
	const struct file_operations___183 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___183 *f_mapping;
	struct mutex___186 f_pos_lock;
};

struct vm_operations_struct___163;

struct vm_area_struct___190 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___190 *vm_next;
	struct vm_area_struct___190 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___190 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___163 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___183 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___99 *, struct module_kobject___99 *, char *);
	ssize_t (*store)(struct module_attribute___99 *, struct module_kobject___99 *, const char *, size_t);
	void (*setup)(struct module___100 *, const char *);
	int (*test)(struct module___100 *);
	void (*free)(struct module___100 *);
};

struct kmem_cache_cpu___168 {
	void **freelist;
	long unsigned int tid;
	struct page___182 *page;
	struct page___182 *partial;
};

struct memcg_cache_params___169;

struct kmem_cache___169 {
	struct kmem_cache_cpu___168 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___169 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___169 {
	bool is_root_cache;
	union {
		struct kmem_cache___169 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___169 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___182 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___182 *page;
	long unsigned int vaddr;
};

struct address_space_operations___183;

struct address_space___183 {
	struct inode___183 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___186 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___183 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___47 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___160;

struct vm_operations_struct___163 {
	void (*open)(struct vm_area_struct___190 *);
	void (*close)(struct vm_area_struct___190 *);
	int (*fault)(struct vm_area_struct___190 *, struct vm_fault___160 *);
	int (*page_mkwrite)(struct vm_area_struct___190 *, struct vm_fault___160 *);
	int (*access)(struct vm_area_struct___190 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___190 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___190 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___190 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___190 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___185 {
	struct task_struct___185 *task;
	struct core_thread___185 *next;
};

struct core_state___185 {
	atomic_t nr_threads;
	struct core_thread___185 dumper;
	struct completion startup;
};

struct signal_struct___185 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___185 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___185 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___186 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___38;

struct bio_list___37 {
	struct bio___38 *head;
	struct bio___38 *tail;
};

struct bdi_writeback___47 {
	struct backing_dev_info___47 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___47 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___47 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___148 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___183 *debug_dir;
	struct dentry___183 *debug_stats;
};

struct io_cq___37;

struct io_context___37 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___37 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___114;

struct css_set___114 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___114 *subsys[11];
	struct callback_head callback_head;
};

struct bus_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___148 *, char *);
	ssize_t (*store)(struct bus_type___148 *, const char *, size_t);
};

struct device_attribute___148;

struct driver_attribute___148;

struct bus_type___148 {
	const char *name;
	const char *dev_name;
	struct device___148 *dev_root;
	struct bus_attribute___148 *bus_attrs;
	struct device_attribute___148 *dev_attrs;
	struct driver_attribute___148 *drv_attrs;
	const struct attribute_group___140 **bus_groups;
	const struct attribute_group___140 **dev_groups;
	const struct attribute_group___140 **drv_groups;
	int (*match)(struct device___148 *, struct device_driver___148 *);
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	int (*probe)(struct device___148 *);
	int (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*online)(struct device___148 *);
	int (*offline)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct device___148 *, struct device_attribute___148 *, char *);
	ssize_t (*store)(struct device___148 *, struct device_attribute___148 *, const char *, size_t);
};

struct driver_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___148 *, char *);
	ssize_t (*store)(struct device_driver___148 *, const char *, size_t);
};

struct device_driver___148 {
	const char *name;
	struct bus_type___148 *bus;
	struct module___100 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___148 *);
	int (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	const struct attribute_group___140 **groups;
	const struct dev_pm_ops___148 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___148 {
	const char *name;
	const struct attribute_group___140 **groups;
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
};

struct class_attribute___148;

struct class___148 {
	const char *name;
	struct module___100 *owner;
	struct class_attribute___148 *class_attrs;
	struct device_attribute___148 *dev_attrs;
	const struct attribute_group___140 **dev_groups;
	struct bin_attribute___142 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *);
	void (*class_release)(struct class___148 *);
	void (*dev_release)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
	struct subsys_private *p;
};

struct class_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct class___148 *, struct class_attribute___148 *, char *);
	ssize_t (*store)(struct class___148 *, struct class_attribute___148 *, const char *, size_t);
	const void * (*namespace)(struct class___148 *, const struct class_attribute___148 *);
};

struct device_rh___148 {
	struct dev_pm_info_rh___148 power;
};

struct dentry_operations___183;

struct super_block___183;

struct dentry___183 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___183 *d_parent;
	struct qstr d_name;
	struct inode___183 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___183 *d_op;
	struct super_block___183 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___183;

struct file_lock___183;

struct dquot___183;

struct block_device___183;

struct inode___183 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___183 *i_op;
	struct super_block___183 *i_sb;
	struct address_space___183 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___186 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___183 *i_fop;
	struct file_lock___183 *i_flock;
	struct address_space___183 i_data;
	struct dquot___183 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___183 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___183 {
	int (*d_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_hash)(const struct dentry___183 *, struct qstr *);
	int (*d_compare)(const struct dentry___183 *, const struct dentry___183 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___183 *);
	void (*d_release)(struct dentry___183 *);
	void (*d_prune)(struct dentry___183 *);
	void (*d_iput)(struct dentry___183 *, struct inode___183 *);
	char * (*d_dname)(struct dentry___183 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___183 *);
	int (*d_manage)(struct dentry___183 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___183;

struct mem_dqinfo___183 {
	struct quota_format_type___183 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___183;

struct quota_info___183 {
	unsigned int flags;
	struct mutex___186 dqio_mutex;
	struct mutex___186 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___183 *files[2];
	struct mem_dqinfo___183 info[2];
	const struct quota_format_ops___183 *ops[2];
};

struct file_system_type___183;

struct super_operations___183;

struct dquot_operations___183;

struct quotactl_ops___183;

struct xattr_handler___115;

struct super_block___183 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___183 *s_type;
	const struct super_operations___183 *s_op;
	const struct dquot_operations___183 *dq_op;
	const struct quotactl_ops___183 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___183 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___115 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___183 *s_bdev;
	struct backing_dev_info___47 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___183 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___186 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___183 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___38(struct bio___38 *, int);

struct bio_vec___38 {
	struct page___182 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___38;

struct bio_set___38;

struct bio___38 {
	sector_t bi_sector;
	struct bio___38 *bi_next;
	struct block_device___183 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___38 *bi_end_io;
	void *bi_private;
	struct io_context___37 *bi_ioc;
	struct cgroup_subsys_state___114 *bi_css;
	struct bio_integrity_payload___38 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___38 *bi_io_vec;
	struct bio_set___38 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___38 bi_inline_vecs[0];
};

struct hd_struct___38;

struct gendisk___38;

struct request_queue___37;

struct block_device___183 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___183 *bd_inode;
	struct super_block___183 *bd_super;
	struct mutex___186 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___183 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___38 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___38 *bd_disk;
	struct request_queue___37 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___186 bd_fsfreeze_mutex;
};

struct cgroup___114;

struct cgroup_subsys_state___114 {
	struct cgroup___114 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___38 {
	struct bio___38 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___38 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___38 *bip_vec;
	struct bio_vec___38 bip_inline_vecs[0];
};

struct bio_set___38 {
	struct kmem_cache___169 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___37 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___183 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___183 *ia_file;
};

struct dquot___183 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___186 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___183 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___183 {
	int qf_fmt_id;
	const struct quota_format_ops___183 *qf_ops;
	struct module___100 *qf_owner;
	struct quota_format_type___183 *qf_next;
};

struct quota_format_ops___183 {
	int (*check_quota_file)(struct super_block___183 *, int);
	int (*read_file_info)(struct super_block___183 *, int);
	int (*write_file_info)(struct super_block___183 *, int);
	int (*free_file_info)(struct super_block___183 *, int);
	int (*read_dqblk)(struct dquot___183 *);
	int (*commit_dqblk)(struct dquot___183 *);
	int (*release_dqblk)(struct dquot___183 *);
};

struct dquot_operations___183 {
	int (*write_dquot)(struct dquot___183 *);
	struct dquot___183 * (*alloc_dquot)(struct super_block___183 *, int);
	void (*destroy_dquot)(struct dquot___183 *);
	int (*acquire_dquot)(struct dquot___183 *);
	int (*release_dquot)(struct dquot___183 *);
	int (*mark_dirty)(struct dquot___183 *);
	int (*write_info)(struct super_block___183 *, int);
	qsize_t * (*get_reserved_space)(struct inode___183 *);
};

struct quotactl_ops___183 {
	int (*quota_on)(struct super_block___183 *, int, int, struct path___183 *);
	int (*quota_on_meta)(struct super_block___183 *, int, int);
	int (*quota_off)(struct super_block___183 *, int);
	int (*quota_sync)(struct super_block___183 *, int);
	int (*get_info)(struct super_block___183 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___183 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___183 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___183 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___183 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___183 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___183 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___183 *, unsigned int);
};

struct address_space_operations___183 {
	int (*writepage)(struct page___182 *, struct writeback_control *);
	int (*readpage)(struct file___183 *, struct page___182 *);
	int (*writepages)(struct address_space___183 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___182 *);
	int (*readpages)(struct file___183 *, struct address_space___183 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___183 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___182 **, void **);
	int (*write_end)(struct file___183 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___182 *, void *);
	sector_t (*bmap)(struct address_space___183 *, sector_t);
	void (*invalidatepage)(struct page___182 *, long unsigned int);
	int (*releasepage)(struct page___182 *, gfp_t);
	void (*freepage)(struct page___182 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___183 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___183 *, struct page___182 *, struct page___182 *, enum migrate_mode);
	int (*launder_page)(struct page___182 *);
	int (*is_partially_uptodate)(struct page___182 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___182 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___183 *, struct page___182 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___183 *, sector_t *);
	void (*swap_deactivate)(struct file___183 *);
	void (*invalidatepage_range)(struct page___182 *, unsigned int, unsigned int);
};

struct hd_struct___38 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___148 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___38;

struct block_device_operations___37;

struct gendisk___38 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___38 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___38 *part_tbl;
	struct hd_struct___38 part0;
	const struct block_device_operations___37 *fops;
	struct request_queue___37 *queue;
	void *private_data;
	int flags;
	struct device___148 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct blkcg_gq___5;

struct request_list___37 {
	struct request_queue___37 *q;
	struct blkcg_gq___5 *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___37(struct request_queue___37 *);

typedef void make_request_fn___37(struct request_queue___37 *, struct bio___38 *);

struct request___37;

typedef int prep_rq_fn___37(struct request_queue___37 *, struct request___37 *);

struct bvec_merge_data___37;

typedef int merge_bvec_fn___38(struct request_queue___37 *, struct bvec_merge_data___37 *, struct bio_vec___38 *);

typedef void softirq_done_fn___37(struct request___37 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___37(struct request___37 *);

typedef int dma_drain_needed_fn___37(struct request___37 *);

typedef int lld_busy_fn___37(struct request_queue___37 *);

struct bsg_class_device___37 {
	struct device___148 *class_dev;
	struct device___148 *parent;
	int minor;
	struct request_queue___37 *queue;
	struct kref ref;
	void (*release)(struct device___148 *);
};

typedef void unprep_rq_fn___37(struct request_queue___37 *, struct request___37 *);

struct elevator_queue___37;

struct blk_mq_ops___11;

struct blk_mq_ctx___11;

struct blk_mq_hw_ctx___11;

struct blk_queue_tag___37;

struct blk_trace___9;

struct blk_mq_tag_set___11;

struct blk_flush_queue___11;

struct request_queue___37 {
	struct list_head queue_head;
	struct request___37 *last_merge;
	struct elevator_queue___37 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___37 root_rl;
	request_fn_proc___37 *request_fn;
	make_request_fn___37 *make_request_fn;
	prep_rq_fn___37 *prep_rq_fn;
	merge_bvec_fn___38 *merge_bvec_fn;
	softirq_done_fn___37 *softirq_done_fn;
	rq_timed_out_fn___37 *rq_timed_out_fn;
	dma_drain_needed_fn___37 *dma_drain_needed;
	lld_busy_fn___37 *lld_busy_fn;
	struct blk_mq_ops___11 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___11 *queue_ctx;
		struct {
			struct blk_mq_ctx___11 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___11 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___37 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___47 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___148 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___37 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___5 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___9 *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___37 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___186 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___37 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___37 *unprep_rq_fn;
	struct blk_mq_tag_set___11 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___38 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___11 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___183 {
	struct dentry___183 * (*lookup)(struct inode___183 *, struct dentry___183 *, unsigned int);
	void * (*follow_link)(struct dentry___183 *, struct nameidata *);
	int (*permission)(struct inode___183 *, int);
	struct posix_acl * (*get_acl)(struct inode___183 *, int);
	int (*readlink)(struct dentry___183 *, char *, int);
	void (*put_link)(struct dentry___183 *, struct nameidata *, void *);
	int (*create)(struct inode___183 *, struct dentry___183 *, umode_t, bool);
	int (*link)(struct dentry___183 *, struct inode___183 *, struct dentry___183 *);
	int (*unlink)(struct inode___183 *, struct dentry___183 *);
	int (*symlink)(struct inode___183 *, struct dentry___183 *, const char *);
	int (*mkdir)(struct inode___183 *, struct dentry___183 *, umode_t);
	int (*rmdir)(struct inode___183 *, struct dentry___183 *);
	int (*mknod)(struct inode___183 *, struct dentry___183 *, umode_t, dev_t);
	int (*rename)(struct inode___183 *, struct dentry___183 *, struct inode___183 *, struct dentry___183 *);
	int (*setattr)(struct dentry___183 *, struct iattr___183 *);
	int (*getattr)(struct vfsmount *, struct dentry___183 *, struct kstat *);
	int (*setxattr)(struct dentry___183 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___183 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___183 *, char *, size_t);
	int (*removexattr)(struct dentry___183 *, const char *);
	int (*fiemap)(struct inode___183 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___183 *, struct timespec *, int);
	int (*atomic_open)(struct inode___183 *, struct dentry___183 *, struct file___183 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___108;

struct seq_file___131;

struct file_operations___183 {
	struct module___100 *owner;
	loff_t (*llseek)(struct file___183 *, loff_t, int);
	ssize_t (*read)(struct file___183 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___183 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___183 *, void *, filldir_t);
	unsigned int (*poll)(struct file___183 *, struct poll_table_struct___108 *);
	long int (*unlocked_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___183 *, struct vm_area_struct___190 *);
	int (*open)(struct inode___183 *, struct file___183 *);
	int (*flush)(struct file___183 *, fl_owner_t);
	int (*release)(struct inode___183 *, struct file___183 *);
	int (*fsync)(struct file___183 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___183 *, int);
	int (*lock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*sendpage)(struct file___183 *, struct page___182 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___183 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___183 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___183 *, long int, struct file_lock___183 **, void **);
		struct {
			int (*setlease)(struct file___183 *, long int, struct file_lock___183 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___183 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___131 *, struct file___183 *);
};

struct fasync_struct___183;

struct file_lock_operations___183;

struct lock_manager_operations___183;

struct file_lock___183 {
	struct file_lock___183 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___183 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___183 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___183 *fl_ops;
	const struct lock_manager_operations___183 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___183 {
	void (*fl_copy_lock)(struct file_lock___183 *, struct file_lock___183 *);
	void (*fl_release_private)(struct file_lock___183 *);
};

struct lock_manager_operations___183 {
	int (*lm_compare_owner)(struct file_lock___183 *, struct file_lock___183 *);
	long unsigned int (*lm_owner_key)(struct file_lock___183 *);
	void (*lm_notify)(struct file_lock___183 *);
	int (*lm_grant)(struct file_lock___183 *, struct file_lock___183 *, int);
	void (*lm_break)(struct file_lock___183 *);
	int (*lm_change)(struct file_lock___183 **, int);
};

struct fasync_struct___183 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___183 *fa_next;
	struct file___183 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___183 {
	const char *name;
	int fs_flags;
	struct dentry___183 * (*mount)(struct file_system_type___183 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___183 *);
	struct module___100 *owner;
	struct file_system_type___183 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___183 {
	struct inode___183 * (*alloc_inode)(struct super_block___183 *);
	void (*destroy_inode)(struct inode___183 *);
	void (*dirty_inode)(struct inode___183 *, int);
	int (*write_inode)(struct inode___183 *, struct writeback_control *);
	int (*drop_inode)(struct inode___183 *);
	void (*evict_inode)(struct inode___183 *);
	void (*put_super)(struct super_block___183 *);
	int (*sync_fs)(struct super_block___183 *, int);
	int (*freeze_fs)(struct super_block___183 *);
	int (*unfreeze_fs)(struct super_block___183 *);
	int (*statfs)(struct dentry___183 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___183 *, int *, char *);
	void (*umount_begin)(struct super_block___183 *);
	int (*show_options)(struct seq_file___131 *, struct dentry___183 *);
	int (*show_devname)(struct seq_file___131 *, struct dentry___183 *);
	int (*show_path)(struct seq_file___131 *, struct dentry___183 *);
	int (*show_stats)(struct seq_file___131 *, struct dentry___183 *);
	ssize_t (*quota_read)(struct super_block___183 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___183 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___183 *);
	int (*bdev_try_to_free_page)(struct super_block___183 *, struct page___182 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___183 *);
	void (*free_cached_objects)(struct super_block___183 *, int);
};

struct xattr_handler___115 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___183 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___183 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___183 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___110)(struct file___183 *, wait_queue_head_t *, struct poll_table_struct___108 *);

struct poll_table_struct___108 {
	poll_queue_proc___110 _qproc;
	long unsigned int _key;
};

struct seq_operations___131;

struct seq_file___131 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___186 lock;
	const struct seq_operations___131 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___38 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___38 *last_lookup;
	struct hd_struct___38 *part[0];
};

struct block_device_operations___37 {
	int (*open)(struct block_device___183 *, fmode_t);
	void (*release)(struct gendisk___38 *, fmode_t);
	int (*ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___183 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___38 *, unsigned int);
	int (*media_changed)(struct gendisk___38 *);
	void (*unlock_native_capacity)(struct gendisk___38 *);
	int (*revalidate_disk)(struct gendisk___38 *);
	int (*getgeo)(struct block_device___183 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___183 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___100 *owner;
};

struct vm_fault___160 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___182 *page;
};

struct irq_chip___126 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___126 *);
	void (*irq_shutdown)(struct irq_data___126 *);
	void (*irq_enable)(struct irq_data___126 *);
	void (*irq_disable)(struct irq_data___126 *);
	void (*irq_ack)(struct irq_data___126 *);
	void (*irq_mask)(struct irq_data___126 *);
	void (*irq_mask_ack)(struct irq_data___126 *);
	void (*irq_unmask)(struct irq_data___126 *);
	void (*irq_eoi)(struct irq_data___126 *);
	int (*irq_set_affinity)(struct irq_data___126 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___126 *);
	int (*irq_set_type)(struct irq_data___126 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___126 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___126 *);
	void (*irq_bus_sync_unlock)(struct irq_data___126 *);
	void (*irq_cpu_online)(struct irq_data___126 *);
	void (*irq_cpu_offline)(struct irq_data___126 *);
	void (*irq_suspend)(struct irq_data___126 *);
	void (*irq_resume)(struct irq_data___126 *);
	void (*irq_pm_shutdown)(struct irq_data___126 *);
	void (*irq_print_chip)(struct irq_data___126 *, struct seq_file___131 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___126 *, void *);
	long unsigned int flags;
};

struct io_cq___37 {
	struct request_queue___37 *q;
	struct io_context___37 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___169 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___37(struct request___37 *, int);

struct request___37 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___37 *q;
	struct blk_mq_ctx___11 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___38 *bio;
	struct bio___38 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___37 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___37 *saved_end_io;
		} flush;
	};
	struct gendisk___38 *rq_disk;
	struct hd_struct___38 *part;
	long unsigned int start_time;
	struct request_list___37 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___37 *end_io;
	void *end_io_data;
	struct request___37 *next_rq;
};

struct blkcg___5;

struct blkg_policy_data___5;

struct blkcg_gq___5 {
	struct request_queue___37 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___5 *blkcg;
	struct blkcg_gq___5 *parent;
	struct request_list___37 rl;
	union {
		atomic_t refcnt;
		struct {
			int refcnt;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	bool online;
	struct blkg_policy_data___5 *pd[2];
	struct callback_head callback_head;
};

struct blk_mq_ctx___11 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___37 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___37(struct request_queue___37 *, struct request___37 **, struct bio___38 *);

typedef void elevator_merge_req_fn___37(struct request_queue___37 *, struct request___37 *, struct request___37 *);

typedef void elevator_merged_fn___37(struct request_queue___37 *, struct request___37 *, int);

typedef int elevator_allow_merge_fn___37(struct request_queue___37 *, struct request___37 *, struct bio___38 *);

typedef void elevator_bio_merged_fn___37(struct request_queue___37 *, struct request___37 *, struct bio___38 *);

typedef int elevator_dispatch_fn___37(struct request_queue___37 *, int);

typedef void elevator_add_req_fn___37(struct request_queue___37 *, struct request___37 *);

typedef struct request___37 *elevator_request_list_fn___37(struct request_queue___37 *, struct request___37 *);

typedef void elevator_completed_req_fn___37(struct request_queue___37 *, struct request___37 *);

typedef int elevator_may_queue_fn___37(struct request_queue___37 *, int);

typedef void elevator_init_icq_fn___37(struct io_cq___37 *);

typedef void elevator_exit_icq_fn___37(struct io_cq___37 *);

typedef int elevator_set_req_fn___37(struct request_queue___37 *, struct request___37 *, struct bio___38 *, gfp_t);

typedef void elevator_put_req_fn___37(struct request___37 *);

typedef void elevator_activate_req_fn___37(struct request_queue___37 *, struct request___37 *);

typedef void elevator_deactivate_req_fn___37(struct request_queue___37 *, struct request___37 *);

struct elevator_type___37;

typedef int elevator_init_fn___38(struct request_queue___37 *, struct elevator_type___37 *);

typedef void elevator_exit_fn___37(struct elevator_queue___37 *);

struct elevator_ops___37 {
	elevator_merge_fn___37 *elevator_merge_fn;
	elevator_merged_fn___37 *elevator_merged_fn;
	elevator_merge_req_fn___37 *elevator_merge_req_fn;
	elevator_allow_merge_fn___37 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___37 *elevator_bio_merged_fn;
	elevator_dispatch_fn___37 *elevator_dispatch_fn;
	elevator_add_req_fn___37 *elevator_add_req_fn;
	elevator_activate_req_fn___37 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___37 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___37 *elevator_completed_req_fn;
	elevator_request_list_fn___37 *elevator_former_req_fn;
	elevator_request_list_fn___37 *elevator_latter_req_fn;
	elevator_init_icq_fn___37 *elevator_init_icq_fn;
	elevator_exit_icq_fn___37 *elevator_exit_icq_fn;
	elevator_set_req_fn___37 *elevator_set_req_fn;
	elevator_put_req_fn___37 *elevator_put_req_fn;
	elevator_may_queue_fn___37 *elevator_may_queue_fn;
	elevator_init_fn___38 *elevator_init_fn;
	elevator_exit_fn___37 *elevator_exit_fn;
};

struct elv_fs_entry___37;

struct elevator_type___37 {
	struct kmem_cache___169 *icq_cache;
	struct elevator_ops___37 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___37 *elevator_attrs;
	char elevator_name[16];
	struct module___100 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___37 {
	struct elevator_type___37 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___186 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___37 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___37 *, char *);
	ssize_t (*store)(struct elevator_queue___37 *, const char *, size_t);
};

struct bvec_merge_data___37 {
	struct block_device___183 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___37 {
	struct request___37 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___11;

typedef int queue_rq_fn___12(struct blk_mq_hw_ctx___11 *, const struct blk_mq_queue_data___11 *);

typedef struct blk_mq_hw_ctx___11 *map_queue_fn___12(struct request_queue___37 *, const int);

typedef enum blk_eh_timer_return timeout_fn___12(struct request___37 *, bool);

typedef int init_request_fn___12(void *, struct request___37 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___12(void *, struct request___37 *, unsigned int, unsigned int);

typedef int init_hctx_fn___11(struct blk_mq_hw_ctx___11 *, void *, unsigned int);

typedef void exit_hctx_fn___11(struct blk_mq_hw_ctx___11 *, unsigned int);

struct blk_mq_ops___11 {
	queue_rq_fn___12 *queue_rq;
	map_queue_fn___12 *map_queue;
	union {
		timeout_fn___12 *timeout;
		struct {
			rq_timed_out_fn___37 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___37 *complete;
	init_request_fn___12 *init_request;
	exit_request_fn___12 *exit_request;
	init_hctx_fn___11 *init_hctx;
	exit_hctx_fn___11 *exit_hctx;
};

struct blk_mq_hw_ctx___11 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___37 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___11 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___37 **padding2;
		struct {
			struct request___37 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___11 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan___10;

struct blk_trace___9 {
	int trace_state;
	struct rchan___10 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___183 *dir;
	struct dentry___183 *dropped_file;
	struct dentry___183 *msg_file;
	atomic_t dropped;
};

struct blk_mq_tag_set___11 {
	struct blk_mq_ops___11 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___186 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___11 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___37 *flush_rq;
	struct request___37 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct rchan_buf___10 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___10 *chan;
	wait_queue_head_t read_wait;
	struct timer_list timer;
	struct dentry___183 *dentry;
	struct kref kref;
	struct page___182 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___10;

struct rchan___10 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___10 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___10 *buf[5120];
	int is_global;
	struct list_head list;
	struct dentry___183 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___10 {
	int (*subbuf_start)(struct rchan_buf___10 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___10 *, struct file___183 *);
	void (*buf_unmapped)(struct rchan_buf___10 *, struct file___183 *);
	struct dentry___183 * (*create_buf_file)(const char *, struct dentry___183 *, umode_t, struct rchan_buf___10 *, int *);
	int (*remove_buf_file)(struct dentry___183 *);
};

struct blk_mq_queue_data___11 {
	struct request___37 *rq;
	struct list_head *list;
	bool last;
};

struct cgroupfs_root___114;

struct cgroup___114 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___114 *parent;
	struct dentry___183 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___114 *subsys[11];
	struct cgroupfs_root___114 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___186 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___114 {
	struct super_block___183 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___114 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___60 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___183 *, struct file___183 *);
	ssize_t (*read)(struct cgroup___114 *, struct cftype___60 *, struct file___183 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___114 *, struct cftype___60 *);
	s64 (*read_s64)(struct cgroup___114 *, struct cftype___60 *);
	int (*read_map)(struct cgroup___114 *, struct cftype___60 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___114 *, struct cftype___60 *, struct seq_file___131 *);
	ssize_t (*write)(struct cgroup___114 *, struct cftype___60 *, struct file___183 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___114 *, struct cftype___60 *, u64);
	int (*write_s64)(struct cgroup___114 *, struct cftype___60 *, s64);
	int (*write_string)(struct cgroup___114 *, struct cftype___60 *, const char *);
	int (*trigger)(struct cgroup___114 *, unsigned int);
	int (*release)(struct inode___183 *, struct file___183 *);
	int (*register_event)(struct cgroup___114 *, struct cftype___60 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___114 *, struct cftype___60 *, struct eventfd_ctx *);
};

struct seq_operations___131 {
	void * (*start)(struct seq_file___131 *, loff_t *);
	void (*stop)(struct seq_file___131 *, void *);
	void * (*next)(struct seq_file___131 *, void *, loff_t *);
	int (*show)(struct seq_file___131 *, void *);
};

struct blkcg___5 {
	struct cgroup_subsys_state___114 css;
	spinlock_t lock;
	struct radix_tree_root blkg_tree;
	struct blkcg_gq___5 *blkg_hint;
	struct hlist_head blkg_list;
	uint64_t id;
	unsigned int cfq_weight;
	unsigned int cfq_leaf_weight;
};

struct blkg_policy_data___5 {
	struct blkcg_gq___5 *blkg;
	int plid;
	struct list_head alloc_node;
};

typedef void blkcg_pol_init_pd_fn___3(struct blkcg_gq___5 *);

typedef void blkcg_pol_online_pd_fn___3(struct blkcg_gq___5 *);

typedef void blkcg_pol_offline_pd_fn___3(struct blkcg_gq___5 *);

typedef void blkcg_pol_exit_pd_fn___3(struct blkcg_gq___5 *);

typedef void blkcg_pol_reset_pd_stats_fn___3(struct blkcg_gq___5 *);

struct blkcg_policy___3 {
	int plid;
	size_t pd_size;
	struct cftype___60 *cftypes;
	blkcg_pol_init_pd_fn___3 *pd_init_fn;
	blkcg_pol_online_pd_fn___3 *pd_online_fn;
	blkcg_pol_offline_pd_fn___3 *pd_offline_fn;
	blkcg_pol_exit_pd_fn___3 *pd_exit_fn;
	blkcg_pol_reset_pd_stats_fn___3 *pd_reset_stats_fn;
};

struct blkg_conf_ctx___3 {
	struct gendisk___38 *disk;
	struct blkcg_gq___5 *blkg;
	u64 v;
};

struct cfq_ttime {
	long unsigned int last_end_request;
	long unsigned int ttime_total;
	long unsigned int ttime_samples;
	long unsigned int ttime_mean;
};

struct cfq_rb_root {
	struct rb_root rb;
	struct rb_node *left;
	unsigned int count;
	u64 min_vdisktime;
	struct cfq_ttime ttime;
};

struct cfq_data;

struct cfq_group;

struct cfq_queue {
	int ref;
	unsigned int flags;
	struct cfq_data *cfqd;
	struct rb_node rb_node;
	long unsigned int rb_key;
	struct rb_node p_node;
	struct rb_root *p_root;
	struct rb_root sort_list;
	struct request___37 *next_rq;
	int queued[2];
	int allocated[2];
	struct list_head fifo;
	long unsigned int dispatch_start;
	unsigned int allocated_slice;
	unsigned int slice_dispatch;
	long unsigned int slice_start;
	long unsigned int slice_end;
	long int slice_resid;
	int prio_pending;
	int dispatched;
	short unsigned int ioprio;
	short unsigned int org_ioprio;
	short unsigned int ioprio_class;
	pid_t pid;
	u32 seek_history;
	sector_t last_request_pos;
	struct cfq_rb_root *service_tree;
	struct cfq_queue *new_cfqq;
	struct cfq_group *cfqg;
	long unsigned int nr_sectors;
};

enum wl_class_t {
	BE_WORKLOAD = 0,
	RT_WORKLOAD = 1,
	IDLE_WORKLOAD = 2,
	CFQ_PRIO_NR = 3,
};

enum wl_type_t {
	ASYNC_WORKLOAD = 0,
	SYNC_NOIDLE_WORKLOAD = 1,
	SYNC_WORKLOAD = 2,
};

struct cfq_io_cq;

struct cfq_data {
	struct request_queue___37 *queue;
	struct cfq_rb_root grp_service_tree;
	struct cfq_group *root_group;
	enum wl_class_t serving_wl_class;
	enum wl_type_t serving_wl_type;
	long unsigned int workload_expires;
	struct cfq_group *serving_group;
	struct rb_root prio_trees[8];
	unsigned int busy_queues;
	unsigned int busy_sync_queues;
	int rq_in_driver;
	int rq_in_flight[2];
	int rq_queued;
	int hw_tag;
	int hw_tag_est_depth;
	unsigned int hw_tag_samples;
	struct timer_list idle_slice_timer;
	struct work_struct unplug_work;
	struct cfq_queue *active_queue;
	struct cfq_io_cq *active_cic;
	struct cfq_queue *async_cfqq[16];
	struct cfq_queue *async_idle_cfqq;
	sector_t last_position;
	unsigned int cfq_quantum;
	unsigned int cfq_fifo_expire[2];
	unsigned int cfq_back_penalty;
	unsigned int cfq_back_max;
	unsigned int cfq_slice[2];
	unsigned int cfq_slice_async_rq;
	unsigned int cfq_slice_idle;
	unsigned int cfq_group_idle;
	unsigned int cfq_latency;
	unsigned int cfq_target_latency;
	struct cfq_queue oom_cfqq;
	long unsigned int last_delayed_sync;
};

struct cfqg_stats {
	struct blkg_rwstat service_bytes;
	struct blkg_rwstat serviced;
	struct blkg_rwstat merged;
	struct blkg_rwstat service_time;
	struct blkg_rwstat wait_time;
	struct blkg_rwstat queued;
	struct blkg_stat sectors;
	struct blkg_stat time;
};

struct cfq_group {
	struct blkg_policy_data___5 pd;
	struct rb_node rb_node;
	u64 vdisktime;
	int nr_active;
	unsigned int children_weight;
	unsigned int vfraction;
	unsigned int weight;
	unsigned int new_weight;
	unsigned int dev_weight;
	unsigned int leaf_weight;
	unsigned int new_leaf_weight;
	unsigned int dev_leaf_weight;
	int nr_cfqq;
	unsigned int busy_queues_avg[3];
	struct cfq_rb_root service_trees[6];
	struct cfq_rb_root service_tree_idle;
	long unsigned int saved_wl_slice;
	enum wl_type_t saved_wl_type;
	enum wl_class_t saved_wl_class;
	int dispatched;
	struct cfq_ttime ttime;
	struct cfqg_stats stats;
	struct cfqg_stats dead_stats;
};

struct cfq_io_cq {
	struct io_cq___37 icq;
	struct cfq_queue *cfqq[2];
	struct cfq_ttime ttime;
	int ioprio;
	uint64_t blkcg_id;
};

enum cfqq_state_flags {
	CFQ_CFQQ_FLAG_on_rr = 0,
	CFQ_CFQQ_FLAG_wait_request = 1,
	CFQ_CFQQ_FLAG_must_dispatch = 2,
	CFQ_CFQQ_FLAG_must_alloc_slice = 3,
	CFQ_CFQQ_FLAG_fifo_expire = 4,
	CFQ_CFQQ_FLAG_idle_window = 5,
	CFQ_CFQQ_FLAG_prio_changed = 6,
	CFQ_CFQQ_FLAG_slice_new = 7,
	CFQ_CFQQ_FLAG_sync = 8,
	CFQ_CFQQ_FLAG_coop = 9,
	CFQ_CFQQ_FLAG_split_coop = 10,
	CFQ_CFQQ_FLAG_deep = 11,
	CFQ_CFQQ_FLAG_wait_busy = 12,
};

struct cdrom_msf0 {
	__u8 minute;
	__u8 second;
	__u8 frame;
};

union cdrom_addr {
	struct cdrom_msf0 msf;
	int lba;
};

struct cdrom_read_audio {
	union cdrom_addr addr;
	__u8 addr_format;
	int nframes;
	__u8 *buf;
};

struct floppy_struct {
	unsigned int size;
	unsigned int sect;
	unsigned int head;
	unsigned int track;
	unsigned int stretch;
	unsigned char gap;
	unsigned char rate;
	unsigned char spec1;
	unsigned char fmt_gap;
	const char *name;
};

struct floppy_max_errors {
	unsigned int abort;
	unsigned int read_track;
	unsigned int reset;
	unsigned int recal;
	unsigned int reporting;
};

struct floppy_drive_params {
	signed char cmos;
	long unsigned int max_dtr;
	long unsigned int hlt;
	long unsigned int hut;
	long unsigned int srt;
	long unsigned int spinup;
	long unsigned int spindown;
	unsigned char spindown_offset;
	unsigned char select_delay;
	unsigned char rps;
	unsigned char tracks;
	long unsigned int timeout;
	unsigned char interleave_sect;
	struct floppy_max_errors max_errors;
	char flags;
	char read_track;
	short int autodetect[8];
	int checkfreq;
	int native_format;
};

struct floppy_drive_struct {
	long unsigned int flags;
	long unsigned int spinup_date;
	long unsigned int select_date;
	long unsigned int first_read_date;
	short int probed_format;
	short int track;
	short int maxblock;
	short int maxtrack;
	int generation;
	int keep_data;
	int fd_ref;
	int fd_device;
	long unsigned int last_checked;
	char *dmabuf;
	int bufblocks;
};

struct floppy_fdc_state {
	int spec1;
	int spec2;
	int dtr;
	unsigned char version;
	unsigned char dor;
	long unsigned int address;
	unsigned int rawcmd: 2;
	unsigned int reset: 1;
	unsigned int need_configure: 1;
	unsigned int perp_mode: 2;
	unsigned int has_fifo: 1;
	unsigned int driver_version;
	unsigned char track[4];
};

struct floppy_write_errors {
	unsigned int write_errors;
	long unsigned int first_error_sector;
	int first_error_generation;
	long unsigned int last_error_sector;
	int last_error_generation;
	unsigned int badness;
};

struct compat_floppy_struct {
	compat_uint_t size;
	compat_uint_t sect;
	compat_uint_t head;
	compat_uint_t track;
	compat_uint_t stretch;
	unsigned char gap;
	unsigned char rate;
	unsigned char spec1;
	unsigned char fmt_gap;
	const compat_caddr_t name;
};

struct compat_hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	short unsigned int cylinders;
	u32 start;
};

struct compat_cdrom_read_audio {
	union cdrom_addr addr;
	u8 addr_format;
	compat_int_t nframes;
	compat_caddr_t buf;
};

struct compat_cdrom_generic_command {
	unsigned char cmd[12];
	compat_caddr_t buffer;
	compat_uint_t buflen;
	compat_int_t stat;
	compat_caddr_t sense;
	unsigned char data_direction;
	compat_int_t quiet;
	compat_int_t timeout;
	compat_caddr_t reserved[1];
};

struct compat_blkpg_ioctl_arg {
	compat_int_t op;
	compat_int_t flags;
	compat_int_t datalen;
	compat_caddr_t data;
};

struct compat_floppy_drive_params {
	char cmos;
	compat_ulong_t max_dtr;
	compat_ulong_t hlt;
	compat_ulong_t hut;
	compat_ulong_t srt;
	compat_ulong_t spinup;
	compat_ulong_t spindown;
	unsigned char spindown_offset;
	unsigned char select_delay;
	unsigned char rps;
	unsigned char tracks;
	compat_ulong_t timeout;
	unsigned char interleave_sect;
	struct floppy_max_errors max_errors;
	char flags;
	char read_track;
	short int autodetect[8];
	compat_int_t checkfreq;
	compat_int_t native_format;
};

struct compat_floppy_drive_struct {
	signed char flags;
	compat_ulong_t spinup_date;
	compat_ulong_t select_date;
	compat_ulong_t first_read_date;
	short int probed_format;
	short int track;
	short int maxblock;
	short int maxtrack;
	compat_int_t generation;
	compat_int_t keep_data;
	compat_int_t fd_ref;
	compat_int_t fd_device;
	compat_int_t last_checked;
	compat_caddr_t dmabuf;
	compat_int_t bufblocks;
};

struct compat_floppy_fdc_state {
	compat_int_t spec1;
	compat_int_t spec2;
	compat_int_t dtr;
	unsigned char version;
	unsigned char dor;
	compat_ulong_t address;
	unsigned int rawcmd: 2;
	unsigned int reset: 1;
	unsigned int need_configure: 1;
	unsigned int perp_mode: 2;
	unsigned int has_fifo: 1;
	unsigned int driver_version;
	unsigned char track[4];
};

struct compat_floppy_write_errors {
	unsigned int write_errors;
	compat_ulong_t first_error_sector;
	compat_int_t first_error_generation;
	compat_ulong_t last_error_sector;
	compat_int_t last_error_generation;
	compat_uint_t badness;
};

struct page___183;

typedef struct page___183 *pgtable_t___183;

struct address_space___184;

struct kmem_cache___170;

struct page___183 {
	long unsigned int flags;
	struct address_space___184 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___183 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___183 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___170 *slab_cache;
		struct page___183 *first_page;
	};
	long: 64;
};

struct task_struct___186;

struct pv_cpu_ops___186 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___186 *);
	void (*end_context_switch)(struct task_struct___186 *);
};

struct mutex___187 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___186 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___179 {
	struct page___183 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___191;

struct signal_struct___186;

struct bio_list___38;

struct backing_dev_info___48;

struct io_context___38;

struct task_struct___186 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___186 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___191 *mm;
	struct mm_struct___191 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___186 *real_parent;
	struct task_struct___186 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___186 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___186 = 0,
		VTIME_USER___186 = 1,
		VTIME_SYS___186 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___186 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___38 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___48 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___187 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___179 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___191 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___191 *, struct mm_struct___191 *);
	void (*dup_mmap)(struct mm_struct___191 *, struct mm_struct___191 *);
	void (*exit_mmap)(struct mm_struct___191 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___191 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___191 *);
	void (*pgd_free)(struct mm_struct___191 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___191 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___191 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___191 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___191 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___191 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___191 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___191 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___191 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___191 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___191 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___191 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___187 lock;
	void *vdso;
} mm_context_t___187;

struct xol_area___183;

struct uprobes_state___183 {
	struct xol_area___183 *xol_area;
};

struct vm_area_struct___191;

struct file___184;

struct core_state___186;

struct mm_struct___191 {
	struct vm_area_struct___191 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___191 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___191 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___187 context;
	long unsigned int flags;
	struct core_state___186 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___186 *owner;
	struct file___184 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___183 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___183 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___183 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___169;

struct memcg_cache_params___170;

struct kmem_cache___170 {
	struct kmem_cache_cpu___169 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___4 kobj;
	struct memcg_cache_params___170 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___184;

struct address_space_operations___184;

struct address_space___184 {
	struct inode___184 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___187 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___184 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___48 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___184;

struct path___184 {
	struct vfsmount *mnt;
	struct dentry___184 *dentry;
};

struct file_operations___184;

struct file___184 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___184 f_path;
	struct inode___184 *f_inode;
	const struct file_operations___184 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___184 *f_mapping;
	struct mutex___187 f_pos_lock;
};

struct vm_operations_struct___164;

struct vm_area_struct___191 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___191 *vm_next;
	struct vm_area_struct___191 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___191 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___164 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___184 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___161;

struct vm_operations_struct___164 {
	void (*open)(struct vm_area_struct___191 *);
	void (*close)(struct vm_area_struct___191 *);
	int (*fault)(struct vm_area_struct___191 *, struct vm_fault___161 *);
	int (*page_mkwrite)(struct vm_area_struct___191 *, struct vm_fault___161 *);
	int (*access)(struct vm_area_struct___191 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___191 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___191 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___191 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___191 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___186 {
	struct task_struct___186 *task;
	struct core_thread___186 *next;
};

struct core_state___186 {
	atomic_t nr_threads;
	struct core_thread___186 dumper;
	struct completion startup;
};

struct device___149;

struct dev_pm_ops___149 {
	int (*prepare)(struct device___149 *);
	void (*complete)(struct device___149 *);
	int (*suspend)(struct device___149 *);
	int (*resume)(struct device___149 *);
	int (*freeze)(struct device___149 *);
	int (*thaw)(struct device___149 *);
	int (*poweroff)(struct device___149 *);
	int (*restore)(struct device___149 *);
	int (*suspend_late)(struct device___149 *);
	int (*resume_early)(struct device___149 *);
	int (*freeze_late)(struct device___149 *);
	int (*thaw_early)(struct device___149 *);
	int (*poweroff_late)(struct device___149 *);
	int (*restore_early)(struct device___149 *);
	int (*suspend_noirq)(struct device___149 *);
	int (*resume_noirq)(struct device___149 *);
	int (*freeze_noirq)(struct device___149 *);
	int (*thaw_noirq)(struct device___149 *);
	int (*poweroff_noirq)(struct device___149 *);
	int (*restore_noirq)(struct device___149 *);
	int (*runtime_suspend)(struct device___149 *);
	int (*runtime_resume)(struct device___149 *);
	int (*runtime_idle)(struct device___149 *);
};

struct device_type___149;

struct bus_type___149;

struct device_driver___149;

struct dev_pm_domain___149;

struct class___149;

struct attribute_group___141;

struct device_rh___149;

struct device___149 {
	struct device___149 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___149 *type;
	struct mutex___187 mutex;
	struct bus_type___149 *bus;
	struct device_driver___149 *driver;
	void *platform_data;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___149 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___58 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___2 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___149 *class;
	const struct attribute_group___141 **groups;
	void (*release)(struct device___149 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___149 *device_rh;
};

struct dev_pm_info_rh___149 {
	void (*set_latency_tolerance)(struct device___149 *, s32);
};

struct dev_pm_domain___149 {
	struct dev_pm_ops___149 ops;
};

struct smp_ops___186 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___186 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___186;

struct lruvec___186 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___186 *zone;
};

struct pglist_data___186;

struct zone___186 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___186 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___186 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___186 {
	struct zone___186 *zone;
	int zone_idx;
};

struct zonelist___186 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___186 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___186 {
	struct zone___186 node_zones[4];
	struct zonelist___186 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___186 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___186 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___186 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___186 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___187 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___39;

struct bio_list___38 {
	struct bio___39 *head;
	struct bio___39 *tail;
};

struct bdi_writeback___48 {
	struct backing_dev_info___48 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___48 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___48 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___149 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___184 *debug_dir;
	struct dentry___184 *debug_stats;
};

struct io_cq___38;

struct io_context___38 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___38 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bin_attribute___143;

struct attribute_group___141 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___143 **bin_attrs;
};

struct bin_attribute___143 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___184 *, struct kobject___4 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___184 *, struct kobject___4 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	int (*mmap)(struct file___184 *, struct kobject___4 *, struct bin_attribute___143 *, struct vm_area_struct___191 *);
};

struct kmem_cache_cpu___169 {
	void **freelist;
	long unsigned int tid;
	struct page___183 *page;
	struct page___183 *partial;
};

struct memcg_cache_params___170 {
	bool is_root_cache;
	union {
		struct kmem_cache___170 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___170 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___149 *, char *);
	ssize_t (*store)(struct bus_type___149 *, const char *, size_t);
};

struct device_attribute___149;

struct driver_attribute___149;

struct bus_type___149 {
	const char *name;
	const char *dev_name;
	struct device___149 *dev_root;
	struct bus_attribute___149 *bus_attrs;
	struct device_attribute___149 *dev_attrs;
	struct driver_attribute___149 *drv_attrs;
	const struct attribute_group___141 **bus_groups;
	const struct attribute_group___141 **dev_groups;
	const struct attribute_group___141 **drv_groups;
	int (*match)(struct device___149 *, struct device_driver___149 *);
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	int (*probe)(struct device___149 *);
	int (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*online)(struct device___149 *);
	int (*offline)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct device___149 *, struct device_attribute___149 *, char *);
	ssize_t (*store)(struct device___149 *, struct device_attribute___149 *, const char *, size_t);
};

struct driver_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___149 *, char *);
	ssize_t (*store)(struct device_driver___149 *, const char *, size_t);
};

struct device_driver___149 {
	const char *name;
	struct bus_type___149 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___149 *);
	int (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	const struct attribute_group___141 **groups;
	const struct dev_pm_ops___149 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___149 {
	const char *name;
	const struct attribute_group___141 **groups;
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
};

struct class_attribute___149;

struct class___149 {
	const char *name;
	struct module *owner;
	struct class_attribute___149 *class_attrs;
	struct device_attribute___149 *dev_attrs;
	const struct attribute_group___141 **dev_groups;
	struct bin_attribute___143 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *);
	void (*class_release)(struct class___149 *);
	void (*dev_release)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
	struct subsys_private *p;
};

struct class_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct class___149 *, struct class_attribute___149 *, char *);
	ssize_t (*store)(struct class___149 *, struct class_attribute___149 *, const char *, size_t);
	const void * (*namespace)(struct class___149 *, const struct class_attribute___149 *);
};

struct device_rh___149 {
	struct dev_pm_info_rh___149 power;
};

struct dentry_operations___184;

struct super_block___184;

struct dentry___184 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___184 *d_parent;
	struct qstr d_name;
	struct inode___184 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___184 *d_op;
	struct super_block___184 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___184;

struct file_lock___184;

struct dquot___184;

struct block_device___184;

struct inode___184 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___184 *i_op;
	struct super_block___184 *i_sb;
	struct address_space___184 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___187 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___184 *i_fop;
	struct file_lock___184 *i_flock;
	struct address_space___184 i_data;
	struct dquot___184 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___184 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___184 {
	int (*d_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_hash)(const struct dentry___184 *, struct qstr *);
	int (*d_compare)(const struct dentry___184 *, const struct dentry___184 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___184 *);
	void (*d_release)(struct dentry___184 *);
	void (*d_prune)(struct dentry___184 *);
	void (*d_iput)(struct dentry___184 *, struct inode___184 *);
	char * (*d_dname)(struct dentry___184 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___184 *);
	int (*d_manage)(struct dentry___184 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___184;

struct mem_dqinfo___184 {
	struct quota_format_type___184 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___184;

struct quota_info___184 {
	unsigned int flags;
	struct mutex___187 dqio_mutex;
	struct mutex___187 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___184 *files[2];
	struct mem_dqinfo___184 info[2];
	const struct quota_format_ops___184 *ops[2];
};

struct file_system_type___184;

struct super_operations___184;

struct dquot_operations___184;

struct quotactl_ops___184;

struct super_block___184 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___184 *s_type;
	const struct super_operations___184 *s_op;
	const struct dquot_operations___184 *dq_op;
	const struct quotactl_ops___184 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___184 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___184 *s_bdev;
	struct backing_dev_info___48 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___184 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___187 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___184 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___39(struct bio___39 *, int);

struct bio_vec___39 {
	struct page___183 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___39;

struct bio_set___39;

struct bio___39 {
	sector_t bi_sector;
	struct bio___39 *bi_next;
	struct block_device___184 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___39 *bi_end_io;
	void *bi_private;
	struct io_context___38 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___39 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___39 *bi_io_vec;
	struct bio_set___39 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___39 bi_inline_vecs[0];
};

struct hd_struct___39;

struct gendisk___39;

struct request_queue___38;

struct block_device___184 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___184 *bd_inode;
	struct super_block___184 *bd_super;
	struct mutex___187 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___184 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___39 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___39 *bd_disk;
	struct request_queue___38 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___187 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___39 {
	struct bio___39 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___39 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___39 *bip_vec;
	struct bio_vec___39 bip_inline_vecs[0];
};

struct bio_set___39 {
	struct kmem_cache___170 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___38 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___184 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___184 *ia_file;
};

struct dquot___184 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___187 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___184 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___184 {
	int qf_fmt_id;
	const struct quota_format_ops___184 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___184 *qf_next;
};

struct quota_format_ops___184 {
	int (*check_quota_file)(struct super_block___184 *, int);
	int (*read_file_info)(struct super_block___184 *, int);
	int (*write_file_info)(struct super_block___184 *, int);
	int (*free_file_info)(struct super_block___184 *, int);
	int (*read_dqblk)(struct dquot___184 *);
	int (*commit_dqblk)(struct dquot___184 *);
	int (*release_dqblk)(struct dquot___184 *);
};

struct dquot_operations___184 {
	int (*write_dquot)(struct dquot___184 *);
	struct dquot___184 * (*alloc_dquot)(struct super_block___184 *, int);
	void (*destroy_dquot)(struct dquot___184 *);
	int (*acquire_dquot)(struct dquot___184 *);
	int (*release_dquot)(struct dquot___184 *);
	int (*mark_dirty)(struct dquot___184 *);
	int (*write_info)(struct super_block___184 *, int);
	qsize_t * (*get_reserved_space)(struct inode___184 *);
};

struct quotactl_ops___184 {
	int (*quota_on)(struct super_block___184 *, int, int, struct path___184 *);
	int (*quota_on_meta)(struct super_block___184 *, int, int);
	int (*quota_off)(struct super_block___184 *, int);
	int (*quota_sync)(struct super_block___184 *, int);
	int (*get_info)(struct super_block___184 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___184 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___184 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___184 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___184 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___184 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___184 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___184 *, unsigned int);
};

struct address_space_operations___184 {
	int (*writepage)(struct page___183 *, struct writeback_control *);
	int (*readpage)(struct file___184 *, struct page___183 *);
	int (*writepages)(struct address_space___184 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___183 *);
	int (*readpages)(struct file___184 *, struct address_space___184 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___184 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___183 **, void **);
	int (*write_end)(struct file___184 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___183 *, void *);
	sector_t (*bmap)(struct address_space___184 *, sector_t);
	void (*invalidatepage)(struct page___183 *, long unsigned int);
	int (*releasepage)(struct page___183 *, gfp_t);
	void (*freepage)(struct page___183 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___184 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___184 *, struct page___183 *, struct page___183 *, enum migrate_mode);
	int (*launder_page)(struct page___183 *);
	int (*is_partially_uptodate)(struct page___183 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___183 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___184 *, struct page___183 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___184 *, sector_t *);
	void (*swap_deactivate)(struct file___184 *);
	void (*invalidatepage_range)(struct page___183 *, unsigned int, unsigned int);
};

struct hd_struct___39 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___149 __dev;
	struct kobject___4 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___39;

struct block_device_operations___38;

struct gendisk___39 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___39 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___39 *part_tbl;
	struct hd_struct___39 part0;
	const struct block_device_operations___38 *fops;
	struct request_queue___38 *queue;
	void *private_data;
	int flags;
	struct device___149 *driverfs_dev;
	struct kobject___4 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___38 {
	struct request_queue___38 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___38(struct request_queue___38 *);

typedef void make_request_fn___38(struct request_queue___38 *, struct bio___39 *);

struct request___38;

typedef int prep_rq_fn___38(struct request_queue___38 *, struct request___38 *);

struct bvec_merge_data___38;

typedef int merge_bvec_fn___39(struct request_queue___38 *, struct bvec_merge_data___38 *, struct bio_vec___39 *);

typedef void softirq_done_fn___38(struct request___38 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___38(struct request___38 *);

typedef int dma_drain_needed_fn___38(struct request___38 *);

typedef int lld_busy_fn___38(struct request_queue___38 *);

struct bsg_class_device___38 {
	struct device___149 *class_dev;
	struct device___149 *parent;
	int minor;
	struct request_queue___38 *queue;
	struct kref ref;
	void (*release)(struct device___149 *);
};

typedef void unprep_rq_fn___38(struct request_queue___38 *, struct request___38 *);

struct elevator_queue___38;

struct blk_mq_ops___12;

struct blk_mq_ctx___12;

struct blk_mq_hw_ctx___12;

struct blk_queue_tag___38;

struct blk_mq_tag_set___12;

struct blk_flush_queue___12;

struct request_queue___38 {
	struct list_head queue_head;
	struct request___38 *last_merge;
	struct elevator_queue___38 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___38 root_rl;
	request_fn_proc___38 *request_fn;
	make_request_fn___38 *make_request_fn;
	prep_rq_fn___38 *prep_rq_fn;
	merge_bvec_fn___39 *merge_bvec_fn;
	softirq_done_fn___38 *softirq_done_fn;
	rq_timed_out_fn___38 *rq_timed_out_fn;
	dma_drain_needed_fn___38 *dma_drain_needed;
	lld_busy_fn___38 *lld_busy_fn;
	struct blk_mq_ops___12 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___12 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___38 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___48 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___4 kobj;
	struct kobject___4 mq_kobj;
	struct device___149 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___38 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___38 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___187 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___38 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___38 *unprep_rq_fn;
	struct blk_mq_tag_set___12 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___39 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue___12 *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___184 {
	struct dentry___184 * (*lookup)(struct inode___184 *, struct dentry___184 *, unsigned int);
	void * (*follow_link)(struct dentry___184 *, struct nameidata *);
	int (*permission)(struct inode___184 *, int);
	struct posix_acl * (*get_acl)(struct inode___184 *, int);
	int (*readlink)(struct dentry___184 *, char *, int);
	void (*put_link)(struct dentry___184 *, struct nameidata *, void *);
	int (*create)(struct inode___184 *, struct dentry___184 *, umode_t, bool);
	int (*link)(struct dentry___184 *, struct inode___184 *, struct dentry___184 *);
	int (*unlink)(struct inode___184 *, struct dentry___184 *);
	int (*symlink)(struct inode___184 *, struct dentry___184 *, const char *);
	int (*mkdir)(struct inode___184 *, struct dentry___184 *, umode_t);
	int (*rmdir)(struct inode___184 *, struct dentry___184 *);
	int (*mknod)(struct inode___184 *, struct dentry___184 *, umode_t, dev_t);
	int (*rename)(struct inode___184 *, struct dentry___184 *, struct inode___184 *, struct dentry___184 *);
	int (*setattr)(struct dentry___184 *, struct iattr___184 *);
	int (*getattr)(struct vfsmount *, struct dentry___184 *, struct kstat *);
	int (*setxattr)(struct dentry___184 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___184 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___184 *, char *, size_t);
	int (*removexattr)(struct dentry___184 *, const char *);
	int (*fiemap)(struct inode___184 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___184 *, struct timespec *, int);
	int (*atomic_open)(struct inode___184 *, struct dentry___184 *, struct file___184 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___184 {
	struct module *owner;
	loff_t (*llseek)(struct file___184 *, loff_t, int);
	ssize_t (*read)(struct file___184 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___184 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___184 *, void *, filldir_t);
	unsigned int (*poll)(struct file___184 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___184 *, struct vm_area_struct___191 *);
	int (*open)(struct inode___184 *, struct file___184 *);
	int (*flush)(struct file___184 *, fl_owner_t);
	int (*release)(struct inode___184 *, struct file___184 *);
	int (*fsync)(struct file___184 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___184 *, int);
	int (*lock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*sendpage)(struct file___184 *, struct page___183 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___184 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___184 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___184 *, long int, struct file_lock___184 **, void **);
		struct {
			int (*setlease)(struct file___184 *, long int, struct file_lock___184 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___184 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___184 *);
};

struct fasync_struct___184;

struct file_lock_operations___184;

struct lock_manager_operations___184;

struct file_lock___184 {
	struct file_lock___184 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___184 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___184 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___184 *fl_ops;
	const struct lock_manager_operations___184 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___184 {
	void (*fl_copy_lock)(struct file_lock___184 *, struct file_lock___184 *);
	void (*fl_release_private)(struct file_lock___184 *);
};

struct lock_manager_operations___184 {
	int (*lm_compare_owner)(struct file_lock___184 *, struct file_lock___184 *);
	long unsigned int (*lm_owner_key)(struct file_lock___184 *);
	void (*lm_notify)(struct file_lock___184 *);
	int (*lm_grant)(struct file_lock___184 *, struct file_lock___184 *, int);
	void (*lm_break)(struct file_lock___184 *);
	int (*lm_change)(struct file_lock___184 **, int);
};

struct fasync_struct___184 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___184 *fa_next;
	struct file___184 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___184 {
	const char *name;
	int fs_flags;
	struct dentry___184 * (*mount)(struct file_system_type___184 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___184 *);
	struct module *owner;
	struct file_system_type___184 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___184 {
	struct inode___184 * (*alloc_inode)(struct super_block___184 *);
	void (*destroy_inode)(struct inode___184 *);
	void (*dirty_inode)(struct inode___184 *, int);
	int (*write_inode)(struct inode___184 *, struct writeback_control *);
	int (*drop_inode)(struct inode___184 *);
	void (*evict_inode)(struct inode___184 *);
	void (*put_super)(struct super_block___184 *);
	int (*sync_fs)(struct super_block___184 *, int);
	int (*freeze_fs)(struct super_block___184 *);
	int (*unfreeze_fs)(struct super_block___184 *);
	int (*statfs)(struct dentry___184 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___184 *, int *, char *);
	void (*umount_begin)(struct super_block___184 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___184 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___184 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___184 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___184 *);
	ssize_t (*quota_read)(struct super_block___184 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___184 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___184 *);
	int (*bdev_try_to_free_page)(struct super_block___184 *, struct page___183 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___184 *);
	void (*free_cached_objects)(struct super_block___184 *, int);
};

struct disk_part_tbl___39 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___39 *last_lookup;
	struct hd_struct___39 *part[0];
};

struct block_device_operations___38 {
	int (*open)(struct block_device___184 *, fmode_t);
	void (*release)(struct gendisk___39 *, fmode_t);
	int (*ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___184 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___39 *, unsigned int);
	int (*media_changed)(struct gendisk___39 *);
	void (*unlock_native_capacity)(struct gendisk___39 *);
	int (*revalidate_disk)(struct gendisk___39 *);
	int (*getgeo)(struct block_device___184 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___184 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___161 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___183 *page;
};

struct io_cq___38 {
	struct request_queue___38 *q;
	struct io_context___38 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___170 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___38(struct request___38 *, int);

struct request___38 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___38 *q;
	struct blk_mq_ctx___12 *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___39 *bio;
	struct bio___39 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___38 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___38 *saved_end_io;
		} flush;
	};
	struct gendisk___39 *rq_disk;
	struct hd_struct___39 *part;
	long unsigned int start_time;
	struct request_list___38 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___38 *end_io;
	void *end_io_data;
	struct request___38 *next_rq;
};

struct blk_mq_ctx___12 {
	struct {
		spinlock_t lock;
		struct list_head rq_list;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	unsigned int cpu;
	unsigned int index_hw;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int last_tag;
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int rq_completed[2];
	struct request_queue___38 *queue;
	struct kobject___4 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int elevator_merge_fn___38(struct request_queue___38 *, struct request___38 **, struct bio___39 *);

typedef void elevator_merge_req_fn___38(struct request_queue___38 *, struct request___38 *, struct request___38 *);

typedef void elevator_merged_fn___38(struct request_queue___38 *, struct request___38 *, int);

typedef int elevator_allow_merge_fn___38(struct request_queue___38 *, struct request___38 *, struct bio___39 *);

typedef void elevator_bio_merged_fn___38(struct request_queue___38 *, struct request___38 *, struct bio___39 *);

typedef int elevator_dispatch_fn___38(struct request_queue___38 *, int);

typedef void elevator_add_req_fn___38(struct request_queue___38 *, struct request___38 *);

typedef struct request___38 *elevator_request_list_fn___38(struct request_queue___38 *, struct request___38 *);

typedef void elevator_completed_req_fn___38(struct request_queue___38 *, struct request___38 *);

typedef int elevator_may_queue_fn___38(struct request_queue___38 *, int);

typedef void elevator_init_icq_fn___38(struct io_cq___38 *);

typedef void elevator_exit_icq_fn___38(struct io_cq___38 *);

typedef int elevator_set_req_fn___38(struct request_queue___38 *, struct request___38 *, struct bio___39 *, gfp_t);

typedef void elevator_put_req_fn___38(struct request___38 *);

typedef void elevator_activate_req_fn___38(struct request_queue___38 *, struct request___38 *);

typedef void elevator_deactivate_req_fn___38(struct request_queue___38 *, struct request___38 *);

struct elevator_type___38;

typedef int elevator_init_fn___39(struct request_queue___38 *, struct elevator_type___38 *);

typedef void elevator_exit_fn___38(struct elevator_queue___38 *);

struct elevator_ops___38 {
	elevator_merge_fn___38 *elevator_merge_fn;
	elevator_merged_fn___38 *elevator_merged_fn;
	elevator_merge_req_fn___38 *elevator_merge_req_fn;
	elevator_allow_merge_fn___38 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___38 *elevator_bio_merged_fn;
	elevator_dispatch_fn___38 *elevator_dispatch_fn;
	elevator_add_req_fn___38 *elevator_add_req_fn;
	elevator_activate_req_fn___38 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___38 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___38 *elevator_completed_req_fn;
	elevator_request_list_fn___38 *elevator_former_req_fn;
	elevator_request_list_fn___38 *elevator_latter_req_fn;
	elevator_init_icq_fn___38 *elevator_init_icq_fn;
	elevator_exit_icq_fn___38 *elevator_exit_icq_fn;
	elevator_set_req_fn___38 *elevator_set_req_fn;
	elevator_put_req_fn___38 *elevator_put_req_fn;
	elevator_may_queue_fn___38 *elevator_may_queue_fn;
	elevator_init_fn___39 *elevator_init_fn;
	elevator_exit_fn___38 *elevator_exit_fn;
};

struct elv_fs_entry___38;

struct elevator_type___38 {
	struct kmem_cache___170 *icq_cache;
	struct elevator_ops___38 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___38 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___38 {
	struct elevator_type___38 *type;
	void *elevator_data;
	struct kobject___4 kobj;
	struct mutex___187 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___38 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___38 *, char *);
	ssize_t (*store)(struct elevator_queue___38 *, const char *, size_t);
};

struct bvec_merge_data___38 {
	struct block_device___184 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___38 {
	struct request___38 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___12;

typedef int queue_rq_fn___13(struct blk_mq_hw_ctx___12 *, const struct blk_mq_queue_data___12 *);

typedef struct blk_mq_hw_ctx___12 *map_queue_fn___13(struct request_queue___38 *, const int);

typedef enum blk_eh_timer_return timeout_fn___13(struct request___38 *, bool);

typedef int init_request_fn___13(void *, struct request___38 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___13(void *, struct request___38 *, unsigned int, unsigned int);

typedef int init_hctx_fn___12(struct blk_mq_hw_ctx___12 *, void *, unsigned int);

typedef void exit_hctx_fn___12(struct blk_mq_hw_ctx___12 *, unsigned int);

struct blk_mq_ops___12 {
	queue_rq_fn___13 *queue_rq;
	map_queue_fn___13 *map_queue;
	union {
		timeout_fn___13 *timeout;
		struct {
			rq_timed_out_fn___38 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___38 *complete;
	init_request_fn___13 *init_request;
	exit_request_fn___13 *exit_request;
	init_hctx_fn___12 *init_hctx;
	exit_hctx_fn___12 *exit_hctx;
};

struct blk_mq_hw_ctx___12 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___38 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx___12 **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___38 **padding2;
		struct {
			struct request___38 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___4 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue___12 *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___12 {
	struct blk_mq_ops___12 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___187 tag_list_lock;
	struct list_head tag_list;
};

struct blk_flush_queue___12 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___38 *flush_rq;
	struct request___38 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_queue_data___12 {
	struct request___38 *rq;
	struct list_head *list;
	bool last;
};

struct integrity_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_integrity *, char *);
	ssize_t (*store)(struct blk_integrity *, const char *, size_t);
};

struct compress_format {
	unsigned char magic[2];
	const char *name;
	decompress_fn decompressor;
};

struct group_data {
	int limit[21];
	int base[20];
	int permute[258];
	int minLen;
	int maxLen;
};

struct bunzip_data {
	int writeCopies;
	int writePos;
	int writeRunCountdown;
	int writeCount;
	int writeCurrent;
	int (*fill)(void *, unsigned int);
	int inbufCount;
	int inbufPos;
	unsigned char *inbuf;
	unsigned int inbufBitCount;
	unsigned int inbufBits;
	unsigned int crc32Table[256];
	unsigned int headerCRC;
	unsigned int totalCRC;
	unsigned int writeCRC;
	unsigned int *dbuf;
	unsigned int dbufSize;
	unsigned char selectors[32768];
	struct group_data groups[6];
	int io_error;
	int byteCount[256];
	unsigned char symToByte[256];
	unsigned char mtfSymbol[256];
};

typedef unsigned char Byte;

typedef unsigned int uInt;

typedef long unsigned int uLong;

struct internal_state;

struct z_stream_s {
	const Byte *next_in;
	uInt avail_in;
	uLong total_in;
	Byte *next_out;
	uInt avail_out;
	uLong total_out;
	char *msg;
	struct internal_state *state;
	void *workspace;
	int data_type;
	uLong adler;
	uLong reserved;
};

typedef struct z_stream_s z_stream;

typedef z_stream *z_streamp;

typedef struct {
	unsigned char op;
	unsigned char bits;
	short unsigned int val;
} code;

typedef enum {
	HEAD = 0,
	FLAGS = 1,
	TIME = 2,
	OS = 3,
	EXLEN = 4,
	EXTRA = 5,
	NAME = 6,
	COMMENT = 7,
	HCRC = 8,
	DICTID = 9,
	DICT = 10,
	TYPE = 11,
	TYPEDO = 12,
	STORED = 13,
	COPY = 14,
	TABLE = 15,
	LENLENS = 16,
	CODELENS = 17,
	LEN = 18,
	LENEXT = 19,
	DIST = 20,
	DISTEXT = 21,
	MATCH = 22,
	LIT = 23,
	CHECK = 24,
	LENGTH = 25,
	DONE = 26,
	BAD = 27,
	MEM = 28,
	SYNC = 29,
} inflate_mode;

struct inflate_state {
	inflate_mode mode;
	int last;
	int wrap;
	int havedict;
	int flags;
	unsigned int dmax;
	long unsigned int check;
	long unsigned int total;
	unsigned int wbits;
	unsigned int wsize;
	unsigned int whave;
	unsigned int write;
	unsigned char *window;
	long unsigned int hold;
	unsigned int bits;
	unsigned int length;
	unsigned int offset;
	unsigned int extra;
	const code *lencode;
	const code *distcode;
	unsigned int lenbits;
	unsigned int distbits;
	unsigned int ncode;
	unsigned int nlen;
	unsigned int ndist;
	unsigned int have;
	code *next;
	short unsigned int lens[320];
	short unsigned int work[288];
	code codes[2048];
};

struct inflate_workspace {
	struct inflate_state inflate_state;
	unsigned char working_window[32768];
};

struct rc {
	int (*fill)(void *, unsigned int);
	uint8_t *ptr;
	uint8_t *buffer;
	uint8_t *buffer_end;
	int buffer_size;
	uint32_t code;
	uint32_t range;
	uint32_t bound;
	void (*error)(char *);
};

struct lzma_header {
	uint8_t pos;
	uint32_t dict_size;
	uint64_t dst_size;
} __attribute__((packed));

struct writer {
	uint8_t *buffer;
	uint8_t previous_byte;
	size_t buffer_pos;
	int bufsize;
	size_t global_pos;
	int (*flush)(void *, unsigned int);
	struct lzma_header *header;
};

struct cstate {
	int state;
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
};

enum xz_mode {
	XZ_SINGLE = 0,
	XZ_PREALLOC = 1,
	XZ_DYNALLOC = 2,
};

enum xz_ret {
	XZ_OK = 0,
	XZ_STREAM_END = 1,
	XZ_UNSUPPORTED_CHECK = 2,
	XZ_MEM_ERROR = 3,
	XZ_MEMLIMIT_ERROR = 4,
	XZ_FORMAT_ERROR = 5,
	XZ_OPTIONS_ERROR = 6,
	XZ_DATA_ERROR = 7,
	XZ_BUF_ERROR = 8,
};

struct xz_buf {
	const uint8_t *in;
	size_t in_pos;
	size_t in_size;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
};

struct xz_dec;

enum cpio_fields {
	C_MAGIC = 0,
	C_INO = 1,
	C_MODE = 2,
	C_UID = 3,
	C_GID = 4,
	C_NLINK = 5,
	C_MTIME = 6,
	C_FILESIZE = 7,
	C_MAJ = 8,
	C_MIN = 9,
	C_RMAJ = 10,
	C_RMIN = 11,
	C_NAMESIZE = 12,
	C_CHKSUM = 13,
	C_NFIELDS = 14,
};

struct fprop_local_single {
	long unsigned int events;
	unsigned int period;
	raw_spinlock_t lock;
};

typedef struct idr_layer *pto_T_____9;

struct netlink_skb_parms___2 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___14 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___3 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___19 *);
	struct mutex___162 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___28 *, struct sock___14 *);
};

struct pernet_operations___2 {
	struct list_head list;
	int (*init)(struct net___28 *);
	void (*exit)(struct net___28 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct uevent_sock {
	struct list_head list;
	struct sock___14 *sk;
};

struct thread_info___83 {
	struct task_struct___36 *task;
	struct exec_domain___44 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct radix_tree_preload {
	int nr;
	struct radix_tree_node *nodes[21];
};

enum rwsem_waiter_type {
	RWSEM_WAITING_FOR_WRITE = 0,
	RWSEM_WAITING_FOR_READ = 1,
};

struct rwsem_waiter {
	struct list_head list;
	struct task_struct___186 *task;
	enum rwsem_waiter_type type;
};

enum rwsem_wake_type {
	RWSEM_WAKE_ANY = 0,
	RWSEM_WAKE_READERS = 1,
	RWSEM_WAKE_READ_OWNED = 2,
};

typedef struct pglist_data___185 pg_data_t___13;

struct page___184;

typedef struct page___184 *pgtable_t___184;

struct address_space___185;

struct kmem_cache___171;

struct page___184 {
	long unsigned int flags;
	struct address_space___185 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___184 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___184 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___171 *slab_cache;
		struct page___184 *first_page;
	};
	long: 64;
};

struct task_struct___187;

struct pv_cpu_ops___187 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___187 *);
	void (*end_context_switch)(struct task_struct___187 *);
};

struct mutex___188 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___187 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___180 {
	struct page___184 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___192;

struct nsproxy___103;

struct signal_struct___187;

struct css_set___115;

struct task_struct___187 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___187 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___192 *mm;
	struct mm_struct___192 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___187 *real_parent;
	struct task_struct___187 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___187 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___187 = 0,
		VTIME_USER___187 = 1,
		VTIME_SYS___187 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___103 *nsproxy;
	struct signal_struct___187 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___115 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___188 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___180 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___192 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___192 *, struct mm_struct___192 *);
	void (*dup_mmap)(struct mm_struct___192 *, struct mm_struct___192 *);
	void (*exit_mmap)(struct mm_struct___192 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___192 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___192 *);
	void (*pgd_free)(struct mm_struct___192 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___192 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___192 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___192 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___192 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___192 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___192 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___192 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___192 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___192 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___192 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___192 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___188 lock;
	void *vdso;
} mm_context_t___188;

struct xol_area___184;

struct uprobes_state___184 {
	struct xol_area___184 *xol_area;
};

struct vm_area_struct___192;

struct file___185;

struct core_state___187;

struct mm_struct___192 {
	struct vm_area_struct___192 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___192 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___192 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___188 context;
	long unsigned int flags;
	struct core_state___187 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___187 *owner;
	struct file___185 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___184 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___101;

struct exec_domain___45 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___101 *module;
	struct exec_domain___45 *next;
};

struct kset___20;

struct kobj_type___20;

struct kobject___20 {
	const char *name;
	struct list_head entry;
	struct kobject___20 *parent;
	struct kset___20 *kset;
	struct kobj_type___20 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___100 {
	struct kobject___20 kobj;
	struct module___101 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___100;

struct module___101 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___100 mkobj;
	struct module_attribute___100 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___187 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___84 {
	struct task_struct___187 *task;
	struct exec_domain___45 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___187;

struct lruvec___187 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___187 *zone;
};

struct pglist_data___187;

struct zone___187 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___187 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___187 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___187 {
	struct zone___187 *zone;
	int zone_idx;
};

struct zonelist___187 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___187 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___187 {
	struct zone___187 node_zones[4];
	struct zonelist___187 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___187 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___127;

struct x86_io_apic_ops___127 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___127 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___127;

struct irq_data___127 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___127 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___150;

struct dev_pm_ops___150 {
	int (*prepare)(struct device___150 *);
	void (*complete)(struct device___150 *);
	int (*suspend)(struct device___150 *);
	int (*resume)(struct device___150 *);
	int (*freeze)(struct device___150 *);
	int (*thaw)(struct device___150 *);
	int (*poweroff)(struct device___150 *);
	int (*restore)(struct device___150 *);
	int (*suspend_late)(struct device___150 *);
	int (*resume_early)(struct device___150 *);
	int (*freeze_late)(struct device___150 *);
	int (*thaw_early)(struct device___150 *);
	int (*poweroff_late)(struct device___150 *);
	int (*restore_early)(struct device___150 *);
	int (*suspend_noirq)(struct device___150 *);
	int (*resume_noirq)(struct device___150 *);
	int (*freeze_noirq)(struct device___150 *);
	int (*thaw_noirq)(struct device___150 *);
	int (*poweroff_noirq)(struct device___150 *);
	int (*restore_noirq)(struct device___150 *);
	int (*runtime_suspend)(struct device___150 *);
	int (*runtime_resume)(struct device___150 *);
	int (*runtime_idle)(struct device___150 *);
};

struct dev_pm_qos___25;

struct dev_pm_info___25 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___25 *qos;
};

struct dma_map_ops___59;

struct dev_archdata___59 {
	struct dma_map_ops___59 *dma_ops;
	void *iommu;
};

struct device_type___150;

struct bus_type___150;

struct device_driver___150;

struct dev_pm_domain___150;

struct class___150;

struct attribute_group___142;

struct device_rh___150;

struct device___150 {
	struct device___150 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___150 *type;
	struct mutex___188 mutex;
	struct bus_type___150 *bus;
	struct device_driver___150 *driver;
	void *platform_data;
	struct dev_pm_info___25 power;
	struct dev_pm_domain___150 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___59 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___150 *class;
	const struct attribute_group___142 **groups;
	void (*release)(struct device___150 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___150 *device_rh;
};

struct dev_pm_qos_request___25;

struct dev_pm_qos___25 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___25 *latency_req;
	struct dev_pm_qos_request___25 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___25 *latency_tolerance_req;
};

struct dev_pm_info_rh___150 {
	void (*set_latency_tolerance)(struct device___150 *, s32);
};

struct dev_pm_domain___150 {
	struct dev_pm_ops___150 ops;
};

struct smp_ops___187 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___187 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___35;

struct ctl_node___35 {
	struct rb_node node;
	struct ctl_table_header___35 *header;
};

struct ctl_table_root___35;

struct ctl_table_set___35;

struct ctl_dir___35;

struct ctl_table_header___35 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___35 *root;
	struct ctl_table_set___35 *set;
	struct ctl_dir___35 *parent;
	struct ctl_node___35 *node;
};

struct ctl_dir___35 {
	struct ctl_table_header___35 header;
	struct rb_root root;
};

struct ctl_table_set___35 {
	int (*is_seen)(struct ctl_table_set___35 *);
	struct ctl_dir___35 dir;
};

struct ctl_table_root___35 {
	struct ctl_table_set___35 default_set;
	struct ctl_table_set___35 * (*lookup)(struct ctl_table_root___35 *, struct nsproxy___103 *);
	int (*permissions)(struct ctl_table_header___35 *, struct ctl_table *);
};

struct net___34;

struct nsproxy___103 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___34 *net_ns;
};

struct sock___18;

struct kobj_ns_type_operations___17 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___18 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___17;

struct sock_common___17 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___17 *skc_prot;
	struct net___34 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___24;

struct sk_buff_head___22 {
	struct sk_buff___24 *next;
	struct sk_buff___24 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___18;

struct socket_wq___17;

struct dst_entry___17;

struct socket___18;

struct cg_proto___17;

struct sock___18 {
	struct sock_common___17 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___22 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___24 *head;
		struct sk_buff___24 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___18 *sk_filter;
	struct socket_wq___17 *sk_wq;
	struct sk_buff_head___22 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___17 *sk_rx_dst;
	struct dst_entry___17 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___22 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___22 sk_error_queue;
	struct proto___17 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___43 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___18 *sk_socket;
	void *sk_user_data;
	struct page_frag___180 sk_frag;
	struct sk_buff___24 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___17 *sk_cgrp;
	void (*sk_state_change)(struct sock___18 *);
	void (*sk_data_ready)(struct sock___18 *, int);
	void (*sk_write_space)(struct sock___18 *);
	void (*sk_error_report)(struct sock___18 *);
	int (*sk_backlog_rcv)(struct sock___18 *, struct sk_buff___24 *);
	void (*sk_destruct)(struct sock___18 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___144;

struct attribute_group___142 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___144 **bin_attrs;
};

struct bin_attribute___144 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___185 *, struct kobject___20 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___185 *, struct kobject___20 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	int (*mmap)(struct file___185 *, struct kobject___20 *, struct bin_attribute___144 *, struct vm_area_struct___192 *);
};

struct dentry___185;

struct path___185 {
	struct vfsmount *mnt;
	struct dentry___185 *dentry;
};

struct inode___185;

struct file_operations___185;

struct file___185 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___185 f_path;
	struct inode___185 *f_inode;
	const struct file_operations___185 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___185 *f_mapping;
	struct mutex___188 f_pos_lock;
};

struct vm_operations_struct___165;

struct vm_area_struct___192 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___192 *vm_next;
	struct vm_area_struct___192 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___192 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___165 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___185 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___20 {
	ssize_t (*show)(struct kobject___20 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___20 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___20 *, const struct attribute *);
};

struct kset_uevent_ops___20;

struct kset___20 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___20 kobj;
	const struct kset_uevent_ops___20 *uevent_ops;
};

struct kobj_type___20 {
	void (*release)(struct kobject___20 *);
	const struct sysfs_ops___20 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___17 * (*child_ns_type)(struct kobject___20 *);
	const void * (*namespace)(struct kobject___20 *);
};

struct kset_uevent_ops___20 {
	int (* const filter)(struct kset___20 *, struct kobject___20 *);
	const char * (* const name)(struct kset___20 *, struct kobject___20 *);
	int (* const uevent)(struct kset___20 *, struct kobject___20 *, struct kobj_uevent_env *);
};

struct module_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___100 *, struct module_kobject___100 *, char *);
	ssize_t (*store)(struct module_attribute___100 *, struct module_kobject___100 *, const char *, size_t);
	void (*setup)(struct module___101 *, const char *);
	int (*test)(struct module___101 *);
	void (*free)(struct module___101 *);
};

struct dentry_operations___185;

struct super_block___185;

struct dentry___185 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___185 *d_parent;
	struct qstr d_name;
	struct inode___185 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___185 *d_op;
	struct super_block___185 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___185;

struct address_space___185 {
	struct inode___185 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___188 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___185 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___185;

struct file_lock___185;

struct dquot___185;

struct block_device___185;

struct inode___185 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___185 *i_op;
	struct super_block___185 *i_sb;
	struct address_space___185 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___188 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___185 *i_fop;
	struct file_lock___185 *i_flock;
	struct address_space___185 i_data;
	struct dquot___185 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___185 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___185 {
	int (*d_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_hash)(const struct dentry___185 *, struct qstr *);
	int (*d_compare)(const struct dentry___185 *, const struct dentry___185 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___185 *);
	void (*d_release)(struct dentry___185 *);
	void (*d_prune)(struct dentry___185 *);
	void (*d_iput)(struct dentry___185 *, struct inode___185 *);
	char * (*d_dname)(struct dentry___185 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___185 *);
	int (*d_manage)(struct dentry___185 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___185;

struct mem_dqinfo___185 {
	struct quota_format_type___185 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___185;

struct quota_info___185 {
	unsigned int flags;
	struct mutex___188 dqio_mutex;
	struct mutex___188 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___185 *files[2];
	struct mem_dqinfo___185 info[2];
	const struct quota_format_ops___185 *ops[2];
};

struct file_system_type___185;

struct super_operations___185;

struct dquot_operations___185;

struct quotactl_ops___185;

struct xattr_handler___116;

struct super_block___185 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___185 *s_type;
	const struct super_operations___185 *s_op;
	const struct dquot_operations___185 *dq_op;
	const struct quotactl_ops___185 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___185 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___116 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___185 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___185 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___188 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___185 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct kiocb___24;

struct poll_table_struct___109;

struct seq_file___132;

struct file_operations___185 {
	struct module___101 *owner;
	loff_t (*llseek)(struct file___185 *, loff_t, int);
	ssize_t (*read)(struct file___185 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___185 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___24 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___24 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___185 *, void *, filldir_t);
	unsigned int (*poll)(struct file___185 *, struct poll_table_struct___109 *);
	long int (*unlocked_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___185 *, struct vm_area_struct___192 *);
	int (*open)(struct inode___185 *, struct file___185 *);
	int (*flush)(struct file___185 *, fl_owner_t);
	int (*release)(struct inode___185 *, struct file___185 *);
	int (*fsync)(struct file___185 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___24 *, int);
	int (*fasync)(int, struct file___185 *, int);
	int (*lock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*sendpage)(struct file___185 *, struct page___184 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___185 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___185 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___185 *, long int, struct file_lock___185 **, void **);
		struct {
			int (*setlease)(struct file___185 *, long int, struct file_lock___185 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___185 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___132 *, struct file___185 *);
};

struct dma_map_ops___59 {
	void * (*alloc)(struct device___150 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___150 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___150 *, struct vm_area_struct___192 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___150 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___150 *, struct page___184 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___150 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___150 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___150 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___150 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___150 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___150 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___150 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___150 *, dma_addr_t);
	int (*dma_supported)(struct device___150 *, u64);
	int (*set_dma_mask)(struct device___150 *, u64);
	int is_phys;
};

struct bus_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___150 *, char *);
	ssize_t (*store)(struct bus_type___150 *, const char *, size_t);
};

struct device_attribute___150;

struct driver_attribute___150;

struct bus_type___150 {
	const char *name;
	const char *dev_name;
	struct device___150 *dev_root;
	struct bus_attribute___150 *bus_attrs;
	struct device_attribute___150 *dev_attrs;
	struct driver_attribute___150 *drv_attrs;
	const struct attribute_group___142 **bus_groups;
	const struct attribute_group___142 **dev_groups;
	const struct attribute_group___142 **drv_groups;
	int (*match)(struct device___150 *, struct device_driver___150 *);
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	int (*probe)(struct device___150 *);
	int (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*online)(struct device___150 *);
	int (*offline)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct device___150 *, struct device_attribute___150 *, char *);
	ssize_t (*store)(struct device___150 *, struct device_attribute___150 *, const char *, size_t);
};

struct driver_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___150 *, char *);
	ssize_t (*store)(struct device_driver___150 *, const char *, size_t);
};

struct device_driver___150 {
	const char *name;
	struct bus_type___150 *bus;
	struct module___101 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___150 *);
	int (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	const struct attribute_group___142 **groups;
	const struct dev_pm_ops___150 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___150 {
	const char *name;
	const struct attribute_group___142 **groups;
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
};

struct class_attribute___150;

struct class___150 {
	const char *name;
	struct module___101 *owner;
	struct class_attribute___150 *class_attrs;
	struct device_attribute___150 *dev_attrs;
	const struct attribute_group___142 **dev_groups;
	struct bin_attribute___144 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *);
	void (*class_release)(struct class___150 *);
	void (*dev_release)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
	struct subsys_private *p;
};

struct class_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct class___150 *, struct class_attribute___150 *, char *);
	ssize_t (*store)(struct class___150 *, struct class_attribute___150 *, const char *, size_t);
	const void * (*namespace)(struct class___150 *, const struct class_attribute___150 *);
};

struct device_rh___150 {
	struct dev_pm_info_rh___150 power;
};

struct dev_pm_qos_request___25 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___150 *dev;
};

struct xol_area___184 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___184 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___170;

struct memcg_cache_params___171;

struct kmem_cache___171 {
	struct kmem_cache_cpu___170 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___171 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___162;

struct vm_operations_struct___165 {
	void (*open)(struct vm_area_struct___192 *);
	void (*close)(struct vm_area_struct___192 *);
	int (*fault)(struct vm_area_struct___192 *, struct vm_fault___162 *);
	int (*page_mkwrite)(struct vm_area_struct___192 *, struct vm_fault___162 *);
	int (*access)(struct vm_area_struct___192 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___192 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___192 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___192 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___192 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___187 {
	struct task_struct___187 *task;
	struct core_thread___187 *next;
};

struct core_state___187 {
	atomic_t nr_threads;
	struct core_thread___187 dumper;
	struct completion startup;
};

struct vm_fault___162 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___184 *page;
};

struct block_device___185 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___185 *bd_inode;
	struct super_block___185 *bd_super;
	struct mutex___188 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___185 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___188 bd_fsfreeze_mutex;
};

struct cgroup___115;

struct cgroup_subsys_state___115 {
	struct cgroup___115 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___24(struct kiocb___24 *, struct io_event *);

struct kiocb___24 {
	atomic_t ki_users;
	struct file___185 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___24 *ki_cancel;
	void (*ki_dtor)(struct kiocb___24 *);
	union {
		void *user;
		struct task_struct___187 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___185 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___185 *ia_file;
};

struct dquot___185 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___188 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___185 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___185 {
	int qf_fmt_id;
	const struct quota_format_ops___185 *qf_ops;
	struct module___101 *qf_owner;
	struct quota_format_type___185 *qf_next;
};

struct quota_format_ops___185 {
	int (*check_quota_file)(struct super_block___185 *, int);
	int (*read_file_info)(struct super_block___185 *, int);
	int (*write_file_info)(struct super_block___185 *, int);
	int (*free_file_info)(struct super_block___185 *, int);
	int (*read_dqblk)(struct dquot___185 *);
	int (*commit_dqblk)(struct dquot___185 *);
	int (*release_dqblk)(struct dquot___185 *);
};

struct dquot_operations___185 {
	int (*write_dquot)(struct dquot___185 *);
	struct dquot___185 * (*alloc_dquot)(struct super_block___185 *, int);
	void (*destroy_dquot)(struct dquot___185 *);
	int (*acquire_dquot)(struct dquot___185 *);
	int (*release_dquot)(struct dquot___185 *);
	int (*mark_dirty)(struct dquot___185 *);
	int (*write_info)(struct super_block___185 *, int);
	qsize_t * (*get_reserved_space)(struct inode___185 *);
};

struct quotactl_ops___185 {
	int (*quota_on)(struct super_block___185 *, int, int, struct path___185 *);
	int (*quota_on_meta)(struct super_block___185 *, int, int);
	int (*quota_off)(struct super_block___185 *, int);
	int (*quota_sync)(struct super_block___185 *, int);
	int (*get_info)(struct super_block___185 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___185 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___185 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___185 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___185 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___185 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___185 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___185 *, unsigned int);
};

struct address_space_operations___185 {
	int (*writepage)(struct page___184 *, struct writeback_control *);
	int (*readpage)(struct file___185 *, struct page___184 *);
	int (*writepages)(struct address_space___185 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___184 *);
	int (*readpages)(struct file___185 *, struct address_space___185 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___185 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___184 **, void **);
	int (*write_end)(struct file___185 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___184 *, void *);
	sector_t (*bmap)(struct address_space___185 *, sector_t);
	void (*invalidatepage)(struct page___184 *, long unsigned int);
	int (*releasepage)(struct page___184 *, gfp_t);
	void (*freepage)(struct page___184 *);
	ssize_t (*direct_IO)(int, struct kiocb___24 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___185 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___185 *, struct page___184 *, struct page___184 *, enum migrate_mode);
	int (*launder_page)(struct page___184 *);
	int (*is_partially_uptodate)(struct page___184 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___184 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___185 *, struct page___184 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___185 *, sector_t *);
	void (*swap_deactivate)(struct file___185 *);
	void (*invalidatepage_range)(struct page___184 *, unsigned int, unsigned int);
};

struct inode_operations___185 {
	struct dentry___185 * (*lookup)(struct inode___185 *, struct dentry___185 *, unsigned int);
	void * (*follow_link)(struct dentry___185 *, struct nameidata *);
	int (*permission)(struct inode___185 *, int);
	struct posix_acl * (*get_acl)(struct inode___185 *, int);
	int (*readlink)(struct dentry___185 *, char *, int);
	void (*put_link)(struct dentry___185 *, struct nameidata *, void *);
	int (*create)(struct inode___185 *, struct dentry___185 *, umode_t, bool);
	int (*link)(struct dentry___185 *, struct inode___185 *, struct dentry___185 *);
	int (*unlink)(struct inode___185 *, struct dentry___185 *);
	int (*symlink)(struct inode___185 *, struct dentry___185 *, const char *);
	int (*mkdir)(struct inode___185 *, struct dentry___185 *, umode_t);
	int (*rmdir)(struct inode___185 *, struct dentry___185 *);
	int (*mknod)(struct inode___185 *, struct dentry___185 *, umode_t, dev_t);
	int (*rename)(struct inode___185 *, struct dentry___185 *, struct inode___185 *, struct dentry___185 *);
	int (*setattr)(struct dentry___185 *, struct iattr___185 *);
	int (*getattr)(struct vfsmount *, struct dentry___185 *, struct kstat *);
	int (*setxattr)(struct dentry___185 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___185 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___185 *, char *, size_t);
	int (*removexattr)(struct dentry___185 *, const char *);
	int (*fiemap)(struct inode___185 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___185 *, struct timespec *, int);
	int (*atomic_open)(struct inode___185 *, struct dentry___185 *, struct file___185 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___185;

struct file_lock_operations___185;

struct lock_manager_operations___185;

struct file_lock___185 {
	struct file_lock___185 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___185 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___185 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___185 *fl_ops;
	const struct lock_manager_operations___185 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___185 {
	void (*fl_copy_lock)(struct file_lock___185 *, struct file_lock___185 *);
	void (*fl_release_private)(struct file_lock___185 *);
};

struct lock_manager_operations___185 {
	int (*lm_compare_owner)(struct file_lock___185 *, struct file_lock___185 *);
	long unsigned int (*lm_owner_key)(struct file_lock___185 *);
	void (*lm_notify)(struct file_lock___185 *);
	int (*lm_grant)(struct file_lock___185 *, struct file_lock___185 *, int);
	void (*lm_break)(struct file_lock___185 *);
	int (*lm_change)(struct file_lock___185 **, int);
};

struct fasync_struct___185 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___185 *fa_next;
	struct file___185 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___185 {
	const char *name;
	int fs_flags;
	struct dentry___185 * (*mount)(struct file_system_type___185 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___185 *);
	struct module___101 *owner;
	struct file_system_type___185 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___185 {
	struct inode___185 * (*alloc_inode)(struct super_block___185 *);
	void (*destroy_inode)(struct inode___185 *);
	void (*dirty_inode)(struct inode___185 *, int);
	int (*write_inode)(struct inode___185 *, struct writeback_control *);
	int (*drop_inode)(struct inode___185 *);
	void (*evict_inode)(struct inode___185 *);
	void (*put_super)(struct super_block___185 *);
	int (*sync_fs)(struct super_block___185 *, int);
	int (*freeze_fs)(struct super_block___185 *);
	int (*unfreeze_fs)(struct super_block___185 *);
	int (*statfs)(struct dentry___185 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___185 *, int *, char *);
	void (*umount_begin)(struct super_block___185 *);
	int (*show_options)(struct seq_file___132 *, struct dentry___185 *);
	int (*show_devname)(struct seq_file___132 *, struct dentry___185 *);
	int (*show_path)(struct seq_file___132 *, struct dentry___185 *);
	int (*show_stats)(struct seq_file___132 *, struct dentry___185 *);
	ssize_t (*quota_read)(struct super_block___185 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___185 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___185 *);
	int (*bdev_try_to_free_page)(struct super_block___185 *, struct page___184 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___185 *);
	void (*free_cached_objects)(struct super_block___185 *, int);
};

struct xattr_handler___116 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___185 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___185 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___185 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___111)(struct file___185 *, wait_queue_head_t *, struct poll_table_struct___109 *);

struct poll_table_struct___109 {
	poll_queue_proc___111 _qproc;
	long unsigned int _key;
};

struct seq_operations___132;

struct seq_file___132 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___188 lock;
	const struct seq_operations___132 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___187 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___187 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___187 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___188 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___115 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___115 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___17 {
	wait_queue_head_t wait;
	struct fasync_struct___185 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___17;

struct socket___18 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___17 *wq;
	struct file___185 *file;
	struct sock___18 *sk;
	const struct proto_ops___17 *ops;
};

struct proto_ops___17 {
	int family;
	struct module___101 *owner;
	int (*release)(struct socket___18 *);
	int (*bind)(struct socket___18 *, struct sockaddr *, int);
	int (*connect)(struct socket___18 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___18 *, struct socket___18 *);
	int (*accept)(struct socket___18 *, struct socket___18 *, int);
	int (*getname)(struct socket___18 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___185 *, struct socket___18 *, struct poll_table_struct___109 *);
	int (*ioctl)(struct socket___18 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___18 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___18 *, int);
	int (*shutdown)(struct socket___18 *, int);
	int (*setsockopt)(struct socket___18 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___18 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___18 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___18 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___24 *, struct socket___18 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___24 *, struct socket___18 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___185 *, struct socket___18 *, struct vm_area_struct___192 *);
	ssize_t (*sendpage)(struct socket___18 *, struct page___184 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___18 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___18 *, int);
		struct {
			void (*set_peek_off)(struct sock___18 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___32 {
	struct ctl_table_header___35 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___32 {
	struct mutex___188 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___32 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___35 *ctl;
};

struct netns_ipv4___32 {
	struct ctl_table_header___35 *forw_hdr;
	struct ctl_table_header___35 *frags_hdr;
	struct ctl_table_header___35 *ipv4_hdr;
	struct ctl_table_header___35 *route_hdr;
	struct ctl_table_header___35 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___18 *fibnl;
	struct sock___18 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___32 {
	struct ctl_table_header___35 *hdr;
	struct ctl_table_header___35 *route_hdr;
	struct ctl_table_header___35 *icmp_hdr;
	struct ctl_table_header___35 *frags_hdr;
	struct ctl_table_header___35 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___23;

struct neighbour___17;

struct dst_ops___33 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___33 *);
	struct dst_entry___17 * (*check)(struct dst_entry___17 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___17 *);
	unsigned int (*mtu)(const struct dst_entry___17 *);
	u32 * (*cow_metrics)(struct dst_entry___17 *, long unsigned int);
	void (*destroy)(struct dst_entry___17 *);
	void (*ifdown)(struct dst_entry___17 *, struct net_device___23 *, int);
	struct dst_entry___17 * (*negative_advice)(struct dst_entry___17 *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___24 *, u32);
	void (*redirect)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___24 *);
	int (*local_out)(struct sk_buff___24 *);
	struct neighbour___17 * (*neigh_lookup)(const struct dst_entry___17 *, struct sk_buff___24 *, const void *);
	struct kmem_cache___171 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___33 {
	struct netns_sysctl_ipv6___32 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___33 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___18 **icmp_sk;
	struct sock___18 *ndisc_sk;
	struct sock___18 *tcp_sk;
	struct sock___18 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___32 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___35 *sysctl_header;
	struct sock___18 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___17 {
	struct sock___18 *v4_ctl_sk;
	struct sock___18 *v6_ctl_sk;
};

struct netns_nf___32 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___35 *nf_log_dir_header;
};

struct nf_proto_net___32 {
	struct ctl_table_header___35 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___32 {
	struct nf_proto_net___32 pn;
	unsigned int timeout;
};

struct nf_tcp_net___32 {
	struct nf_proto_net___32 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___32 {
	struct nf_proto_net___32 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___32 {
	struct nf_proto_net___32 pn;
	unsigned int timeout;
};

struct nf_ip_net___32 {
	struct nf_generic_net___32 generic;
	struct nf_tcp_net___32 tcp;
	struct nf_udp_net___32 udp;
	struct nf_icmp_net___32 icmp;
	struct nf_icmp_net___32 icmpv6;
};

struct netns_ct___32 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___35 *sysctl_header;
	struct ctl_table_header___35 *acct_sysctl_header;
	struct ctl_table_header___35 *tstamp_sysctl_header;
	struct ctl_table_header___35 *event_sysctl_header;
	struct ctl_table_header___35 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___171 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___32 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___32 {
	struct netns_sysctl_ipv6___32 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___33 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___18 *nlsk;
	struct sock___18 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___35 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___33 xfrm4_dst_ops;
	struct dst_ops___33 xfrm6_dst_ops;
};

struct net___34 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___35 sysctls;
	struct sock___18 *rtnl;
	struct sock___18 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___23 *loopback_dev;
	struct netns_core___32 core;
	struct netns_mib mib;
	struct netns_packet___32 packet;
	struct netns_unix___32 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___32 ipv4;
	struct netns_ipv6___33 ipv6;
	struct netns_sctp___32 sctp;
	struct netns_dccp___17 dccp;
	struct netns_nf___32 nf;
	struct netns_xt xt;
	struct netns_ct___32 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___32 nf_frag;
	struct sock___18 *nfnl;
	struct sock___18 *nfnl_stash;
	struct sk_buff_head___22 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___33 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___18 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___18 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___188 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___188 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___170 {
	void **freelist;
	long unsigned int tid;
	struct page___184 *page;
	struct page___184 *partial;
};

struct memcg_cache_params___171 {
	bool is_root_cache;
	union {
		struct kmem_cache___171 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___171 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___21 {
	atomic_t use;
	unsigned int mask;
	struct net_device___23 *physindev;
	struct net_device___23 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___21(struct sk_buff___24 **);

struct net_device_ops___21;

struct ethtool_ops___21;

struct header_ops___21;

struct inet6_dev___10;

struct netdev_rx_queue___21;

struct netdev_queue___21;

struct rtnl_link_ops___17;

struct dcbnl_rtnl_ops___21;

struct net_device___23 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___21 *netdev_ops;
	const struct ethtool_ops___21 *ethtool_ops;
	const struct header_ops___21 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___20 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___10 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___21 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___21 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___21 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___21 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___21 = 0,
		NETREG_REGISTERED___21 = 1,
		NETREG_UNREGISTERING___21 = 2,
		NETREG_UNREGISTERED___21 = 3,
		NETREG_RELEASED___21 = 4,
		NETREG_DUMMY___21 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___21 = 0,
		RTNL_LINK_INITIALIZING___21 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___23 *);
	struct netpoll_info *npinfo;
	struct net___34 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___150 dev;
	const struct attribute_group___142 *sysfs_groups[4];
	const struct rtnl_link_ops___17 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___21 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___24 {
	struct sk_buff___24 *next;
	struct sk_buff___24 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___18 *sk;
	struct net_device___23 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___24 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___21 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___21 {
	int (*get_settings)(struct net_device___23 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___23 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___23 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___23 *);
	void (*get_regs)(struct net_device___23 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___23 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___23 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___23 *);
	void (*set_msglevel)(struct net_device___23 *, u32);
	int (*nway_reset)(struct net_device___23 *);
	u32 (*get_link)(struct net_device___23 *);
	int (*get_eeprom_len)(struct net_device___23 *);
	int (*get_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___23 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___23 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___23 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___23 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___23 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___23 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___23 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___23 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___23 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___23 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___23 *);
	void (*complete)(struct net_device___23 *);
	u32 (*get_priv_flags)(struct net_device___23 *);
	int (*set_priv_flags)(struct net_device___23 *, u32);
	int (*get_sset_count)(struct net_device___23 *, int);
	int (*get_rxnfc)(struct net_device___23 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___23 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___23 *, struct ethtool_flash *);
	int (*reset)(struct net_device___23 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___23 *);
	int (*get_rxfh_indir)(struct net_device___23 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___23 *, const u32 *);
	void (*get_channels)(struct net_device___23 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___23 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___23 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___23 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___23 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___23 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___23 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___23 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___23 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___23 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___23 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___23 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___17 {
	struct callback_head callback_head;
	struct dst_entry___17 *child;
	struct net_device___23 *dev;
	struct dst_ops___33 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___17 *path;
	struct dst_entry___17 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___24 *);
	union {
		int (*output)(struct sock___18 *, struct sk_buff___24 *);
		struct {
			int (*output)(struct sk_buff___24 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___17 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___17;

struct neigh_parms___17;

struct neigh_ops___17;

struct neighbour___17 {
	struct neighbour___17 *next;
	struct neigh_table___17 *tbl;
	struct neigh_parms___17 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___22 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___17 *, struct sk_buff___24 *);
	const struct neigh_ops___17 *ops;
	struct callback_head rcu;
	struct net_device___23 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___33 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___24 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___24 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___34 *, struct dst_entry___17 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___24 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___24 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___127 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___127 *);
	void (*irq_shutdown)(struct irq_data___127 *);
	void (*irq_enable)(struct irq_data___127 *);
	void (*irq_disable)(struct irq_data___127 *);
	void (*irq_ack)(struct irq_data___127 *);
	void (*irq_mask)(struct irq_data___127 *);
	void (*irq_mask_ack)(struct irq_data___127 *);
	void (*irq_unmask)(struct irq_data___127 *);
	void (*irq_eoi)(struct irq_data___127 *);
	int (*irq_set_affinity)(struct irq_data___127 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___127 *);
	int (*irq_set_type)(struct irq_data___127 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___127 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___127 *);
	void (*irq_bus_sync_unlock)(struct irq_data___127 *);
	void (*irq_cpu_online)(struct irq_data___127 *);
	void (*irq_cpu_offline)(struct irq_data___127 *);
	void (*irq_suspend)(struct irq_data___127 *);
	void (*irq_resume)(struct irq_data___127 *);
	void (*irq_pm_shutdown)(struct irq_data___127 *);
	void (*irq_print_chip)(struct irq_data___127 *, struct seq_file___132 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___127 *, void *);
	long unsigned int flags;
};

struct seq_operations___132 {
	void * (*start)(struct seq_file___132 *, loff_t *);
	void (*stop)(struct seq_file___132 *, void *);
	void * (*next)(struct seq_file___132 *, void *, loff_t *);
	int (*show)(struct seq_file___132 *, void *);
};

struct dcbnl_rtnl_ops___21 {
	int (*ieee_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___23 *);
	u8 (*setstate)(struct net_device___23 *, u8);
	void (*getpermhwaddr)(struct net_device___23 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___23 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___23 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___23 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___23 *, int, u8 *);
	void (*setpfccfg)(struct net_device___23 *, int, u8);
	void (*getpfccfg)(struct net_device___23 *, int, u8 *);
	u8 (*setall)(struct net_device___23 *);
	u8 (*getcap)(struct net_device___23 *, int, u8 *);
	int (*getnumtcs)(struct net_device___23 *, int, u8 *);
	int (*setnumtcs)(struct net_device___23 *, int, u8);
	u8 (*getpfcstate)(struct net_device___23 *);
	void (*setpfcstate)(struct net_device___23 *, u8);
	void (*getbcncfg)(struct net_device___23 *, int, u32 *);
	void (*setbcncfg)(struct net_device___23 *, int, u32);
	void (*getbcnrp)(struct net_device___23 *, int, u8 *);
	void (*setbcnrp)(struct net_device___23 *, int, u8);
	u8 (*setapp)(struct net_device___23 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___23 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___23 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___23 *, int, u8);
	u8 (*getdcbx)(struct net_device___23 *);
	u8 (*setdcbx)(struct net_device___23 *, u8);
	int (*peer_getappinfo)(struct net_device___23 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___23 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___23 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___23 *, struct cee_pfc *);
};

struct cgroupfs_root___115;

struct cgroup___115 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___115 *parent;
	struct dentry___185 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___115 *subsys[11];
	struct cgroupfs_root___115 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___188 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___115 {
	struct super_block___185 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___115 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___61 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___185 *, struct file___185 *);
	ssize_t (*read)(struct cgroup___115 *, struct cftype___61 *, struct file___185 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___115 *, struct cftype___61 *);
	s64 (*read_s64)(struct cgroup___115 *, struct cftype___61 *);
	int (*read_map)(struct cgroup___115 *, struct cftype___61 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___115 *, struct cftype___61 *, struct seq_file___132 *);
	ssize_t (*write)(struct cgroup___115 *, struct cftype___61 *, struct file___185 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___115 *, struct cftype___61 *, u64);
	int (*write_s64)(struct cgroup___115 *, struct cftype___61 *, s64);
	int (*write_string)(struct cgroup___115 *, struct cftype___61 *, const char *);
	int (*trigger)(struct cgroup___115 *, unsigned int);
	int (*release)(struct inode___185 *, struct file___185 *);
	int (*register_event)(struct cgroup___115 *, struct cftype___61 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___115 *, struct cftype___61 *, struct eventfd_ctx *);
};

struct cftype_set___57 {
	struct list_head node;
	struct cftype___61 *cfts;
};

struct task_and_cgroup___57 {
	struct task_struct___187 *task;
	struct cgroup___115 *cgrp;
	struct css_set___115 *cg;
};

struct cgroup_taskset___57 {
	struct task_and_cgroup___57 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___115 *cur_cgrp;
};

struct cgroup_subsys___57 {
	struct cgroup_subsys_state___115 * (*css_alloc)(struct cgroup___115 *);
	int (*css_online)(struct cgroup___115 *);
	void (*css_offline)(struct cgroup___115 *);
	void (*css_free)(struct cgroup___115 *);
	int (*can_attach)(struct cgroup___115 *, struct cgroup_taskset___57 *);
	void (*cancel_attach)(struct cgroup___115 *, struct cgroup_taskset___57 *);
	void (*attach)(struct cgroup___115 *, struct cgroup_taskset___57 *);
	void (*fork)(struct task_struct___187 *);
	void (*exit)(struct cgroup___115 *, struct cgroup___115 *, struct task_struct___187 *);
	void (*bind)(struct cgroup___115 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___115 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___61 *base_cftypes;
	struct cftype_set___57 base_cftset;
	struct module___101 *module;
};

struct request_sock_ops___12;

struct request_sock___13 {
	struct sock_common___17 __req_common;
	struct request_sock___13 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___12 *rsk_ops;
	struct sock___18 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___22 {
	struct sk_buff___24 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___24 *, struct netlink_callback___22 *);
	int (*done)(struct netlink_callback___22 *);
	void *data;
	struct module___101 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___21 {
	int (*create)(struct sk_buff___24 *, struct net_device___23 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___24 *, unsigned char *);
	int (*rebuild)(struct sk_buff___24 *);
	int (*cache)(const struct neighbour___17 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___23 *, const unsigned char *);
};

struct napi_struct___21 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___21 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___23 *dev;
	struct sk_buff___24 *gro_list;
	struct sk_buff___24 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___21 {
	struct net_device___23 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___20 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___21 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___20 kobj;
	struct net_device___23 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___21 {
	int (*ndo_init)(struct net_device___23 *);
	void (*ndo_uninit)(struct net_device___23 *);
	int (*ndo_open)(struct net_device___23 *);
	int (*ndo_stop)(struct net_device___23 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___24 *, struct net_device___23 *);
	u16 (*ndo_select_queue)(struct net_device___23 *, struct sk_buff___24 *);
	void (*ndo_change_rx_flags)(struct net_device___23 *, int);
	void (*ndo_set_rx_mode)(struct net_device___23 *);
	int (*ndo_set_mac_address)(struct net_device___23 *, void *);
	int (*ndo_validate_addr)(struct net_device___23 *);
	int (*ndo_do_ioctl)(struct net_device___23 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___23 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___23 *, int);
	int (*ndo_neigh_setup)(struct net_device___23 *, struct neigh_parms___17 *);
	void (*ndo_tx_timeout)(struct net_device___23 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___23 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___23 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___23 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___23 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___23 *);
	int (*ndo_netpoll_setup)(struct net_device___23 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___23 *);
	int (*ndo_busy_poll)(struct napi_struct___21 *);
	int (*ndo_set_vf_mac)(struct net_device___23 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___23 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___23 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___23 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___23 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___23 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___23 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___23 *, int, struct sk_buff___24 *);
	int (*ndo_setup_tc)(struct net_device___23 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___23 *);
	int (*ndo_fcoe_disable)(struct net_device___23 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___23 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___23 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___23 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___23 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___23 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___23 *, const struct sk_buff___24 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___23 *, struct net_device___23 *);
	int (*ndo_del_slave)(struct net_device___23 *, struct net_device___23 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___17 *);
	void (*ndo_neigh_destroy)(struct neighbour___17 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___24 *, struct netlink_callback___22 *, struct net_device___23 *, int);
	int (*ndo_bridge_setlink)(struct net_device___23 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___24 *, u32, u32, struct net_device___23 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___23 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___23 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___23 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___23 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___23 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___23 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___24 *, struct net_device___23 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___23 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___23 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___23 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___17 {
	struct net___34 *net;
	struct net_device___23 *dev;
	struct neigh_parms___17 *next;
	int (*neigh_setup)(struct neighbour___17 *);
	void (*neigh_cleanup)(struct neighbour___17 *);
	struct neigh_table___17 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___10;

struct ifacaddr6___10;

struct inet6_dev___10 {
	struct net_device___23 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___10 *mc_list;
	struct ifmcaddr6___10 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___17 *nd_parms;
	struct inet6_dev___10 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___17 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___23 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___34 *, struct net_device___23 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___23 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___23 *, struct list_head *);
	size_t (*get_size)(const struct net_device___23 *);
	int (*fill_info)(struct sk_buff___24 *, const struct net_device___23 *);
	size_t (*get_xstats_size)(const struct net_device___23 *);
	int (*fill_xstats)(struct sk_buff___24 *, const struct net_device___23 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___34 * (*get_link_net)(const struct net_device___23 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___23 *, struct net_device___23 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___23 *, const struct net_device___23 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___24 *, const struct net_device___23 *, const struct net_device___23 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___18 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___24 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___17;

struct neigh_hash_table___17;

struct neigh_table___17 {
	struct neigh_table___17 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___23 *, __u32 *);
	int (*constructor)(struct neighbour___17 *);
	int (*pconstructor)(struct pneigh_entry___17 *);
	void (*pdestructor)(struct pneigh_entry___17 *);
	void (*proxy_redo)(struct sk_buff___24 *);
	char *id;
	struct neigh_parms___17 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___22 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___17 *nht;
	struct pneigh_entry___17 **phash_buckets;
};

struct neigh_ops___17 {
	int family;
	void (*solicit)(struct neighbour___17 *, struct sk_buff___24 *);
	void (*error_report)(struct neighbour___17 *, struct sk_buff___24 *);
	int (*output)(struct neighbour___17 *, struct sk_buff___24 *);
	int (*connected_output)(struct neighbour___17 *, struct sk_buff___24 *);
};

struct pneigh_entry___17 {
	struct pneigh_entry___17 *next;
	struct net___34 *net;
	struct net_device___23 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___17 {
	struct neighbour___17 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___10;

struct proto___17 {
	void (*close)(struct sock___18 *, long int);
	int (*connect)(struct sock___18 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___18 *, int);
	struct sock___18 * (*accept)(struct sock___18 *, int, int *);
	int (*ioctl)(struct sock___18 *, int, long unsigned int);
	int (*init)(struct sock___18 *);
	void (*destroy)(struct sock___18 *);
	void (*shutdown)(struct sock___18 *, int);
	int (*setsockopt)(struct sock___18 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___18 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___18 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___18 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___18 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___24 *, struct sock___18 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___24 *, struct sock___18 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___18 *, struct page___184 *, int, size_t, int);
	int (*bind)(struct sock___18 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___18 *, struct sk_buff___24 *);
	void (*release_cb)(struct sock___18 *);
	void (*mtu_reduced)(struct sock___18 *);
	void (*hash)(struct sock___18 *);
	void (*unhash)(struct sock___18 *);
	void (*rehash)(struct sock___18 *);
	int (*get_port)(struct sock___18 *, short unsigned int);
	void (*clear_sk)(struct sock___18 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___18 *);
	void (*enter_memory_pressure)(struct sock___18 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___171 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___12 *rsk_prot;
	struct timewait_sock_ops___10 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___101 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___57 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___17 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___17 {
	void (*enter_memory_pressure)(struct sock___18 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___12 {
	int family;
	int obj_size;
	struct kmem_cache___171 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___18 *, struct request_sock___13 *);
	void (*send_ack)(struct sock___18 *, struct sk_buff___24 *, struct request_sock___13 *);
	void (*send_reset)(struct sock___18 *, struct sk_buff___24 *);
	void (*destructor)(struct request_sock___13 *);
	void (*syn_ack_timeout)(struct sock___18 *, struct request_sock___13 *);
};

struct timewait_sock_ops___10 {
	struct kmem_cache___171 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___18 *, struct sock___18 *, void *);
	void (*twsk_destructor)(struct sock___18 *);
};

struct ifmcaddr6___10 {
	struct in6_addr mca_addr;
	struct inet6_dev___10 *idev;
	struct ifmcaddr6___10 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___10 {
	struct in6_addr aca_addr;
	struct inet6_dev___10 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___10 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

enum format_type {
	FORMAT_TYPE_NONE = 0,
	FORMAT_TYPE_WIDTH = 1,
	FORMAT_TYPE_PRECISION = 2,
	FORMAT_TYPE_CHAR = 3,
	FORMAT_TYPE_STR = 4,
	FORMAT_TYPE_PTR = 5,
	FORMAT_TYPE_PERCENT_CHAR = 6,
	FORMAT_TYPE_INVALID = 7,
	FORMAT_TYPE_LONG_LONG = 8,
	FORMAT_TYPE_ULONG = 9,
	FORMAT_TYPE_LONG = 10,
	FORMAT_TYPE_UBYTE = 11,
	FORMAT_TYPE_BYTE = 12,
	FORMAT_TYPE_USHORT = 13,
	FORMAT_TYPE_SHORT = 14,
	FORMAT_TYPE_UINT = 15,
	FORMAT_TYPE_INT = 16,
	FORMAT_TYPE_NRCHARS = 17,
	FORMAT_TYPE_SIZE_T = 18,
	FORMAT_TYPE_PTRDIFF = 19,
};

struct printf_spec {
	u8 type;
	u8 flags;
	u8 base;
	u8 qualifier;
	s16 field_width;
	s16 precision;
};

enum {
	st_wordstart = 0,
	st_wordcmp = 1,
	st_wordskip = 2,
};

struct rnd_state {
	__u32 s1;
	__u32 s2;
	__u32 s3;
	__u32 s4;
};

enum {
	REG_OP_ISFREE = 0,
	REG_OP_ALLOC = 1,
	REG_OP_RELEASE = 2,
};

typedef struct scatterlist *sg_alloc_fn(unsigned int, gfp_t);

typedef void sg_free_fn(struct scatterlist *, unsigned int);

struct sg_page_iter {
	struct scatterlist *sg;
	unsigned int sg_pgoffset;
	unsigned int __nents;
	int __pg_advance;
};

struct sg_mapping_iter {
	struct page___178 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

typedef struct {
	__u8 b[16];
} uuid_be;

struct flex_array_part {
	char elements[4096];
};

struct percpu_ida_cpu;

struct percpu_ida {
	unsigned int nr_tags;
	unsigned int percpu_max_size;
	unsigned int percpu_batch_size;
	struct percpu_ida_cpu *tag_cpu;
	cpumask_t cpus_have_tags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct {
		spinlock_t lock;
		unsigned int cpu_last_stolen;
		wait_queue_head_t wait;
		unsigned int nr_free;
		unsigned int *freelist;
		long: 64;
		long: 64;
	};
};

struct percpu_ida_cpu {
	spinlock_t lock;
	unsigned int nr_free;
	unsigned int freelist[0];
};

typedef int (*percpu_ida_cb)(unsigned int, void *);

struct fast_hash_ops {
	u32 (*hash)(const void *, u32, u32);
	u32 (*hash2)(const u32 *, u32, u32);
};

struct rhash_head {
	struct rhash_head *next;
};

struct bucket_table {
	size_t size;
	struct rhash_head *buckets[0];
};

typedef u32 (*rht_hashfn_t)(const void *, u32, u32);

typedef u32 (*rht_obj_hashfn_t)(const void *, u32);

struct rhashtable;

struct rhashtable_params {
	size_t nelem_hint;
	size_t key_len;
	size_t key_offset;
	size_t head_offset;
	u32 hash_rnd;
	size_t max_shift;
	size_t min_shift;
	rht_hashfn_t hashfn;
	rht_obj_hashfn_t obj_hashfn;
	bool (*grow_decision)(const struct rhashtable *, size_t);
	bool (*shrink_decision)(const struct rhashtable *, size_t);
	int (*mutex_is_held)();
};

struct rhashtable {
	struct bucket_table *tbl;
	size_t nelems;
	size_t shift;
	struct rhashtable_params p;
};

enum string_size_units {
	STRING_UNITS_10 = 0,
	STRING_UNITS_2 = 1,
};

struct test_fail {
	const char *str;
	unsigned int base;
};

struct test_ull {
	const char *str;
	unsigned int base;
	long long unsigned int expected_res;
};

struct test_ll {
	const char *str;
	unsigned int base;
	long long int expected_res;
};

struct test_u64 {
	const char *str;
	unsigned int base;
	u64 expected_res;
};

struct test_s64 {
	const char *str;
	unsigned int base;
	s64 expected_res;
};

struct test_u32 {
	const char *str;
	unsigned int base;
	u32 expected_res;
};

struct test_s32 {
	const char *str;
	unsigned int base;
	s32 expected_res;
};

struct test_u16 {
	const char *str;
	unsigned int base;
	u16 expected_res;
};

struct test_s16 {
	const char *str;
	unsigned int base;
	s16 expected_res;
};

struct test_u8 {
	const char *str;
	unsigned int base;
	u8 expected_res;
};

struct test_s8 {
	const char *str;
	unsigned int base;
	s8 expected_res;
};

typedef void (*dr_release_t___3)(struct device___150 *, void *);

typedef int (*dr_match_t___3)(struct device___150 *, void *, void *);

struct pcim_iomap_devres {
	void *table[6];
};

struct interval_tree_node {
	struct rb_node rb;
	long unsigned int start;
	long unsigned int last;
	long unsigned int __subtree_last;
};

enum assoc_array_walk_status {
	assoc_array_walk_tree_empty = 0,
	assoc_array_walk_found_terminal_node = 1,
	assoc_array_walk_found_wrong_shortcut = 2,
};

struct assoc_array_walk_result {
	struct {
		struct assoc_array_node *node;
		int level;
		int slot;
	} terminal_node;
	struct {
		struct assoc_array_shortcut *shortcut;
		int level;
		int sc_level;
		long unsigned int sc_segments;
		long unsigned int dissimilarity;
	} wrong_shortcut;
};

struct assoc_array_delete_collapse_context {
	struct assoc_array_node *node;
	const void *skip_leaf;
	int slot;
};

typedef long unsigned int (*genpool_algo_t)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *);

struct gen_pool {
	spinlock_t lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t algo;
	void *data;
};

struct gen_pool_chunk {
	struct list_head next_chunk;
	atomic_t avail;
	phys_addr_t phys_addr;
	long unsigned int start_addr;
	long unsigned int end_addr;
	long unsigned int bits[0];
};

union uu {
	short unsigned int us;
	unsigned char b[2];
};

typedef enum {
	CODES = 0,
	LENS = 1,
	DISTS = 2,
} codetype;

typedef uint64_t vli_type;

enum xz_check {
	XZ_CHECK_NONE = 0,
	XZ_CHECK_CRC32 = 1,
	XZ_CHECK_CRC64 = 4,
	XZ_CHECK_SHA256 = 10,
};

struct xz_dec_hash {
	vli_type unpadded;
	vli_type uncompressed;
	uint32_t crc32;
};

struct xz_dec_lzma2;

struct xz_dec_bcj;

struct xz_dec___2 {
	enum {
		SEQ_STREAM_HEADER = 0,
		SEQ_BLOCK_START = 1,
		SEQ_BLOCK_HEADER = 2,
		SEQ_BLOCK_UNCOMPRESS = 3,
		SEQ_BLOCK_PADDING = 4,
		SEQ_BLOCK_CHECK = 5,
		SEQ_INDEX = 6,
		SEQ_INDEX_PADDING = 7,
		SEQ_INDEX_CRC32 = 8,
		SEQ_STREAM_FOOTER = 9,
	} sequence;
	uint32_t pos;
	vli_type vli;
	size_t in_start;
	size_t out_start;
	uint32_t crc32;
	enum xz_check check_type;
	enum xz_mode mode;
	bool allow_buf_error;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		uint32_t size;
	} block_header;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		vli_type count;
		struct xz_dec_hash hash;
	} block;
	struct {
		enum {
			SEQ_INDEX_COUNT = 0,
			SEQ_INDEX_UNPADDED = 1,
			SEQ_INDEX_UNCOMPRESSED = 2,
		} sequence;
		vli_type size;
		vli_type count;
		struct xz_dec_hash hash;
	} index;
	struct {
		size_t pos;
		size_t size;
		uint8_t buf[1024];
	} temp;
	struct xz_dec_lzma2 *lzma2;
	struct xz_dec_bcj *bcj;
	bool bcj_active;
};

enum lzma_state {
	STATE_LIT_LIT = 0,
	STATE_MATCH_LIT_LIT = 1,
	STATE_REP_LIT_LIT = 2,
	STATE_SHORTREP_LIT_LIT = 3,
	STATE_MATCH_LIT = 4,
	STATE_REP_LIT = 5,
	STATE_SHORTREP_LIT = 6,
	STATE_LIT_MATCH = 7,
	STATE_LIT_LONGREP = 8,
	STATE_LIT_SHORTREP = 9,
	STATE_NONLIT_MATCH = 10,
	STATE_NONLIT_REP = 11,
};

struct dictionary {
	uint8_t *buf;
	size_t start;
	size_t pos;
	size_t full;
	size_t limit;
	size_t end;
	uint32_t size;
	uint32_t size_max;
	uint32_t allocated;
	enum xz_mode mode;
};

struct rc_dec {
	uint32_t range;
	uint32_t code;
	uint32_t init_bytes_left;
	const uint8_t *in;
	size_t in_pos;
	size_t in_limit;
};

struct lzma_len_dec {
	uint16_t choice;
	uint16_t choice2;
	uint16_t low[128];
	uint16_t mid[128];
	uint16_t high[256];
};

struct lzma_dec {
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
	enum lzma_state state;
	uint32_t len;
	uint32_t lc;
	uint32_t literal_pos_mask;
	uint32_t pos_mask;
	uint16_t is_match[192];
	uint16_t is_rep[12];
	uint16_t is_rep0[12];
	uint16_t is_rep1[12];
	uint16_t is_rep2[12];
	uint16_t is_rep0_long[192];
	uint16_t dist_slot[256];
	uint16_t dist_special[114];
	uint16_t dist_align[16];
	struct lzma_len_dec match_len_dec;
	struct lzma_len_dec rep_len_dec;
	uint16_t literal[12288];
};

enum lzma2_seq {
	SEQ_CONTROL = 0,
	SEQ_UNCOMPRESSED_1 = 1,
	SEQ_UNCOMPRESSED_2 = 2,
	SEQ_COMPRESSED_0 = 3,
	SEQ_COMPRESSED_1 = 4,
	SEQ_PROPERTIES = 5,
	SEQ_LZMA_PREPARE = 6,
	SEQ_LZMA_RUN = 7,
	SEQ_COPY = 8,
};

struct lzma2_dec {
	enum lzma2_seq sequence;
	enum lzma2_seq next_sequence;
	uint32_t uncompressed;
	uint32_t compressed;
	bool need_dict_reset;
	bool need_props;
};

struct xz_dec_lzma2___2 {
	struct rc_dec rc;
	struct dictionary dict;
	struct lzma2_dec lzma2;
	struct lzma_dec lzma;
	struct {
		uint32_t size;
		uint8_t buf[63];
	} temp;
};

struct xz_dec_bcj___2 {
	enum {
		BCJ_X86 = 4,
		BCJ_POWERPC = 5,
		BCJ_IA64 = 6,
		BCJ_ARM = 7,
		BCJ_ARMTHUMB = 8,
		BCJ_SPARC = 9,
	} type;
	enum xz_ret ret;
	bool single_call;
	uint32_t pos;
	uint32_t x86_prev_mask;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
	struct {
		size_t filtered;
		size_t size;
		uint8_t buf[16];
	} temp;
};

struct ts_state {
	unsigned int offset;
	char cb[40];
};

struct ts_config;

struct ts_ops {
	const char *name;
	struct ts_config * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config *, struct ts_state *);
	void (*destroy)(struct ts_config *);
	void * (*get_pattern)(struct ts_config *);
	unsigned int (*get_pattern_len)(struct ts_config *);
	struct module___101 *owner;
	struct list_head list;
};

struct ts_config {
	struct ts_ops *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config *, struct ts_state *);
	void (*finish)(struct ts_config *, struct ts_state *);
};

struct ts_linear_state {
	unsigned int len;
	const void *data;
};

enum dma_sync_target {
	SYNC_FOR_CPU = 0,
	SYNC_FOR_DEVICE = 1,
};

struct page___185;

typedef struct page___185 *pgtable_t___185;

struct address_space___186;

struct kmem_cache___172;

struct page___185 {
	long unsigned int flags;
	struct address_space___186 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___185 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___185 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___172 *slab_cache;
		struct page___185 *first_page;
	};
	long: 64;
};

struct task_struct___188;

struct pv_cpu_ops___188 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___188 *);
	void (*end_context_switch)(struct task_struct___188 *);
};

struct mutex___189 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___188 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___181 {
	struct page___185 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___193;

struct nsproxy___104;

struct signal_struct___188;

struct css_set___116;

struct task_struct___188 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___188 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___193 *mm;
	struct mm_struct___193 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___188 *real_parent;
	struct task_struct___188 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___188 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___188 = 0,
		VTIME_USER___188 = 1,
		VTIME_SYS___188 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___104 *nsproxy;
	struct signal_struct___188 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___116 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___189 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___181 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___193 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___193 *, struct mm_struct___193 *);
	void (*dup_mmap)(struct mm_struct___193 *, struct mm_struct___193 *);
	void (*exit_mmap)(struct mm_struct___193 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___193 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___193 *);
	void (*pgd_free)(struct mm_struct___193 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___193 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___193 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___193 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___193 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___193 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___193 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___193 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___193 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___193 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___193 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___193 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___189 lock;
	void *vdso;
} mm_context_t___189;

struct xol_area___185;

struct uprobes_state___185 {
	struct xol_area___185 *xol_area;
};

struct vm_area_struct___193;

struct file___186;

struct core_state___188;

struct mm_struct___193 {
	struct vm_area_struct___193 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___193 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___193 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___189 context;
	long unsigned int flags;
	struct core_state___188 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___188 *owner;
	struct file___186 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___185 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___102;

struct exec_domain___46 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___102 *module;
	struct exec_domain___46 *next;
};

struct module_kobject___101 {
	struct kobject___20 kobj;
	struct module___102 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___101;

struct module___102 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___101 mkobj;
	struct module_attribute___101 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___188 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___85 {
	struct task_struct___188 *task;
	struct exec_domain___46 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___188;

struct lruvec___188 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___188 *zone;
};

struct pglist_data___188;

struct zone___188 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___188 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___188 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___188 {
	struct zone___188 *zone;
	int zone_idx;
};

struct zonelist___188 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___188 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___188 {
	struct zone___188 node_zones[4];
	struct zonelist___188 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___188 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___128;

struct x86_io_apic_ops___128 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___128 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___128;

struct irq_data___128 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___128 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___151;

struct dev_pm_ops___151 {
	int (*prepare)(struct device___151 *);
	void (*complete)(struct device___151 *);
	int (*suspend)(struct device___151 *);
	int (*resume)(struct device___151 *);
	int (*freeze)(struct device___151 *);
	int (*thaw)(struct device___151 *);
	int (*poweroff)(struct device___151 *);
	int (*restore)(struct device___151 *);
	int (*suspend_late)(struct device___151 *);
	int (*resume_early)(struct device___151 *);
	int (*freeze_late)(struct device___151 *);
	int (*thaw_early)(struct device___151 *);
	int (*poweroff_late)(struct device___151 *);
	int (*restore_early)(struct device___151 *);
	int (*suspend_noirq)(struct device___151 *);
	int (*resume_noirq)(struct device___151 *);
	int (*freeze_noirq)(struct device___151 *);
	int (*thaw_noirq)(struct device___151 *);
	int (*poweroff_noirq)(struct device___151 *);
	int (*restore_noirq)(struct device___151 *);
	int (*runtime_suspend)(struct device___151 *);
	int (*runtime_resume)(struct device___151 *);
	int (*runtime_idle)(struct device___151 *);
};

struct dev_pm_qos___26;

struct dev_pm_info___26 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___26 *qos;
};

struct dma_map_ops___60;

struct dev_archdata___60 {
	struct dma_map_ops___60 *dma_ops;
	void *iommu;
};

struct device_type___151;

struct bus_type___151;

struct device_driver___151;

struct dev_pm_domain___151;

struct class___151;

struct attribute_group___143;

struct device_rh___151;

struct device___151 {
	struct device___151 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___151 *type;
	struct mutex___189 mutex;
	struct bus_type___151 *bus;
	struct device_driver___151 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___151 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___60 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___151 *class;
	const struct attribute_group___143 **groups;
	void (*release)(struct device___151 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___151 *device_rh;
};

struct dev_pm_qos_request___26;

struct dev_pm_qos___26 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___26 *latency_req;
	struct dev_pm_qos_request___26 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___26 *latency_tolerance_req;
};

struct dev_pm_info_rh___151 {
	void (*set_latency_tolerance)(struct device___151 *, s32);
};

struct dev_pm_domain___151 {
	struct dev_pm_ops___151 ops;
};

struct smp_ops___188 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___188 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___36;

struct ctl_node___36 {
	struct rb_node node;
	struct ctl_table_header___36 *header;
};

struct ctl_table_root___36;

struct ctl_table_set___36;

struct ctl_dir___36;

struct ctl_table_header___36 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___36 *root;
	struct ctl_table_set___36 *set;
	struct ctl_dir___36 *parent;
	struct ctl_node___36 *node;
};

struct ctl_dir___36 {
	struct ctl_table_header___36 header;
	struct rb_root root;
};

struct ctl_table_set___36 {
	int (*is_seen)(struct ctl_table_set___36 *);
	struct ctl_dir___36 dir;
};

struct ctl_table_root___36 {
	struct ctl_table_set___36 default_set;
	struct ctl_table_set___36 * (*lookup)(struct ctl_table_root___36 *, struct nsproxy___104 *);
	int (*permissions)(struct ctl_table_header___36 *, struct ctl_table *);
};

struct net___35;

struct nsproxy___104 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___35 *net_ns;
};

struct bin_attribute___145;

struct attribute_group___143 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___145 **bin_attrs;
};

struct bin_attribute___145 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___186 *, struct kobject___20 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___186 *, struct kobject___20 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	int (*mmap)(struct file___186 *, struct kobject___20 *, struct bin_attribute___145 *, struct vm_area_struct___193 *);
};

struct dentry___186;

struct path___186 {
	struct vfsmount *mnt;
	struct dentry___186 *dentry;
};

struct inode___186;

struct file_operations___186;

struct file___186 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___186 f_path;
	struct inode___186 *f_inode;
	const struct file_operations___186 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___186 *f_mapping;
	struct mutex___189 f_pos_lock;
};

struct vm_operations_struct___166;

struct vm_area_struct___193 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___193 *vm_next;
	struct vm_area_struct___193 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___193 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___166 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___186 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___101 *, struct module_kobject___101 *, char *);
	ssize_t (*store)(struct module_attribute___101 *, struct module_kobject___101 *, const char *, size_t);
	void (*setup)(struct module___102 *, const char *);
	int (*test)(struct module___102 *);
	void (*free)(struct module___102 *);
};

struct dentry_operations___186;

struct super_block___186;

struct dentry___186 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___186 *d_parent;
	struct qstr d_name;
	struct inode___186 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___186 *d_op;
	struct super_block___186 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___186;

struct address_space___186 {
	struct inode___186 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___189 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___186 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___186;

struct file_lock___186;

struct dquot___186;

struct block_device___186;

struct inode___186 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___186 *i_op;
	struct super_block___186 *i_sb;
	struct address_space___186 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___189 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___186 *i_fop;
	struct file_lock___186 *i_flock;
	struct address_space___186 i_data;
	struct dquot___186 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___186 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___186 {
	int (*d_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_hash)(const struct dentry___186 *, struct qstr *);
	int (*d_compare)(const struct dentry___186 *, const struct dentry___186 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___186 *);
	void (*d_release)(struct dentry___186 *);
	void (*d_prune)(struct dentry___186 *);
	void (*d_iput)(struct dentry___186 *, struct inode___186 *);
	char * (*d_dname)(struct dentry___186 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___186 *);
	int (*d_manage)(struct dentry___186 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___186;

struct mem_dqinfo___186 {
	struct quota_format_type___186 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___186;

struct quota_info___186 {
	unsigned int flags;
	struct mutex___189 dqio_mutex;
	struct mutex___189 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___186 *files[2];
	struct mem_dqinfo___186 info[2];
	const struct quota_format_ops___186 *ops[2];
};

struct file_system_type___186;

struct super_operations___186;

struct dquot_operations___186;

struct quotactl_ops___186;

struct xattr_handler___117;

struct super_block___186 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___186 *s_type;
	const struct super_operations___186 *s_op;
	const struct dquot_operations___186 *dq_op;
	const struct quotactl_ops___186 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___186 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___117 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___186 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___186 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___189 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___186 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___186 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___186 *bd_inode;
	struct super_block___186 *bd_super;
	struct mutex___189 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___186 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___189 bd_fsfreeze_mutex;
};

struct cgroup___116;

struct cgroup_subsys_state___116 {
	struct cgroup___116 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___186 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___186 *ia_file;
};

struct dquot___186 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___189 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___186 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___186 {
	int qf_fmt_id;
	const struct quota_format_ops___186 *qf_ops;
	struct module___102 *qf_owner;
	struct quota_format_type___186 *qf_next;
};

struct quota_format_ops___186 {
	int (*check_quota_file)(struct super_block___186 *, int);
	int (*read_file_info)(struct super_block___186 *, int);
	int (*write_file_info)(struct super_block___186 *, int);
	int (*free_file_info)(struct super_block___186 *, int);
	int (*read_dqblk)(struct dquot___186 *);
	int (*commit_dqblk)(struct dquot___186 *);
	int (*release_dqblk)(struct dquot___186 *);
};

struct dquot_operations___186 {
	int (*write_dquot)(struct dquot___186 *);
	struct dquot___186 * (*alloc_dquot)(struct super_block___186 *, int);
	void (*destroy_dquot)(struct dquot___186 *);
	int (*acquire_dquot)(struct dquot___186 *);
	int (*release_dquot)(struct dquot___186 *);
	int (*mark_dirty)(struct dquot___186 *);
	int (*write_info)(struct super_block___186 *, int);
	qsize_t * (*get_reserved_space)(struct inode___186 *);
};

struct quotactl_ops___186 {
	int (*quota_on)(struct super_block___186 *, int, int, struct path___186 *);
	int (*quota_on_meta)(struct super_block___186 *, int, int);
	int (*quota_off)(struct super_block___186 *, int);
	int (*quota_sync)(struct super_block___186 *, int);
	int (*get_info)(struct super_block___186 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___186 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___186 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___186 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___186 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___186 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___186 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___186 *, unsigned int);
};

struct address_space_operations___186 {
	int (*writepage)(struct page___185 *, struct writeback_control *);
	int (*readpage)(struct file___186 *, struct page___185 *);
	int (*writepages)(struct address_space___186 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___185 *);
	int (*readpages)(struct file___186 *, struct address_space___186 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___186 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___185 **, void **);
	int (*write_end)(struct file___186 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___185 *, void *);
	sector_t (*bmap)(struct address_space___186 *, sector_t);
	void (*invalidatepage)(struct page___185 *, long unsigned int);
	int (*releasepage)(struct page___185 *, gfp_t);
	void (*freepage)(struct page___185 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___186 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___186 *, struct page___185 *, struct page___185 *, enum migrate_mode);
	int (*launder_page)(struct page___185 *);
	int (*is_partially_uptodate)(struct page___185 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___185 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___186 *, struct page___185 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___186 *, sector_t *);
	void (*swap_deactivate)(struct file___186 *);
	void (*invalidatepage_range)(struct page___185 *, unsigned int, unsigned int);
};

struct inode_operations___186 {
	struct dentry___186 * (*lookup)(struct inode___186 *, struct dentry___186 *, unsigned int);
	void * (*follow_link)(struct dentry___186 *, struct nameidata *);
	int (*permission)(struct inode___186 *, int);
	struct posix_acl * (*get_acl)(struct inode___186 *, int);
	int (*readlink)(struct dentry___186 *, char *, int);
	void (*put_link)(struct dentry___186 *, struct nameidata *, void *);
	int (*create)(struct inode___186 *, struct dentry___186 *, umode_t, bool);
	int (*link)(struct dentry___186 *, struct inode___186 *, struct dentry___186 *);
	int (*unlink)(struct inode___186 *, struct dentry___186 *);
	int (*symlink)(struct inode___186 *, struct dentry___186 *, const char *);
	int (*mkdir)(struct inode___186 *, struct dentry___186 *, umode_t);
	int (*rmdir)(struct inode___186 *, struct dentry___186 *);
	int (*mknod)(struct inode___186 *, struct dentry___186 *, umode_t, dev_t);
	int (*rename)(struct inode___186 *, struct dentry___186 *, struct inode___186 *, struct dentry___186 *);
	int (*setattr)(struct dentry___186 *, struct iattr___186 *);
	int (*getattr)(struct vfsmount *, struct dentry___186 *, struct kstat *);
	int (*setxattr)(struct dentry___186 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___186 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___186 *, char *, size_t);
	int (*removexattr)(struct dentry___186 *, const char *);
	int (*fiemap)(struct inode___186 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___186 *, struct timespec *, int);
	int (*atomic_open)(struct inode___186 *, struct dentry___186 *, struct file___186 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___133;

struct file_operations___186 {
	struct module___102 *owner;
	loff_t (*llseek)(struct file___186 *, loff_t, int);
	ssize_t (*read)(struct file___186 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___186 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___186 *, void *, filldir_t);
	unsigned int (*poll)(struct file___186 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___186 *, struct vm_area_struct___193 *);
	int (*open)(struct inode___186 *, struct file___186 *);
	int (*flush)(struct file___186 *, fl_owner_t);
	int (*release)(struct inode___186 *, struct file___186 *);
	int (*fsync)(struct file___186 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___186 *, int);
	int (*lock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*sendpage)(struct file___186 *, struct page___185 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___186 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___186 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___186 *, long int, struct file_lock___186 **, void **);
		struct {
			int (*setlease)(struct file___186 *, long int, struct file_lock___186 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___186 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___133 *, struct file___186 *);
};

struct fasync_struct___186;

struct file_lock_operations___186;

struct lock_manager_operations___186;

struct file_lock___186 {
	struct file_lock___186 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___186 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___186 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___186 *fl_ops;
	const struct lock_manager_operations___186 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___186 {
	void (*fl_copy_lock)(struct file_lock___186 *, struct file_lock___186 *);
	void (*fl_release_private)(struct file_lock___186 *);
};

struct lock_manager_operations___186 {
	int (*lm_compare_owner)(struct file_lock___186 *, struct file_lock___186 *);
	long unsigned int (*lm_owner_key)(struct file_lock___186 *);
	void (*lm_notify)(struct file_lock___186 *);
	int (*lm_grant)(struct file_lock___186 *, struct file_lock___186 *, int);
	void (*lm_break)(struct file_lock___186 *);
	int (*lm_change)(struct file_lock___186 **, int);
};

struct fasync_struct___186 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___186 *fa_next;
	struct file___186 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___186 {
	const char *name;
	int fs_flags;
	struct dentry___186 * (*mount)(struct file_system_type___186 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___186 *);
	struct module___102 *owner;
	struct file_system_type___186 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___186 {
	struct inode___186 * (*alloc_inode)(struct super_block___186 *);
	void (*destroy_inode)(struct inode___186 *);
	void (*dirty_inode)(struct inode___186 *, int);
	int (*write_inode)(struct inode___186 *, struct writeback_control *);
	int (*drop_inode)(struct inode___186 *);
	void (*evict_inode)(struct inode___186 *);
	void (*put_super)(struct super_block___186 *);
	int (*sync_fs)(struct super_block___186 *, int);
	int (*freeze_fs)(struct super_block___186 *);
	int (*unfreeze_fs)(struct super_block___186 *);
	int (*statfs)(struct dentry___186 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___186 *, int *, char *);
	void (*umount_begin)(struct super_block___186 *);
	int (*show_options)(struct seq_file___133 *, struct dentry___186 *);
	int (*show_devname)(struct seq_file___133 *, struct dentry___186 *);
	int (*show_path)(struct seq_file___133 *, struct dentry___186 *);
	int (*show_stats)(struct seq_file___133 *, struct dentry___186 *);
	ssize_t (*quota_read)(struct super_block___186 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___186 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___186 *);
	int (*bdev_try_to_free_page)(struct super_block___186 *, struct page___185 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___186 *);
	void (*free_cached_objects)(struct super_block___186 *, int);
};

struct xattr_handler___117 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___186 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___186 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___186 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___133;

struct seq_file___133 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___189 lock;
	const struct seq_operations___133 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___133 {
	void * (*start)(struct seq_file___133 *, loff_t *);
	void (*stop)(struct seq_file___133 *, void *);
	void * (*next)(struct seq_file___133 *, void *, loff_t *);
	int (*show)(struct seq_file___133 *, void *);
};

struct kmem_cache_cpu___171 {
	void **freelist;
	long unsigned int tid;
	struct page___185 *page;
	struct page___185 *partial;
};

struct memcg_cache_params___172;

struct kmem_cache___172 {
	struct kmem_cache_cpu___171 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___172 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___172 {
	bool is_root_cache;
	union {
		struct kmem_cache___172 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___172 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct irq_chip___128 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___128 *);
	void (*irq_shutdown)(struct irq_data___128 *);
	void (*irq_enable)(struct irq_data___128 *);
	void (*irq_disable)(struct irq_data___128 *);
	void (*irq_ack)(struct irq_data___128 *);
	void (*irq_mask)(struct irq_data___128 *);
	void (*irq_mask_ack)(struct irq_data___128 *);
	void (*irq_unmask)(struct irq_data___128 *);
	void (*irq_eoi)(struct irq_data___128 *);
	int (*irq_set_affinity)(struct irq_data___128 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___128 *);
	int (*irq_set_type)(struct irq_data___128 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___128 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___128 *);
	void (*irq_bus_sync_unlock)(struct irq_data___128 *);
	void (*irq_cpu_online)(struct irq_data___128 *);
	void (*irq_cpu_offline)(struct irq_data___128 *);
	void (*irq_suspend)(struct irq_data___128 *);
	void (*irq_resume)(struct irq_data___128 *);
	void (*irq_pm_shutdown)(struct irq_data___128 *);
	void (*irq_print_chip)(struct irq_data___128 *, struct seq_file___133 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___128 *, void *);
	long unsigned int flags;
};

struct xol_area___185 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___185 *page;
	long unsigned int vaddr;
};

struct vm_fault___163;

struct vm_operations_struct___166 {
	void (*open)(struct vm_area_struct___193 *);
	void (*close)(struct vm_area_struct___193 *);
	int (*fault)(struct vm_area_struct___193 *, struct vm_fault___163 *);
	int (*page_mkwrite)(struct vm_area_struct___193 *, struct vm_fault___163 *);
	int (*access)(struct vm_area_struct___193 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___193 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___193 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___193 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___193 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___188 {
	struct task_struct___188 *task;
	struct core_thread___188 *next;
};

struct core_state___188 {
	atomic_t nr_threads;
	struct core_thread___188 dumper;
	struct completion startup;
};

struct signal_struct___188 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___188 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___188 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___189 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___116 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___116 *subsys[11];
	struct callback_head callback_head;
};

struct dma_map_ops___60 {
	void * (*alloc)(struct device___151 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___151 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___151 *, struct vm_area_struct___193 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___151 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___151 *, struct page___185 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___151 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___151 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___151 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___151 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___151 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___151 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___151 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___151 *, dma_addr_t);
	int (*dma_supported)(struct device___151 *, u64);
	int (*set_dma_mask)(struct device___151 *, u64);
	int is_phys;
};

struct bus_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___151 *, char *);
	ssize_t (*store)(struct bus_type___151 *, const char *, size_t);
};

struct device_attribute___151;

struct driver_attribute___151;

struct bus_type___151 {
	const char *name;
	const char *dev_name;
	struct device___151 *dev_root;
	struct bus_attribute___151 *bus_attrs;
	struct device_attribute___151 *dev_attrs;
	struct driver_attribute___151 *drv_attrs;
	const struct attribute_group___143 **bus_groups;
	const struct attribute_group___143 **dev_groups;
	const struct attribute_group___143 **drv_groups;
	int (*match)(struct device___151 *, struct device_driver___151 *);
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	int (*probe)(struct device___151 *);
	int (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*online)(struct device___151 *);
	int (*offline)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct device___151 *, struct device_attribute___151 *, char *);
	ssize_t (*store)(struct device___151 *, struct device_attribute___151 *, const char *, size_t);
};

struct driver_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___151 *, char *);
	ssize_t (*store)(struct device_driver___151 *, const char *, size_t);
};

struct device_driver___151 {
	const char *name;
	struct bus_type___151 *bus;
	struct module___102 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___151 *);
	int (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	const struct attribute_group___143 **groups;
	const struct dev_pm_ops___151 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___151 {
	const char *name;
	const struct attribute_group___143 **groups;
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
};

struct class_attribute___151;

struct class___151 {
	const char *name;
	struct module___102 *owner;
	struct class_attribute___151 *class_attrs;
	struct device_attribute___151 *dev_attrs;
	const struct attribute_group___143 **dev_groups;
	struct bin_attribute___145 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *);
	void (*class_release)(struct class___151 *);
	void (*dev_release)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
	struct subsys_private *p;
};

struct class_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct class___151 *, struct class_attribute___151 *, char *);
	ssize_t (*store)(struct class___151 *, struct class_attribute___151 *, const char *, size_t);
	const void * (*namespace)(struct class___151 *, const struct class_attribute___151 *);
};

struct device_rh___151 {
	struct dev_pm_info_rh___151 power;
};

struct dev_pm_qos_request___26 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___151 *dev;
};

struct vm_fault___163 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___185 *page;
};

struct netns_core___33 {
	struct ctl_table_header___36 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___33 {
	struct mutex___189 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___33 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___36 *ctl;
};

struct netns_ipv4___33 {
	struct ctl_table_header___36 *forw_hdr;
	struct ctl_table_header___36 *frags_hdr;
	struct ctl_table_header___36 *ipv4_hdr;
	struct ctl_table_header___36 *route_hdr;
	struct ctl_table_header___36 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___33 {
	struct ctl_table_header___36 *hdr;
	struct ctl_table_header___36 *route_hdr;
	struct ctl_table_header___36 *icmp_hdr;
	struct ctl_table_header___36 *frags_hdr;
	struct ctl_table_header___36 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___24;

struct sk_buff___25;

struct dst_ops___34 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___34 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___24 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___25 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___25 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___25 *);
	int (*local_out)(struct sk_buff___25 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___25 *, const void *);
	struct kmem_cache___172 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___34 {
	struct netns_sysctl_ipv6___33 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___34 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___33 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___36 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___33 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___36 *nf_log_dir_header;
};

struct nf_proto_net___33 {
	struct ctl_table_header___36 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___33 {
	struct nf_proto_net___33 pn;
	unsigned int timeout;
};

struct nf_tcp_net___33 {
	struct nf_proto_net___33 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___33 {
	struct nf_proto_net___33 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___33 {
	struct nf_proto_net___33 pn;
	unsigned int timeout;
};

struct nf_ip_net___33 {
	struct nf_generic_net___33 generic;
	struct nf_tcp_net___33 tcp;
	struct nf_udp_net___33 udp;
	struct nf_icmp_net___33 icmp;
	struct nf_icmp_net___33 icmpv6;
};

struct netns_ct___33 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___36 *sysctl_header;
	struct ctl_table_header___36 *acct_sysctl_header;
	struct ctl_table_header___36 *tstamp_sysctl_header;
	struct ctl_table_header___36 *event_sysctl_header;
	struct ctl_table_header___36 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___172 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___33 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___33 {
	struct netns_sysctl_ipv6___33 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___23 {
	struct sk_buff___25 *next;
	struct sk_buff___25 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___34 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___36 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___34 xfrm4_dst_ops;
	struct dst_ops___34 xfrm6_dst_ops;
};

struct net___35 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___36 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___24 *loopback_dev;
	struct netns_core___33 core;
	struct netns_mib mib;
	struct netns_packet___33 packet;
	struct netns_unix___33 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___33 ipv4;
	struct netns_ipv6___34 ipv6;
	struct netns_sctp___33 sctp;
	struct netns_dccp___17 dccp;
	struct netns_nf___33 nf;
	struct netns_xt xt;
	struct netns_ct___33 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___33 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___23 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___34 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___189 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___189 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___22 {
	atomic_t use;
	unsigned int mask;
	struct net_device___24 *physindev;
	struct net_device___24 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___22(struct sk_buff___25 **);

struct net_device_ops___22;

struct ethtool_ops___22;

struct header_ops___22;

struct netdev_rx_queue___22;

struct netdev_queue___22;

struct dcbnl_rtnl_ops___22;

struct net_device___24 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___22 *netdev_ops;
	const struct ethtool_ops___22 *ethtool_ops;
	const struct header_ops___22 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___20 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___22 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___22 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___22 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___22 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___22 = 0,
		NETREG_REGISTERED___22 = 1,
		NETREG_UNREGISTERING___22 = 2,
		NETREG_UNREGISTERED___22 = 3,
		NETREG_RELEASED___22 = 4,
		NETREG_DUMMY___22 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___22 = 0,
		RTNL_LINK_INITIALIZING___22 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___24 *);
	struct netpoll_info *npinfo;
	struct net___35 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___151 dev;
	const struct attribute_group___143 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___22 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___25 {
	struct sk_buff___25 *next;
	struct sk_buff___25 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___24 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___25 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___22 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___22 {
	int (*get_settings)(struct net_device___24 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___24 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___24 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___24 *);
	void (*get_regs)(struct net_device___24 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___24 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___24 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___24 *);
	void (*set_msglevel)(struct net_device___24 *, u32);
	int (*nway_reset)(struct net_device___24 *);
	u32 (*get_link)(struct net_device___24 *);
	int (*get_eeprom_len)(struct net_device___24 *);
	int (*get_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___24 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___24 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___24 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___24 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___24 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___24 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___24 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___24 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___24 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___24 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___24 *);
	void (*complete)(struct net_device___24 *);
	u32 (*get_priv_flags)(struct net_device___24 *);
	int (*set_priv_flags)(struct net_device___24 *, u32);
	int (*get_sset_count)(struct net_device___24 *, int);
	int (*get_rxnfc)(struct net_device___24 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___24 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___24 *, struct ethtool_flash *);
	int (*reset)(struct net_device___24 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___24 *);
	int (*get_rxfh_indir)(struct net_device___24 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___24 *, const u32 *);
	void (*get_channels)(struct net_device___24 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___24 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___24 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___24 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___24 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___24 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___24 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___24 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___24 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___24 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___24 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___24 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___34 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___25 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___25 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___35 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___25 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___25 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dcbnl_rtnl_ops___22 {
	int (*ieee_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___24 *);
	u8 (*setstate)(struct net_device___24 *, u8);
	void (*getpermhwaddr)(struct net_device___24 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___24 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___24 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___24 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___24 *, int, u8 *);
	void (*setpfccfg)(struct net_device___24 *, int, u8);
	void (*getpfccfg)(struct net_device___24 *, int, u8 *);
	u8 (*setall)(struct net_device___24 *);
	u8 (*getcap)(struct net_device___24 *, int, u8 *);
	int (*getnumtcs)(struct net_device___24 *, int, u8 *);
	int (*setnumtcs)(struct net_device___24 *, int, u8);
	u8 (*getpfcstate)(struct net_device___24 *);
	void (*setpfcstate)(struct net_device___24 *, u8);
	void (*getbcncfg)(struct net_device___24 *, int, u32 *);
	void (*setbcncfg)(struct net_device___24 *, int, u32);
	void (*getbcnrp)(struct net_device___24 *, int, u8 *);
	void (*setbcnrp)(struct net_device___24 *, int, u8);
	u8 (*setapp)(struct net_device___24 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___24 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___24 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___24 *, int, u8);
	u8 (*getdcbx)(struct net_device___24 *);
	u8 (*setdcbx)(struct net_device___24 *, u8);
	int (*peer_getappinfo)(struct net_device___24 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___24 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___24 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___24 *, struct cee_pfc *);
};

struct cgroupfs_root___116;

struct cgroup___116 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___116 *parent;
	struct dentry___186 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___116 *subsys[11];
	struct cgroupfs_root___116 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___189 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___116 {
	struct super_block___186 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___116 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___23 {
	struct sk_buff___25 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___25 *, struct netlink_callback___23 *);
	int (*done)(struct netlink_callback___23 *);
	void *data;
	struct module___102 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___22 {
	int (*create)(struct sk_buff___25 *, struct net_device___24 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___25 *, unsigned char *);
	int (*rebuild)(struct sk_buff___25 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___24 *, const unsigned char *);
};

struct napi_struct___22 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___22 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___24 *dev;
	struct sk_buff___25 *gro_list;
	struct sk_buff___25 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___22 {
	struct net_device___24 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___20 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___22 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___20 kobj;
	struct net_device___24 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___22 {
	int (*ndo_init)(struct net_device___24 *);
	void (*ndo_uninit)(struct net_device___24 *);
	int (*ndo_open)(struct net_device___24 *);
	int (*ndo_stop)(struct net_device___24 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___25 *, struct net_device___24 *);
	u16 (*ndo_select_queue)(struct net_device___24 *, struct sk_buff___25 *);
	void (*ndo_change_rx_flags)(struct net_device___24 *, int);
	void (*ndo_set_rx_mode)(struct net_device___24 *);
	int (*ndo_set_mac_address)(struct net_device___24 *, void *);
	int (*ndo_validate_addr)(struct net_device___24 *);
	int (*ndo_do_ioctl)(struct net_device___24 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___24 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___24 *, int);
	int (*ndo_neigh_setup)(struct net_device___24 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___24 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___24 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___24 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___24 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___24 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___24 *);
	int (*ndo_netpoll_setup)(struct net_device___24 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___24 *);
	int (*ndo_busy_poll)(struct napi_struct___22 *);
	int (*ndo_set_vf_mac)(struct net_device___24 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___24 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___24 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___24 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___24 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___24 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___24 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___24 *, int, struct sk_buff___25 *);
	int (*ndo_setup_tc)(struct net_device___24 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___24 *);
	int (*ndo_fcoe_disable)(struct net_device___24 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___24 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___24 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___24 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___24 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___24 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___24 *, const struct sk_buff___25 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___24 *, struct net_device___24 *);
	int (*ndo_del_slave)(struct net_device___24 *, struct net_device___24 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___25 *, struct netlink_callback___23 *, struct net_device___24 *, int);
	int (*ndo_bridge_setlink)(struct net_device___24 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___25 *, u32, u32, struct net_device___24 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___24 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___24 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___24 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___24 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___24 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___24 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___25 *, struct net_device___24 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___24 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___24 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___24 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct ddebug_table {
	struct list_head link;
	char *mod_name;
	unsigned int num_ddebugs;
	struct _ddebug *ddebugs;
};

struct ddebug_query {
	const char *filename;
	const char *module;
	const char *function;
	const char *format;
	unsigned int first_lineno;
	unsigned int last_lineno;
};

struct ddebug_iter {
	struct ddebug_table *table;
	unsigned int idx;
};

struct ewma {
	long unsigned int internal;
	long unsigned int factor;
	long unsigned int weight;
};

struct cpu_rmap___2 {
	struct kref refcount;
	u16 size;
	u16 used;
	void **obj;
	struct {
		u16 index;
		u16 dist;
	} near[0];
};

struct irq_glue {
	struct irq_affinity_notify notify;
	struct cpu_rmap___2 *rmap;
	u16 index;
};

typedef mpi_limb_t *mpi_ptr_t;

typedef int mpi_size_t;

typedef mpi_limb_t UWtype;

typedef unsigned int UHWtype;

struct karatsuba_ctx {
	struct karatsuba_ctx *next;
	mpi_ptr_t tspace;
	mpi_size_t tspace_size;
	mpi_ptr_t tp;
	mpi_size_t tp_size;
};

typedef long int mpi_limb_signed_t;

enum pubkey_algo {
	PUBKEY_ALGO_RSA = 0,
	PUBKEY_ALGO_MAX = 1,
};

struct pubkey_hdr {
	uint8_t version;
	uint32_t timestamp;
	uint8_t algo;
	uint8_t nmpi;
	char mpi[0];
} __attribute__((packed));

struct signature_hdr {
	uint8_t version;
	uint32_t timestamp;
	uint8_t algo;
	uint8_t hash;
	uint8_t keyid[8];
	uint8_t nmpi;
	char mpi[0];
} __attribute__((packed));

struct msr {
	union {
		struct {
			u32 l;
			u32 h;
		};
		u64 q;
	};
};

struct msr_info {
	u32 msr_no;
	struct msr reg;
	struct msr *msrs;
	int err;
};

struct msr_regs_info {
	u32 *regs;
	int err;
};

struct pci_sriov {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev *dev;
	struct pci_dev *self;
	struct mutex___85 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_vpd_ops;

struct pci_vpd {
	unsigned int len;
	const struct pci_vpd_ops *ops;
	struct bin_attribute___58 *attr;
};

struct pci_vpd_ops {
	ssize_t (*read)(struct pci_dev *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev *);
};

struct pci_vpd_pci22 {
	struct pci_vpd base;
	struct mutex___85 lock;
	u16 flag;
	bool busy;
	u8 cap;
};

struct pci_bus___13;

struct pci_slot___13;

struct pci_driver___13;

struct pci_vpd___2;

struct pci_sriov___2;

struct pci_dev___13 {
	struct list_head bus_list;
	struct pci_bus___13 *bus;
	struct pci_bus___13 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___13 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___13 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___150 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___144 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___144 *res_attr[17];
	struct bin_attribute___144 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___142 **msi_irq_groups;
	struct pci_vpd___2 *vpd;
	union {
		struct pci_sriov___2 *sriov;
		struct pci_dev___13 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct pci_slot___13 {
	struct pci_bus___13 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___13;

struct pci_bus___13 {
	struct list_head node;
	struct pci_bus___13 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___13 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___13 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___150 *bridge;
	struct device___150 dev;
	struct bin_attribute___144 *legacy_io;
	struct bin_attribute___144 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_sriov___2 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___13 *dev;
	struct pci_dev___13 *self;
	struct mutex___188 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___13;

struct pci_driver_rh___13;

struct pci_driver___13 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___13 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___13 *);
	int (*suspend)(struct pci_dev___13 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___13 *, pm_message_t);
	int (*resume_early)(struct pci_dev___13 *);
	int (*resume)(struct pci_dev___13 *);
	void (*shutdown)(struct pci_dev___13 *);
	int (*sriov_configure)(struct pci_dev___13 *, int);
	const struct pci_error_handlers___13 *err_handler;
	struct device_driver___150 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___13 *pci_driver_rh;
};

struct pci_vpd_ops___2;

struct pci_vpd___2 {
	unsigned int len;
	const struct pci_vpd_ops___2 *ops;
	struct bin_attribute___144 *attr;
};

struct pci_host_bridge_window {
	struct list_head list;
	struct resource *res;
	resource_size_t offset;
};

struct pci_bus_resource {
	struct list_head list;
	struct resource *res;
	unsigned int flags;
};

struct pci_ops___13 {
	int (*read)(struct pci_bus___13 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___13 *, unsigned int, int, int, u32);
};

struct pci_bus_region {
	dma_addr_t start;
	dma_addr_t end;
};

struct pci_error_handlers___13 {
	pci_ers_result_t (*error_detected)(struct pci_dev___13 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___13 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___13 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___13 *);
	void (*resume)(struct pci_dev___13 *);
};

struct pci_driver_rh___13 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___13 *, bool);
};

enum pci_fixup_pass {
	pci_fixup_early = 0,
	pci_fixup_header = 1,
	pci_fixup_final = 2,
	pci_fixup_enable = 3,
	pci_fixup_resume = 4,
	pci_fixup_suspend = 5,
	pci_fixup_resume_early = 6,
};

struct pci_vpd_ops___2 {
	ssize_t (*read)(struct pci_dev___13 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___13 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___13 *);
};

enum pci_bus_speed {
	PCI_SPEED_33MHz = 0,
	PCI_SPEED_66MHz = 1,
	PCI_SPEED_66MHz_PCIX = 2,
	PCI_SPEED_100MHz_PCIX = 3,
	PCI_SPEED_133MHz_PCIX = 4,
	PCI_SPEED_66MHz_PCIX_ECC = 5,
	PCI_SPEED_100MHz_PCIX_ECC = 6,
	PCI_SPEED_133MHz_PCIX_ECC = 7,
	PCI_SPEED_66MHz_PCIX_266 = 9,
	PCI_SPEED_100MHz_PCIX_266 = 10,
	PCI_SPEED_133MHz_PCIX_266 = 11,
	AGP_UNKNOWN = 12,
	AGP_1X = 13,
	AGP_2X = 14,
	AGP_4X = 15,
	AGP_8X = 16,
	PCI_SPEED_66MHz_PCIX_533 = 17,
	PCI_SPEED_100MHz_PCIX_533 = 18,
	PCI_SPEED_133MHz_PCIX_533 = 19,
	PCIE_SPEED_2_5GT = 20,
	PCIE_SPEED_5_0GT = 21,
	PCIE_SPEED_8_0GT = 22,
	PCI_SPEED_UNKNOWN = 255,
};

struct pci_host_bridge {
	struct device___150 dev;
	struct pci_bus___13 *bus;
	struct list_head windows;
	void (*release_fn)(struct pci_host_bridge *);
	void *release_data;
};

enum pcie_bus_config_types {
	PCIE_BUS_TUNE_OFF = 0,
	PCIE_BUS_SAFE = 1,
	PCIE_BUS_PERFORMANCE = 2,
	PCIE_BUS_PEER2PEER = 3,
};

enum {
	PCI_REASSIGN_ALL_RSRC = 1,
	PCI_REASSIGN_ALL_BUS = 2,
	PCI_PROBE_ONLY = 4,
	PCI_CAN_SKIP_ISA_ALIGN = 8,
	PCI_ENABLE_PROC_DOMAINS = 16,
	PCI_COMPAT_DOMAIN_0 = 32,
	PCI_SCAN_ALL_PCIE_DEVS = 64,
};

enum pci_bar_type {
	pci_bar_unknown = 0,
	pci_bar_io = 1,
	pci_bar_mem32 = 2,
	pci_bar_mem64 = 3,
};

struct pci_domain_busn_res {
	struct list_head list;
	struct resource res;
	int domain_nr;
};

struct pci_bus___14;

struct pci_slot___14;

struct pci_driver___14;

struct pci_vpd___3;

struct pci_sriov___3;

struct pci_dev___14 {
	struct list_head bus_list;
	struct pci_bus___14 *bus;
	struct pci_bus___14 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___14 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___14 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___6 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___55 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___55 *res_attr[17];
	struct bin_attribute___55 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___3 *msi_kset;
	const struct attribute_group___55 **msi_irq_groups;
	struct pci_vpd___3 *vpd;
	union {
		struct pci_sriov___3 *sriov;
		struct pci_dev___14 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

typedef void (*dr_release_t___4)(struct device___6 *, void *);

typedef int (*dr_match_t___4)(struct device___6 *, void *, void *);

struct pci_slot___14 {
	struct pci_bus___14 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___3 kobj;
};

struct pci_ops___14;

struct pci_bus___14 {
	struct list_head node;
	struct pci_bus___14 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___14 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___14 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___6 *bridge;
	struct device___6 dev;
	struct bin_attribute___55 *legacy_io;
	struct bin_attribute___55 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct hotplug_slot_ops;

struct hotplug_slot_info;

struct hotplug_slot {
	struct hotplug_slot_ops *ops;
	struct hotplug_slot_info *info;
	void (*release)(struct hotplug_slot *);
	void *private;
	struct list_head slot_list;
	struct pci_slot___14 *pci_slot;
};

enum pcie_reset_state {
	pcie_deassert_reset = 1,
	pcie_warm_reset = 2,
	pcie_hot_reset = 3,
};

enum pci_dev_flags {
	PCI_DEV_FLAGS_MSI_INTX_DISABLE_BUG = 1,
	PCI_DEV_FLAGS_NO_D3 = 2,
	PCI_DEV_FLAGS_ASSIGNED = 4,
	PCI_DEV_FLAGS_ACS_ENABLED_QUIRK = 8,
	PCI_DEV_FLAGS_DMA_ALIAS_DEVFN = 16,
	PCI_DEV_FLAG_PCIE_BRIDGE_ALIAS = 32,
	PCI_DEV_FLAGS_NO_BUS_RESET = 64,
	PCI_DEV_FLAGS_NO_PM_RESET = 128,
};

enum pci_bus_flags {
	PCI_BUS_FLAGS_NO_MSI = 1,
	PCI_BUS_FLAGS_NO_MMRBC = 2,
};

enum pcie_link_width {
	PCIE_LNK_WIDTH_RESRV = 0,
	PCIE_LNK_X1 = 1,
	PCIE_LNK_X2 = 2,
	PCIE_LNK_X4 = 4,
	PCIE_LNK_X8 = 8,
	PCIE_LNK_X12 = 12,
	PCIE_LNK_X16 = 16,
	PCIE_LNK_X32 = 32,
	PCIE_LNK_WIDTH_UNKNOWN = 255,
};

struct pci_cap_saved_data {
	u16 cap_nr;
	bool cap_extended;
	unsigned int size;
	u32 data[0];
};

struct pci_cap_saved_state {
	struct hlist_node next;
	struct pci_cap_saved_data cap;
};

struct pci_sriov___3 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___14 *dev;
	struct pci_dev___14 *self;
	struct mutex___80 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___14;

struct pci_driver_rh___14;

struct pci_driver___14 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___14 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___14 *);
	int (*suspend)(struct pci_dev___14 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___14 *, pm_message_t);
	int (*resume_early)(struct pci_dev___14 *);
	int (*resume)(struct pci_dev___14 *);
	void (*shutdown)(struct pci_dev___14 *);
	int (*sriov_configure)(struct pci_dev___14 *, int);
	const struct pci_error_handlers___14 *err_handler;
	struct device_driver___6 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___14 *pci_driver_rh;
};

struct pci_vpd_ops___3;

struct pci_vpd___3 {
	unsigned int len;
	const struct pci_vpd_ops___3 *ops;
	struct bin_attribute___55 *attr;
};

struct pci_ops___14 {
	int (*read)(struct pci_bus___14 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___14 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___14 {
	pci_ers_result_t (*error_detected)(struct pci_dev___14 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___14 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___14 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___14 *);
	void (*resume)(struct pci_dev___14 *);
};

struct pci_driver_rh___14 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___14 *, bool);
};

typedef int (*arch_set_vga_state_t___2)(struct pci_dev___14 *, bool, unsigned int, u32);

struct pci_sysdata___2 {
	int domain;
	int node;
	struct acpi_device___2 *companion;
	void *iommu;
};

struct hotplug_slot_ops {
	struct module___43 *owner;
	const char *mod_name;
	int (*enable_slot)(struct hotplug_slot *);
	int (*disable_slot)(struct hotplug_slot *);
	int (*set_attention_status)(struct hotplug_slot *, u8);
	int (*hardware_test)(struct hotplug_slot *, u32);
	int (*get_power_status)(struct hotplug_slot *, u8 *);
	int (*get_attention_status)(struct hotplug_slot *, u8 *);
	int (*get_latch_status)(struct hotplug_slot *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot *, u8 *);
	int (*reset_slot)(struct hotplug_slot *, int);
};

struct hotplug_slot_info {
	u8 power_status;
	u8 attention_status;
	u8 latch_status;
	u8 adapter_status;
};

struct pci_platform_pm_ops {
	bool (*is_manageable)(struct pci_dev___14 *);
	int (*set_state)(struct pci_dev___14 *, pci_power_t);
	pci_power_t (*choose_state)(struct pci_dev___14 *);
	int (*sleep_wake)(struct pci_dev___14 *, bool);
	int (*run_wake)(struct pci_dev___14 *, bool);
};

struct pci_vpd_ops___3 {
	ssize_t (*read)(struct pci_dev___14 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___14 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___14 *);
};

struct pci_pme_device {
	struct list_head list;
	struct pci_dev___14 *dev;
};

struct pci_saved_state {
	u32 config_space[16];
	struct pci_cap_saved_data cap[0];
};

struct pci_devres {
	unsigned int enabled: 1;
	unsigned int pinned: 1;
	unsigned int orig_intx: 1;
	unsigned int restore_intx: 1;
	u32 region_mask;
};

struct page___186;

typedef struct page___186 *pgtable_t___186;

struct address_space___187;

struct kmem_cache___173;

struct page___186 {
	long unsigned int flags;
	struct address_space___187 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___186 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___186 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___173 *slab_cache;
		struct page___186 *first_page;
	};
	long: 64;
};

struct task_struct___189;

struct pv_cpu_ops___189 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___189 *);
	void (*end_context_switch)(struct task_struct___189 *);
};

struct mutex___190 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___189 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___182 {
	struct page___186 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___194;

struct signal_struct___189;

struct css_set___117;

struct task_struct___189 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___189 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___194 *mm;
	struct mm_struct___194 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___189 *real_parent;
	struct task_struct___189 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___189 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___189 = 0,
		VTIME_USER___189 = 1,
		VTIME_SYS___189 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___189 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___117 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___190 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___182 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___194 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___194 *, struct mm_struct___194 *);
	void (*dup_mmap)(struct mm_struct___194 *, struct mm_struct___194 *);
	void (*exit_mmap)(struct mm_struct___194 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___194 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___194 *);
	void (*pgd_free)(struct mm_struct___194 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___194 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___194 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___194 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___194 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___194 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___194 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___194 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___194 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___194 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___194 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___194 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___190 lock;
	void *vdso;
} mm_context_t___190;

struct xol_area___186;

struct uprobes_state___186 {
	struct xol_area___186 *xol_area;
};

struct vm_area_struct___194;

struct file___187;

struct core_state___189;

struct mm_struct___194 {
	struct vm_area_struct___194 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___194 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___194 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___190 context;
	long unsigned int flags;
	struct core_state___189 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___189 *owner;
	struct file___187 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___186 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___103;

struct module_kobject___102 {
	struct kobject___20 kobj;
	struct module___103 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___102;

struct module___103 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___102 mkobj;
	struct module_attribute___102 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___189 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct bin_attribute___146;

struct attribute_group___144 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___146 **bin_attrs;
};

struct bin_attribute___146 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___187 *, struct kobject___20 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___187 *, struct kobject___20 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	int (*mmap)(struct file___187 *, struct kobject___20 *, struct bin_attribute___146 *, struct vm_area_struct___194 *);
};

struct dentry___187;

struct path___187 {
	struct vfsmount *mnt;
	struct dentry___187 *dentry;
};

struct inode___187;

struct file_operations___187;

struct file___187 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___187 f_path;
	struct inode___187 *f_inode;
	const struct file_operations___187 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___187 *f_mapping;
	struct mutex___190 f_pos_lock;
};

struct vm_operations_struct___167;

struct vm_area_struct___194 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___194 *vm_next;
	struct vm_area_struct___194 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___194 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___167 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___187 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___152;

struct dev_pm_ops___152 {
	int (*prepare)(struct device___152 *);
	void (*complete)(struct device___152 *);
	int (*suspend)(struct device___152 *);
	int (*resume)(struct device___152 *);
	int (*freeze)(struct device___152 *);
	int (*thaw)(struct device___152 *);
	int (*poweroff)(struct device___152 *);
	int (*restore)(struct device___152 *);
	int (*suspend_late)(struct device___152 *);
	int (*resume_early)(struct device___152 *);
	int (*freeze_late)(struct device___152 *);
	int (*thaw_early)(struct device___152 *);
	int (*poweroff_late)(struct device___152 *);
	int (*restore_early)(struct device___152 *);
	int (*suspend_noirq)(struct device___152 *);
	int (*resume_noirq)(struct device___152 *);
	int (*freeze_noirq)(struct device___152 *);
	int (*thaw_noirq)(struct device___152 *);
	int (*poweroff_noirq)(struct device___152 *);
	int (*restore_noirq)(struct device___152 *);
	int (*runtime_suspend)(struct device___152 *);
	int (*runtime_resume)(struct device___152 *);
	int (*runtime_idle)(struct device___152 *);
};

struct dma_map_ops___61;

struct dev_archdata___61 {
	struct dma_map_ops___61 *dma_ops;
	void *iommu;
};

struct device_type___152;

struct bus_type___152;

struct device_driver___152;

struct dev_pm_domain___152;

struct class___152;

struct device_rh___152;

struct device___152 {
	struct device___152 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___152 *type;
	struct mutex___190 mutex;
	struct bus_type___152 *bus;
	struct device_driver___152 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___152 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___61 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___152 *class;
	const struct attribute_group___144 **groups;
	void (*release)(struct device___152 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___152 *device_rh;
};

struct dev_pm_info_rh___152 {
	void (*set_latency_tolerance)(struct device___152 *, s32);
};

struct dev_pm_domain___152 {
	struct dev_pm_ops___152 ops;
};

struct zone___189;

struct lruvec___189 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___189 *zone;
};

struct pglist_data___189;

struct zone___189 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___189 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___189 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___189 {
	struct zone___189 *zone;
	int zone_idx;
};

struct zonelist___189 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___189 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___189 {
	struct zone___189 node_zones[4];
	struct zonelist___189 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___189 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_bus___15;

struct pci_slot___15;

struct pci_driver___15;

struct pci_vpd___4;

struct pci_sriov___4;

struct pci_dev___15 {
	struct list_head bus_list;
	struct pci_bus___15 *bus;
	struct pci_bus___15 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___15 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___15 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___152 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___146 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___146 *res_attr[17];
	struct bin_attribute___146 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___144 **msi_irq_groups;
	struct pci_vpd___4 *vpd;
	union {
		struct pci_sriov___4 *sriov;
		struct pci_dev___15 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct smp_ops___189 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___189 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___61 {
	void * (*alloc)(struct device___152 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___152 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___152 *, struct vm_area_struct___194 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___152 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___152 *, struct page___186 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___152 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___152 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___152 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___152 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___152 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___152 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___152 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___152 *, dma_addr_t);
	int (*dma_supported)(struct device___152 *, u64);
	int (*set_dma_mask)(struct device___152 *, u64);
	int is_phys;
};

struct bus_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___152 *, char *);
	ssize_t (*store)(struct bus_type___152 *, const char *, size_t);
};

struct device_attribute___152;

struct driver_attribute___152;

struct bus_type___152 {
	const char *name;
	const char *dev_name;
	struct device___152 *dev_root;
	struct bus_attribute___152 *bus_attrs;
	struct device_attribute___152 *dev_attrs;
	struct driver_attribute___152 *drv_attrs;
	const struct attribute_group___144 **bus_groups;
	const struct attribute_group___144 **dev_groups;
	const struct attribute_group___144 **drv_groups;
	int (*match)(struct device___152 *, struct device_driver___152 *);
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	int (*probe)(struct device___152 *);
	int (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*online)(struct device___152 *);
	int (*offline)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct device___152 *, struct device_attribute___152 *, char *);
	ssize_t (*store)(struct device___152 *, struct device_attribute___152 *, const char *, size_t);
};

struct driver_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___152 *, char *);
	ssize_t (*store)(struct device_driver___152 *, const char *, size_t);
};

struct device_driver___152 {
	const char *name;
	struct bus_type___152 *bus;
	struct module___103 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___152 *);
	int (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	const struct attribute_group___144 **groups;
	const struct dev_pm_ops___152 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___152 {
	const char *name;
	const struct attribute_group___144 **groups;
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
};

struct class_attribute___152;

struct class___152 {
	const char *name;
	struct module___103 *owner;
	struct class_attribute___152 *class_attrs;
	struct device_attribute___152 *dev_attrs;
	const struct attribute_group___144 **dev_groups;
	struct bin_attribute___146 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *);
	void (*class_release)(struct class___152 *);
	void (*dev_release)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
	struct subsys_private *p;
};

struct class_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct class___152 *, struct class_attribute___152 *, char *);
	ssize_t (*store)(struct class___152 *, struct class_attribute___152 *, const char *, size_t);
	const void * (*namespace)(struct class___152 *, const struct class_attribute___152 *);
};

struct device_rh___152 {
	struct dev_pm_info_rh___152 power;
};

struct pci_slot___15 {
	struct pci_bus___15 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___15;

struct pci_bus___15 {
	struct list_head node;
	struct pci_bus___15 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___15 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___15 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___152 *bridge;
	struct device___152 dev;
	struct bin_attribute___146 *legacy_io;
	struct bin_attribute___146 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_sriov___4 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___15 *dev;
	struct pci_dev___15 *self;
	struct mutex___190 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___15;

struct pci_driver_rh___15;

struct pci_driver___15 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___15 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___15 *);
	int (*suspend)(struct pci_dev___15 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___15 *, pm_message_t);
	int (*resume_early)(struct pci_dev___15 *);
	int (*resume)(struct pci_dev___15 *);
	void (*shutdown)(struct pci_dev___15 *);
	int (*sriov_configure)(struct pci_dev___15 *, int);
	const struct pci_error_handlers___15 *err_handler;
	struct device_driver___152 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___15 *pci_driver_rh;
};

struct pci_vpd_ops___4;

struct pci_vpd___4 {
	unsigned int len;
	const struct pci_vpd_ops___4 *ops;
	struct bin_attribute___146 *attr;
};

struct pci_ops___15 {
	int (*read)(struct pci_bus___15 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___15 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___15 {
	pci_ers_result_t (*error_detected)(struct pci_dev___15 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___15 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___15 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___15 *);
	void (*resume)(struct pci_dev___15 *);
};

struct pci_driver_rh___15 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___15 *, bool);
};

struct xol_area___186 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___186 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___172;

struct memcg_cache_params___173;

struct kmem_cache___173 {
	struct kmem_cache_cpu___172 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___173 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___187;

struct address_space___187 {
	struct inode___187 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___190 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___187 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___164;

struct vm_operations_struct___167 {
	void (*open)(struct vm_area_struct___194 *);
	void (*close)(struct vm_area_struct___194 *);
	int (*fault)(struct vm_area_struct___194 *, struct vm_fault___164 *);
	int (*page_mkwrite)(struct vm_area_struct___194 *, struct vm_fault___164 *);
	int (*access)(struct vm_area_struct___194 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___194 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___194 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___194 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___194 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___189 {
	struct task_struct___189 *task;
	struct core_thread___189 *next;
};

struct core_state___189 {
	atomic_t nr_threads;
	struct core_thread___189 dumper;
	struct completion startup;
};

struct vm_fault___164 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___186 *page;
};

struct kmem_cache_cpu___172 {
	void **freelist;
	long unsigned int tid;
	struct page___186 *page;
	struct page___186 *partial;
};

struct memcg_cache_params___173 {
	bool is_root_cache;
	union {
		struct kmem_cache___173 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___173 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct module_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___102 *, struct module_kobject___102 *, char *);
	ssize_t (*store)(struct module_attribute___102 *, struct module_kobject___102 *, const char *, size_t);
	void (*setup)(struct module___103 *, const char *);
	int (*test)(struct module___103 *);
	void (*free)(struct module___103 *);
};

struct dentry_operations___187;

struct super_block___187;

struct dentry___187 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___187 *d_parent;
	struct qstr d_name;
	struct inode___187 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___187 *d_op;
	struct super_block___187 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___187;

struct file_lock___187;

struct dquot___187;

struct block_device___187;

struct inode___187 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___187 *i_op;
	struct super_block___187 *i_sb;
	struct address_space___187 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___190 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___187 *i_fop;
	struct file_lock___187 *i_flock;
	struct address_space___187 i_data;
	struct dquot___187 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___187 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___187 {
	int (*d_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_hash)(const struct dentry___187 *, struct qstr *);
	int (*d_compare)(const struct dentry___187 *, const struct dentry___187 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___187 *);
	void (*d_release)(struct dentry___187 *);
	void (*d_prune)(struct dentry___187 *);
	void (*d_iput)(struct dentry___187 *, struct inode___187 *);
	char * (*d_dname)(struct dentry___187 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___187 *);
	int (*d_manage)(struct dentry___187 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___187;

struct mem_dqinfo___187 {
	struct quota_format_type___187 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___187;

struct quota_info___187 {
	unsigned int flags;
	struct mutex___190 dqio_mutex;
	struct mutex___190 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___187 *files[2];
	struct mem_dqinfo___187 info[2];
	const struct quota_format_ops___187 *ops[2];
};

struct file_system_type___187;

struct super_operations___187;

struct dquot_operations___187;

struct quotactl_ops___187;

struct xattr_handler___118;

struct super_block___187 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___187 *s_type;
	const struct super_operations___187 *s_op;
	const struct dquot_operations___187 *dq_op;
	const struct quotactl_ops___187 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___187 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___118 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___187 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___187 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___190 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___187 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___187 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___187 *bd_inode;
	struct super_block___187 *bd_super;
	struct mutex___190 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___187 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___190 bd_fsfreeze_mutex;
};

struct cgroup___117;

struct cgroup_subsys_state___117 {
	struct cgroup___117 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___187 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___187 *ia_file;
};

struct dquot___187 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___190 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___187 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___187 {
	int qf_fmt_id;
	const struct quota_format_ops___187 *qf_ops;
	struct module___103 *qf_owner;
	struct quota_format_type___187 *qf_next;
};

struct quota_format_ops___187 {
	int (*check_quota_file)(struct super_block___187 *, int);
	int (*read_file_info)(struct super_block___187 *, int);
	int (*write_file_info)(struct super_block___187 *, int);
	int (*free_file_info)(struct super_block___187 *, int);
	int (*read_dqblk)(struct dquot___187 *);
	int (*commit_dqblk)(struct dquot___187 *);
	int (*release_dqblk)(struct dquot___187 *);
};

struct dquot_operations___187 {
	int (*write_dquot)(struct dquot___187 *);
	struct dquot___187 * (*alloc_dquot)(struct super_block___187 *, int);
	void (*destroy_dquot)(struct dquot___187 *);
	int (*acquire_dquot)(struct dquot___187 *);
	int (*release_dquot)(struct dquot___187 *);
	int (*mark_dirty)(struct dquot___187 *);
	int (*write_info)(struct super_block___187 *, int);
	qsize_t * (*get_reserved_space)(struct inode___187 *);
};

struct quotactl_ops___187 {
	int (*quota_on)(struct super_block___187 *, int, int, struct path___187 *);
	int (*quota_on_meta)(struct super_block___187 *, int, int);
	int (*quota_off)(struct super_block___187 *, int);
	int (*quota_sync)(struct super_block___187 *, int);
	int (*get_info)(struct super_block___187 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___187 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___187 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___187 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___187 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___187 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___187 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___187 *, unsigned int);
};

struct swap_info_struct___39;

struct address_space_operations___187 {
	int (*writepage)(struct page___186 *, struct writeback_control *);
	int (*readpage)(struct file___187 *, struct page___186 *);
	int (*writepages)(struct address_space___187 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___186 *);
	int (*readpages)(struct file___187 *, struct address_space___187 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___187 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___186 **, void **);
	int (*write_end)(struct file___187 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___186 *, void *);
	sector_t (*bmap)(struct address_space___187 *, sector_t);
	void (*invalidatepage)(struct page___186 *, long unsigned int);
	int (*releasepage)(struct page___186 *, gfp_t);
	void (*freepage)(struct page___186 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___187 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___187 *, struct page___186 *, struct page___186 *, enum migrate_mode);
	int (*launder_page)(struct page___186 *);
	int (*is_partially_uptodate)(struct page___186 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___186 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___187 *, struct page___186 *);
	int (*swap_activate)(struct swap_info_struct___39 *, struct file___187 *, sector_t *);
	void (*swap_deactivate)(struct file___187 *);
	void (*invalidatepage_range)(struct page___186 *, unsigned int, unsigned int);
};

struct swap_info_struct___39 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___187 *bdev;
	struct file___187 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___187 {
	struct dentry___187 * (*lookup)(struct inode___187 *, struct dentry___187 *, unsigned int);
	void * (*follow_link)(struct dentry___187 *, struct nameidata *);
	int (*permission)(struct inode___187 *, int);
	struct posix_acl * (*get_acl)(struct inode___187 *, int);
	int (*readlink)(struct dentry___187 *, char *, int);
	void (*put_link)(struct dentry___187 *, struct nameidata *, void *);
	int (*create)(struct inode___187 *, struct dentry___187 *, umode_t, bool);
	int (*link)(struct dentry___187 *, struct inode___187 *, struct dentry___187 *);
	int (*unlink)(struct inode___187 *, struct dentry___187 *);
	int (*symlink)(struct inode___187 *, struct dentry___187 *, const char *);
	int (*mkdir)(struct inode___187 *, struct dentry___187 *, umode_t);
	int (*rmdir)(struct inode___187 *, struct dentry___187 *);
	int (*mknod)(struct inode___187 *, struct dentry___187 *, umode_t, dev_t);
	int (*rename)(struct inode___187 *, struct dentry___187 *, struct inode___187 *, struct dentry___187 *);
	int (*setattr)(struct dentry___187 *, struct iattr___187 *);
	int (*getattr)(struct vfsmount *, struct dentry___187 *, struct kstat *);
	int (*setxattr)(struct dentry___187 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___187 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___187 *, char *, size_t);
	int (*removexattr)(struct dentry___187 *, const char *);
	int (*fiemap)(struct inode___187 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___187 *, struct timespec *, int);
	int (*atomic_open)(struct inode___187 *, struct dentry___187 *, struct file___187 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___187 {
	struct module___103 *owner;
	loff_t (*llseek)(struct file___187 *, loff_t, int);
	ssize_t (*read)(struct file___187 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___187 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___187 *, void *, filldir_t);
	unsigned int (*poll)(struct file___187 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___187 *, struct vm_area_struct___194 *);
	int (*open)(struct inode___187 *, struct file___187 *);
	int (*flush)(struct file___187 *, fl_owner_t);
	int (*release)(struct inode___187 *, struct file___187 *);
	int (*fsync)(struct file___187 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___187 *, int);
	int (*lock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*sendpage)(struct file___187 *, struct page___186 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___187 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___187 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___187 *, long int, struct file_lock___187 **, void **);
		struct {
			int (*setlease)(struct file___187 *, long int, struct file_lock___187 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___187 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___187 *);
};

struct fasync_struct___187;

struct file_lock_operations___187;

struct lock_manager_operations___187;

struct file_lock___187 {
	struct file_lock___187 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___187 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___187 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___187 *fl_ops;
	const struct lock_manager_operations___187 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___187 {
	void (*fl_copy_lock)(struct file_lock___187 *, struct file_lock___187 *);
	void (*fl_release_private)(struct file_lock___187 *);
};

struct lock_manager_operations___187 {
	int (*lm_compare_owner)(struct file_lock___187 *, struct file_lock___187 *);
	long unsigned int (*lm_owner_key)(struct file_lock___187 *);
	void (*lm_notify)(struct file_lock___187 *);
	int (*lm_grant)(struct file_lock___187 *, struct file_lock___187 *, int);
	void (*lm_break)(struct file_lock___187 *);
	int (*lm_change)(struct file_lock___187 **, int);
};

struct fasync_struct___187 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___187 *fa_next;
	struct file___187 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___187 {
	const char *name;
	int fs_flags;
	struct dentry___187 * (*mount)(struct file_system_type___187 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___187 *);
	struct module___103 *owner;
	struct file_system_type___187 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___187 {
	struct inode___187 * (*alloc_inode)(struct super_block___187 *);
	void (*destroy_inode)(struct inode___187 *);
	void (*dirty_inode)(struct inode___187 *, int);
	int (*write_inode)(struct inode___187 *, struct writeback_control *);
	int (*drop_inode)(struct inode___187 *);
	void (*evict_inode)(struct inode___187 *);
	void (*put_super)(struct super_block___187 *);
	int (*sync_fs)(struct super_block___187 *, int);
	int (*freeze_fs)(struct super_block___187 *);
	int (*unfreeze_fs)(struct super_block___187 *);
	int (*statfs)(struct dentry___187 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___187 *, int *, char *);
	void (*umount_begin)(struct super_block___187 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___187 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___187 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___187 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___187 *);
	ssize_t (*quota_read)(struct super_block___187 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___187 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___187 *);
	int (*bdev_try_to_free_page)(struct super_block___187 *, struct page___186 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___187 *);
	void (*free_cached_objects)(struct super_block___187 *, int);
};

struct xattr_handler___118 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___187 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___187 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___187 *, const char *, const void *, size_t, int, int);
};

struct signal_struct___189 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___189 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___189 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___190 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___117 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___117 *subsys[11];
	struct callback_head callback_head;
};

struct cgroupfs_root___117;

struct cgroup___117 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___117 *parent;
	struct dentry___187 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___117 *subsys[11];
	struct cgroupfs_root___117 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___190 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___117 {
	struct super_block___187 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___117 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___62 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___187 *, struct file___187 *);
	ssize_t (*read)(struct cgroup___117 *, struct cftype___62 *, struct file___187 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___117 *, struct cftype___62 *);
	s64 (*read_s64)(struct cgroup___117 *, struct cftype___62 *);
	int (*read_map)(struct cgroup___117 *, struct cftype___62 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___117 *, struct cftype___62 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___117 *, struct cftype___62 *, struct file___187 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___117 *, struct cftype___62 *, u64);
	int (*write_s64)(struct cgroup___117 *, struct cftype___62 *, s64);
	int (*write_string)(struct cgroup___117 *, struct cftype___62 *, const char *);
	int (*trigger)(struct cgroup___117 *, unsigned int);
	int (*release)(struct inode___187 *, struct file___187 *);
	int (*register_event)(struct cgroup___117 *, struct cftype___62 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___117 *, struct cftype___62 *, struct eventfd_ctx *);
};

struct cftype_set___58 {
	struct list_head node;
	struct cftype___62 *cfts;
};

struct task_and_cgroup___58 {
	struct task_struct___189 *task;
	struct cgroup___117 *cgrp;
	struct css_set___117 *cg;
};

struct cgroup_taskset___58 {
	struct task_and_cgroup___58 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___117 *cur_cgrp;
};

struct cgroup_subsys___58 {
	struct cgroup_subsys_state___117 * (*css_alloc)(struct cgroup___117 *);
	int (*css_online)(struct cgroup___117 *);
	void (*css_offline)(struct cgroup___117 *);
	void (*css_free)(struct cgroup___117 *);
	int (*can_attach)(struct cgroup___117 *, struct cgroup_taskset___58 *);
	void (*cancel_attach)(struct cgroup___117 *, struct cgroup_taskset___58 *);
	void (*attach)(struct cgroup___117 *, struct cgroup_taskset___58 *);
	void (*fork)(struct task_struct___189 *);
	void (*exit)(struct cgroup___117 *, struct cgroup___117 *, struct task_struct___189 *);
	void (*bind)(struct cgroup___117 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___117 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___62 *base_cftypes;
	struct cftype_set___58 base_cftset;
	struct module___103 *module;
};

struct pci_vpd_ops___4 {
	ssize_t (*read)(struct pci_dev___15 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___15 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___15 *);
};

struct pci_dynid {
	struct list_head node;
	struct pci_device_id id;
};

struct drv_dev_and_id {
	struct pci_driver___15 *drv;
	struct pci_dev___15 *dev;
	const struct pci_device_id *id;
};

struct pci_bus___16;

struct pci_slot___16;

struct pci_driver___16;

struct pci_vpd___5;

struct pci_sriov___5;

struct pci_dev___16 {
	struct list_head bus_list;
	struct pci_bus___16 *bus;
	struct pci_bus___16 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___16 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___16 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___9 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___9 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___9 *res_attr[17];
	struct bin_attribute___9 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___4 *msi_kset;
	const struct attribute_group___9 **msi_irq_groups;
	struct pci_vpd___5 *vpd;
	union {
		struct pci_sriov___5 *sriov;
		struct pci_dev___16 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct pci_slot___16 {
	struct pci_bus___16 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___4 kobj;
};

struct pci_ops___16;

struct pci_bus___16 {
	struct list_head node;
	struct pci_bus___16 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___16 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___16 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___9 *bridge;
	struct device___9 dev;
	struct bin_attribute___9 *legacy_io;
	struct bin_attribute___9 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

enum pci_mmap_state {
	pci_mmap_io = 0,
	pci_mmap_mem = 1,
};

struct pci_sriov___5 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___16 *dev;
	struct pci_dev___16 *self;
	struct mutex___187 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___16;

struct pci_driver_rh___16;

struct pci_driver___16 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___16 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___16 *);
	int (*suspend)(struct pci_dev___16 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___16 *, pm_message_t);
	int (*resume_early)(struct pci_dev___16 *);
	int (*resume)(struct pci_dev___16 *);
	void (*shutdown)(struct pci_dev___16 *);
	int (*sriov_configure)(struct pci_dev___16 *, int);
	const struct pci_error_handlers___16 *err_handler;
	struct device_driver___9 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___16 *pci_driver_rh;
};

struct pci_vpd_ops___5;

struct pci_vpd___5 {
	unsigned int len;
	const struct pci_vpd_ops___5 *ops;
	struct bin_attribute___9 *attr;
};

struct pci_ops___16 {
	int (*read)(struct pci_bus___16 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___16 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___16 {
	pci_ers_result_t (*error_detected)(struct pci_dev___16 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___16 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___16 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___16 *);
	void (*resume)(struct pci_dev___16 *);
};

struct pci_driver_rh___16 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___16 *, bool);
};

enum pci_mmap_api {
	PCI_MMAP_SYSFS = 0,
	PCI_MMAP_PROCFS = 1,
};

struct pci_vpd_ops___5 {
	ssize_t (*read)(struct pci_dev___16 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___16 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___16 *);
};

enum pci_lost_interrupt_reason {
	PCI_LOST_IRQ_NO_INFORMATION = 0,
	PCI_LOST_IRQ_DISABLE_MSI = 1,
	PCI_LOST_IRQ_DISABLE_MSIX = 2,
	PCI_LOST_IRQ_DISABLE_ACPI = 3,
};

struct pci_dev_resource {
	struct list_head list;
	struct resource *res;
	struct pci_dev___15 *dev;
	resource_size_t start;
	resource_size_t end;
	resource_size_t add_size;
	resource_size_t min_align;
	long unsigned int flags;
};

enum release_type {
	leaf_only = 0,
	whole_subtree = 1,
};

enum enable_type {
	undefined = 4294967295,
	user_disabled = 0,
	auto_disabled = 1,
	user_enabled = 2,
	auto_enabled = 3,
};

struct pci_filp_private {
	enum pci_mmap_state mmap_state;
	int write_combine;
};

struct pci_slot_attribute {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___14 *, char *);
	ssize_t (*store)(struct pci_slot___14 *, const char *, size_t);
};

enum pci_irq_reroute_variant {
	INTEL_IRQ_REROUTE_VARIANT = 1,
	MAX_IRQ_REROUTE_VARIANTS = 3,
};

struct pci_dev_reset_methods {
	u16 vendor;
	u16 device;
	int (*reset)(struct pci_dev___14 *, int);
};

struct pci_dev_dma_source {
	u16 vendor;
	u16 device;
	struct pci_dev___14 * (*dma_source)(struct pci_dev___14 *);
};

struct pci_dev_acs_enabled {
	u16 vendor;
	u16 device;
	int (*acs_enabled)(struct pci_dev___14 *, u16);
};

struct pci_dev_enable_acs {
	u16 vendor;
	u16 device;
	int (*enable_acs)(struct pci_dev___14 *);
};

struct aspm_latency {
	u32 l0s;
	u32 l1;
};

struct pcie_link_state {
	struct pci_dev___15 *pdev;
	struct pcie_link_state *root;
	struct pcie_link_state *parent;
	struct list_head sibling;
	struct list_head children;
	struct list_head link;
	u32 aspm_support: 3;
	u32 aspm_enabled: 3;
	u32 aspm_capable: 3;
	u32 aspm_default: 3;
	u32 aspm_disable: 3;
	u32 clkpm_capable: 1;
	u32 clkpm_enabled: 1;
	u32 clkpm_default: 1;
	struct aspm_latency latency_up;
	struct aspm_latency latency_dw;
	struct aspm_latency acceptable[8];
};

struct aspm_register_info {
	u32 support: 2;
	u32 enabled: 2;
	u32 latency_encoding_l0s;
	u32 latency_encoding_l1;
};

struct msix_entry {
	u32 vector;
	u16 entry;
};

struct pcie_device {
	int irq;
	struct pci_dev___15 *port;
	u32 service;
	void *priv_data;
	struct device___152 device;
};

struct pcie_port_service_driver {
	const char *name;
	int (*probe)(struct pcie_device *);
	void (*remove)(struct pcie_device *);
	int (*suspend)(struct pcie_device *);
	int (*resume)(struct pcie_device *);
	const struct pci_error_handlers___15 *err_handler;
	pci_ers_result_t (*reset_link)(struct pci_dev___15 *);
	int port_type;
	u32 service;
	struct device_driver___152 driver;
};

enum pci_ers_result {
	PCI_ERS_RESULT_NONE = 1,
	PCI_ERS_RESULT_CAN_RECOVER = 2,
	PCI_ERS_RESULT_NEED_RESET = 3,
	PCI_ERS_RESULT_DISCONNECT = 4,
	PCI_ERS_RESULT_RECOVERED = 5,
	PCI_ERS_RESULT_NO_AER_DRIVER = 6,
};

struct aer_broadcast_data {
	enum pci_channel_state state;
	enum pci_ers_result result;
};

struct d3cold_info {
	bool no_d3cold;
	unsigned int d3cold_delay;
};

struct acpi_pci_root {
	struct acpi_device___2 *device;
	struct pci_bus___14 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

struct dma_map_ops___62;

struct dev_archdata___62 {
	struct dma_map_ops___62 *dma_ops;
	void *iommu;
};

struct device_type___153;

struct bus_type___153;

struct device_driver___153;

struct dev_pm_domain___153;

struct class___153;

struct device_rh___153;

struct device___153 {
	struct device___153 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___153 *type;
	struct mutex___91 mutex;
	struct bus_type___153 *bus;
	struct device_driver___153 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___153 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___62 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___4 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___153 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___153 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___153 *device_rh;
};

struct pci_bus___17;

struct pci_slot___17;

struct pci_driver___17;

struct pci_dev___17 {
	struct list_head bus_list;
	struct pci_bus___17 *bus;
	struct pci_bus___17 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___17 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___17 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___153 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___62 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___62 *res_attr[17];
	struct bin_attribute___62 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___62 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___17 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___153 {
	int (*prepare)(struct device___153 *);
	void (*complete)(struct device___153 *);
	int (*suspend)(struct device___153 *);
	int (*resume)(struct device___153 *);
	int (*freeze)(struct device___153 *);
	int (*thaw)(struct device___153 *);
	int (*poweroff)(struct device___153 *);
	int (*restore)(struct device___153 *);
	int (*suspend_late)(struct device___153 *);
	int (*resume_early)(struct device___153 *);
	int (*freeze_late)(struct device___153 *);
	int (*thaw_early)(struct device___153 *);
	int (*poweroff_late)(struct device___153 *);
	int (*restore_early)(struct device___153 *);
	int (*suspend_noirq)(struct device___153 *);
	int (*resume_noirq)(struct device___153 *);
	int (*freeze_noirq)(struct device___153 *);
	int (*thaw_noirq)(struct device___153 *);
	int (*poweroff_noirq)(struct device___153 *);
	int (*restore_noirq)(struct device___153 *);
	int (*runtime_suspend)(struct device___153 *);
	int (*runtime_resume)(struct device___153 *);
	int (*runtime_idle)(struct device___153 *);
};

struct dev_pm_info_rh___153 {
	void (*set_latency_tolerance)(struct device___153 *, s32);
};

struct dev_pm_domain___153 {
	struct dev_pm_ops___153 ops;
};

struct dma_map_ops___62 {
	void * (*alloc)(struct device___153 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___153 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___153 *, struct vm_area_struct___95 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___153 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___153 *, struct page___90 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___153 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___153 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___153 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___153 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___153 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___153 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___153 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___153 *, dma_addr_t);
	int (*dma_supported)(struct device___153 *, u64);
	int (*set_dma_mask)(struct device___153 *, u64);
	int is_phys;
};

struct bus_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___153 *, char *);
	ssize_t (*store)(struct bus_type___153 *, const char *, size_t);
};

struct device_attribute___153;

struct driver_attribute___153;

struct bus_type___153 {
	const char *name;
	const char *dev_name;
	struct device___153 *dev_root;
	struct bus_attribute___153 *bus_attrs;
	struct device_attribute___153 *dev_attrs;
	struct driver_attribute___153 *drv_attrs;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___153 *, struct device_driver___153 *);
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	int (*probe)(struct device___153 *);
	int (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*online)(struct device___153 *);
	int (*offline)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct device___153 *, struct device_attribute___153 *, char *);
	ssize_t (*store)(struct device___153 *, struct device_attribute___153 *, const char *, size_t);
};

struct driver_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___153 *, char *);
	ssize_t (*store)(struct device_driver___153 *, const char *, size_t);
};

struct device_driver___153 {
	const char *name;
	struct bus_type___153 *bus;
	struct module___47 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___153 *);
	int (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___153 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___153 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
};

struct class_attribute___153;

struct class___153 {
	const char *name;
	struct module___47 *owner;
	struct class_attribute___153 *class_attrs;
	struct device_attribute___153 *dev_attrs;
	const struct attribute_group___62 **dev_groups;
	struct bin_attribute___62 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *);
	void (*class_release)(struct class___153 *);
	void (*dev_release)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
	struct subsys_private *p;
};

struct class_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct class___153 *, struct class_attribute___153 *, char *);
	ssize_t (*store)(struct class___153 *, struct class_attribute___153 *, const char *, size_t);
	const void * (*namespace)(struct class___153 *, const struct class_attribute___153 *);
};

struct device_rh___153 {
	struct dev_pm_info_rh___153 power;
};

struct pci_slot___17 {
	struct pci_bus___17 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___17;

struct pci_bus___17 {
	struct list_head node;
	struct pci_bus___17 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___17 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___17 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___153 *bridge;
	struct device___153 dev;
	struct bin_attribute___62 *legacy_io;
	struct bin_attribute___62 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___17;

struct pci_driver_rh___17;

struct pci_driver___17 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___17 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___17 *);
	int (*suspend)(struct pci_dev___17 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___17 *, pm_message_t);
	int (*resume_early)(struct pci_dev___17 *);
	int (*resume)(struct pci_dev___17 *);
	void (*shutdown)(struct pci_dev___17 *);
	int (*sriov_configure)(struct pci_dev___17 *, int);
	const struct pci_error_handlers___17 *err_handler;
	struct device_driver___153 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___17 *pci_driver_rh;
};

struct pci_ops___17 {
	int (*read)(struct pci_bus___17 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___17 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___17 {
	pci_ers_result_t (*error_detected)(struct pci_dev___17 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___17 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___17 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___17 *);
	void (*resume)(struct pci_dev___17 *);
};

struct pci_driver_rh___17 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___17 *, bool);
};

struct aer_header_log_regs {
	unsigned int dw0;
	unsigned int dw1;
	unsigned int dw2;
	unsigned int dw3;
};

struct aer_capability_regs {
	u32 header;
	u32 uncor_status;
	u32 uncor_mask;
	u32 uncor_severity;
	u32 cor_status;
	u32 cor_mask;
	u32 cap_control;
	struct aer_header_log_regs header_log;
	u32 root_command;
	u32 root_status;
	u16 cor_err_source;
	u16 uncor_err_source;
};

struct aer_err_info {
	struct pci_dev___17 *dev[5];
	int error_dev_num;
	unsigned int id: 16;
	unsigned int severity: 2;
	unsigned int __pad1: 5;
	unsigned int multi_error_valid: 1;
	unsigned int first_error: 5;
	unsigned int __pad2: 2;
	unsigned int tlp_header_valid: 1;
	unsigned int status;
	unsigned int mask;
	struct aer_header_log_regs tlp;
};

struct pcie_device___2 {
	int irq;
	struct pci_dev___17 *port;
	u32 service;
	void *priv_data;
	struct device___153 device;
};

struct pcie_port_service_driver___2 {
	const char *name;
	int (*probe)(struct pcie_device___2 *);
	void (*remove)(struct pcie_device___2 *);
	int (*suspend)(struct pcie_device___2 *);
	int (*resume)(struct pcie_device___2 *);
	const struct pci_error_handlers___17 *err_handler;
	pci_ers_result_t (*reset_link)(struct pci_dev___17 *);
	int port_type;
	u32 service;
	struct device_driver___153 driver;
};

struct aer_err_source {
	unsigned int status;
	unsigned int id;
};

struct aer_rpc {
	struct pcie_device___2 *rpd;
	struct work_struct dpc_handler;
	struct aer_err_source e_sources[100];
	short unsigned int prod_idx;
	short unsigned int cons_idx;
	int isr;
	spinlock_t e_lock;
	struct mutex___91 rpc_mutex;
	wait_queue_head_t wait_release;
};

struct aer_recover_entry {
	u8 bus;
	u8 devfn;
	u16 domain;
	int severity;
	struct aer_capability_regs *regs;
};

struct pcie_device___3 {
	int irq;
	struct pci_dev___14 *port;
	u32 service;
	void *priv_data;
	struct device___6 device;
};

struct pcie_port_service_driver___3 {
	const char *name;
	int (*probe)(struct pcie_device___3 *);
	void (*remove)(struct pcie_device___3 *);
	int (*suspend)(struct pcie_device___3 *);
	int (*resume)(struct pcie_device___3 *);
	const struct pci_error_handlers___14 *err_handler;
	pci_ers_result_t (*reset_link)(struct pci_dev___14 *);
	int port_type;
	u32 service;
	struct device_driver___6 driver;
};

struct aer_rpc___2 {
	struct pcie_device___3 *rpd;
	struct work_struct dpc_handler;
	struct aer_err_source e_sources[100];
	short unsigned int prod_idx;
	short unsigned int cons_idx;
	int isr;
	spinlock_t e_lock;
	struct mutex___80 rpc_mutex;
	wait_queue_head_t wait_release;
};

struct dma_map_ops___63;

struct dev_archdata___63 {
	struct dma_map_ops___63 *dma_ops;
	void *iommu;
};

struct acpi_device___12;

struct acpi_dev_node___18 {
	union {
		struct acpi_device___12 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___154;

struct bus_type___154;

struct device_driver___154;

struct dev_pm_domain___154;

struct class___154;

struct device_rh___154;

struct device___154 {
	struct device___154 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___154 *type;
	struct mutex___91 mutex;
	struct bus_type___154 *bus;
	struct device_driver___154 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___154 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___63 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___18 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___154 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___154 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___154 *device_rh;
};

struct pci_bus___18;

struct pci_slot___18;

struct pci_driver___18;

struct pci_dev___18 {
	struct list_head bus_list;
	struct pci_bus___18 *bus;
	struct pci_bus___18 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___18 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___18 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___154 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___62 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___62 *res_attr[17];
	struct bin_attribute___62 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___62 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___18 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___154 {
	int (*prepare)(struct device___154 *);
	void (*complete)(struct device___154 *);
	int (*suspend)(struct device___154 *);
	int (*resume)(struct device___154 *);
	int (*freeze)(struct device___154 *);
	int (*thaw)(struct device___154 *);
	int (*poweroff)(struct device___154 *);
	int (*restore)(struct device___154 *);
	int (*suspend_late)(struct device___154 *);
	int (*resume_early)(struct device___154 *);
	int (*freeze_late)(struct device___154 *);
	int (*thaw_early)(struct device___154 *);
	int (*poweroff_late)(struct device___154 *);
	int (*restore_early)(struct device___154 *);
	int (*suspend_noirq)(struct device___154 *);
	int (*resume_noirq)(struct device___154 *);
	int (*freeze_noirq)(struct device___154 *);
	int (*thaw_noirq)(struct device___154 *);
	int (*poweroff_noirq)(struct device___154 *);
	int (*restore_noirq)(struct device___154 *);
	int (*runtime_suspend)(struct device___154 *);
	int (*runtime_resume)(struct device___154 *);
	int (*runtime_idle)(struct device___154 *);
};

struct dev_pm_info_rh___154 {
	void (*set_latency_tolerance)(struct device___154 *, s32);
};

struct dev_pm_domain___154 {
	struct dev_pm_ops___154 ops;
};

struct dma_map_ops___63 {
	void * (*alloc)(struct device___154 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___154 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___154 *, struct vm_area_struct___95 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___154 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___154 *, struct page___90 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___154 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___154 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___154 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___154 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___154 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___154 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___154 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___154 *, dma_addr_t);
	int (*dma_supported)(struct device___154 *, u64);
	int (*set_dma_mask)(struct device___154 *, u64);
	int is_phys;
};

struct bus_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___154 *, char *);
	ssize_t (*store)(struct bus_type___154 *, const char *, size_t);
};

struct device_attribute___154;

struct driver_attribute___154;

struct bus_type___154 {
	const char *name;
	const char *dev_name;
	struct device___154 *dev_root;
	struct bus_attribute___154 *bus_attrs;
	struct device_attribute___154 *dev_attrs;
	struct driver_attribute___154 *drv_attrs;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___154 *, struct device_driver___154 *);
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	int (*probe)(struct device___154 *);
	int (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*online)(struct device___154 *);
	int (*offline)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct device___154 *, struct device_attribute___154 *, char *);
	ssize_t (*store)(struct device___154 *, struct device_attribute___154 *, const char *, size_t);
};

struct driver_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___154 *, char *);
	ssize_t (*store)(struct device_driver___154 *, const char *, size_t);
};

struct device_driver___154 {
	const char *name;
	struct bus_type___154 *bus;
	struct module___47 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___154 *);
	int (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___154 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___154 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
};

struct class_attribute___154;

struct class___154 {
	const char *name;
	struct module___47 *owner;
	struct class_attribute___154 *class_attrs;
	struct device_attribute___154 *dev_attrs;
	const struct attribute_group___62 **dev_groups;
	struct bin_attribute___62 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *);
	void (*class_release)(struct class___154 *);
	void (*dev_release)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
	struct subsys_private *p;
};

struct class_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct class___154 *, struct class_attribute___154 *, char *);
	ssize_t (*store)(struct class___154 *, struct class_attribute___154 *, const char *, size_t);
	const void * (*namespace)(struct class___154 *, const struct class_attribute___154 *);
};

struct acpi_scan_handler___12;

struct acpi_hotplug_context___12;

struct acpi_driver___12;

struct acpi_device___12 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___12 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___12 *handler;
	struct acpi_hotplug_context___12 *hp;
	struct acpi_driver___12 *driver;
	void *driver_data;
	struct device___154 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___91 physical_node_lock;
	void (*remove)(struct acpi_device___12 *);
};

struct device_rh___154 {
	struct dev_pm_info_rh___154 power;
};

struct pci_slot___18 {
	struct pci_bus___18 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___18;

struct pci_bus___18 {
	struct list_head node;
	struct pci_bus___18 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___18 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___18 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___154 *bridge;
	struct device___154 dev;
	struct bin_attribute___62 *legacy_io;
	struct bin_attribute___62 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___18;

struct pci_driver_rh___18;

struct pci_driver___18 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___18 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___18 *);
	int (*suspend)(struct pci_dev___18 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___18 *, pm_message_t);
	int (*resume_early)(struct pci_dev___18 *);
	int (*resume)(struct pci_dev___18 *);
	void (*shutdown)(struct pci_dev___18 *);
	int (*sriov_configure)(struct pci_dev___18 *, int);
	const struct pci_error_handlers___18 *err_handler;
	struct device_driver___154 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___18 *pci_driver_rh;
};

struct pci_ops___18 {
	int (*read)(struct pci_bus___18 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___18 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___18 {
	pci_ers_result_t (*error_detected)(struct pci_dev___18 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___18 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___18 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___18 *);
	void (*resume)(struct pci_dev___18 *);
};

struct pci_driver_rh___18 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___18 *, bool);
};

struct pci_sysdata___3 {
	int domain;
	int node;
	struct acpi_device___12 *companion;
	void *iommu;
};

struct acpi_hest_header {
	u16 type;
	u16 source_id;
};

enum acpi_hest_types {
	ACPI_HEST_TYPE_IA32_CHECK = 0,
	ACPI_HEST_TYPE_IA32_CORRECTED_CHECK = 1,
	ACPI_HEST_TYPE_IA32_NMI = 2,
	ACPI_HEST_TYPE_NOT_USED3 = 3,
	ACPI_HEST_TYPE_NOT_USED4 = 4,
	ACPI_HEST_TYPE_NOT_USED5 = 5,
	ACPI_HEST_TYPE_AER_ROOT_PORT = 6,
	ACPI_HEST_TYPE_AER_ENDPOINT = 7,
	ACPI_HEST_TYPE_AER_BRIDGE = 8,
	ACPI_HEST_TYPE_GENERIC_ERROR = 9,
	ACPI_HEST_TYPE_RESERVED = 10,
};

struct acpi_hest_aer_common {
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 bus;
	u16 device;
	u16 function;
	u16 device_control;
	u16 reserved2;
	u32 uncorrectable_mask;
	u32 uncorrectable_severity;
	u32 correctable_mask;
	u32 advanced_capabilities;
};

struct acpi_hotplug_profile___12 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___12 *);
	void (*notify_online)(struct acpi_device___12 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___12 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___12 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___12 *);
	void (*bind)(struct device___154 *);
	void (*unbind)(struct device___154 *);
	struct acpi_hotplug_profile___12 hotplug;
};

struct acpi_hotplug_context___12 {
	struct acpi_device___12 *self;
	int (*notify)(struct acpi_device___12 *, u32);
	void (*uevent)(struct acpi_device___12 *, u32);
	void (*fixup)(struct acpi_device___12 *);
};

typedef int (*acpi_op_add___12)(struct acpi_device___12 *);

typedef int (*acpi_op_remove___12)(struct acpi_device___12 *);

typedef void (*acpi_op_notify___12)(struct acpi_device___12 *, u32);

struct acpi_device_ops___12 {
	acpi_op_add___12 add;
	acpi_op_remove___12 remove;
	acpi_op_notify___12 notify;
};

struct acpi_driver___12 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___12 ops;
	struct device_driver___154 drv;
	struct module___47 *owner;
};

typedef int (*apei_hest_func_t)(struct acpi_hest_header *, void *);

struct aer_hest_parse_info {
	struct pci_dev___18 *pci_dev;
	int firmware_first;
};

struct pcie_pme_service_data {
	spinlock_t lock;
	struct pcie_device___3 *srv;
	struct work_struct work;
	bool noirq;
};

struct acpi_object_list {
	u32 count;
	union acpi_object *pointer;
};

struct ioapic___2 {
	acpi_handle handle;
	u32 gsi_base;
};

struct page___187;

typedef struct page___187 *pgtable_t___187;

struct address_space___188;

struct kmem_cache___174;

struct page___187 {
	long unsigned int flags;
	struct address_space___188 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___187 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___187 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___174 *slab_cache;
		struct page___187 *first_page;
	};
	long: 64;
};

struct task_struct___190;

struct pv_cpu_ops___190 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___190 *);
	void (*end_context_switch)(struct task_struct___190 *);
};

struct mutex___191 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___190 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___183 {
	struct page___187 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___195;

struct signal_struct___190;

struct task_struct___190 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___190 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___195 *mm;
	struct mm_struct___195 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___190 *real_parent;
	struct task_struct___190 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___190 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___190 = 0,
		VTIME_USER___190 = 1,
		VTIME_SYS___190 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___190 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___191 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___183 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___195 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___195 *, struct mm_struct___195 *);
	void (*dup_mmap)(struct mm_struct___195 *, struct mm_struct___195 *);
	void (*exit_mmap)(struct mm_struct___195 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___195 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___195 *);
	void (*pgd_free)(struct mm_struct___195 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___195 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___195 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___195 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___195 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___195 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___195 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___195 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___195 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___195 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___195 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___195 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___191 lock;
	void *vdso;
} mm_context_t___191;

struct xol_area___187;

struct uprobes_state___187 {
	struct xol_area___187 *xol_area;
};

struct vm_area_struct___195;

struct file___188;

struct core_state___190;

struct mm_struct___195 {
	struct vm_area_struct___195 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___195 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___195 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___191 context;
	long unsigned int flags;
	struct core_state___190 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___190 *owner;
	struct file___188 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___187 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___104;

struct module_kobject___103 {
	struct kobject___20 kobj;
	struct module___104 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___103;

struct module___104 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___103 mkobj;
	struct module_attribute___103 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___190 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___190;

struct lruvec___190 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___190 *zone;
};

struct pglist_data___190;

struct zone___190 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___190 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___190 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___190 {
	struct zone___190 *zone;
	int zone_idx;
};

struct zonelist___190 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___190 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___190 {
	struct zone___190 node_zones[4];
	struct zonelist___190 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___190 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___64;

struct dev_archdata___64 {
	struct dma_map_ops___64 *dma_ops;
	void *iommu;
};

struct acpi_device___13;

struct acpi_dev_node___19 {
	union {
		struct acpi_device___13 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct device_type___155;

struct bus_type___155;

struct device_driver___155;

struct dev_pm_domain___155;

struct class___155;

struct attribute_group___145;

struct device_rh___155;

struct device___155 {
	struct device___155 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___155 *type;
	struct mutex___191 mutex;
	struct bus_type___155 *bus;
	struct device_driver___155 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___155 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___64 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___19 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___155 *class;
	const struct attribute_group___145 **groups;
	void (*release)(struct device___155 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___155 *device_rh;
};

struct pci_bus___19;

struct pci_slot___19;

struct pci_driver___19;

struct bin_attribute___147;

struct pci_vpd___6;

struct pci_sriov___6;

struct pci_dev___19 {
	struct list_head bus_list;
	struct pci_bus___19 *bus;
	struct pci_bus___19 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___19 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___19 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___155 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___147 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___147 *res_attr[17];
	struct bin_attribute___147 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___145 **msi_irq_groups;
	struct pci_vpd___6 *vpd;
	union {
		struct pci_sriov___6 *sriov;
		struct pci_dev___19 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___155 {
	int (*prepare)(struct device___155 *);
	void (*complete)(struct device___155 *);
	int (*suspend)(struct device___155 *);
	int (*resume)(struct device___155 *);
	int (*freeze)(struct device___155 *);
	int (*thaw)(struct device___155 *);
	int (*poweroff)(struct device___155 *);
	int (*restore)(struct device___155 *);
	int (*suspend_late)(struct device___155 *);
	int (*resume_early)(struct device___155 *);
	int (*freeze_late)(struct device___155 *);
	int (*thaw_early)(struct device___155 *);
	int (*poweroff_late)(struct device___155 *);
	int (*restore_early)(struct device___155 *);
	int (*suspend_noirq)(struct device___155 *);
	int (*resume_noirq)(struct device___155 *);
	int (*freeze_noirq)(struct device___155 *);
	int (*thaw_noirq)(struct device___155 *);
	int (*poweroff_noirq)(struct device___155 *);
	int (*restore_noirq)(struct device___155 *);
	int (*runtime_suspend)(struct device___155 *);
	int (*runtime_resume)(struct device___155 *);
	int (*runtime_idle)(struct device___155 *);
};

struct dev_pm_info_rh___155 {
	void (*set_latency_tolerance)(struct device___155 *, s32);
};

struct dev_pm_domain___155 {
	struct dev_pm_ops___155 ops;
};

struct smp_ops___190 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___190 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct attribute_group___145 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___147 **bin_attrs;
};

struct bin_attribute___147 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___188 *, struct kobject___20 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___188 *, struct kobject___20 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	int (*mmap)(struct file___188 *, struct kobject___20 *, struct bin_attribute___147 *, struct vm_area_struct___195 *);
};

struct vfsmount___41;

struct dentry___188;

struct path___188 {
	struct vfsmount___41 *mnt;
	struct dentry___188 *dentry;
};

struct inode___188;

struct file_operations___188;

struct file___188 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___188 f_path;
	struct inode___188 *f_inode;
	const struct file_operations___188 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___188 *f_mapping;
	struct mutex___191 f_pos_lock;
};

struct vm_operations_struct___168;

struct vm_area_struct___195 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___195 *vm_next;
	struct vm_area_struct___195 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___195 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___168 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___188 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___103 *, struct module_kobject___103 *, char *);
	ssize_t (*store)(struct module_attribute___103 *, struct module_kobject___103 *, const char *, size_t);
	void (*setup)(struct module___104 *, const char *);
	int (*test)(struct module___104 *);
	void (*free)(struct module___104 *);
};

struct xol_area___187 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___187 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___173;

struct memcg_cache_params___174;

struct kmem_cache___174 {
	struct kmem_cache_cpu___173 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___174 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___188;

struct address_space___188 {
	struct inode___188 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___191 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___188 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___165;

struct vm_operations_struct___168 {
	void (*open)(struct vm_area_struct___195 *);
	void (*close)(struct vm_area_struct___195 *);
	int (*fault)(struct vm_area_struct___195 *, struct vm_fault___165 *);
	int (*page_mkwrite)(struct vm_area_struct___195 *, struct vm_fault___165 *);
	int (*access)(struct vm_area_struct___195 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___195 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___195 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___195 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___195 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___190 {
	struct task_struct___190 *task;
	struct core_thread___190 *next;
};

struct core_state___190 {
	atomic_t nr_threads;
	struct core_thread___190 dumper;
	struct completion startup;
};

struct vm_fault___165 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___187 *page;
};

struct dentry_operations___188;

struct super_block___188;

struct dentry___188 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___188 *d_parent;
	struct qstr d_name;
	struct inode___188 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___188 *d_op;
	struct super_block___188 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___188;

struct file_lock___188;

struct dquot___188;

struct block_device___188;

struct inode___188 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___188 *i_op;
	struct super_block___188 *i_sb;
	struct address_space___188 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___191 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___188 *i_fop;
	struct file_lock___188 *i_flock;
	struct address_space___188 i_data;
	struct dquot___188 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___188 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___188 {
	int (*d_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_hash)(const struct dentry___188 *, struct qstr *);
	int (*d_compare)(const struct dentry___188 *, const struct dentry___188 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___188 *);
	void (*d_release)(struct dentry___188 *);
	void (*d_prune)(struct dentry___188 *);
	void (*d_iput)(struct dentry___188 *, struct inode___188 *);
	char * (*d_dname)(struct dentry___188 *, char *, int);
	struct vfsmount___41 * (*d_automount)(struct path___188 *);
	int (*d_manage)(struct dentry___188 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___188;

struct mem_dqinfo___188 {
	struct quota_format_type___188 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___188;

struct quota_info___188 {
	unsigned int flags;
	struct mutex___191 dqio_mutex;
	struct mutex___191 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___188 *files[2];
	struct mem_dqinfo___188 info[2];
	const struct quota_format_ops___188 *ops[2];
};

struct file_system_type___188;

struct super_operations___188;

struct dquot_operations___188;

struct quotactl_ops___188;

struct super_block___188 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___188 *s_type;
	const struct super_operations___188 *s_op;
	const struct dquot_operations___188 *dq_op;
	const struct quotactl_ops___188 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___188 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___188 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___188 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___191 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___188 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___41 {
	struct dentry___188 *mnt_root;
	struct super_block___188 *mnt_sb;
	int mnt_flags;
};

struct block_device___188 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___188 *bd_inode;
	struct super_block___188 *bd_super;
	struct mutex___191 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___188 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___191 bd_fsfreeze_mutex;
};

struct iattr___188 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___188 *ia_file;
};

struct dquot___188 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___191 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___188 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___188 {
	int qf_fmt_id;
	const struct quota_format_ops___188 *qf_ops;
	struct module___104 *qf_owner;
	struct quota_format_type___188 *qf_next;
};

struct quota_format_ops___188 {
	int (*check_quota_file)(struct super_block___188 *, int);
	int (*read_file_info)(struct super_block___188 *, int);
	int (*write_file_info)(struct super_block___188 *, int);
	int (*free_file_info)(struct super_block___188 *, int);
	int (*read_dqblk)(struct dquot___188 *);
	int (*commit_dqblk)(struct dquot___188 *);
	int (*release_dqblk)(struct dquot___188 *);
};

struct dquot_operations___188 {
	int (*write_dquot)(struct dquot___188 *);
	struct dquot___188 * (*alloc_dquot)(struct super_block___188 *, int);
	void (*destroy_dquot)(struct dquot___188 *);
	int (*acquire_dquot)(struct dquot___188 *);
	int (*release_dquot)(struct dquot___188 *);
	int (*mark_dirty)(struct dquot___188 *);
	int (*write_info)(struct super_block___188 *, int);
	qsize_t * (*get_reserved_space)(struct inode___188 *);
};

struct quotactl_ops___188 {
	int (*quota_on)(struct super_block___188 *, int, int, struct path___188 *);
	int (*quota_on_meta)(struct super_block___188 *, int, int);
	int (*quota_off)(struct super_block___188 *, int);
	int (*quota_sync)(struct super_block___188 *, int);
	int (*get_info)(struct super_block___188 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___188 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___188 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___188 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___188 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___188 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___188 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___188 *, unsigned int);
};

struct address_space_operations___188 {
	int (*writepage)(struct page___187 *, struct writeback_control *);
	int (*readpage)(struct file___188 *, struct page___187 *);
	int (*writepages)(struct address_space___188 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___187 *);
	int (*readpages)(struct file___188 *, struct address_space___188 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___188 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___187 **, void **);
	int (*write_end)(struct file___188 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___187 *, void *);
	sector_t (*bmap)(struct address_space___188 *, sector_t);
	void (*invalidatepage)(struct page___187 *, long unsigned int);
	int (*releasepage)(struct page___187 *, gfp_t);
	void (*freepage)(struct page___187 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___188 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___188 *, struct page___187 *, struct page___187 *, enum migrate_mode);
	int (*launder_page)(struct page___187 *);
	int (*is_partially_uptodate)(struct page___187 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___187 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___188 *, struct page___187 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___188 *, sector_t *);
	void (*swap_deactivate)(struct file___188 *);
	void (*invalidatepage_range)(struct page___187 *, unsigned int, unsigned int);
};

struct nameidata___25;

struct inode_operations___188 {
	struct dentry___188 * (*lookup)(struct inode___188 *, struct dentry___188 *, unsigned int);
	void * (*follow_link)(struct dentry___188 *, struct nameidata___25 *);
	int (*permission)(struct inode___188 *, int);
	struct posix_acl * (*get_acl)(struct inode___188 *, int);
	int (*readlink)(struct dentry___188 *, char *, int);
	void (*put_link)(struct dentry___188 *, struct nameidata___25 *, void *);
	int (*create)(struct inode___188 *, struct dentry___188 *, umode_t, bool);
	int (*link)(struct dentry___188 *, struct inode___188 *, struct dentry___188 *);
	int (*unlink)(struct inode___188 *, struct dentry___188 *);
	int (*symlink)(struct inode___188 *, struct dentry___188 *, const char *);
	int (*mkdir)(struct inode___188 *, struct dentry___188 *, umode_t);
	int (*rmdir)(struct inode___188 *, struct dentry___188 *);
	int (*mknod)(struct inode___188 *, struct dentry___188 *, umode_t, dev_t);
	int (*rename)(struct inode___188 *, struct dentry___188 *, struct inode___188 *, struct dentry___188 *);
	int (*setattr)(struct dentry___188 *, struct iattr___188 *);
	int (*getattr)(struct vfsmount___41 *, struct dentry___188 *, struct kstat *);
	int (*setxattr)(struct dentry___188 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___188 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___188 *, char *, size_t);
	int (*removexattr)(struct dentry___188 *, const char *);
	int (*fiemap)(struct inode___188 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___188 *, struct timespec *, int);
	int (*atomic_open)(struct inode___188 *, struct dentry___188 *, struct file___188 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___188 {
	struct module___104 *owner;
	loff_t (*llseek)(struct file___188 *, loff_t, int);
	ssize_t (*read)(struct file___188 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___188 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___188 *, void *, filldir_t);
	unsigned int (*poll)(struct file___188 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___188 *, struct vm_area_struct___195 *);
	int (*open)(struct inode___188 *, struct file___188 *);
	int (*flush)(struct file___188 *, fl_owner_t);
	int (*release)(struct inode___188 *, struct file___188 *);
	int (*fsync)(struct file___188 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___188 *, int);
	int (*lock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*sendpage)(struct file___188 *, struct page___187 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___188 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___188 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___188 *, long int, struct file_lock___188 **, void **);
		struct {
			int (*setlease)(struct file___188 *, long int, struct file_lock___188 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___188 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___188 *);
};

struct fasync_struct___188;

struct file_lock_operations___188;

struct lock_manager_operations___188;

struct file_lock___188 {
	struct file_lock___188 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___188 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___188 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___188 *fl_ops;
	const struct lock_manager_operations___188 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___188 {
	void (*fl_copy_lock)(struct file_lock___188 *, struct file_lock___188 *);
	void (*fl_release_private)(struct file_lock___188 *);
};

struct lock_manager_operations___188 {
	int (*lm_compare_owner)(struct file_lock___188 *, struct file_lock___188 *);
	long unsigned int (*lm_owner_key)(struct file_lock___188 *);
	void (*lm_notify)(struct file_lock___188 *);
	int (*lm_grant)(struct file_lock___188 *, struct file_lock___188 *, int);
	void (*lm_break)(struct file_lock___188 *);
	int (*lm_change)(struct file_lock___188 **, int);
};

struct fasync_struct___188 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___188 *fa_next;
	struct file___188 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___188 {
	const char *name;
	int fs_flags;
	struct dentry___188 * (*mount)(struct file_system_type___188 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___188 *);
	struct module___104 *owner;
	struct file_system_type___188 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___188 {
	struct inode___188 * (*alloc_inode)(struct super_block___188 *);
	void (*destroy_inode)(struct inode___188 *);
	void (*dirty_inode)(struct inode___188 *, int);
	int (*write_inode)(struct inode___188 *, struct writeback_control *);
	int (*drop_inode)(struct inode___188 *);
	void (*evict_inode)(struct inode___188 *);
	void (*put_super)(struct super_block___188 *);
	int (*sync_fs)(struct super_block___188 *, int);
	int (*freeze_fs)(struct super_block___188 *);
	int (*unfreeze_fs)(struct super_block___188 *);
	int (*statfs)(struct dentry___188 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___188 *, int *, char *);
	void (*umount_begin)(struct super_block___188 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___188 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___188 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___188 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___188 *);
	ssize_t (*quota_read)(struct super_block___188 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___188 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___188 *);
	int (*bdev_try_to_free_page)(struct super_block___188 *, struct page___187 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___188 *);
	void (*free_cached_objects)(struct super_block___188 *, int);
};

struct nameidata___25 {
	struct path___188 path;
	struct qstr last;
	struct path___188 root;
	struct inode___188 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct dma_map_ops___64 {
	void * (*alloc)(struct device___155 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___155 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___155 *, struct vm_area_struct___195 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___155 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___155 *, struct page___187 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___155 *, dma_addr_t);
	int (*dma_supported)(struct device___155 *, u64);
	int (*set_dma_mask)(struct device___155 *, u64);
	int is_phys;
};

struct bus_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___155 *, char *);
	ssize_t (*store)(struct bus_type___155 *, const char *, size_t);
};

struct device_attribute___155;

struct driver_attribute___155;

struct bus_type___155 {
	const char *name;
	const char *dev_name;
	struct device___155 *dev_root;
	struct bus_attribute___155 *bus_attrs;
	struct device_attribute___155 *dev_attrs;
	struct driver_attribute___155 *drv_attrs;
	const struct attribute_group___145 **bus_groups;
	const struct attribute_group___145 **dev_groups;
	const struct attribute_group___145 **drv_groups;
	int (*match)(struct device___155 *, struct device_driver___155 *);
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	int (*probe)(struct device___155 *);
	int (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*online)(struct device___155 *);
	int (*offline)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct device___155 *, struct device_attribute___155 *, char *);
	ssize_t (*store)(struct device___155 *, struct device_attribute___155 *, const char *, size_t);
};

struct driver_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___155 *, char *);
	ssize_t (*store)(struct device_driver___155 *, const char *, size_t);
};

struct device_driver___155 {
	const char *name;
	struct bus_type___155 *bus;
	struct module___104 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___155 *);
	int (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	const struct attribute_group___145 **groups;
	const struct dev_pm_ops___155 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___155 {
	const char *name;
	const struct attribute_group___145 **groups;
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
};

struct class_attribute___155;

struct class___155 {
	const char *name;
	struct module___104 *owner;
	struct class_attribute___155 *class_attrs;
	struct device_attribute___155 *dev_attrs;
	const struct attribute_group___145 **dev_groups;
	struct bin_attribute___147 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *);
	void (*class_release)(struct class___155 *);
	void (*dev_release)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
	struct subsys_private *p;
};

struct class_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct class___155 *, struct class_attribute___155 *, char *);
	ssize_t (*store)(struct class___155 *, struct class_attribute___155 *, const char *, size_t);
	const void * (*namespace)(struct class___155 *, const struct class_attribute___155 *);
};

struct acpi_scan_handler___13;

struct acpi_hotplug_context___13;

struct acpi_driver___13;

struct acpi_device___13 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___13 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___13 *handler;
	struct acpi_hotplug_context___13 *hp;
	struct acpi_driver___13 *driver;
	void *driver_data;
	struct device___155 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___191 physical_node_lock;
	void (*remove)(struct acpi_device___13 *);
};

struct device_rh___155 {
	struct dev_pm_info_rh___155 power;
};

struct hotplug_slot___2;

struct pci_slot___19 {
	struct pci_bus___19 *bus;
	struct list_head list;
	struct hotplug_slot___2 *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___19;

struct pci_bus___19 {
	struct list_head node;
	struct pci_bus___19 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___19 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___19 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___155 *bridge;
	struct device___155 dev;
	struct bin_attribute___147 *legacy_io;
	struct bin_attribute___147 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct hotplug_slot_ops___2;

struct hotplug_slot___2 {
	struct hotplug_slot_ops___2 *ops;
	struct hotplug_slot_info *info;
	void (*release)(struct hotplug_slot___2 *);
	void *private;
	struct list_head slot_list;
	struct pci_slot___19 *pci_slot;
};

struct pci_sriov___6 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___19 *dev;
	struct pci_dev___19 *self;
	struct mutex___191 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___19;

struct pci_driver_rh___19;

struct pci_driver___19 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___19 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___19 *);
	int (*suspend)(struct pci_dev___19 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___19 *, pm_message_t);
	int (*resume_early)(struct pci_dev___19 *);
	int (*resume)(struct pci_dev___19 *);
	void (*shutdown)(struct pci_dev___19 *);
	int (*sriov_configure)(struct pci_dev___19 *, int);
	const struct pci_error_handlers___19 *err_handler;
	struct device_driver___155 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___19 *pci_driver_rh;
};

struct pci_vpd_ops___6;

struct pci_vpd___6 {
	unsigned int len;
	const struct pci_vpd_ops___6 *ops;
	struct bin_attribute___147 *attr;
};

struct pci_ops___19 {
	int (*read)(struct pci_bus___19 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___19 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___19 {
	pci_ers_result_t (*error_detected)(struct pci_dev___19 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___19 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___19 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___19 *);
	void (*resume)(struct pci_dev___19 *);
};

struct pci_driver_rh___19 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___19 *, bool);
};

struct kmem_cache_cpu___173 {
	void **freelist;
	long unsigned int tid;
	struct page___187 *page;
	struct page___187 *partial;
};

struct memcg_cache_params___174 {
	bool is_root_cache;
	union {
		struct kmem_cache___174 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___174 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct hotplug_slot_ops___2 {
	struct module___104 *owner;
	const char *mod_name;
	int (*enable_slot)(struct hotplug_slot___2 *);
	int (*disable_slot)(struct hotplug_slot___2 *);
	int (*set_attention_status)(struct hotplug_slot___2 *, u8);
	int (*hardware_test)(struct hotplug_slot___2 *, u32);
	int (*get_power_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___2 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___2 *, int);
};

struct signal_struct___190 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___190 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___190 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___191 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_hotplug_profile___13 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___13 *);
	void (*notify_online)(struct acpi_device___13 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___13 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___13 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___13 *);
	void (*bind)(struct device___155 *);
	void (*unbind)(struct device___155 *);
	struct acpi_hotplug_profile___13 hotplug;
};

struct acpi_hotplug_context___13 {
	struct acpi_device___13 *self;
	int (*notify)(struct acpi_device___13 *, u32);
	void (*uevent)(struct acpi_device___13 *, u32);
	void (*fixup)(struct acpi_device___13 *);
};

typedef int (*acpi_op_add___13)(struct acpi_device___13 *);

typedef int (*acpi_op_remove___13)(struct acpi_device___13 *);

typedef void (*acpi_op_notify___13)(struct acpi_device___13 *, u32);

struct acpi_device_ops___13 {
	acpi_op_add___13 add;
	acpi_op_remove___13 remove;
	acpi_op_notify___13 notify;
};

struct acpi_driver___13 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___13 ops;
	struct device_driver___155 drv;
	struct module___104 *owner;
};

struct pci_vpd_ops___6 {
	ssize_t (*read)(struct pci_dev___19 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___19 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___19 *);
};

struct pci_slot_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___19 *, char *);
	ssize_t (*store)(struct pci_slot___19 *, const char *, size_t);
};

struct hpp_type0 {
	u32 revision;
	u8 cache_line_size;
	u8 latency_timer;
	u8 enable_serr;
	u8 enable_perr;
};

struct hpp_type1 {
	u32 revision;
	u8 max_mem_read;
	u8 avg_max_split;
	u16 tot_max_split;
};

struct hpp_type2 {
	u32 revision;
	u32 unc_err_mask_and;
	u32 unc_err_mask_or;
	u32 unc_err_sever_and;
	u32 unc_err_sever_or;
	u32 cor_err_mask_and;
	u32 cor_err_mask_or;
	u32 adv_err_cap_and;
	u32 adv_err_cap_or;
	u16 pci_exp_devctl_and;
	u16 pci_exp_devctl_or;
	u16 pci_exp_lnkctl_and;
	u16 pci_exp_lnkctl_or;
	u32 sec_unc_err_sever_and;
	u32 sec_unc_err_sever_or;
	u32 sec_unc_err_mask_and;
	u32 sec_unc_err_mask_or;
};

struct hotplug_params {
	struct hpp_type0 *t0;
	struct hpp_type1 *t1;
	struct hpp_type2 *t2;
	struct hpp_type0 type0_data;
	struct hpp_type1 type1_data;
	struct hpp_type2 type2_data;
};

typedef u64 acpi_size;

struct acpi_buffer {
	acpi_size length;
	void *pointer;
};

typedef acpi_status (*acpi_walk_callback)(acpi_handle, u32, void *, void **);

struct controller;

struct slot {
	u8 state;
	struct controller *ctrl;
	struct hotplug_slot *hotplug_slot;
	struct delayed_work work;
	struct mutex___80 lock;
	struct mutex___80 hotplug_lock;
	struct workqueue_struct *wq;
};

struct controller {
	struct mutex___80 ctrl_lock;
	struct pcie_device___3 *pcie;
	struct slot *slot;
	wait_queue_head_t queue;
	u32 slot_cap;
	u16 slot_ctrl;
	struct timer_list poll_timer;
	long unsigned int cmd_started;
	unsigned int cmd_busy: 1;
	unsigned int link_active_reporting: 1;
	unsigned int notification_enabled: 1;
	unsigned int power_fault_detected;
};

struct event_info {
	u32 event_type;
	struct slot *p_slot;
	struct work_struct work;
};

struct power_work_info {
	struct slot *p_slot;
	struct work_struct work;
	unsigned int req;
};

struct acpiphp_slot;

struct slot___2 {
	struct hotplug_slot *hotplug_slot;
	struct acpiphp_slot *acpi_slot;
	struct hotplug_slot_info info;
	unsigned int sun;
};

struct acpiphp_slot {
	struct list_head node;
	struct pci_bus___18 *bus;
	struct list_head funcs;
	struct slot___2 *slot;
	u8 device;
	u32 flags;
};

struct acpiphp_attention_info {
	int (*set_attn)(struct hotplug_slot *, u8);
	int (*get_attn)(struct hotplug_slot *, u8 *);
	struct module___43 *owner;
};

struct acpiphp_slot___2;

struct slot___3 {
	struct hotplug_slot *hotplug_slot;
	struct acpiphp_slot___2 *acpi_slot;
	struct hotplug_slot_info info;
	unsigned int sun;
};

struct acpiphp_slot___2 {
	struct list_head node;
	struct pci_bus___14 *bus;
	struct list_head funcs;
	struct slot___3 *slot;
	u8 device;
	u32 flags;
};

struct acpiphp_context;

struct acpiphp_bridge {
	struct list_head list;
	struct list_head slots;
	struct kref ref;
	struct acpiphp_context *context;
	int nr_slots;
	struct pci_bus___14 *pci_bus;
	struct pci_dev___14 *pci_dev;
	bool is_going_away;
};

struct acpiphp_func {
	struct acpiphp_bridge *parent;
	struct acpiphp_slot___2 *slot;
	struct list_head sibling;
	u8 function;
	u32 flags;
};

struct acpiphp_context {
	struct acpi_hotplug_context___2 hp;
	struct acpiphp_func func;
	struct acpiphp_bridge *bridge;
	unsigned int refcount;
};

struct acpiphp_root_context {
	struct acpi_hotplug_context___2 hp;
	struct acpiphp_bridge *root_bridge;
};

struct pci_bus___20;

struct pci_slot___20;

struct pci_driver___20;

struct pci_vpd___7;

struct pci_sriov___7;

struct pci_dev___20 {
	struct list_head bus_list;
	struct pci_bus___20 *bus;
	struct pci_bus___20 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___20 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___20 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___38 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___33 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___33 *res_attr[17];
	struct bin_attribute___33 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___33 **msi_irq_groups;
	struct pci_vpd___7 *vpd;
	union {
		struct pci_sriov___7 *sriov;
		struct pci_dev___20 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___5 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___20 *dev;
	struct msi_msg msg;
	struct kobject kobj;
};

struct irq_data___129;

struct x86_io_apic_ops___129 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___129 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___129;

struct irq_data___129 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___129 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___5 *msi_desc;
	cpumask_var_t affinity;
};

struct irq_desc___9;

typedef void (*irq_flow_handler_t___9)(unsigned int, struct irq_desc___9 *);

struct irq_desc___9 {
	struct irq_data___129 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___9 handle_irq;
	struct irqaction___7 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	struct proc_dir_entry *dir;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
};

struct irq_chip___129 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___129 *);
	void (*irq_shutdown)(struct irq_data___129 *);
	void (*irq_enable)(struct irq_data___129 *);
	void (*irq_disable)(struct irq_data___129 *);
	void (*irq_ack)(struct irq_data___129 *);
	void (*irq_mask)(struct irq_data___129 *);
	void (*irq_mask_ack)(struct irq_data___129 *);
	void (*irq_unmask)(struct irq_data___129 *);
	void (*irq_eoi)(struct irq_data___129 *);
	int (*irq_set_affinity)(struct irq_data___129 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___129 *);
	int (*irq_set_type)(struct irq_data___129 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___129 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___129 *);
	void (*irq_bus_sync_unlock)(struct irq_data___129 *);
	void (*irq_cpu_online)(struct irq_data___129 *);
	void (*irq_cpu_offline)(struct irq_data___129 *);
	void (*irq_suspend)(struct irq_data___129 *);
	void (*irq_resume)(struct irq_data___129 *);
	void (*irq_pm_shutdown)(struct irq_data___129 *);
	void (*irq_print_chip)(struct irq_data___129 *, struct seq_file___5 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___129 *, void *);
	long unsigned int flags;
};

struct pci_slot___20 {
	struct pci_bus___20 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___20;

struct msi_chip___5;

struct pci_bus___20 {
	struct list_head node;
	struct pci_bus___20 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___20 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___20 *ops;
	struct msi_chip___5 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___38 *bridge;
	struct device___38 dev;
	struct bin_attribute___33 *legacy_io;
	struct bin_attribute___33 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_sriov___7 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___20 *dev;
	struct pci_dev___20 *self;
	struct mutex___50 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___20;

struct pci_driver_rh___20;

struct pci_driver___20 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___20 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___20 *);
	int (*suspend)(struct pci_dev___20 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___20 *, pm_message_t);
	int (*resume_early)(struct pci_dev___20 *);
	int (*resume)(struct pci_dev___20 *);
	void (*shutdown)(struct pci_dev___20 *);
	int (*sriov_configure)(struct pci_dev___20 *, int);
	const struct pci_error_handlers___20 *err_handler;
	struct device_driver___38 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___20 *pci_driver_rh;
};

struct pci_vpd_ops___7;

struct pci_vpd___7 {
	unsigned int len;
	const struct pci_vpd_ops___7 *ops;
	struct bin_attribute___33 *attr;
};

struct pci_ops___20 {
	int (*read)(struct pci_bus___20 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___20 *, unsigned int, int, int, u32);
};

struct msi_chip___5 {
	struct module *owner;
	struct device___38 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___5 *, struct pci_dev___20 *, struct msi_desc___5 *);
	void (*teardown_irq)(struct msi_chip___5 *, unsigned int);
	int (*check_device)(struct msi_chip___5 *, struct pci_dev___20 *, int, int);
};

struct pci_error_handlers___20 {
	pci_ers_result_t (*error_detected)(struct pci_dev___20 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___20 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___20 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___20 *);
	void (*resume)(struct pci_dev___20 *);
};

struct pci_driver_rh___20 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___20 *, bool);
};

struct pci_vpd_ops___7 {
	ssize_t (*read)(struct pci_dev___20 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___20 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___20 *);
};

struct mm_struct___196;

struct pv_mmu_ops___196 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___196 *, struct mm_struct___196 *);
	void (*dup_mmap)(struct mm_struct___196 *, struct mm_struct___196 *);
	void (*exit_mmap)(struct mm_struct___196 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___196 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___196 *);
	void (*pgd_free)(struct mm_struct___196 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___196 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___196 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___196 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___196 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___196 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___196 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___196 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___196 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___196 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___196 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___196 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct vm_area_struct___196;

struct mm_struct___196 {
	struct vm_area_struct___196 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___196 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___196 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___79 context;
	long unsigned int flags;
	struct core_state___190 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___187 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct dma_map_ops___65;

struct dev_archdata___65 {
	struct dma_map_ops___65 *dma_ops;
	void *iommu;
};

struct device_type___156;

struct bus_type___156;

struct device_driver___156;

struct dev_pm_domain___156;

struct class___156;

struct attribute_group___146;

struct device_rh___156;

struct device___156 {
	struct device___156 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___156 *type;
	struct mutex___79 mutex;
	struct bus_type___156 *bus;
	struct device_driver___156 *driver;
	void *platform_data;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___156 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___65 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___18 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___156 *class;
	const struct attribute_group___146 **groups;
	void (*release)(struct device___156 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___156 *device_rh;
};

struct pci_bus___21;

struct pci_slot___21;

struct pci_driver___21;

struct bin_attribute___148;

struct pci_dev___21 {
	struct list_head bus_list;
	struct pci_bus___21 *bus;
	struct pci_bus___21 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___21 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___21 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___156 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___148 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___148 *res_attr[17];
	struct bin_attribute___148 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___146 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___21 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___156 {
	int (*prepare)(struct device___156 *);
	void (*complete)(struct device___156 *);
	int (*suspend)(struct device___156 *);
	int (*resume)(struct device___156 *);
	int (*freeze)(struct device___156 *);
	int (*thaw)(struct device___156 *);
	int (*poweroff)(struct device___156 *);
	int (*restore)(struct device___156 *);
	int (*suspend_late)(struct device___156 *);
	int (*resume_early)(struct device___156 *);
	int (*freeze_late)(struct device___156 *);
	int (*thaw_early)(struct device___156 *);
	int (*poweroff_late)(struct device___156 *);
	int (*restore_early)(struct device___156 *);
	int (*suspend_noirq)(struct device___156 *);
	int (*resume_noirq)(struct device___156 *);
	int (*freeze_noirq)(struct device___156 *);
	int (*thaw_noirq)(struct device___156 *);
	int (*poweroff_noirq)(struct device___156 *);
	int (*restore_noirq)(struct device___156 *);
	int (*runtime_suspend)(struct device___156 *);
	int (*runtime_resume)(struct device___156 *);
	int (*runtime_idle)(struct device___156 *);
};

struct dev_pm_info_rh___156 {
	void (*set_latency_tolerance)(struct device___156 *, s32);
};

struct dev_pm_domain___156 {
	struct dev_pm_ops___156 ops;
};

struct attribute_group___146 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___148 **bin_attrs;
};

struct bin_attribute___148 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file *, struct kobject___20 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file *, struct kobject___20 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	int (*mmap)(struct file *, struct kobject___20 *, struct bin_attribute___148 *, struct vm_area_struct___196 *);
};

struct vm_operations_struct___169;

struct vm_area_struct___196 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___196 *vm_next;
	struct vm_area_struct___196 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___196 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___169 *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dma_map_ops___65 {
	void * (*alloc)(struct device___156 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___156 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___156 *, struct vm_area_struct___196 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___156 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___156 *, struct page___187 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___156 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___156 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___156 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___156 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___156 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___156 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___156 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___156 *, dma_addr_t);
	int (*dma_supported)(struct device___156 *, u64);
	int (*set_dma_mask)(struct device___156 *, u64);
	int is_phys;
};

struct bus_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___156 *, char *);
	ssize_t (*store)(struct bus_type___156 *, const char *, size_t);
};

struct device_attribute___156;

struct driver_attribute___156;

struct bus_type___156 {
	const char *name;
	const char *dev_name;
	struct device___156 *dev_root;
	struct bus_attribute___156 *bus_attrs;
	struct device_attribute___156 *dev_attrs;
	struct driver_attribute___156 *drv_attrs;
	const struct attribute_group___146 **bus_groups;
	const struct attribute_group___146 **dev_groups;
	const struct attribute_group___146 **drv_groups;
	int (*match)(struct device___156 *, struct device_driver___156 *);
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	int (*probe)(struct device___156 *);
	int (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*online)(struct device___156 *);
	int (*offline)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct device___156 *, struct device_attribute___156 *, char *);
	ssize_t (*store)(struct device___156 *, struct device_attribute___156 *, const char *, size_t);
};

struct driver_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___156 *, char *);
	ssize_t (*store)(struct device_driver___156 *, const char *, size_t);
};

struct device_driver___156 {
	const char *name;
	struct bus_type___156 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___156 *);
	int (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	const struct attribute_group___146 **groups;
	const struct dev_pm_ops___156 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___156 {
	const char *name;
	const struct attribute_group___146 **groups;
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
};

struct class_attribute___156;

struct class___156 {
	const char *name;
	struct module *owner;
	struct class_attribute___156 *class_attrs;
	struct device_attribute___156 *dev_attrs;
	const struct attribute_group___146 **dev_groups;
	struct bin_attribute___148 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *);
	void (*class_release)(struct class___156 *);
	void (*dev_release)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
	struct subsys_private *p;
};

struct class_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct class___156 *, struct class_attribute___156 *, char *);
	ssize_t (*store)(struct class___156 *, struct class_attribute___156 *, const char *, size_t);
	const void * (*namespace)(struct class___156 *, const struct class_attribute___156 *);
};

struct device_rh___156 {
	struct dev_pm_info_rh___156 power;
};

struct pci_slot___21 {
	struct pci_bus___21 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___21;

struct pci_bus___21 {
	struct list_head node;
	struct pci_bus___21 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___21 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___21 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___156 *bridge;
	struct device___156 dev;
	struct bin_attribute___148 *legacy_io;
	struct bin_attribute___148 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___21;

struct pci_driver_rh___21;

struct pci_driver___21 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___21 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___21 *);
	int (*suspend)(struct pci_dev___21 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___21 *, pm_message_t);
	int (*resume_early)(struct pci_dev___21 *);
	int (*resume)(struct pci_dev___21 *);
	void (*shutdown)(struct pci_dev___21 *);
	int (*sriov_configure)(struct pci_dev___21 *, int);
	const struct pci_error_handlers___21 *err_handler;
	struct device_driver___156 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___21 *pci_driver_rh;
};

struct pci_ops___21 {
	int (*read)(struct pci_bus___21 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___21 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___21 {
	pci_ers_result_t (*error_detected)(struct pci_dev___21 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___21 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___21 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___21 *);
	void (*resume)(struct pci_dev___21 *);
};

struct pci_driver_rh___21 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___21 *, bool);
};

struct vm_operations_struct___169 {
	void (*open)(struct vm_area_struct___196 *);
	void (*close)(struct vm_area_struct___196 *);
	int (*fault)(struct vm_area_struct___196 *, struct vm_fault___165 *);
	int (*page_mkwrite)(struct vm_area_struct___196 *, struct vm_fault___165 *);
	int (*access)(struct vm_area_struct___196 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___196 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___196 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___196 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___196 *, long unsigned int, long unsigned int, long unsigned int);
};

typedef void ht_irq_update_t(struct pci_dev___21 *, int, struct ht_irq_msg *);

struct ht_irq_cfg {
	struct pci_dev___21 *dev;
	ht_irq_update_t *update;
	unsigned int pos;
	unsigned int idx;
	struct ht_irq_msg msg;
};

struct pci_ats {
	int pos;
	int stu;
	int qdep;
	int ref_cnt;
	unsigned int is_enabled: 1;
};

struct device___157;

struct dev_pm_ops___157 {
	int (*prepare)(struct device___157 *);
	void (*complete)(struct device___157 *);
	int (*suspend)(struct device___157 *);
	int (*resume)(struct device___157 *);
	int (*freeze)(struct device___157 *);
	int (*thaw)(struct device___157 *);
	int (*poweroff)(struct device___157 *);
	int (*restore)(struct device___157 *);
	int (*suspend_late)(struct device___157 *);
	int (*resume_early)(struct device___157 *);
	int (*freeze_late)(struct device___157 *);
	int (*thaw_early)(struct device___157 *);
	int (*poweroff_late)(struct device___157 *);
	int (*restore_early)(struct device___157 *);
	int (*suspend_noirq)(struct device___157 *);
	int (*resume_noirq)(struct device___157 *);
	int (*freeze_noirq)(struct device___157 *);
	int (*thaw_noirq)(struct device___157 *);
	int (*poweroff_noirq)(struct device___157 *);
	int (*restore_noirq)(struct device___157 *);
	int (*runtime_suspend)(struct device___157 *);
	int (*runtime_resume)(struct device___157 *);
	int (*runtime_idle)(struct device___157 *);
};

struct dev_pm_qos___27;

struct dev_pm_info___27 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___27 *qos;
};

struct dma_map_ops___66;

struct dev_archdata___66 {
	struct dma_map_ops___66 *dma_ops;
	void *iommu;
};

struct acpi_device___14;

struct acpi_dev_node___20 {
	union {
		struct acpi_device___14 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___157;

struct bus_type___157;

struct device_driver___157;

struct dev_pm_domain___157;

struct class___157;

struct device_rh___157;

struct device___157 {
	struct device___157 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___157 *type;
	struct mutex___80 mutex;
	struct bus_type___157 *bus;
	struct device_driver___157 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___157 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___66 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___20 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___157 *class;
	const struct attribute_group___55 **groups;
	void (*release)(struct device___157 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___157 *device_rh;
};

struct dev_pm_qos_request___27;

struct dev_pm_qos___27 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___27 *latency_req;
	struct dev_pm_qos_request___27 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___27 *latency_tolerance_req;
};

struct dev_pm_info_rh___157 {
	void (*set_latency_tolerance)(struct device___157 *, s32);
};

struct dev_pm_domain___157 {
	struct dev_pm_ops___157 ops;
};

struct pci_bus___22;

struct pci_slot___22;

struct pci_driver___22;

struct pci_vpd___8;

struct pci_sriov___8;

struct pci_dev___22 {
	struct list_head bus_list;
	struct pci_bus___22 *bus;
	struct pci_bus___22 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___22 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___22 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___157 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___55 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___55 *res_attr[17];
	struct bin_attribute___55 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___3 *msi_kset;
	const struct attribute_group___55 **msi_irq_groups;
	struct pci_vpd___8 *vpd;
	union {
		struct pci_sriov___8 *sriov;
		struct pci_dev___22 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dma_map_ops___66 {
	void * (*alloc)(struct device___157 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___157 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___157 *, struct vm_area_struct___84 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___157 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___157 *, struct page___80 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___157 *, dma_addr_t);
	int (*dma_supported)(struct device___157 *, u64);
	int (*set_dma_mask)(struct device___157 *, u64);
	int is_phys;
};

struct bus_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___157 *, char *);
	ssize_t (*store)(struct bus_type___157 *, const char *, size_t);
};

struct device_attribute___157;

struct driver_attribute___157;

struct bus_type___157 {
	const char *name;
	const char *dev_name;
	struct device___157 *dev_root;
	struct bus_attribute___157 *bus_attrs;
	struct device_attribute___157 *dev_attrs;
	struct driver_attribute___157 *drv_attrs;
	const struct attribute_group___55 **bus_groups;
	const struct attribute_group___55 **dev_groups;
	const struct attribute_group___55 **drv_groups;
	int (*match)(struct device___157 *, struct device_driver___157 *);
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	int (*probe)(struct device___157 *);
	int (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*online)(struct device___157 *);
	int (*offline)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct device___157 *, struct device_attribute___157 *, char *);
	ssize_t (*store)(struct device___157 *, struct device_attribute___157 *, const char *, size_t);
};

struct driver_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___157 *, char *);
	ssize_t (*store)(struct device_driver___157 *, const char *, size_t);
};

struct device_driver___157 {
	const char *name;
	struct bus_type___157 *bus;
	struct module___43 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___157 *);
	int (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	const struct attribute_group___55 **groups;
	const struct dev_pm_ops___157 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___157 {
	const char *name;
	const struct attribute_group___55 **groups;
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
};

struct class_attribute___157;

struct class___157 {
	const char *name;
	struct module___43 *owner;
	struct class_attribute___157 *class_attrs;
	struct device_attribute___157 *dev_attrs;
	const struct attribute_group___55 **dev_groups;
	struct bin_attribute___55 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *);
	void (*class_release)(struct class___157 *);
	void (*dev_release)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
	struct subsys_private *p;
};

struct class_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct class___157 *, struct class_attribute___157 *, char *);
	ssize_t (*store)(struct class___157 *, struct class_attribute___157 *, const char *, size_t);
	const void * (*namespace)(struct class___157 *, const struct class_attribute___157 *);
};

struct acpi_scan_handler___14;

struct acpi_hotplug_context___14;

struct acpi_driver___14;

struct acpi_device___14 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___14 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___14 *handler;
	struct acpi_hotplug_context___14 *hp;
	struct acpi_driver___14 *driver;
	void *driver_data;
	struct device___157 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___80 physical_node_lock;
	void (*remove)(struct acpi_device___14 *);
};

struct device_rh___157 {
	struct dev_pm_info_rh___157 power;
};

struct pci_slot___22 {
	struct pci_bus___22 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___3 kobj;
};

struct pci_ops___22;

struct pci_bus___22 {
	struct list_head node;
	struct pci_bus___22 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___22 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___22 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___157 *bridge;
	struct device___157 dev;
	struct bin_attribute___55 *legacy_io;
	struct bin_attribute___55 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_sriov___8 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u32 pgsz;
	u8 link;
	u16 driver_max_VFs;
	struct pci_dev___22 *dev;
	struct pci_dev___22 *self;
	struct mutex___80 lock;
	struct work_struct mtask;
	u8 *mstate;
	resource_size_t barsz[6];
};

struct pci_error_handlers___22;

struct pci_driver_rh___22;

struct pci_driver___22 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___22 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___22 *);
	int (*suspend)(struct pci_dev___22 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___22 *, pm_message_t);
	int (*resume_early)(struct pci_dev___22 *);
	int (*resume)(struct pci_dev___22 *);
	void (*shutdown)(struct pci_dev___22 *);
	int (*sriov_configure)(struct pci_dev___22 *, int);
	const struct pci_error_handlers___22 *err_handler;
	struct device_driver___157 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___22 *pci_driver_rh;
};

struct pci_vpd_ops___8;

struct pci_vpd___8 {
	unsigned int len;
	const struct pci_vpd_ops___8 *ops;
	struct bin_attribute___55 *attr;
};

struct pci_ops___22 {
	int (*read)(struct pci_bus___22 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___22 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___22 {
	pci_ers_result_t (*error_detected)(struct pci_dev___22 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___22 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___22 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___22 *);
	void (*resume)(struct pci_dev___22 *);
};

struct pci_driver_rh___22 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___22 *, bool);
};

typedef void (*acpi_notify_handler)(acpi_handle, u32, void *);

struct acpi_hotplug_profile___14 {
	struct kobject___3 kobj;
	int (*scan_dependent)(struct acpi_device___14 *);
	void (*notify_online)(struct acpi_device___14 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___14 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___14 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___14 *);
	void (*bind)(struct device___157 *);
	void (*unbind)(struct device___157 *);
	struct acpi_hotplug_profile___14 hotplug;
};

struct acpi_hotplug_context___14 {
	struct acpi_device___14 *self;
	int (*notify)(struct acpi_device___14 *, u32);
	void (*uevent)(struct acpi_device___14 *, u32);
	void (*fixup)(struct acpi_device___14 *);
};

typedef int (*acpi_op_add___14)(struct acpi_device___14 *);

typedef int (*acpi_op_remove___14)(struct acpi_device___14 *);

typedef void (*acpi_op_notify___14)(struct acpi_device___14 *, u32);

struct acpi_device_ops___14 {
	acpi_op_add___14 add;
	acpi_op_remove___14 remove;
	acpi_op_notify___14 notify;
};

struct acpi_driver___14 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___14 ops;
	struct device_driver___157 drv;
	struct module___43 *owner;
};

struct acpi_bus_type {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___157 *);
	struct acpi_device___14 * (*find_companion)(struct device___157 *);
	void (*setup)(struct device___157 *);
	void (*cleanup)(struct device___157 *);
};

enum pm_qos_flags_status {
	PM_QOS_FLAGS_UNDEFINED = 4294967295,
	PM_QOS_FLAGS_NONE = 0,
	PM_QOS_FLAGS_SOME = 1,
	PM_QOS_FLAGS_ALL = 2,
};

struct dev_pm_qos_request___27 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___157 *dev;
};

struct pci_platform_pm_ops___2 {
	bool (*is_manageable)(struct pci_dev___22 *);
	int (*set_state)(struct pci_dev___22 *, pci_power_t);
	pci_power_t (*choose_state)(struct pci_dev___22 *);
	int (*sleep_wake)(struct pci_dev___22 *, bool);
	int (*run_wake)(struct pci_dev___22 *, bool);
};

struct pci_vpd_ops___8 {
	ssize_t (*read)(struct pci_dev___22 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___22 *, loff_t, size_t, const void *);
	void (*release)(struct pci_dev___22 *);
};

enum dmi_device_type {
	DMI_DEV_TYPE_ANY = 0,
	DMI_DEV_TYPE_OTHER = 1,
	DMI_DEV_TYPE_UNKNOWN = 2,
	DMI_DEV_TYPE_VIDEO = 3,
	DMI_DEV_TYPE_SCSI = 4,
	DMI_DEV_TYPE_ETHERNET = 5,
	DMI_DEV_TYPE_TOKENRING = 6,
	DMI_DEV_TYPE_SOUND = 7,
	DMI_DEV_TYPE_PATA = 8,
	DMI_DEV_TYPE_SATA = 9,
	DMI_DEV_TYPE_SAS = 10,
	DMI_DEV_TYPE_IPMI = 4294967295,
	DMI_DEV_TYPE_OEM_STRING = 4294967294,
	DMI_DEV_TYPE_DEV_ONBOARD = 4294967293,
};

struct dmi_device {
	struct list_head list;
	int type;
	const char *name;
	void *device_data;
};

struct dmi_dev_onboard {
	struct dmi_device dev;
	int instance;
	int segment;
	int bus;
	int devfn;
};

enum smbios_attr_enum {
	SMBIOS_ATTR_NONE = 0,
	SMBIOS_ATTR_LABEL_SHOW = 1,
	SMBIOS_ATTR_INSTANCE_SHOW = 2,
};

enum acpi_attr_enum {
	ACPI_ATTR_LABEL_SHOW = 0,
	ACPI_ATTR_INDEX_SHOW = 1,
};

enum hdmi_infoframe_type {
	HDMI_INFOFRAME_TYPE_VENDOR = 129,
	HDMI_INFOFRAME_TYPE_AVI = 130,
	HDMI_INFOFRAME_TYPE_SPD = 131,
	HDMI_INFOFRAME_TYPE_AUDIO = 132,
};

struct hdmi_any_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
};

enum hdmi_colorspace {
	HDMI_COLORSPACE_RGB = 0,
	HDMI_COLORSPACE_YUV422 = 1,
	HDMI_COLORSPACE_YUV444 = 2,
};

enum hdmi_scan_mode {
	HDMI_SCAN_MODE_NONE = 0,
	HDMI_SCAN_MODE_OVERSCAN = 1,
	HDMI_SCAN_MODE_UNDERSCAN = 2,
};

enum hdmi_colorimetry {
	HDMI_COLORIMETRY_NONE = 0,
	HDMI_COLORIMETRY_ITU_601 = 1,
	HDMI_COLORIMETRY_ITU_709 = 2,
	HDMI_COLORIMETRY_EXTENDED = 3,
};

enum hdmi_picture_aspect {
	HDMI_PICTURE_ASPECT_NONE = 0,
	HDMI_PICTURE_ASPECT_4_3 = 1,
	HDMI_PICTURE_ASPECT_16_9 = 2,
};

enum hdmi_active_aspect {
	HDMI_ACTIVE_ASPECT_16_9_TOP = 2,
	HDMI_ACTIVE_ASPECT_14_9_TOP = 3,
	HDMI_ACTIVE_ASPECT_16_9_CENTER = 4,
	HDMI_ACTIVE_ASPECT_PICTURE = 8,
	HDMI_ACTIVE_ASPECT_4_3 = 9,
	HDMI_ACTIVE_ASPECT_16_9 = 10,
	HDMI_ACTIVE_ASPECT_14_9 = 11,
	HDMI_ACTIVE_ASPECT_4_3_SP_14_9 = 13,
	HDMI_ACTIVE_ASPECT_16_9_SP_14_9 = 14,
	HDMI_ACTIVE_ASPECT_16_9_SP_4_3 = 15,
};

enum hdmi_extended_colorimetry {
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_601 = 0,
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_709 = 1,
	HDMI_EXTENDED_COLORIMETRY_S_YCC_601 = 2,
	HDMI_EXTENDED_COLORIMETRY_ADOBE_YCC_601 = 3,
	HDMI_EXTENDED_COLORIMETRY_ADOBE_RGB = 4,
};

enum hdmi_quantization_range {
	HDMI_QUANTIZATION_RANGE_DEFAULT = 0,
	HDMI_QUANTIZATION_RANGE_LIMITED = 1,
	HDMI_QUANTIZATION_RANGE_FULL = 2,
};

enum hdmi_nups {
	HDMI_NUPS_UNKNOWN = 0,
	HDMI_NUPS_HORIZONTAL = 1,
	HDMI_NUPS_VERTICAL = 2,
	HDMI_NUPS_BOTH = 3,
};

enum hdmi_ycc_quantization_range {
	HDMI_YCC_QUANTIZATION_RANGE_LIMITED = 0,
	HDMI_YCC_QUANTIZATION_RANGE_FULL = 1,
};

enum hdmi_content_type {
	HDMI_CONTENT_TYPE_NONE = 0,
	HDMI_CONTENT_TYPE_PHOTO = 1,
	HDMI_CONTENT_TYPE_CINEMA = 2,
	HDMI_CONTENT_TYPE_GAME = 3,
};

struct hdmi_avi_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	enum hdmi_colorspace colorspace;
	enum hdmi_scan_mode scan_mode;
	enum hdmi_colorimetry colorimetry;
	enum hdmi_picture_aspect picture_aspect;
	enum hdmi_active_aspect active_aspect;
	bool itc;
	enum hdmi_extended_colorimetry extended_colorimetry;
	enum hdmi_quantization_range quantization_range;
	enum hdmi_nups nups;
	unsigned char video_code;
	enum hdmi_ycc_quantization_range ycc_quantization_range;
	enum hdmi_content_type content_type;
	unsigned char pixel_repeat;
	short unsigned int top_bar;
	short unsigned int bottom_bar;
	short unsigned int left_bar;
	short unsigned int right_bar;
};

enum hdmi_spd_sdi {
	HDMI_SPD_SDI_UNKNOWN = 0,
	HDMI_SPD_SDI_DSTB = 1,
	HDMI_SPD_SDI_DVDP = 2,
	HDMI_SPD_SDI_DVHS = 3,
	HDMI_SPD_SDI_HDDVR = 4,
	HDMI_SPD_SDI_DVC = 5,
	HDMI_SPD_SDI_DSC = 6,
	HDMI_SPD_SDI_VCD = 7,
	HDMI_SPD_SDI_GAME = 8,
	HDMI_SPD_SDI_PC = 9,
	HDMI_SPD_SDI_BD = 10,
	HDMI_SPD_SDI_SACD = 11,
	HDMI_SPD_SDI_HDDVD = 12,
	HDMI_SPD_SDI_PMP = 13,
};

struct hdmi_spd_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	char vendor[8];
	char product[16];
	enum hdmi_spd_sdi sdi;
};

enum hdmi_audio_coding_type {
	HDMI_AUDIO_CODING_TYPE_STREAM = 0,
	HDMI_AUDIO_CODING_TYPE_PCM = 1,
	HDMI_AUDIO_CODING_TYPE_AC3 = 2,
	HDMI_AUDIO_CODING_TYPE_MPEG1 = 3,
	HDMI_AUDIO_CODING_TYPE_MP3 = 4,
	HDMI_AUDIO_CODING_TYPE_MPEG2 = 5,
	HDMI_AUDIO_CODING_TYPE_AAC_LC = 6,
	HDMI_AUDIO_CODING_TYPE_DTS = 7,
	HDMI_AUDIO_CODING_TYPE_ATRAC = 8,
	HDMI_AUDIO_CODING_TYPE_DSD = 9,
	HDMI_AUDIO_CODING_TYPE_EAC3 = 10,
	HDMI_AUDIO_CODING_TYPE_DTS_HD = 11,
	HDMI_AUDIO_CODING_TYPE_MLP = 12,
	HDMI_AUDIO_CODING_TYPE_DST = 13,
	HDMI_AUDIO_CODING_TYPE_WMA_PRO = 14,
};

enum hdmi_audio_sample_size {
	HDMI_AUDIO_SAMPLE_SIZE_STREAM = 0,
	HDMI_AUDIO_SAMPLE_SIZE_16 = 1,
	HDMI_AUDIO_SAMPLE_SIZE_20 = 2,
	HDMI_AUDIO_SAMPLE_SIZE_24 = 3,
};

enum hdmi_audio_sample_frequency {
	HDMI_AUDIO_SAMPLE_FREQUENCY_STREAM = 0,
	HDMI_AUDIO_SAMPLE_FREQUENCY_32000 = 1,
	HDMI_AUDIO_SAMPLE_FREQUENCY_44100 = 2,
	HDMI_AUDIO_SAMPLE_FREQUENCY_48000 = 3,
	HDMI_AUDIO_SAMPLE_FREQUENCY_88200 = 4,
	HDMI_AUDIO_SAMPLE_FREQUENCY_96000 = 5,
	HDMI_AUDIO_SAMPLE_FREQUENCY_176400 = 6,
	HDMI_AUDIO_SAMPLE_FREQUENCY_192000 = 7,
};

enum hdmi_audio_coding_type_ext {
	HDMI_AUDIO_CODING_TYPE_EXT_STREAM = 0,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC = 1,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC_V2 = 2,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG_SURROUND = 3,
};

struct hdmi_audio_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned char channels;
	enum hdmi_audio_coding_type coding_type;
	enum hdmi_audio_sample_size sample_size;
	enum hdmi_audio_sample_frequency sample_frequency;
	enum hdmi_audio_coding_type_ext coding_type_ext;
	unsigned char channel_allocation;
	unsigned char level_shift_value;
	bool downmix_inhibit;
};

enum hdmi_3d_structure {
	HDMI_3D_STRUCTURE_INVALID = 4294967295,
	HDMI_3D_STRUCTURE_FRAME_PACKING = 0,
	HDMI_3D_STRUCTURE_FIELD_ALTERNATIVE = 1,
	HDMI_3D_STRUCTURE_LINE_ALTERNATIVE = 2,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_FULL = 3,
	HDMI_3D_STRUCTURE_L_DEPTH = 4,
	HDMI_3D_STRUCTURE_L_DEPTH_GFX_GFX_DEPTH = 5,
	HDMI_3D_STRUCTURE_TOP_AND_BOTTOM = 6,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_HALF = 8,
};

struct hdmi_vendor_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned int oui;
	u8 vic;
	enum hdmi_3d_structure s3d_struct;
	unsigned int s3d_ext_data;
};

union hdmi_vendor_any_infoframe {
	struct {
		enum hdmi_infoframe_type type;
		unsigned char version;
		unsigned char length;
		unsigned int oui;
	} any;
	struct hdmi_vendor_infoframe hdmi;
};

union hdmi_infoframe {
	struct hdmi_any_infoframe any;
	struct hdmi_avi_infoframe avi;
	struct hdmi_spd_infoframe spd;
	union hdmi_vendor_any_infoframe vendor;
	struct hdmi_audio_infoframe audio;
};

struct device___158;

struct dev_pm_ops___158 {
	int (*prepare)(struct device___158 *);
	void (*complete)(struct device___158 *);
	int (*suspend)(struct device___158 *);
	int (*resume)(struct device___158 *);
	int (*freeze)(struct device___158 *);
	int (*thaw)(struct device___158 *);
	int (*poweroff)(struct device___158 *);
	int (*restore)(struct device___158 *);
	int (*suspend_late)(struct device___158 *);
	int (*resume_early)(struct device___158 *);
	int (*freeze_late)(struct device___158 *);
	int (*thaw_early)(struct device___158 *);
	int (*poweroff_late)(struct device___158 *);
	int (*restore_early)(struct device___158 *);
	int (*suspend_noirq)(struct device___158 *);
	int (*resume_noirq)(struct device___158 *);
	int (*freeze_noirq)(struct device___158 *);
	int (*thaw_noirq)(struct device___158 *);
	int (*poweroff_noirq)(struct device___158 *);
	int (*restore_noirq)(struct device___158 *);
	int (*runtime_suspend)(struct device___158 *);
	int (*runtime_resume)(struct device___158 *);
	int (*runtime_idle)(struct device___158 *);
};

struct device_type___158;

struct bus_type___158;

struct device_driver___158;

struct dev_pm_domain___158;

struct device_node___7;

struct class___158;

struct device_rh___158;

struct device___158 {
	struct device___158 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___158 *type;
	struct mutex___3 mutex;
	struct bus_type___158 *bus;
	struct device_driver___158 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___158 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___66 archdata;
	struct device_node___7 *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___158 *class;
	const struct attribute_group___56 **groups;
	void (*release)(struct device___158 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___158 *device_rh;
};

struct dev_pm_info_rh___158 {
	void (*set_latency_tolerance)(struct device___158 *, s32);
};

struct dev_pm_domain___158 {
	struct dev_pm_ops___158 ops;
};

struct property___7;

struct device_node___7 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___7 *properties;
	struct property___7 *deadprops;
	struct device_node___7 *parent;
	struct device_node___7 *child;
	struct device_node___7 *sibling;
	struct device_node___7 *next;
	struct device_node___7 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct linux_logo {
	int type;
	unsigned int width;
	unsigned int height;
	unsigned int clutsize;
	const unsigned char *clut;
	const unsigned char *data;
};

struct bus_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___158 *, char *);
	ssize_t (*store)(struct bus_type___158 *, const char *, size_t);
};

struct device_attribute___158;

struct driver_attribute___158;

struct bus_type___158 {
	const char *name;
	const char *dev_name;
	struct device___158 *dev_root;
	struct bus_attribute___158 *bus_attrs;
	struct device_attribute___158 *dev_attrs;
	struct driver_attribute___158 *drv_attrs;
	const struct attribute_group___56 **bus_groups;
	const struct attribute_group___56 **dev_groups;
	const struct attribute_group___56 **drv_groups;
	int (*match)(struct device___158 *, struct device_driver___158 *);
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	int (*probe)(struct device___158 *);
	int (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*online)(struct device___158 *);
	int (*offline)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct device___158 *, struct device_attribute___158 *, char *);
	ssize_t (*store)(struct device___158 *, struct device_attribute___158 *, const char *, size_t);
};

struct driver_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___158 *, char *);
	ssize_t (*store)(struct device_driver___158 *, const char *, size_t);
};

struct device_driver___158 {
	const char *name;
	struct bus_type___158 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___158 *);
	int (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	const struct attribute_group___56 **groups;
	const struct dev_pm_ops___158 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___158 {
	const char *name;
	const struct attribute_group___56 **groups;
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
};

struct class_attribute___158;

struct class___158 {
	const char *name;
	struct module *owner;
	struct class_attribute___158 *class_attrs;
	struct device_attribute___158 *dev_attrs;
	const struct attribute_group___56 **dev_groups;
	struct bin_attribute___56 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *);
	void (*class_release)(struct class___158 *);
	void (*dev_release)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
	struct subsys_private *p;
};

struct class_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct class___158 *, struct class_attribute___158 *, char *);
	ssize_t (*store)(struct class___158 *, struct class_attribute___158 *, const char *, size_t);
	const void * (*namespace)(struct class___158 *, const struct class_attribute___158 *);
};

struct device_rh___158 {
	struct dev_pm_info_rh___158 power;
};

struct property___7 {
	char *name;
	int length;
	void *value;
	struct property___7 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___56 attr;
};

struct fb_fix_screeninfo {
	char id[16];
	long unsigned int smem_start;
	__u32 smem_len;
	__u32 type;
	__u32 type_aux;
	__u32 visual;
	__u16 xpanstep;
	__u16 ypanstep;
	__u16 ywrapstep;
	__u32 line_length;
	long unsigned int mmio_start;
	__u32 mmio_len;
	__u32 accel;
	__u16 capabilities;
	__u16 reserved[2];
};

struct fb_bitfield {
	__u32 offset;
	__u32 length;
	__u32 msb_right;
};

struct fb_var_screeninfo {
	__u32 xres;
	__u32 yres;
	__u32 xres_virtual;
	__u32 yres_virtual;
	__u32 xoffset;
	__u32 yoffset;
	__u32 bits_per_pixel;
	__u32 grayscale;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	__u32 nonstd;
	__u32 activate;
	__u32 height;
	__u32 width;
	__u32 accel_flags;
	__u32 pixclock;
	__u32 left_margin;
	__u32 right_margin;
	__u32 upper_margin;
	__u32 lower_margin;
	__u32 hsync_len;
	__u32 vsync_len;
	__u32 sync;
	__u32 vmode;
	__u32 rotate;
	__u32 colorspace;
	__u32 reserved[4];
};

struct fb_cmap {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

struct fb_con2fbmap {
	__u32 console;
	__u32 framebuffer;
};

enum {
	FB_BLANK_UNBLANK = 0,
	FB_BLANK_NORMAL = 1,
	FB_BLANK_VSYNC_SUSPEND = 2,
	FB_BLANK_HSYNC_SUSPEND = 3,
	FB_BLANK_POWERDOWN = 4,
};

struct fb_copyarea {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 sx;
	__u32 sy;
};

struct fb_fillrect {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 color;
	__u32 rop;
};

struct fb_image {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 fg_color;
	__u32 bg_color;
	__u8 depth;
	const char *data;
	struct fb_cmap cmap;
};

struct fbcurpos {
	__u16 x;
	__u16 y;
};

struct fb_cursor {
	__u16 set;
	__u16 enable;
	__u16 rop;
	const char *mask;
	struct fbcurpos hot;
	struct fb_image image;
};

enum backlight_type {
	BACKLIGHT_RAW = 1,
	BACKLIGHT_PLATFORM = 2,
	BACKLIGHT_FIRMWARE = 3,
	BACKLIGHT_TYPE_MAX = 4,
};

struct backlight_device;

struct fb_info;

struct backlight_ops {
	unsigned int options;
	int (*update_status)(struct backlight_device *);
	int (*get_brightness)(struct backlight_device *);
	int (*check_fb)(struct backlight_device *, struct fb_info *);
};

struct backlight_properties {
	int brightness;
	int max_brightness;
	int power;
	int fb_blank;
	enum backlight_type type;
	unsigned int state;
};

struct backlight_device {
	struct backlight_properties props;
	struct mutex___3 update_lock;
	struct mutex___3 ops_lock;
	const struct backlight_ops *ops;
	struct notifier_block fb_notif;
	struct device___158 dev;
	struct list_head entry;
};

struct fb_chroma {
	__u32 redx;
	__u32 greenx;
	__u32 bluex;
	__u32 whitex;
	__u32 redy;
	__u32 greeny;
	__u32 bluey;
	__u32 whitey;
};

struct fb_videomode;

struct fb_monspecs {
	struct fb_chroma chroma;
	struct fb_videomode *modedb;
	__u8 manufacturer[4];
	__u8 monitor[14];
	__u8 serial_no[14];
	__u8 ascii[14];
	__u32 modedb_len;
	__u32 model;
	__u32 serial;
	__u32 year;
	__u32 week;
	__u32 hfmin;
	__u32 hfmax;
	__u32 dclkmin;
	__u32 dclkmax;
	__u16 input;
	__u16 dpms;
	__u16 signal;
	__u16 vfmin;
	__u16 vfmax;
	__u16 gamma;
	__u16 gtf: 1;
	__u16 misc;
	__u8 version;
	__u8 revision;
	__u8 max_x;
	__u8 max_y;
};

struct fb_pixmap {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info *, void *, void *, unsigned int);
	void (*readio)(struct fb_info *, void *, void *, unsigned int);
};

struct fb_deferred_io;

struct fb_ops;

struct fb_tile_ops;

struct apertures_struct;

struct fb_info {
	atomic_t count;
	int node;
	int flags;
	struct mutex___3 lock;
	struct mutex___3 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap pixmap;
	struct fb_pixmap sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device *bl_dev;
	struct mutex___3 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io *fbdefio;
	struct fb_ops *fbops;
	struct device___158 *device;
	struct device___158 *dev;
	int class_flag;
	struct fb_tile_ops *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_videomode {
	const char *name;
	u32 refresh;
	u32 xres;
	u32 yres;
	u32 pixclock;
	u32 left_margin;
	u32 right_margin;
	u32 upper_margin;
	u32 lower_margin;
	u32 hsync_len;
	u32 vsync_len;
	u32 sync;
	u32 vmode;
	u32 flag;
};

struct fb_cmap_user {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

struct fb_event {
	struct fb_info *info;
	void *data;
};

struct fb_blit_caps {
	u32 x;
	u32 y;
	u32 len;
	u32 flags;
};

struct fb_deferred_io {
	long unsigned int delay;
	struct mutex___3 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info *);
	void (*deferred_io)(struct fb_info *, struct list_head *);
};

struct fb_ops {
	struct module *owner;
	int (*fb_open)(struct fb_info *, int);
	int (*fb_release)(struct fb_info *, int);
	ssize_t (*fb_read)(struct fb_info *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info *);
	int (*fb_set_par)(struct fb_info *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info *);
	int (*fb_blank)(int, struct fb_info *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info *);
	void (*fb_fillrect)(struct fb_info *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info *, int);
	int (*fb_sync)(struct fb_info *);
	int (*fb_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info *, struct vm_area_struct___3 *);
	void (*fb_get_caps)(struct fb_info *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info *);
	int (*fb_debug_enter)(struct fb_info *);
	int (*fb_debug_leave)(struct fb_info *);
};

struct fb_tilemap {
	__u32 width;
	__u32 height;
	__u32 depth;
	__u32 length;
	const __u8 *data;
};

struct fb_tilerect {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 index;
	__u32 fg;
	__u32 bg;
	__u32 rop;
};

struct fb_tilearea {
	__u32 sx;
	__u32 sy;
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
};

struct fb_tileblit {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 fg;
	__u32 bg;
	__u32 length;
	__u32 *indices;
};

struct fb_tilecursor {
	__u32 sx;
	__u32 sy;
	__u32 mode;
	__u32 shape;
	__u32 fg;
	__u32 bg;
};

struct fb_tile_ops {
	void (*fb_settile)(struct fb_info *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info *);
};

struct aperture {
	resource_size_t base;
	resource_size_t size;
};

struct apertures_struct {
	unsigned int count;
	struct aperture ranges[0];
};

struct fb_modelist {
	struct list_head list;
	struct fb_videomode mode;
};

struct logo_data {
	int depth;
	int needs_directpalette;
	int needs_truepalette;
	int needs_cmapreset;
	const struct linux_logo *logo;
};

struct fb_fix_screeninfo32 {
	char id[16];
	compat_caddr_t smem_start;
	u32 smem_len;
	u32 type;
	u32 type_aux;
	u32 visual;
	u16 xpanstep;
	u16 ypanstep;
	u16 ywrapstep;
	u32 line_length;
	compat_caddr_t mmio_start;
	u32 mmio_len;
	u32 accel;
	u16 reserved[3];
};

struct fb_cmap32 {
	u32 start;
	u32 len;
	compat_caddr_t red;
	compat_caddr_t green;
	compat_caddr_t blue;
	compat_caddr_t transp;
};

struct device___159;

struct dev_pm_ops___159 {
	int (*prepare)(struct device___159 *);
	void (*complete)(struct device___159 *);
	int (*suspend)(struct device___159 *);
	int (*resume)(struct device___159 *);
	int (*freeze)(struct device___159 *);
	int (*thaw)(struct device___159 *);
	int (*poweroff)(struct device___159 *);
	int (*restore)(struct device___159 *);
	int (*suspend_late)(struct device___159 *);
	int (*resume_early)(struct device___159 *);
	int (*freeze_late)(struct device___159 *);
	int (*thaw_early)(struct device___159 *);
	int (*poweroff_late)(struct device___159 *);
	int (*restore_early)(struct device___159 *);
	int (*suspend_noirq)(struct device___159 *);
	int (*resume_noirq)(struct device___159 *);
	int (*freeze_noirq)(struct device___159 *);
	int (*thaw_noirq)(struct device___159 *);
	int (*poweroff_noirq)(struct device___159 *);
	int (*restore_noirq)(struct device___159 *);
	int (*runtime_suspend)(struct device___159 *);
	int (*runtime_resume)(struct device___159 *);
	int (*runtime_idle)(struct device___159 *);
};

struct dma_map_ops___67;

struct dev_archdata___67 {
	struct dma_map_ops___67 *dma_ops;
	void *iommu;
};

struct device_type___159;

struct bus_type___159;

struct device_driver___159;

struct dev_pm_domain___159;

struct device_node___8;

struct class___159;

struct device_rh___159;

struct device___159 {
	struct device___159 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___159 *type;
	struct mutex___80 mutex;
	struct bus_type___159 *bus;
	struct device_driver___159 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___159 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___67 archdata;
	struct device_node___8 *of_node;
	struct acpi_dev_node___20 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___159 *class;
	const struct attribute_group___55 **groups;
	void (*release)(struct device___159 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___159 *device_rh;
};

struct dev_pm_info_rh___159 {
	void (*set_latency_tolerance)(struct device___159 *, s32);
};

struct dev_pm_domain___159 {
	struct dev_pm_ops___159 ops;
};

struct property___8;

struct device_node___8 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___8 *properties;
	struct property___8 *deadprops;
	struct device_node___8 *parent;
	struct device_node___8 *child;
	struct device_node___8 *sibling;
	struct device_node___8 *next;
	struct device_node___8 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___3 kobj;
};

struct dma_map_ops___67 {
	void * (*alloc)(struct device___159 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___159 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___159 *, struct vm_area_struct___84 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___159 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___159 *, struct page___80 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___159 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___159 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___159 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___159 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___159 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___159 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___159 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___159 *, dma_addr_t);
	int (*dma_supported)(struct device___159 *, u64);
	int (*set_dma_mask)(struct device___159 *, u64);
	int is_phys;
};

struct bus_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___159 *, char *);
	ssize_t (*store)(struct bus_type___159 *, const char *, size_t);
};

struct device_attribute___159;

struct driver_attribute___159;

struct bus_type___159 {
	const char *name;
	const char *dev_name;
	struct device___159 *dev_root;
	struct bus_attribute___159 *bus_attrs;
	struct device_attribute___159 *dev_attrs;
	struct driver_attribute___159 *drv_attrs;
	const struct attribute_group___55 **bus_groups;
	const struct attribute_group___55 **dev_groups;
	const struct attribute_group___55 **drv_groups;
	int (*match)(struct device___159 *, struct device_driver___159 *);
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	int (*probe)(struct device___159 *);
	int (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*online)(struct device___159 *);
	int (*offline)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct device___159 *, struct device_attribute___159 *, char *);
	ssize_t (*store)(struct device___159 *, struct device_attribute___159 *, const char *, size_t);
};

struct driver_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___159 *, char *);
	ssize_t (*store)(struct device_driver___159 *, const char *, size_t);
};

struct device_driver___159 {
	const char *name;
	struct bus_type___159 *bus;
	struct module___43 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___159 *);
	int (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	const struct attribute_group___55 **groups;
	const struct dev_pm_ops___159 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___159 {
	const char *name;
	const struct attribute_group___55 **groups;
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
};

struct class_attribute___159;

struct class___159 {
	const char *name;
	struct module___43 *owner;
	struct class_attribute___159 *class_attrs;
	struct device_attribute___159 *dev_attrs;
	const struct attribute_group___55 **dev_groups;
	struct bin_attribute___55 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *);
	void (*class_release)(struct class___159 *);
	void (*dev_release)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
	struct subsys_private *p;
};

struct class_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct class___159 *, struct class_attribute___159 *, char *);
	ssize_t (*store)(struct class___159 *, struct class_attribute___159 *, const char *, size_t);
	const void * (*namespace)(struct class___159 *, const struct class_attribute___159 *);
};

struct device_rh___159 {
	struct dev_pm_info_rh___159 power;
};

struct property___8 {
	char *name;
	int length;
	void *value;
	struct property___8 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___55 attr;
};

struct backlight_device___2;

struct fb_info___2;

struct backlight_ops___2 {
	unsigned int options;
	int (*update_status)(struct backlight_device___2 *);
	int (*get_brightness)(struct backlight_device___2 *);
	int (*check_fb)(struct backlight_device___2 *, struct fb_info___2 *);
};

struct backlight_device___2 {
	struct backlight_properties props;
	struct mutex___80 update_lock;
	struct mutex___80 ops_lock;
	const struct backlight_ops___2 *ops;
	struct notifier_block fb_notif;
	struct device___159 dev;
	struct list_head entry;
};

struct fb_pixmap___2 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___2 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___2 *, void *, void *, unsigned int);
};

struct fb_deferred_io___2;

struct fb_ops___2;

struct fb_tile_ops___2;

struct fb_info___2 {
	atomic_t count;
	int node;
	int flags;
	struct mutex___80 lock;
	struct mutex___80 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___2 pixmap;
	struct fb_pixmap___2 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___2 *bl_dev;
	struct mutex___80 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___2 *fbdefio;
	struct fb_ops___2 *fbops;
	struct device___159 *device;
	struct device___159 *dev;
	int class_flag;
	struct fb_tile_ops___2 *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___2 {
	long unsigned int delay;
	struct mutex___80 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___2 *);
	void (*deferred_io)(struct fb_info___2 *, struct list_head *);
};

struct fb_ops___2 {
	struct module___43 *owner;
	int (*fb_open)(struct fb_info___2 *, int);
	int (*fb_release)(struct fb_info___2 *, int);
	ssize_t (*fb_read)(struct fb_info___2 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___2 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___2 *);
	int (*fb_set_par)(struct fb_info___2 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___2 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___2 *);
	int (*fb_blank)(int, struct fb_info___2 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___2 *);
	void (*fb_fillrect)(struct fb_info___2 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___2 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___2 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___2 *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info___2 *, int);
	int (*fb_sync)(struct fb_info___2 *);
	int (*fb_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___2 *, struct vm_area_struct___84 *);
	void (*fb_get_caps)(struct fb_info___2 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___2 *);
	int (*fb_debug_enter)(struct fb_info___2 *);
	int (*fb_debug_leave)(struct fb_info___2 *);
};

struct fb_tile_ops___2 {
	void (*fb_settile)(struct fb_info___2 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___2 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___2 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___2 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___2 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___2 *);
};

struct fb_cvt_data {
	u32 xres;
	u32 yres;
	u32 refresh;
	u32 f_refresh;
	u32 pixclock;
	u32 hperiod;
	u32 hblank;
	u32 hfreq;
	u32 htotal;
	u32 vtotal;
	u32 vsync;
	u32 hsync;
	u32 h_front_porch;
	u32 h_back_porch;
	u32 v_front_porch;
	u32 v_back_porch;
	u32 h_margin;
	u32 v_margin;
	u32 interlace;
	u32 aspect_ratio;
	u32 active_pixels;
	u32 flags;
	u32 status;
};

struct console_font {
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_mode {
	char mode;
	char waitv;
	short int relsig;
	short int acqsig;
	short int frsig;
};

struct vc_data {
	struct tty_port port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct vc {
	struct vc_data *d;
	struct work_struct SAK_work;
};

struct vgastate {
	void *vgabase;
	long unsigned int membase;
	__u32 memsize;
	__u32 flags;
	__u32 depth;
	__u32 num_attr;
	__u32 num_crtc;
	__u32 num_gfx;
	__u32 num_seq;
	void *vidstate;
};

typedef unsigned char u_char;

struct page___188;

typedef struct page___188 *pgtable_t___188;

struct address_space___189;

struct kmem_cache___175;

struct page___188 {
	long unsigned int flags;
	struct address_space___189 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___188 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___188 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___175 *slab_cache;
		struct page___188 *first_page;
	};
	long: 64;
};

struct task_struct___191;

struct pv_cpu_ops___191 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___191 *);
	void (*end_context_switch)(struct task_struct___191 *);
};

struct mutex___192 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___191 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___184 {
	struct page___188 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___197;

struct signal_struct___191;

struct task_struct___191 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___191 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___197 *mm;
	struct mm_struct___197 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___191 *real_parent;
	struct task_struct___191 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___191 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___191 = 0,
		VTIME_USER___191 = 1,
		VTIME_SYS___191 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___191 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___192 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___184 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___197 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___197 *, struct mm_struct___197 *);
	void (*dup_mmap)(struct mm_struct___197 *, struct mm_struct___197 *);
	void (*exit_mmap)(struct mm_struct___197 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___197 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___197 *);
	void (*pgd_free)(struct mm_struct___197 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___197 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___197 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___197 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___197 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___197 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___197 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___197 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___197 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___197 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___197 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___197 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___192 lock;
	void *vdso;
} mm_context_t___192;

struct xol_area___188;

struct uprobes_state___188 {
	struct xol_area___188 *xol_area;
};

struct vm_area_struct___197;

struct file___189;

struct core_state___191;

struct mm_struct___197 {
	struct vm_area_struct___197 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___197 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___197 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___192 context;
	long unsigned int flags;
	struct core_state___191 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___191 *owner;
	struct file___189 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___188 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___105;

struct module_kobject___104 {
	struct kobject___20 kobj;
	struct module___105 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___104;

struct module___105 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___104 mkobj;
	struct module_attribute___104 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___191 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___191;

struct lruvec___191 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___191 *zone;
};

struct pglist_data___191;

struct zone___191 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___191 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___191 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___191 {
	struct zone___191 *zone;
	int zone_idx;
};

struct zonelist___191 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___191 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___191 {
	struct zone___191 node_zones[4];
	struct zonelist___191 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___191 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___160;

struct dev_pm_ops___160 {
	int (*prepare)(struct device___160 *);
	void (*complete)(struct device___160 *);
	int (*suspend)(struct device___160 *);
	int (*resume)(struct device___160 *);
	int (*freeze)(struct device___160 *);
	int (*thaw)(struct device___160 *);
	int (*poweroff)(struct device___160 *);
	int (*restore)(struct device___160 *);
	int (*suspend_late)(struct device___160 *);
	int (*resume_early)(struct device___160 *);
	int (*freeze_late)(struct device___160 *);
	int (*thaw_early)(struct device___160 *);
	int (*poweroff_late)(struct device___160 *);
	int (*restore_early)(struct device___160 *);
	int (*suspend_noirq)(struct device___160 *);
	int (*resume_noirq)(struct device___160 *);
	int (*freeze_noirq)(struct device___160 *);
	int (*thaw_noirq)(struct device___160 *);
	int (*poweroff_noirq)(struct device___160 *);
	int (*restore_noirq)(struct device___160 *);
	int (*runtime_suspend)(struct device___160 *);
	int (*runtime_resume)(struct device___160 *);
	int (*runtime_idle)(struct device___160 *);
};

struct device_type___160;

struct bus_type___160;

struct device_driver___160;

struct dev_pm_domain___160;

struct device_node___9;

struct class___160;

struct attribute_group___147;

struct device_rh___160;

struct device___160 {
	struct device___160 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___160 *type;
	struct mutex___192 mutex;
	struct bus_type___160 *bus;
	struct device_driver___160 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___160 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___67 archdata;
	struct device_node___9 *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___160 *class;
	const struct attribute_group___147 **groups;
	void (*release)(struct device___160 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___160 *device_rh;
};

struct dev_pm_info_rh___160 {
	void (*set_latency_tolerance)(struct device___160 *, s32);
};

struct dev_pm_domain___160 {
	struct dev_pm_ops___160 ops;
};

struct property___9;

struct device_node___9 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___9 *properties;
	struct property___9 *deadprops;
	struct device_node___9 *parent;
	struct device_node___9 *child;
	struct device_node___9 *sibling;
	struct device_node___9 *next;
	struct device_node___9 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___20 kobj;
};

struct smp_ops___191 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___191 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___149;

struct attribute_group___147 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___149 **bin_attrs;
};

struct bin_attribute___149 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___189 *, struct kobject___20 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___189 *, struct kobject___20 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	int (*mmap)(struct file___189 *, struct kobject___20 *, struct bin_attribute___149 *, struct vm_area_struct___197 *);
};

struct dentry___189;

struct path___189 {
	struct vfsmount *mnt;
	struct dentry___189 *dentry;
};

struct inode___189;

struct file_operations___189;

struct file___189 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___189 f_path;
	struct inode___189 *f_inode;
	const struct file_operations___189 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___189 *f_mapping;
	struct mutex___192 f_pos_lock;
};

struct vm_operations_struct___170;

struct vm_area_struct___197 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___197 *vm_next;
	struct vm_area_struct___197 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___197 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___170 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___189 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___104 *, struct module_kobject___104 *, char *);
	ssize_t (*store)(struct module_attribute___104 *, struct module_kobject___104 *, const char *, size_t);
	void (*setup)(struct module___105 *, const char *);
	int (*test)(struct module___105 *);
	void (*free)(struct module___105 *);
};

struct dentry_operations___189;

struct super_block___189;

struct dentry___189 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___189 *d_parent;
	struct qstr d_name;
	struct inode___189 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___189 *d_op;
	struct super_block___189 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___189;

struct address_space___189 {
	struct inode___189 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___192 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___189 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___189;

struct file_lock___189;

struct dquot___189;

struct block_device___189;

struct cdev___45;

struct inode___189 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___189 *i_op;
	struct super_block___189 *i_sb;
	struct address_space___189 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___192 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___189 *i_fop;
	struct file_lock___189 *i_flock;
	struct address_space___189 i_data;
	struct dquot___189 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___189 *i_bdev;
		struct cdev___45 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___189 {
	int (*d_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_hash)(const struct dentry___189 *, struct qstr *);
	int (*d_compare)(const struct dentry___189 *, const struct dentry___189 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___189 *);
	void (*d_release)(struct dentry___189 *);
	void (*d_prune)(struct dentry___189 *);
	void (*d_iput)(struct dentry___189 *, struct inode___189 *);
	char * (*d_dname)(struct dentry___189 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___189 *);
	int (*d_manage)(struct dentry___189 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___189;

struct mem_dqinfo___189 {
	struct quota_format_type___189 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___189;

struct quota_info___189 {
	unsigned int flags;
	struct mutex___192 dqio_mutex;
	struct mutex___192 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___189 *files[2];
	struct mem_dqinfo___189 info[2];
	const struct quota_format_ops___189 *ops[2];
};

struct file_system_type___189;

struct super_operations___189;

struct dquot_operations___189;

struct quotactl_ops___189;

struct super_block___189 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___189 *s_type;
	const struct super_operations___189 *s_op;
	const struct dquot_operations___189 *dq_op;
	const struct quotactl_ops___189 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___189 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___189 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___189 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___192 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___189 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___189 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___189 *bd_inode;
	struct super_block___189 *bd_super;
	struct mutex___192 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___189 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___192 bd_fsfreeze_mutex;
};

struct iattr___189 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___189 *ia_file;
};

struct dquot___189 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___192 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___189 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___189 {
	int qf_fmt_id;
	const struct quota_format_ops___189 *qf_ops;
	struct module___105 *qf_owner;
	struct quota_format_type___189 *qf_next;
};

struct quota_format_ops___189 {
	int (*check_quota_file)(struct super_block___189 *, int);
	int (*read_file_info)(struct super_block___189 *, int);
	int (*write_file_info)(struct super_block___189 *, int);
	int (*free_file_info)(struct super_block___189 *, int);
	int (*read_dqblk)(struct dquot___189 *);
	int (*commit_dqblk)(struct dquot___189 *);
	int (*release_dqblk)(struct dquot___189 *);
};

struct dquot_operations___189 {
	int (*write_dquot)(struct dquot___189 *);
	struct dquot___189 * (*alloc_dquot)(struct super_block___189 *, int);
	void (*destroy_dquot)(struct dquot___189 *);
	int (*acquire_dquot)(struct dquot___189 *);
	int (*release_dquot)(struct dquot___189 *);
	int (*mark_dirty)(struct dquot___189 *);
	int (*write_info)(struct super_block___189 *, int);
	qsize_t * (*get_reserved_space)(struct inode___189 *);
};

struct quotactl_ops___189 {
	int (*quota_on)(struct super_block___189 *, int, int, struct path___189 *);
	int (*quota_on_meta)(struct super_block___189 *, int, int);
	int (*quota_off)(struct super_block___189 *, int);
	int (*quota_sync)(struct super_block___189 *, int);
	int (*get_info)(struct super_block___189 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___189 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___189 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___189 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___189 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___189 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___189 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___189 *, unsigned int);
};

struct address_space_operations___189 {
	int (*writepage)(struct page___188 *, struct writeback_control *);
	int (*readpage)(struct file___189 *, struct page___188 *);
	int (*writepages)(struct address_space___189 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___188 *);
	int (*readpages)(struct file___189 *, struct address_space___189 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___189 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___188 **, void **);
	int (*write_end)(struct file___189 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___188 *, void *);
	sector_t (*bmap)(struct address_space___189 *, sector_t);
	void (*invalidatepage)(struct page___188 *, long unsigned int);
	int (*releasepage)(struct page___188 *, gfp_t);
	void (*freepage)(struct page___188 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___189 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___189 *, struct page___188 *, struct page___188 *, enum migrate_mode);
	int (*launder_page)(struct page___188 *);
	int (*is_partially_uptodate)(struct page___188 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___188 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___189 *, struct page___188 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___189 *, sector_t *);
	void (*swap_deactivate)(struct file___189 *);
	void (*invalidatepage_range)(struct page___188 *, unsigned int, unsigned int);
};

struct cdev___45 {
	struct kobject___20 kobj;
	struct module___105 *owner;
	const struct file_operations___189 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___189 {
	struct dentry___189 * (*lookup)(struct inode___189 *, struct dentry___189 *, unsigned int);
	void * (*follow_link)(struct dentry___189 *, struct nameidata *);
	int (*permission)(struct inode___189 *, int);
	struct posix_acl * (*get_acl)(struct inode___189 *, int);
	int (*readlink)(struct dentry___189 *, char *, int);
	void (*put_link)(struct dentry___189 *, struct nameidata *, void *);
	int (*create)(struct inode___189 *, struct dentry___189 *, umode_t, bool);
	int (*link)(struct dentry___189 *, struct inode___189 *, struct dentry___189 *);
	int (*unlink)(struct inode___189 *, struct dentry___189 *);
	int (*symlink)(struct inode___189 *, struct dentry___189 *, const char *);
	int (*mkdir)(struct inode___189 *, struct dentry___189 *, umode_t);
	int (*rmdir)(struct inode___189 *, struct dentry___189 *);
	int (*mknod)(struct inode___189 *, struct dentry___189 *, umode_t, dev_t);
	int (*rename)(struct inode___189 *, struct dentry___189 *, struct inode___189 *, struct dentry___189 *);
	int (*setattr)(struct dentry___189 *, struct iattr___189 *);
	int (*getattr)(struct vfsmount *, struct dentry___189 *, struct kstat *);
	int (*setxattr)(struct dentry___189 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___189 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___189 *, char *, size_t);
	int (*removexattr)(struct dentry___189 *, const char *);
	int (*fiemap)(struct inode___189 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___189 *, struct timespec *, int);
	int (*atomic_open)(struct inode___189 *, struct dentry___189 *, struct file___189 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___189 {
	struct module___105 *owner;
	loff_t (*llseek)(struct file___189 *, loff_t, int);
	ssize_t (*read)(struct file___189 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___189 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___189 *, void *, filldir_t);
	unsigned int (*poll)(struct file___189 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___189 *, struct vm_area_struct___197 *);
	int (*open)(struct inode___189 *, struct file___189 *);
	int (*flush)(struct file___189 *, fl_owner_t);
	int (*release)(struct inode___189 *, struct file___189 *);
	int (*fsync)(struct file___189 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___189 *, int);
	int (*lock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*sendpage)(struct file___189 *, struct page___188 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___189 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___189 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___189 *, long int, struct file_lock___189 **, void **);
		struct {
			int (*setlease)(struct file___189 *, long int, struct file_lock___189 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___189 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___189 *);
};

struct fasync_struct___189;

struct file_lock_operations___189;

struct lock_manager_operations___189;

struct file_lock___189 {
	struct file_lock___189 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___189 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___189 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___189 *fl_ops;
	const struct lock_manager_operations___189 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___189 {
	void (*fl_copy_lock)(struct file_lock___189 *, struct file_lock___189 *);
	void (*fl_release_private)(struct file_lock___189 *);
};

struct lock_manager_operations___189 {
	int (*lm_compare_owner)(struct file_lock___189 *, struct file_lock___189 *);
	long unsigned int (*lm_owner_key)(struct file_lock___189 *);
	void (*lm_notify)(struct file_lock___189 *);
	int (*lm_grant)(struct file_lock___189 *, struct file_lock___189 *, int);
	void (*lm_break)(struct file_lock___189 *);
	int (*lm_change)(struct file_lock___189 **, int);
};

struct fasync_struct___189 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___189 *fa_next;
	struct file___189 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___189 {
	const char *name;
	int fs_flags;
	struct dentry___189 * (*mount)(struct file_system_type___189 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___189 *);
	struct module___105 *owner;
	struct file_system_type___189 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___189 {
	struct inode___189 * (*alloc_inode)(struct super_block___189 *);
	void (*destroy_inode)(struct inode___189 *);
	void (*dirty_inode)(struct inode___189 *, int);
	int (*write_inode)(struct inode___189 *, struct writeback_control *);
	int (*drop_inode)(struct inode___189 *);
	void (*evict_inode)(struct inode___189 *);
	void (*put_super)(struct super_block___189 *);
	int (*sync_fs)(struct super_block___189 *, int);
	int (*freeze_fs)(struct super_block___189 *);
	int (*unfreeze_fs)(struct super_block___189 *);
	int (*statfs)(struct dentry___189 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___189 *, int *, char *);
	void (*umount_begin)(struct super_block___189 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___189 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___189 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___189 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___189 *);
	ssize_t (*quota_read)(struct super_block___189 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___189 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___189 *);
	int (*bdev_try_to_free_page)(struct super_block___189 *, struct page___188 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___189 *);
	void (*free_cached_objects)(struct super_block___189 *, int);
};

struct vc_data___2;

struct consw___2 {
	struct module___105 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___2 *, int);
	void (*con_deinit)(struct vc_data___2 *);
	void (*con_clear)(struct vc_data___2 *, int, int, int, int);
	void (*con_putc)(struct vc_data___2 *, int, int, int);
	void (*con_putcs)(struct vc_data___2 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___2 *, int);
	int (*con_scroll)(struct vc_data___2 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___2 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___2 *);
	int (*con_blank)(struct vc_data___2 *, int, int);
	int (*con_font_set)(struct vc_data___2 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___2 *, struct console_font *);
	int (*con_font_default)(struct vc_data___2 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___2 *, int);
	int (*con_resize)(struct vc_data___2 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___2 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___2 *, int);
	int (*con_set_origin)(struct vc_data___2 *);
	void (*con_save_screen)(struct vc_data___2 *);
	u8 (*con_build_attr)(struct vc_data___2 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___2 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___2 *, int);
	long unsigned int (*con_getxy)(struct vc_data___2 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___2 *);
	int (*con_debug_leave)(struct vc_data___2 *);
};

struct tty_struct___15;

struct tty_port_operations___15;

struct tty_port___15 {
	struct tty_bufhead buf;
	struct tty_struct___15 *tty;
	struct tty_struct___15 *itty;
	const struct tty_port_operations___15 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___192 mutex;
	struct mutex___192 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct vc_data___2 {
	struct tty_port___15 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___2 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___43 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___2 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct tty_operations___15;

struct tty_driver___15 {
	int magic;
	struct kref kref;
	struct cdev___45 *cdevs;
	struct module___105 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___15 *other;
	struct tty_struct___15 **ttys;
	struct tty_port___15 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___15 *ops;
	struct list_head tty_drivers;
};

struct kmem_cache_cpu___174 {
	void **freelist;
	long unsigned int tid;
	struct page___188 *page;
	struct page___188 *partial;
};

struct memcg_cache_params___175;

struct kmem_cache___175 {
	struct kmem_cache_cpu___174 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___175 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___175 {
	bool is_root_cache;
	union {
		struct kmem_cache___175 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___175 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___160 *, char *);
	ssize_t (*store)(struct bus_type___160 *, const char *, size_t);
};

struct device_attribute___160;

struct driver_attribute___160;

struct bus_type___160 {
	const char *name;
	const char *dev_name;
	struct device___160 *dev_root;
	struct bus_attribute___160 *bus_attrs;
	struct device_attribute___160 *dev_attrs;
	struct driver_attribute___160 *drv_attrs;
	const struct attribute_group___147 **bus_groups;
	const struct attribute_group___147 **dev_groups;
	const struct attribute_group___147 **drv_groups;
	int (*match)(struct device___160 *, struct device_driver___160 *);
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	int (*probe)(struct device___160 *);
	int (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*online)(struct device___160 *);
	int (*offline)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct device___160 *, struct device_attribute___160 *, char *);
	ssize_t (*store)(struct device___160 *, struct device_attribute___160 *, const char *, size_t);
};

struct driver_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___160 *, char *);
	ssize_t (*store)(struct device_driver___160 *, const char *, size_t);
};

struct device_driver___160 {
	const char *name;
	struct bus_type___160 *bus;
	struct module___105 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___160 *);
	int (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	const struct attribute_group___147 **groups;
	const struct dev_pm_ops___160 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___160 {
	const char *name;
	const struct attribute_group___147 **groups;
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
};

struct class_attribute___160;

struct class___160 {
	const char *name;
	struct module___105 *owner;
	struct class_attribute___160 *class_attrs;
	struct device_attribute___160 *dev_attrs;
	const struct attribute_group___147 **dev_groups;
	struct bin_attribute___149 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *);
	void (*class_release)(struct class___160 *);
	void (*dev_release)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
	struct subsys_private *p;
};

struct class_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct class___160 *, struct class_attribute___160 *, char *);
	ssize_t (*store)(struct class___160 *, struct class_attribute___160 *, const char *, size_t);
	const void * (*namespace)(struct class___160 *, const struct class_attribute___160 *);
};

struct device_rh___160 {
	struct dev_pm_info_rh___160 power;
};

struct xol_area___188 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___188 *page;
	long unsigned int vaddr;
};

struct vm_fault___166;

struct vm_operations_struct___170 {
	void (*open)(struct vm_area_struct___197 *);
	void (*close)(struct vm_area_struct___197 *);
	int (*fault)(struct vm_area_struct___197 *, struct vm_fault___166 *);
	int (*page_mkwrite)(struct vm_area_struct___197 *, struct vm_fault___166 *);
	int (*access)(struct vm_area_struct___197 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___197 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___197 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___197 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___197 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___191 {
	struct task_struct___191 *task;
	struct core_thread___191 *next;
};

struct core_state___191 {
	atomic_t nr_threads;
	struct core_thread___191 dumper;
	struct completion startup;
};

struct signal_struct___191 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___191 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___191 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct___15 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___192 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_ldisc___15;

struct tty_struct___15 {
	int magic;
	struct kref kref;
	struct device___160 *dev;
	struct tty_driver___15 *driver;
	const struct tty_operations___15 *ops;
	int index;
	struct mutex___192 ldisc_mutex;
	struct tty_ldisc___15 *ldisc;
	struct mutex___192 atomic_write_lock;
	struct mutex___192 legacy_mutex;
	struct mutex___192 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___43 *pgrp;
	struct pid___43 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___15 *link;
	struct fasync_struct___189 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___15 *port;
	struct ld_semaphore ldisc_sem;
};

struct property___9 {
	char *name;
	int length;
	void *value;
	struct property___9 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___149 attr;
};

struct backlight_device___3;

struct fb_info___3;

struct backlight_ops___3 {
	unsigned int options;
	int (*update_status)(struct backlight_device___3 *);
	int (*get_brightness)(struct backlight_device___3 *);
	int (*check_fb)(struct backlight_device___3 *, struct fb_info___3 *);
};

struct backlight_device___3 {
	struct backlight_properties props;
	struct mutex___192 update_lock;
	struct mutex___192 ops_lock;
	const struct backlight_ops___3 *ops;
	struct notifier_block fb_notif;
	struct device___160 dev;
	struct list_head entry;
};

struct fb_pixmap___3 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___3 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___3 *, void *, void *, unsigned int);
};

struct fb_deferred_io___3;

struct fb_ops___3;

struct fb_tile_ops___3;

struct fb_info___3 {
	atomic_t count;
	int node;
	int flags;
	struct mutex___192 lock;
	struct mutex___192 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___3 pixmap;
	struct fb_pixmap___3 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___3 *bl_dev;
	struct mutex___192 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___3 *fbdefio;
	struct fb_ops___3 *fbops;
	struct device___160 *device;
	struct device___160 *dev;
	int class_flag;
	struct fb_tile_ops___3 *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_event___2 {
	struct fb_info___3 *info;
	void *data;
};

struct fb_deferred_io___3 {
	long unsigned int delay;
	struct mutex___192 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___3 *);
	void (*deferred_io)(struct fb_info___3 *, struct list_head *);
};

struct fb_ops___3 {
	struct module___105 *owner;
	int (*fb_open)(struct fb_info___3 *, int);
	int (*fb_release)(struct fb_info___3 *, int);
	ssize_t (*fb_read)(struct fb_info___3 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___3 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___3 *);
	int (*fb_set_par)(struct fb_info___3 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___3 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___3 *);
	int (*fb_blank)(int, struct fb_info___3 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___3 *);
	void (*fb_fillrect)(struct fb_info___3 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___3 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___3 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___3 *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info___3 *, int);
	int (*fb_sync)(struct fb_info___3 *);
	int (*fb_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___3 *, struct vm_area_struct___197 *);
	void (*fb_get_caps)(struct fb_info___3 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___3 *);
	int (*fb_debug_enter)(struct fb_info___3 *);
	int (*fb_debug_leave)(struct fb_info___3 *);
};

struct fb_tile_ops___3 {
	void (*fb_settile)(struct fb_info___3 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___3 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___3 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___3 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___3 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___3 *);
};

struct tty_operations___15 {
	struct tty_struct___15 * (*lookup)(struct tty_driver___15 *, struct inode___189 *, int);
	int (*install)(struct tty_driver___15 *, struct tty_struct___15 *);
	void (*remove)(struct tty_driver___15 *, struct tty_struct___15 *);
	int (*open)(struct tty_struct___15 *, struct file___189 *);
	void (*close)(struct tty_struct___15 *, struct file___189 *);
	void (*shutdown)(struct tty_struct___15 *);
	void (*cleanup)(struct tty_struct___15 *);
	int (*write)(struct tty_struct___15 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___15 *, unsigned char);
	void (*flush_chars)(struct tty_struct___15 *);
	int (*write_room)(struct tty_struct___15 *);
	int (*chars_in_buffer)(struct tty_struct___15 *);
	int (*ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	void (*throttle)(struct tty_struct___15 *);
	void (*unthrottle)(struct tty_struct___15 *);
	void (*stop)(struct tty_struct___15 *);
	void (*start)(struct tty_struct___15 *);
	void (*hangup)(struct tty_struct___15 *);
	int (*break_ctl)(struct tty_struct___15 *, int);
	void (*flush_buffer)(struct tty_struct___15 *);
	void (*set_ldisc)(struct tty_struct___15 *);
	void (*wait_until_sent)(struct tty_struct___15 *, int);
	void (*send_xchar)(struct tty_struct___15 *, char);
	int (*tiocmget)(struct tty_struct___15 *);
	int (*tiocmset)(struct tty_struct___15 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___15 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___15 *, struct termiox *);
	int (*get_icount)(struct tty_struct___15 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___15 *, int, char *);
	int (*poll_get_char)(struct tty_driver___15 *, int);
	void (*poll_put_char)(struct tty_driver___15 *, int, char);
	const struct file_operations___189 *proc_fops;
};

struct tty_ldisc_ops___15 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___15 *);
	void (*close)(struct tty_struct___15 *);
	void (*flush_buffer)(struct tty_struct___15 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___15 *);
	ssize_t (*read)(struct tty_struct___15 *, struct file___189 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___15 *, struct file___189 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___15 *, struct file___189 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___15 *, struct file___189 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___15 *, struct file___189 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___15 *);
	void (*receive_buf)(struct tty_struct___15 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___15 *);
	void (*dcd_change)(struct tty_struct___15 *, unsigned int);
	struct module___105 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___15 *, int);
};

struct tty_ldisc___15 {
	struct tty_ldisc_ops___15 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___15 *tty;
};

struct tty_port_operations___15 {
	int (*carrier_raised)(struct tty_port___15 *);
	void (*dtr_rts)(struct tty_port___15 *, int);
	void (*shutdown)(struct tty_port___15 *);
	void (*drop)(struct tty_port___15 *);
	int (*activate)(struct tty_port___15 *, struct tty_struct___15 *);
	void (*destruct)(struct tty_port___15 *);
};

struct vc___2 {
	struct vc_data___2 *d;
	struct work_struct SAK_work;
};

struct vm_fault___166 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___188 *page;
};

struct display {
	const u_char *fontdata;
	int userfont;
	u_short scrollmode;
	u_short inverse;
	short int yscroll;
	int vrows;
	int cursor_shape;
	int con_rotate;
	u32 xres_virtual;
	u32 yres_virtual;
	u32 height;
	u32 width;
	u32 bits_per_pixel;
	u32 grayscale;
	u32 nonstd;
	u32 accel_flags;
	u32 rotate;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	const struct fb_videomode *mode;
};

struct fbcon_ops {
	void (*bmove)(struct vc_data___2 *, struct fb_info___3 *, int, int, int, int, int, int);
	void (*clear)(struct vc_data___2 *, struct fb_info___3 *, int, int, int, int);
	void (*putcs)(struct vc_data___2 *, struct fb_info___3 *, const short unsigned int *, int, int, int, int, int);
	void (*clear_margins)(struct vc_data___2 *, struct fb_info___3 *, int);
	void (*cursor)(struct vc_data___2 *, struct fb_info___3 *, int, int, int, int);
	int (*update_start)(struct fb_info___3 *);
	int (*rotate_font)(struct fb_info___3 *, struct vc_data___2 *);
	struct fb_var_screeninfo var;
	struct timer_list cursor_timer;
	struct fb_cursor cursor_state;
	struct display *p;
	int currcon;
	int cursor_flash;
	int cursor_reset;
	int blank_state;
	int graphics;
	int save_graphics;
	int flags;
	int rotate;
	int cur_rotate;
	char *cursor_data;
	u8 *fontbuffer;
	u8 *fontdata;
	u8 *cursor_src;
	u32 cursor_size;
	u32 fd_size;
};

enum {
	FBCON_LOGO_CANSHOW = 4294967295,
	FBCON_LOGO_DRAW = 4294967294,
	FBCON_LOGO_DONTSHOW = 4294967293,
};

struct page___189;

typedef struct page___189 *pgtable_t___189;

struct address_space___190;

struct kmem_cache___176;

struct page___189 {
	long unsigned int flags;
	struct address_space___190 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___189 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___189 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___176 *slab_cache;
		struct page___189 *first_page;
	};
	long: 64;
};

struct task_struct___192;

struct pv_cpu_ops___192 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___192 *);
	void (*end_context_switch)(struct task_struct___192 *);
};

struct mutex___193 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___192 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___185 {
	struct page___189 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___198;

struct signal_struct___192;

struct task_struct___192 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___192 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___198 *mm;
	struct mm_struct___198 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___192 *real_parent;
	struct task_struct___192 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___192 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___192 = 0,
		VTIME_USER___192 = 1,
		VTIME_SYS___192 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___192 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___193 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___185 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___198 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___198 *, struct mm_struct___198 *);
	void (*dup_mmap)(struct mm_struct___198 *, struct mm_struct___198 *);
	void (*exit_mmap)(struct mm_struct___198 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___198 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___198 *);
	void (*pgd_free)(struct mm_struct___198 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___198 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___198 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___198 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___198 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___198 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___198 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___198 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___198 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___198 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___198 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___198 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___193 lock;
	void *vdso;
} mm_context_t___193;

struct xol_area___189;

struct uprobes_state___189 {
	struct xol_area___189 *xol_area;
};

struct vm_area_struct___198;

struct file___190;

struct core_state___192;

struct mm_struct___198 {
	struct vm_area_struct___198 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___198 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___198 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___193 context;
	long unsigned int flags;
	struct core_state___192 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___192 *owner;
	struct file___190 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___189 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___106;

struct module_kobject___105 {
	struct kobject___20 kobj;
	struct module___106 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___105;

struct module___106 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___105 mkobj;
	struct module_attribute___105 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___192 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___192;

struct lruvec___192 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___192 *zone;
};

struct pglist_data___192;

struct zone___192 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___192 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___192 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___192 {
	struct zone___192 *zone;
	int zone_idx;
};

struct zonelist___192 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___192 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___192 {
	struct zone___192 node_zones[4];
	struct zonelist___192 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___192 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___161;

struct dev_pm_ops___161 {
	int (*prepare)(struct device___161 *);
	void (*complete)(struct device___161 *);
	int (*suspend)(struct device___161 *);
	int (*resume)(struct device___161 *);
	int (*freeze)(struct device___161 *);
	int (*thaw)(struct device___161 *);
	int (*poweroff)(struct device___161 *);
	int (*restore)(struct device___161 *);
	int (*suspend_late)(struct device___161 *);
	int (*resume_early)(struct device___161 *);
	int (*freeze_late)(struct device___161 *);
	int (*thaw_early)(struct device___161 *);
	int (*poweroff_late)(struct device___161 *);
	int (*restore_early)(struct device___161 *);
	int (*suspend_noirq)(struct device___161 *);
	int (*resume_noirq)(struct device___161 *);
	int (*freeze_noirq)(struct device___161 *);
	int (*thaw_noirq)(struct device___161 *);
	int (*poweroff_noirq)(struct device___161 *);
	int (*restore_noirq)(struct device___161 *);
	int (*runtime_suspend)(struct device___161 *);
	int (*runtime_resume)(struct device___161 *);
	int (*runtime_idle)(struct device___161 *);
};

struct device_type___161;

struct bus_type___161;

struct device_driver___161;

struct dev_pm_domain___161;

struct device_node___10;

struct class___161;

struct attribute_group___148;

struct device_rh___161;

struct device___161 {
	struct device___161 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___161 *type;
	struct mutex___193 mutex;
	struct bus_type___161 *bus;
	struct device_driver___161 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___161 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___67 archdata;
	struct device_node___10 *of_node;
	struct acpi_dev_node___20 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___161 *class;
	const struct attribute_group___148 **groups;
	void (*release)(struct device___161 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___161 *device_rh;
};

struct dev_pm_info_rh___161 {
	void (*set_latency_tolerance)(struct device___161 *, s32);
};

struct dev_pm_domain___161 {
	struct dev_pm_ops___161 ops;
};

struct property___10;

struct device_node___10 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___10 *properties;
	struct property___10 *deadprops;
	struct device_node___10 *parent;
	struct device_node___10 *child;
	struct device_node___10 *sibling;
	struct device_node___10 *next;
	struct device_node___10 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___20 kobj;
};

struct smp_ops___192 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___192 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___150;

struct attribute_group___148 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___150 **bin_attrs;
};

struct bin_attribute___150 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___190 *, struct kobject___20 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___190 *, struct kobject___20 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	int (*mmap)(struct file___190 *, struct kobject___20 *, struct bin_attribute___150 *, struct vm_area_struct___198 *);
};

struct dentry___190;

struct path___190 {
	struct vfsmount *mnt;
	struct dentry___190 *dentry;
};

struct inode___190;

struct file_operations___190;

struct file___190 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___190 f_path;
	struct inode___190 *f_inode;
	const struct file_operations___190 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___190 *f_mapping;
	struct mutex___193 f_pos_lock;
};

struct vm_operations_struct___171;

struct vm_area_struct___198 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___198 *vm_next;
	struct vm_area_struct___198 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___198 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___171 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___190 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___105 *, struct module_kobject___105 *, char *);
	ssize_t (*store)(struct module_attribute___105 *, struct module_kobject___105 *, const char *, size_t);
	void (*setup)(struct module___106 *, const char *);
	int (*test)(struct module___106 *);
	void (*free)(struct module___106 *);
};

struct kmem_cache_cpu___175 {
	void **freelist;
	long unsigned int tid;
	struct page___189 *page;
	struct page___189 *partial;
};

struct memcg_cache_params___176;

struct kmem_cache___176 {
	struct kmem_cache_cpu___175 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___176 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___176 {
	bool is_root_cache;
	union {
		struct kmem_cache___176 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___176 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___161 *, char *);
	ssize_t (*store)(struct bus_type___161 *, const char *, size_t);
};

struct device_attribute___161;

struct driver_attribute___161;

struct bus_type___161 {
	const char *name;
	const char *dev_name;
	struct device___161 *dev_root;
	struct bus_attribute___161 *bus_attrs;
	struct device_attribute___161 *dev_attrs;
	struct driver_attribute___161 *drv_attrs;
	const struct attribute_group___148 **bus_groups;
	const struct attribute_group___148 **dev_groups;
	const struct attribute_group___148 **drv_groups;
	int (*match)(struct device___161 *, struct device_driver___161 *);
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	int (*probe)(struct device___161 *);
	int (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*online)(struct device___161 *);
	int (*offline)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct device___161 *, struct device_attribute___161 *, char *);
	ssize_t (*store)(struct device___161 *, struct device_attribute___161 *, const char *, size_t);
};

struct driver_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___161 *, char *);
	ssize_t (*store)(struct device_driver___161 *, const char *, size_t);
};

struct device_driver___161 {
	const char *name;
	struct bus_type___161 *bus;
	struct module___106 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___161 *);
	int (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	const struct attribute_group___148 **groups;
	const struct dev_pm_ops___161 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___161 {
	const char *name;
	const struct attribute_group___148 **groups;
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
};

struct class_attribute___161;

struct class___161 {
	const char *name;
	struct module___106 *owner;
	struct class_attribute___161 *class_attrs;
	struct device_attribute___161 *dev_attrs;
	const struct attribute_group___148 **dev_groups;
	struct bin_attribute___150 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *);
	void (*class_release)(struct class___161 *);
	void (*dev_release)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
	struct subsys_private *p;
};

struct class_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct class___161 *, struct class_attribute___161 *, char *);
	ssize_t (*store)(struct class___161 *, struct class_attribute___161 *, const char *, size_t);
	const void * (*namespace)(struct class___161 *, const struct class_attribute___161 *);
};

struct device_rh___161 {
	struct dev_pm_info_rh___161 power;
};

struct xol_area___189 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___189 *page;
	long unsigned int vaddr;
};

struct address_space_operations___190;

struct address_space___190 {
	struct inode___190 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___193 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___190 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___167;

struct vm_operations_struct___171 {
	void (*open)(struct vm_area_struct___198 *);
	void (*close)(struct vm_area_struct___198 *);
	int (*fault)(struct vm_area_struct___198 *, struct vm_fault___167 *);
	int (*page_mkwrite)(struct vm_area_struct___198 *, struct vm_fault___167 *);
	int (*access)(struct vm_area_struct___198 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___198 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___198 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___198 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___198 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___192 {
	struct task_struct___192 *task;
	struct core_thread___192 *next;
};

struct core_state___192 {
	atomic_t nr_threads;
	struct core_thread___192 dumper;
	struct completion startup;
};

struct tty_struct___16;

struct signal_struct___192 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___192 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___192 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct___16 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___193 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___16;

struct tty_operations___16;

struct tty_ldisc___16;

struct fasync_struct___190;

struct tty_port___16;

struct tty_struct___16 {
	int magic;
	struct kref kref;
	struct device___161 *dev;
	struct tty_driver___16 *driver;
	const struct tty_operations___16 *ops;
	int index;
	struct mutex___193 ldisc_mutex;
	struct tty_ldisc___16 *ldisc;
	struct mutex___193 atomic_write_lock;
	struct mutex___193 legacy_mutex;
	struct mutex___193 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___43 *pgrp;
	struct pid___43 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___16 *link;
	struct fasync_struct___190 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___16 *port;
	struct ld_semaphore ldisc_sem;
};

struct property___10 {
	char *name;
	int length;
	void *value;
	struct property___10 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___150 attr;
};

struct dentry_operations___190;

struct super_block___190;

struct dentry___190 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___190 *d_parent;
	struct qstr d_name;
	struct inode___190 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___190 *d_op;
	struct super_block___190 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___190;

struct file_lock___190;

struct dquot___190;

struct block_device___190;

struct cdev___46;

struct inode___190 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___190 *i_op;
	struct super_block___190 *i_sb;
	struct address_space___190 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___193 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___190 *i_fop;
	struct file_lock___190 *i_flock;
	struct address_space___190 i_data;
	struct dquot___190 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___190 *i_bdev;
		struct cdev___46 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___190 {
	int (*d_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_hash)(const struct dentry___190 *, struct qstr *);
	int (*d_compare)(const struct dentry___190 *, const struct dentry___190 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___190 *);
	void (*d_release)(struct dentry___190 *);
	void (*d_prune)(struct dentry___190 *);
	void (*d_iput)(struct dentry___190 *, struct inode___190 *);
	char * (*d_dname)(struct dentry___190 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___190 *);
	int (*d_manage)(struct dentry___190 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___190;

struct mem_dqinfo___190 {
	struct quota_format_type___190 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___190;

struct quota_info___190 {
	unsigned int flags;
	struct mutex___193 dqio_mutex;
	struct mutex___193 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___190 *files[2];
	struct mem_dqinfo___190 info[2];
	const struct quota_format_ops___190 *ops[2];
};

struct file_system_type___190;

struct super_operations___190;

struct dquot_operations___190;

struct quotactl_ops___190;

struct super_block___190 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___190 *s_type;
	const struct super_operations___190 *s_op;
	const struct dquot_operations___190 *dq_op;
	const struct quotactl_ops___190 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___190 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___190 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___190 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___193 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___190 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___190 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___190 *bd_inode;
	struct super_block___190 *bd_super;
	struct mutex___193 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___190 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___193 bd_fsfreeze_mutex;
};

struct iattr___190 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___190 *ia_file;
};

struct dquot___190 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___193 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___190 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___190 {
	int qf_fmt_id;
	const struct quota_format_ops___190 *qf_ops;
	struct module___106 *qf_owner;
	struct quota_format_type___190 *qf_next;
};

struct quota_format_ops___190 {
	int (*check_quota_file)(struct super_block___190 *, int);
	int (*read_file_info)(struct super_block___190 *, int);
	int (*write_file_info)(struct super_block___190 *, int);
	int (*free_file_info)(struct super_block___190 *, int);
	int (*read_dqblk)(struct dquot___190 *);
	int (*commit_dqblk)(struct dquot___190 *);
	int (*release_dqblk)(struct dquot___190 *);
};

struct dquot_operations___190 {
	int (*write_dquot)(struct dquot___190 *);
	struct dquot___190 * (*alloc_dquot)(struct super_block___190 *, int);
	void (*destroy_dquot)(struct dquot___190 *);
	int (*acquire_dquot)(struct dquot___190 *);
	int (*release_dquot)(struct dquot___190 *);
	int (*mark_dirty)(struct dquot___190 *);
	int (*write_info)(struct super_block___190 *, int);
	qsize_t * (*get_reserved_space)(struct inode___190 *);
};

struct quotactl_ops___190 {
	int (*quota_on)(struct super_block___190 *, int, int, struct path___190 *);
	int (*quota_on_meta)(struct super_block___190 *, int, int);
	int (*quota_off)(struct super_block___190 *, int);
	int (*quota_sync)(struct super_block___190 *, int);
	int (*get_info)(struct super_block___190 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___190 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___190 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___190 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___190 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___190 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___190 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___190 *, unsigned int);
};

struct address_space_operations___190 {
	int (*writepage)(struct page___189 *, struct writeback_control *);
	int (*readpage)(struct file___190 *, struct page___189 *);
	int (*writepages)(struct address_space___190 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___189 *);
	int (*readpages)(struct file___190 *, struct address_space___190 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___190 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___189 **, void **);
	int (*write_end)(struct file___190 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___189 *, void *);
	sector_t (*bmap)(struct address_space___190 *, sector_t);
	void (*invalidatepage)(struct page___189 *, long unsigned int);
	int (*releasepage)(struct page___189 *, gfp_t);
	void (*freepage)(struct page___189 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___190 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___190 *, struct page___189 *, struct page___189 *, enum migrate_mode);
	int (*launder_page)(struct page___189 *);
	int (*is_partially_uptodate)(struct page___189 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___189 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___190 *, struct page___189 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___190 *, sector_t *);
	void (*swap_deactivate)(struct file___190 *);
	void (*invalidatepage_range)(struct page___189 *, unsigned int, unsigned int);
};

struct cdev___46 {
	struct kobject___20 kobj;
	struct module___106 *owner;
	const struct file_operations___190 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___190 {
	struct dentry___190 * (*lookup)(struct inode___190 *, struct dentry___190 *, unsigned int);
	void * (*follow_link)(struct dentry___190 *, struct nameidata *);
	int (*permission)(struct inode___190 *, int);
	struct posix_acl * (*get_acl)(struct inode___190 *, int);
	int (*readlink)(struct dentry___190 *, char *, int);
	void (*put_link)(struct dentry___190 *, struct nameidata *, void *);
	int (*create)(struct inode___190 *, struct dentry___190 *, umode_t, bool);
	int (*link)(struct dentry___190 *, struct inode___190 *, struct dentry___190 *);
	int (*unlink)(struct inode___190 *, struct dentry___190 *);
	int (*symlink)(struct inode___190 *, struct dentry___190 *, const char *);
	int (*mkdir)(struct inode___190 *, struct dentry___190 *, umode_t);
	int (*rmdir)(struct inode___190 *, struct dentry___190 *);
	int (*mknod)(struct inode___190 *, struct dentry___190 *, umode_t, dev_t);
	int (*rename)(struct inode___190 *, struct dentry___190 *, struct inode___190 *, struct dentry___190 *);
	int (*setattr)(struct dentry___190 *, struct iattr___190 *);
	int (*getattr)(struct vfsmount *, struct dentry___190 *, struct kstat *);
	int (*setxattr)(struct dentry___190 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___190 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___190 *, char *, size_t);
	int (*removexattr)(struct dentry___190 *, const char *);
	int (*fiemap)(struct inode___190 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___190 *, struct timespec *, int);
	int (*atomic_open)(struct inode___190 *, struct dentry___190 *, struct file___190 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___190 {
	struct module___106 *owner;
	loff_t (*llseek)(struct file___190 *, loff_t, int);
	ssize_t (*read)(struct file___190 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___190 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___190 *, void *, filldir_t);
	unsigned int (*poll)(struct file___190 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___190 *, struct vm_area_struct___198 *);
	int (*open)(struct inode___190 *, struct file___190 *);
	int (*flush)(struct file___190 *, fl_owner_t);
	int (*release)(struct inode___190 *, struct file___190 *);
	int (*fsync)(struct file___190 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___190 *, int);
	int (*lock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*sendpage)(struct file___190 *, struct page___189 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___190 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___190 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___190 *, long int, struct file_lock___190 **, void **);
		struct {
			int (*setlease)(struct file___190 *, long int, struct file_lock___190 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___190 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___190 *);
};

struct file_lock_operations___190;

struct lock_manager_operations___190;

struct file_lock___190 {
	struct file_lock___190 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___190 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___190 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___190 *fl_ops;
	const struct lock_manager_operations___190 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___190 {
	void (*fl_copy_lock)(struct file_lock___190 *, struct file_lock___190 *);
	void (*fl_release_private)(struct file_lock___190 *);
};

struct lock_manager_operations___190 {
	int (*lm_compare_owner)(struct file_lock___190 *, struct file_lock___190 *);
	long unsigned int (*lm_owner_key)(struct file_lock___190 *);
	void (*lm_notify)(struct file_lock___190 *);
	int (*lm_grant)(struct file_lock___190 *, struct file_lock___190 *, int);
	void (*lm_break)(struct file_lock___190 *);
	int (*lm_change)(struct file_lock___190 **, int);
};

struct fasync_struct___190 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___190 *fa_next;
	struct file___190 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___190 {
	const char *name;
	int fs_flags;
	struct dentry___190 * (*mount)(struct file_system_type___190 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___190 *);
	struct module___106 *owner;
	struct file_system_type___190 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___190 {
	struct inode___190 * (*alloc_inode)(struct super_block___190 *);
	void (*destroy_inode)(struct inode___190 *);
	void (*dirty_inode)(struct inode___190 *, int);
	int (*write_inode)(struct inode___190 *, struct writeback_control *);
	int (*drop_inode)(struct inode___190 *);
	void (*evict_inode)(struct inode___190 *);
	void (*put_super)(struct super_block___190 *);
	int (*sync_fs)(struct super_block___190 *, int);
	int (*freeze_fs)(struct super_block___190 *);
	int (*unfreeze_fs)(struct super_block___190 *);
	int (*statfs)(struct dentry___190 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___190 *, int *, char *);
	void (*umount_begin)(struct super_block___190 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___190 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___190 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___190 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___190 *);
	ssize_t (*quota_read)(struct super_block___190 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___190 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___190 *);
	int (*bdev_try_to_free_page)(struct super_block___190 *, struct page___189 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___190 *);
	void (*free_cached_objects)(struct super_block___190 *, int);
};

struct backlight_device___4;

struct fb_info___4;

struct backlight_ops___4 {
	unsigned int options;
	int (*update_status)(struct backlight_device___4 *);
	int (*get_brightness)(struct backlight_device___4 *);
	int (*check_fb)(struct backlight_device___4 *, struct fb_info___4 *);
};

struct backlight_device___4 {
	struct backlight_properties props;
	struct mutex___193 update_lock;
	struct mutex___193 ops_lock;
	const struct backlight_ops___4 *ops;
	struct notifier_block fb_notif;
	struct device___161 dev;
	struct list_head entry;
};

struct fb_pixmap___4 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___4 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___4 *, void *, void *, unsigned int);
};

struct fb_deferred_io___4;

struct fb_ops___4;

struct fb_tile_ops___4;

struct fb_info___4 {
	atomic_t count;
	int node;
	int flags;
	struct mutex___193 lock;
	struct mutex___193 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___4 pixmap;
	struct fb_pixmap___4 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___4 *bl_dev;
	struct mutex___193 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___4 *fbdefio;
	struct fb_ops___4 *fbops;
	struct device___161 *device;
	struct device___161 *dev;
	int class_flag;
	struct fb_tile_ops___4 *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___4 {
	long unsigned int delay;
	struct mutex___193 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___4 *);
	void (*deferred_io)(struct fb_info___4 *, struct list_head *);
};

struct fb_ops___4 {
	struct module___106 *owner;
	int (*fb_open)(struct fb_info___4 *, int);
	int (*fb_release)(struct fb_info___4 *, int);
	ssize_t (*fb_read)(struct fb_info___4 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___4 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___4 *);
	int (*fb_set_par)(struct fb_info___4 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___4 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___4 *);
	int (*fb_blank)(int, struct fb_info___4 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___4 *);
	void (*fb_fillrect)(struct fb_info___4 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___4 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___4 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___4 *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info___4 *, int);
	int (*fb_sync)(struct fb_info___4 *);
	int (*fb_ioctl)(struct fb_info___4 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___4 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___4 *, struct vm_area_struct___198 *);
	void (*fb_get_caps)(struct fb_info___4 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___4 *);
	int (*fb_debug_enter)(struct fb_info___4 *);
	int (*fb_debug_leave)(struct fb_info___4 *);
};

struct fb_tile_ops___4 {
	void (*fb_settile)(struct fb_info___4 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___4 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___4 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___4 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___4 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___4 *);
};

struct tty_operations___16 {
	struct tty_struct___16 * (*lookup)(struct tty_driver___16 *, struct inode___190 *, int);
	int (*install)(struct tty_driver___16 *, struct tty_struct___16 *);
	void (*remove)(struct tty_driver___16 *, struct tty_struct___16 *);
	int (*open)(struct tty_struct___16 *, struct file___190 *);
	void (*close)(struct tty_struct___16 *, struct file___190 *);
	void (*shutdown)(struct tty_struct___16 *);
	void (*cleanup)(struct tty_struct___16 *);
	int (*write)(struct tty_struct___16 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___16 *, unsigned char);
	void (*flush_chars)(struct tty_struct___16 *);
	int (*write_room)(struct tty_struct___16 *);
	int (*chars_in_buffer)(struct tty_struct___16 *);
	int (*ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	void (*throttle)(struct tty_struct___16 *);
	void (*unthrottle)(struct tty_struct___16 *);
	void (*stop)(struct tty_struct___16 *);
	void (*start)(struct tty_struct___16 *);
	void (*hangup)(struct tty_struct___16 *);
	int (*break_ctl)(struct tty_struct___16 *, int);
	void (*flush_buffer)(struct tty_struct___16 *);
	void (*set_ldisc)(struct tty_struct___16 *);
	void (*wait_until_sent)(struct tty_struct___16 *, int);
	void (*send_xchar)(struct tty_struct___16 *, char);
	int (*tiocmget)(struct tty_struct___16 *);
	int (*tiocmset)(struct tty_struct___16 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___16 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___16 *, struct termiox *);
	int (*get_icount)(struct tty_struct___16 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___16 *, int, char *);
	int (*poll_get_char)(struct tty_driver___16 *, int);
	void (*poll_put_char)(struct tty_driver___16 *, int, char);
	const struct file_operations___190 *proc_fops;
};

struct tty_driver___16 {
	int magic;
	struct kref kref;
	struct cdev___46 *cdevs;
	struct module___106 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___16 *other;
	struct tty_struct___16 **ttys;
	struct tty_port___16 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___16 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___16;

struct tty_port___16 {
	struct tty_bufhead buf;
	struct tty_struct___16 *tty;
	struct tty_struct___16 *itty;
	const struct tty_port_operations___16 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___193 mutex;
	struct mutex___193 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___16 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___16 *);
	void (*close)(struct tty_struct___16 *);
	void (*flush_buffer)(struct tty_struct___16 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___16 *);
	ssize_t (*read)(struct tty_struct___16 *, struct file___190 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___16 *, struct file___190 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___16 *, struct file___190 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___16 *, struct file___190 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___16 *, struct file___190 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___16 *);
	void (*receive_buf)(struct tty_struct___16 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___16 *);
	void (*dcd_change)(struct tty_struct___16 *, unsigned int);
	struct module___106 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___16 *, int);
};

struct tty_ldisc___16 {
	struct tty_ldisc_ops___16 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___16 *tty;
};

struct tty_port_operations___16 {
	int (*carrier_raised)(struct tty_port___16 *);
	void (*dtr_rts)(struct tty_port___16 *, int);
	void (*shutdown)(struct tty_port___16 *);
	void (*drop)(struct tty_port___16 *);
	int (*activate)(struct tty_port___16 *, struct tty_struct___16 *);
	void (*destruct)(struct tty_port___16 *);
};

struct consw___3;

struct vc_data___3 {
	struct tty_port___16 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___3 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___43 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___3 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct consw___3 {
	struct module___106 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___3 *, int);
	void (*con_deinit)(struct vc_data___3 *);
	void (*con_clear)(struct vc_data___3 *, int, int, int, int);
	void (*con_putc)(struct vc_data___3 *, int, int, int);
	void (*con_putcs)(struct vc_data___3 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___3 *, int);
	int (*con_scroll)(struct vc_data___3 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___3 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___3 *);
	int (*con_blank)(struct vc_data___3 *, int, int);
	int (*con_font_set)(struct vc_data___3 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___3 *, struct console_font *);
	int (*con_font_default)(struct vc_data___3 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___3 *, int);
	int (*con_resize)(struct vc_data___3 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___3 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___3 *, int);
	int (*con_set_origin)(struct vc_data___3 *);
	void (*con_save_screen)(struct vc_data___3 *);
	u8 (*con_build_attr)(struct vc_data___3 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___3 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___3 *, int);
	long unsigned int (*con_getxy)(struct vc_data___3 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___3 *);
	int (*con_debug_leave)(struct vc_data___3 *);
};

struct vm_fault___167 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___189 *page;
};

struct fbcon_ops___2 {
	void (*bmove)(struct vc_data___3 *, struct fb_info___4 *, int, int, int, int, int, int);
	void (*clear)(struct vc_data___3 *, struct fb_info___4 *, int, int, int, int);
	void (*putcs)(struct vc_data___3 *, struct fb_info___4 *, const short unsigned int *, int, int, int, int, int);
	void (*clear_margins)(struct vc_data___3 *, struct fb_info___4 *, int);
	void (*cursor)(struct vc_data___3 *, struct fb_info___4 *, int, int, int, int);
	int (*update_start)(struct fb_info___4 *);
	int (*rotate_font)(struct fb_info___4 *, struct vc_data___3 *);
	struct fb_var_screeninfo var;
	struct timer_list cursor_timer;
	struct fb_cursor cursor_state;
	struct display *p;
	int currcon;
	int cursor_flash;
	int cursor_reset;
	int blank_state;
	int graphics;
	int save_graphics;
	int flags;
	int rotate;
	int cur_rotate;
	char *cursor_data;
	u8 *fontbuffer;
	u8 *fontdata;
	u8 *cursor_src;
	u32 cursor_size;
	u32 fd_size;
};

enum backlight_update_reason {
	BACKLIGHT_UPDATE_HOTKEY = 0,
	BACKLIGHT_UPDATE_SYSFS = 1,
};

enum backlight_notification {
	BACKLIGHT_REGISTERED = 0,
	BACKLIGHT_UNREGISTERED = 1,
};

struct fb_event___3 {
	struct fb_info___4 *info;
	void *data;
};

struct device___162;

struct dev_pm_ops___162 {
	int (*prepare)(struct device___162 *);
	void (*complete)(struct device___162 *);
	int (*suspend)(struct device___162 *);
	int (*resume)(struct device___162 *);
	int (*freeze)(struct device___162 *);
	int (*thaw)(struct device___162 *);
	int (*poweroff)(struct device___162 *);
	int (*restore)(struct device___162 *);
	int (*suspend_late)(struct device___162 *);
	int (*resume_early)(struct device___162 *);
	int (*freeze_late)(struct device___162 *);
	int (*thaw_early)(struct device___162 *);
	int (*poweroff_late)(struct device___162 *);
	int (*restore_early)(struct device___162 *);
	int (*suspend_noirq)(struct device___162 *);
	int (*resume_noirq)(struct device___162 *);
	int (*freeze_noirq)(struct device___162 *);
	int (*thaw_noirq)(struct device___162 *);
	int (*poweroff_noirq)(struct device___162 *);
	int (*restore_noirq)(struct device___162 *);
	int (*runtime_suspend)(struct device___162 *);
	int (*runtime_resume)(struct device___162 *);
	int (*runtime_idle)(struct device___162 *);
};

struct device_type___162;

struct bus_type___162;

struct device_driver___162;

struct dev_pm_domain___162;

struct device_node___11;

struct class___162;

struct device_rh___162;

struct device___162 {
	struct device___162 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___162 *type;
	struct mutex___90 mutex;
	struct bus_type___162 *bus;
	struct device_driver___162 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___162 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___67 archdata;
	struct device_node___11 *of_node;
	struct acpi_dev_node___13 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___162 *class;
	const struct attribute_group___61 **groups;
	void (*release)(struct device___162 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___162 *device_rh;
};

struct dev_pm_info_rh___162 {
	void (*set_latency_tolerance)(struct device___162 *, s32);
};

struct dev_pm_domain___162 {
	struct dev_pm_ops___162 ops;
};

struct property___11;

struct device_node___11 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___11 *properties;
	struct property___11 *deadprops;
	struct device_node___11 *parent;
	struct device_node___11 *child;
	struct device_node___11 *sibling;
	struct device_node___11 *next;
	struct device_node___11 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct bus_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___162 *, char *);
	ssize_t (*store)(struct bus_type___162 *, const char *, size_t);
};

struct device_attribute___162;

struct driver_attribute___162;

struct bus_type___162 {
	const char *name;
	const char *dev_name;
	struct device___162 *dev_root;
	struct bus_attribute___162 *bus_attrs;
	struct device_attribute___162 *dev_attrs;
	struct driver_attribute___162 *drv_attrs;
	const struct attribute_group___61 **bus_groups;
	const struct attribute_group___61 **dev_groups;
	const struct attribute_group___61 **drv_groups;
	int (*match)(struct device___162 *, struct device_driver___162 *);
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	int (*probe)(struct device___162 *);
	int (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*online)(struct device___162 *);
	int (*offline)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct device___162 *, struct device_attribute___162 *, char *);
	ssize_t (*store)(struct device___162 *, struct device_attribute___162 *, const char *, size_t);
};

struct driver_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___162 *, char *);
	ssize_t (*store)(struct device_driver___162 *, const char *, size_t);
};

struct device_driver___162 {
	const char *name;
	struct bus_type___162 *bus;
	struct module___46 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___162 *);
	int (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	const struct attribute_group___61 **groups;
	const struct dev_pm_ops___162 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___162 {
	const char *name;
	const struct attribute_group___61 **groups;
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
};

struct class_attribute___162;

struct class___162 {
	const char *name;
	struct module___46 *owner;
	struct class_attribute___162 *class_attrs;
	struct device_attribute___162 *dev_attrs;
	const struct attribute_group___61 **dev_groups;
	struct bin_attribute___61 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *);
	void (*class_release)(struct class___162 *);
	void (*dev_release)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
	struct subsys_private *p;
};

struct class_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct class___162 *, struct class_attribute___162 *, char *);
	ssize_t (*store)(struct class___162 *, struct class_attribute___162 *, const char *, size_t);
	const void * (*namespace)(struct class___162 *, const struct class_attribute___162 *);
};

struct device_rh___162 {
	struct dev_pm_info_rh___162 power;
};

struct property___11 {
	char *name;
	int length;
	void *value;
	struct property___11 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___61 attr;
};

struct backlight_device___5;

struct fb_info___5;

struct backlight_ops___5 {
	unsigned int options;
	int (*update_status)(struct backlight_device___5 *);
	int (*get_brightness)(struct backlight_device___5 *);
	int (*check_fb)(struct backlight_device___5 *, struct fb_info___5 *);
};

struct backlight_device___5 {
	struct backlight_properties props;
	struct mutex___90 update_lock;
	struct mutex___90 ops_lock;
	const struct backlight_ops___5 *ops;
	struct notifier_block fb_notif;
	struct device___162 dev;
	struct list_head entry;
};

struct fb_pixmap___5 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___5 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___5 *, void *, void *, unsigned int);
};

struct fb_deferred_io___5;

struct fb_ops___5;

struct fb_tile_ops___5;

struct fb_info___5 {
	atomic_t count;
	int node;
	int flags;
	struct mutex___90 lock;
	struct mutex___90 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___5 pixmap;
	struct fb_pixmap___5 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___5 *bl_dev;
	struct mutex___90 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___5 *fbdefio;
	struct fb_ops___5 *fbops;
	struct device___162 *device;
	struct device___162 *dev;
	int class_flag;
	struct fb_tile_ops___5 *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___5 {
	long unsigned int delay;
	struct mutex___90 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___5 *);
	void (*deferred_io)(struct fb_info___5 *, struct list_head *);
};

struct fb_ops___5 {
	struct module___46 *owner;
	int (*fb_open)(struct fb_info___5 *, int);
	int (*fb_release)(struct fb_info___5 *, int);
	ssize_t (*fb_read)(struct fb_info___5 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___5 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___5 *);
	int (*fb_set_par)(struct fb_info___5 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___5 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___5 *);
	int (*fb_blank)(int, struct fb_info___5 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___5 *);
	void (*fb_fillrect)(struct fb_info___5 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___5 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___5 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___5 *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info___5 *, int);
	int (*fb_sync)(struct fb_info___5 *);
	int (*fb_ioctl)(struct fb_info___5 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___5 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___5 *, struct vm_area_struct___94 *);
	void (*fb_get_caps)(struct fb_info___5 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___5 *);
	int (*fb_debug_enter)(struct fb_info___5 *);
	int (*fb_debug_leave)(struct fb_info___5 *);
};

struct fb_tile_ops___5 {
	void (*fb_settile)(struct fb_info___5 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___5 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___5 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___5 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___5 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___5 *);
};

struct cftype___63 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___90 *, struct file___89 *);
	ssize_t (*read)(struct cgroup___56 *, struct cftype___63 *, struct file___89 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___56 *, struct cftype___63 *);
	s64 (*read_s64)(struct cgroup___56 *, struct cftype___63 *);
	int (*read_map)(struct cgroup___56 *, struct cftype___63 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___56 *, struct cftype___63 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___56 *, struct cftype___63 *, struct file___89 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___56 *, struct cftype___63 *, u64);
	int (*write_s64)(struct cgroup___56 *, struct cftype___63 *, s64);
	int (*write_string)(struct cgroup___56 *, struct cftype___63 *, const char *);
	int (*trigger)(struct cgroup___56 *, unsigned int);
	int (*release)(struct inode___90 *, struct file___89 *);
	int (*register_event)(struct cgroup___56 *, struct cftype___63 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___56 *, struct cftype___63 *, struct eventfd_ctx *);
};

struct cftype_set___59 {
	struct list_head node;
	struct cftype___63 *cfts;
};

struct task_and_cgroup___59 {
	struct task_struct___89 *task;
	struct cgroup___56 *cgrp;
	struct css_set___56 *cg;
};

struct cgroup_taskset___59 {
	struct task_and_cgroup___59 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___56 *cur_cgrp;
};

struct cgroup_subsys___59 {
	struct cgroup_subsys_state___56 * (*css_alloc)(struct cgroup___56 *);
	int (*css_online)(struct cgroup___56 *);
	void (*css_offline)(struct cgroup___56 *);
	void (*css_free)(struct cgroup___56 *);
	int (*can_attach)(struct cgroup___56 *, struct cgroup_taskset___59 *);
	void (*cancel_attach)(struct cgroup___56 *, struct cgroup_taskset___59 *);
	void (*attach)(struct cgroup___56 *, struct cgroup_taskset___59 *);
	void (*fork)(struct task_struct___89 *);
	void (*exit)(struct cgroup___56 *, struct cgroup___56 *, struct task_struct___89 *);
	void (*bind)(struct cgroup___56 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___56 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___63 *base_cftypes;
	struct cftype_set___59 base_cftset;
	struct module___46 *module;
};

struct platform_device___4 {
	const char *name;
	int id;
	bool id_auto;
	struct device___162 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___2 {
	int (*probe)(struct platform_device___4 *);
	int (*remove)(struct platform_device___4 *);
	void (*shutdown)(struct platform_device___4 *);
	int (*suspend)(struct platform_device___4 *, pm_message_t);
	int (*resume)(struct platform_device___4 *);
	struct device_driver___162 driver;
	const struct platform_device_id *id_table;
};

struct pci_bus___23;

struct pci_slot___23;

struct pci_driver___23;

struct pci_dev___23 {
	struct list_head bus_list;
	struct pci_bus___23 *bus;
	struct pci_bus___23 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___23 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___23 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___159 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___55 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___55 *res_attr[17];
	struct bin_attribute___55 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___55 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___23 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct platform_device___5 {
	const char *name;
	int id;
	bool id_auto;
	struct device___159 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___3 {
	int (*probe)(struct platform_device___5 *);
	int (*remove)(struct platform_device___5 *);
	void (*shutdown)(struct platform_device___5 *);
	int (*suspend)(struct platform_device___5 *, pm_message_t);
	int (*resume)(struct platform_device___5 *);
	struct device_driver___159 driver;
	const struct platform_device_id *id_table;
};

struct pci_slot___23 {
	struct pci_bus___23 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___23;

struct pci_bus___23 {
	struct list_head node;
	struct pci_bus___23 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___23 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___23 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___159 *bridge;
	struct device___159 dev;
	struct bin_attribute___55 *legacy_io;
	struct bin_attribute___55 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___23;

struct pci_driver_rh___23;

struct pci_driver___23 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___23 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___23 *);
	int (*suspend)(struct pci_dev___23 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___23 *, pm_message_t);
	int (*resume_early)(struct pci_dev___23 *);
	int (*resume)(struct pci_dev___23 *);
	void (*shutdown)(struct pci_dev___23 *);
	int (*sriov_configure)(struct pci_dev___23 *, int);
	const struct pci_error_handlers___23 *err_handler;
	struct device_driver___159 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___23 *pci_driver_rh;
};

struct pci_ops___23 {
	int (*read)(struct pci_bus___23 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___23 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___23 {
	pci_ers_result_t (*error_detected)(struct pci_dev___23 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___23 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___23 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___23 *);
	void (*resume)(struct pci_dev___23 *);
};

struct pci_driver_rh___23 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___23 *, bool);
};

enum {
	M_I17 = 0,
	M_I20 = 1,
	M_I20_SR = 2,
	M_I24 = 3,
	M_I24_8_1 = 4,
	M_I24_10_1 = 5,
	M_I27_11_1 = 6,
	M_MINI = 7,
	M_MINI_3_1 = 8,
	M_MINI_4_1 = 9,
	M_MB = 10,
	M_MB_2 = 11,
	M_MB_3 = 12,
	M_MB_5_1 = 13,
	M_MB_6_1 = 14,
	M_MB_7_1 = 15,
	M_MB_SR = 16,
	M_MBA = 17,
	M_MBA_3 = 18,
	M_MBP = 19,
	M_MBP_2 = 20,
	M_MBP_2_2 = 21,
	M_MBP_SR = 22,
	M_MBP_4 = 23,
	M_MBP_5_1 = 24,
	M_MBP_5_2 = 25,
	M_MBP_5_3 = 26,
	M_MBP_6_1 = 27,
	M_MBP_6_2 = 28,
	M_MBP_7_1 = 29,
	M_MBP_8_2 = 30,
	M_UNKNOWN = 31,
};

struct efifb_dmi_info {
	char *optname;
	long unsigned int base;
	int stride;
	int width;
	int height;
	int flags;
};

struct exec_domain___47 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___22 *module;
	struct exec_domain___47 *next;
};

struct thread_info___86 {
	struct task_struct___36 *task;
	struct exec_domain___47 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct cpuidle_state_usage {
	long long unsigned int disable;
	long long unsigned int usage;
	long long unsigned int time;
};

struct cpuidle_device;

struct cpuidle_driver;

struct cpuidle_state {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
};

struct cpuidle_driver_kobj;

struct cpuidle_state_kobj;

struct cpuidle_device {
	unsigned int registered: 1;
	unsigned int enabled: 1;
	unsigned int cpu;
	int last_residency;
	int state_count;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct list_head device_list;
	struct kobject kobj;
	struct completion kobj_unregister;
};

struct cpuidle_driver {
	const char *name;
	struct module___22 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct idle_cpu {
	struct cpuidle_state *state_table;
	long unsigned int auto_demotion_disable_flags;
	bool disable_promotion_to_c1e;
};

typedef u8 acpi_owner_id;

union acpi_name_union {
	u32 integer;
	char ascii[4];
};

struct acpi_table_desc {
	acpi_physical_address address;
	struct acpi_table_header *pointer;
	u32 length;
	union acpi_name_union signature;
	acpi_owner_id owner_id;
	u8 flags;
};

struct acpi_madt_io_sapic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 global_irq_base;
	u64 address;
};

struct acpi_madt_interrupt_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u8 type;
	u8 id;
	u8 eid;
	u8 io_sapic_vector;
	u32 global_irq;
	u32 flags;
};

enum acpi_blacklist_predicates {
	all_versions = 0,
	less_than_or_equal = 1,
	equal = 2,
	greater_than_or_equal = 3,
};

struct acpi_blacklist_item {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
	char *table;
	enum acpi_blacklist_predicates oem_revision_predicate;
	char *reason;
	u32 is_critical_error;
};

struct device___163;

struct dev_pm_ops___163 {
	int (*prepare)(struct device___163 *);
	void (*complete)(struct device___163 *);
	int (*suspend)(struct device___163 *);
	int (*resume)(struct device___163 *);
	int (*freeze)(struct device___163 *);
	int (*thaw)(struct device___163 *);
	int (*poweroff)(struct device___163 *);
	int (*restore)(struct device___163 *);
	int (*suspend_late)(struct device___163 *);
	int (*resume_early)(struct device___163 *);
	int (*freeze_late)(struct device___163 *);
	int (*thaw_early)(struct device___163 *);
	int (*poweroff_late)(struct device___163 *);
	int (*restore_early)(struct device___163 *);
	int (*suspend_noirq)(struct device___163 *);
	int (*resume_noirq)(struct device___163 *);
	int (*freeze_noirq)(struct device___163 *);
	int (*thaw_noirq)(struct device___163 *);
	int (*poweroff_noirq)(struct device___163 *);
	int (*restore_noirq)(struct device___163 *);
	int (*runtime_suspend)(struct device___163 *);
	int (*runtime_resume)(struct device___163 *);
	int (*runtime_idle)(struct device___163 *);
};

struct dma_map_ops___68;

struct dev_archdata___68 {
	struct dma_map_ops___68 *dma_ops;
	void *iommu;
};

struct acpi_device___15;

struct acpi_dev_node___21 {
	union {
		struct acpi_device___15 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct device_type___163;

struct bus_type___163;

struct device_driver___163;

struct dev_pm_domain___163;

struct class___163;

struct device_rh___163;

struct device___163 {
	struct device___163 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___163 *type;
	struct mutex___53 mutex;
	struct bus_type___163 *bus;
	struct device_driver___163 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___163 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___68 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___21 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___163 *class;
	const struct attribute_group___36 **groups;
	void (*release)(struct device___163 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___163 *device_rh;
};

struct dev_pm_info_rh___163 {
	void (*set_latency_tolerance)(struct device___163 *, s32);
};

struct dev_pm_domain___163 {
	struct dev_pm_ops___163 ops;
};

struct dma_map_ops___68 {
	void * (*alloc)(struct device___163 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___163 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___163 *, struct vm_area_struct___56 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___163 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___163 *, struct page___52 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___163 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___163 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___163 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___163 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___163 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___163 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___163 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___163 *, dma_addr_t);
	int (*dma_supported)(struct device___163 *, u64);
	int (*set_dma_mask)(struct device___163 *, u64);
	int is_phys;
};

struct bus_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___163 *, char *);
	ssize_t (*store)(struct bus_type___163 *, const char *, size_t);
};

struct device_attribute___163;

struct driver_attribute___163;

struct bus_type___163 {
	const char *name;
	const char *dev_name;
	struct device___163 *dev_root;
	struct bus_attribute___163 *bus_attrs;
	struct device_attribute___163 *dev_attrs;
	struct driver_attribute___163 *drv_attrs;
	const struct attribute_group___36 **bus_groups;
	const struct attribute_group___36 **dev_groups;
	const struct attribute_group___36 **drv_groups;
	int (*match)(struct device___163 *, struct device_driver___163 *);
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	int (*probe)(struct device___163 *);
	int (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*online)(struct device___163 *);
	int (*offline)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct device___163 *, struct device_attribute___163 *, char *);
	ssize_t (*store)(struct device___163 *, struct device_attribute___163 *, const char *, size_t);
};

struct driver_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___163 *, char *);
	ssize_t (*store)(struct device_driver___163 *, const char *, size_t);
};

struct device_driver___163 {
	const char *name;
	struct bus_type___163 *bus;
	struct module___35 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___163 *);
	int (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	const struct attribute_group___36 **groups;
	const struct dev_pm_ops___163 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___163 {
	const char *name;
	const struct attribute_group___36 **groups;
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
};

struct class_attribute___163;

struct class___163 {
	const char *name;
	struct module___35 *owner;
	struct class_attribute___163 *class_attrs;
	struct device_attribute___163 *dev_attrs;
	const struct attribute_group___36 **dev_groups;
	struct bin_attribute___36 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *);
	void (*class_release)(struct class___163 *);
	void (*dev_release)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
	struct subsys_private *p;
};

struct class_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct class___163 *, struct class_attribute___163 *, char *);
	ssize_t (*store)(struct class___163 *, struct class_attribute___163 *, const char *, size_t);
	const void * (*namespace)(struct class___163 *, const struct class_attribute___163 *);
};

struct acpi_scan_handler___15;

struct acpi_hotplug_context___15;

struct acpi_driver___15;

struct acpi_device___15 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___15 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___15 *handler;
	struct acpi_hotplug_context___15 *hp;
	struct acpi_driver___15 *driver;
	void *driver_data;
	struct device___163 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___53 physical_node_lock;
	void (*remove)(struct acpi_device___15 *);
};

struct device_rh___163 {
	struct dev_pm_info_rh___163 power;
};

struct acpi_predefined_names {
	char *name;
	u8 type;
	char *val;
};

typedef u32 (*acpi_osd_handler)(void *);

typedef void (*acpi_osd_exec_callback)(void *);

typedef u32 (*acpi_interface_handler)(acpi_string, u32);

struct acpi_pci_id {
	u16 segment;
	u16 bus;
	u16 device;
	u16 function;
};

typedef enum {
	OSL_GLOBAL_LOCK_HANDLER = 0,
	OSL_NOTIFY_HANDLER = 1,
	OSL_GPE_HANDLER = 2,
	OSL_DEBUGGER_THREAD = 3,
	OSL_EC_POLL_HANDLER = 4,
	OSL_EC_BURST_HANDLER = 5,
} acpi_execute_type;

struct acpi_hotplug_profile___15 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___15 *);
	void (*notify_online)(struct acpi_device___15 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___15 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___15 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___15 *);
	void (*bind)(struct device___163 *);
	void (*unbind)(struct device___163 *);
	struct acpi_hotplug_profile___15 hotplug;
};

struct acpi_hotplug_context___15 {
	struct acpi_device___15 *self;
	int (*notify)(struct acpi_device___15 *, u32);
	void (*uevent)(struct acpi_device___15 *, u32);
	void (*fixup)(struct acpi_device___15 *);
};

typedef int (*acpi_op_add___15)(struct acpi_device___15 *);

typedef int (*acpi_op_remove___15)(struct acpi_device___15 *);

typedef void (*acpi_op_notify___15)(struct acpi_device___15 *, u32);

struct acpi_device_ops___15 {
	acpi_op_add___15 add;
	acpi_op_remove___15 remove;
	acpi_op_notify___15 notify;
};

struct acpi_driver___15 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___15 ops;
	struct device_driver___163 drv;
	struct module___35 *owner;
};

struct acpi_os_dpc {
	acpi_osd_exec_callback function;
	void *context;
	struct work_struct work;
};

struct acpi_ioremap {
	struct list_head list;
	void *virt;
	acpi_physical_address phys;
	acpi_size size;
	long unsigned int refcount;
};

struct osi_linux {
	unsigned int enable: 1;
	unsigned int dmi: 1;
	unsigned int cmdline: 1;
};

struct acpi_hp_work {
	struct work_struct work;
	struct acpi_device___15 *adev;
	u32 src;
};

struct osi_setup_entry {
	char string[64];
	bool enable;
};

struct acpi_pld_info {
	u8 revision;
	u8 ignore_color;
	u32 color;
	u16 width;
	u16 height;
	u8 user_visible;
	u8 dock;
	u8 lid;
	u8 panel;
	u8 vertical_position;
	u8 horizontal_position;
	u8 shape;
	u8 group_orientation;
	u8 group_token;
	u8 group_position;
	u8 bay;
	u8 ejectable;
	u8 ospm_eject_required;
	u8 cabinet_number;
	u8 card_cage_number;
	u8 reference;
	u8 rotation;
	u8 order;
	u8 reserved;
	u16 vertical_offset;
	u16 horizontal_offset;
};

struct acpi_handle_list {
	u32 count;
	acpi_handle handles[10];
};

struct nvs_region {
	__u64 phys_start;
	__u64 size;
	struct list_head node;
};

struct nvs_page {
	long unsigned int phys_start;
	unsigned int size;
	void *kaddr;
	void *data;
	bool unmap;
	struct list_head node;
};

struct page___190;

typedef struct page___190 *pgtable_t___190;

struct address_space___191;

struct kmem_cache___177;

struct page___190 {
	long unsigned int flags;
	struct address_space___191 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___190 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___190 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___177 *slab_cache;
		struct page___190 *first_page;
	};
	long: 64;
};

struct task_struct___193;

struct pv_cpu_ops___193 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___193 *);
	void (*end_context_switch)(struct task_struct___193 *);
};

struct mutex___194 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___193 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___186 {
	struct page___190 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___199;

struct signal_struct___193;

struct css_set___118;

struct task_struct___193 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___193 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___199 *mm;
	struct mm_struct___199 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___193 *real_parent;
	struct task_struct___193 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___193 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___193 = 0,
		VTIME_USER___193 = 1,
		VTIME_SYS___193 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___193 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___118 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___194 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___186 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___199 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___199 *, struct mm_struct___199 *);
	void (*dup_mmap)(struct mm_struct___199 *, struct mm_struct___199 *);
	void (*exit_mmap)(struct mm_struct___199 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___199 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___199 *);
	void (*pgd_free)(struct mm_struct___199 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___199 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___199 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___199 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___199 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___199 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___199 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___199 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___199 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___199 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___199 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___199 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___194 lock;
	void *vdso;
} mm_context_t___194;

struct xol_area___190;

struct uprobes_state___190 {
	struct xol_area___190 *xol_area;
};

struct vm_area_struct___199;

struct file___191;

struct core_state___193;

struct mm_struct___199 {
	struct vm_area_struct___199 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___199 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___199 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___194 context;
	long unsigned int flags;
	struct core_state___193 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___193 *owner;
	struct file___191 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___190 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___107;

struct module_kobject___106 {
	struct kobject___20 kobj;
	struct module___107 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___106;

struct module___107 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___106 mkobj;
	struct module_attribute___106 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___193 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct device___164;

struct dev_pm_ops___164 {
	int (*prepare)(struct device___164 *);
	void (*complete)(struct device___164 *);
	int (*suspend)(struct device___164 *);
	int (*resume)(struct device___164 *);
	int (*freeze)(struct device___164 *);
	int (*thaw)(struct device___164 *);
	int (*poweroff)(struct device___164 *);
	int (*restore)(struct device___164 *);
	int (*suspend_late)(struct device___164 *);
	int (*resume_early)(struct device___164 *);
	int (*freeze_late)(struct device___164 *);
	int (*thaw_early)(struct device___164 *);
	int (*poweroff_late)(struct device___164 *);
	int (*restore_early)(struct device___164 *);
	int (*suspend_noirq)(struct device___164 *);
	int (*resume_noirq)(struct device___164 *);
	int (*freeze_noirq)(struct device___164 *);
	int (*thaw_noirq)(struct device___164 *);
	int (*poweroff_noirq)(struct device___164 *);
	int (*restore_noirq)(struct device___164 *);
	int (*runtime_suspend)(struct device___164 *);
	int (*runtime_resume)(struct device___164 *);
	int (*runtime_idle)(struct device___164 *);
};

struct acpi_device___16;

struct acpi_dev_node___22 {
	union {
		struct acpi_device___16 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___164;

struct bus_type___164;

struct device_driver___164;

struct dev_pm_domain___164;

struct class___164;

struct attribute_group___149;

struct device_rh___164;

struct device___164 {
	struct device___164 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___164 *type;
	struct mutex___194 mutex;
	struct bus_type___164 *bus;
	struct device_driver___164 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___164 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___68 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___22 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___164 *class;
	const struct attribute_group___149 **groups;
	void (*release)(struct device___164 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___164 *device_rh;
};

struct dev_pm_info_rh___164 {
	void (*set_latency_tolerance)(struct device___164 *, s32);
};

struct dev_pm_domain___164 {
	struct dev_pm_ops___164 ops;
};

struct smp_ops___193 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___193 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___193;

struct lruvec___193 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___193 *zone;
};

struct pglist_data___193;

struct zone___193 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___193 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___193 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___193 {
	struct zone___193 *zone;
	int zone_idx;
};

struct zonelist___193 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___193 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___193 {
	struct zone___193 node_zones[4];
	struct zonelist___193 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___193 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___151;

struct attribute_group___149 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___151 **bin_attrs;
};

struct bin_attribute___151 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___191 *, struct kobject___20 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___191 *, struct kobject___20 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	int (*mmap)(struct file___191 *, struct kobject___20 *, struct bin_attribute___151 *, struct vm_area_struct___199 *);
};

struct dentry___191;

struct path___191 {
	struct vfsmount *mnt;
	struct dentry___191 *dentry;
};

struct inode___191;

struct file_operations___191;

struct file___191 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___191 f_path;
	struct inode___191 *f_inode;
	const struct file_operations___191 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___191 *f_mapping;
	struct mutex___194 f_pos_lock;
};

struct vm_operations_struct___172;

struct vm_area_struct___199 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___199 *vm_next;
	struct vm_area_struct___199 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___199 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___172 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___191 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___164 *, char *);
	ssize_t (*store)(struct bus_type___164 *, const char *, size_t);
};

struct device_attribute___164;

struct driver_attribute___164;

struct bus_type___164 {
	const char *name;
	const char *dev_name;
	struct device___164 *dev_root;
	struct bus_attribute___164 *bus_attrs;
	struct device_attribute___164 *dev_attrs;
	struct driver_attribute___164 *drv_attrs;
	const struct attribute_group___149 **bus_groups;
	const struct attribute_group___149 **dev_groups;
	const struct attribute_group___149 **drv_groups;
	int (*match)(struct device___164 *, struct device_driver___164 *);
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	int (*probe)(struct device___164 *);
	int (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*online)(struct device___164 *);
	int (*offline)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct device___164 *, struct device_attribute___164 *, char *);
	ssize_t (*store)(struct device___164 *, struct device_attribute___164 *, const char *, size_t);
};

struct driver_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___164 *, char *);
	ssize_t (*store)(struct device_driver___164 *, const char *, size_t);
};

struct device_driver___164 {
	const char *name;
	struct bus_type___164 *bus;
	struct module___107 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___164 *);
	int (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	const struct attribute_group___149 **groups;
	const struct dev_pm_ops___164 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___164 {
	const char *name;
	const struct attribute_group___149 **groups;
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
};

struct class_attribute___164;

struct class___164 {
	const char *name;
	struct module___107 *owner;
	struct class_attribute___164 *class_attrs;
	struct device_attribute___164 *dev_attrs;
	const struct attribute_group___149 **dev_groups;
	struct bin_attribute___151 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *);
	void (*class_release)(struct class___164 *);
	void (*dev_release)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
	struct subsys_private *p;
};

struct class_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct class___164 *, struct class_attribute___164 *, char *);
	ssize_t (*store)(struct class___164 *, struct class_attribute___164 *, const char *, size_t);
	const void * (*namespace)(struct class___164 *, const struct class_attribute___164 *);
};

struct acpi_scan_handler___16;

struct acpi_hotplug_context___16;

struct acpi_driver___16;

struct acpi_device___16 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___16 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___16 *handler;
	struct acpi_hotplug_context___16 *hp;
	struct acpi_driver___16 *driver;
	void *driver_data;
	struct device___164 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___194 physical_node_lock;
	void (*remove)(struct acpi_device___16 *);
};

struct device_rh___164 {
	struct dev_pm_info_rh___164 power;
};

struct xol_area___190 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___190 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___176;

struct memcg_cache_params___177;

struct kmem_cache___177 {
	struct kmem_cache_cpu___176 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___177 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___191;

struct address_space___191 {
	struct inode___191 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___194 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___191 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___168;

struct vm_operations_struct___172 {
	void (*open)(struct vm_area_struct___199 *);
	void (*close)(struct vm_area_struct___199 *);
	int (*fault)(struct vm_area_struct___199 *, struct vm_fault___168 *);
	int (*page_mkwrite)(struct vm_area_struct___199 *, struct vm_fault___168 *);
	int (*access)(struct vm_area_struct___199 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___199 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___199 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___199 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___199 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___193 {
	struct task_struct___193 *task;
	struct core_thread___193 *next;
};

struct core_state___193 {
	atomic_t nr_threads;
	struct core_thread___193 dumper;
	struct completion startup;
};

struct signal_struct___193 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___193 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___193 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___194 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___118;

struct css_set___118 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___118 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___176 {
	void **freelist;
	long unsigned int tid;
	struct page___190 *page;
	struct page___190 *partial;
};

struct memcg_cache_params___177 {
	bool is_root_cache;
	union {
		struct kmem_cache___177 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___177 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xattr_handler___119 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___191 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___191 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___191 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___191;

struct super_block___191;

struct dentry___191 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___191 *d_parent;
	struct qstr d_name;
	struct inode___191 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___191 *d_op;
	struct super_block___191 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___191;

struct file_lock___191;

struct dquot___191;

struct block_device___191;

struct inode___191 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___191 *i_op;
	struct super_block___191 *i_sb;
	struct address_space___191 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___194 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___191 *i_fop;
	struct file_lock___191 *i_flock;
	struct address_space___191 i_data;
	struct dquot___191 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___191 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___191 {
	int (*d_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_hash)(const struct dentry___191 *, struct qstr *);
	int (*d_compare)(const struct dentry___191 *, const struct dentry___191 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___191 *);
	void (*d_release)(struct dentry___191 *);
	void (*d_prune)(struct dentry___191 *);
	void (*d_iput)(struct dentry___191 *, struct inode___191 *);
	char * (*d_dname)(struct dentry___191 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___191 *);
	int (*d_manage)(struct dentry___191 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___191;

struct mem_dqinfo___191 {
	struct quota_format_type___191 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___191;

struct quota_info___191 {
	unsigned int flags;
	struct mutex___194 dqio_mutex;
	struct mutex___194 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___191 *files[2];
	struct mem_dqinfo___191 info[2];
	const struct quota_format_ops___191 *ops[2];
};

struct file_system_type___191;

struct super_operations___191;

struct dquot_operations___191;

struct quotactl_ops___191;

struct super_block___191 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___191 *s_type;
	const struct super_operations___191 *s_op;
	const struct dquot_operations___191 *dq_op;
	const struct quotactl_ops___191 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___191 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___119 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___191 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___191 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___194 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___191 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___191 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___191 *bd_inode;
	struct super_block___191 *bd_super;
	struct mutex___194 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___191 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___194 bd_fsfreeze_mutex;
};

struct cgroup___118;

struct cgroup_subsys_state___118 {
	struct cgroup___118 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___191 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___191 *ia_file;
};

struct dquot___191 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___194 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___191 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___191 {
	int qf_fmt_id;
	const struct quota_format_ops___191 *qf_ops;
	struct module___107 *qf_owner;
	struct quota_format_type___191 *qf_next;
};

struct quota_format_ops___191 {
	int (*check_quota_file)(struct super_block___191 *, int);
	int (*read_file_info)(struct super_block___191 *, int);
	int (*write_file_info)(struct super_block___191 *, int);
	int (*free_file_info)(struct super_block___191 *, int);
	int (*read_dqblk)(struct dquot___191 *);
	int (*commit_dqblk)(struct dquot___191 *);
	int (*release_dqblk)(struct dquot___191 *);
};

struct dquot_operations___191 {
	int (*write_dquot)(struct dquot___191 *);
	struct dquot___191 * (*alloc_dquot)(struct super_block___191 *, int);
	void (*destroy_dquot)(struct dquot___191 *);
	int (*acquire_dquot)(struct dquot___191 *);
	int (*release_dquot)(struct dquot___191 *);
	int (*mark_dirty)(struct dquot___191 *);
	int (*write_info)(struct super_block___191 *, int);
	qsize_t * (*get_reserved_space)(struct inode___191 *);
};

struct quotactl_ops___191 {
	int (*quota_on)(struct super_block___191 *, int, int, struct path___191 *);
	int (*quota_on_meta)(struct super_block___191 *, int, int);
	int (*quota_off)(struct super_block___191 *, int);
	int (*quota_sync)(struct super_block___191 *, int);
	int (*get_info)(struct super_block___191 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___191 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___191 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___191 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___191 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___191 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___191 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___191 *, unsigned int);
};

struct swap_info_struct___40;

struct address_space_operations___191 {
	int (*writepage)(struct page___190 *, struct writeback_control *);
	int (*readpage)(struct file___191 *, struct page___190 *);
	int (*writepages)(struct address_space___191 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___190 *);
	int (*readpages)(struct file___191 *, struct address_space___191 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___191 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___190 **, void **);
	int (*write_end)(struct file___191 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___190 *, void *);
	sector_t (*bmap)(struct address_space___191 *, sector_t);
	void (*invalidatepage)(struct page___190 *, long unsigned int);
	int (*releasepage)(struct page___190 *, gfp_t);
	void (*freepage)(struct page___190 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___191 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___191 *, struct page___190 *, struct page___190 *, enum migrate_mode);
	int (*launder_page)(struct page___190 *);
	int (*is_partially_uptodate)(struct page___190 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___190 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___191 *, struct page___190 *);
	int (*swap_activate)(struct swap_info_struct___40 *, struct file___191 *, sector_t *);
	void (*swap_deactivate)(struct file___191 *);
	void (*invalidatepage_range)(struct page___190 *, unsigned int, unsigned int);
};

struct swap_info_struct___40 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___191 *bdev;
	struct file___191 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___191 {
	struct dentry___191 * (*lookup)(struct inode___191 *, struct dentry___191 *, unsigned int);
	void * (*follow_link)(struct dentry___191 *, struct nameidata *);
	int (*permission)(struct inode___191 *, int);
	struct posix_acl * (*get_acl)(struct inode___191 *, int);
	int (*readlink)(struct dentry___191 *, char *, int);
	void (*put_link)(struct dentry___191 *, struct nameidata *, void *);
	int (*create)(struct inode___191 *, struct dentry___191 *, umode_t, bool);
	int (*link)(struct dentry___191 *, struct inode___191 *, struct dentry___191 *);
	int (*unlink)(struct inode___191 *, struct dentry___191 *);
	int (*symlink)(struct inode___191 *, struct dentry___191 *, const char *);
	int (*mkdir)(struct inode___191 *, struct dentry___191 *, umode_t);
	int (*rmdir)(struct inode___191 *, struct dentry___191 *);
	int (*mknod)(struct inode___191 *, struct dentry___191 *, umode_t, dev_t);
	int (*rename)(struct inode___191 *, struct dentry___191 *, struct inode___191 *, struct dentry___191 *);
	int (*setattr)(struct dentry___191 *, struct iattr___191 *);
	int (*getattr)(struct vfsmount *, struct dentry___191 *, struct kstat *);
	int (*setxattr)(struct dentry___191 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___191 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___191 *, char *, size_t);
	int (*removexattr)(struct dentry___191 *, const char *);
	int (*fiemap)(struct inode___191 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___191 *, struct timespec *, int);
	int (*atomic_open)(struct inode___191 *, struct dentry___191 *, struct file___191 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___191 {
	struct module___107 *owner;
	loff_t (*llseek)(struct file___191 *, loff_t, int);
	ssize_t (*read)(struct file___191 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___191 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___191 *, void *, filldir_t);
	unsigned int (*poll)(struct file___191 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___191 *, struct vm_area_struct___199 *);
	int (*open)(struct inode___191 *, struct file___191 *);
	int (*flush)(struct file___191 *, fl_owner_t);
	int (*release)(struct inode___191 *, struct file___191 *);
	int (*fsync)(struct file___191 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___191 *, int);
	int (*lock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*sendpage)(struct file___191 *, struct page___190 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___191 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___191 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___191 *, long int, struct file_lock___191 **, void **);
		struct {
			int (*setlease)(struct file___191 *, long int, struct file_lock___191 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___191 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___191 *);
};

struct fasync_struct___191;

struct file_lock_operations___191;

struct lock_manager_operations___191;

struct file_lock___191 {
	struct file_lock___191 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___191 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___191 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___191 *fl_ops;
	const struct lock_manager_operations___191 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___191 {
	void (*fl_copy_lock)(struct file_lock___191 *, struct file_lock___191 *);
	void (*fl_release_private)(struct file_lock___191 *);
};

struct lock_manager_operations___191 {
	int (*lm_compare_owner)(struct file_lock___191 *, struct file_lock___191 *);
	long unsigned int (*lm_owner_key)(struct file_lock___191 *);
	void (*lm_notify)(struct file_lock___191 *);
	int (*lm_grant)(struct file_lock___191 *, struct file_lock___191 *, int);
	void (*lm_break)(struct file_lock___191 *);
	int (*lm_change)(struct file_lock___191 **, int);
};

struct fasync_struct___191 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___191 *fa_next;
	struct file___191 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___191 {
	const char *name;
	int fs_flags;
	struct dentry___191 * (*mount)(struct file_system_type___191 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___191 *);
	struct module___107 *owner;
	struct file_system_type___191 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___191 {
	struct inode___191 * (*alloc_inode)(struct super_block___191 *);
	void (*destroy_inode)(struct inode___191 *);
	void (*dirty_inode)(struct inode___191 *, int);
	int (*write_inode)(struct inode___191 *, struct writeback_control *);
	int (*drop_inode)(struct inode___191 *);
	void (*evict_inode)(struct inode___191 *);
	void (*put_super)(struct super_block___191 *);
	int (*sync_fs)(struct super_block___191 *, int);
	int (*freeze_fs)(struct super_block___191 *);
	int (*unfreeze_fs)(struct super_block___191 *);
	int (*statfs)(struct dentry___191 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___191 *, int *, char *);
	void (*umount_begin)(struct super_block___191 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___191 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___191 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___191 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___191 *);
	ssize_t (*quota_read)(struct super_block___191 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___191 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___191 *);
	int (*bdev_try_to_free_page)(struct super_block___191 *, struct page___190 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___191 *);
	void (*free_cached_objects)(struct super_block___191 *, int);
};

struct cgroupfs_root___118;

struct cgroup___118 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___118 *parent;
	struct dentry___191 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___118 *subsys[11];
	struct cgroupfs_root___118 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___194 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___118 {
	struct super_block___191 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___118 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___64 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___191 *, struct file___191 *);
	ssize_t (*read)(struct cgroup___118 *, struct cftype___64 *, struct file___191 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___118 *, struct cftype___64 *);
	s64 (*read_s64)(struct cgroup___118 *, struct cftype___64 *);
	int (*read_map)(struct cgroup___118 *, struct cftype___64 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___118 *, struct cftype___64 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___118 *, struct cftype___64 *, struct file___191 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___118 *, struct cftype___64 *, u64);
	int (*write_s64)(struct cgroup___118 *, struct cftype___64 *, s64);
	int (*write_string)(struct cgroup___118 *, struct cftype___64 *, const char *);
	int (*trigger)(struct cgroup___118 *, unsigned int);
	int (*release)(struct inode___191 *, struct file___191 *);
	int (*register_event)(struct cgroup___118 *, struct cftype___64 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___118 *, struct cftype___64 *, struct eventfd_ctx *);
};

struct cftype_set___60 {
	struct list_head node;
	struct cftype___64 *cfts;
};

struct task_and_cgroup___60 {
	struct task_struct___193 *task;
	struct cgroup___118 *cgrp;
	struct css_set___118 *cg;
};

struct cgroup_taskset___60 {
	struct task_and_cgroup___60 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___118 *cur_cgrp;
};

struct cgroup_subsys___60 {
	struct cgroup_subsys_state___118 * (*css_alloc)(struct cgroup___118 *);
	int (*css_online)(struct cgroup___118 *);
	void (*css_offline)(struct cgroup___118 *);
	void (*css_free)(struct cgroup___118 *);
	int (*can_attach)(struct cgroup___118 *, struct cgroup_taskset___60 *);
	void (*cancel_attach)(struct cgroup___118 *, struct cgroup_taskset___60 *);
	void (*attach)(struct cgroup___118 *, struct cgroup_taskset___60 *);
	void (*fork)(struct task_struct___193 *);
	void (*exit)(struct cgroup___118 *, struct cgroup___118 *, struct task_struct___193 *);
	void (*bind)(struct cgroup___118 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___118 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___64 *base_cftypes;
	struct cftype_set___60 base_cftset;
	struct module___107 *module;
};

struct vm_fault___168 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___190 *page;
};

typedef u32 acpi_event_status;

struct acpi_table_facs {
	char signature[4];
	u32 length;
	u32 hardware_signature;
	u32 firmware_waking_vector;
	u32 global_lock;
	u32 flags;
	u64 xfirmware_waking_vector;
	u8 version;
	u8 reserved[3];
	u32 ospm_flags;
	u8 reserved1[24];
};

struct acpi_hotplug_profile___16 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___16 *);
	void (*notify_online)(struct acpi_device___16 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___16 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___16 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___16 *);
	void (*bind)(struct device___164 *);
	void (*unbind)(struct device___164 *);
	struct acpi_hotplug_profile___16 hotplug;
};

struct acpi_hotplug_context___16 {
	struct acpi_device___16 *self;
	int (*notify)(struct acpi_device___16 *, u32);
	void (*uevent)(struct acpi_device___16 *, u32);
	void (*fixup)(struct acpi_device___16 *);
};

typedef int (*acpi_op_add___16)(struct acpi_device___16 *);

typedef int (*acpi_op_remove___16)(struct acpi_device___16 *);

typedef void (*acpi_op_notify___16)(struct acpi_device___16 *, u32);

struct acpi_device_ops___16 {
	acpi_op_add___16 add;
	acpi_op_remove___16 remove;
	acpi_op_notify___16 notify;
};

struct acpi_driver___16 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___16 ops;
	struct device_driver___164 drv;
	struct module___107 *owner;
};

struct module_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___106 *, struct module_kobject___106 *, char *);
	ssize_t (*store)(struct module_attribute___106 *, struct module_kobject___106 *, const char *, size_t);
	void (*setup)(struct module___107 *, const char *);
	int (*test)(struct module___107 *);
	void (*free)(struct module___107 *);
};

struct acpi_device_physical_node {
	unsigned int node_id;
	struct list_head node;
	struct device___63 *dev;
	bool put_online: 1;
};

struct page___191;

typedef struct page___191 *pgtable_t___191;

struct address_space___192;

struct kmem_cache___178;

struct page___191 {
	long unsigned int flags;
	struct address_space___192 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___191 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___191 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___178 *slab_cache;
		struct page___191 *first_page;
	};
	long: 64;
};

struct task_struct___194;

struct pv_cpu_ops___194 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___194 *);
	void (*end_context_switch)(struct task_struct___194 *);
};

struct mutex___195 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___194 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___187 {
	struct page___191 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___200;

struct signal_struct___194;

struct css_set___119;

struct task_struct___194 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___194 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___200 *mm;
	struct mm_struct___200 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___194 *real_parent;
	struct task_struct___194 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___194 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___194 = 0,
		VTIME_USER___194 = 1,
		VTIME_SYS___194 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___194 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___119 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___195 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___187 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___200 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___200 *, struct mm_struct___200 *);
	void (*dup_mmap)(struct mm_struct___200 *, struct mm_struct___200 *);
	void (*exit_mmap)(struct mm_struct___200 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___200 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___200 *);
	void (*pgd_free)(struct mm_struct___200 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___200 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___200 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___200 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___200 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___200 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___200 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___200 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___200 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___200 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___200 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___200 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___195 lock;
	void *vdso;
} mm_context_t___195;

struct xol_area___191;

struct uprobes_state___191 {
	struct xol_area___191 *xol_area;
};

struct vm_area_struct___200;

struct file___192;

struct core_state___194;

struct mm_struct___200 {
	struct vm_area_struct___200 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___200 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___200 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___195 context;
	long unsigned int flags;
	struct core_state___194 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___194 *owner;
	struct file___192 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___191 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___108;

struct module_kobject___107 {
	struct kobject___20 kobj;
	struct module___108 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___107;

struct module___108 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___107 mkobj;
	struct module_attribute___107 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___194 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___194;

struct lruvec___194 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___194 *zone;
};

struct pglist_data___194;

struct zone___194 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___194 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___194 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___194 {
	struct zone___194 *zone;
	int zone_idx;
};

struct zonelist___194 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___194 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___194 {
	struct zone___194 node_zones[4];
	struct zonelist___194 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___194 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___165;

struct dev_pm_ops___165 {
	int (*prepare)(struct device___165 *);
	void (*complete)(struct device___165 *);
	int (*suspend)(struct device___165 *);
	int (*resume)(struct device___165 *);
	int (*freeze)(struct device___165 *);
	int (*thaw)(struct device___165 *);
	int (*poweroff)(struct device___165 *);
	int (*restore)(struct device___165 *);
	int (*suspend_late)(struct device___165 *);
	int (*resume_early)(struct device___165 *);
	int (*freeze_late)(struct device___165 *);
	int (*thaw_early)(struct device___165 *);
	int (*poweroff_late)(struct device___165 *);
	int (*restore_early)(struct device___165 *);
	int (*suspend_noirq)(struct device___165 *);
	int (*resume_noirq)(struct device___165 *);
	int (*freeze_noirq)(struct device___165 *);
	int (*thaw_noirq)(struct device___165 *);
	int (*poweroff_noirq)(struct device___165 *);
	int (*restore_noirq)(struct device___165 *);
	int (*runtime_suspend)(struct device___165 *);
	int (*runtime_resume)(struct device___165 *);
	int (*runtime_idle)(struct device___165 *);
};

struct dma_map_ops___69;

struct dev_archdata___69 {
	struct dma_map_ops___69 *dma_ops;
	void *iommu;
};

struct acpi_device___17;

struct acpi_dev_node___23 {
	union {
		struct acpi_device___17 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___165;

struct bus_type___165;

struct device_driver___165;

struct dev_pm_domain___165;

struct class___165;

struct attribute_group___150;

struct device_rh___165;

struct device___165 {
	struct device___165 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___165 *type;
	struct mutex___195 mutex;
	struct bus_type___165 *bus;
	struct device_driver___165 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___165 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___69 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___23 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___165 *class;
	const struct attribute_group___150 **groups;
	void (*release)(struct device___165 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___165 *device_rh;
};

struct dev_pm_info_rh___165 {
	void (*set_latency_tolerance)(struct device___165 *, s32);
};

struct dev_pm_domain___165 {
	struct dev_pm_ops___165 ops;
};

struct smp_ops___194 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___194 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___152;

struct attribute_group___150 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___152 **bin_attrs;
};

struct bin_attribute___152 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___192 *, struct kobject___20 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___192 *, struct kobject___20 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	int (*mmap)(struct file___192 *, struct kobject___20 *, struct bin_attribute___152 *, struct vm_area_struct___200 *);
};

struct dentry___192;

struct path___192 {
	struct vfsmount *mnt;
	struct dentry___192 *dentry;
};

struct inode___192;

struct file_operations___192;

struct file___192 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___192 f_path;
	struct inode___192 *f_inode;
	const struct file_operations___192 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___192 *f_mapping;
	struct mutex___195 f_pos_lock;
};

struct vm_operations_struct___173;

struct vm_area_struct___200 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___200 *vm_next;
	struct vm_area_struct___200 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___200 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___173 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___192 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___107 *, struct module_kobject___107 *, char *);
	ssize_t (*store)(struct module_attribute___107 *, struct module_kobject___107 *, const char *, size_t);
	void (*setup)(struct module___108 *, const char *);
	int (*test)(struct module___108 *);
	void (*free)(struct module___108 *);
};

struct xol_area___191 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___191 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___177;

struct memcg_cache_params___178;

struct kmem_cache___178 {
	struct kmem_cache_cpu___177 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___178 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___192;

struct address_space___192 {
	struct inode___192 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___195 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___192 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___169;

struct vm_operations_struct___173 {
	void (*open)(struct vm_area_struct___200 *);
	void (*close)(struct vm_area_struct___200 *);
	int (*fault)(struct vm_area_struct___200 *, struct vm_fault___169 *);
	int (*page_mkwrite)(struct vm_area_struct___200 *, struct vm_fault___169 *);
	int (*access)(struct vm_area_struct___200 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___200 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___200 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___200 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___200 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___194 {
	struct task_struct___194 *task;
	struct core_thread___194 *next;
};

struct core_state___194 {
	atomic_t nr_threads;
	struct core_thread___194 dumper;
	struct completion startup;
};

struct signal_struct___194 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___194 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___194 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___195 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___119;

struct css_set___119 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___119 *subsys[11];
	struct callback_head callback_head;
};

struct dma_map_ops___69 {
	void * (*alloc)(struct device___165 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___165 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___165 *, struct vm_area_struct___200 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___165 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___165 *, struct page___191 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___165 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___165 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___165 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___165 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___165 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___165 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___165 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___165 *, dma_addr_t);
	int (*dma_supported)(struct device___165 *, u64);
	int (*set_dma_mask)(struct device___165 *, u64);
	int is_phys;
};

struct bus_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___165 *, char *);
	ssize_t (*store)(struct bus_type___165 *, const char *, size_t);
};

struct device_attribute___165;

struct driver_attribute___165;

struct bus_type___165 {
	const char *name;
	const char *dev_name;
	struct device___165 *dev_root;
	struct bus_attribute___165 *bus_attrs;
	struct device_attribute___165 *dev_attrs;
	struct driver_attribute___165 *drv_attrs;
	const struct attribute_group___150 **bus_groups;
	const struct attribute_group___150 **dev_groups;
	const struct attribute_group___150 **drv_groups;
	int (*match)(struct device___165 *, struct device_driver___165 *);
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	int (*probe)(struct device___165 *);
	int (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*online)(struct device___165 *);
	int (*offline)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct device___165 *, struct device_attribute___165 *, char *);
	ssize_t (*store)(struct device___165 *, struct device_attribute___165 *, const char *, size_t);
};

struct driver_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___165 *, char *);
	ssize_t (*store)(struct device_driver___165 *, const char *, size_t);
};

struct device_driver___165 {
	const char *name;
	struct bus_type___165 *bus;
	struct module___108 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___165 *);
	int (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	const struct attribute_group___150 **groups;
	const struct dev_pm_ops___165 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___165 {
	const char *name;
	const struct attribute_group___150 **groups;
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
};

struct class_attribute___165;

struct class___165 {
	const char *name;
	struct module___108 *owner;
	struct class_attribute___165 *class_attrs;
	struct device_attribute___165 *dev_attrs;
	const struct attribute_group___150 **dev_groups;
	struct bin_attribute___152 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *);
	void (*class_release)(struct class___165 *);
	void (*dev_release)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
	struct subsys_private *p;
};

struct class_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct class___165 *, struct class_attribute___165 *, char *);
	ssize_t (*store)(struct class___165 *, struct class_attribute___165 *, const char *, size_t);
	const void * (*namespace)(struct class___165 *, const struct class_attribute___165 *);
};

struct acpi_scan_handler___17;

struct acpi_hotplug_context___17;

struct acpi_driver___17;

struct acpi_device___17 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___17 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___17 *handler;
	struct acpi_hotplug_context___17 *hp;
	struct acpi_driver___17 *driver;
	void *driver_data;
	struct device___165 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___195 physical_node_lock;
	void (*remove)(struct acpi_device___17 *);
};

struct device_rh___165 {
	struct dev_pm_info_rh___165 power;
};

struct dentry_operations___192;

struct super_block___192;

struct dentry___192 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___192 *d_parent;
	struct qstr d_name;
	struct inode___192 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___192 *d_op;
	struct super_block___192 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___192;

struct file_lock___192;

struct dquot___192;

struct block_device___192;

struct inode___192 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___192 *i_op;
	struct super_block___192 *i_sb;
	struct address_space___192 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___195 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___192 *i_fop;
	struct file_lock___192 *i_flock;
	struct address_space___192 i_data;
	struct dquot___192 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___192 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___192 {
	int (*d_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_hash)(const struct dentry___192 *, struct qstr *);
	int (*d_compare)(const struct dentry___192 *, const struct dentry___192 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___192 *);
	void (*d_release)(struct dentry___192 *);
	void (*d_prune)(struct dentry___192 *);
	void (*d_iput)(struct dentry___192 *, struct inode___192 *);
	char * (*d_dname)(struct dentry___192 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___192 *);
	int (*d_manage)(struct dentry___192 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___192;

struct mem_dqinfo___192 {
	struct quota_format_type___192 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___192;

struct quota_info___192 {
	unsigned int flags;
	struct mutex___195 dqio_mutex;
	struct mutex___195 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___192 *files[2];
	struct mem_dqinfo___192 info[2];
	const struct quota_format_ops___192 *ops[2];
};

struct file_system_type___192;

struct super_operations___192;

struct dquot_operations___192;

struct quotactl_ops___192;

struct xattr_handler___120;

struct super_block___192 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___192 *s_type;
	const struct super_operations___192 *s_op;
	const struct dquot_operations___192 *dq_op;
	const struct quotactl_ops___192 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___192 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___120 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___192 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___192 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___195 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___192 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___192 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___192 *bd_inode;
	struct super_block___192 *bd_super;
	struct mutex___195 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___192 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___195 bd_fsfreeze_mutex;
};

struct cgroup___119;

struct cgroup_subsys_state___119 {
	struct cgroup___119 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___192 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___192 *ia_file;
};

struct dquot___192 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___195 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___192 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___192 {
	int qf_fmt_id;
	const struct quota_format_ops___192 *qf_ops;
	struct module___108 *qf_owner;
	struct quota_format_type___192 *qf_next;
};

struct quota_format_ops___192 {
	int (*check_quota_file)(struct super_block___192 *, int);
	int (*read_file_info)(struct super_block___192 *, int);
	int (*write_file_info)(struct super_block___192 *, int);
	int (*free_file_info)(struct super_block___192 *, int);
	int (*read_dqblk)(struct dquot___192 *);
	int (*commit_dqblk)(struct dquot___192 *);
	int (*release_dqblk)(struct dquot___192 *);
};

struct dquot_operations___192 {
	int (*write_dquot)(struct dquot___192 *);
	struct dquot___192 * (*alloc_dquot)(struct super_block___192 *, int);
	void (*destroy_dquot)(struct dquot___192 *);
	int (*acquire_dquot)(struct dquot___192 *);
	int (*release_dquot)(struct dquot___192 *);
	int (*mark_dirty)(struct dquot___192 *);
	int (*write_info)(struct super_block___192 *, int);
	qsize_t * (*get_reserved_space)(struct inode___192 *);
};

struct quotactl_ops___192 {
	int (*quota_on)(struct super_block___192 *, int, int, struct path___192 *);
	int (*quota_on_meta)(struct super_block___192 *, int, int);
	int (*quota_off)(struct super_block___192 *, int);
	int (*quota_sync)(struct super_block___192 *, int);
	int (*get_info)(struct super_block___192 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___192 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___192 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___192 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___192 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___192 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___192 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___192 *, unsigned int);
};

struct swap_info_struct___41;

struct address_space_operations___192 {
	int (*writepage)(struct page___191 *, struct writeback_control *);
	int (*readpage)(struct file___192 *, struct page___191 *);
	int (*writepages)(struct address_space___192 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___191 *);
	int (*readpages)(struct file___192 *, struct address_space___192 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___192 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___191 **, void **);
	int (*write_end)(struct file___192 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___191 *, void *);
	sector_t (*bmap)(struct address_space___192 *, sector_t);
	void (*invalidatepage)(struct page___191 *, long unsigned int);
	int (*releasepage)(struct page___191 *, gfp_t);
	void (*freepage)(struct page___191 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___192 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___192 *, struct page___191 *, struct page___191 *, enum migrate_mode);
	int (*launder_page)(struct page___191 *);
	int (*is_partially_uptodate)(struct page___191 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___191 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___192 *, struct page___191 *);
	int (*swap_activate)(struct swap_info_struct___41 *, struct file___192 *, sector_t *);
	void (*swap_deactivate)(struct file___192 *);
	void (*invalidatepage_range)(struct page___191 *, unsigned int, unsigned int);
};

struct swap_info_struct___41 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___192 *bdev;
	struct file___192 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___192 {
	struct dentry___192 * (*lookup)(struct inode___192 *, struct dentry___192 *, unsigned int);
	void * (*follow_link)(struct dentry___192 *, struct nameidata *);
	int (*permission)(struct inode___192 *, int);
	struct posix_acl * (*get_acl)(struct inode___192 *, int);
	int (*readlink)(struct dentry___192 *, char *, int);
	void (*put_link)(struct dentry___192 *, struct nameidata *, void *);
	int (*create)(struct inode___192 *, struct dentry___192 *, umode_t, bool);
	int (*link)(struct dentry___192 *, struct inode___192 *, struct dentry___192 *);
	int (*unlink)(struct inode___192 *, struct dentry___192 *);
	int (*symlink)(struct inode___192 *, struct dentry___192 *, const char *);
	int (*mkdir)(struct inode___192 *, struct dentry___192 *, umode_t);
	int (*rmdir)(struct inode___192 *, struct dentry___192 *);
	int (*mknod)(struct inode___192 *, struct dentry___192 *, umode_t, dev_t);
	int (*rename)(struct inode___192 *, struct dentry___192 *, struct inode___192 *, struct dentry___192 *);
	int (*setattr)(struct dentry___192 *, struct iattr___192 *);
	int (*getattr)(struct vfsmount *, struct dentry___192 *, struct kstat *);
	int (*setxattr)(struct dentry___192 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___192 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___192 *, char *, size_t);
	int (*removexattr)(struct dentry___192 *, const char *);
	int (*fiemap)(struct inode___192 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___192 *, struct timespec *, int);
	int (*atomic_open)(struct inode___192 *, struct dentry___192 *, struct file___192 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___192 {
	struct module___108 *owner;
	loff_t (*llseek)(struct file___192 *, loff_t, int);
	ssize_t (*read)(struct file___192 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___192 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___192 *, void *, filldir_t);
	unsigned int (*poll)(struct file___192 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___192 *, struct vm_area_struct___200 *);
	int (*open)(struct inode___192 *, struct file___192 *);
	int (*flush)(struct file___192 *, fl_owner_t);
	int (*release)(struct inode___192 *, struct file___192 *);
	int (*fsync)(struct file___192 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___192 *, int);
	int (*lock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*sendpage)(struct file___192 *, struct page___191 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___192 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___192 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___192 *, long int, struct file_lock___192 **, void **);
		struct {
			int (*setlease)(struct file___192 *, long int, struct file_lock___192 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___192 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___192 *);
};

struct fasync_struct___192;

struct file_lock_operations___192;

struct lock_manager_operations___192;

struct file_lock___192 {
	struct file_lock___192 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___192 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___192 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___192 *fl_ops;
	const struct lock_manager_operations___192 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___192 {
	void (*fl_copy_lock)(struct file_lock___192 *, struct file_lock___192 *);
	void (*fl_release_private)(struct file_lock___192 *);
};

struct lock_manager_operations___192 {
	int (*lm_compare_owner)(struct file_lock___192 *, struct file_lock___192 *);
	long unsigned int (*lm_owner_key)(struct file_lock___192 *);
	void (*lm_notify)(struct file_lock___192 *);
	int (*lm_grant)(struct file_lock___192 *, struct file_lock___192 *, int);
	void (*lm_break)(struct file_lock___192 *);
	int (*lm_change)(struct file_lock___192 **, int);
};

struct fasync_struct___192 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___192 *fa_next;
	struct file___192 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___192 {
	const char *name;
	int fs_flags;
	struct dentry___192 * (*mount)(struct file_system_type___192 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___192 *);
	struct module___108 *owner;
	struct file_system_type___192 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___192 {
	struct inode___192 * (*alloc_inode)(struct super_block___192 *);
	void (*destroy_inode)(struct inode___192 *);
	void (*dirty_inode)(struct inode___192 *, int);
	int (*write_inode)(struct inode___192 *, struct writeback_control *);
	int (*drop_inode)(struct inode___192 *);
	void (*evict_inode)(struct inode___192 *);
	void (*put_super)(struct super_block___192 *);
	int (*sync_fs)(struct super_block___192 *, int);
	int (*freeze_fs)(struct super_block___192 *);
	int (*unfreeze_fs)(struct super_block___192 *);
	int (*statfs)(struct dentry___192 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___192 *, int *, char *);
	void (*umount_begin)(struct super_block___192 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___192 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___192 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___192 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___192 *);
	ssize_t (*quota_read)(struct super_block___192 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___192 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___192 *);
	int (*bdev_try_to_free_page)(struct super_block___192 *, struct page___191 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___192 *);
	void (*free_cached_objects)(struct super_block___192 *, int);
};

struct xattr_handler___120 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___192 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___192 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___192 *, const char *, const void *, size_t, int, int);
};

struct kmem_cache_cpu___177 {
	void **freelist;
	long unsigned int tid;
	struct page___191 *page;
	struct page___191 *partial;
};

struct memcg_cache_params___178 {
	bool is_root_cache;
	union {
		struct kmem_cache___178 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___178 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef long long unsigned int UINT64;

typedef void (*acpi_object_handler)(acpi_handle, void *);

struct acpi_hotplug_profile___17 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___17 *);
	void (*notify_online)(struct acpi_device___17 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___17 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___17 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___17 *);
	void (*bind)(struct device___165 *);
	void (*unbind)(struct device___165 *);
	struct acpi_hotplug_profile___17 hotplug;
};

struct acpi_hotplug_context___17 {
	struct acpi_device___17 *self;
	int (*notify)(struct acpi_device___17 *, u32);
	void (*uevent)(struct acpi_device___17 *, u32);
	void (*fixup)(struct acpi_device___17 *);
};

typedef int (*acpi_op_add___17)(struct acpi_device___17 *);

typedef int (*acpi_op_remove___17)(struct acpi_device___17 *);

typedef void (*acpi_op_notify___17)(struct acpi_device___17 *, u32);

struct acpi_device_ops___17 {
	acpi_op_add___17 add;
	acpi_op_remove___17 remove;
	acpi_op_notify___17 notify;
};

struct acpi_driver___17 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___17 ops;
	struct device_driver___165 drv;
	struct module___108 *owner;
};

struct acpi_osc_context {
	char *uuid_str;
	int rev;
	struct acpi_buffer cap;
	struct acpi_buffer ret;
};

struct vm_fault___169 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___191 *page;
};

struct cgroupfs_root___119;

struct cgroup___119 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___119 *parent;
	struct dentry___192 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___119 *subsys[11];
	struct cgroupfs_root___119 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___195 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___119 {
	struct super_block___192 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___119 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___65 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___192 *, struct file___192 *);
	ssize_t (*read)(struct cgroup___119 *, struct cftype___65 *, struct file___192 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___119 *, struct cftype___65 *);
	s64 (*read_s64)(struct cgroup___119 *, struct cftype___65 *);
	int (*read_map)(struct cgroup___119 *, struct cftype___65 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___119 *, struct cftype___65 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___119 *, struct cftype___65 *, struct file___192 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___119 *, struct cftype___65 *, u64);
	int (*write_s64)(struct cgroup___119 *, struct cftype___65 *, s64);
	int (*write_string)(struct cgroup___119 *, struct cftype___65 *, const char *);
	int (*trigger)(struct cgroup___119 *, unsigned int);
	int (*release)(struct inode___192 *, struct file___192 *);
	int (*register_event)(struct cgroup___119 *, struct cftype___65 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___119 *, struct cftype___65 *, struct eventfd_ctx *);
};

struct cftype_set___61 {
	struct list_head node;
	struct cftype___65 *cfts;
};

struct task_and_cgroup___61 {
	struct task_struct___194 *task;
	struct cgroup___119 *cgrp;
	struct css_set___119 *cg;
};

struct cgroup_taskset___61 {
	struct task_and_cgroup___61 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___119 *cur_cgrp;
};

struct cgroup_subsys___61 {
	struct cgroup_subsys_state___119 * (*css_alloc)(struct cgroup___119 *);
	int (*css_online)(struct cgroup___119 *);
	void (*css_offline)(struct cgroup___119 *);
	void (*css_free)(struct cgroup___119 *);
	int (*can_attach)(struct cgroup___119 *, struct cgroup_taskset___61 *);
	void (*cancel_attach)(struct cgroup___119 *, struct cgroup_taskset___61 *);
	void (*attach)(struct cgroup___119 *, struct cgroup_taskset___61 *);
	void (*fork)(struct task_struct___194 *);
	void (*exit)(struct cgroup___119 *, struct cgroup___119 *, struct task_struct___194 *);
	void (*bind)(struct cgroup___119 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___119 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___65 *base_cftypes;
	struct cftype_set___61 base_cftset;
	struct module___108 *module;
};

struct acpi_device_physical_node___2 {
	unsigned int node_id;
	struct list_head node;
	struct device___157 *dev;
	bool put_online: 1;
};

typedef unsigned int UINT32;

typedef u32 (*acpi_event_handler)(void *);

struct acpi_pnp_device_id {
	u32 length;
	char *string;
};

struct acpi_pnp_device_id_list {
	u32 count;
	u32 list_size;
	struct acpi_pnp_device_id ids[1];
};

struct acpi_device_info {
	u32 info_size;
	u32 name;
	acpi_object_type type;
	u8 param_count;
	u8 valid;
	u8 flags;
	u8 highest_dstates[4];
	u8 lowest_dstates[5];
	u32 current_status;
	u64 address;
	struct acpi_pnp_device_id hardware_id;
	struct acpi_pnp_device_id unique_id;
	struct acpi_pnp_device_id subsystem_id;
	struct acpi_pnp_device_id_list compatible_id_list;
};

enum acpi_bus_device_type {
	ACPI_BUS_TYPE_DEVICE = 0,
	ACPI_BUS_TYPE_POWER = 1,
	ACPI_BUS_TYPE_PROCESSOR = 2,
	ACPI_BUS_TYPE_THERMAL = 3,
	ACPI_BUS_TYPE_POWER_BUTTON = 4,
	ACPI_BUS_TYPE_SLEEP_BUTTON = 5,
	ACPI_BUS_DEVICE_TYPE_COUNT = 6,
};

struct acpi_hardware_id {
	struct list_head list;
	char *id;
};

struct acpi_device_bus_id {
	char bus_id[15];
	unsigned int instance_no;
	struct list_head node;
};

struct acpi_resource_irq {
	u8 descriptor_length;
	u8 triggering;
	u8 polarity;
	u8 sharable;
	u8 wake_capable;
	u8 interrupt_count;
	u8 interrupts[1];
};

struct acpi_resource_dma {
	u8 type;
	u8 bus_master;
	u8 transfer;
	u8 channel_count;
	u8 channels[1];
};

struct acpi_resource_start_dependent {
	u8 descriptor_length;
	u8 compatibility_priority;
	u8 performance_robustness;
};

struct acpi_resource_io {
	u8 io_decode;
	u8 alignment;
	u8 address_length;
	u16 minimum;
	u16 maximum;
} __attribute__((packed));

struct acpi_resource_fixed_io {
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_dma {
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct acpi_resource_vendor {
	u16 byte_length;
	u8 byte_data[1];
} __attribute__((packed));

struct acpi_resource_vendor_typed {
	u16 byte_length;
	u8 uuid_subtype;
	u8 uuid[16];
	u8 byte_data[1];
};

struct acpi_resource_end_tag {
	u8 checksum;
};

struct acpi_resource_memory24 {
	u8 write_protect;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct acpi_resource_memory32 {
	u8 write_protect;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_memory32 {
	u8 write_protect;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct acpi_memory_attribute {
	u8 write_protect;
	u8 caching;
	u8 range_type;
	u8 translation;
};

struct acpi_io_attribute {
	u8 range_type;
	u8 translation;
	u8 translation_type;
	u8 reserved1;
};

union acpi_resource_attribute {
	struct acpi_memory_attribute mem;
	struct acpi_io_attribute io;
	u8 type_specific;
};

struct acpi_resource_source {
	u8 index;
	u16 string_length;
	char *string_ptr;
} __attribute__((packed));

struct acpi_resource_address {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
};

struct acpi_resource_address16 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address32 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_extended_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u8 revision_ID;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
	u64 type_specific;
} __attribute__((packed));

struct acpi_resource_extended_irq {
	u8 producer_consumer;
	u8 triggering;
	u8 polarity;
	u8 sharable;
	u8 wake_capable;
	u8 interrupt_count;
	struct acpi_resource_source resource_source;
	u32 interrupts[1];
} __attribute__((packed));

struct acpi_resource_generic_register {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_resource_gpio {
	u8 revision_id;
	u8 connection_type;
	u8 producer_consumer;
	u8 pin_config;
	u8 sharable;
	u8 wake_capable;
	u8 io_restriction;
	u8 triggering;
	u8 polarity;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_common_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_i2c_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 access_mode;
	u16 slave_address;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_spi_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 wire_mode;
	u8 device_polarity;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_uart_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 endian;
	u8 data_bits;
	u8 stop_bits;
	u8 flow_control;
	u8 parity;
	u8 lines_enabled;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u32 default_baud_rate;
} __attribute__((packed));

union acpi_resource_data {
	struct acpi_resource_irq irq;
	struct acpi_resource_dma dma;
	struct acpi_resource_start_dependent start_dpf;
	struct acpi_resource_io io;
	struct acpi_resource_fixed_io fixed_io;
	struct acpi_resource_fixed_dma fixed_dma;
	struct acpi_resource_vendor vendor;
	struct acpi_resource_vendor_typed vendor_typed;
	struct acpi_resource_end_tag end_tag;
	struct acpi_resource_memory24 memory24;
	struct acpi_resource_memory32 memory32;
	struct acpi_resource_fixed_memory32 fixed_memory32;
	struct acpi_resource_address16 address16;
	struct acpi_resource_address32 address32;
	struct acpi_resource_address64 address64;
	struct acpi_resource_extended_address64 ext_address64;
	struct acpi_resource_extended_irq extended_irq;
	struct acpi_resource_generic_register generic_reg;
	struct acpi_resource_gpio gpio;
	struct acpi_resource_i2c_serialbus i2c_serial_bus;
	struct acpi_resource_spi_serialbus spi_serial_bus;
	struct acpi_resource_uart_serialbus uart_serial_bus;
	struct acpi_resource_common_serialbus common_serial_bus;
	struct acpi_resource_address address;
};

struct acpi_resource {
	u32 type;
	u32 length;
	union acpi_resource_data data;
} __attribute__((packed));

typedef acpi_status (*acpi_walk_resource_callback)(struct acpi_resource *, void *);

struct resource_list_entry {
	struct list_head node;
	struct resource res;
};

struct res_proc_context {
	struct list_head *list;
	int (*preproc)(struct acpi_resource *, void *);
	void *preproc_data;
	int count;
	int error;
};

struct thermal_cooling_device_ops;

struct thermal_cooling_device {
	int id;
	char type[20];
	struct device___157 device;
	void *devdata;
	const struct thermal_cooling_device_ops *ops;
	bool updated;
	struct mutex___193 lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops {
	int (*get_max_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device *, long unsigned int);
};

struct acpi_processor_power {
	struct acpi_processor_cx *state;
	long unsigned int bm_check_timestamp;
	u32 default_state;
	int count;
	struct acpi_processor_cx states[8];
	int timer_broadcast_on_state;
};

struct acpi_psd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_pct_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_processor_px {
	u64 core_frequency;
	u64 power;
	u64 transition_latency;
	u64 bus_master_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_performance {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_px *states;
	struct acpi_psd_package domain_info;
	cpumask_var_t shared_cpu_map;
	unsigned int shared_type;
	int: 32;
} __attribute__((packed));

struct acpi_tsd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_processor_tx_tss {
	u64 freqpercentage;
	u64 power;
	u64 transition_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_tx {
	u16 power;
	u16 performance;
};

struct acpi_processor;

struct acpi_processor_throttling {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor *);
	int (*acpi_processor_set_throttling)(struct acpi_processor *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor_lx {
	int px;
	int tx;
};

struct acpi_processor_limit {
	struct acpi_processor_lx state;
	struct acpi_processor_lx thermal;
	struct acpi_processor_lx user;
};

struct acpi_processor {
	acpi_handle handle;
	u32 acpi_id;
	u32 phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device *cdev;
	struct device___157 *dev;
};

struct acpi_processor_errata {
	u8 smp;
	struct {
		u8 throttle: 1;
		u8 fdma: 1;
		u8 reserved: 6;
		u32 bmisx;
	} piix4;
};

typedef u32 (*acpi_gpe_handler)(acpi_handle, u32, void *);

typedef acpi_status (*acpi_adr_space_handler)(u32, acpi_physical_address, u32, u64 *, void *, void *);

typedef acpi_status (*acpi_adr_space_setup)(acpi_handle, u32, void *, void **);

struct acpi_table_ecdt {
	struct acpi_table_header header;
	struct acpi_generic_address control;
	struct acpi_generic_address data;
	u32 uid;
	u8 gpe;
	u8 id[1];
} __attribute__((packed));

struct transaction;

struct acpi_ec {
	acpi_handle handle;
	long unsigned int gpe;
	long unsigned int command_addr;
	long unsigned int data_addr;
	long unsigned int global_lock;
	long unsigned int flags;
	struct mutex___193 mutex;
	wait_queue_head_t wait;
	struct list_head list;
	struct transaction *curr;
	spinlock_t lock;
};

struct transaction {
	const u8 *wdata;
	u8 *rdata;
	short unsigned int irq_count;
	u8 command;
	u8 wi;
	u8 ri;
	u8 wlen;
	u8 rlen;
	bool done;
};

enum ec_command {
	ACPI_EC_COMMAND_READ = 128,
	ACPI_EC_COMMAND_WRITE = 129,
	ACPI_EC_BURST_ENABLE = 130,
	ACPI_EC_BURST_DISABLE = 131,
	ACPI_EC_COMMAND_QUERY = 132,
};

enum {
	EC_FLAGS_QUERY_PENDING = 0,
	EC_FLAGS_GPE_STORM = 1,
	EC_FLAGS_HANDLERS_INSTALLED = 2,
	EC_FLAGS_BLOCKED = 3,
};

typedef int (*acpi_ec_query_func)(void *);

struct acpi_ec_query_handler {
	struct list_head node;
	acpi_ec_query_func func;
	acpi_handle handle;
	void *data;
	u8 query_bit;
};

struct platform_device_info___4 {
	struct device___157 *parent;
	struct acpi_dev_node___20 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct acpi_dock_ops {
	acpi_notify_handler fixup;
	acpi_notify_handler handler;
	acpi_notify_handler uevent;
};

struct dock_station {
	acpi_handle handle;
	long unsigned int last_dock_time;
	u32 flags;
	struct list_head dependent_devices;
	struct list_head sibling;
	struct platform_device___5 *dock_device;
};

struct dock_dependent_device {
	struct list_head list;
	struct acpi_device___14 *adev;
	const struct acpi_dock_ops *hp_ops;
	void *hp_context;
	unsigned int hp_refcount;
	void (*hp_release)(void *);
};

enum dock_callback_type {
	DOCK_CALL_HANDLER = 0,
	DOCK_CALL_FIXUP = 1,
	DOCK_CALL_UEVENT = 2,
};

struct acpi_pci_root___2 {
	struct acpi_device___14 *device;
	struct pci_bus___22 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

struct pci_osc_bit_struct {
	u32 bit;
	char *desc;
};

struct acpi_handle_node {
	struct list_head node;
	acpi_handle handle;
};

struct acpi_pci_link_irq {
	u8 active;
	u8 triggering;
	u8 polarity;
	u8 resource_type;
	u8 possible_count;
	u8 possible[16];
	u8 initialized: 1;
	u8 reserved: 7;
};

struct acpi_pci_link {
	struct list_head list;
	struct acpi_device___14 *device;
	struct acpi_pci_link_irq irq;
	int refcnt;
};

struct acpi_pci_routing_table {
	u32 length;
	u32 pin;
	u64 address;
	u32 source_index;
	char source[4];
};

struct acpi_prt_entry {
	struct list_head list;
	struct acpi_pci_id id;
	u8 pin;
	acpi_handle link;
	u32 index;
};

struct prt_quirk {
	const struct dmi_system_id *system;
	unsigned int segment;
	unsigned int bus;
	unsigned int device;
	unsigned char pin;
	const char *source;
	const char *actual_source;
};

struct acpi_power_resource {
	struct acpi_device___14 device;
	struct list_head list_node;
	char *name;
	u32 system_level;
	u32 order;
	unsigned int ref_count;
	bool wakeup_enabled;
	struct mutex___193 resource_lock;
};

struct acpi_power_resource_entry {
	struct list_head node;
	struct acpi_power_resource *resource;
};

struct device___166;

struct dev_pm_ops___166 {
	int (*prepare)(struct device___166 *);
	void (*complete)(struct device___166 *);
	int (*suspend)(struct device___166 *);
	int (*resume)(struct device___166 *);
	int (*freeze)(struct device___166 *);
	int (*thaw)(struct device___166 *);
	int (*poweroff)(struct device___166 *);
	int (*restore)(struct device___166 *);
	int (*suspend_late)(struct device___166 *);
	int (*resume_early)(struct device___166 *);
	int (*freeze_late)(struct device___166 *);
	int (*thaw_early)(struct device___166 *);
	int (*poweroff_late)(struct device___166 *);
	int (*restore_early)(struct device___166 *);
	int (*suspend_noirq)(struct device___166 *);
	int (*resume_noirq)(struct device___166 *);
	int (*freeze_noirq)(struct device___166 *);
	int (*thaw_noirq)(struct device___166 *);
	int (*poweroff_noirq)(struct device___166 *);
	int (*restore_noirq)(struct device___166 *);
	int (*runtime_suspend)(struct device___166 *);
	int (*runtime_resume)(struct device___166 *);
	int (*runtime_idle)(struct device___166 *);
};

struct dma_map_ops___70;

struct dev_archdata___70 {
	struct dma_map_ops___70 *dma_ops;
	void *iommu;
};

struct acpi_device___18;

struct acpi_dev_node___24 {
	union {
		struct acpi_device___18 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___166;

struct bus_type___166;

struct device_driver___166;

struct dev_pm_domain___166;

struct class___166;

struct device_rh___166;

struct device___166 {
	struct device___166 *parent;
	struct device_private *p;
	struct kobject___17 kobj;
	const char *init_name;
	const struct device_type___166 *type;
	struct mutex___163 mutex;
	struct bus_type___166 *bus;
	struct device_driver___166 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___166 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___70 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___24 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___166 *class;
	const struct attribute_group___117 **groups;
	void (*release)(struct device___166 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___166 *device_rh;
};

struct dev_pm_info_rh___166 {
	void (*set_latency_tolerance)(struct device___166 *, s32);
};

struct dev_pm_domain___166 {
	struct dev_pm_ops___166 ops;
};

struct dma_map_ops___70 {
	void * (*alloc)(struct device___166 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___166 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___166 *, struct vm_area_struct___167 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___166 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___166 *, struct page___159 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___166 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___166 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___166 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___166 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___166 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___166 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___166 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___166 *, dma_addr_t);
	int (*dma_supported)(struct device___166 *, u64);
	int (*set_dma_mask)(struct device___166 *, u64);
	int is_phys;
};

struct bus_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___166 *, char *);
	ssize_t (*store)(struct bus_type___166 *, const char *, size_t);
};

struct device_attribute___166;

struct driver_attribute___166;

struct bus_type___166 {
	const char *name;
	const char *dev_name;
	struct device___166 *dev_root;
	struct bus_attribute___166 *bus_attrs;
	struct device_attribute___166 *dev_attrs;
	struct driver_attribute___166 *drv_attrs;
	const struct attribute_group___117 **bus_groups;
	const struct attribute_group___117 **dev_groups;
	const struct attribute_group___117 **drv_groups;
	int (*match)(struct device___166 *, struct device_driver___166 *);
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	int (*probe)(struct device___166 *);
	int (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*online)(struct device___166 *);
	int (*offline)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct device___166 *, struct device_attribute___166 *, char *);
	ssize_t (*store)(struct device___166 *, struct device_attribute___166 *, const char *, size_t);
};

struct driver_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___166 *, char *);
	ssize_t (*store)(struct device_driver___166 *, const char *, size_t);
};

struct device_driver___166 {
	const char *name;
	struct bus_type___166 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___166 *);
	int (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	const struct attribute_group___117 **groups;
	const struct dev_pm_ops___166 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___166 {
	const char *name;
	const struct attribute_group___117 **groups;
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
};

struct class_attribute___166;

struct class___166 {
	const char *name;
	struct module *owner;
	struct class_attribute___166 *class_attrs;
	struct device_attribute___166 *dev_attrs;
	const struct attribute_group___117 **dev_groups;
	struct bin_attribute___119 *dev_bin_attrs;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *);
	void (*class_release)(struct class___166 *);
	void (*dev_release)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
	struct subsys_private *p;
};

struct class_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct class___166 *, struct class_attribute___166 *, char *);
	ssize_t (*store)(struct class___166 *, struct class_attribute___166 *, const char *, size_t);
	const void * (*namespace)(struct class___166 *, const struct class_attribute___166 *);
};

struct acpi_scan_handler___18;

struct acpi_hotplug_context___18;

struct acpi_driver___18;

struct acpi_device___18 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___18 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___18 *handler;
	struct acpi_hotplug_context___18 *hp;
	struct acpi_driver___18 *driver;
	void *driver_data;
	struct device___166 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___163 physical_node_lock;
	void (*remove)(struct acpi_device___18 *);
};

struct device_rh___166 {
	struct dev_pm_info_rh___166 power;
};

struct acpi_hotplug_profile___18 {
	struct kobject___17 kobj;
	int (*scan_dependent)(struct acpi_device___18 *);
	void (*notify_online)(struct acpi_device___18 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___18 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___18 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___18 *);
	void (*bind)(struct device___166 *);
	void (*unbind)(struct device___166 *);
	struct acpi_hotplug_profile___18 hotplug;
};

struct acpi_hotplug_context___18 {
	struct acpi_device___18 *self;
	int (*notify)(struct acpi_device___18 *, u32);
	void (*uevent)(struct acpi_device___18 *, u32);
	void (*fixup)(struct acpi_device___18 *);
};

typedef int (*acpi_op_add___18)(struct acpi_device___18 *);

typedef int (*acpi_op_remove___18)(struct acpi_device___18 *);

typedef void (*acpi_op_notify___18)(struct acpi_device___18 *, u32);

struct acpi_device_ops___18 {
	acpi_op_add___18 add;
	acpi_op_remove___18 remove;
	acpi_op_notify___18 notify;
};

struct acpi_driver___18 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___18 ops;
	struct device_driver___166 drv;
	struct module *owner;
};

struct acpi_bus_event {
	struct list_head node;
	acpi_device_class device_class;
	acpi_bus_id bus_id;
	u32 type;
	u32 data;
};

struct genl_ops___3;

struct genl_info___3;

struct genl_family___3 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___3 *, struct sk_buff___20 *, struct genl_info___3 *);
	void (*post_doit)(const struct genl_ops___3 *, struct sk_buff___20 *, struct genl_info___3 *);
	struct nlattr **attrbuf;
	const struct genl_ops___3 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___3 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___20 *, struct genl_info___3 *);
	int (*dumpit)(struct sk_buff___20 *, struct netlink_callback___23 *);
	int (*done)(struct netlink_callback___23 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___3 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___29 *_net;
	void *user_ptr[2];
	struct sock *dst_sk;
};

struct acpi_genl_event {
	acpi_device_class device_class;
	char bus_id[15];
	u32 type;
	u32 data;
};

enum {
	ACPI_GENL_ATTR_UNSPEC = 0,
	ACPI_GENL_ATTR_EVENT = 1,
	__ACPI_GENL_ATTR_MAX = 2,
};

enum {
	ACPI_GENL_CMD_UNSPEC = 0,
	ACPI_GENL_CMD_EVENT = 1,
	__ACPI_GENL_CMD_MAX = 2,
};

typedef void (*acpi_gbl_event_handler)(u32, acpi_handle, u32, void *);

typedef acpi_status (*acpi_table_handler)(u32, void *, void *);

struct acpi_table_attr {
	struct bin_attribute___150 attr;
	char name[8];
	int instance;
	struct list_head node;
};

struct event_counter {
	u32 count;
	u32 flags;
};

struct acpi_table_srat {
	struct acpi_table_header header;
	u32 table_revision;
	u64 reserved;
};

enum acpi_srat_type {
	ACPI_SRAT_TYPE_CPU_AFFINITY = 0,
	ACPI_SRAT_TYPE_MEMORY_AFFINITY = 1,
	ACPI_SRAT_TYPE_X2APIC_CPU_AFFINITY = 2,
	ACPI_SRAT_TYPE_RESERVED = 3,
};

union acpi_operand_object;

struct acpi_namespace_node {
	union acpi_operand_object *object;
	u8 descriptor_type;
	u8 type;
	u8 flags;
	acpi_owner_id owner_id;
	union acpi_name_union name;
	struct acpi_namespace_node *parent;
	struct acpi_namespace_node *child;
	struct acpi_namespace_node *peer;
};

struct acpi_object_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
};

struct acpi_object_integer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 fill[3];
	u64 value;
};

struct acpi_object_string {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	char *pointer;
	u32 length;
};

struct acpi_object_buffer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 *pointer;
	u32 length;
	u32 aml_length;
	u8 *aml_start;
	struct acpi_namespace_node *node;
};

struct acpi_object_package {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	union acpi_operand_object **elements;
	u8 *aml_start;
	u32 aml_length;
	u32 count;
};

struct acpi_object_event {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	void *os_semaphore;
};

struct acpi_walk_state;

typedef acpi_status (*acpi_internal_method)(struct acpi_walk_state *);

struct acpi_object_method {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 info_flags;
	u8 param_count;
	u8 sync_level;
	union acpi_operand_object *mutex;
	u8 *aml_start;
	union {
		acpi_internal_method implementation;
		union acpi_operand_object *handler;
	} dispatch;
	u32 aml_length;
	u8 thread_count;
	acpi_owner_id owner_id;
};

struct acpi_thread_state;

struct acpi_object_mutex {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 sync_level;
	u16 acquisition_depth;
	void *os_mutex;
	u64 thread_id;
	struct acpi_thread_state *owner_thread;
	union acpi_operand_object *prev;
	union acpi_operand_object *next;
	struct acpi_namespace_node *node;
	u8 original_sync_level;
};

struct acpi_object_region {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler;
	union acpi_operand_object *next;
	acpi_physical_address address;
	u32 length;
};

struct acpi_object_notify_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_gpe_block_info;

struct acpi_object_device {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	struct acpi_gpe_block_info *gpe_block;
};

struct acpi_object_power_resource {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	u32 system_level;
	u32 resource_order;
};

struct acpi_object_processor {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 proc_id;
	u8 length;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	acpi_io_address address;
};

struct acpi_object_thermal_zone {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_object_field_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
};

struct acpi_object_region_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	u16 resource_length;
	union acpi_operand_object *region_obj;
	u8 *resource_buffer;
};

struct acpi_object_buffer_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *buffer_obj;
};

struct acpi_object_bank_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
	union acpi_operand_object *bank_obj;
};

struct acpi_object_index_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *index_obj;
	union acpi_operand_object *data_obj;
};

struct acpi_object_notify_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	u32 handler_type;
	acpi_notify_handler handler;
	void *context;
	union acpi_operand_object *next[2];
};

struct acpi_object_addr_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	u8 handler_flags;
	acpi_adr_space_handler handler;
	struct acpi_namespace_node *node;
	void *context;
	acpi_adr_space_setup setup;
	union acpi_operand_object *region_list;
	union acpi_operand_object *next;
};

struct acpi_object_reference {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 class;
	u8 target_type;
	u8 reserved;
	void *object;
	struct acpi_namespace_node *node;
	union acpi_operand_object **where;
	u32 value;
};

struct acpi_object_extra {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *method_REG;
	struct acpi_namespace_node *scope_node;
	void *region_context;
	u8 *aml_start;
	u32 aml_length;
};

struct acpi_object_data {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	acpi_object_handler handler;
	void *pointer;
};

struct acpi_object_cache_list {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *next;
};

union acpi_operand_object {
	struct acpi_object_common common;
	struct acpi_object_integer integer;
	struct acpi_object_string string;
	struct acpi_object_buffer buffer;
	struct acpi_object_package package;
	struct acpi_object_event event;
	struct acpi_object_method method;
	struct acpi_object_mutex mutex;
	struct acpi_object_region region;
	struct acpi_object_notify_common common_notify;
	struct acpi_object_device device;
	struct acpi_object_power_resource power_resource;
	struct acpi_object_processor processor;
	struct acpi_object_thermal_zone thermal_zone;
	struct acpi_object_field_common common_field;
	struct acpi_object_region_field field;
	struct acpi_object_buffer_field buffer_field;
	struct acpi_object_bank_field bank_field;
	struct acpi_object_index_field index_field;
	struct acpi_object_notify_handler notify;
	struct acpi_object_addr_handler address_space;
	struct acpi_object_reference reference;
	struct acpi_object_extra extra;
	struct acpi_object_data data;
	struct acpi_object_cache_list cache;
	struct acpi_namespace_node node;
};

union acpi_parse_object;

union acpi_generic_state;

struct acpi_parse_state {
	u8 *aml_start;
	u8 *aml;
	u8 *aml_end;
	u8 *pkg_start;
	u8 *pkg_end;
	union acpi_parse_object *start_op;
	struct acpi_namespace_node *start_node;
	union acpi_generic_state *scope;
	union acpi_parse_object *start_scope;
	u32 aml_size;
};

typedef acpi_status (*acpi_parse_downwards)(struct acpi_walk_state *, union acpi_parse_object **);

typedef acpi_status (*acpi_parse_upwards)(struct acpi_walk_state *);

struct acpi_opcode_info;

struct acpi_walk_state {
	struct acpi_walk_state *next;
	u8 descriptor_type;
	u8 walk_type;
	u16 opcode;
	u8 next_op_info;
	u8 num_operands;
	u8 operand_index;
	acpi_owner_id owner_id;
	u8 last_predicate;
	u8 current_result;
	u8 return_used;
	u8 scope_depth;
	u8 pass_number;
	u8 result_size;
	u8 result_count;
	u32 aml_offset;
	u32 arg_types;
	u32 method_breakpoint;
	u32 user_breakpoint;
	u32 parse_flags;
	struct acpi_parse_state parser_state;
	u32 prev_arg_types;
	u32 arg_count;
	struct acpi_namespace_node arguments[7];
	struct acpi_namespace_node local_variables[8];
	union acpi_operand_object *operands[9];
	union acpi_operand_object **params;
	u8 *aml_last_while;
	union acpi_operand_object **caller_return_desc;
	union acpi_generic_state *control_state;
	struct acpi_namespace_node *deferred_node;
	union acpi_operand_object *implicit_return_obj;
	struct acpi_namespace_node *method_call_node;
	union acpi_parse_object *method_call_op;
	union acpi_operand_object *method_desc;
	struct acpi_namespace_node *method_node;
	union acpi_parse_object *op;
	const struct acpi_opcode_info *op_info;
	union acpi_parse_object *origin;
	union acpi_operand_object *result_obj;
	union acpi_generic_state *results;
	union acpi_operand_object *return_desc;
	union acpi_generic_state *scope_info;
	union acpi_parse_object *prev_op;
	union acpi_parse_object *next_op;
	struct acpi_thread_state *thread;
	acpi_parse_downwards descending_callback;
	acpi_parse_upwards ascending_callback;
};

struct acpi_name_info {
	char name[4];
	u16 argument_list;
	u8 expected_btypes;
} __attribute__((packed));

struct acpi_package_info {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 object_type2;
	u8 count2;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info2 {
	u8 type;
	u8 count;
	u8 object_type[4];
	u8 reserved;
};

struct acpi_package_info3 {
	u8 type;
	u8 count;
	u8 object_type[2];
	u8 tail_object_type;
	u16 reserved;
} __attribute__((packed));

union acpi_predefined_info {
	struct acpi_name_info info;
	struct acpi_package_info ret_info;
	struct acpi_package_info2 ret_info2;
	struct acpi_package_info3 ret_info3;
};

struct acpi_gpe_handler_info {
	acpi_gpe_handler address;
	void *context;
	struct acpi_namespace_node *method_node;
	u8 original_flags;
	u8 originally_enabled;
};

struct acpi_gpe_notify_info {
	struct acpi_namespace_node *device_node;
	struct acpi_gpe_notify_info *next;
};

union acpi_gpe_dispatch_info {
	struct acpi_namespace_node *method_node;
	struct acpi_gpe_handler_info *handler;
	struct acpi_gpe_notify_info *notify_list;
};

struct acpi_gpe_register_info;

struct acpi_gpe_event_info {
	union acpi_gpe_dispatch_info dispatch;
	struct acpi_gpe_register_info *register_info;
	u8 flags;
	u8 gpe_number;
	u8 runtime_count;
};

struct acpi_gpe_register_info {
	struct acpi_generic_address status_address;
	struct acpi_generic_address enable_address;
	u8 enable_for_wake;
	u8 enable_for_run;
	u8 base_gpe_number;
} __attribute__((packed));

struct acpi_gpe_xrupt_info;

struct acpi_gpe_block_info {
	struct acpi_namespace_node *node;
	struct acpi_gpe_block_info *previous;
	struct acpi_gpe_block_info *next;
	struct acpi_gpe_xrupt_info *xrupt_block;
	struct acpi_gpe_register_info *register_info;
	struct acpi_gpe_event_info *event_info;
	struct acpi_generic_address block_address;
	u32 register_count;
	u16 gpe_count;
	u8 block_base_number;
	u8 initialized;
};

struct acpi_gpe_xrupt_info {
	struct acpi_gpe_xrupt_info *previous;
	struct acpi_gpe_xrupt_info *next;
	struct acpi_gpe_block_info *gpe_block_list_head;
	u32 interrupt_number;
};

struct acpi_common_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
};

struct acpi_update_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *object;
};

struct acpi_pkg_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u16 index;
	union acpi_operand_object *source_object;
	union acpi_operand_object *dest_object;
	struct acpi_walk_state *walk_state;
	void *this_target_obj;
	u32 num_packages;
};

struct acpi_control_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u16 opcode;
	union acpi_parse_object *predicate_op;
	u8 *aml_predicate_start;
	u8 *package_end;
	u32 loop_count;
};

union acpi_parse_value {
	u64 integer;
	u32 size;
	char *string;
	u8 *buffer;
	char *name;
	union acpi_parse_object *arg;
};

struct acpi_parse_obj_common {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u32 aml_offset;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
};

struct acpi_parse_obj_named {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u32 aml_offset;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	u8 *path;
	u8 *data;
	u32 length;
	u32 name;
};

struct acpi_parse_obj_asl {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u32 aml_offset;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	union acpi_parse_object *child;
	union acpi_parse_object *parent_method;
	char *filename;
	char *external_name;
	char *namepath;
	char name_seg[4];
	u32 extra_value;
	u32 column;
	u32 line_number;
	u32 logical_line_number;
	u32 logical_byte_offset;
	u32 end_line;
	u32 end_logical_line;
	u32 acpi_btype;
	u32 aml_length;
	u32 aml_subtree_length;
	u32 final_aml_length;
	u32 final_aml_offset;
	u32 compile_flags;
	u16 parse_opcode;
	u8 aml_opcode_length;
	u8 aml_pkg_len_bytes;
	u8 extra;
	char parse_op_name[20];
};

union acpi_parse_object {
	struct acpi_parse_obj_common common;
	struct acpi_parse_obj_named named;
	struct acpi_parse_obj_asl asl;
};

struct acpi_scope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	struct acpi_namespace_node *node;
};

struct acpi_pscope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u32 arg_count;
	union acpi_parse_object *op;
	u8 *arg_end;
	u8 *pkg_end;
	u32 arg_list;
};

struct acpi_thread_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 current_sync_level;
	struct acpi_walk_state *walk_state_list;
	union acpi_operand_object *acquired_mutex_list;
	u64 thread_id;
};

struct acpi_result_values {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *obj_desc[8];
};

struct acpi_global_notify_handler {
	acpi_notify_handler handler;
	void *context;
};

struct acpi_notify_info {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 handler_list_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler_list_head;
	struct acpi_global_notify_handler *global;
};

union acpi_generic_state {
	struct acpi_common_state common;
	struct acpi_control_state control;
	struct acpi_update_state update;
	struct acpi_scope_state scope;
	struct acpi_pscope_state parse_scope;
	struct acpi_pkg_state pkg;
	struct acpi_thread_state thread;
	struct acpi_result_values results;
	struct acpi_notify_info notify;
};

struct acpi_opcode_info {
	u32 parse_args;
	u32 runtime_args;
	u16 flags;
	u8 object_type;
	u8 class;
	u8 type;
};

struct acpi_evaluate_info {
	struct acpi_namespace_node *prefix_node;
	char *relative_pathname;
	union acpi_operand_object **parameters;
	struct acpi_namespace_node *node;
	union acpi_operand_object *obj_desc;
	char *full_pathname;
	const union acpi_predefined_info *predefined;
	union acpi_operand_object *return_object;
	union acpi_operand_object *parent_package;
	u32 return_flags;
	u32 return_btype;
	u16 param_count;
	u8 pass_number;
	u8 return_object_type;
	u8 node_flags;
	u8 flags;
};

enum {
	ACPI_REFCLASS_LOCAL = 0,
	ACPI_REFCLASS_ARG = 1,
	ACPI_REFCLASS_REFOF = 2,
	ACPI_REFCLASS_INDEX = 3,
	ACPI_REFCLASS_TABLE = 4,
	ACPI_REFCLASS_NAME = 5,
	ACPI_REFCLASS_DEBUG = 6,
	ACPI_REFCLASS_MAX = 6,
};

struct acpi_common_descriptor {
	void *common_pointer;
	u8 descriptor_type;
};

union acpi_descriptor {
	struct acpi_common_descriptor common;
	union acpi_operand_object object;
	struct acpi_namespace_node node;
	union acpi_parse_object op;
};

typedef enum {
	ACPI_IMODE_LOAD_PASS1 = 1,
	ACPI_IMODE_LOAD_PASS2 = 2,
	ACPI_IMODE_EXECUTE = 3,
} acpi_interpreter_mode;

struct acpi_create_field_info {
	struct acpi_namespace_node *region_node;
	struct acpi_namespace_node *field_node;
	struct acpi_namespace_node *register_node;
	struct acpi_namespace_node *data_register_node;
	struct acpi_namespace_node *connection_node;
	u8 *resource_buffer;
	u32 bank_value;
	u32 field_bit_position;
	u32 field_bit_length;
	u16 resource_length;
	u8 field_flags;
	u8 attribute;
	u8 field_type;
	u8 access_length;
};

typedef u32 acpi_mutex_handle;

struct acpi_init_walk_info {
	u32 table_index;
	u32 object_count;
	u32 method_count;
	u32 device_count;
	u32 op_region_count;
	u32 field_count;
	u32 buffer_count;
	u32 package_count;
	u32 op_region_init;
	u32 field_init;
	u32 buffer_init;
	u32 package_init;
	acpi_owner_id owner_id;
};

typedef unsigned char UINT8;

typedef u32 acpi_name;

typedef acpi_status (*acpi_exception_handler)(acpi_status, acpi_name, u16, u32, void *);

enum {
	AML_FIELD_ACCESS_ANY = 0,
	AML_FIELD_ACCESS_BYTE = 1,
	AML_FIELD_ACCESS_WORD = 2,
	AML_FIELD_ACCESS_DWORD = 3,
	AML_FIELD_ACCESS_QWORD = 4,
	AML_FIELD_ACCESS_BUFFER = 5,
};

typedef acpi_status (*acpi_execute_op)(struct acpi_walk_state *);

struct acpi_fixed_event_handler {
	acpi_event_handler handler;
	void *context;
};

struct acpi_fixed_event_info {
	u8 status_register_id;
	u8 enable_register_id;
	u16 status_bit_mask;
	u16 enable_bit_mask;
};

struct acpi_gpe_walk_info {
	struct acpi_namespace_node *gpe_device;
	struct acpi_gpe_block_info *gpe_block;
	u16 count;
	acpi_owner_id owner_id;
	u8 execute_by_owner_id;
};

struct acpi_gpe_device_info {
	u32 index;
	u32 next_block_base_index;
	acpi_status status;
	struct acpi_namespace_node *gpe_device;
};

typedef acpi_status (*acpi_gpe_callback)(struct acpi_gpe_xrupt_info *, struct acpi_gpe_block_info *, void *);

struct acpi_connection_info {
	u8 *connection;
	u16 length;
	u8 access_length;
};

struct acpi_mem_space_context {
	u32 length;
	acpi_physical_address address;
	acpi_physical_address mapped_physical_address;
	u8 *mapped_logical_address;
	acpi_size mapped_length;
};

enum {
	AML_FIELD_UPDATE_PRESERVE = 0,
	AML_FIELD_UPDATE_WRITE_AS_ONES = 32,
	AML_FIELD_UPDATE_WRITE_AS_ZEROS = 64,
};

struct acpi_signal_fatal_info {
	u32 type;
	u32 code;
	u32 argument;
};

enum {
	MATCH_MTR = 0,
	MATCH_MEQ = 1,
	MATCH_MLE = 2,
	MATCH_MLT = 3,
	MATCH_MGE = 4,
	MATCH_MGT = 5,
};

struct acpi_pci_device {
	acpi_handle device;
	struct acpi_pci_device *next;
};

struct acpi_bit_register_info {
	u8 parent_register;
	u8 bit_position;
	u16 access_bit_mask;
};

typedef short unsigned int UINT16;

struct acpi_port_info {
	char *name;
	u16 start;
	u16 end;
	u8 osi_dependency;
};

typedef acpi_status (*acpi_sleep_function)(u8);

struct acpi_sleep_functions {
	acpi_sleep_function legacy_function;
	acpi_sleep_function extended_function;
};

typedef acpi_status (*acpi_init_handler)(acpi_handle, u32);

struct acpi_device_walk_info {
	struct acpi_table_desc *table_desc;
	struct acpi_evaluate_info *evaluate_info;
	u32 device_count;
	u32 num_STA;
	u32 num_INI;
};

enum acpi_return_package_types {
	ACPI_PTYPE1_FIXED = 1,
	ACPI_PTYPE1_VAR = 2,
	ACPI_PTYPE1_OPTION = 3,
	ACPI_PTYPE2 = 4,
	ACPI_PTYPE2_COUNT = 5,
	ACPI_PTYPE2_PKG_COUNT = 6,
	ACPI_PTYPE2_FIXED = 7,
	ACPI_PTYPE2_MIN = 8,
	ACPI_PTYPE2_REV_FIXED = 9,
	ACPI_PTYPE2_FIX_VAR = 10,
};

typedef acpi_status (*acpi_object_converter)(union acpi_operand_object *, union acpi_operand_object **);

struct acpi_simple_repair_info {
	char name[4];
	u32 unexpected_btypes;
	u32 package_index;
	acpi_object_converter object_converter;
};

typedef acpi_status (*acpi_repair_function)(struct acpi_evaluate_info *, union acpi_operand_object **);

struct acpi_repair_info {
	char name[4];
	acpi_repair_function repair_function;
};

struct acpi_namestring_info {
	const char *external_name;
	const char *next_external_char;
	char *internal_name;
	u32 length;
	u32 num_segments;
	u32 num_carats;
	u8 fully_qualified;
};

struct acpi_rw_lock {
	void *writer_mutex;
	void *reader_mutex;
	u32 num_readers;
};

struct acpi_get_devices_info {
	acpi_walk_callback user_function;
	void *context;
	const char *hid;
};

struct aml_resource_small_header {
	u8 descriptor_type;
};

struct aml_resource_irq {
	u8 descriptor_type;
	u16 irq_mask;
	u8 flags;
} __attribute__((packed));

struct aml_resource_dma {
	u8 descriptor_type;
	u8 dma_channel_mask;
	u8 flags;
};

struct aml_resource_start_dependent {
	u8 descriptor_type;
	u8 flags;
};

struct aml_resource_end_dependent {
	u8 descriptor_type;
};

struct aml_resource_io {
	u8 descriptor_type;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u8 alignment;
	u8 address_length;
};

struct aml_resource_fixed_io {
	u8 descriptor_type;
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct aml_resource_vendor_small {
	u8 descriptor_type;
};

struct aml_resource_end_tag {
	u8 descriptor_type;
	u8 checksum;
};

struct aml_resource_fixed_dma {
	u8 descriptor_type;
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct aml_resource_large_header {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory24 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_vendor_large {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_fixed_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
} __attribute__((packed));

struct aml_resource_extended_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u8 revision_ID;
	u8 reserved;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
	u64 type_specific;
} __attribute__((packed));

struct aml_resource_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
} __attribute__((packed));

struct aml_resource_address32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address16 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_extended_irq {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u8 interrupt_count;
	u32 interrupts[1];
} __attribute__((packed));

struct aml_resource_generic_register {
	u8 descriptor_type;
	u16 resource_length;
	u8 address_space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct aml_resource_gpio {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 connection_type;
	u16 flags;
	u16 int_flags;
	u8 pin_config;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_common_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
} __attribute__((packed));

struct aml_resource_i2c_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u16 slave_address;
} __attribute__((packed));

struct aml_resource_spi_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
} __attribute__((packed));

struct aml_resource_uart_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 default_baud_rate;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u8 parity;
	u8 lines_enabled;
} __attribute__((packed));

union aml_resource {
	u8 descriptor_type;
	struct aml_resource_small_header small_header;
	struct aml_resource_large_header large_header;
	struct aml_resource_irq irq;
	struct aml_resource_dma dma;
	struct aml_resource_start_dependent start_dpf;
	struct aml_resource_end_dependent end_dpf;
	struct aml_resource_io io;
	struct aml_resource_fixed_io fixed_io;
	struct aml_resource_fixed_dma fixed_dma;
	struct aml_resource_vendor_small vendor_small;
	struct aml_resource_end_tag end_tag;
	struct aml_resource_memory24 memory24;
	struct aml_resource_generic_register generic_reg;
	struct aml_resource_vendor_large vendor_large;
	struct aml_resource_memory32 memory32;
	struct aml_resource_fixed_memory32 fixed_memory32;
	struct aml_resource_address16 address16;
	struct aml_resource_address32 address32;
	struct aml_resource_address64 address64;
	struct aml_resource_extended_address64 ext_address64;
	struct aml_resource_extended_irq extended_irq;
	struct aml_resource_gpio gpio;
	struct aml_resource_i2c_serialbus i2c_serial_bus;
	struct aml_resource_spi_serialbus spi_serial_bus;
	struct aml_resource_uart_serialbus uart_serial_bus;
	struct aml_resource_common_serialbus common_serial_bus;
	struct aml_resource_address address;
	u32 dword_item;
	u16 word_item;
	u8 byte_item;
};

struct acpi_rsconvert_info {
	u8 opcode;
	u8 resource_offset;
	u8 aml_offset;
	u8 value;
};

enum {
	ACPI_RSC_INITGET = 0,
	ACPI_RSC_INITSET = 1,
	ACPI_RSC_FLAGINIT = 2,
	ACPI_RSC_1BITFLAG = 3,
	ACPI_RSC_2BITFLAG = 4,
	ACPI_RSC_3BITFLAG = 5,
	ACPI_RSC_ADDRESS = 6,
	ACPI_RSC_BITMASK = 7,
	ACPI_RSC_BITMASK16 = 8,
	ACPI_RSC_COUNT = 9,
	ACPI_RSC_COUNT16 = 10,
	ACPI_RSC_COUNT_GPIO_PIN = 11,
	ACPI_RSC_COUNT_GPIO_RES = 12,
	ACPI_RSC_COUNT_GPIO_VEN = 13,
	ACPI_RSC_COUNT_SERIAL_RES = 14,
	ACPI_RSC_COUNT_SERIAL_VEN = 15,
	ACPI_RSC_DATA8 = 16,
	ACPI_RSC_EXIT_EQ = 17,
	ACPI_RSC_EXIT_LE = 18,
	ACPI_RSC_EXIT_NE = 19,
	ACPI_RSC_LENGTH = 20,
	ACPI_RSC_MOVE_GPIO_PIN = 21,
	ACPI_RSC_MOVE_GPIO_RES = 22,
	ACPI_RSC_MOVE_SERIAL_RES = 23,
	ACPI_RSC_MOVE_SERIAL_VEN = 24,
	ACPI_RSC_MOVE8 = 25,
	ACPI_RSC_MOVE16 = 26,
	ACPI_RSC_MOVE32 = 27,
	ACPI_RSC_MOVE64 = 28,
	ACPI_RSC_SET8 = 29,
	ACPI_RSC_SOURCE = 30,
	ACPI_RSC_SOURCEX = 31,
};

typedef u16 acpi_rs_length;

typedef acpi_status (*acpi_walk_aml_callback)(u8 *, u32, u32, u8, void **);

typedef u32 acpi_rsdesc_size;

struct acpi_vendor_uuid {
	u8 subtype;
	u8 data[16];
};

struct acpi_vendor_walk_info {
	struct acpi_vendor_uuid *uuid;
	struct acpi_buffer *buffer;
	acpi_status status;
};

struct acpi_table_list {
	struct acpi_table_desc *tables;
	u32 current_table_count;
	u32 max_table_count;
	u8 flags;
};

struct acpi_fadt_info {
	char *name;
	u16 address64;
	u16 address32;
	u16 length;
	u8 default_length;
	u8 flags;
};

struct acpi_fadt_pm_info {
	struct acpi_generic_address *target;
	u16 source;
	u8 register_num;
};

struct acpi_table_rsdp {
	char signature[8];
	u8 checksum;
	char oem_id[6];
	u8 revision;
	u32 rsdt_physical_address;
	u32 length;
	u64 xsdt_physical_address;
	u8 extended_checksum;
	u8 reserved[3];
} __attribute__((packed));

struct acpi_address_range {
	struct acpi_address_range *next;
	struct acpi_namespace_node *region_node;
	acpi_physical_address start_address;
	acpi_physical_address end_address;
};

typedef acpi_status (*acpi_pkg_callback)(u8, union acpi_operand_object *, union acpi_generic_state *, void *);

struct acpi_pkg_info {
	u8 *free_space;
	acpi_size length;
	u32 object_space;
	u32 num_packages;
};

struct acpi_exception_info {
	char *name;
};

struct acpi_mutex_info {
	void *mutex;
	u32 use_count;
	u64 thread_id;
};

struct acpi_interface_info {
	char *name;
	struct acpi_interface_info *next;
	u8 flags;
	u8 value;
};

enum led_brightness {
	LED_OFF = 0,
	LED_HALF = 127,
	LED_FULL = 255,
};

struct led_trigger;

struct led_classdev {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev *);
	int (*blink_set)(struct led_classdev *, long unsigned int *, long unsigned int *);
	struct device___157 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger {
	const char *name;
	void (*activate)(struct led_classdev *);
	void (*deactivate)(struct led_classdev *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

enum power_supply_property {
	POWER_SUPPLY_PROP_STATUS = 0,
	POWER_SUPPLY_PROP_CHARGE_TYPE = 1,
	POWER_SUPPLY_PROP_HEALTH = 2,
	POWER_SUPPLY_PROP_PRESENT = 3,
	POWER_SUPPLY_PROP_ONLINE = 4,
	POWER_SUPPLY_PROP_AUTHENTIC = 5,
	POWER_SUPPLY_PROP_TECHNOLOGY = 6,
	POWER_SUPPLY_PROP_CYCLE_COUNT = 7,
	POWER_SUPPLY_PROP_VOLTAGE_MAX = 8,
	POWER_SUPPLY_PROP_VOLTAGE_MIN = 9,
	POWER_SUPPLY_PROP_VOLTAGE_MAX_DESIGN = 10,
	POWER_SUPPLY_PROP_VOLTAGE_MIN_DESIGN = 11,
	POWER_SUPPLY_PROP_VOLTAGE_NOW = 12,
	POWER_SUPPLY_PROP_VOLTAGE_AVG = 13,
	POWER_SUPPLY_PROP_VOLTAGE_OCV = 14,
	POWER_SUPPLY_PROP_CURRENT_MAX = 15,
	POWER_SUPPLY_PROP_CURRENT_NOW = 16,
	POWER_SUPPLY_PROP_CURRENT_AVG = 17,
	POWER_SUPPLY_PROP_POWER_NOW = 18,
	POWER_SUPPLY_PROP_POWER_AVG = 19,
	POWER_SUPPLY_PROP_CHARGE_FULL_DESIGN = 20,
	POWER_SUPPLY_PROP_CHARGE_EMPTY_DESIGN = 21,
	POWER_SUPPLY_PROP_CHARGE_FULL = 22,
	POWER_SUPPLY_PROP_CHARGE_EMPTY = 23,
	POWER_SUPPLY_PROP_CHARGE_NOW = 24,
	POWER_SUPPLY_PROP_CHARGE_AVG = 25,
	POWER_SUPPLY_PROP_CHARGE_COUNTER = 26,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT = 27,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT_MAX = 28,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE = 29,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE_MAX = 30,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT = 31,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT_MAX = 32,
	POWER_SUPPLY_PROP_ENERGY_FULL_DESIGN = 33,
	POWER_SUPPLY_PROP_ENERGY_EMPTY_DESIGN = 34,
	POWER_SUPPLY_PROP_ENERGY_FULL = 35,
	POWER_SUPPLY_PROP_ENERGY_EMPTY = 36,
	POWER_SUPPLY_PROP_ENERGY_NOW = 37,
	POWER_SUPPLY_PROP_ENERGY_AVG = 38,
	POWER_SUPPLY_PROP_CAPACITY = 39,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MIN = 40,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MAX = 41,
	POWER_SUPPLY_PROP_CAPACITY_LEVEL = 42,
	POWER_SUPPLY_PROP_TEMP = 43,
	POWER_SUPPLY_PROP_TEMP_ALERT_MIN = 44,
	POWER_SUPPLY_PROP_TEMP_ALERT_MAX = 45,
	POWER_SUPPLY_PROP_TEMP_AMBIENT = 46,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MIN = 47,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MAX = 48,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_NOW = 49,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_AVG = 50,
	POWER_SUPPLY_PROP_TIME_TO_FULL_NOW = 51,
	POWER_SUPPLY_PROP_TIME_TO_FULL_AVG = 52,
	POWER_SUPPLY_PROP_TYPE = 53,
	POWER_SUPPLY_PROP_SCOPE = 54,
	POWER_SUPPLY_PROP_MODEL_NAME = 55,
	POWER_SUPPLY_PROP_MANUFACTURER = 56,
	POWER_SUPPLY_PROP_SERIAL_NUMBER = 57,
};

enum power_supply_type {
	POWER_SUPPLY_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_TYPE_BATTERY = 1,
	POWER_SUPPLY_TYPE_UPS = 2,
	POWER_SUPPLY_TYPE_MAINS = 3,
	POWER_SUPPLY_TYPE_USB = 4,
	POWER_SUPPLY_TYPE_USB_DCP = 5,
	POWER_SUPPLY_TYPE_USB_CDP = 6,
	POWER_SUPPLY_TYPE_USB_ACA = 7,
};

union power_supply_propval {
	int intval;
	const char *strval;
};

struct thermal_zone_device;

struct power_supply {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply *);
	void (*set_charged)(struct power_supply *);
	int use_for_apm;
	struct device___157 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger *charging_trig;
	char *charging_trig_name;
	struct led_trigger *full_trig;
	char *full_trig_name;
	struct led_trigger *online_trig;
	char *online_trig_name;
	struct led_trigger *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct acpi_ac {
	struct power_supply charger;
	struct acpi_device___14 *device;
	long long unsigned int state;
};

struct device___167;

struct dev_pm_ops___167 {
	int (*prepare)(struct device___167 *);
	void (*complete)(struct device___167 *);
	int (*suspend)(struct device___167 *);
	int (*resume)(struct device___167 *);
	int (*freeze)(struct device___167 *);
	int (*thaw)(struct device___167 *);
	int (*poweroff)(struct device___167 *);
	int (*restore)(struct device___167 *);
	int (*suspend_late)(struct device___167 *);
	int (*resume_early)(struct device___167 *);
	int (*freeze_late)(struct device___167 *);
	int (*thaw_early)(struct device___167 *);
	int (*poweroff_late)(struct device___167 *);
	int (*restore_early)(struct device___167 *);
	int (*suspend_noirq)(struct device___167 *);
	int (*resume_noirq)(struct device___167 *);
	int (*freeze_noirq)(struct device___167 *);
	int (*thaw_noirq)(struct device___167 *);
	int (*poweroff_noirq)(struct device___167 *);
	int (*restore_noirq)(struct device___167 *);
	int (*runtime_suspend)(struct device___167 *);
	int (*runtime_resume)(struct device___167 *);
	int (*runtime_idle)(struct device___167 *);
};

struct acpi_device___19;

struct acpi_dev_node___25 {
	union {
		struct acpi_device___19 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___167;

struct bus_type___167;

struct device_driver___167;

struct dev_pm_domain___167;

struct class___167;

struct device_rh___167;

struct device___167 {
	struct device___167 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___167 *type;
	struct mutex___178 mutex;
	struct bus_type___167 *bus;
	struct device_driver___167 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___167 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___70 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___167 *class;
	const struct attribute_group___132 **groups;
	void (*release)(struct device___167 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___167 *device_rh;
};

struct dev_pm_info_rh___167 {
	void (*set_latency_tolerance)(struct device___167 *, s32);
};

struct dev_pm_domain___167 {
	struct dev_pm_ops___167 ops;
};

struct input_id {
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
};

struct input_absinfo {
	__s32 value;
	__s32 minimum;
	__s32 maximum;
	__s32 fuzz;
	__s32 flat;
	__s32 resolution;
};

struct input_keymap_entry {
	__u8 flags;
	__u8 len;
	__u16 index;
	__u32 keycode;
	__u8 scancode[32];
};

struct ff_replay {
	__u16 length;
	__u16 delay;
};

struct ff_trigger {
	__u16 button;
	__u16 interval;
};

struct ff_envelope {
	__u16 attack_length;
	__u16 attack_level;
	__u16 fade_length;
	__u16 fade_level;
};

struct ff_constant_effect {
	__s16 level;
	struct ff_envelope envelope;
};

struct ff_ramp_effect {
	__s16 start_level;
	__s16 end_level;
	struct ff_envelope envelope;
};

struct ff_condition_effect {
	__u16 right_saturation;
	__u16 left_saturation;
	__s16 right_coeff;
	__s16 left_coeff;
	__u16 deadband;
	__s16 center;
};

struct ff_periodic_effect {
	__u16 waveform;
	__u16 period;
	__s16 magnitude;
	__s16 offset;
	__u16 phase;
	struct ff_envelope envelope;
	__u32 custom_len;
	__s16 *custom_data;
};

struct ff_rumble_effect {
	__u16 strong_magnitude;
	__u16 weak_magnitude;
};

struct ff_effect {
	__u16 type;
	__s16 id;
	__u16 direction;
	struct ff_trigger trigger;
	struct ff_replay replay;
	union {
		struct ff_constant_effect constant;
		struct ff_ramp_effect ramp;
		struct ff_periodic_effect periodic;
		struct ff_condition_effect condition[2];
		struct ff_rumble_effect rumble;
	} u;
};

struct bus_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___167 *, char *);
	ssize_t (*store)(struct bus_type___167 *, const char *, size_t);
};

struct device_attribute___167;

struct driver_attribute___167;

struct bus_type___167 {
	const char *name;
	const char *dev_name;
	struct device___167 *dev_root;
	struct bus_attribute___167 *bus_attrs;
	struct device_attribute___167 *dev_attrs;
	struct driver_attribute___167 *drv_attrs;
	const struct attribute_group___132 **bus_groups;
	const struct attribute_group___132 **dev_groups;
	const struct attribute_group___132 **drv_groups;
	int (*match)(struct device___167 *, struct device_driver___167 *);
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	int (*probe)(struct device___167 *);
	int (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*online)(struct device___167 *);
	int (*offline)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct device___167 *, struct device_attribute___167 *, char *);
	ssize_t (*store)(struct device___167 *, struct device_attribute___167 *, const char *, size_t);
};

struct driver_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___167 *, char *);
	ssize_t (*store)(struct device_driver___167 *, const char *, size_t);
};

struct device_driver___167 {
	const char *name;
	struct bus_type___167 *bus;
	struct module___94 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___167 *);
	int (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	const struct attribute_group___132 **groups;
	const struct dev_pm_ops___167 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___167 {
	const char *name;
	const struct attribute_group___132 **groups;
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
};

struct class_attribute___167;

struct class___167 {
	const char *name;
	struct module___94 *owner;
	struct class_attribute___167 *class_attrs;
	struct device_attribute___167 *dev_attrs;
	const struct attribute_group___132 **dev_groups;
	struct bin_attribute___134 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *);
	void (*class_release)(struct class___167 *);
	void (*dev_release)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
	struct subsys_private *p;
};

struct class_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct class___167 *, struct class_attribute___167 *, char *);
	ssize_t (*store)(struct class___167 *, struct class_attribute___167 *, const char *, size_t);
	const void * (*namespace)(struct class___167 *, const struct class_attribute___167 *);
};

struct acpi_scan_handler___19;

struct acpi_hotplug_context___19;

struct acpi_driver___19;

struct acpi_device___19 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___19 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___19 *handler;
	struct acpi_hotplug_context___19 *hp;
	struct acpi_driver___19 *driver;
	void *driver_data;
	struct device___167 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___178 physical_node_lock;
	void (*remove)(struct acpi_device___19 *);
};

struct device_rh___167 {
	struct dev_pm_info_rh___167 power;
};

struct input_device_id {
	kernel_ulong_t flags;
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
	kernel_ulong_t evbit[1];
	kernel_ulong_t keybit[12];
	kernel_ulong_t relbit[1];
	kernel_ulong_t absbit[1];
	kernel_ulong_t mscbit[1];
	kernel_ulong_t ledbit[1];
	kernel_ulong_t sndbit[1];
	kernel_ulong_t ffbit[2];
	kernel_ulong_t swbit[1];
	kernel_ulong_t driver_info;
};

struct input_value {
	__u16 type;
	__u16 code;
	__s32 value;
};

struct ff_device;

struct input_mt;

struct input_handle;

struct input_dev {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev *, struct input_keymap_entry *);
	struct ff_device *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev *);
	void (*close)(struct input_dev *);
	int (*flush)(struct input_dev *, struct file___175 *);
	int (*event)(struct input_dev *, unsigned int, unsigned int, int);
	struct input_handle *grab;
	spinlock_t event_lock;
	struct mutex___178 mutex;
	unsigned int users;
	bool going_away;
	struct device___167 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device {
	int (*upload)(struct input_dev *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev *, int);
	int (*playback)(struct input_dev *, int, int);
	void (*set_gain)(struct input_dev *, u16);
	void (*set_autocenter)(struct input_dev *, u16);
	void (*destroy)(struct ff_device *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___178 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___175 *effect_owners[0];
};

struct input_handler;

struct input_handle {
	void *private;
	int open;
	const char *name;
	struct input_dev *dev;
	struct input_handler *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler {
	void *private;
	void (*event)(struct input_handle *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler *, struct input_dev *);
	int (*connect)(struct input_handler *, struct input_dev *, const struct input_device_id *);
	void (*disconnect)(struct input_handle *);
	void (*start)(struct input_handle *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct acpi_hotplug_profile___19 {
	struct kobject___4 kobj;
	int (*scan_dependent)(struct acpi_device___19 *);
	void (*notify_online)(struct acpi_device___19 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___19 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___19 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___19 *);
	void (*bind)(struct device___167 *);
	void (*unbind)(struct device___167 *);
	struct acpi_hotplug_profile___19 hotplug;
};

struct acpi_hotplug_context___19 {
	struct acpi_device___19 *self;
	int (*notify)(struct acpi_device___19 *, u32);
	void (*uevent)(struct acpi_device___19 *, u32);
	void (*fixup)(struct acpi_device___19 *);
};

typedef int (*acpi_op_add___19)(struct acpi_device___19 *);

typedef int (*acpi_op_remove___19)(struct acpi_device___19 *);

typedef void (*acpi_op_notify___19)(struct acpi_device___19 *, u32);

struct acpi_device_ops___19 {
	acpi_op_add___19 add;
	acpi_op_remove___19 remove;
	acpi_op_notify___19 notify;
};

struct acpi_driver___19 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___19 ops;
	struct device_driver___167 drv;
	struct module___94 *owner;
};

struct acpi_button {
	unsigned int type;
	struct input_dev *input;
	char phys[32];
	long unsigned int pushed;
	bool wakeup_enabled;
};

struct acpi_fan_fps {
	u64 control;
	u64 trip_point;
	u64 speed;
	u64 noise_level;
	u64 power;
};

struct acpi_fan_fif {
	u64 revision;
	u64 fine_grain_ctrl;
	u64 step_size;
	u64 low_speed_notification;
};

struct acpi_fan {
	bool acpi4;
	struct acpi_fan_fif fif;
	struct acpi_fan_fps *fps;
	int fps_count;
	struct thermal_cooling_device *cdev;
};

struct acpi_pci_slot {
	struct pci_slot___22 *pci_slot;
	struct list_head list;
};

struct cpuidle_driver___2;

struct cpuidle_state___2 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___2 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
};

struct cpuidle_driver___2 {
	const char *name;
	struct module___106 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___2 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct thermal_cooling_device_ops___2;

struct thermal_cooling_device___2 {
	int id;
	char type[20];
	struct device___165 device;
	void *devdata;
	const struct thermal_cooling_device_ops___2 *ops;
	bool updated;
	struct mutex___195 lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___2 {
	int (*get_max_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___2 *, long unsigned int);
};

struct acpi_processor___2;

struct acpi_processor_throttling___2 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___2 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___2 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___2 {
	acpi_handle handle;
	u32 acpi_id;
	u32 phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___2 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___2 *cdev;
	struct device___165 *dev;
};

struct throttling_tstate {
	unsigned int cpu;
	int target_state;
};

struct cpufreq_cpuinfo {
	unsigned int max_freq;
	unsigned int min_freq;
	unsigned int transition_latency;
};

struct cpufreq_governor;

struct cpufreq_real_policy {
	unsigned int min;
	unsigned int max;
	unsigned int policy;
	struct cpufreq_governor *governor;
};

struct cpufreq_policy;

struct cpufreq_governor {
	char name[16];
	int initialized;
	int (*governor)(struct cpufreq_policy *, unsigned int);
	ssize_t (*show_setspeed)(struct cpufreq_policy *, char *);
	int (*store_setspeed)(struct cpufreq_policy *, unsigned int);
	unsigned int max_transition_latency;
	struct list_head governor_list;
	struct module___106 *owner;
};

struct clk;

struct cpufreq_frequency_table;

struct cpufreq_policy {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	unsigned int last_cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	struct cpufreq_governor *governor;
	void *governor_data;
	bool governor_enabled;
	struct work_struct update;
	struct cpufreq_real_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	struct list_head policy_list;
	struct kobject___20 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___192 *transition_task;
};

struct cpufreq_frequency_table {
	unsigned int flags;
	unsigned int driver_data;
	unsigned int frequency;
};

struct container_dev {
	struct device___157 dev;
	int (*offline)(struct container_dev *);
};

enum thermal_device_mode {
	THERMAL_DEVICE_DISABLED = 0,
	THERMAL_DEVICE_ENABLED = 1,
};

enum thermal_trip_type {
	THERMAL_TRIP_ACTIVE = 0,
	THERMAL_TRIP_PASSIVE = 1,
	THERMAL_TRIP_HOT = 2,
	THERMAL_TRIP_CRITICAL = 3,
};

enum thermal_trend {
	THERMAL_TREND_STABLE = 0,
	THERMAL_TREND_RAISING = 1,
	THERMAL_TREND_DROPPING = 2,
	THERMAL_TREND_RAISE_FULL = 3,
	THERMAL_TREND_DROP_FULL = 4,
};

struct thermal_zone_device_ops {
	int (*bind)(struct thermal_zone_device *, struct thermal_cooling_device *);
	int (*unbind)(struct thermal_zone_device *, struct thermal_cooling_device *);
	int (*get_temp)(struct thermal_zone_device *, long unsigned int *);
	int (*get_mode)(struct thermal_zone_device *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device *, int, long unsigned int *);
	int (*set_trip_temp)(struct thermal_zone_device *, int, long unsigned int);
	int (*get_trip_hyst)(struct thermal_zone_device *, int, long unsigned int *);
	int (*set_trip_hyst)(struct thermal_zone_device *, int, long unsigned int);
	int (*get_crit_temp)(struct thermal_zone_device *, long unsigned int *);
	int (*set_emul_temp)(struct thermal_zone_device *, long unsigned int);
	int (*get_trend)(struct thermal_zone_device *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device *, int, enum thermal_trip_type);
};

struct thermal_attr;

struct thermal_zone_params;

struct thermal_governor;

struct thermal_zone_device {
	int id;
	char type[20];
	struct device___157 device;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	void *devdata;
	int trips;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	unsigned int forced_passive;
	const struct thermal_zone_device_ops *ops;
	const struct thermal_zone_params *tzp;
	struct thermal_governor *governor;
	struct list_head thermal_instances;
	struct idr idr;
	struct mutex___193 lock;
	struct list_head node;
	struct delayed_work poll_queue;
};

struct thermal_attr {
	struct device_attribute___157 attr;
	char name[20];
};

struct thermal_bind_params;

struct thermal_zone_params {
	char governor_name[20];
	int num_tbps;
	struct thermal_bind_params *tbp;
};

struct thermal_governor {
	char name[20];
	int (*throttle)(struct thermal_zone_device *, int);
	struct list_head governor_list;
};

struct thermal_bind_params {
	struct thermal_cooling_device *cdev;
	int weight;
	int trip_mask;
	int (*match)(struct thermal_zone_device *, struct thermal_cooling_device *);
};

struct acpi_thermal_state {
	u8 critical: 1;
	u8 hot: 1;
	u8 passive: 1;
	u8 active: 1;
	u8 reserved: 4;
	int active_index;
};

struct acpi_thermal_state_flags {
	u8 valid: 1;
	u8 enabled: 1;
	u8 reserved: 6;
};

struct acpi_thermal_critical {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_hot {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_passive {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	long unsigned int tc1;
	long unsigned int tc2;
	long unsigned int tsp;
	struct acpi_handle_list devices;
};

struct acpi_thermal_active {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	struct acpi_handle_list devices;
};

struct acpi_thermal_trips {
	struct acpi_thermal_critical critical;
	struct acpi_thermal_hot hot;
	struct acpi_thermal_passive passive;
	struct acpi_thermal_active active[10];
};

struct acpi_thermal_flags {
	u8 cooling_mode: 1;
	u8 devices: 1;
	u8 reserved: 6;
};

struct acpi_thermal {
	struct acpi_device___14 *device;
	acpi_bus_id name;
	long unsigned int temperature;
	long unsigned int last_temperature;
	long unsigned int polling_frequency;
	volatile u8 zombie;
	struct acpi_thermal_flags flags;
	struct acpi_thermal_state state;
	struct acpi_thermal_trips trips;
	struct acpi_handle_list devices;
	struct thermal_zone_device *thermal_zone;
	int tz_enabled;
	int kelvin_offset;
	struct mutex___193 lock;
};

struct memory_block___2 {
	long unsigned int start_section_nr;
	long unsigned int end_section_nr;
	long unsigned int state;
	int section_count;
	int online_type;
	int phys_device;
	void *hw;
	int (*phys_callback)(struct memory_block___2 *);
	struct device___157 dev;
};

struct acpi_memory_info {
	struct list_head list;
	u64 start_addr;
	u64 length;
	short unsigned int caching;
	short unsigned int write_protect;
	unsigned int enabled: 1;
};

struct acpi_memory_device {
	struct acpi_device___14 *device;
	unsigned int state;
	struct list_head res_list;
};

enum dmi_entry_type {
	DMI_ENTRY_BIOS = 0,
	DMI_ENTRY_SYSTEM = 1,
	DMI_ENTRY_BASEBOARD = 2,
	DMI_ENTRY_CHASSIS = 3,
	DMI_ENTRY_PROCESSOR = 4,
	DMI_ENTRY_MEM_CONTROLLER = 5,
	DMI_ENTRY_MEM_MODULE = 6,
	DMI_ENTRY_CACHE = 7,
	DMI_ENTRY_PORT_CONNECTOR = 8,
	DMI_ENTRY_SYSTEM_SLOT = 9,
	DMI_ENTRY_ONBOARD_DEVICE = 10,
	DMI_ENTRY_OEMSTRINGS = 11,
	DMI_ENTRY_SYSCONF = 12,
	DMI_ENTRY_BIOS_LANG = 13,
	DMI_ENTRY_GROUP_ASSOC = 14,
	DMI_ENTRY_SYSTEM_EVENT_LOG = 15,
	DMI_ENTRY_PHYS_MEM_ARRAY = 16,
	DMI_ENTRY_MEM_DEVICE = 17,
	DMI_ENTRY_32_MEM_ERROR = 18,
	DMI_ENTRY_MEM_ARRAY_MAPPED_ADDR = 19,
	DMI_ENTRY_MEM_DEV_MAPPED_ADDR = 20,
	DMI_ENTRY_BUILTIN_POINTING_DEV = 21,
	DMI_ENTRY_PORTABLE_BATTERY = 22,
	DMI_ENTRY_SYSTEM_RESET = 23,
	DMI_ENTRY_HW_SECURITY = 24,
	DMI_ENTRY_SYSTEM_POWER_CONTROLS = 25,
	DMI_ENTRY_VOLTAGE_PROBE = 26,
	DMI_ENTRY_COOLING_DEV = 27,
	DMI_ENTRY_TEMP_PROBE = 28,
	DMI_ENTRY_ELECTRICAL_CURRENT_PROBE = 29,
	DMI_ENTRY_OOB_REMOTE_ACCESS = 30,
	DMI_ENTRY_BIS_ENTRY = 31,
	DMI_ENTRY_SYSTEM_BOOT = 32,
	DMI_ENTRY_MGMT_DEV = 33,
	DMI_ENTRY_MGMT_DEV_COMPONENT = 34,
	DMI_ENTRY_MGMT_DEV_THRES = 35,
	DMI_ENTRY_MEM_CHANNEL = 36,
	DMI_ENTRY_IPMI_DEV = 37,
	DMI_ENTRY_SYS_POWER_SUPPLY = 38,
	DMI_ENTRY_ADDITIONAL = 39,
	DMI_ENTRY_ONBOARD_DEV_EXT = 40,
	DMI_ENTRY_MGMT_CONTROLLER_HOST = 41,
	DMI_ENTRY_INACTIVE = 126,
	DMI_ENTRY_END_OF_TABLE = 127,
};

struct dmi_header {
	u8 type;
	u8 length;
	u16 handle;
};

struct led_trigger___2;

struct led_classdev___2 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___2 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___2 *);
	int (*blink_set)(struct led_classdev___2 *, long unsigned int *, long unsigned int *);
	struct device___43 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___2 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___2 {
	const char *name;
	void (*activate)(struct led_classdev___2 *);
	void (*deactivate)(struct led_classdev___2 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

enum {
	POWER_SUPPLY_STATUS_UNKNOWN = 0,
	POWER_SUPPLY_STATUS_CHARGING = 1,
	POWER_SUPPLY_STATUS_DISCHARGING = 2,
	POWER_SUPPLY_STATUS_NOT_CHARGING = 3,
	POWER_SUPPLY_STATUS_FULL = 4,
};

enum {
	POWER_SUPPLY_TECHNOLOGY_UNKNOWN = 0,
	POWER_SUPPLY_TECHNOLOGY_NiMH = 1,
	POWER_SUPPLY_TECHNOLOGY_LION = 2,
	POWER_SUPPLY_TECHNOLOGY_LIPO = 3,
	POWER_SUPPLY_TECHNOLOGY_LiFe = 4,
	POWER_SUPPLY_TECHNOLOGY_NiCd = 5,
	POWER_SUPPLY_TECHNOLOGY_LiMn = 6,
};

struct power_supply___2 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply___2 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___2 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___2 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___2 *);
	void (*set_charged)(struct power_supply___2 *);
	int use_for_apm;
	struct device___43 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger___2 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___2 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___2 *full_trig;
	char *full_trig_name;
	struct led_trigger___2 *online_trig;
	char *online_trig_name;
	struct led_trigger___2 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

enum {
	ACPI_BATTERY_ALARM_PRESENT = 0,
	ACPI_BATTERY_XINFO_PRESENT = 1,
	ACPI_BATTERY_QUIRK_PERCENTAGE_CAPACITY = 2,
	ACPI_BATTERY_QUIRK_THINKPAD_MAH = 3,
};

struct acpi_battery {
	struct mutex___66 lock;
	struct mutex___66 sysfs_lock;
	struct power_supply___2 bat;
	struct acpi_device___11 *device;
	struct notifier_block pm_nb;
	long unsigned int update_time;
	int revision;
	int rate_now;
	int capacity_now;
	int voltage_now;
	int design_capacity;
	int full_charge_capacity;
	int technology;
	int design_voltage;
	int design_capacity_warning;
	int design_capacity_low;
	int cycle_count;
	int measurement_accuracy;
	int max_sampling_time;
	int min_sampling_time;
	int max_averaging_interval;
	int min_averaging_interval;
	int capacity_granularity_1;
	int capacity_granularity_2;
	int alarm;
	char model_number[32];
	char serial_number[32];
	char type[32];
	char oem_info[32];
	int state;
	int power_unit;
	long unsigned int flags;
};

struct acpi_offsets {
	size_t offset;
	u8 mode;
};

struct acpi_whea_header {
	u8 action;
	u8 instruction;
	u8 flags;
	u8 reserved;
	struct acpi_generic_address register_region;
	u64 value;
	u64 mask;
} __attribute__((packed));

struct apei_exec_context;

typedef int (*apei_exec_ins_func_t)(struct apei_exec_context *, struct acpi_whea_header *);

struct apei_exec_ins_type;

struct apei_exec_context {
	u32 ip;
	u64 value;
	u64 var1;
	u64 var2;
	u64 src_base;
	u64 dst_base;
	struct apei_exec_ins_type *ins_table;
	u32 instructions;
	struct acpi_whea_header *action_table;
	u32 entries;
};

struct apei_exec_ins_type {
	u32 flags;
	apei_exec_ins_func_t run;
};

struct apei_resources {
	struct list_head iomem;
	struct list_head ioport;
};

typedef int (*apei_exec_entry_func_t)(struct apei_exec_context *, struct acpi_whea_header *, void *);

struct apei_res {
	struct list_head list;
	long unsigned int start;
	long unsigned int end;
};

struct acpi_table_hest {
	struct acpi_table_header header;
	u32 error_source_count;
};

struct acpi_hest_ia_error_bank {
	u8 bank_number;
	u8 clear_status_on_init;
	u8 status_format;
	u8 reserved;
	u32 control_register;
	u64 control_data;
	u32 status_register;
	u32 address_register;
	u32 misc_register;
} __attribute__((packed));

struct acpi_hest_notify {
	u8 type;
	u8 length;
	u16 config_write_enable;
	u32 poll_interval;
	u32 vector;
	u32 polling_threshold_value;
	u32 polling_threshold_window;
	u32 error_threshold_value;
	u32 error_threshold_window;
};

struct acpi_hest_ia_machine_check {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u64 global_capability_data;
	u64 global_control_data;
	u8 num_hardware_banks;
	u8 reserved3[7];
};

struct acpi_hest_ia_corrected {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	struct acpi_hest_notify notify;
	u8 num_hardware_banks;
	u8 reserved2[3];
};

struct acpi_hest_generic {
	struct acpi_hest_header header;
	u16 related_source_id;
	u8 reserved;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 max_raw_data_length;
	struct acpi_generic_address error_status_address;
	struct acpi_hest_notify notify;
	u32 error_block_length;
} __attribute__((packed));

struct ghes_arr {
	struct platform_device___5 **ghes_devs;
	unsigned int count;
};

struct acpi_table_erst {
	struct acpi_table_header header;
	u32 header_length;
	u32 reserved;
	u32 entries;
};

enum acpi_erst_actions {
	ACPI_ERST_BEGIN_WRITE = 0,
	ACPI_ERST_BEGIN_READ = 1,
	ACPI_ERST_BEGIN_CLEAR = 2,
	ACPI_ERST_END = 3,
	ACPI_ERST_SET_RECORD_OFFSET = 4,
	ACPI_ERST_EXECUTE_OPERATION = 5,
	ACPI_ERST_CHECK_BUSY_STATUS = 6,
	ACPI_ERST_GET_COMMAND_STATUS = 7,
	ACPI_ERST_GET_RECORD_ID = 8,
	ACPI_ERST_SET_RECORD_ID = 9,
	ACPI_ERST_GET_RECORD_COUNT = 10,
	ACPI_ERST_BEGIN_DUMMY_WRIITE = 11,
	ACPI_ERST_NOT_USED = 12,
	ACPI_ERST_GET_ERROR_RANGE = 13,
	ACPI_ERST_GET_ERROR_LENGTH = 14,
	ACPI_ERST_GET_ERROR_ATTRIBUTES = 15,
	ACPI_ERST_ACTION_RESERVED = 16,
};

enum acpi_erst_instructions {
	ACPI_ERST_READ_REGISTER = 0,
	ACPI_ERST_READ_REGISTER_VALUE = 1,
	ACPI_ERST_WRITE_REGISTER = 2,
	ACPI_ERST_WRITE_REGISTER_VALUE = 3,
	ACPI_ERST_NOOP = 4,
	ACPI_ERST_LOAD_VAR1 = 5,
	ACPI_ERST_LOAD_VAR2 = 6,
	ACPI_ERST_STORE_VAR1 = 7,
	ACPI_ERST_ADD = 8,
	ACPI_ERST_SUBTRACT = 9,
	ACPI_ERST_ADD_VALUE = 10,
	ACPI_ERST_SUBTRACT_VALUE = 11,
	ACPI_ERST_STALL = 12,
	ACPI_ERST_STALL_WHILE_TRUE = 13,
	ACPI_ERST_SKIP_NEXT_IF_TRUE = 14,
	ACPI_ERST_GOTO = 15,
	ACPI_ERST_SET_SRC_ADDRESS_BASE = 16,
	ACPI_ERST_SET_DST_ADDRESS_BASE = 17,
	ACPI_ERST_MOVE_DATA = 18,
	ACPI_ERST_INSTRUCTION_RESERVED = 19,
};

struct pstore_info___2 {
	struct module___106 *owner;
	char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex___193 read_mutex;
	int (*open)(struct pstore_info___2 *);
	int (*close)(struct pstore_info___2 *);
	ssize_t (*read)(u64 *, enum pstore_type_id *, int *, struct timespec *, char **, bool *, struct pstore_info___2 *);
	int (*write)(enum pstore_type_id, enum kmsg_dump_reason, u64 *, unsigned int, int, bool, size_t, struct pstore_info___2 *);
	int (*write_buf)(enum pstore_type_id, enum kmsg_dump_reason, u64 *, unsigned int, const char *, bool, size_t, struct pstore_info___2 *);
	int (*erase)(enum pstore_type_id, u64, int, struct timespec, struct pstore_info___2 *);
	void *data;
};

struct erst_erange {
	u64 base;
	u64 size;
	void *vaddr;
	u32 attr;
};

struct erst_record_id_cache {
	struct mutex___193 lock;
	u64 *entries;
	int len;
	int size;
	int refcount;
};

struct cper_pstore_record {
	struct cper_record_header hdr;
	struct cper_section_descriptor sec_hdr;
	char data[0];
};

struct vm_struct___4 {
	struct vm_struct___4 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___189 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

enum acpi_hest_notify_types {
	ACPI_HEST_NOTIFY_POLLED = 0,
	ACPI_HEST_NOTIFY_EXTERNAL = 1,
	ACPI_HEST_NOTIFY_LOCAL = 2,
	ACPI_HEST_NOTIFY_SCI = 3,
	ACPI_HEST_NOTIFY_NMI = 4,
	ACPI_HEST_NOTIFY_CMCI = 5,
	ACPI_HEST_NOTIFY_MCE = 6,
	ACPI_HEST_NOTIFY_RESERVED = 7,
};

struct acpi_generic_status {
	u32 block_status;
	u32 raw_data_offset;
	u32 raw_data_length;
	u32 data_length;
	u32 error_severity;
};

struct acpi_generic_data {
	u8 section_type[16];
	u32 error_severity;
	u16 revision;
	u8 validation_bits;
	u8 flags;
	u32 error_data_length;
	u8 fru_id[16];
	u8 fru_text[20];
};

struct cper_sec_pcie {
	__u64 validation_bits;
	__u32 port_type;
	struct {
		__u8 minor;
		__u8 major;
		__u8 reserved[2];
	} version;
	__u16 command;
	__u16 status;
	__u32 reserved;
	struct {
		__u16 vendor_id;
		__u16 device_id;
		__u8 class_code[3];
		__u8 function;
		__u8 device;
		__u16 segment;
		__u8 bus;
		__u8 secondary_bus;
		__u16 slot;
		__u8 reserved;
	} __attribute__((packed)) device_id;
	struct {
		__u32 lower;
		__u32 upper;
	} serial_number;
	struct {
		__u16 secondary_status;
		__u16 control;
	} bridge;
	__u8 capability[60];
	__u8 aer_info[96];
};

struct ghes {
	struct acpi_hest_generic *generic;
	struct acpi_generic_status *estatus;
	u64 buffer_paddr;
	long unsigned int flags;
	union {
		struct list_head list;
		struct timer_list timer;
		unsigned int irq;
	};
};

struct ghes_estatus_node {
	struct llist_node llnode;
	struct acpi_hest_generic *generic;
	struct ghes *ghes;
};

struct ghes_estatus_cache {
	u32 estatus_len;
	atomic_t count;
	struct acpi_hest_generic *generic;
	long long unsigned int time_in;
	struct callback_head rcu;
};

struct acpi_table_xsdt {
	struct acpi_table_header header;
	u64 table_offset_entry[1];
} __attribute__((packed));

struct sfi_table_key {
	char *sig;
	char *oem_id;
	char *oem_table_id;
};

struct sfi_table_attr {
	struct bin_attribute___143 attr;
	char name[8];
};

struct sfi_table_attr___2 {
	struct bin_attribute___150 attr;
	char name[8];
};

struct pnp_protocol___2;

struct pnp_card___2 {
	struct device___159 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___2 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___2;

struct pnp_protocol___2 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___2 *);
	int (*set)(struct pnp_dev___2 *);
	int (*disable)(struct pnp_dev___2 *);
	bool (*can_wakeup)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	unsigned char number;
	struct device___159 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___2;

struct pnp_card_link___2 {
	struct pnp_card___2 *card;
	struct pnp_card_driver___2 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___2 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___2 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___2 *);
	void (*shutdown)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	struct device_driver___159 driver;
};

struct pnp_card_driver___2 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___2 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___2 *);
	int (*suspend)(struct pnp_card_link___2 *, pm_message_t);
	int (*resume)(struct pnp_card_link___2 *);
	struct pnp_driver___2 link;
};

struct pnp_dev___2 {
	struct device___159 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___2 *protocol;
	struct pnp_card___2 *card;
	struct pnp_driver___2 *driver;
	struct pnp_card_link___2 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_resource {
	struct list_head list;
	struct resource res;
};

struct pnp_port {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

typedef struct {
	long unsigned int bits[4];
} pnp_irq_mask_t;

struct pnp_irq {
	pnp_irq_mask_t map;
	unsigned char flags;
};

struct pnp_dma {
	unsigned char map;
	unsigned char flags;
};

struct pnp_mem {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

struct pnp_option {
	struct list_head list;
	unsigned int flags;
	long unsigned int type;
	union {
		struct pnp_port port;
		struct pnp_irq irq;
		struct pnp_dma dma;
		struct pnp_mem mem;
	} u;
};

struct pnp_info_buffer {
	char *buffer;
	char *curr;
	long unsigned int size;
	long unsigned int len;
	int stop;
	int error;
};

typedef struct pnp_info_buffer pnp_info_buffer_t;

struct pnp_fixup {
	char id[7];
	void (*quirk_function)(struct pnp_dev___2 *);
};

struct pnp_protocol___3;

struct pnp_card___3 {
	struct device___157 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___3 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___3;

struct pnp_protocol___3 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___3 *);
	int (*set)(struct pnp_dev___3 *);
	int (*disable)(struct pnp_dev___3 *);
	bool (*can_wakeup)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	unsigned char number;
	struct device___157 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___3;

struct pnp_card_link___3 {
	struct pnp_card___3 *card;
	struct pnp_card_driver___3 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___3 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___3 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___3 *);
	void (*shutdown)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	struct device_driver___157 driver;
};

struct pnp_card_driver___3 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___3 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___3 *);
	int (*suspend)(struct pnp_card_link___3 *, pm_message_t);
	int (*resume)(struct pnp_card_link___3 *);
	struct pnp_driver___3 link;
};

struct pnp_dev___3 {
	struct device___157 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___3 *protocol;
	struct pnp_card___3 *card;
	struct pnp_driver___3 *driver;
	struct pnp_card_link___3 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct acpipnp_parse_option_s {
	struct pnp_dev___3 *dev;
	unsigned int option_flags;
};

struct device___168;

struct dev_pm_ops___168 {
	int (*prepare)(struct device___168 *);
	void (*complete)(struct device___168 *);
	int (*suspend)(struct device___168 *);
	int (*resume)(struct device___168 *);
	int (*freeze)(struct device___168 *);
	int (*thaw)(struct device___168 *);
	int (*poweroff)(struct device___168 *);
	int (*restore)(struct device___168 *);
	int (*suspend_late)(struct device___168 *);
	int (*resume_early)(struct device___168 *);
	int (*freeze_late)(struct device___168 *);
	int (*thaw_early)(struct device___168 *);
	int (*poweroff_late)(struct device___168 *);
	int (*restore_early)(struct device___168 *);
	int (*suspend_noirq)(struct device___168 *);
	int (*resume_noirq)(struct device___168 *);
	int (*freeze_noirq)(struct device___168 *);
	int (*thaw_noirq)(struct device___168 *);
	int (*poweroff_noirq)(struct device___168 *);
	int (*restore_noirq)(struct device___168 *);
	int (*runtime_suspend)(struct device___168 *);
	int (*runtime_resume)(struct device___168 *);
	int (*runtime_idle)(struct device___168 *);
};

struct dma_map_ops___71;

struct dev_archdata___71 {
	struct dma_map_ops___71 *dma_ops;
	void *iommu;
};

struct acpi_device___20;

struct acpi_dev_node___26 {
	union {
		struct acpi_device___20 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___168;

struct bus_type___168;

struct device_driver___168;

struct dev_pm_domain___168;

struct class___168;

struct device_rh___168;

struct device___168 {
	struct device___168 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___168 *type;
	struct mutex___193 mutex;
	struct bus_type___168 *bus;
	struct device_driver___168 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___168 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node___10 *of_node;
	struct acpi_dev_node___26 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___168 *class;
	const struct attribute_group___148 **groups;
	void (*release)(struct device___168 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___168 *device_rh;
};

struct dev_pm_info_rh___168 {
	void (*set_latency_tolerance)(struct device___168 *, s32);
};

struct dev_pm_domain___168 {
	struct dev_pm_ops___168 ops;
};

struct dma_map_ops___71 {
	void * (*alloc)(struct device___168 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___168 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___168 *, struct vm_area_struct___198 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___168 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___168 *, struct page___189 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___168 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___168 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___168 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___168 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___168 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___168 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___168 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___168 *, dma_addr_t);
	int (*dma_supported)(struct device___168 *, u64);
	int (*set_dma_mask)(struct device___168 *, u64);
	int is_phys;
};

struct bus_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___168 *, char *);
	ssize_t (*store)(struct bus_type___168 *, const char *, size_t);
};

struct device_attribute___168;

struct driver_attribute___168;

struct bus_type___168 {
	const char *name;
	const char *dev_name;
	struct device___168 *dev_root;
	struct bus_attribute___168 *bus_attrs;
	struct device_attribute___168 *dev_attrs;
	struct driver_attribute___168 *drv_attrs;
	const struct attribute_group___148 **bus_groups;
	const struct attribute_group___148 **dev_groups;
	const struct attribute_group___148 **drv_groups;
	int (*match)(struct device___168 *, struct device_driver___168 *);
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	int (*probe)(struct device___168 *);
	int (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*online)(struct device___168 *);
	int (*offline)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct device___168 *, struct device_attribute___168 *, char *);
	ssize_t (*store)(struct device___168 *, struct device_attribute___168 *, const char *, size_t);
};

struct driver_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___168 *, char *);
	ssize_t (*store)(struct device_driver___168 *, const char *, size_t);
};

struct device_driver___168 {
	const char *name;
	struct bus_type___168 *bus;
	struct module___106 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___168 *);
	int (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	const struct attribute_group___148 **groups;
	const struct dev_pm_ops___168 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___168 {
	const char *name;
	const struct attribute_group___148 **groups;
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
};

struct class_attribute___168;

struct class___168 {
	const char *name;
	struct module___106 *owner;
	struct class_attribute___168 *class_attrs;
	struct device_attribute___168 *dev_attrs;
	const struct attribute_group___148 **dev_groups;
	struct bin_attribute___150 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *);
	void (*class_release)(struct class___168 *);
	void (*dev_release)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
	struct subsys_private *p;
};

struct class_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct class___168 *, struct class_attribute___168 *, char *);
	ssize_t (*store)(struct class___168 *, struct class_attribute___168 *, const char *, size_t);
	const void * (*namespace)(struct class___168 *, const struct class_attribute___168 *);
};

struct acpi_scan_handler___20;

struct acpi_hotplug_context___20;

struct acpi_driver___20;

struct acpi_device___20 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___20 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___20 *handler;
	struct acpi_hotplug_context___20 *hp;
	struct acpi_driver___20 *driver;
	void *driver_data;
	struct device___168 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___193 physical_node_lock;
	void (*remove)(struct acpi_device___20 *);
};

struct device_rh___168 {
	struct dev_pm_info_rh___168 power;
};

enum dma_status {
	DMA_SUCCESS = 0,
	DMA_IN_PROGRESS = 1,
	DMA_PAUSED = 2,
	DMA_ERROR = 3,
};

enum dma_transfer_direction {
	DMA_MEM_TO_MEM = 0,
	DMA_MEM_TO_DEV = 1,
	DMA_DEV_TO_MEM = 2,
	DMA_DEV_TO_DEV = 3,
	DMA_TRANS_NONE = 4,
};

struct data_chunk {
	size_t size;
	size_t icg;
};

struct dma_interleaved_template {
	dma_addr_t src_start;
	dma_addr_t dst_start;
	enum dma_transfer_direction dir;
	bool src_inc;
	bool dst_inc;
	bool src_sgl;
	bool dst_sgl;
	size_t numf;
	size_t frame_size;
	struct data_chunk sgl[0];
};

enum dma_ctrl_flags {
	DMA_PREP_INTERRUPT = 1,
	DMA_CTRL_ACK = 2,
	DMA_COMPL_SKIP_SRC_UNMAP = 4,
	DMA_COMPL_SKIP_DEST_UNMAP = 8,
	DMA_COMPL_SRC_UNMAP_SINGLE = 16,
	DMA_COMPL_DEST_UNMAP_SINGLE = 32,
	DMA_PREP_PQ_DISABLE_P = 64,
	DMA_PREP_PQ_DISABLE_Q = 128,
	DMA_PREP_CONTINUE = 256,
	DMA_PREP_FENCE = 512,
};

enum dma_ctrl_cmd {
	DMA_TERMINATE_ALL = 0,
	DMA_PAUSE = 1,
	DMA_RESUME = 2,
	DMA_SLAVE_CONFIG = 3,
	FSLDMA_EXTERNAL_START = 4,
};

enum sum_check_flags {
	SUM_CHECK_P_RESULT = 1,
	SUM_CHECK_Q_RESULT = 2,
};

typedef struct {
	long unsigned int bits[1];
} dma_cap_mask_t;

struct dma_chan_percpu {
	long unsigned int memcpy_count;
	long unsigned int bytes_transferred;
};

struct dma_device;

struct dma_chan_dev;

struct dma_chan___2 {
	struct dma_device *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor;

struct dma_tx_state;

struct dma_device {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___168 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___2 *);
	void (*device_free_chan_resources)(struct dma_chan___2 *);
	struct dma_async_tx_descriptor * (*device_prep_dma_memcpy)(struct dma_chan___2 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor)(struct dma_chan___2 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor_val)(struct dma_chan___2 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq_val)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_memset)(struct dma_chan___2 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_interrupt)(struct dma_chan___2 *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_slave_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor * (*device_prep_dma_cyclic)(struct dma_chan___2 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor * (*device_prep_interleaved_dma)(struct dma_chan___2 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___2 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___2 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___2 *);
};

struct dma_chan_dev {
	struct dma_chan___2 *chan;
	struct device___168 device;
	int dev_id;
	atomic_t *idr_ref;
};

typedef bool (*dma_filter_fn)(struct dma_chan___2 *, void *);

typedef void (*dma_async_tx_callback)(void *);

struct dma_async_tx_descriptor {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___2 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_tx_state {
	dma_cookie_t last;
	dma_cookie_t used;
	u32 residue;
};

struct acpi_hotplug_profile___20 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___20 *);
	void (*notify_online)(struct acpi_device___20 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___20 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___20 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___20 *);
	void (*bind)(struct device___168 *);
	void (*unbind)(struct device___168 *);
	struct acpi_hotplug_profile___20 hotplug;
};

struct acpi_hotplug_context___20 {
	struct acpi_device___20 *self;
	int (*notify)(struct acpi_device___20 *, u32);
	void (*uevent)(struct acpi_device___20 *, u32);
	void (*fixup)(struct acpi_device___20 *);
};

typedef int (*acpi_op_add___20)(struct acpi_device___20 *);

typedef int (*acpi_op_remove___20)(struct acpi_device___20 *);

typedef void (*acpi_op_notify___20)(struct acpi_device___20 *, u32);

struct acpi_device_ops___20 {
	acpi_op_add___20 add;
	acpi_op_remove___20 remove;
	acpi_op_notify___20 notify;
};

struct acpi_driver___20 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___20 ops;
	struct device_driver___168 drv;
	struct module___106 *owner;
};

struct dma_chan_tbl_ent {
	struct dma_chan___2 *chan;
};

typedef void (*dr_release_t___5)(struct device___168 *, void *);

typedef int (*dr_match_t___5)(struct device___168 *, void *, void *);

struct acpi_table_csrt {
	struct acpi_table_header header;
};

struct acpi_csrt_group {
	u32 length;
	u32 vendor_id;
	u32 subvendor_id;
	u16 device_id;
	u16 subdevice_id;
	u16 revision;
	u16 reserved;
	u32 shared_info_length;
};

struct acpi_csrt_shared_info {
	u16 major_version;
	u16 minor_version;
	u32 mmio_base_low;
	u32 mmio_base_high;
	u32 gsi_interrupt;
	u8 interrupt_polarity;
	u8 interrupt_mode;
	u8 num_channels;
	u8 dma_address_width;
	u16 base_request_line;
	u16 num_handshake_signals;
	u32 max_block_size;
};

struct acpi_dma_spec {
	int chan_id;
	int slave_id;
	struct device___168 *dev;
};

struct acpi_dma {
	struct list_head dma_controllers;
	struct device___168 *dev;
	struct dma_chan___2 * (*acpi_dma_xlate)(struct acpi_dma_spec *, struct acpi_dma *);
	void *data;
	short unsigned int base_request_line;
	short unsigned int end_request_line;
};

struct acpi_dma_filter_info {
	dma_cap_mask_t dma_cap;
	dma_filter_fn filter_fn;
};

struct acpi_dma_parser_data {
	struct acpi_dma_spec dma_spec;
	size_t index;
	size_t n;
};

struct xsd_errors {
	int errnum;
	const char *errstring;
};

struct xenbus_watch {
	struct list_head list;
	const char *node;
	void (*callback)(struct xenbus_watch *, const char **, unsigned int);
};

struct xenbus_transaction {
	u32 id;
};

enum shutdown_state {
	SHUTDOWN_INVALID = 4294967295,
	SHUTDOWN_POWEROFF = 0,
	SHUTDOWN_SUSPEND = 2,
	SHUTDOWN_HALT = 4,
};

struct suspend_info {
	int cancelled;
	long unsigned int arg;
	void (*pre)();
	void (*post)(int);
};

struct shutdown_handler {
	const char *command;
	void (*cb)();
};

enum xs_watch_type {
	XS_WATCH_PATH = 0,
	XS_WATCH_TOKEN = 1,
};

typedef uint32_t evtchn_port_t;

struct evtchn_alloc_unbound {
	domid_t dom;
	domid_t remote_dom;
	evtchn_port_t port;
};

struct evtchn_bind_interdomain {
	domid_t remote_dom;
	evtchn_port_t remote_port;
	evtchn_port_t local_port;
};

struct evtchn_bind_virq {
	uint32_t virq;
	uint32_t vcpu;
	evtchn_port_t port;
};

struct evtchn_bind_pirq {
	uint32_t pirq;
	uint32_t flags;
	evtchn_port_t port;
};

struct evtchn_bind_ipi {
	uint32_t vcpu;
	evtchn_port_t port;
};

struct evtchn_close {
	evtchn_port_t port;
};

struct evtchn_send {
	evtchn_port_t port;
};

struct evtchn_status {
	domid_t dom;
	evtchn_port_t port;
	uint32_t status;
	uint32_t vcpu;
	union {
		struct {
			domid_t dom;
		} unbound;
		struct {
			domid_t dom;
			evtchn_port_t port;
		} interdomain;
		uint32_t pirq;
		uint32_t virq;
	} u;
};

struct evtchn_bind_vcpu {
	evtchn_port_t port;
	uint32_t vcpu;
};

struct evtchn_unmask {
	evtchn_port_t port;
};

struct evtchn_op {
	uint32_t cmd;
	union {
		struct evtchn_alloc_unbound alloc_unbound;
		struct evtchn_bind_interdomain bind_interdomain;
		struct evtchn_bind_virq bind_virq;
		struct evtchn_bind_pirq bind_pirq;
		struct evtchn_bind_ipi bind_ipi;
		struct evtchn_close close;
		struct evtchn_send send;
		struct evtchn_status status;
		struct evtchn_bind_vcpu bind_vcpu;
		struct evtchn_unmask unmask;
	} u;
};

struct physdev_irq_status_query {
	uint32_t irq;
	uint32_t flags;
};

struct physdev_set_iobitmap {
	uint8_t *bitmap;
	uint32_t nr_ports;
};

struct physdev_apic {
	long unsigned int apic_physbase;
	uint32_t reg;
	uint32_t value;
};

struct physdev_irq {
	uint32_t irq;
	uint32_t vector;
};

struct physdev_op {
	uint32_t cmd;
	union {
		struct physdev_irq_status_query irq_status_query;
		struct physdev_set_iopl set_iopl;
		struct physdev_set_iobitmap set_iobitmap;
		struct physdev_apic apic_op;
		struct physdev_irq irq_op;
	} u;
};

struct grant_entry_v1 {
	uint16_t flags;
	domid_t domid;
	uint32_t frame;
};

struct grant_entry_header {
	uint16_t flags;
	domid_t domid;
};

union grant_entry_v2 {
	struct grant_entry_header hdr;
	struct {
		struct grant_entry_header hdr;
		uint32_t pad0;
		uint64_t frame;
	} full_page;
	struct {
		struct grant_entry_header hdr;
		uint16_t page_off;
		uint16_t length;
		uint64_t frame;
	} sub_page;
	struct {
		struct grant_entry_header hdr;
		domid_t trans_domid;
		uint16_t pad0;
		grant_ref_t gref;
	} transitive;
	uint32_t __spacer[4];
};

struct gnttab_setup_table {
	domid_t dom;
	uint32_t nr_frames;
	int16_t status;
	__guest_handle_xen_pfn_t frame_list;
};

struct gnttab_copy {
	struct {
		union {
			grant_ref_t ref;
			xen_pfn_t gmfn;
		} u;
		domid_t domid;
		uint16_t offset;
	} source;
	struct {
		union {
			grant_ref_t ref;
			xen_pfn_t gmfn;
		} u;
		domid_t domid;
		uint16_t offset;
	} dest;
	uint16_t len;
	uint16_t flags;
	int16_t status;
};

struct gnttab_query_size {
	domid_t dom;
	uint32_t nr_frames;
	uint32_t max_nr_frames;
	int16_t status;
};

struct gnttab_set_version {
	uint32_t version;
};

struct gnttab_get_status_frames {
	uint32_t nr_frames;
	domid_t dom;
	int16_t status;
	__guest_handle_uint64_t frame_list;
};

struct gnttab_free_callback {
	struct gnttab_free_callback *next;
	void (*fn)(void *);
	void *arg;
	u16 count;
};

struct gnttab_ops {
	int (*map_frames)(xen_pfn_t *, unsigned int);
	void (*unmap_frames)();
	void (*update_entry)(grant_ref_t, domid_t, long unsigned int, unsigned int);
	int (*end_foreign_access_ref)(grant_ref_t, int);
	long unsigned int (*end_foreign_transfer_ref)(grant_ref_t);
	int (*query_foreign_access)(grant_ref_t);
	void (*update_subpage_entry)(grant_ref_t, domid_t, long unsigned int, int, unsigned int, unsigned int);
	void (*update_trans_entry)(grant_ref_t, domid_t, int, domid_t, grant_ref_t);
};

struct deferred_entry {
	struct list_head list;
	grant_ref_t ref;
	bool ro;
	uint16_t warn_delay;
	struct page___191 *page;
};

struct xen_feature_info {
	unsigned int submap_idx;
	uint32_t submap;
};

struct xen_pci_frontend_ops___2 {
	int (*enable_msi)(struct pci_dev___21 *, int *);
	void (*disable_msi)(struct pci_dev___21 *);
	int (*enable_msix)(struct pci_dev___21 *, int *, int);
	void (*disable_msix)(struct pci_dev___21 *);
};

typedef evtchn_port_t *__guest_handle_evtchn_port_t;

struct sched_poll {
	__guest_handle_evtchn_port_t ports;
	unsigned int nr_ports;
	uint64_t timeout;
};

struct physdev_eoi {
	uint32_t irq;
};

struct physdev_pirq_eoi_gmfn {
	xen_ulong_t gmfn;
};

struct physdev_map_pirq {
	domid_t domid;
	int type;
	int index;
	int pirq;
	int bus;
	int devfn;
	int entry_nr;
	uint64_t table_base;
};

struct physdev_unmap_pirq {
	domid_t domid;
	int pirq;
};

struct physdev_get_free_pirq {
	int type;
	uint32_t pirq;
};

struct xen_hvm_param {
	domid_t domid;
	uint32_t index;
	uint64_t value;
};

enum xen_irq_type {
	IRQT_UNBOUND = 0,
	IRQT_PIRQ = 1,
	IRQT_VIRQ = 2,
	IRQT_IPI = 3,
	IRQT_EVTCHN = 4,
};

struct irq_info {
	struct list_head list;
	int refcnt;
	enum xen_irq_type type;
	unsigned int irq;
	short unsigned int evtchn;
	short unsigned int cpu;
	union {
		short unsigned int virq;
		enum ipi_vector ipi;
		struct {
			short unsigned int pirq;
			short unsigned int gsi;
			unsigned char flags;
			uint16_t domid;
		} pirq;
	} u;
};

struct exec_domain___48 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___27 *module;
	struct exec_domain___48 *next;
};

struct thread_info___87 {
	struct task_struct___43 *task;
	struct exec_domain___48 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct balloon_stats {
	long unsigned int current_pages;
	long unsigned int target_pages;
	long unsigned int balloon_low;
	long unsigned int balloon_high;
	long unsigned int schedule_delay;
	long unsigned int max_schedule_delay;
	long unsigned int retry_count;
	long unsigned int max_retry_count;
};

enum bp_state {
	BP_DONE = 0,
	BP_EAGAIN = 1,
	BP_ECANCELED = 2,
};

enum xenbus_state {
	XenbusStateUnknown = 0,
	XenbusStateInitialising = 1,
	XenbusStateInitWait = 2,
	XenbusStateInitialised = 3,
	XenbusStateConnected = 4,
	XenbusStateClosing = 5,
	XenbusStateClosed = 6,
	XenbusStateReconfiguring = 7,
	XenbusStateReconfigured = 8,
};

struct xenbus_device {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___162 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
};

struct xenbus_map_node {
	struct list_head next;
	union {
		struct vm_struct___4 *area;
		struct page___191 *page;
	};
	grant_handle_t handle;
};

struct xenbus_ring_ops {
	int (*map)(struct xenbus_device *, int, void **);
	int (*unmap)(struct xenbus_device *, void *);
};

typedef uint32_t XENSTORE_RING_IDX;

struct xenstore_domain_interface {
	char req[1024];
	char rsp[1024];
	XENSTORE_RING_IDX req_cons;
	XENSTORE_RING_IDX req_prod;
	XENSTORE_RING_IDX rsp_cons;
	XENSTORE_RING_IDX rsp_prod;
};

enum xsd_sockmsg_type {
	XS_DEBUG = 0,
	XS_DIRECTORY = 1,
	XS_READ = 2,
	XS_GET_PERMS = 3,
	XS_WATCH = 4,
	XS_UNWATCH = 5,
	XS_TRANSACTION_START = 6,
	XS_TRANSACTION_END = 7,
	XS_INTRODUCE = 8,
	XS_RELEASE = 9,
	XS_GET_DOMAIN_PATH = 10,
	XS_WRITE = 11,
	XS_MKDIR = 12,
	XS_RM = 13,
	XS_SET_PERMS = 14,
	XS_WATCH_EVENT = 15,
	XS_ERROR = 16,
	XS_IS_DOMAIN_INTRODUCED = 17,
	XS_RESUME = 18,
	XS_SET_TARGET = 19,
	XS_RESTRICT = 20,
	XS_RESET_WATCHES = 21,
};

struct xsd_sockmsg {
	uint32_t type;
	uint32_t req_id;
	uint32_t tx_id;
	uint32_t len;
};

struct xs_stored_msg {
	struct list_head list;
	struct xsd_sockmsg hdr;
	union {
		struct {
			char *body;
		} reply;
		struct {
			struct xenbus_watch *handle;
			char **vec;
			unsigned int vec_size;
		} watch;
	} u;
};

struct xs_handle {
	struct list_head reply_list;
	spinlock_t reply_lock;
	wait_queue_head_t reply_waitq;
	struct mutex___195 request_mutex;
	struct mutex___195 response_mutex;
	struct mutex___195 transaction_mutex;
	atomic_t transaction_count;
	wait_queue_head_t transaction_wq;
	struct rw_semaphore watch_mutex;
};

struct xenbus_device___2 {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___39 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
};

struct xenbus_device_id {
	char devicetype[32];
};

struct xenbus_driver {
	const struct xenbus_device_id *ids;
	int (*probe)(struct xenbus_device___2 *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device___2 *, enum xenbus_state);
	int (*remove)(struct xenbus_device___2 *);
	int (*suspend)(struct xenbus_device___2 *);
	int (*resume)(struct xenbus_device___2 *);
	int (*uevent)(struct xenbus_device___2 *, struct kobj_uevent_env *);
	struct device_driver___39 driver;
	int (*read_otherend_details)(struct xenbus_device___2 *);
	int (*is_ready)(struct xenbus_device___2 *);
};

struct xen_bus_type {
	char *root;
	unsigned int levels;
	int (*get_bus_id)(char *, const char *);
	int (*probe)(struct xen_bus_type *, const char *, const char *);
	void (*otherend_changed)(struct xenbus_watch *, const char **, unsigned int);
	struct bus_type___39 bus;
};

enum xenstore_init {
	XS_UNKNOWN = 0,
	XS_PV = 1,
	XS_HVM = 2,
	XS_LOCAL = 3,
};

struct xb_find_info {
	struct xenbus_device___2 *dev;
	const char *nodename;
};

struct xenbus_transaction_holder {
	struct list_head list;
	struct xenbus_transaction handle;
};

struct read_buffer {
	struct list_head list;
	unsigned int cons;
	unsigned int len;
	char msg[0];
};

struct xenbus_file_priv {
	struct mutex___116 msgbuffer_mutex;
	struct list_head transactions;
	struct list_head watches;
	unsigned int len;
	union {
		struct xsd_sockmsg msg;
		char buffer[4096];
	} u;
	struct mutex___116 reply_mutex;
	struct list_head read_buffers;
	wait_queue_head_t read_waitq;
};

struct watch_adapter {
	struct list_head list;
	struct xenbus_watch watch;
	struct xenbus_file_priv *dev_data;
	char *token;
};

struct miscdevice___6 {
	int minor;
	const char *name;
	const struct file_operations___65 *fops;
	struct list_head list;
	struct device___54 *parent;
	struct device___54 *this_device;
	const char *nodename;
	umode_t mode;
};

typedef struct poll_table_struct___41 poll_table___21;

struct ioctl_evtchn_bind_virq {
	unsigned int virq;
};

struct ioctl_evtchn_bind_interdomain {
	unsigned int remote_domain;
	unsigned int remote_port;
};

struct ioctl_evtchn_bind_unbound_port {
	unsigned int remote_domain;
};

struct ioctl_evtchn_unbind {
	unsigned int port;
};

struct ioctl_evtchn_notify {
	unsigned int port;
};

struct per_user_data {
	struct mutex___66 bind_mutex;
	evtchn_port_t *ring;
	unsigned int ring_cons;
	unsigned int ring_prod;
	unsigned int ring_overflow;
	struct mutex___66 ring_cons_mutex;
	wait_queue_head_t evtchn_wait;
	struct fasync_struct___65 *evtchn_async_queue;
	const char *name;
};

typedef int (*pte_fn_t___4)(pte_t *, pgtable_t___185, long unsigned int, void *);

struct mmu_notifier___2;

struct mmu_notifier_ops___2 {
	void (*release)(struct mmu_notifier___2 *, struct mm_struct___193 *);
	int (*clear_flush_young)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int);
	int (*test_young)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int, pte_t);
	void (*invalidate_page)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int);
	void (*invalidate_range_start)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___2 *, struct mm_struct___193 *, long unsigned int, long unsigned int);
};

struct mmu_notifier___2 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___2 *ops;
};

struct ioctl_gntdev_grant_ref {
	uint32_t domid;
	uint32_t ref;
};

struct ioctl_gntdev_map_grant_ref {
	uint32_t count;
	uint32_t pad;
	uint64_t index;
	struct ioctl_gntdev_grant_ref refs[1];
};

struct ioctl_gntdev_unmap_grant_ref {
	uint64_t index;
	uint32_t count;
	uint32_t pad;
};

struct ioctl_gntdev_get_offset_for_vaddr {
	uint64_t vaddr;
	uint64_t offset;
	uint32_t count;
	uint32_t pad;
};

struct ioctl_gntdev_unmap_notify {
	uint64_t index;
	uint32_t action;
	uint32_t event_channel_port;
};

struct gntdev_priv {
	struct list_head maps;
	struct list_head freeable_maps;
	spinlock_t lock;
	struct mm_struct___193 *mm;
	struct mmu_notifier___2 mn;
};

struct unmap_notify {
	int flags;
	int addr;
	int event;
};

struct grant_map {
	struct list_head next;
	struct vm_area_struct___193 *vma;
	int index;
	int count;
	int flags;
	atomic_t users;
	struct unmap_notify notify;
	struct ioctl_gntdev_grant_ref *grants;
	struct gnttab_map_grant_ref *map_ops;
	struct gnttab_unmap_grant_ref *unmap_ops;
	struct gnttab_map_grant_ref *kmap_ops;
	struct page___185 **pages;
};

typedef uint8_t xen_domain_handle_t[16];

struct xen_compile_info {
	char compiler[64];
	char compile_by[16];
	char compile_domain[32];
	char compile_date[32];
};

struct xen_platform_parameters {
	xen_ulong_t virt_start;
};

struct hyp_sysfs_attr {
	struct attribute attr;
	ssize_t (*show)(struct hyp_sysfs_attr *, char *);
	ssize_t (*store)(struct hyp_sysfs_attr *, const char *, size_t);
	void *hyp_attr_data;
};

enum xen_swiotlb_err {
	XEN_SWIOTLB_UNKNOWN = 0,
	XEN_SWIOTLB_ENOMEM = 1,
	XEN_SWIOTLB_EFIXUP = 2,
};

struct page___192;

typedef struct page___192 *pgtable_t___192;

struct address_space___193;

struct kmem_cache___179;

struct page___192 {
	long unsigned int flags;
	struct address_space___193 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___192 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___192 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___179 *slab_cache;
		struct page___192 *first_page;
	};
	long: 64;
};

struct task_struct___195;

struct pv_cpu_ops___195 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___39 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___39 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___195 *);
	void (*end_context_switch)(struct task_struct___195 *);
};

struct mutex___196 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___195 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___188 {
	struct page___192 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___201;

struct files_struct___14;

struct signal_struct___195;

struct task_struct___195 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___195 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___201 *mm;
	struct mm_struct___201 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___195 *real_parent;
	struct task_struct___195 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___195 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___43 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___195 = 0,
		VTIME_USER___195 = 1,
		VTIME_SYS___195 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___39 thread;
	struct fs_struct *fs;
	struct files_struct___14 *files;
	struct nsproxy___104 *nsproxy;
	struct signal_struct___195 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___196 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___188 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___201 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___201 *, struct mm_struct___201 *);
	void (*dup_mmap)(struct mm_struct___201 *, struct mm_struct___201 *);
	void (*exit_mmap)(struct mm_struct___201 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___201 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___201 *);
	void (*pgd_free)(struct mm_struct___201 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___201 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___201 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___201 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___201 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___201 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___201 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___201 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___201 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___201 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___201 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___201 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___196 lock;
	void *vdso;
} mm_context_t___196;

struct xol_area___192;

struct uprobes_state___192 {
	struct xol_area___192 *xol_area;
};

struct vm_area_struct___201;

struct file___193;

struct core_state___195;

struct mm_struct___201 {
	struct vm_area_struct___201 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___201 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___201 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___196 context;
	long unsigned int flags;
	struct core_state___195 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___195 *owner;
	struct file___193 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___192 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___109;

struct exec_domain___49 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___109 *module;
	struct exec_domain___49 *next;
};

struct module_kobject___108 {
	struct kobject___20 kobj;
	struct module___109 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___108;

struct module___109 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___108 mkobj;
	struct module_attribute___108 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___195 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___88 {
	struct task_struct___195 *task;
	struct exec_domain___49 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___192 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___192 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___178;

struct memcg_cache_params___179;

struct kmem_cache___179 {
	struct kmem_cache_cpu___178 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___179 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___193;

struct address_space_operations___193;

struct address_space___193 {
	struct inode___193 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___196 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___193 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___193;

struct path___193 {
	struct vfsmount *mnt;
	struct dentry___193 *dentry;
};

struct file_operations___193;

struct file___193 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___193 f_path;
	struct inode___193 *f_inode;
	const struct file_operations___193 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___193 *f_mapping;
	struct mutex___196 f_pos_lock;
};

struct vm_operations_struct___174;

struct vm_area_struct___201 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___201 *vm_next;
	struct vm_area_struct___201 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___201 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___174 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___193 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___170;

struct vm_operations_struct___174 {
	void (*open)(struct vm_area_struct___201 *);
	void (*close)(struct vm_area_struct___201 *);
	int (*fault)(struct vm_area_struct___201 *, struct vm_fault___170 *);
	int (*page_mkwrite)(struct vm_area_struct___201 *, struct vm_fault___170 *);
	int (*access)(struct vm_area_struct___201 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___201 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___201 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___201 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___201 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___195 {
	struct task_struct___195 *task;
	struct core_thread___195 *next;
};

struct core_state___195 {
	atomic_t nr_threads;
	struct core_thread___195 dumper;
	struct completion startup;
};

struct irq_data___130;

struct x86_io_apic_ops___130 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___130 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___130;

struct irq_data___130 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___130 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___169;

struct dev_pm_ops___169 {
	int (*prepare)(struct device___169 *);
	void (*complete)(struct device___169 *);
	int (*suspend)(struct device___169 *);
	int (*resume)(struct device___169 *);
	int (*freeze)(struct device___169 *);
	int (*thaw)(struct device___169 *);
	int (*poweroff)(struct device___169 *);
	int (*restore)(struct device___169 *);
	int (*suspend_late)(struct device___169 *);
	int (*resume_early)(struct device___169 *);
	int (*freeze_late)(struct device___169 *);
	int (*thaw_early)(struct device___169 *);
	int (*poweroff_late)(struct device___169 *);
	int (*restore_early)(struct device___169 *);
	int (*suspend_noirq)(struct device___169 *);
	int (*resume_noirq)(struct device___169 *);
	int (*freeze_noirq)(struct device___169 *);
	int (*thaw_noirq)(struct device___169 *);
	int (*poweroff_noirq)(struct device___169 *);
	int (*restore_noirq)(struct device___169 *);
	int (*runtime_suspend)(struct device___169 *);
	int (*runtime_resume)(struct device___169 *);
	int (*runtime_idle)(struct device___169 *);
};

struct device_type___169;

struct bus_type___169;

struct device_driver___169;

struct dev_pm_domain___169;

struct class___169;

struct attribute_group___151;

struct device_rh___169;

struct device___169 {
	struct device___169 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___169 *type;
	struct mutex___196 mutex;
	struct bus_type___169 *bus;
	struct device_driver___169 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___169 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___169 *class;
	const struct attribute_group___151 **groups;
	void (*release)(struct device___169 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___169 *device_rh;
};

struct dev_pm_info_rh___169 {
	void (*set_latency_tolerance)(struct device___169 *, s32);
};

struct dev_pm_domain___169 {
	struct dev_pm_ops___169 ops;
};

struct smp_ops___195 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___195 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___195;

struct lruvec___195 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___195 *zone;
};

struct pglist_data___195;

struct zone___195 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___195 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___195 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___195 {
	struct zone___195 *zone;
	int zone_idx;
};

struct zonelist___195 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___195 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___195 {
	struct zone___195 node_zones[4];
	struct zonelist___195 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___195 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tty_struct___17;

struct signal_struct___195 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___195 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___195 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___43 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct___17 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___196 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___17;

struct tty_operations___17;

struct tty_ldisc___17;

struct fasync_struct___193;

struct tty_port___17;

struct tty_struct___17 {
	int magic;
	struct kref kref;
	struct device___169 *dev;
	struct tty_driver___17 *driver;
	const struct tty_operations___17 *ops;
	int index;
	struct mutex___196 ldisc_mutex;
	struct tty_ldisc___17 *ldisc;
	struct mutex___196 atomic_write_lock;
	struct mutex___196 legacy_mutex;
	struct mutex___196 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___43 *pgrp;
	struct pid___43 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___17 *link;
	struct fasync_struct___193 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___17 *port;
	struct ld_semaphore ldisc_sem;
};

struct fdtable___14 {
	unsigned int max_fds;
	struct file___193 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___14 {
	atomic_t count;
	struct fdtable___14 *fdt;
	struct fdtable___14 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___193 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___134;

struct irq_chip___130 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___130 *);
	void (*irq_shutdown)(struct irq_data___130 *);
	void (*irq_enable)(struct irq_data___130 *);
	void (*irq_disable)(struct irq_data___130 *);
	void (*irq_ack)(struct irq_data___130 *);
	void (*irq_mask)(struct irq_data___130 *);
	void (*irq_mask_ack)(struct irq_data___130 *);
	void (*irq_unmask)(struct irq_data___130 *);
	void (*irq_eoi)(struct irq_data___130 *);
	int (*irq_set_affinity)(struct irq_data___130 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___130 *);
	int (*irq_set_type)(struct irq_data___130 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___130 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___130 *);
	void (*irq_bus_sync_unlock)(struct irq_data___130 *);
	void (*irq_cpu_online)(struct irq_data___130 *);
	void (*irq_cpu_offline)(struct irq_data___130 *);
	void (*irq_suspend)(struct irq_data___130 *);
	void (*irq_resume)(struct irq_data___130 *);
	void (*irq_pm_shutdown)(struct irq_data___130 *);
	void (*irq_print_chip)(struct irq_data___130 *, struct seq_file___134 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___130 *, void *);
	long unsigned int flags;
};

struct seq_operations___134;

struct seq_file___134 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___196 lock;
	const struct seq_operations___134 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___193;

struct super_block___193;

struct dentry___193 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___193 *d_parent;
	struct qstr d_name;
	struct inode___193 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___193 *d_op;
	struct super_block___193 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___193;

struct file_lock___193;

struct dquot___193;

struct block_device___193;

struct cdev___47;

struct inode___193 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___193 *i_op;
	struct super_block___193 *i_sb;
	struct address_space___193 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___196 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___193 *i_fop;
	struct file_lock___193 *i_flock;
	struct address_space___193 i_data;
	struct dquot___193 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___193 *i_bdev;
		struct cdev___47 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___193 {
	int (*d_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_hash)(const struct dentry___193 *, struct qstr *);
	int (*d_compare)(const struct dentry___193 *, const struct dentry___193 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___193 *);
	void (*d_release)(struct dentry___193 *);
	void (*d_prune)(struct dentry___193 *);
	void (*d_iput)(struct dentry___193 *, struct inode___193 *);
	char * (*d_dname)(struct dentry___193 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___193 *);
	int (*d_manage)(struct dentry___193 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___193;

struct mem_dqinfo___193 {
	struct quota_format_type___193 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___193;

struct quota_info___193 {
	unsigned int flags;
	struct mutex___196 dqio_mutex;
	struct mutex___196 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___193 *files[2];
	struct mem_dqinfo___193 info[2];
	const struct quota_format_ops___193 *ops[2];
};

struct file_system_type___193;

struct super_operations___193;

struct dquot_operations___193;

struct quotactl_ops___193;

struct super_block___193 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___193 *s_type;
	const struct super_operations___193 *s_op;
	const struct dquot_operations___193 *dq_op;
	const struct quotactl_ops___193 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___193 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___193 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___193 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___196 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___193 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___193 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___193 *bd_inode;
	struct super_block___193 *bd_super;
	struct mutex___196 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___193 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___196 bd_fsfreeze_mutex;
};

struct iattr___193 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___193 *ia_file;
};

struct dquot___193 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___196 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___193 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___193 {
	int qf_fmt_id;
	const struct quota_format_ops___193 *qf_ops;
	struct module___109 *qf_owner;
	struct quota_format_type___193 *qf_next;
};

struct quota_format_ops___193 {
	int (*check_quota_file)(struct super_block___193 *, int);
	int (*read_file_info)(struct super_block___193 *, int);
	int (*write_file_info)(struct super_block___193 *, int);
	int (*free_file_info)(struct super_block___193 *, int);
	int (*read_dqblk)(struct dquot___193 *);
	int (*commit_dqblk)(struct dquot___193 *);
	int (*release_dqblk)(struct dquot___193 *);
};

struct dquot_operations___193 {
	int (*write_dquot)(struct dquot___193 *);
	struct dquot___193 * (*alloc_dquot)(struct super_block___193 *, int);
	void (*destroy_dquot)(struct dquot___193 *);
	int (*acquire_dquot)(struct dquot___193 *);
	int (*release_dquot)(struct dquot___193 *);
	int (*mark_dirty)(struct dquot___193 *);
	int (*write_info)(struct super_block___193 *, int);
	qsize_t * (*get_reserved_space)(struct inode___193 *);
};

struct quotactl_ops___193 {
	int (*quota_on)(struct super_block___193 *, int, int, struct path___193 *);
	int (*quota_on_meta)(struct super_block___193 *, int, int);
	int (*quota_off)(struct super_block___193 *, int);
	int (*quota_sync)(struct super_block___193 *, int);
	int (*get_info)(struct super_block___193 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___193 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___193 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___193 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___193 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___193 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___193 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___193 *, unsigned int);
};

struct address_space_operations___193 {
	int (*writepage)(struct page___192 *, struct writeback_control *);
	int (*readpage)(struct file___193 *, struct page___192 *);
	int (*writepages)(struct address_space___193 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___192 *);
	int (*readpages)(struct file___193 *, struct address_space___193 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___193 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___192 **, void **);
	int (*write_end)(struct file___193 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___192 *, void *);
	sector_t (*bmap)(struct address_space___193 *, sector_t);
	void (*invalidatepage)(struct page___192 *, long unsigned int);
	int (*releasepage)(struct page___192 *, gfp_t);
	void (*freepage)(struct page___192 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___193 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___193 *, struct page___192 *, struct page___192 *, enum migrate_mode);
	int (*launder_page)(struct page___192 *);
	int (*is_partially_uptodate)(struct page___192 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___192 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___193 *, struct page___192 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___193 *, sector_t *);
	void (*swap_deactivate)(struct file___193 *);
	void (*invalidatepage_range)(struct page___192 *, unsigned int, unsigned int);
};

struct cdev___47 {
	struct kobject___20 kobj;
	struct module___109 *owner;
	const struct file_operations___193 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___193 {
	struct dentry___193 * (*lookup)(struct inode___193 *, struct dentry___193 *, unsigned int);
	void * (*follow_link)(struct dentry___193 *, struct nameidata *);
	int (*permission)(struct inode___193 *, int);
	struct posix_acl * (*get_acl)(struct inode___193 *, int);
	int (*readlink)(struct dentry___193 *, char *, int);
	void (*put_link)(struct dentry___193 *, struct nameidata *, void *);
	int (*create)(struct inode___193 *, struct dentry___193 *, umode_t, bool);
	int (*link)(struct dentry___193 *, struct inode___193 *, struct dentry___193 *);
	int (*unlink)(struct inode___193 *, struct dentry___193 *);
	int (*symlink)(struct inode___193 *, struct dentry___193 *, const char *);
	int (*mkdir)(struct inode___193 *, struct dentry___193 *, umode_t);
	int (*rmdir)(struct inode___193 *, struct dentry___193 *);
	int (*mknod)(struct inode___193 *, struct dentry___193 *, umode_t, dev_t);
	int (*rename)(struct inode___193 *, struct dentry___193 *, struct inode___193 *, struct dentry___193 *);
	int (*setattr)(struct dentry___193 *, struct iattr___193 *);
	int (*getattr)(struct vfsmount *, struct dentry___193 *, struct kstat *);
	int (*setxattr)(struct dentry___193 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___193 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___193 *, char *, size_t);
	int (*removexattr)(struct dentry___193 *, const char *);
	int (*fiemap)(struct inode___193 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___193 *, struct timespec *, int);
	int (*atomic_open)(struct inode___193 *, struct dentry___193 *, struct file___193 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___14 *fl_owner_t___14;

struct poll_table_struct___110;

struct file_operations___193 {
	struct module___109 *owner;
	loff_t (*llseek)(struct file___193 *, loff_t, int);
	ssize_t (*read)(struct file___193 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___193 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___193 *, void *, filldir_t);
	unsigned int (*poll)(struct file___193 *, struct poll_table_struct___110 *);
	long int (*unlocked_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___193 *, struct vm_area_struct___201 *);
	int (*open)(struct inode___193 *, struct file___193 *);
	int (*flush)(struct file___193 *, fl_owner_t___14);
	int (*release)(struct inode___193 *, struct file___193 *);
	int (*fsync)(struct file___193 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___193 *, int);
	int (*lock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*sendpage)(struct file___193 *, struct page___192 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___193 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___193 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___193 *, long int, struct file_lock___193 **, void **);
		struct {
			int (*setlease)(struct file___193 *, long int, struct file_lock___193 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___193 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___134 *, struct file___193 *);
};

struct file_lock_operations___193;

struct lock_manager_operations___193;

struct file_lock___193 {
	struct file_lock___193 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___14 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___43 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___193 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___193 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___193 *fl_ops;
	const struct lock_manager_operations___193 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___193 {
	void (*fl_copy_lock)(struct file_lock___193 *, struct file_lock___193 *);
	void (*fl_release_private)(struct file_lock___193 *);
};

struct lock_manager_operations___193 {
	int (*lm_compare_owner)(struct file_lock___193 *, struct file_lock___193 *);
	long unsigned int (*lm_owner_key)(struct file_lock___193 *);
	void (*lm_notify)(struct file_lock___193 *);
	int (*lm_grant)(struct file_lock___193 *, struct file_lock___193 *, int);
	void (*lm_break)(struct file_lock___193 *);
	int (*lm_change)(struct file_lock___193 **, int);
};

struct fasync_struct___193 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___193 *fa_next;
	struct file___193 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___193 {
	const char *name;
	int fs_flags;
	struct dentry___193 * (*mount)(struct file_system_type___193 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___193 *);
	struct module___109 *owner;
	struct file_system_type___193 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___193 {
	struct inode___193 * (*alloc_inode)(struct super_block___193 *);
	void (*destroy_inode)(struct inode___193 *);
	void (*dirty_inode)(struct inode___193 *, int);
	int (*write_inode)(struct inode___193 *, struct writeback_control *);
	int (*drop_inode)(struct inode___193 *);
	void (*evict_inode)(struct inode___193 *);
	void (*put_super)(struct super_block___193 *);
	int (*sync_fs)(struct super_block___193 *, int);
	int (*freeze_fs)(struct super_block___193 *);
	int (*unfreeze_fs)(struct super_block___193 *);
	int (*statfs)(struct dentry___193 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___193 *, int *, char *);
	void (*umount_begin)(struct super_block___193 *);
	int (*show_options)(struct seq_file___134 *, struct dentry___193 *);
	int (*show_devname)(struct seq_file___134 *, struct dentry___193 *);
	int (*show_path)(struct seq_file___134 *, struct dentry___193 *);
	int (*show_stats)(struct seq_file___134 *, struct dentry___193 *);
	ssize_t (*quota_read)(struct super_block___193 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___193 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___193 *);
	int (*bdev_try_to_free_page)(struct super_block___193 *, struct page___192 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___193 *);
	void (*free_cached_objects)(struct super_block___193 *, int);
};

typedef void (*poll_queue_proc___112)(struct file___193 *, wait_queue_head_t *, struct poll_table_struct___110 *);

struct poll_table_struct___110 {
	poll_queue_proc___112 _qproc;
	long unsigned int _key;
};

struct bin_attribute___153;

struct attribute_group___151 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___153 **bin_attrs;
};

struct bin_attribute___153 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___193 *, struct kobject___20 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___193 *, struct kobject___20 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	int (*mmap)(struct file___193 *, struct kobject___20 *, struct bin_attribute___153 *, struct vm_area_struct___201 *);
};

struct tty_operations___17 {
	struct tty_struct___17 * (*lookup)(struct tty_driver___17 *, struct inode___193 *, int);
	int (*install)(struct tty_driver___17 *, struct tty_struct___17 *);
	void (*remove)(struct tty_driver___17 *, struct tty_struct___17 *);
	int (*open)(struct tty_struct___17 *, struct file___193 *);
	void (*close)(struct tty_struct___17 *, struct file___193 *);
	void (*shutdown)(struct tty_struct___17 *);
	void (*cleanup)(struct tty_struct___17 *);
	int (*write)(struct tty_struct___17 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___17 *, unsigned char);
	void (*flush_chars)(struct tty_struct___17 *);
	int (*write_room)(struct tty_struct___17 *);
	int (*chars_in_buffer)(struct tty_struct___17 *);
	int (*ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	void (*throttle)(struct tty_struct___17 *);
	void (*unthrottle)(struct tty_struct___17 *);
	void (*stop)(struct tty_struct___17 *);
	void (*start)(struct tty_struct___17 *);
	void (*hangup)(struct tty_struct___17 *);
	int (*break_ctl)(struct tty_struct___17 *, int);
	void (*flush_buffer)(struct tty_struct___17 *);
	void (*set_ldisc)(struct tty_struct___17 *);
	void (*wait_until_sent)(struct tty_struct___17 *, int);
	void (*send_xchar)(struct tty_struct___17 *, char);
	int (*tiocmget)(struct tty_struct___17 *);
	int (*tiocmset)(struct tty_struct___17 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___17 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___17 *, struct termiox *);
	int (*get_icount)(struct tty_struct___17 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___17 *, int, char *);
	int (*poll_get_char)(struct tty_driver___17 *, int);
	void (*poll_put_char)(struct tty_driver___17 *, int, char);
	const struct file_operations___193 *proc_fops;
};

struct tty_driver___17 {
	int magic;
	struct kref kref;
	struct cdev___47 *cdevs;
	struct module___109 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___17 *other;
	struct tty_struct___17 **ttys;
	struct tty_port___17 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___17 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___17;

struct tty_port___17 {
	struct tty_bufhead buf;
	struct tty_struct___17 *tty;
	struct tty_struct___17 *itty;
	const struct tty_port_operations___17 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___196 mutex;
	struct mutex___196 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___17 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___17 *);
	void (*close)(struct tty_struct___17 *);
	void (*flush_buffer)(struct tty_struct___17 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___17 *);
	ssize_t (*read)(struct tty_struct___17 *, struct file___193 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___17 *, struct file___193 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___17 *, struct file___193 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___17 *, struct file___193 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___17 *, struct file___193 *, struct poll_table_struct___110 *);
	int (*hangup)(struct tty_struct___17 *);
	void (*receive_buf)(struct tty_struct___17 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___17 *);
	void (*dcd_change)(struct tty_struct___17 *, unsigned int);
	struct module___109 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___17 *, int);
};

struct tty_ldisc___17 {
	struct tty_ldisc_ops___17 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___17 *tty;
};

struct tty_port_operations___17 {
	int (*carrier_raised)(struct tty_port___17 *);
	void (*dtr_rts)(struct tty_port___17 *, int);
	void (*shutdown)(struct tty_port___17 *);
	void (*drop)(struct tty_port___17 *);
	int (*activate)(struct tty_port___17 *, struct tty_struct___17 *);
	void (*destruct)(struct tty_port___17 *);
};

struct tty_file_private___2 {
	struct tty_struct___17 *tty;
	struct file___193 *file;
	struct list_head list;
};

struct console___4 {
	char name[16];
	void (*write)(struct console___4 *, const char *, unsigned int);
	int (*read)(struct console___4 *, char *, unsigned int);
	struct tty_driver___17 * (*device)(struct console___4 *, int *);
	void (*unblank)();
	int (*setup)(struct console___4 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___4 *next;
};

struct vm_fault___170 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___192 *page;
};

struct kmem_cache_cpu___178 {
	void **freelist;
	long unsigned int tid;
	struct page___192 *page;
	struct page___192 *partial;
};

struct memcg_cache_params___179 {
	bool is_root_cache;
	union {
		struct kmem_cache___179 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___179 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef struct poll_table_struct___110 poll_table___22;

struct module_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___108 *, struct module_kobject___108 *, char *);
	ssize_t (*store)(struct module_attribute___108 *, struct module_kobject___108 *, const char *, size_t);
	void (*setup)(struct module___109 *, const char *);
	int (*test)(struct module___109 *);
	void (*free)(struct module___109 *);
};

struct bus_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___169 *, char *);
	ssize_t (*store)(struct bus_type___169 *, const char *, size_t);
};

struct device_attribute___169;

struct driver_attribute___169;

struct bus_type___169 {
	const char *name;
	const char *dev_name;
	struct device___169 *dev_root;
	struct bus_attribute___169 *bus_attrs;
	struct device_attribute___169 *dev_attrs;
	struct driver_attribute___169 *drv_attrs;
	const struct attribute_group___151 **bus_groups;
	const struct attribute_group___151 **dev_groups;
	const struct attribute_group___151 **drv_groups;
	int (*match)(struct device___169 *, struct device_driver___169 *);
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	int (*probe)(struct device___169 *);
	int (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*online)(struct device___169 *);
	int (*offline)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct device___169 *, struct device_attribute___169 *, char *);
	ssize_t (*store)(struct device___169 *, struct device_attribute___169 *, const char *, size_t);
};

struct driver_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___169 *, char *);
	ssize_t (*store)(struct device_driver___169 *, const char *, size_t);
};

struct device_driver___169 {
	const char *name;
	struct bus_type___169 *bus;
	struct module___109 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___169 *);
	int (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	const struct attribute_group___151 **groups;
	const struct dev_pm_ops___169 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___169 {
	const char *name;
	const struct attribute_group___151 **groups;
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
};

struct class_attribute___169;

struct class___169 {
	const char *name;
	struct module___109 *owner;
	struct class_attribute___169 *class_attrs;
	struct device_attribute___169 *dev_attrs;
	const struct attribute_group___151 **dev_groups;
	struct bin_attribute___153 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *);
	void (*class_release)(struct class___169 *);
	void (*dev_release)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
	struct subsys_private *p;
};

struct class_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct class___169 *, struct class_attribute___169 *, char *);
	ssize_t (*store)(struct class___169 *, struct class_attribute___169 *, const char *, size_t);
	const void * (*namespace)(struct class___169 *, const struct class_attribute___169 *);
};

struct device_rh___169 {
	struct dev_pm_info_rh___169 power;
};

struct seq_operations___134 {
	void * (*start)(struct seq_file___134 *, loff_t *);
	void (*stop)(struct seq_file___134 *, void *);
	void * (*next)(struct seq_file___134 *, void *, loff_t *);
	int (*show)(struct seq_file___134 *, void *);
};

struct n_tty_data {
	unsigned int column;
	long unsigned int overrun_time;
	int num_overrun;
	unsigned char lnext: 1;
	unsigned char erasing: 1;
	unsigned char raw: 1;
	unsigned char real_raw: 1;
	unsigned char icanon: 1;
	unsigned char echo_overrun: 1;
	long unsigned int process_char_map[4];
	long unsigned int read_flags[64];
	char *read_buf;
	int read_head;
	int read_tail;
	int read_cnt;
	int minimum_to_wake;
	unsigned char *echo_buf;
	unsigned int echo_pos;
	unsigned int echo_cnt;
	int canon_data;
	long unsigned int canon_head;
	unsigned int canon_column;
	struct mutex___196 atomic_read_lock;
	struct mutex___196 output_lock;
	struct mutex___196 echo_lock;
	raw_spinlock_t read_lock;
};

enum {
	ERASE = 0,
	WERASE = 1,
	KILL = 2,
};

struct termios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
};

struct termios2 {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct termio {
	short unsigned int c_iflag;
	short unsigned int c_oflag;
	short unsigned int c_cflag;
	short unsigned int c_lflag;
	unsigned char c_line;
	unsigned char c_cc[8];
};

enum {
	TTY_MUTEX_NORMAL = 0,
	TTY_MUTEX_NESTED = 1,
};

struct ldsem_waiter {
	struct list_head list;
	struct task_struct___188 *task;
};

struct tty_audit_buf {
	atomic_t count;
	struct mutex___196 mutex;
	int major;
	int minor;
	unsigned int icanon: 1;
	size_t valid;
	unsigned char *data;
};

struct page___193;

typedef struct page___193 *pgtable_t___193;

struct address_space___194;

struct kmem_cache___180;

struct page___193 {
	long unsigned int flags;
	struct address_space___194 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___193 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___193 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___180 *slab_cache;
		struct page___193 *first_page;
	};
	long: 64;
};

struct thread_struct___77;

struct task_struct___196;

struct pv_cpu_ops___196 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___77 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___77 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___196 *);
	void (*end_context_switch)(struct task_struct___196 *);
};

struct perf_event___77;

struct thread_struct___77 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___77 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___86;

struct pid_link___86 {
	struct hlist_node node;
	struct pid___86 *pid;
};

struct mutex___197 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___196 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___189 {
	struct page___193 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___202;

struct nsproxy___105;

struct signal_struct___196;

struct css_set___120;

struct perf_event_context___77;

struct task_struct___196 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___196 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___202 *mm;
	struct mm_struct___202 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___196 *real_parent;
	struct task_struct___196 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___196 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___86 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___196 = 0,
		VTIME_USER___196 = 1,
		VTIME_SYS___196 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___77 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___105 *nsproxy;
	struct signal_struct___196 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___120 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___77 *perf_event_ctxp[2];
	struct mutex___197 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___189 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___202 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___202 *, struct mm_struct___202 *);
	void (*dup_mmap)(struct mm_struct___202 *, struct mm_struct___202 *);
	void (*exit_mmap)(struct mm_struct___202 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___202 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___202 *);
	void (*pgd_free)(struct mm_struct___202 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___202 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___202 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___202 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___202 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___202 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___202 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___202 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___202 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___202 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___202 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___202 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___197 lock;
	void *vdso;
} mm_context_t___197;

struct xol_area___193;

struct uprobes_state___193 {
	struct xol_area___193 *xol_area;
};

struct vm_area_struct___202;

struct file___194;

struct core_state___196;

struct mm_struct___202 {
	struct vm_area_struct___202 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___202 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___202 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___197 context;
	long unsigned int flags;
	struct core_state___196 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___196 *owner;
	struct file___194 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___193 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___110;

struct module_kobject___109 {
	struct kobject___20 kobj;
	struct module___110 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___109;

struct module___110 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___109 mkobj;
	struct module_attribute___109 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___196 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___77 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___196 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___196 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___196 *target;
};

typedef void (*perf_overflow_handler_t___77)(struct perf_event___77 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___77;

typedef void (*ftrace_func_t___77)(long unsigned int, long unsigned int, struct ftrace_ops___77 *, struct pt_regs *);

struct ftrace_ops___77 {
	ftrace_func_t___77 func;
	struct ftrace_ops___77 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___197 regex_lock;
};

struct pmu___77;

struct fasync_struct___194;

struct pid_namespace___86;

struct perf_cgroup___77;

struct perf_event___77 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___77 *group_leader;
	struct pmu___77 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___77 hw;
	struct perf_event_context___77 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___197 child_mutex;
	struct list_head child_list;
	struct perf_event___77 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___196 *owner;
	struct mutex___197 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___194 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___77 *);
	struct callback_head callback_head;
	struct pid_namespace___86 *ns;
	u64 id;
	perf_overflow_handler_t___77 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___77 ftrace_ops;
	struct perf_cgroup___77 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct xol_area___193 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___193 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___179;

struct memcg_cache_params___180;

struct kmem_cache___180 {
	struct kmem_cache_cpu___179 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___180 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___194;

struct address_space_operations___194;

struct address_space___194 {
	struct inode___194 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___197 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___194 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___42;

struct dentry___194;

struct path___194 {
	struct vfsmount___42 *mnt;
	struct dentry___194 *dentry;
};

struct fown_struct___86 {
	rwlock_t lock;
	struct pid___86 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___194;

struct file___194 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___194 f_path;
	struct inode___194 *f_inode;
	const struct file_operations___194 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___86 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___194 *f_mapping;
	struct mutex___197 f_pos_lock;
};

struct vm_operations_struct___175;

struct vm_area_struct___202 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___202 *vm_next;
	struct vm_area_struct___202 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___202 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___175 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___194 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___171;

struct vm_operations_struct___175 {
	void (*open)(struct vm_area_struct___202 *);
	void (*close)(struct vm_area_struct___202 *);
	int (*fault)(struct vm_area_struct___202 *, struct vm_fault___171 *);
	int (*page_mkwrite)(struct vm_area_struct___202 *, struct vm_fault___171 *);
	int (*access)(struct vm_area_struct___202 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___202 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___202 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___202 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___202 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___196 {
	struct task_struct___196 *task;
	struct core_thread___196 *next;
};

struct core_state___196 {
	atomic_t nr_threads;
	struct core_thread___196 dumper;
	struct completion startup;
};

struct device___170;

struct dev_pm_ops___170 {
	int (*prepare)(struct device___170 *);
	void (*complete)(struct device___170 *);
	int (*suspend)(struct device___170 *);
	int (*resume)(struct device___170 *);
	int (*freeze)(struct device___170 *);
	int (*thaw)(struct device___170 *);
	int (*poweroff)(struct device___170 *);
	int (*restore)(struct device___170 *);
	int (*suspend_late)(struct device___170 *);
	int (*resume_early)(struct device___170 *);
	int (*freeze_late)(struct device___170 *);
	int (*thaw_early)(struct device___170 *);
	int (*poweroff_late)(struct device___170 *);
	int (*restore_early)(struct device___170 *);
	int (*suspend_noirq)(struct device___170 *);
	int (*resume_noirq)(struct device___170 *);
	int (*freeze_noirq)(struct device___170 *);
	int (*thaw_noirq)(struct device___170 *);
	int (*poweroff_noirq)(struct device___170 *);
	int (*restore_noirq)(struct device___170 *);
	int (*runtime_suspend)(struct device___170 *);
	int (*runtime_resume)(struct device___170 *);
	int (*runtime_idle)(struct device___170 *);
};

struct device_type___170;

struct bus_type___170;

struct device_driver___170;

struct dev_pm_domain___170;

struct class___170;

struct attribute_group___152;

struct device_rh___170;

struct device___170 {
	struct device___170 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___170 *type;
	struct mutex___197 mutex;
	struct bus_type___170 *bus;
	struct device_driver___170 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___170 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___170 *class;
	const struct attribute_group___152 **groups;
	void (*release)(struct device___170 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___170 *device_rh;
};

struct dev_pm_info_rh___170 {
	void (*set_latency_tolerance)(struct device___170 *, s32);
};

struct dev_pm_domain___170 {
	struct dev_pm_ops___170 ops;
};

struct smp_ops___196 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___196 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___86 {
	int nr;
	struct pid_namespace___86 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___86 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___196 *child_reaper;
	struct kmem_cache___180 *pid_cachep;
	unsigned int level;
	struct pid_namespace___86 *parent;
	struct vfsmount___42 *proc_mnt;
	struct dentry___194 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___86 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___86 numbers[1];
};

struct zone___196;

struct lruvec___196 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___196 *zone;
};

struct pglist_data___196;

struct zone___196 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___196 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___196 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___196 {
	struct zone___196 *zone;
	int zone_idx;
};

struct zonelist___196 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___196 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___196 {
	struct zone___196 node_zones[4];
	struct zonelist___196 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___196 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___105 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___86 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___18;

struct signal_struct___196 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___196 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___196 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___86 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___86 *tty_old_pgrp;
	int leader;
	struct tty_struct___18 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___197 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___18;

struct tty_operations___18;

struct tty_ldisc___18;

struct tty_port___18;

struct tty_struct___18 {
	int magic;
	struct kref kref;
	struct device___170 *dev;
	struct tty_driver___18 *driver;
	const struct tty_operations___18 *ops;
	int index;
	struct mutex___197 ldisc_mutex;
	struct tty_ldisc___18 *ldisc;
	struct mutex___197 atomic_write_lock;
	struct mutex___197 legacy_mutex;
	struct mutex___197 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___86 *pgrp;
	struct pid___86 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___18 *link;
	struct fasync_struct___194 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___18 *port;
	struct ld_semaphore ldisc_sem;
};

struct cgroup_subsys_state___120;

struct css_set___120 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___120 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___77 {
	struct pmu___77 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___197 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___196 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___77 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct vm_fault___171 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___193 *page;
};

struct dentry_operations___194;

struct super_block___194;

struct dentry___194 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___194 *d_parent;
	struct qstr d_name;
	struct inode___194 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___194 *d_op;
	struct super_block___194 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___194;

struct file_lock___194;

struct dquot___194;

struct block_device___194;

struct cdev___48;

struct inode___194 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___194 *i_op;
	struct super_block___194 *i_sb;
	struct address_space___194 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___197 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___194 *i_fop;
	struct file_lock___194 *i_flock;
	struct address_space___194 i_data;
	struct dquot___194 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___194 *i_bdev;
		struct cdev___48 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___194 {
	int (*d_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_hash)(const struct dentry___194 *, struct qstr *);
	int (*d_compare)(const struct dentry___194 *, const struct dentry___194 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___194 *);
	void (*d_release)(struct dentry___194 *);
	void (*d_prune)(struct dentry___194 *);
	void (*d_iput)(struct dentry___194 *, struct inode___194 *);
	char * (*d_dname)(struct dentry___194 *, char *, int);
	struct vfsmount___42 * (*d_automount)(struct path___194 *);
	int (*d_manage)(struct dentry___194 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___194;

struct mem_dqinfo___194 {
	struct quota_format_type___194 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___194;

struct quota_info___194 {
	unsigned int flags;
	struct mutex___197 dqio_mutex;
	struct mutex___197 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___194 *files[2];
	struct mem_dqinfo___194 info[2];
	const struct quota_format_ops___194 *ops[2];
};

struct file_system_type___194;

struct super_operations___194;

struct dquot_operations___194;

struct quotactl_ops___194;

struct xattr_handler___121;

struct super_block___194 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___194 *s_type;
	const struct super_operations___194 *s_op;
	const struct dquot_operations___194 *dq_op;
	const struct quotactl_ops___194 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___194 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___121 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___194 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___194 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___197 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___194 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___42 {
	struct dentry___194 *mnt_root;
	struct super_block___194 *mnt_sb;
	int mnt_flags;
};

struct block_device___194 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___194 *bd_inode;
	struct super_block___194 *bd_super;
	struct mutex___197 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___194 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___197 bd_fsfreeze_mutex;
};

struct cgroup___120;

struct cgroup_subsys_state___120 {
	struct cgroup___120 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___194 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___194 *ia_file;
};

struct dquot___194 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___197 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___194 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___194 {
	int qf_fmt_id;
	const struct quota_format_ops___194 *qf_ops;
	struct module___110 *qf_owner;
	struct quota_format_type___194 *qf_next;
};

struct quota_format_ops___194 {
	int (*check_quota_file)(struct super_block___194 *, int);
	int (*read_file_info)(struct super_block___194 *, int);
	int (*write_file_info)(struct super_block___194 *, int);
	int (*free_file_info)(struct super_block___194 *, int);
	int (*read_dqblk)(struct dquot___194 *);
	int (*commit_dqblk)(struct dquot___194 *);
	int (*release_dqblk)(struct dquot___194 *);
};

struct dquot_operations___194 {
	int (*write_dquot)(struct dquot___194 *);
	struct dquot___194 * (*alloc_dquot)(struct super_block___194 *, int);
	void (*destroy_dquot)(struct dquot___194 *);
	int (*acquire_dquot)(struct dquot___194 *);
	int (*release_dquot)(struct dquot___194 *);
	int (*mark_dirty)(struct dquot___194 *);
	int (*write_info)(struct super_block___194 *, int);
	qsize_t * (*get_reserved_space)(struct inode___194 *);
};

struct quotactl_ops___194 {
	int (*quota_on)(struct super_block___194 *, int, int, struct path___194 *);
	int (*quota_on_meta)(struct super_block___194 *, int, int);
	int (*quota_off)(struct super_block___194 *, int);
	int (*quota_sync)(struct super_block___194 *, int);
	int (*get_info)(struct super_block___194 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___194 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___194 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___194 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___194 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___194 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___194 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___194 *, unsigned int);
};

struct swap_info_struct___42;

struct address_space_operations___194 {
	int (*writepage)(struct page___193 *, struct writeback_control *);
	int (*readpage)(struct file___194 *, struct page___193 *);
	int (*writepages)(struct address_space___194 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___193 *);
	int (*readpages)(struct file___194 *, struct address_space___194 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___194 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___193 **, void **);
	int (*write_end)(struct file___194 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___193 *, void *);
	sector_t (*bmap)(struct address_space___194 *, sector_t);
	void (*invalidatepage)(struct page___193 *, long unsigned int);
	int (*releasepage)(struct page___193 *, gfp_t);
	void (*freepage)(struct page___193 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___194 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___194 *, struct page___193 *, struct page___193 *, enum migrate_mode);
	int (*launder_page)(struct page___193 *);
	int (*is_partially_uptodate)(struct page___193 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___193 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___194 *, struct page___193 *);
	int (*swap_activate)(struct swap_info_struct___42 *, struct file___194 *, sector_t *);
	void (*swap_deactivate)(struct file___194 *);
	void (*invalidatepage_range)(struct page___193 *, unsigned int, unsigned int);
};

struct swap_info_struct___42 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___194 *bdev;
	struct file___194 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___48 {
	struct kobject___20 kobj;
	struct module___110 *owner;
	const struct file_operations___194 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___194 {
	struct dentry___194 * (*lookup)(struct inode___194 *, struct dentry___194 *, unsigned int);
	void * (*follow_link)(struct dentry___194 *, struct nameidata *);
	int (*permission)(struct inode___194 *, int);
	struct posix_acl * (*get_acl)(struct inode___194 *, int);
	int (*readlink)(struct dentry___194 *, char *, int);
	void (*put_link)(struct dentry___194 *, struct nameidata *, void *);
	int (*create)(struct inode___194 *, struct dentry___194 *, umode_t, bool);
	int (*link)(struct dentry___194 *, struct inode___194 *, struct dentry___194 *);
	int (*unlink)(struct inode___194 *, struct dentry___194 *);
	int (*symlink)(struct inode___194 *, struct dentry___194 *, const char *);
	int (*mkdir)(struct inode___194 *, struct dentry___194 *, umode_t);
	int (*rmdir)(struct inode___194 *, struct dentry___194 *);
	int (*mknod)(struct inode___194 *, struct dentry___194 *, umode_t, dev_t);
	int (*rename)(struct inode___194 *, struct dentry___194 *, struct inode___194 *, struct dentry___194 *);
	int (*setattr)(struct dentry___194 *, struct iattr___194 *);
	int (*getattr)(struct vfsmount___42 *, struct dentry___194 *, struct kstat *);
	int (*setxattr)(struct dentry___194 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___194 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___194 *, char *, size_t);
	int (*removexattr)(struct dentry___194 *, const char *);
	int (*fiemap)(struct inode___194 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___194 *, struct timespec *, int);
	int (*atomic_open)(struct inode___194 *, struct dentry___194 *, struct file___194 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___194 {
	struct module___110 *owner;
	loff_t (*llseek)(struct file___194 *, loff_t, int);
	ssize_t (*read)(struct file___194 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___194 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___194 *, void *, filldir_t);
	unsigned int (*poll)(struct file___194 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___194 *, struct vm_area_struct___202 *);
	int (*open)(struct inode___194 *, struct file___194 *);
	int (*flush)(struct file___194 *, fl_owner_t);
	int (*release)(struct inode___194 *, struct file___194 *);
	int (*fsync)(struct file___194 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___194 *, int);
	int (*lock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*sendpage)(struct file___194 *, struct page___193 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___194 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___194 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___194 *, long int, struct file_lock___194 **, void **);
		struct {
			int (*setlease)(struct file___194 *, long int, struct file_lock___194 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___194 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___194 *);
};

struct file_lock_operations___194;

struct lock_manager_operations___194;

struct file_lock___194 {
	struct file_lock___194 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___86 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___194 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___194 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___194 *fl_ops;
	const struct lock_manager_operations___194 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___194 {
	void (*fl_copy_lock)(struct file_lock___194 *, struct file_lock___194 *);
	void (*fl_release_private)(struct file_lock___194 *);
};

struct lock_manager_operations___194 {
	int (*lm_compare_owner)(struct file_lock___194 *, struct file_lock___194 *);
	long unsigned int (*lm_owner_key)(struct file_lock___194 *);
	void (*lm_notify)(struct file_lock___194 *);
	int (*lm_grant)(struct file_lock___194 *, struct file_lock___194 *, int);
	void (*lm_break)(struct file_lock___194 *);
	int (*lm_change)(struct file_lock___194 **, int);
};

struct fasync_struct___194 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___194 *fa_next;
	struct file___194 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___194 {
	const char *name;
	int fs_flags;
	struct dentry___194 * (*mount)(struct file_system_type___194 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___194 *);
	struct module___110 *owner;
	struct file_system_type___194 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___194 {
	struct inode___194 * (*alloc_inode)(struct super_block___194 *);
	void (*destroy_inode)(struct inode___194 *);
	void (*dirty_inode)(struct inode___194 *, int);
	int (*write_inode)(struct inode___194 *, struct writeback_control *);
	int (*drop_inode)(struct inode___194 *);
	void (*evict_inode)(struct inode___194 *);
	void (*put_super)(struct super_block___194 *);
	int (*sync_fs)(struct super_block___194 *, int);
	int (*freeze_fs)(struct super_block___194 *);
	int (*unfreeze_fs)(struct super_block___194 *);
	int (*statfs)(struct dentry___194 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___194 *, int *, char *);
	void (*umount_begin)(struct super_block___194 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___194 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___194 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___194 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___194 *);
	ssize_t (*quota_read)(struct super_block___194 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___194 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___194 *);
	int (*bdev_try_to_free_page)(struct super_block___194 *, struct page___193 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___194 *);
	void (*free_cached_objects)(struct super_block___194 *, int);
};

struct xattr_handler___121 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___194 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___194 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___194 *, const char *, const void *, size_t, int, int);
};

struct bin_attribute___154;

struct attribute_group___152 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___154 **bin_attrs;
};

struct bin_attribute___154 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___194 *, struct kobject___20 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___194 *, struct kobject___20 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	int (*mmap)(struct file___194 *, struct kobject___20 *, struct bin_attribute___154 *, struct vm_area_struct___202 *);
};

struct tty_operations___18 {
	struct tty_struct___18 * (*lookup)(struct tty_driver___18 *, struct inode___194 *, int);
	int (*install)(struct tty_driver___18 *, struct tty_struct___18 *);
	void (*remove)(struct tty_driver___18 *, struct tty_struct___18 *);
	int (*open)(struct tty_struct___18 *, struct file___194 *);
	void (*close)(struct tty_struct___18 *, struct file___194 *);
	void (*shutdown)(struct tty_struct___18 *);
	void (*cleanup)(struct tty_struct___18 *);
	int (*write)(struct tty_struct___18 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___18 *, unsigned char);
	void (*flush_chars)(struct tty_struct___18 *);
	int (*write_room)(struct tty_struct___18 *);
	int (*chars_in_buffer)(struct tty_struct___18 *);
	int (*ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	void (*throttle)(struct tty_struct___18 *);
	void (*unthrottle)(struct tty_struct___18 *);
	void (*stop)(struct tty_struct___18 *);
	void (*start)(struct tty_struct___18 *);
	void (*hangup)(struct tty_struct___18 *);
	int (*break_ctl)(struct tty_struct___18 *, int);
	void (*flush_buffer)(struct tty_struct___18 *);
	void (*set_ldisc)(struct tty_struct___18 *);
	void (*wait_until_sent)(struct tty_struct___18 *, int);
	void (*send_xchar)(struct tty_struct___18 *, char);
	int (*tiocmget)(struct tty_struct___18 *);
	int (*tiocmset)(struct tty_struct___18 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___18 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___18 *, struct termiox *);
	int (*get_icount)(struct tty_struct___18 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___18 *, int, char *);
	int (*poll_get_char)(struct tty_driver___18 *, int);
	void (*poll_put_char)(struct tty_driver___18 *, int, char);
	const struct file_operations___194 *proc_fops;
};

struct tty_driver___18 {
	int magic;
	struct kref kref;
	struct cdev___48 *cdevs;
	struct module___110 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___18 *other;
	struct tty_struct___18 **ttys;
	struct tty_port___18 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___18 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___18;

struct tty_port___18 {
	struct tty_bufhead buf;
	struct tty_struct___18 *tty;
	struct tty_struct___18 *itty;
	const struct tty_port_operations___18 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___197 mutex;
	struct mutex___197 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___18 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___18 *);
	void (*close)(struct tty_struct___18 *);
	void (*flush_buffer)(struct tty_struct___18 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___18 *);
	ssize_t (*read)(struct tty_struct___18 *, struct file___194 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___18 *, struct file___194 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___18 *, struct file___194 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___18 *, struct file___194 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___18 *, struct file___194 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___18 *);
	void (*receive_buf)(struct tty_struct___18 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___18 *);
	void (*dcd_change)(struct tty_struct___18 *, unsigned int);
	struct module___110 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___18 *, int);
};

struct tty_ldisc___18 {
	struct tty_ldisc_ops___18 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___18 *tty;
};

struct tty_port_operations___18 {
	int (*carrier_raised)(struct tty_port___18 *);
	void (*dtr_rts)(struct tty_port___18 *, int);
	void (*shutdown)(struct tty_port___18 *);
	void (*drop)(struct tty_port___18 *);
	int (*activate)(struct tty_port___18 *, struct tty_struct___18 *);
	void (*destruct)(struct tty_port___18 *);
};

struct vc_data___4 {
	struct tty_port___18 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___3 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___86 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___4 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct bus_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___170 *, char *);
	ssize_t (*store)(struct bus_type___170 *, const char *, size_t);
};

struct device_attribute___170;

struct driver_attribute___170;

struct bus_type___170 {
	const char *name;
	const char *dev_name;
	struct device___170 *dev_root;
	struct bus_attribute___170 *bus_attrs;
	struct device_attribute___170 *dev_attrs;
	struct driver_attribute___170 *drv_attrs;
	const struct attribute_group___152 **bus_groups;
	const struct attribute_group___152 **dev_groups;
	const struct attribute_group___152 **drv_groups;
	int (*match)(struct device___170 *, struct device_driver___170 *);
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	int (*probe)(struct device___170 *);
	int (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*online)(struct device___170 *);
	int (*offline)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct device___170 *, struct device_attribute___170 *, char *);
	ssize_t (*store)(struct device___170 *, struct device_attribute___170 *, const char *, size_t);
};

struct driver_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___170 *, char *);
	ssize_t (*store)(struct device_driver___170 *, const char *, size_t);
};

struct device_driver___170 {
	const char *name;
	struct bus_type___170 *bus;
	struct module___110 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___170 *);
	int (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	const struct attribute_group___152 **groups;
	const struct dev_pm_ops___170 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___170 {
	const char *name;
	const struct attribute_group___152 **groups;
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
};

struct class_attribute___170;

struct class___170 {
	const char *name;
	struct module___110 *owner;
	struct class_attribute___170 *class_attrs;
	struct device_attribute___170 *dev_attrs;
	const struct attribute_group___152 **dev_groups;
	struct bin_attribute___154 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *);
	void (*class_release)(struct class___170 *);
	void (*dev_release)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
	struct subsys_private *p;
};

struct class_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct class___170 *, struct class_attribute___170 *, char *);
	ssize_t (*store)(struct class___170 *, struct class_attribute___170 *, const char *, size_t);
	const void * (*namespace)(struct class___170 *, const struct class_attribute___170 *);
};

struct device_rh___170 {
	struct dev_pm_info_rh___170 power;
};

struct kmem_cache_cpu___179 {
	void **freelist;
	long unsigned int tid;
	struct page___193 *page;
	struct page___193 *partial;
};

struct memcg_cache_params___180 {
	bool is_root_cache;
	union {
		struct kmem_cache___180 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___180 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___120;

struct cgroup___120 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___120 *parent;
	struct dentry___194 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___120 *subsys[11];
	struct cgroupfs_root___120 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___197 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___120 {
	struct super_block___194 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___120 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___66 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___194 *, struct file___194 *);
	ssize_t (*read)(struct cgroup___120 *, struct cftype___66 *, struct file___194 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___120 *, struct cftype___66 *);
	s64 (*read_s64)(struct cgroup___120 *, struct cftype___66 *);
	int (*read_map)(struct cgroup___120 *, struct cftype___66 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___120 *, struct cftype___66 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___120 *, struct cftype___66 *, struct file___194 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___120 *, struct cftype___66 *, u64);
	int (*write_s64)(struct cgroup___120 *, struct cftype___66 *, s64);
	int (*write_string)(struct cgroup___120 *, struct cftype___66 *, const char *);
	int (*trigger)(struct cgroup___120 *, unsigned int);
	int (*release)(struct inode___194 *, struct file___194 *);
	int (*register_event)(struct cgroup___120 *, struct cftype___66 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___120 *, struct cftype___66 *, struct eventfd_ctx *);
};

struct cftype_set___62 {
	struct list_head node;
	struct cftype___66 *cfts;
};

struct task_and_cgroup___62 {
	struct task_struct___196 *task;
	struct cgroup___120 *cgrp;
	struct css_set___120 *cg;
};

struct cgroup_taskset___62 {
	struct task_and_cgroup___62 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___120 *cur_cgrp;
};

struct cgroup_subsys___62 {
	struct cgroup_subsys_state___120 * (*css_alloc)(struct cgroup___120 *);
	int (*css_online)(struct cgroup___120 *);
	void (*css_offline)(struct cgroup___120 *);
	void (*css_free)(struct cgroup___120 *);
	int (*can_attach)(struct cgroup___120 *, struct cgroup_taskset___62 *);
	void (*cancel_attach)(struct cgroup___120 *, struct cgroup_taskset___62 *);
	void (*attach)(struct cgroup___120 *, struct cgroup_taskset___62 *);
	void (*fork)(struct task_struct___196 *);
	void (*exit)(struct cgroup___120 *, struct cgroup___120 *, struct task_struct___196 *);
	void (*bind)(struct cgroup___120 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___120 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___66 *base_cftypes;
	struct cftype_set___62 base_cftset;
	struct module___110 *module;
};

struct perf_cpu_context___77;

struct pmu___77 {
	struct list_head entry;
	struct device___170 *dev;
	const struct attribute_group___152 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___77 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___77 *);
	void (*pmu_disable)(struct pmu___77 *);
	int (*event_init)(struct perf_event___77 *);
	int (*add)(struct perf_event___77 *, int);
	void (*del)(struct perf_event___77 *, int);
	void (*start)(struct perf_event___77 *, int);
	void (*stop)(struct perf_event___77 *, int);
	void (*read)(struct perf_event___77 *);
	void (*start_txn)(struct pmu___77 *);
	int (*commit_txn)(struct pmu___77 *);
	void (*cancel_txn)(struct pmu___77 *);
	int (*event_idx)(struct perf_event___77 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___110 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___77 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___77 *);
};

struct perf_cpu_context___77 {
	struct perf_event_context___77 ctx;
	struct perf_event_context___77 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___77 *unique_pmu;
	struct perf_cgroup___77 *cgrp;
};

struct perf_cgroup___77 {
	struct cgroup_subsys_state___120 css;
	struct perf_cgroup_info *info;
};

struct module_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___109 *, struct module_kobject___109 *, char *);
	ssize_t (*store)(struct module_attribute___109 *, struct module_kobject___109 *, const char *, size_t);
	void (*setup)(struct module___110 *, const char *);
	int (*test)(struct module___110 *);
	void (*free)(struct module___110 *);
};

struct vc___3 {
	struct vc_data___4 *d;
	struct work_struct SAK_work;
};

struct ff_device___2;

struct input_handle___2;

struct input_dev___2 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___2 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___2 *, struct input_keymap_entry *);
	struct ff_device___2 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___2 *);
	void (*close)(struct input_dev___2 *);
	int (*flush)(struct input_dev___2 *, struct file___194 *);
	int (*event)(struct input_dev___2 *, unsigned int, unsigned int, int);
	struct input_handle___2 *grab;
	spinlock_t event_lock;
	struct mutex___197 mutex;
	unsigned int users;
	bool going_away;
	struct device___170 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___2 {
	int (*upload)(struct input_dev___2 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___2 *, int);
	int (*playback)(struct input_dev___2 *, int, int);
	void (*set_gain)(struct input_dev___2 *, u16);
	void (*set_autocenter)(struct input_dev___2 *, u16);
	void (*destroy)(struct ff_device___2 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___197 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___194 *effect_owners[0];
};

struct input_handler___2;

struct input_handle___2 {
	void *private;
	int open;
	const char *name;
	struct input_dev___2 *dev;
	struct input_handler___2 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___2 {
	void *private;
	void (*event)(struct input_handle___2 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___2 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___2 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___2 *, struct input_dev___2 *);
	int (*connect)(struct input_handler___2 *, struct input_dev___2 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___2 *);
	void (*start)(struct input_handle___2 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct sysrq_state {
	struct input_handle___2 handle;
	struct work_struct reinject_work;
	long unsigned int key_down[12];
	unsigned int alt;
	unsigned int alt_use;
	bool active;
	bool need_reinject;
	bool reinjecting;
	bool reset_canceled;
	long unsigned int reset_keybit[12];
	int reset_seq_len;
	int reset_seq_cnt;
	int reset_seq_version;
	struct timer_list keyreset_timer;
};

struct page___194;

typedef struct page___194 *pgtable_t___194;

struct address_space___195;

struct kmem_cache___181;

struct page___194 {
	long unsigned int flags;
	struct address_space___195 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___194 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___194 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___181 *slab_cache;
		struct page___194 *first_page;
	};
	long: 64;
};

struct thread_struct___78;

struct task_struct___197;

struct pv_cpu_ops___197 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___197 *);
	void (*end_context_switch)(struct task_struct___197 *);
};

struct perf_event___78;

struct thread_struct___78 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___78 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___87;

struct pid_link___87 {
	struct hlist_node node;
	struct pid___87 *pid;
};

struct mutex___198 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___197 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___190 {
	struct page___194 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___203;

struct nsproxy___106;

struct signal_struct___197;

struct css_set___121;

struct perf_event_context___78;

struct task_struct___197 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___197 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___203 *mm;
	struct mm_struct___203 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___197 *real_parent;
	struct task_struct___197 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___197 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___197 = 0,
		VTIME_USER___197 = 1,
		VTIME_SYS___197 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___106 *nsproxy;
	struct signal_struct___197 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___121 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___78 *perf_event_ctxp[2];
	struct mutex___198 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___190 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___203 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___203 *, struct mm_struct___203 *);
	void (*dup_mmap)(struct mm_struct___203 *, struct mm_struct___203 *);
	void (*exit_mmap)(struct mm_struct___203 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___203 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___203 *);
	void (*pgd_free)(struct mm_struct___203 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___203 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___203 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___203 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___203 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___203 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___203 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___203 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___203 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___203 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___203 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___203 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___198 lock;
	void *vdso;
} mm_context_t___198;

struct xol_area___194;

struct uprobes_state___194 {
	struct xol_area___194 *xol_area;
};

struct vm_area_struct___203;

struct file___195;

struct core_state___197;

struct mm_struct___203 {
	struct vm_area_struct___203 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___203 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___203 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___198 context;
	long unsigned int flags;
	struct core_state___197 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___197 *owner;
	struct file___195 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___194 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___111;

struct exec_domain___50 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___111 *module;
	struct exec_domain___50 *next;
};

struct module_kobject___110 {
	struct kobject___20 kobj;
	struct module___111 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___110;

struct ftrace_event_call___67;

struct module___111 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___110 mkobj;
	struct module_attribute___110 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___67 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___197 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___78 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___197 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___197 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___197 *target;
};

typedef void (*perf_overflow_handler_t___78)(struct perf_event___78 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___78;

typedef void (*ftrace_func_t___78)(long unsigned int, long unsigned int, struct ftrace_ops___78 *, struct pt_regs *);

struct ftrace_ops___78 {
	ftrace_func_t___78 func;
	struct ftrace_ops___78 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___198 regex_lock;
};

struct pmu___78;

struct fasync_struct___195;

struct pid_namespace___87;

struct perf_cgroup___78;

struct perf_event___78 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___78 *group_leader;
	struct pmu___78 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___78 hw;
	struct perf_event_context___78 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___198 child_mutex;
	struct list_head child_list;
	struct perf_event___78 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___197 *owner;
	struct mutex___198 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___195 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___78 *);
	struct callback_head callback_head;
	struct pid_namespace___87 *ns;
	u64 id;
	perf_overflow_handler_t___78 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___67 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___78 ftrace_ops;
	struct perf_cgroup___78 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___89 {
	struct task_struct___197 *task;
	struct exec_domain___50 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___194 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___194 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___180;

struct memcg_cache_params___181;

struct kmem_cache___181 {
	struct kmem_cache_cpu___180 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___181 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___195;

struct address_space_operations___195;

struct address_space___195 {
	struct inode___195 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___198 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___195 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___195;

struct path___195 {
	struct vfsmount *mnt;
	struct dentry___195 *dentry;
};

struct fown_struct___87 {
	rwlock_t lock;
	struct pid___87 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___195;

struct file___195 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___195 f_path;
	struct inode___195 *f_inode;
	const struct file_operations___195 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___195 *f_mapping;
	struct mutex___198 f_pos_lock;
};

struct vm_operations_struct___176;

struct vm_area_struct___203 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___203 *vm_next;
	struct vm_area_struct___203 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___203 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___176 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___195 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___172;

struct vm_operations_struct___176 {
	void (*open)(struct vm_area_struct___203 *);
	void (*close)(struct vm_area_struct___203 *);
	int (*fault)(struct vm_area_struct___203 *, struct vm_fault___172 *);
	int (*page_mkwrite)(struct vm_area_struct___203 *, struct vm_fault___172 *);
	int (*access)(struct vm_area_struct___203 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___203 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___203 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___203 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___203 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___197 {
	struct task_struct___197 *task;
	struct core_thread___197 *next;
};

struct core_state___197 {
	atomic_t nr_threads;
	struct core_thread___197 dumper;
	struct completion startup;
};

struct irq_data___131;

struct x86_io_apic_ops___131 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___131 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___131;

struct irq_data___131 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___131 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___171;

struct dev_pm_ops___171 {
	int (*prepare)(struct device___171 *);
	void (*complete)(struct device___171 *);
	int (*suspend)(struct device___171 *);
	int (*resume)(struct device___171 *);
	int (*freeze)(struct device___171 *);
	int (*thaw)(struct device___171 *);
	int (*poweroff)(struct device___171 *);
	int (*restore)(struct device___171 *);
	int (*suspend_late)(struct device___171 *);
	int (*resume_early)(struct device___171 *);
	int (*freeze_late)(struct device___171 *);
	int (*thaw_early)(struct device___171 *);
	int (*poweroff_late)(struct device___171 *);
	int (*restore_early)(struct device___171 *);
	int (*suspend_noirq)(struct device___171 *);
	int (*resume_noirq)(struct device___171 *);
	int (*freeze_noirq)(struct device___171 *);
	int (*thaw_noirq)(struct device___171 *);
	int (*poweroff_noirq)(struct device___171 *);
	int (*restore_noirq)(struct device___171 *);
	int (*runtime_suspend)(struct device___171 *);
	int (*runtime_resume)(struct device___171 *);
	int (*runtime_idle)(struct device___171 *);
};

struct device_type___171;

struct bus_type___171;

struct device_driver___171;

struct dev_pm_domain___171;

struct class___171;

struct attribute_group___153;

struct device_rh___171;

struct device___171 {
	struct device___171 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___171 *type;
	struct mutex___198 mutex;
	struct bus_type___171 *bus;
	struct device_driver___171 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___171 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___171 *class;
	const struct attribute_group___153 **groups;
	void (*release)(struct device___171 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___171 *device_rh;
};

struct dev_pm_info_rh___171 {
	void (*set_latency_tolerance)(struct device___171 *, s32);
};

struct dev_pm_domain___171 {
	struct dev_pm_ops___171 ops;
};

struct smp_ops___197 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___197 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___87 {
	int nr;
	struct pid_namespace___87 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___87 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___197 *child_reaper;
	struct kmem_cache___181 *pid_cachep;
	unsigned int level;
	struct pid_namespace___87 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___195 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___87 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___87 numbers[1];
};

struct zone___197;

struct lruvec___197 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___197 *zone;
};

struct pglist_data___197;

struct zone___197 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___197 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___197 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___197 {
	struct zone___197 *zone;
	int zone_idx;
};

struct zonelist___197 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___197 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___197 {
	struct zone___197 node_zones[4];
	struct zonelist___197 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___197 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___106 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___87 *pid_ns;
	struct net *net_ns;
};

struct tty_struct___19;

struct signal_struct___197 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___197 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___197 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___19 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___198 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___19;

struct tty_operations___19;

struct tty_ldisc___19;

struct tty_port___19;

struct tty_struct___19 {
	int magic;
	struct kref kref;
	struct device___171 *dev;
	struct tty_driver___19 *driver;
	const struct tty_operations___19 *ops;
	int index;
	struct mutex___198 ldisc_mutex;
	struct tty_ldisc___19 *ldisc;
	struct mutex___198 atomic_write_lock;
	struct mutex___198 legacy_mutex;
	struct mutex___198 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___19 *link;
	struct fasync_struct___195 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___19 *port;
	struct ld_semaphore ldisc_sem;
};

struct cgroup_subsys_state___121;

struct css_set___121 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___121 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___78 {
	struct pmu___78 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___198 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___197 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___78 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dentry_operations___195;

struct super_block___195;

struct dentry___195 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___195 *d_parent;
	struct qstr d_name;
	struct inode___195 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___195 *d_op;
	struct super_block___195 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___195;

struct file_lock___195;

struct dquot___195;

struct block_device___195;

struct cdev___49;

struct inode___195 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___195 *i_op;
	struct super_block___195 *i_sb;
	struct address_space___195 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___198 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___195 *i_fop;
	struct file_lock___195 *i_flock;
	struct address_space___195 i_data;
	struct dquot___195 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___195 *i_bdev;
		struct cdev___49 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___195 {
	int (*d_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_hash)(const struct dentry___195 *, struct qstr *);
	int (*d_compare)(const struct dentry___195 *, const struct dentry___195 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___195 *);
	void (*d_release)(struct dentry___195 *);
	void (*d_prune)(struct dentry___195 *);
	void (*d_iput)(struct dentry___195 *, struct inode___195 *);
	char * (*d_dname)(struct dentry___195 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___195 *);
	int (*d_manage)(struct dentry___195 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___195;

struct mem_dqinfo___195 {
	struct quota_format_type___195 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___195;

struct quota_info___195 {
	unsigned int flags;
	struct mutex___198 dqio_mutex;
	struct mutex___198 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___195 *files[2];
	struct mem_dqinfo___195 info[2];
	const struct quota_format_ops___195 *ops[2];
};

struct file_system_type___195;

struct super_operations___195;

struct dquot_operations___195;

struct quotactl_ops___195;

struct xattr_handler___122;

struct super_block___195 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___195 *s_type;
	const struct super_operations___195 *s_op;
	const struct dquot_operations___195 *dq_op;
	const struct quotactl_ops___195 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___195 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___122 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___195 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___195 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___198 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___195 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___195 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___195 *bd_inode;
	struct super_block___195 *bd_super;
	struct mutex___198 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___195 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___198 bd_fsfreeze_mutex;
};

struct cgroup___121;

struct cgroup_subsys_state___121 {
	struct cgroup___121 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___195 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___195 *ia_file;
};

struct dquot___195 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___198 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___195 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___195 {
	int qf_fmt_id;
	const struct quota_format_ops___195 *qf_ops;
	struct module___111 *qf_owner;
	struct quota_format_type___195 *qf_next;
};

struct quota_format_ops___195 {
	int (*check_quota_file)(struct super_block___195 *, int);
	int (*read_file_info)(struct super_block___195 *, int);
	int (*write_file_info)(struct super_block___195 *, int);
	int (*free_file_info)(struct super_block___195 *, int);
	int (*read_dqblk)(struct dquot___195 *);
	int (*commit_dqblk)(struct dquot___195 *);
	int (*release_dqblk)(struct dquot___195 *);
};

struct dquot_operations___195 {
	int (*write_dquot)(struct dquot___195 *);
	struct dquot___195 * (*alloc_dquot)(struct super_block___195 *, int);
	void (*destroy_dquot)(struct dquot___195 *);
	int (*acquire_dquot)(struct dquot___195 *);
	int (*release_dquot)(struct dquot___195 *);
	int (*mark_dirty)(struct dquot___195 *);
	int (*write_info)(struct super_block___195 *, int);
	qsize_t * (*get_reserved_space)(struct inode___195 *);
};

struct quotactl_ops___195 {
	int (*quota_on)(struct super_block___195 *, int, int, struct path___195 *);
	int (*quota_on_meta)(struct super_block___195 *, int, int);
	int (*quota_off)(struct super_block___195 *, int);
	int (*quota_sync)(struct super_block___195 *, int);
	int (*get_info)(struct super_block___195 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___195 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___195 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___195 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___195 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___195 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___195 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___195 *, unsigned int);
};

struct swap_info_struct___43;

struct address_space_operations___195 {
	int (*writepage)(struct page___194 *, struct writeback_control *);
	int (*readpage)(struct file___195 *, struct page___194 *);
	int (*writepages)(struct address_space___195 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___194 *);
	int (*readpages)(struct file___195 *, struct address_space___195 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___195 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___194 **, void **);
	int (*write_end)(struct file___195 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___194 *, void *);
	sector_t (*bmap)(struct address_space___195 *, sector_t);
	void (*invalidatepage)(struct page___194 *, long unsigned int);
	int (*releasepage)(struct page___194 *, gfp_t);
	void (*freepage)(struct page___194 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___195 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___195 *, struct page___194 *, struct page___194 *, enum migrate_mode);
	int (*launder_page)(struct page___194 *);
	int (*is_partially_uptodate)(struct page___194 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___194 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___195 *, struct page___194 *);
	int (*swap_activate)(struct swap_info_struct___43 *, struct file___195 *, sector_t *);
	void (*swap_deactivate)(struct file___195 *);
	void (*invalidatepage_range)(struct page___194 *, unsigned int, unsigned int);
};

struct swap_info_struct___43 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___195 *bdev;
	struct file___195 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct cdev___49 {
	struct kobject___20 kobj;
	struct module___111 *owner;
	const struct file_operations___195 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___195 {
	struct dentry___195 * (*lookup)(struct inode___195 *, struct dentry___195 *, unsigned int);
	void * (*follow_link)(struct dentry___195 *, struct nameidata *);
	int (*permission)(struct inode___195 *, int);
	struct posix_acl * (*get_acl)(struct inode___195 *, int);
	int (*readlink)(struct dentry___195 *, char *, int);
	void (*put_link)(struct dentry___195 *, struct nameidata *, void *);
	int (*create)(struct inode___195 *, struct dentry___195 *, umode_t, bool);
	int (*link)(struct dentry___195 *, struct inode___195 *, struct dentry___195 *);
	int (*unlink)(struct inode___195 *, struct dentry___195 *);
	int (*symlink)(struct inode___195 *, struct dentry___195 *, const char *);
	int (*mkdir)(struct inode___195 *, struct dentry___195 *, umode_t);
	int (*rmdir)(struct inode___195 *, struct dentry___195 *);
	int (*mknod)(struct inode___195 *, struct dentry___195 *, umode_t, dev_t);
	int (*rename)(struct inode___195 *, struct dentry___195 *, struct inode___195 *, struct dentry___195 *);
	int (*setattr)(struct dentry___195 *, struct iattr___195 *);
	int (*getattr)(struct vfsmount *, struct dentry___195 *, struct kstat *);
	int (*setxattr)(struct dentry___195 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___195 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___195 *, char *, size_t);
	int (*removexattr)(struct dentry___195 *, const char *);
	int (*fiemap)(struct inode___195 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___195 *, struct timespec *, int);
	int (*atomic_open)(struct inode___195 *, struct dentry___195 *, struct file___195 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___111;

struct seq_file___135;

struct file_operations___195 {
	struct module___111 *owner;
	loff_t (*llseek)(struct file___195 *, loff_t, int);
	ssize_t (*read)(struct file___195 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___195 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___195 *, void *, filldir_t);
	unsigned int (*poll)(struct file___195 *, struct poll_table_struct___111 *);
	long int (*unlocked_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___195 *, struct vm_area_struct___203 *);
	int (*open)(struct inode___195 *, struct file___195 *);
	int (*flush)(struct file___195 *, fl_owner_t);
	int (*release)(struct inode___195 *, struct file___195 *);
	int (*fsync)(struct file___195 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___195 *, int);
	int (*lock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*sendpage)(struct file___195 *, struct page___194 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___195 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___195 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___195 *, long int, struct file_lock___195 **, void **);
		struct {
			int (*setlease)(struct file___195 *, long int, struct file_lock___195 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___195 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___135 *, struct file___195 *);
};

struct file_lock_operations___195;

struct lock_manager_operations___195;

struct file_lock___195 {
	struct file_lock___195 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___195 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___195 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___195 *fl_ops;
	const struct lock_manager_operations___195 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___195 {
	void (*fl_copy_lock)(struct file_lock___195 *, struct file_lock___195 *);
	void (*fl_release_private)(struct file_lock___195 *);
};

struct lock_manager_operations___195 {
	int (*lm_compare_owner)(struct file_lock___195 *, struct file_lock___195 *);
	long unsigned int (*lm_owner_key)(struct file_lock___195 *);
	void (*lm_notify)(struct file_lock___195 *);
	int (*lm_grant)(struct file_lock___195 *, struct file_lock___195 *, int);
	void (*lm_break)(struct file_lock___195 *);
	int (*lm_change)(struct file_lock___195 **, int);
};

struct fasync_struct___195 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___195 *fa_next;
	struct file___195 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___195 {
	const char *name;
	int fs_flags;
	struct dentry___195 * (*mount)(struct file_system_type___195 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___195 *);
	struct module___111 *owner;
	struct file_system_type___195 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___195 {
	struct inode___195 * (*alloc_inode)(struct super_block___195 *);
	void (*destroy_inode)(struct inode___195 *);
	void (*dirty_inode)(struct inode___195 *, int);
	int (*write_inode)(struct inode___195 *, struct writeback_control *);
	int (*drop_inode)(struct inode___195 *);
	void (*evict_inode)(struct inode___195 *);
	void (*put_super)(struct super_block___195 *);
	int (*sync_fs)(struct super_block___195 *, int);
	int (*freeze_fs)(struct super_block___195 *);
	int (*unfreeze_fs)(struct super_block___195 *);
	int (*statfs)(struct dentry___195 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___195 *, int *, char *);
	void (*umount_begin)(struct super_block___195 *);
	int (*show_options)(struct seq_file___135 *, struct dentry___195 *);
	int (*show_devname)(struct seq_file___135 *, struct dentry___195 *);
	int (*show_path)(struct seq_file___135 *, struct dentry___195 *);
	int (*show_stats)(struct seq_file___135 *, struct dentry___195 *);
	ssize_t (*quota_read)(struct super_block___195 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___195 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___195 *);
	int (*bdev_try_to_free_page)(struct super_block___195 *, struct page___194 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___195 *);
	void (*free_cached_objects)(struct super_block___195 *, int);
};

struct xattr_handler___122 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___195 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___195 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___195 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___113)(struct file___195 *, wait_queue_head_t *, struct poll_table_struct___111 *);

struct poll_table_struct___111 {
	poll_queue_proc___113 _qproc;
	long unsigned int _key;
};

struct seq_operations___135;

struct seq_file___135 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___198 lock;
	const struct seq_operations___135 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___155;

struct attribute_group___153 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___155 **bin_attrs;
};

struct bin_attribute___155 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___195 *, struct kobject___20 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___195 *, struct kobject___20 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	int (*mmap)(struct file___195 *, struct kobject___20 *, struct bin_attribute___155 *, struct vm_area_struct___203 *);
};

struct tty_operations___19 {
	struct tty_struct___19 * (*lookup)(struct tty_driver___19 *, struct inode___195 *, int);
	int (*install)(struct tty_driver___19 *, struct tty_struct___19 *);
	void (*remove)(struct tty_driver___19 *, struct tty_struct___19 *);
	int (*open)(struct tty_struct___19 *, struct file___195 *);
	void (*close)(struct tty_struct___19 *, struct file___195 *);
	void (*shutdown)(struct tty_struct___19 *);
	void (*cleanup)(struct tty_struct___19 *);
	int (*write)(struct tty_struct___19 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___19 *, unsigned char);
	void (*flush_chars)(struct tty_struct___19 *);
	int (*write_room)(struct tty_struct___19 *);
	int (*chars_in_buffer)(struct tty_struct___19 *);
	int (*ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	void (*throttle)(struct tty_struct___19 *);
	void (*unthrottle)(struct tty_struct___19 *);
	void (*stop)(struct tty_struct___19 *);
	void (*start)(struct tty_struct___19 *);
	void (*hangup)(struct tty_struct___19 *);
	int (*break_ctl)(struct tty_struct___19 *, int);
	void (*flush_buffer)(struct tty_struct___19 *);
	void (*set_ldisc)(struct tty_struct___19 *);
	void (*wait_until_sent)(struct tty_struct___19 *, int);
	void (*send_xchar)(struct tty_struct___19 *, char);
	int (*tiocmget)(struct tty_struct___19 *);
	int (*tiocmset)(struct tty_struct___19 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___19 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___19 *, struct termiox *);
	int (*get_icount)(struct tty_struct___19 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___19 *, int, char *);
	int (*poll_get_char)(struct tty_driver___19 *, int);
	void (*poll_put_char)(struct tty_driver___19 *, int, char);
	const struct file_operations___195 *proc_fops;
};

struct tty_driver___19 {
	int magic;
	struct kref kref;
	struct cdev___49 *cdevs;
	struct module___111 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___19 *other;
	struct tty_struct___19 **ttys;
	struct tty_port___19 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___19 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___19;

struct tty_port___19 {
	struct tty_bufhead buf;
	struct tty_struct___19 *tty;
	struct tty_struct___19 *itty;
	const struct tty_port_operations___19 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___198 mutex;
	struct mutex___198 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___19 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___19 *);
	void (*close)(struct tty_struct___19 *);
	void (*flush_buffer)(struct tty_struct___19 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___19 *);
	ssize_t (*read)(struct tty_struct___19 *, struct file___195 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___19 *, struct file___195 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___19 *, struct file___195 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___19 *, struct file___195 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___19 *, struct file___195 *, struct poll_table_struct___111 *);
	int (*hangup)(struct tty_struct___19 *);
	void (*receive_buf)(struct tty_struct___19 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___19 *);
	void (*dcd_change)(struct tty_struct___19 *, unsigned int);
	struct module___111 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___19 *, int);
};

struct tty_ldisc___19 {
	struct tty_ldisc_ops___19 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___19 *tty;
};

struct tty_port_operations___19 {
	int (*carrier_raised)(struct tty_port___19 *);
	void (*dtr_rts)(struct tty_port___19 *, int);
	void (*shutdown)(struct tty_port___19 *);
	void (*drop)(struct tty_port___19 *);
	int (*activate)(struct tty_port___19 *, struct tty_struct___19 *);
	void (*destruct)(struct tty_port___19 *);
};

struct module_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___110 *, struct module_kobject___110 *, char *);
	ssize_t (*store)(struct module_attribute___110 *, struct module_kobject___110 *, const char *, size_t);
	void (*setup)(struct module___111 *, const char *);
	int (*test)(struct module___111 *);
	void (*free)(struct module___111 *);
};

struct trace_event_functions___67;

struct trace_event___67 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___67 *funcs;
};

struct ftrace_event_class___67;

struct ftrace_event_call___67 {
	struct list_head list;
	struct ftrace_event_class___67 *class;
	char *name;
	struct trace_event___67 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct consolefontdesc {
	short unsigned int charcount;
	short unsigned int charheight;
	char *chardata;
};

struct unipair {
	short unsigned int unicode;
	short unsigned int fontpos;
};

struct unimapdesc {
	short unsigned int entry_ct;
	struct unipair *entries;
};

struct unimapinit {
	short unsigned int advised_hashsize;
	short unsigned int advised_hashstep;
	short unsigned int advised_hashlevel;
};

struct kbentry {
	unsigned char kb_table;
	unsigned char kb_index;
	short unsigned int kb_value;
};

struct kbsentry {
	unsigned char kb_func;
	unsigned char kb_string[512];
};

struct kbkeycode {
	unsigned int scancode;
	unsigned int keycode;
};

struct kbd_repeat {
	int delay;
	int period;
};

struct console_font_op {
	unsigned int op;
	unsigned int flags;
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_stat {
	short unsigned int v_active;
	short unsigned int v_signal;
	short unsigned int v_state;
};

struct vt_sizes {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_scrollsize;
};

struct vt_consize {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_vlin;
	short unsigned int v_clin;
	short unsigned int v_vcol;
	short unsigned int v_ccol;
};

struct vt_event {
	unsigned int event;
	unsigned int oldev;
	unsigned int newev;
	unsigned int pad[4];
};

struct vt_setactivate {
	unsigned int console;
	struct vt_mode mode;
};

struct kmem_cache_cpu___180 {
	void **freelist;
	long unsigned int tid;
	struct page___194 *page;
	struct page___194 *partial;
};

struct memcg_cache_params___181 {
	bool is_root_cache;
	union {
		struct kmem_cache___181 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___181 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vc_data___5;

struct consw___4 {
	struct module___111 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___5 *, int);
	void (*con_deinit)(struct vc_data___5 *);
	void (*con_clear)(struct vc_data___5 *, int, int, int, int);
	void (*con_putc)(struct vc_data___5 *, int, int, int);
	void (*con_putcs)(struct vc_data___5 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___5 *, int);
	int (*con_scroll)(struct vc_data___5 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___5 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___5 *);
	int (*con_blank)(struct vc_data___5 *, int, int);
	int (*con_font_set)(struct vc_data___5 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___5 *, struct console_font *);
	int (*con_font_default)(struct vc_data___5 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___5 *, int);
	int (*con_resize)(struct vc_data___5 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___5 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___5 *, int);
	int (*con_set_origin)(struct vc_data___5 *);
	void (*con_save_screen)(struct vc_data___5 *);
	u8 (*con_build_attr)(struct vc_data___5 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___5 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___5 *, int);
	long unsigned int (*con_getxy)(struct vc_data___5 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___5 *);
	int (*con_debug_leave)(struct vc_data___5 *);
};

struct vc_data___5 {
	struct tty_port___19 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___4 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___87 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___5 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct cgroupfs_root___121;

struct cgroup___121 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___121 *parent;
	struct dentry___195 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___121 *subsys[11];
	struct cgroupfs_root___121 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___198 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___121 {
	struct super_block___195 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___121 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___67 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___195 *, struct file___195 *);
	ssize_t (*read)(struct cgroup___121 *, struct cftype___67 *, struct file___195 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___121 *, struct cftype___67 *);
	s64 (*read_s64)(struct cgroup___121 *, struct cftype___67 *);
	int (*read_map)(struct cgroup___121 *, struct cftype___67 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___121 *, struct cftype___67 *, struct seq_file___135 *);
	ssize_t (*write)(struct cgroup___121 *, struct cftype___67 *, struct file___195 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___121 *, struct cftype___67 *, u64);
	int (*write_s64)(struct cgroup___121 *, struct cftype___67 *, s64);
	int (*write_string)(struct cgroup___121 *, struct cftype___67 *, const char *);
	int (*trigger)(struct cgroup___121 *, unsigned int);
	int (*release)(struct inode___195 *, struct file___195 *);
	int (*register_event)(struct cgroup___121 *, struct cftype___67 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___121 *, struct cftype___67 *, struct eventfd_ctx *);
};

struct cftype_set___63 {
	struct list_head node;
	struct cftype___67 *cfts;
};

struct task_and_cgroup___63 {
	struct task_struct___197 *task;
	struct cgroup___121 *cgrp;
	struct css_set___121 *cg;
};

struct cgroup_taskset___63 {
	struct task_and_cgroup___63 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___121 *cur_cgrp;
};

struct cgroup_subsys___63 {
	struct cgroup_subsys_state___121 * (*css_alloc)(struct cgroup___121 *);
	int (*css_online)(struct cgroup___121 *);
	void (*css_offline)(struct cgroup___121 *);
	void (*css_free)(struct cgroup___121 *);
	int (*can_attach)(struct cgroup___121 *, struct cgroup_taskset___63 *);
	void (*cancel_attach)(struct cgroup___121 *, struct cgroup_taskset___63 *);
	void (*attach)(struct cgroup___121 *, struct cgroup_taskset___63 *);
	void (*fork)(struct task_struct___197 *);
	void (*exit)(struct cgroup___121 *, struct cgroup___121 *, struct task_struct___197 *);
	void (*bind)(struct cgroup___121 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___121 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___67 *base_cftypes;
	struct cftype_set___63 base_cftset;
	struct module___111 *module;
};

struct irq_chip___131 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___131 *);
	void (*irq_shutdown)(struct irq_data___131 *);
	void (*irq_enable)(struct irq_data___131 *);
	void (*irq_disable)(struct irq_data___131 *);
	void (*irq_ack)(struct irq_data___131 *);
	void (*irq_mask)(struct irq_data___131 *);
	void (*irq_mask_ack)(struct irq_data___131 *);
	void (*irq_unmask)(struct irq_data___131 *);
	void (*irq_eoi)(struct irq_data___131 *);
	int (*irq_set_affinity)(struct irq_data___131 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___131 *);
	int (*irq_set_type)(struct irq_data___131 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___131 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___131 *);
	void (*irq_bus_sync_unlock)(struct irq_data___131 *);
	void (*irq_cpu_online)(struct irq_data___131 *);
	void (*irq_cpu_offline)(struct irq_data___131 *);
	void (*irq_suspend)(struct irq_data___131 *);
	void (*irq_resume)(struct irq_data___131 *);
	void (*irq_pm_shutdown)(struct irq_data___131 *);
	void (*irq_print_chip)(struct irq_data___131 *, struct seq_file___135 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___131 *, void *);
	long unsigned int flags;
};

struct bus_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___171 *, char *);
	ssize_t (*store)(struct bus_type___171 *, const char *, size_t);
};

struct device_attribute___171;

struct driver_attribute___171;

struct bus_type___171 {
	const char *name;
	const char *dev_name;
	struct device___171 *dev_root;
	struct bus_attribute___171 *bus_attrs;
	struct device_attribute___171 *dev_attrs;
	struct driver_attribute___171 *drv_attrs;
	const struct attribute_group___153 **bus_groups;
	const struct attribute_group___153 **dev_groups;
	const struct attribute_group___153 **drv_groups;
	int (*match)(struct device___171 *, struct device_driver___171 *);
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	int (*probe)(struct device___171 *);
	int (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*online)(struct device___171 *);
	int (*offline)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct device___171 *, struct device_attribute___171 *, char *);
	ssize_t (*store)(struct device___171 *, struct device_attribute___171 *, const char *, size_t);
};

struct driver_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___171 *, char *);
	ssize_t (*store)(struct device_driver___171 *, const char *, size_t);
};

struct device_driver___171 {
	const char *name;
	struct bus_type___171 *bus;
	struct module___111 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___171 *);
	int (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	const struct attribute_group___153 **groups;
	const struct dev_pm_ops___171 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___171 {
	const char *name;
	const struct attribute_group___153 **groups;
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
};

struct class_attribute___171;

struct class___171 {
	const char *name;
	struct module___111 *owner;
	struct class_attribute___171 *class_attrs;
	struct device_attribute___171 *dev_attrs;
	const struct attribute_group___153 **dev_groups;
	struct bin_attribute___155 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *);
	void (*class_release)(struct class___171 *);
	void (*dev_release)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
	struct subsys_private *p;
};

struct class_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct class___171 *, struct class_attribute___171 *, char *);
	ssize_t (*store)(struct class___171 *, struct class_attribute___171 *, const char *, size_t);
	const void * (*namespace)(struct class___171 *, const struct class_attribute___171 *);
};

struct device_rh___171 {
	struct dev_pm_info_rh___171 power;
};

struct vm_fault___172 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___194 *page;
};

struct vc___4 {
	struct vc_data___5 *d;
	struct work_struct SAK_work;
};

struct vt_spawn_console {
	spinlock_t lock;
	struct pid___87 *pid;
	int sig;
};

struct seq_operations___135 {
	void * (*start)(struct seq_file___135 *, loff_t *);
	void (*stop)(struct seq_file___135 *, void *);
	void * (*next)(struct seq_file___135 *, void *, loff_t *);
	int (*show)(struct seq_file___135 *, void *);
};

struct perf_cpu_context___78;

struct pmu___78 {
	struct list_head entry;
	struct device___171 *dev;
	const struct attribute_group___153 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___78 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___78 *);
	void (*pmu_disable)(struct pmu___78 *);
	int (*event_init)(struct perf_event___78 *);
	int (*add)(struct perf_event___78 *, int);
	void (*del)(struct perf_event___78 *, int);
	void (*start)(struct perf_event___78 *, int);
	void (*stop)(struct perf_event___78 *, int);
	void (*read)(struct perf_event___78 *);
	void (*start_txn)(struct pmu___78 *);
	int (*commit_txn)(struct pmu___78 *);
	void (*cancel_txn)(struct pmu___78 *);
	int (*event_idx)(struct perf_event___78 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___111 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___78 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___78 *);
};

struct perf_cpu_context___78 {
	struct perf_event_context___78 ctx;
	struct perf_event_context___78 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___78 *unique_pmu;
	struct perf_cgroup___78 *cgrp;
};

struct perf_cgroup___78 {
	struct cgroup_subsys_state___121 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___67 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___198 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___67)(struct trace_iterator___67 *, int, struct trace_event___67 *);

struct trace_event_functions___67 {
	trace_print_func___67 trace;
	trace_print_func___67 raw;
	trace_print_func___67 hex;
	trace_print_func___67 binary;
};

struct ftrace_event_class___67 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___67 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___67 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___67 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___67 *);
};

struct vt_event_wait {
	struct list_head list;
	struct vt_event event;
	int done;
};

struct compat_consolefontdesc {
	short unsigned int charcount;
	short unsigned int charheight;
	compat_caddr_t chardata;
};

struct compat_console_font_op {
	compat_uint_t op;
	compat_uint_t flags;
	compat_uint_t width;
	compat_uint_t height;
	compat_uint_t charcount;
	compat_caddr_t data;
};

struct compat_unimapdesc {
	short unsigned int entry_ct;
	compat_caddr_t entries;
};

struct page___195;

typedef struct page___195 *pgtable_t___195;

struct address_space___196;

struct kmem_cache___182;

struct page___195 {
	long unsigned int flags;
	struct address_space___196 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___195 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___195 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___182 *slab_cache;
		struct page___195 *first_page;
	};
	long: 64;
};

struct task_struct___198;

struct pv_cpu_ops___198 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___198 *);
	void (*end_context_switch)(struct task_struct___198 *);
};

struct mutex___199 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___198 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___191 {
	struct page___195 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___204;

struct signal_struct___198;

struct task_struct___198 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___198 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___204 *mm;
	struct mm_struct___204 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___198 *real_parent;
	struct task_struct___198 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___198 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___198 = 0,
		VTIME_USER___198 = 1,
		VTIME_SYS___198 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___198 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___199 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___191 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___204 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___204 *, struct mm_struct___204 *);
	void (*dup_mmap)(struct mm_struct___204 *, struct mm_struct___204 *);
	void (*exit_mmap)(struct mm_struct___204 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___204 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___204 *);
	void (*pgd_free)(struct mm_struct___204 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___204 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___204 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___204 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___204 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___204 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___204 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___204 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___204 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___204 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___204 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___204 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___199 lock;
	void *vdso;
} mm_context_t___199;

struct xol_area___195;

struct uprobes_state___195 {
	struct xol_area___195 *xol_area;
};

struct vm_area_struct___204;

struct file___196;

struct core_state___198;

struct mm_struct___204 {
	struct vm_area_struct___204 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___204 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___204 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___199 context;
	long unsigned int flags;
	struct core_state___198 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___198 *owner;
	struct file___196 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___195 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___196;

struct dentry_operations___196;

struct super_block___196;

struct dentry___196 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___196 *d_parent;
	struct qstr d_name;
	struct inode___196 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___196 *d_op;
	struct super_block___196 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___196;

struct address_space___196 {
	struct inode___196 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___199 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___196 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___196;

struct file_operations___196;

struct file_lock___196;

struct dquot___196;

struct block_device___196;

struct cdev___50;

struct inode___196 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___196 *i_op;
	struct super_block___196 *i_sb;
	struct address_space___196 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___199 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___196 *i_fop;
	struct file_lock___196 *i_flock;
	struct address_space___196 i_data;
	struct dquot___196 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___196 *i_bdev;
		struct cdev___50 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___196;

struct dentry_operations___196 {
	int (*d_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_hash)(const struct dentry___196 *, struct qstr *);
	int (*d_compare)(const struct dentry___196 *, const struct dentry___196 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___196 *);
	void (*d_release)(struct dentry___196 *);
	void (*d_prune)(struct dentry___196 *);
	void (*d_iput)(struct dentry___196 *, struct inode___196 *);
	char * (*d_dname)(struct dentry___196 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___196 *);
	int (*d_manage)(struct dentry___196 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___196;

struct mem_dqinfo___196 {
	struct quota_format_type___196 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___196;

struct quota_info___196 {
	unsigned int flags;
	struct mutex___199 dqio_mutex;
	struct mutex___199 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___196 *files[2];
	struct mem_dqinfo___196 info[2];
	const struct quota_format_ops___196 *ops[2];
};

struct file_system_type___196;

struct super_operations___196;

struct dquot_operations___196;

struct quotactl_ops___196;

struct super_block___196 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___196 *s_type;
	const struct super_operations___196 *s_op;
	const struct dquot_operations___196 *dq_op;
	const struct quotactl_ops___196 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___196 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___196 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___196 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___199 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___196 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___196 {
	struct vfsmount *mnt;
	struct dentry___196 *dentry;
};

struct device___172;

struct dev_pm_ops___172 {
	int (*prepare)(struct device___172 *);
	void (*complete)(struct device___172 *);
	int (*suspend)(struct device___172 *);
	int (*resume)(struct device___172 *);
	int (*freeze)(struct device___172 *);
	int (*thaw)(struct device___172 *);
	int (*poweroff)(struct device___172 *);
	int (*restore)(struct device___172 *);
	int (*suspend_late)(struct device___172 *);
	int (*resume_early)(struct device___172 *);
	int (*freeze_late)(struct device___172 *);
	int (*thaw_early)(struct device___172 *);
	int (*poweroff_late)(struct device___172 *);
	int (*restore_early)(struct device___172 *);
	int (*suspend_noirq)(struct device___172 *);
	int (*resume_noirq)(struct device___172 *);
	int (*freeze_noirq)(struct device___172 *);
	int (*thaw_noirq)(struct device___172 *);
	int (*poweroff_noirq)(struct device___172 *);
	int (*restore_noirq)(struct device___172 *);
	int (*runtime_suspend)(struct device___172 *);
	int (*runtime_resume)(struct device___172 *);
	int (*runtime_idle)(struct device___172 *);
};

struct device_type___172;

struct bus_type___172;

struct device_driver___172;

struct dev_pm_domain___172;

struct class___172;

struct attribute_group___154;

struct device_rh___172;

struct device___172 {
	struct device___172 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___172 *type;
	struct mutex___199 mutex;
	struct bus_type___172 *bus;
	struct device_driver___172 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___172 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___21 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___172 *class;
	const struct attribute_group___154 **groups;
	void (*release)(struct device___172 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___172 *device_rh;
};

struct dev_pm_info_rh___172 {
	void (*set_latency_tolerance)(struct device___172 *, s32);
};

struct dev_pm_domain___172 {
	struct dev_pm_ops___172 ops;
};

struct smp_ops___198 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___198 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___196 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___196 *bd_inode;
	struct super_block___196 *bd_super;
	struct mutex___199 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___196 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___199 bd_fsfreeze_mutex;
};

struct iattr___196 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___196 *ia_file;
};

struct file___196 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___196 f_path;
	struct inode___196 *f_inode;
	const struct file_operations___196 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___196 *f_mapping;
	struct mutex___199 f_pos_lock;
};

struct zone___198;

struct lruvec___198 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___198 *zone;
};

struct pglist_data___198;

struct zone___198 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___198 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___198 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___198 {
	struct zone___198 *zone;
	int zone_idx;
};

struct zonelist___198 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___198 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___198 {
	struct zone___198 node_zones[4];
	struct zonelist___198 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___198 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___196 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___199 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___196 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___196 {
	int qf_fmt_id;
	const struct quota_format_ops___196 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___196 *qf_next;
};

struct quota_format_ops___196 {
	int (*check_quota_file)(struct super_block___196 *, int);
	int (*read_file_info)(struct super_block___196 *, int);
	int (*write_file_info)(struct super_block___196 *, int);
	int (*free_file_info)(struct super_block___196 *, int);
	int (*read_dqblk)(struct dquot___196 *);
	int (*commit_dqblk)(struct dquot___196 *);
	int (*release_dqblk)(struct dquot___196 *);
};

struct dquot_operations___196 {
	int (*write_dquot)(struct dquot___196 *);
	struct dquot___196 * (*alloc_dquot)(struct super_block___196 *, int);
	void (*destroy_dquot)(struct dquot___196 *);
	int (*acquire_dquot)(struct dquot___196 *);
	int (*release_dquot)(struct dquot___196 *);
	int (*mark_dirty)(struct dquot___196 *);
	int (*write_info)(struct super_block___196 *, int);
	qsize_t * (*get_reserved_space)(struct inode___196 *);
};

struct quotactl_ops___196 {
	int (*quota_on)(struct super_block___196 *, int, int, struct path___196 *);
	int (*quota_on_meta)(struct super_block___196 *, int, int);
	int (*quota_off)(struct super_block___196 *, int);
	int (*quota_sync)(struct super_block___196 *, int);
	int (*get_info)(struct super_block___196 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___196 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___196 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___196 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___196 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___196 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___196 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___196 *, unsigned int);
};

struct address_space_operations___196 {
	int (*writepage)(struct page___195 *, struct writeback_control *);
	int (*readpage)(struct file___196 *, struct page___195 *);
	int (*writepages)(struct address_space___196 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___195 *);
	int (*readpages)(struct file___196 *, struct address_space___196 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___196 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___195 **, void **);
	int (*write_end)(struct file___196 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___195 *, void *);
	sector_t (*bmap)(struct address_space___196 *, sector_t);
	void (*invalidatepage)(struct page___195 *, long unsigned int);
	int (*releasepage)(struct page___195 *, gfp_t);
	void (*freepage)(struct page___195 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___196 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___196 *, struct page___195 *, struct page___195 *, enum migrate_mode);
	int (*launder_page)(struct page___195 *);
	int (*is_partially_uptodate)(struct page___195 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___195 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___196 *, struct page___195 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___196 *, sector_t *);
	void (*swap_deactivate)(struct file___196 *);
	void (*invalidatepage_range)(struct page___195 *, unsigned int, unsigned int);
};

struct cdev___50 {
	struct kobject___20 kobj;
	struct module *owner;
	const struct file_operations___196 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___196 {
	struct dentry___196 * (*lookup)(struct inode___196 *, struct dentry___196 *, unsigned int);
	void * (*follow_link)(struct dentry___196 *, struct nameidata *);
	int (*permission)(struct inode___196 *, int);
	struct posix_acl * (*get_acl)(struct inode___196 *, int);
	int (*readlink)(struct dentry___196 *, char *, int);
	void (*put_link)(struct dentry___196 *, struct nameidata *, void *);
	int (*create)(struct inode___196 *, struct dentry___196 *, umode_t, bool);
	int (*link)(struct dentry___196 *, struct inode___196 *, struct dentry___196 *);
	int (*unlink)(struct inode___196 *, struct dentry___196 *);
	int (*symlink)(struct inode___196 *, struct dentry___196 *, const char *);
	int (*mkdir)(struct inode___196 *, struct dentry___196 *, umode_t);
	int (*rmdir)(struct inode___196 *, struct dentry___196 *);
	int (*mknod)(struct inode___196 *, struct dentry___196 *, umode_t, dev_t);
	int (*rename)(struct inode___196 *, struct dentry___196 *, struct inode___196 *, struct dentry___196 *);
	int (*setattr)(struct dentry___196 *, struct iattr___196 *);
	int (*getattr)(struct vfsmount *, struct dentry___196 *, struct kstat *);
	int (*setxattr)(struct dentry___196 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___196 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___196 *, char *, size_t);
	int (*removexattr)(struct dentry___196 *, const char *);
	int (*fiemap)(struct inode___196 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___196 *, struct timespec *, int);
	int (*atomic_open)(struct inode___196 *, struct dentry___196 *, struct file___196 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___112;

struct file_operations___196 {
	struct module *owner;
	loff_t (*llseek)(struct file___196 *, loff_t, int);
	ssize_t (*read)(struct file___196 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___196 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___196 *, void *, filldir_t);
	unsigned int (*poll)(struct file___196 *, struct poll_table_struct___112 *);
	long int (*unlocked_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___196 *, struct vm_area_struct___204 *);
	int (*open)(struct inode___196 *, struct file___196 *);
	int (*flush)(struct file___196 *, fl_owner_t);
	int (*release)(struct inode___196 *, struct file___196 *);
	int (*fsync)(struct file___196 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___196 *, int);
	int (*lock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*sendpage)(struct file___196 *, struct page___195 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___196 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___196 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___196 *, long int, struct file_lock___196 **, void **);
		struct {
			int (*setlease)(struct file___196 *, long int, struct file_lock___196 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___196 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___196 *);
};

struct fasync_struct___196;

struct file_lock_operations___196;

struct lock_manager_operations___196;

struct file_lock___196 {
	struct file_lock___196 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___196 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___196 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___196 *fl_ops;
	const struct lock_manager_operations___196 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___196 {
	void (*fl_copy_lock)(struct file_lock___196 *, struct file_lock___196 *);
	void (*fl_release_private)(struct file_lock___196 *);
};

struct lock_manager_operations___196 {
	int (*lm_compare_owner)(struct file_lock___196 *, struct file_lock___196 *);
	long unsigned int (*lm_owner_key)(struct file_lock___196 *);
	void (*lm_notify)(struct file_lock___196 *);
	int (*lm_grant)(struct file_lock___196 *, struct file_lock___196 *, int);
	void (*lm_break)(struct file_lock___196 *);
	int (*lm_change)(struct file_lock___196 **, int);
};

struct fasync_struct___196 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___196 *fa_next;
	struct file___196 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___196 {
	const char *name;
	int fs_flags;
	struct dentry___196 * (*mount)(struct file_system_type___196 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___196 *);
	struct module *owner;
	struct file_system_type___196 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___196 {
	struct inode___196 * (*alloc_inode)(struct super_block___196 *);
	void (*destroy_inode)(struct inode___196 *);
	void (*dirty_inode)(struct inode___196 *, int);
	int (*write_inode)(struct inode___196 *, struct writeback_control *);
	int (*drop_inode)(struct inode___196 *);
	void (*evict_inode)(struct inode___196 *);
	void (*put_super)(struct super_block___196 *);
	int (*sync_fs)(struct super_block___196 *, int);
	int (*freeze_fs)(struct super_block___196 *);
	int (*unfreeze_fs)(struct super_block___196 *);
	int (*statfs)(struct dentry___196 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___196 *, int *, char *);
	void (*umount_begin)(struct super_block___196 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___196 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___196 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___196 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___196 *);
	ssize_t (*quota_read)(struct super_block___196 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___196 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___196 *);
	int (*bdev_try_to_free_page)(struct super_block___196 *, struct page___195 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___196 *);
	void (*free_cached_objects)(struct super_block___196 *, int);
};

typedef void (*poll_queue_proc___114)(struct file___196 *, wait_queue_head_t *, struct poll_table_struct___112 *);

struct poll_table_struct___112 {
	poll_queue_proc___114 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___177;

struct vm_area_struct___204 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___204 *vm_next;
	struct vm_area_struct___204 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___204 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___177 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___196 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___156;

struct attribute_group___154 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___156 **bin_attrs;
};

struct bin_attribute___156 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___196 *, struct kobject___20 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___196 *, struct kobject___20 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	int (*mmap)(struct file___196 *, struct kobject___20 *, struct bin_attribute___156 *, struct vm_area_struct___204 *);
};

struct tty_struct___20;

struct tty_driver___20;

struct tty_operations___20 {
	struct tty_struct___20 * (*lookup)(struct tty_driver___20 *, struct inode___196 *, int);
	int (*install)(struct tty_driver___20 *, struct tty_struct___20 *);
	void (*remove)(struct tty_driver___20 *, struct tty_struct___20 *);
	int (*open)(struct tty_struct___20 *, struct file___196 *);
	void (*close)(struct tty_struct___20 *, struct file___196 *);
	void (*shutdown)(struct tty_struct___20 *);
	void (*cleanup)(struct tty_struct___20 *);
	int (*write)(struct tty_struct___20 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___20 *, unsigned char);
	void (*flush_chars)(struct tty_struct___20 *);
	int (*write_room)(struct tty_struct___20 *);
	int (*chars_in_buffer)(struct tty_struct___20 *);
	int (*ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	void (*throttle)(struct tty_struct___20 *);
	void (*unthrottle)(struct tty_struct___20 *);
	void (*stop)(struct tty_struct___20 *);
	void (*start)(struct tty_struct___20 *);
	void (*hangup)(struct tty_struct___20 *);
	int (*break_ctl)(struct tty_struct___20 *, int);
	void (*flush_buffer)(struct tty_struct___20 *);
	void (*set_ldisc)(struct tty_struct___20 *);
	void (*wait_until_sent)(struct tty_struct___20 *, int);
	void (*send_xchar)(struct tty_struct___20 *, char);
	int (*tiocmget)(struct tty_struct___20 *);
	int (*tiocmset)(struct tty_struct___20 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___20 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___20 *, struct termiox *);
	int (*get_icount)(struct tty_struct___20 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___20 *, int, char *);
	int (*poll_get_char)(struct tty_driver___20 *, int);
	void (*poll_put_char)(struct tty_driver___20 *, int, char);
	const struct file_operations___196 *proc_fops;
};

struct tty_ldisc___20;

struct tty_port___20;

struct tty_struct___20 {
	int magic;
	struct kref kref;
	struct device___172 *dev;
	struct tty_driver___20 *driver;
	const struct tty_operations___20 *ops;
	int index;
	struct mutex___199 ldisc_mutex;
	struct tty_ldisc___20 *ldisc;
	struct mutex___199 atomic_write_lock;
	struct mutex___199 legacy_mutex;
	struct mutex___199 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___20 *link;
	struct fasync_struct___196 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___20 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___20 {
	int magic;
	struct kref kref;
	struct cdev___50 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___20 *other;
	struct tty_struct___20 **ttys;
	struct tty_port___20 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___20 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___20;

struct tty_port___20 {
	struct tty_bufhead buf;
	struct tty_struct___20 *tty;
	struct tty_struct___20 *itty;
	const struct tty_port_operations___20 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___199 mutex;
	struct mutex___199 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___20 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___20 *);
	void (*close)(struct tty_struct___20 *);
	void (*flush_buffer)(struct tty_struct___20 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___20 *);
	ssize_t (*read)(struct tty_struct___20 *, struct file___196 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___20 *, struct file___196 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___20 *, struct file___196 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___20 *, struct file___196 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___20 *, struct file___196 *, struct poll_table_struct___112 *);
	int (*hangup)(struct tty_struct___20 *);
	void (*receive_buf)(struct tty_struct___20 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___20 *);
	void (*dcd_change)(struct tty_struct___20 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___20 *, int);
};

struct tty_ldisc___20 {
	struct tty_ldisc_ops___20 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___20 *tty;
};

struct tty_port_operations___20 {
	int (*carrier_raised)(struct tty_port___20 *);
	void (*dtr_rts)(struct tty_port___20 *, int);
	void (*shutdown)(struct tty_port___20 *);
	void (*drop)(struct tty_port___20 *);
	int (*activate)(struct tty_port___20 *, struct tty_struct___20 *);
	void (*destruct)(struct tty_port___20 *);
};

struct xol_area___195 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___195 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___181;

struct memcg_cache_params___182;

struct kmem_cache___182 {
	struct kmem_cache_cpu___181 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___182 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___173;

struct vm_operations_struct___177 {
	void (*open)(struct vm_area_struct___204 *);
	void (*close)(struct vm_area_struct___204 *);
	int (*fault)(struct vm_area_struct___204 *, struct vm_fault___173 *);
	int (*page_mkwrite)(struct vm_area_struct___204 *, struct vm_fault___173 *);
	int (*access)(struct vm_area_struct___204 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___204 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___204 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___204 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___204 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___198 {
	struct task_struct___198 *task;
	struct core_thread___198 *next;
};

struct core_state___198 {
	atomic_t nr_threads;
	struct core_thread___198 dumper;
	struct completion startup;
};

struct vm_fault___173 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___195 *page;
};

struct consw___5;

struct vc_data___6 {
	struct tty_port___20 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___5 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___87 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___6 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct consw___5 {
	struct module *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___6 *, int);
	void (*con_deinit)(struct vc_data___6 *);
	void (*con_clear)(struct vc_data___6 *, int, int, int, int);
	void (*con_putc)(struct vc_data___6 *, int, int, int);
	void (*con_putcs)(struct vc_data___6 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___6 *, int);
	int (*con_scroll)(struct vc_data___6 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___6 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___6 *);
	int (*con_blank)(struct vc_data___6 *, int, int);
	int (*con_font_set)(struct vc_data___6 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___6 *, struct console_font *);
	int (*con_font_default)(struct vc_data___6 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___6 *, int);
	int (*con_resize)(struct vc_data___6 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___6 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___6 *, int);
	int (*con_set_origin)(struct vc_data___6 *);
	void (*con_save_screen)(struct vc_data___6 *);
	u8 (*con_build_attr)(struct vc_data___6 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___6 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___6 *, int);
	long unsigned int (*con_getxy)(struct vc_data___6 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___6 *);
	int (*con_debug_leave)(struct vc_data___6 *);
};

struct vc___5 {
	struct vc_data___6 *d;
	struct work_struct SAK_work;
};

struct vt_notifier_param {
	struct vc_data___6 *vc;
	unsigned int c;
};

struct bus_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___172 *, char *);
	ssize_t (*store)(struct bus_type___172 *, const char *, size_t);
};

struct device_attribute___172;

struct driver_attribute___172;

struct bus_type___172 {
	const char *name;
	const char *dev_name;
	struct device___172 *dev_root;
	struct bus_attribute___172 *bus_attrs;
	struct device_attribute___172 *dev_attrs;
	struct driver_attribute___172 *drv_attrs;
	const struct attribute_group___154 **bus_groups;
	const struct attribute_group___154 **dev_groups;
	const struct attribute_group___154 **drv_groups;
	int (*match)(struct device___172 *, struct device_driver___172 *);
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	int (*probe)(struct device___172 *);
	int (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*online)(struct device___172 *);
	int (*offline)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct device___172 *, struct device_attribute___172 *, char *);
	ssize_t (*store)(struct device___172 *, struct device_attribute___172 *, const char *, size_t);
};

struct driver_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___172 *, char *);
	ssize_t (*store)(struct device_driver___172 *, const char *, size_t);
};

struct device_driver___172 {
	const char *name;
	struct bus_type___172 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___172 *);
	int (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	const struct attribute_group___154 **groups;
	const struct dev_pm_ops___172 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___172 {
	const char *name;
	const struct attribute_group___154 **groups;
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
};

struct class_attribute___172;

struct class___172 {
	const char *name;
	struct module *owner;
	struct class_attribute___172 *class_attrs;
	struct device_attribute___172 *dev_attrs;
	const struct attribute_group___154 **dev_groups;
	struct bin_attribute___156 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *);
	void (*class_release)(struct class___172 *);
	void (*dev_release)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
	struct subsys_private *p;
};

struct class_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct class___172 *, struct class_attribute___172 *, char *);
	ssize_t (*store)(struct class___172 *, struct class_attribute___172 *, const char *, size_t);
	const void * (*namespace)(struct class___172 *, const struct class_attribute___172 *);
};

struct device_rh___172 {
	struct dev_pm_info_rh___172 power;
};

struct signal_struct___198 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___198 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___198 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___20 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___199 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct poll_table_struct___112 poll_table___23;

struct kmem_cache_cpu___181 {
	void **freelist;
	long unsigned int tid;
	struct page___195 *page;
	struct page___195 *partial;
};

struct memcg_cache_params___182 {
	bool is_root_cache;
	union {
		struct kmem_cache___182 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___182 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vcs_poll_data {
	struct notifier_block notifier;
	unsigned int cons_num;
	bool seen_last_update;
	wait_queue_head_t waitq;
	struct fasync_struct___196 *fasync;
};

struct consw___6;

struct vc_data___7 {
	struct tty_port port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___6 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___43 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___7 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct consw___6 {
	struct module___102 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___7 *, int);
	void (*con_deinit)(struct vc_data___7 *);
	void (*con_clear)(struct vc_data___7 *, int, int, int, int);
	void (*con_putc)(struct vc_data___7 *, int, int, int);
	void (*con_putcs)(struct vc_data___7 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___7 *, int);
	int (*con_scroll)(struct vc_data___7 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___7 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___7 *);
	int (*con_blank)(struct vc_data___7 *, int, int);
	int (*con_font_set)(struct vc_data___7 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___7 *, struct console_font *);
	int (*con_font_default)(struct vc_data___7 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___7 *, int);
	int (*con_resize)(struct vc_data___7 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___7 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___7 *, int);
	int (*con_set_origin)(struct vc_data___7 *);
	void (*con_save_screen)(struct vc_data___7 *);
	u8 (*con_build_attr)(struct vc_data___7 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___7 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___7 *, int);
	long unsigned int (*con_getxy)(struct vc_data___7 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___7 *);
	int (*con_debug_leave)(struct vc_data___7 *);
};

struct tiocl_selection {
	short unsigned int xs;
	short unsigned int ys;
	short unsigned int xe;
	short unsigned int ye;
	short unsigned int sel_mode;
};

struct vc_data___8;

struct keyboard_notifier_param {
	struct vc_data___8 *vc;
	int down;
	int shift;
	int ledstate;
	unsigned int value;
};

struct vc_data___8 {
	struct tty_port___6 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___3 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___28 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___8 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct kbd_struct {
	unsigned char lockstate;
	unsigned char slockstate;
	unsigned char ledmode: 2;
	unsigned char ledflagstate: 4;
	char: 2;
	unsigned char default_ledflagstate: 4;
	unsigned char kbdmode: 3;
	char: 1;
	unsigned char modeflags: 5;
};

struct kbdiacr {
	unsigned char diacr;
	unsigned char base;
	unsigned char result;
};

struct kbdiacrs {
	unsigned int kb_cnt;
	struct kbdiacr kbdiacr[256];
};

struct kbdiacruc {
	unsigned int diacr;
	unsigned int base;
	unsigned int result;
};

struct kbdiacrsuc {
	unsigned int kb_cnt;
	struct kbdiacruc kbdiacruc[256];
};

struct vc___6 {
	struct vc_data___8 *d;
	struct work_struct SAK_work;
};

struct ff_device___3;

struct input_handle___3;

struct input_dev___3 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___3 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___3 *, struct input_keymap_entry *);
	struct ff_device___3 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___3 *);
	void (*close)(struct input_dev___3 *);
	int (*flush)(struct input_dev___3 *, struct file___58 *);
	int (*event)(struct input_dev___3 *, unsigned int, unsigned int, int);
	struct input_handle___3 *grab;
	spinlock_t event_lock;
	struct mutex___59 mutex;
	unsigned int users;
	bool going_away;
	struct device___47 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___3 {
	int (*upload)(struct input_dev___3 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___3 *, int);
	int (*playback)(struct input_dev___3 *, int, int);
	void (*set_gain)(struct input_dev___3 *, u16);
	void (*set_autocenter)(struct input_dev___3 *, u16);
	void (*destroy)(struct ff_device___3 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___59 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___58 *effect_owners[0];
};

struct input_handler___3;

struct input_handle___3 {
	void *private;
	int open;
	const char *name;
	struct input_dev___3 *dev;
	struct input_handler___3 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___3 {
	void *private;
	void (*event)(struct input_handle___3 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___3 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___3 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___3 *, struct input_dev___3 *);
	int (*connect)(struct input_handler___3 *, struct input_dev___3 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___3 *);
	void (*start)(struct input_handle___3 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

typedef void k_handler_fn(struct vc_data___8 *, unsigned char, char);

typedef void fn_handler_fn(struct vc_data___8 *);

struct ledptr {
	unsigned int *addr;
	unsigned int mask;
	unsigned char valid: 1;
};

struct getset_keycode_data {
	struct input_keymap_entry ke;
	int error;
};

struct vc_data___9;

struct consw___7 {
	struct module *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___9 *, int);
	void (*con_deinit)(struct vc_data___9 *);
	void (*con_clear)(struct vc_data___9 *, int, int, int, int);
	void (*con_putc)(struct vc_data___9 *, int, int, int);
	void (*con_putcs)(struct vc_data___9 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___9 *, int);
	int (*con_scroll)(struct vc_data___9 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___9 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___9 *);
	int (*con_blank)(struct vc_data___9 *, int, int);
	int (*con_font_set)(struct vc_data___9 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___9 *, struct console_font *);
	int (*con_font_default)(struct vc_data___9 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___9 *, int);
	int (*con_resize)(struct vc_data___9 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___9 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___9 *, int);
	int (*con_set_origin)(struct vc_data___9 *);
	void (*con_save_screen)(struct vc_data___9 *);
	u8 (*con_build_attr)(struct vc_data___9 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___9 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___9 *, int);
	long unsigned int (*con_getxy)(struct vc_data___9 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___9 *);
	int (*con_debug_leave)(struct vc_data___9 *);
};

struct vc_data___9 {
	struct tty_port___4 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___7 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___43 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___9 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct vc___7 {
	struct vc_data___9 *d;
	struct work_struct SAK_work;
};

struct uni_pagedir {
	u16 **uni_pgdir[32];
	long unsigned int refcount;
	long unsigned int sum;
	unsigned char *inverse_translations[4];
	u16 *inverse_trans_unicode;
	int readonly;
};

struct vc_data___10;

struct consw___8 {
	struct module___37 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___10 *, int);
	void (*con_deinit)(struct vc_data___10 *);
	void (*con_clear)(struct vc_data___10 *, int, int, int, int);
	void (*con_putc)(struct vc_data___10 *, int, int, int);
	void (*con_putcs)(struct vc_data___10 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___10 *, int);
	int (*con_scroll)(struct vc_data___10 *, int, int, int, int);
	void (*con_bmove)(struct vc_data___10 *, int, int, int, int, int, int);
	int (*con_switch)(struct vc_data___10 *);
	int (*con_blank)(struct vc_data___10 *, int, int);
	int (*con_font_set)(struct vc_data___10 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___10 *, struct console_font *);
	int (*con_font_default)(struct vc_data___10 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___10 *, int);
	int (*con_resize)(struct vc_data___10 *, unsigned int, unsigned int, unsigned int);
	int (*con_set_palette)(struct vc_data___10 *, unsigned char *);
	int (*con_scrolldelta)(struct vc_data___10 *, int);
	int (*con_set_origin)(struct vc_data___10 *);
	void (*con_save_screen)(struct vc_data___10 *);
	u8 (*con_build_attr)(struct vc_data___10 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___10 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___10 *, int);
	long unsigned int (*con_getxy)(struct vc_data___10 *, long unsigned int, int *, int *);
	int (*con_debug_enter)(struct vc_data___10 *);
	int (*con_debug_leave)(struct vc_data___10 *);
};

struct vc_data___10 {
	struct tty_port___6 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___8 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___28 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_deccolm: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	struct vc_data___10 **vc_display_fg;
	long unsigned int vc_uni_pagedir;
	long unsigned int *vc_uni_pagedir_loc;
	bool vc_panic_force_write;
};

struct console___5 {
	char name[16];
	void (*write)(struct console___5 *, const char *, unsigned int);
	int (*read)(struct console___5 *, char *, unsigned int);
	struct tty_driver___6 * (*device)(struct console___5 *, int *);
	void (*unblank)();
	int (*setup)(struct console___5 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___5 *next;
};

struct vc___8 {
	struct vc_data___10 *d;
	struct work_struct SAK_work;
};

struct vt_notifier_param___2 {
	struct vc_data___10 *vc;
	unsigned int c;
};

struct con_driver {
	const struct consw___8 *con;
	const char *desc;
	struct device___47 *dev;
	int node;
	int first;
	int last;
	int flag;
};

enum {
	blank_off = 0,
	blank_normal_wait = 1,
	blank_vesa_wait = 2,
};

enum {
	ESnormal = 0,
	ESesc = 1,
	ESsquare = 2,
	ESgetpars = 3,
	ESgotpars = 4,
	ESfunckey = 5,
	EShash = 6,
	ESsetG0 = 7,
	ESsetG1 = 8,
	ESpercent = 9,
	ESignore = 10,
	ESnonstd = 11,
	ESpalette = 12,
};

struct interval {
	uint32_t first;
	uint32_t last;
};

struct console___6 {
	char name[16];
	void (*write)(struct console___6 *, const char *, unsigned int);
	int (*read)(struct console___6 *, char *, unsigned int);
	struct tty_driver * (*device)(struct console___6 *, int *);
	void (*unblank)();
	int (*setup)(struct console___6 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___6 *next;
};

struct hv_ops;

struct hvc_struct {
	struct tty_port port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
};

struct hv_ops {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*notifier_add)(struct hvc_struct *, int);
	void (*notifier_del)(struct hvc_struct *, int);
	void (*notifier_hangup)(struct hvc_struct *, int);
	int (*tiocmget)(struct hvc_struct *);
	int (*tiocmset)(struct hvc_struct *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct *, int);
};

struct tty_struct___21;

struct tty_driver___21;

struct tty_operations___21 {
	struct tty_struct___21 * (*lookup)(struct tty_driver___21 *, struct inode___35 *, int);
	int (*install)(struct tty_driver___21 *, struct tty_struct___21 *);
	void (*remove)(struct tty_driver___21 *, struct tty_struct___21 *);
	int (*open)(struct tty_struct___21 *, struct file___34 *);
	void (*close)(struct tty_struct___21 *, struct file___34 *);
	void (*shutdown)(struct tty_struct___21 *);
	void (*cleanup)(struct tty_struct___21 *);
	int (*write)(struct tty_struct___21 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___21 *, unsigned char);
	void (*flush_chars)(struct tty_struct___21 *);
	int (*write_room)(struct tty_struct___21 *);
	int (*chars_in_buffer)(struct tty_struct___21 *);
	int (*ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	void (*throttle)(struct tty_struct___21 *);
	void (*unthrottle)(struct tty_struct___21 *);
	void (*stop)(struct tty_struct___21 *);
	void (*start)(struct tty_struct___21 *);
	void (*hangup)(struct tty_struct___21 *);
	int (*break_ctl)(struct tty_struct___21 *, int);
	void (*flush_buffer)(struct tty_struct___21 *);
	void (*set_ldisc)(struct tty_struct___21 *);
	void (*wait_until_sent)(struct tty_struct___21 *, int);
	void (*send_xchar)(struct tty_struct___21 *, char);
	int (*tiocmget)(struct tty_struct___21 *);
	int (*tiocmset)(struct tty_struct___21 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___21 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___21 *, struct termiox *);
	int (*get_icount)(struct tty_struct___21 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___21 *, int, char *);
	int (*poll_get_char)(struct tty_driver___21 *, int);
	void (*poll_put_char)(struct tty_driver___21 *, int, char);
	const struct file_operations___34 *proc_fops;
};

struct tty_ldisc___21;

struct tty_port___21;

struct tty_struct___21 {
	int magic;
	struct kref kref;
	struct device___31 *dev;
	struct tty_driver___21 *driver;
	const struct tty_operations___21 *ops;
	int index;
	struct mutex___194 ldisc_mutex;
	struct tty_ldisc___21 *ldisc;
	struct mutex___194 atomic_write_lock;
	struct mutex___194 legacy_mutex;
	struct mutex___194 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___16 *pgrp;
	struct pid___16 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___21 *link;
	struct fasync_struct___34 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___21 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___21 {
	int magic;
	struct kref kref;
	struct cdev___16 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___21 *other;
	struct tty_struct___21 **ttys;
	struct tty_port___21 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___21 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___21;

struct tty_port___21 {
	struct tty_bufhead buf;
	struct tty_struct___21 *tty;
	struct tty_struct___21 *itty;
	const struct tty_port_operations___21 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___194 mutex;
	struct mutex___194 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___21 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___21 *);
	void (*close)(struct tty_struct___21 *);
	void (*flush_buffer)(struct tty_struct___21 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___21 *);
	ssize_t (*read)(struct tty_struct___21 *, struct file___34 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___21 *, struct file___34 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___21 *, struct file___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___21 *, struct file___34 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___21 *, struct file___34 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___21 *);
	void (*receive_buf)(struct tty_struct___21 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___21 *);
	void (*dcd_change)(struct tty_struct___21 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___21 *, int);
};

struct tty_ldisc___21 {
	struct tty_ldisc_ops___21 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___21 *tty;
};

struct tty_port_operations___21 {
	int (*carrier_raised)(struct tty_port___21 *);
	void (*dtr_rts)(struct tty_port___21 *, int);
	void (*shutdown)(struct tty_port___21 *);
	void (*drop)(struct tty_port___21 *);
	int (*activate)(struct tty_port___21 *, struct tty_struct___21 *);
	void (*destruct)(struct tty_port___21 *);
};

struct hv_ops___2;

struct hvc_struct___2 {
	struct tty_port___21 port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops___2 *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
};

struct hv_ops___2 {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*notifier_add)(struct hvc_struct___2 *, int);
	void (*notifier_del)(struct hvc_struct___2 *, int);
	void (*notifier_hangup)(struct hvc_struct___2 *, int);
	int (*tiocmget)(struct hvc_struct___2 *);
	int (*tiocmset)(struct hvc_struct___2 *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct___2 *, int);
};

struct tty_driver___22;

struct console___7 {
	char name[16];
	void (*write)(struct console___7 *, const char *, unsigned int);
	int (*read)(struct console___7 *, char *, unsigned int);
	struct tty_driver___22 * (*device)(struct console___7 *, int *);
	void (*unblank)();
	int (*setup)(struct console___7 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___7 *next;
};

struct cdev___51;

struct tty_struct___22;

struct tty_port___22;

struct tty_operations___22;

struct tty_driver___22 {
	int magic;
	struct kref kref;
	struct cdev___51 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___22 *other;
	struct tty_struct___22 **ttys;
	struct tty_port___22 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___22 *ops;
	struct list_head tty_drivers;
};

struct page___196;

typedef struct page___196 *pgtable_t___196;

struct address_space___197;

struct kmem_cache___183;

struct page___196 {
	long unsigned int flags;
	struct address_space___197 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___196 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___196 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___183 *slab_cache;
		struct page___196 *first_page;
	};
	long: 64;
};

struct mm_struct___205;

struct pv_mmu_ops___205 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___205 *, struct mm_struct___205 *);
	void (*dup_mmap)(struct mm_struct___205 *, struct mm_struct___205 *);
	void (*exit_mmap)(struct mm_struct___205 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___205 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___205 *);
	void (*pgd_free)(struct mm_struct___205 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___205 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___205 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___205 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___205 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___205 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___205 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___205 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___205 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___205 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___205 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___205 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct xol_area___196;

struct uprobes_state___196 {
	struct xol_area___196 *xol_area;
};

struct vm_area_struct___205;

struct file___197;

struct mm_struct___205 {
	struct vm_area_struct___205 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___205 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___205 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___194 context;
	long unsigned int flags;
	struct core_state___198 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct *owner;
	struct file___197 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___196 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct device___173;

struct dev_pm_ops___173 {
	int (*prepare)(struct device___173 *);
	void (*complete)(struct device___173 *);
	int (*suspend)(struct device___173 *);
	int (*resume)(struct device___173 *);
	int (*freeze)(struct device___173 *);
	int (*thaw)(struct device___173 *);
	int (*poweroff)(struct device___173 *);
	int (*restore)(struct device___173 *);
	int (*suspend_late)(struct device___173 *);
	int (*resume_early)(struct device___173 *);
	int (*freeze_late)(struct device___173 *);
	int (*thaw_early)(struct device___173 *);
	int (*poweroff_late)(struct device___173 *);
	int (*restore_early)(struct device___173 *);
	int (*suspend_noirq)(struct device___173 *);
	int (*resume_noirq)(struct device___173 *);
	int (*freeze_noirq)(struct device___173 *);
	int (*thaw_noirq)(struct device___173 *);
	int (*poweroff_noirq)(struct device___173 *);
	int (*restore_noirq)(struct device___173 *);
	int (*runtime_suspend)(struct device___173 *);
	int (*runtime_resume)(struct device___173 *);
	int (*runtime_idle)(struct device___173 *);
};

struct device_type___173;

struct bus_type___173;

struct device_driver___173;

struct dev_pm_domain___173;

struct class___173;

struct attribute_group___155;

struct device_rh___173;

struct device___173 {
	struct device___173 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___173 *type;
	struct mutex___194 mutex;
	struct bus_type___173 *bus;
	struct device_driver___173 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___173 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___173 *class;
	const struct attribute_group___155 **groups;
	void (*release)(struct device___173 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___173 *device_rh;
};

struct dev_pm_info_rh___173 {
	void (*set_latency_tolerance)(struct device___173 *, s32);
};

struct dev_pm_domain___173 {
	struct dev_pm_ops___173 ops;
};

struct xol_area___196 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___196 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___182;

struct memcg_cache_params___183;

struct kmem_cache___183 {
	struct kmem_cache_cpu___182 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___183 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___197;

struct address_space_operations___197;

struct address_space___197 {
	struct inode___197 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___194 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___197 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___197;

struct path___197 {
	struct vfsmount *mnt;
	struct dentry___197 *dentry;
};

struct file_operations___197;

struct file___197 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___197 f_path;
	struct inode___197 *f_inode;
	const struct file_operations___197 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___197 *f_mapping;
	struct mutex___194 f_pos_lock;
};

struct vm_operations_struct___178;

struct vm_area_struct___205 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___205 *vm_next;
	struct vm_area_struct___205 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___205 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___178 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___197 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___174;

struct vm_operations_struct___178 {
	void (*open)(struct vm_area_struct___205 *);
	void (*close)(struct vm_area_struct___205 *);
	int (*fault)(struct vm_area_struct___205 *, struct vm_fault___174 *);
	int (*page_mkwrite)(struct vm_area_struct___205 *, struct vm_fault___174 *);
	int (*access)(struct vm_area_struct___205 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___205 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___205 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___205 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___205 *, long unsigned int, long unsigned int, long unsigned int);
};

struct vm_fault___174 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___196 *page;
};

typedef uint32_t XENCONS_RING_IDX;

struct xencons_interface {
	char in[1024];
	char out[2048];
	XENCONS_RING_IDX in_cons;
	XENCONS_RING_IDX in_prod;
	XENCONS_RING_IDX out_cons;
	XENCONS_RING_IDX out_prod;
};

struct bin_attribute___157;

struct attribute_group___155 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___157 **bin_attrs;
};

struct bin_attribute___157 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___197 *, struct kobject___20 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___197 *, struct kobject___20 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	int (*mmap)(struct file___197 *, struct kobject___20 *, struct bin_attribute___157 *, struct vm_area_struct___205 *);
};

struct bus_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___173 *, char *);
	ssize_t (*store)(struct bus_type___173 *, const char *, size_t);
};

struct device_attribute___173;

struct driver_attribute___173;

struct bus_type___173 {
	const char *name;
	const char *dev_name;
	struct device___173 *dev_root;
	struct bus_attribute___173 *bus_attrs;
	struct device_attribute___173 *dev_attrs;
	struct driver_attribute___173 *drv_attrs;
	const struct attribute_group___155 **bus_groups;
	const struct attribute_group___155 **dev_groups;
	const struct attribute_group___155 **drv_groups;
	int (*match)(struct device___173 *, struct device_driver___173 *);
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	int (*probe)(struct device___173 *);
	int (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*online)(struct device___173 *);
	int (*offline)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct device___173 *, struct device_attribute___173 *, char *);
	ssize_t (*store)(struct device___173 *, struct device_attribute___173 *, const char *, size_t);
};

struct driver_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___173 *, char *);
	ssize_t (*store)(struct device_driver___173 *, const char *, size_t);
};

struct device_driver___173 {
	const char *name;
	struct bus_type___173 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___173 *);
	int (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	const struct attribute_group___155 **groups;
	const struct dev_pm_ops___173 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___173 {
	const char *name;
	const struct attribute_group___155 **groups;
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
};

struct class_attribute___173;

struct class___173 {
	const char *name;
	struct module *owner;
	struct class_attribute___173 *class_attrs;
	struct device_attribute___173 *dev_attrs;
	const struct attribute_group___155 **dev_groups;
	struct bin_attribute___157 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *);
	void (*class_release)(struct class___173 *);
	void (*dev_release)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
	struct subsys_private *p;
};

struct class_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct class___173 *, struct class_attribute___173 *, char *);
	ssize_t (*store)(struct class___173 *, struct class_attribute___173 *, const char *, size_t);
	const void * (*namespace)(struct class___173 *, const struct class_attribute___173 *);
};

struct device_rh___173 {
	struct dev_pm_info_rh___173 power;
};

struct kmem_cache_cpu___182 {
	void **freelist;
	long unsigned int tid;
	struct page___196 *page;
	struct page___196 *partial;
};

struct memcg_cache_params___183 {
	bool is_root_cache;
	union {
		struct kmem_cache___183 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___183 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xenbus_device___3 {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___173 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
};

struct xenbus_driver___2 {
	const struct xenbus_device_id *ids;
	int (*probe)(struct xenbus_device___3 *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device___3 *, enum xenbus_state);
	int (*remove)(struct xenbus_device___3 *);
	int (*suspend)(struct xenbus_device___3 *);
	int (*resume)(struct xenbus_device___3 *);
	int (*uevent)(struct xenbus_device___3 *, struct kobj_uevent_env *);
	struct device_driver___173 driver;
	int (*read_otherend_details)(struct xenbus_device___3 *);
	int (*is_ready)(struct xenbus_device___3 *);
};

struct dentry_operations___197;

struct super_block___197;

struct dentry___197 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___197 *d_parent;
	struct qstr d_name;
	struct inode___197 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___197 *d_op;
	struct super_block___197 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___197;

struct file_lock___197;

struct dquot___197;

struct block_device___197;

struct inode___197 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___197 *i_op;
	struct super_block___197 *i_sb;
	struct address_space___197 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___194 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___197 *i_fop;
	struct file_lock___197 *i_flock;
	struct address_space___197 i_data;
	struct dquot___197 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___197 *i_bdev;
		struct cdev___51 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___197 {
	int (*d_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_hash)(const struct dentry___197 *, struct qstr *);
	int (*d_compare)(const struct dentry___197 *, const struct dentry___197 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___197 *);
	void (*d_release)(struct dentry___197 *);
	void (*d_prune)(struct dentry___197 *);
	void (*d_iput)(struct dentry___197 *, struct inode___197 *);
	char * (*d_dname)(struct dentry___197 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___197 *);
	int (*d_manage)(struct dentry___197 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___197;

struct mem_dqinfo___197 {
	struct quota_format_type___197 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___197;

struct quota_info___197 {
	unsigned int flags;
	struct mutex___194 dqio_mutex;
	struct mutex___194 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___197 *files[2];
	struct mem_dqinfo___197 info[2];
	const struct quota_format_ops___197 *ops[2];
};

struct file_system_type___197;

struct super_operations___197;

struct dquot_operations___197;

struct quotactl_ops___197;

struct super_block___197 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___197 *s_type;
	const struct super_operations___197 *s_op;
	const struct dquot_operations___197 *dq_op;
	const struct quotactl_ops___197 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___197 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___197 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___197 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___194 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___197 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___197 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___197 *bd_inode;
	struct super_block___197 *bd_super;
	struct mutex___194 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___197 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___194 bd_fsfreeze_mutex;
};

struct iattr___197 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___197 *ia_file;
};

struct dquot___197 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___194 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___197 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___197 {
	int qf_fmt_id;
	const struct quota_format_ops___197 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___197 *qf_next;
};

struct quota_format_ops___197 {
	int (*check_quota_file)(struct super_block___197 *, int);
	int (*read_file_info)(struct super_block___197 *, int);
	int (*write_file_info)(struct super_block___197 *, int);
	int (*free_file_info)(struct super_block___197 *, int);
	int (*read_dqblk)(struct dquot___197 *);
	int (*commit_dqblk)(struct dquot___197 *);
	int (*release_dqblk)(struct dquot___197 *);
};

struct dquot_operations___197 {
	int (*write_dquot)(struct dquot___197 *);
	struct dquot___197 * (*alloc_dquot)(struct super_block___197 *, int);
	void (*destroy_dquot)(struct dquot___197 *);
	int (*acquire_dquot)(struct dquot___197 *);
	int (*release_dquot)(struct dquot___197 *);
	int (*mark_dirty)(struct dquot___197 *);
	int (*write_info)(struct super_block___197 *, int);
	qsize_t * (*get_reserved_space)(struct inode___197 *);
};

struct quotactl_ops___197 {
	int (*quota_on)(struct super_block___197 *, int, int, struct path___197 *);
	int (*quota_on_meta)(struct super_block___197 *, int, int);
	int (*quota_off)(struct super_block___197 *, int);
	int (*quota_sync)(struct super_block___197 *, int);
	int (*get_info)(struct super_block___197 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___197 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___197 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___197 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___197 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___197 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___197 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___197 *, unsigned int);
};

struct address_space_operations___197 {
	int (*writepage)(struct page___196 *, struct writeback_control *);
	int (*readpage)(struct file___197 *, struct page___196 *);
	int (*writepages)(struct address_space___197 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___196 *);
	int (*readpages)(struct file___197 *, struct address_space___197 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___197 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___196 **, void **);
	int (*write_end)(struct file___197 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___196 *, void *);
	sector_t (*bmap)(struct address_space___197 *, sector_t);
	void (*invalidatepage)(struct page___196 *, long unsigned int);
	int (*releasepage)(struct page___196 *, gfp_t);
	void (*freepage)(struct page___196 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___197 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___197 *, struct page___196 *, struct page___196 *, enum migrate_mode);
	int (*launder_page)(struct page___196 *);
	int (*is_partially_uptodate)(struct page___196 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___196 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___197 *, struct page___196 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___197 *, sector_t *);
	void (*swap_deactivate)(struct file___197 *);
	void (*invalidatepage_range)(struct page___196 *, unsigned int, unsigned int);
};

struct cdev___51 {
	struct kobject___20 kobj;
	struct module *owner;
	const struct file_operations___197 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___197 {
	struct dentry___197 * (*lookup)(struct inode___197 *, struct dentry___197 *, unsigned int);
	void * (*follow_link)(struct dentry___197 *, struct nameidata *);
	int (*permission)(struct inode___197 *, int);
	struct posix_acl * (*get_acl)(struct inode___197 *, int);
	int (*readlink)(struct dentry___197 *, char *, int);
	void (*put_link)(struct dentry___197 *, struct nameidata *, void *);
	int (*create)(struct inode___197 *, struct dentry___197 *, umode_t, bool);
	int (*link)(struct dentry___197 *, struct inode___197 *, struct dentry___197 *);
	int (*unlink)(struct inode___197 *, struct dentry___197 *);
	int (*symlink)(struct inode___197 *, struct dentry___197 *, const char *);
	int (*mkdir)(struct inode___197 *, struct dentry___197 *, umode_t);
	int (*rmdir)(struct inode___197 *, struct dentry___197 *);
	int (*mknod)(struct inode___197 *, struct dentry___197 *, umode_t, dev_t);
	int (*rename)(struct inode___197 *, struct dentry___197 *, struct inode___197 *, struct dentry___197 *);
	int (*setattr)(struct dentry___197 *, struct iattr___197 *);
	int (*getattr)(struct vfsmount *, struct dentry___197 *, struct kstat *);
	int (*setxattr)(struct dentry___197 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___197 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___197 *, char *, size_t);
	int (*removexattr)(struct dentry___197 *, const char *);
	int (*fiemap)(struct inode___197 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___197 *, struct timespec *, int);
	int (*atomic_open)(struct inode___197 *, struct dentry___197 *, struct file___197 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___197 {
	struct module *owner;
	loff_t (*llseek)(struct file___197 *, loff_t, int);
	ssize_t (*read)(struct file___197 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___197 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___197 *, void *, filldir_t);
	unsigned int (*poll)(struct file___197 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___197 *, struct vm_area_struct___205 *);
	int (*open)(struct inode___197 *, struct file___197 *);
	int (*flush)(struct file___197 *, fl_owner_t);
	int (*release)(struct inode___197 *, struct file___197 *);
	int (*fsync)(struct file___197 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___197 *, int);
	int (*lock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*sendpage)(struct file___197 *, struct page___196 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___197 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___197 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___197 *, long int, struct file_lock___197 **, void **);
		struct {
			int (*setlease)(struct file___197 *, long int, struct file_lock___197 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___197 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___197 *);
};

struct fasync_struct___197;

struct file_lock_operations___197;

struct lock_manager_operations___197;

struct file_lock___197 {
	struct file_lock___197 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___197 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___197 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___197 *fl_ops;
	const struct lock_manager_operations___197 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___197 {
	void (*fl_copy_lock)(struct file_lock___197 *, struct file_lock___197 *);
	void (*fl_release_private)(struct file_lock___197 *);
};

struct lock_manager_operations___197 {
	int (*lm_compare_owner)(struct file_lock___197 *, struct file_lock___197 *);
	long unsigned int (*lm_owner_key)(struct file_lock___197 *);
	void (*lm_notify)(struct file_lock___197 *);
	int (*lm_grant)(struct file_lock___197 *, struct file_lock___197 *, int);
	void (*lm_break)(struct file_lock___197 *);
	int (*lm_change)(struct file_lock___197 **, int);
};

struct fasync_struct___197 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___197 *fa_next;
	struct file___197 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___197 {
	const char *name;
	int fs_flags;
	struct dentry___197 * (*mount)(struct file_system_type___197 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___197 *);
	struct module *owner;
	struct file_system_type___197 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___197 {
	struct inode___197 * (*alloc_inode)(struct super_block___197 *);
	void (*destroy_inode)(struct inode___197 *);
	void (*dirty_inode)(struct inode___197 *, int);
	int (*write_inode)(struct inode___197 *, struct writeback_control *);
	int (*drop_inode)(struct inode___197 *);
	void (*evict_inode)(struct inode___197 *);
	void (*put_super)(struct super_block___197 *);
	int (*sync_fs)(struct super_block___197 *, int);
	int (*freeze_fs)(struct super_block___197 *);
	int (*unfreeze_fs)(struct super_block___197 *);
	int (*statfs)(struct dentry___197 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___197 *, int *, char *);
	void (*umount_begin)(struct super_block___197 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___197 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___197 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___197 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___197 *);
	ssize_t (*quota_read)(struct super_block___197 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___197 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___197 *);
	int (*bdev_try_to_free_page)(struct super_block___197 *, struct page___196 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___197 *);
	void (*free_cached_objects)(struct super_block___197 *, int);
};

struct tty_operations___22 {
	struct tty_struct___22 * (*lookup)(struct tty_driver___22 *, struct inode___197 *, int);
	int (*install)(struct tty_driver___22 *, struct tty_struct___22 *);
	void (*remove)(struct tty_driver___22 *, struct tty_struct___22 *);
	int (*open)(struct tty_struct___22 *, struct file___197 *);
	void (*close)(struct tty_struct___22 *, struct file___197 *);
	void (*shutdown)(struct tty_struct___22 *);
	void (*cleanup)(struct tty_struct___22 *);
	int (*write)(struct tty_struct___22 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___22 *, unsigned char);
	void (*flush_chars)(struct tty_struct___22 *);
	int (*write_room)(struct tty_struct___22 *);
	int (*chars_in_buffer)(struct tty_struct___22 *);
	int (*ioctl)(struct tty_struct___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___22 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___22 *, struct ktermios *);
	void (*throttle)(struct tty_struct___22 *);
	void (*unthrottle)(struct tty_struct___22 *);
	void (*stop)(struct tty_struct___22 *);
	void (*start)(struct tty_struct___22 *);
	void (*hangup)(struct tty_struct___22 *);
	int (*break_ctl)(struct tty_struct___22 *, int);
	void (*flush_buffer)(struct tty_struct___22 *);
	void (*set_ldisc)(struct tty_struct___22 *);
	void (*wait_until_sent)(struct tty_struct___22 *, int);
	void (*send_xchar)(struct tty_struct___22 *, char);
	int (*tiocmget)(struct tty_struct___22 *);
	int (*tiocmset)(struct tty_struct___22 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___22 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___22 *, struct termiox *);
	int (*get_icount)(struct tty_struct___22 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___22 *, int, char *);
	int (*poll_get_char)(struct tty_driver___22 *, int);
	void (*poll_put_char)(struct tty_driver___22 *, int, char);
	const struct file_operations___197 *proc_fops;
};

struct tty_ldisc___22;

struct tty_struct___22 {
	int magic;
	struct kref kref;
	struct device___173 *dev;
	struct tty_driver___22 *driver;
	const struct tty_operations___22 *ops;
	int index;
	struct mutex___194 ldisc_mutex;
	struct tty_ldisc___22 *ldisc;
	struct mutex___194 atomic_write_lock;
	struct mutex___194 legacy_mutex;
	struct mutex___194 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___22 *link;
	struct fasync_struct___197 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___22 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_port_operations___22;

struct tty_port___22 {
	struct tty_bufhead buf;
	struct tty_struct___22 *tty;
	struct tty_struct___22 *itty;
	const struct tty_port_operations___22 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___194 mutex;
	struct mutex___194 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___22 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___22 *);
	void (*close)(struct tty_struct___22 *);
	void (*flush_buffer)(struct tty_struct___22 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___22 *);
	ssize_t (*read)(struct tty_struct___22 *, struct file___197 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___22 *, struct file___197 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___22 *, struct file___197 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___22 *, struct file___197 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___22 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___22 *, struct file___197 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___22 *);
	void (*receive_buf)(struct tty_struct___22 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___22 *);
	void (*dcd_change)(struct tty_struct___22 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___22 *, int);
};

struct tty_ldisc___22 {
	struct tty_ldisc_ops___22 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___22 *tty;
};

struct tty_port_operations___22 {
	int (*carrier_raised)(struct tty_port___22 *);
	void (*dtr_rts)(struct tty_port___22 *, int);
	void (*shutdown)(struct tty_port___22 *);
	void (*drop)(struct tty_port___22 *);
	int (*activate)(struct tty_port___22 *, struct tty_struct___22 *);
	void (*destruct)(struct tty_port___22 *);
};

struct hv_ops___3;

struct hvc_struct___3 {
	struct tty_port___22 port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops___3 *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
};

struct hv_ops___3 {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*notifier_add)(struct hvc_struct___3 *, int);
	void (*notifier_del)(struct hvc_struct___3 *, int);
	void (*notifier_hangup)(struct hvc_struct___3 *, int);
	int (*tiocmget)(struct hvc_struct___3 *);
	int (*tiocmset)(struct hvc_struct___3 *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct___3 *, int);
};

struct xencons_info {
	struct list_head list;
	struct xenbus_device___3 *xbdev;
	struct xencons_interface *intf;
	unsigned int evtchn;
	struct hvc_struct___3 *hvc;
	int irq;
	int vtermno;
	grant_ref_t gntref;
};

struct page___197;

typedef struct page___197 *pgtable_t___197;

struct address_space___198;

struct kmem_cache___184;

struct page___197 {
	long unsigned int flags;
	struct address_space___198 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___197 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___197 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___184 *slab_cache;
		struct page___197 *first_page;
	};
	long: 64;
};

struct task_struct___199;

struct pv_cpu_ops___199 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___199 *);
	void (*end_context_switch)(struct task_struct___199 *);
};

struct mutex___200 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___199 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___192 {
	struct page___197 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___206;

struct signal_struct___199;

struct task_struct___199 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___199 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___206 *mm;
	struct mm_struct___206 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___199 *real_parent;
	struct task_struct___199 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___199 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___199 = 0,
		VTIME_USER___199 = 1,
		VTIME_SYS___199 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___199 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___200 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___192 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___206 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___206 *, struct mm_struct___206 *);
	void (*dup_mmap)(struct mm_struct___206 *, struct mm_struct___206 *);
	void (*exit_mmap)(struct mm_struct___206 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___206 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___206 *);
	void (*pgd_free)(struct mm_struct___206 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___206 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___206 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___206 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___206 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___206 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___206 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___206 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___206 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___206 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___206 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___206 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___200 lock;
	void *vdso;
} mm_context_t___200;

struct xol_area___197;

struct uprobes_state___197 {
	struct xol_area___197 *xol_area;
};

struct vm_area_struct___206;

struct file___198;

struct core_state___199;

struct mm_struct___206 {
	struct vm_area_struct___206 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___206 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___206 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___200 context;
	long unsigned int flags;
	struct core_state___199 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___199 *owner;
	struct file___198 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___197 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___112;

struct exec_domain___51 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___112 *module;
	struct exec_domain___51 *next;
};

struct module_kobject___111 {
	struct kobject___20 kobj;
	struct module___112 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___111;

struct module___112 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___111 mkobj;
	struct module_attribute___111 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___199 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___90 {
	struct task_struct___199 *task;
	struct exec_domain___51 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___199;

struct lruvec___199 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___199 *zone;
};

struct pglist_data___199;

struct zone___199 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___199 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___199 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___199 {
	struct zone___199 *zone;
	int zone_idx;
};

struct zonelist___199 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___199 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___199 {
	struct zone___199 node_zones[4];
	struct zonelist___199 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___199 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___132;

struct x86_io_apic_ops___132 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___132 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___132;

struct irq_data___132 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___132 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___174;

struct dev_pm_ops___174 {
	int (*prepare)(struct device___174 *);
	void (*complete)(struct device___174 *);
	int (*suspend)(struct device___174 *);
	int (*resume)(struct device___174 *);
	int (*freeze)(struct device___174 *);
	int (*thaw)(struct device___174 *);
	int (*poweroff)(struct device___174 *);
	int (*restore)(struct device___174 *);
	int (*suspend_late)(struct device___174 *);
	int (*resume_early)(struct device___174 *);
	int (*freeze_late)(struct device___174 *);
	int (*thaw_early)(struct device___174 *);
	int (*poweroff_late)(struct device___174 *);
	int (*restore_early)(struct device___174 *);
	int (*suspend_noirq)(struct device___174 *);
	int (*resume_noirq)(struct device___174 *);
	int (*freeze_noirq)(struct device___174 *);
	int (*thaw_noirq)(struct device___174 *);
	int (*poweroff_noirq)(struct device___174 *);
	int (*restore_noirq)(struct device___174 *);
	int (*runtime_suspend)(struct device___174 *);
	int (*runtime_resume)(struct device___174 *);
	int (*runtime_idle)(struct device___174 *);
};

struct device_type___174;

struct bus_type___174;

struct device_driver___174;

struct dev_pm_domain___174;

struct class___174;

struct attribute_group___156;

struct device_rh___174;

struct device___174 {
	struct device___174 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___174 *type;
	struct mutex___200 mutex;
	struct bus_type___174 *bus;
	struct device_driver___174 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___174 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___174 *class;
	const struct attribute_group___156 **groups;
	void (*release)(struct device___174 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___174 *device_rh;
};

struct dev_pm_info_rh___174 {
	void (*set_latency_tolerance)(struct device___174 *, s32);
};

struct dev_pm_domain___174 {
	struct dev_pm_ops___174 ops;
};

struct smp_ops___199 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___199 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___158;

struct attribute_group___156 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___158 **bin_attrs;
};

struct bin_attribute___158 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___198 *, struct kobject___20 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___198 *, struct kobject___20 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	int (*mmap)(struct file___198 *, struct kobject___20 *, struct bin_attribute___158 *, struct vm_area_struct___206 *);
};

struct dentry___198;

struct path___198 {
	struct vfsmount *mnt;
	struct dentry___198 *dentry;
};

struct inode___198;

struct file_operations___198;

struct file___198 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___198 f_path;
	struct inode___198 *f_inode;
	const struct file_operations___198 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___198 *f_mapping;
	struct mutex___200 f_pos_lock;
};

struct vm_area_struct___206 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___206 *vm_next;
	struct vm_area_struct___206 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___206 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___198 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___111 *, struct module_kobject___111 *, char *);
	ssize_t (*store)(struct module_attribute___111 *, struct module_kobject___111 *, const char *, size_t);
	void (*setup)(struct module___112 *, const char *);
	int (*test)(struct module___112 *);
	void (*free)(struct module___112 *);
};

struct dentry_operations___198;

struct super_block___198;

struct dentry___198 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___198 *d_parent;
	struct qstr d_name;
	struct inode___198 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___198 *d_op;
	struct super_block___198 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___198;

struct address_space___198 {
	struct inode___198 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___200 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___198 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___198;

struct file_lock___198;

struct dquot___198;

struct block_device___198;

struct cdev___52;

struct inode___198 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___198 *i_op;
	struct super_block___198 *i_sb;
	struct address_space___198 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___200 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___198 *i_fop;
	struct file_lock___198 *i_flock;
	struct address_space___198 i_data;
	struct dquot___198 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___198 *i_bdev;
		struct cdev___52 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___198 {
	int (*d_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_hash)(const struct dentry___198 *, struct qstr *);
	int (*d_compare)(const struct dentry___198 *, const struct dentry___198 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___198 *);
	void (*d_release)(struct dentry___198 *);
	void (*d_prune)(struct dentry___198 *);
	void (*d_iput)(struct dentry___198 *, struct inode___198 *);
	char * (*d_dname)(struct dentry___198 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___198 *);
	int (*d_manage)(struct dentry___198 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___198;

struct mem_dqinfo___198 {
	struct quota_format_type___198 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___198;

struct quota_info___198 {
	unsigned int flags;
	struct mutex___200 dqio_mutex;
	struct mutex___200 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___198 *files[2];
	struct mem_dqinfo___198 info[2];
	const struct quota_format_ops___198 *ops[2];
};

struct file_system_type___198;

struct super_operations___198;

struct dquot_operations___198;

struct quotactl_ops___198;

struct super_block___198 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___198 *s_type;
	const struct super_operations___198 *s_op;
	const struct dquot_operations___198 *dq_op;
	const struct quotactl_ops___198 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___198 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___198 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___198 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___200 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___198 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___198 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___198 *bd_inode;
	struct super_block___198 *bd_super;
	struct mutex___200 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___198 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___200 bd_fsfreeze_mutex;
};

struct iattr___198 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___198 *ia_file;
};

struct dquot___198 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___200 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___198 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___198 {
	int qf_fmt_id;
	const struct quota_format_ops___198 *qf_ops;
	struct module___112 *qf_owner;
	struct quota_format_type___198 *qf_next;
};

struct quota_format_ops___198 {
	int (*check_quota_file)(struct super_block___198 *, int);
	int (*read_file_info)(struct super_block___198 *, int);
	int (*write_file_info)(struct super_block___198 *, int);
	int (*free_file_info)(struct super_block___198 *, int);
	int (*read_dqblk)(struct dquot___198 *);
	int (*commit_dqblk)(struct dquot___198 *);
	int (*release_dqblk)(struct dquot___198 *);
};

struct dquot_operations___198 {
	int (*write_dquot)(struct dquot___198 *);
	struct dquot___198 * (*alloc_dquot)(struct super_block___198 *, int);
	void (*destroy_dquot)(struct dquot___198 *);
	int (*acquire_dquot)(struct dquot___198 *);
	int (*release_dquot)(struct dquot___198 *);
	int (*mark_dirty)(struct dquot___198 *);
	int (*write_info)(struct super_block___198 *, int);
	qsize_t * (*get_reserved_space)(struct inode___198 *);
};

struct quotactl_ops___198 {
	int (*quota_on)(struct super_block___198 *, int, int, struct path___198 *);
	int (*quota_on_meta)(struct super_block___198 *, int, int);
	int (*quota_off)(struct super_block___198 *, int);
	int (*quota_sync)(struct super_block___198 *, int);
	int (*get_info)(struct super_block___198 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___198 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___198 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___198 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___198 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___198 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___198 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___198 *, unsigned int);
};

struct address_space_operations___198 {
	int (*writepage)(struct page___197 *, struct writeback_control *);
	int (*readpage)(struct file___198 *, struct page___197 *);
	int (*writepages)(struct address_space___198 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___197 *);
	int (*readpages)(struct file___198 *, struct address_space___198 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___198 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___197 **, void **);
	int (*write_end)(struct file___198 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___197 *, void *);
	sector_t (*bmap)(struct address_space___198 *, sector_t);
	void (*invalidatepage)(struct page___197 *, long unsigned int);
	int (*releasepage)(struct page___197 *, gfp_t);
	void (*freepage)(struct page___197 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___198 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___198 *, struct page___197 *, struct page___197 *, enum migrate_mode);
	int (*launder_page)(struct page___197 *);
	int (*is_partially_uptodate)(struct page___197 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___197 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___198 *, struct page___197 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___198 *, sector_t *);
	void (*swap_deactivate)(struct file___198 *);
	void (*invalidatepage_range)(struct page___197 *, unsigned int, unsigned int);
};

struct cdev___52 {
	struct kobject___20 kobj;
	struct module___112 *owner;
	const struct file_operations___198 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___198 {
	struct dentry___198 * (*lookup)(struct inode___198 *, struct dentry___198 *, unsigned int);
	void * (*follow_link)(struct dentry___198 *, struct nameidata *);
	int (*permission)(struct inode___198 *, int);
	struct posix_acl * (*get_acl)(struct inode___198 *, int);
	int (*readlink)(struct dentry___198 *, char *, int);
	void (*put_link)(struct dentry___198 *, struct nameidata *, void *);
	int (*create)(struct inode___198 *, struct dentry___198 *, umode_t, bool);
	int (*link)(struct dentry___198 *, struct inode___198 *, struct dentry___198 *);
	int (*unlink)(struct inode___198 *, struct dentry___198 *);
	int (*symlink)(struct inode___198 *, struct dentry___198 *, const char *);
	int (*mkdir)(struct inode___198 *, struct dentry___198 *, umode_t);
	int (*rmdir)(struct inode___198 *, struct dentry___198 *);
	int (*mknod)(struct inode___198 *, struct dentry___198 *, umode_t, dev_t);
	int (*rename)(struct inode___198 *, struct dentry___198 *, struct inode___198 *, struct dentry___198 *);
	int (*setattr)(struct dentry___198 *, struct iattr___198 *);
	int (*getattr)(struct vfsmount *, struct dentry___198 *, struct kstat *);
	int (*setxattr)(struct dentry___198 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___198 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___198 *, char *, size_t);
	int (*removexattr)(struct dentry___198 *, const char *);
	int (*fiemap)(struct inode___198 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___198 *, struct timespec *, int);
	int (*atomic_open)(struct inode___198 *, struct dentry___198 *, struct file___198 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___136;

struct file_operations___198 {
	struct module___112 *owner;
	loff_t (*llseek)(struct file___198 *, loff_t, int);
	ssize_t (*read)(struct file___198 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___198 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___198 *, void *, filldir_t);
	unsigned int (*poll)(struct file___198 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___198 *, struct vm_area_struct___206 *);
	int (*open)(struct inode___198 *, struct file___198 *);
	int (*flush)(struct file___198 *, fl_owner_t);
	int (*release)(struct inode___198 *, struct file___198 *);
	int (*fsync)(struct file___198 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___198 *, int);
	int (*lock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*sendpage)(struct file___198 *, struct page___197 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___198 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___198 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___198 *, long int, struct file_lock___198 **, void **);
		struct {
			int (*setlease)(struct file___198 *, long int, struct file_lock___198 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___198 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___136 *, struct file___198 *);
};

struct fasync_struct___198;

struct file_lock_operations___198;

struct lock_manager_operations___198;

struct file_lock___198 {
	struct file_lock___198 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___198 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___198 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___198 *fl_ops;
	const struct lock_manager_operations___198 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___198 {
	void (*fl_copy_lock)(struct file_lock___198 *, struct file_lock___198 *);
	void (*fl_release_private)(struct file_lock___198 *);
};

struct lock_manager_operations___198 {
	int (*lm_compare_owner)(struct file_lock___198 *, struct file_lock___198 *);
	long unsigned int (*lm_owner_key)(struct file_lock___198 *);
	void (*lm_notify)(struct file_lock___198 *);
	int (*lm_grant)(struct file_lock___198 *, struct file_lock___198 *, int);
	void (*lm_break)(struct file_lock___198 *);
	int (*lm_change)(struct file_lock___198 **, int);
};

struct fasync_struct___198 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___198 *fa_next;
	struct file___198 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___198 {
	const char *name;
	int fs_flags;
	struct dentry___198 * (*mount)(struct file_system_type___198 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___198 *);
	struct module___112 *owner;
	struct file_system_type___198 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___198 {
	struct inode___198 * (*alloc_inode)(struct super_block___198 *);
	void (*destroy_inode)(struct inode___198 *);
	void (*dirty_inode)(struct inode___198 *, int);
	int (*write_inode)(struct inode___198 *, struct writeback_control *);
	int (*drop_inode)(struct inode___198 *);
	void (*evict_inode)(struct inode___198 *);
	void (*put_super)(struct super_block___198 *);
	int (*sync_fs)(struct super_block___198 *, int);
	int (*freeze_fs)(struct super_block___198 *);
	int (*unfreeze_fs)(struct super_block___198 *);
	int (*statfs)(struct dentry___198 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___198 *, int *, char *);
	void (*umount_begin)(struct super_block___198 *);
	int (*show_options)(struct seq_file___136 *, struct dentry___198 *);
	int (*show_devname)(struct seq_file___136 *, struct dentry___198 *);
	int (*show_path)(struct seq_file___136 *, struct dentry___198 *);
	int (*show_stats)(struct seq_file___136 *, struct dentry___198 *);
	ssize_t (*quota_read)(struct super_block___198 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___198 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___198 *);
	int (*bdev_try_to_free_page)(struct super_block___198 *, struct page___197 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___198 *);
	void (*free_cached_objects)(struct super_block___198 *, int);
};

struct seq_operations___136;

struct seq_file___136 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___200 lock;
	const struct seq_operations___136 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct tty_struct___23;

struct tty_driver___23;

struct tty_operations___23 {
	struct tty_struct___23 * (*lookup)(struct tty_driver___23 *, struct inode___198 *, int);
	int (*install)(struct tty_driver___23 *, struct tty_struct___23 *);
	void (*remove)(struct tty_driver___23 *, struct tty_struct___23 *);
	int (*open)(struct tty_struct___23 *, struct file___198 *);
	void (*close)(struct tty_struct___23 *, struct file___198 *);
	void (*shutdown)(struct tty_struct___23 *);
	void (*cleanup)(struct tty_struct___23 *);
	int (*write)(struct tty_struct___23 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___23 *, unsigned char);
	void (*flush_chars)(struct tty_struct___23 *);
	int (*write_room)(struct tty_struct___23 *);
	int (*chars_in_buffer)(struct tty_struct___23 *);
	int (*ioctl)(struct tty_struct___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___23 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___23 *, struct ktermios *);
	void (*throttle)(struct tty_struct___23 *);
	void (*unthrottle)(struct tty_struct___23 *);
	void (*stop)(struct tty_struct___23 *);
	void (*start)(struct tty_struct___23 *);
	void (*hangup)(struct tty_struct___23 *);
	int (*break_ctl)(struct tty_struct___23 *, int);
	void (*flush_buffer)(struct tty_struct___23 *);
	void (*set_ldisc)(struct tty_struct___23 *);
	void (*wait_until_sent)(struct tty_struct___23 *, int);
	void (*send_xchar)(struct tty_struct___23 *, char);
	int (*tiocmget)(struct tty_struct___23 *);
	int (*tiocmset)(struct tty_struct___23 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___23 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___23 *, struct termiox *);
	int (*get_icount)(struct tty_struct___23 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___23 *, int, char *);
	int (*poll_get_char)(struct tty_driver___23 *, int);
	void (*poll_put_char)(struct tty_driver___23 *, int, char);
	const struct file_operations___198 *proc_fops;
};

struct tty_ldisc___23;

struct tty_port___23;

struct tty_struct___23 {
	int magic;
	struct kref kref;
	struct device___174 *dev;
	struct tty_driver___23 *driver;
	const struct tty_operations___23 *ops;
	int index;
	struct mutex___200 ldisc_mutex;
	struct tty_ldisc___23 *ldisc;
	struct mutex___200 atomic_write_lock;
	struct mutex___200 legacy_mutex;
	struct mutex___200 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___23 *link;
	struct fasync_struct___198 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___23 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___23 {
	int magic;
	struct kref kref;
	struct cdev___52 *cdevs;
	struct module___112 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___23 *other;
	struct tty_struct___23 **ttys;
	struct tty_port___23 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___23 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___23;

struct tty_port___23 {
	struct tty_bufhead buf;
	struct tty_struct___23 *tty;
	struct tty_struct___23 *itty;
	const struct tty_port_operations___23 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___200 mutex;
	struct mutex___200 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___23 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___23 *);
	void (*close)(struct tty_struct___23 *);
	void (*flush_buffer)(struct tty_struct___23 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___23 *);
	ssize_t (*read)(struct tty_struct___23 *, struct file___198 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___23 *, struct file___198 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___23 *, struct file___198 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___23 *, struct file___198 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___23 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___23 *, struct file___198 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___23 *);
	void (*receive_buf)(struct tty_struct___23 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___23 *);
	void (*dcd_change)(struct tty_struct___23 *, unsigned int);
	struct module___112 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___23 *, int);
};

struct tty_ldisc___23 {
	struct tty_ldisc_ops___23 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___23 *tty;
};

struct tty_port_operations___23 {
	int (*carrier_raised)(struct tty_port___23 *);
	void (*dtr_rts)(struct tty_port___23 *, int);
	void (*shutdown)(struct tty_port___23 *);
	void (*drop)(struct tty_port___23 *);
	int (*activate)(struct tty_port___23 *, struct tty_struct___23 *);
	void (*destruct)(struct tty_port___23 *);
};

struct kmem_cache_cpu___183 {
	void **freelist;
	long unsigned int tid;
	struct page___197 *page;
	struct page___197 *partial;
};

struct memcg_cache_params___184;

struct kmem_cache___184 {
	struct kmem_cache_cpu___183 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___184 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___184 {
	bool is_root_cache;
	union {
		struct kmem_cache___184 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___184 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct console___8 {
	char name[16];
	void (*write)(struct console___8 *, const char *, unsigned int);
	int (*read)(struct console___8 *, char *, unsigned int);
	struct tty_driver___23 * (*device)(struct console___8 *, int *);
	void (*unblank)();
	int (*setup)(struct console___8 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___8 *next;
};

struct seq_operations___136 {
	void * (*start)(struct seq_file___136 *, loff_t *);
	void (*stop)(struct seq_file___136 *, void *);
	void * (*next)(struct seq_file___136 *, void *, loff_t *);
	int (*show)(struct seq_file___136 *, void *);
};

struct bus_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___174 *, char *);
	ssize_t (*store)(struct bus_type___174 *, const char *, size_t);
};

struct device_attribute___174;

struct driver_attribute___174;

struct bus_type___174 {
	const char *name;
	const char *dev_name;
	struct device___174 *dev_root;
	struct bus_attribute___174 *bus_attrs;
	struct device_attribute___174 *dev_attrs;
	struct driver_attribute___174 *drv_attrs;
	const struct attribute_group___156 **bus_groups;
	const struct attribute_group___156 **dev_groups;
	const struct attribute_group___156 **drv_groups;
	int (*match)(struct device___174 *, struct device_driver___174 *);
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	int (*probe)(struct device___174 *);
	int (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*online)(struct device___174 *);
	int (*offline)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct device___174 *, struct device_attribute___174 *, char *);
	ssize_t (*store)(struct device___174 *, struct device_attribute___174 *, const char *, size_t);
};

struct driver_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___174 *, char *);
	ssize_t (*store)(struct device_driver___174 *, const char *, size_t);
};

struct device_driver___174 {
	const char *name;
	struct bus_type___174 *bus;
	struct module___112 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___174 *);
	int (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	const struct attribute_group___156 **groups;
	const struct dev_pm_ops___174 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___174 {
	const char *name;
	const struct attribute_group___156 **groups;
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
};

struct class_attribute___174;

struct class___174 {
	const char *name;
	struct module___112 *owner;
	struct class_attribute___174 *class_attrs;
	struct device_attribute___174 *dev_attrs;
	const struct attribute_group___156 **dev_groups;
	struct bin_attribute___158 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *);
	void (*class_release)(struct class___174 *);
	void (*dev_release)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
	struct subsys_private *p;
};

struct class_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct class___174 *, struct class_attribute___174 *, char *);
	ssize_t (*store)(struct class___174 *, struct class_attribute___174 *, const char *, size_t);
	const void * (*namespace)(struct class___174 *, const struct class_attribute___174 *);
};

struct device_rh___174 {
	struct dev_pm_info_rh___174 power;
};

struct irq_chip___132 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___132 *);
	void (*irq_shutdown)(struct irq_data___132 *);
	void (*irq_enable)(struct irq_data___132 *);
	void (*irq_disable)(struct irq_data___132 *);
	void (*irq_ack)(struct irq_data___132 *);
	void (*irq_mask)(struct irq_data___132 *);
	void (*irq_mask_ack)(struct irq_data___132 *);
	void (*irq_unmask)(struct irq_data___132 *);
	void (*irq_eoi)(struct irq_data___132 *);
	int (*irq_set_affinity)(struct irq_data___132 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___132 *);
	int (*irq_set_type)(struct irq_data___132 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___132 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___132 *);
	void (*irq_bus_sync_unlock)(struct irq_data___132 *);
	void (*irq_cpu_online)(struct irq_data___132 *);
	void (*irq_cpu_offline)(struct irq_data___132 *);
	void (*irq_suspend)(struct irq_data___132 *);
	void (*irq_resume)(struct irq_data___132 *);
	void (*irq_pm_shutdown)(struct irq_data___132 *);
	void (*irq_print_chip)(struct irq_data___132 *, struct seq_file___136 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___132 *, void *);
	long unsigned int flags;
};

struct circ_buf {
	char *buf;
	int head;
	int tail;
};

struct xol_area___197 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___197 *page;
	long unsigned int vaddr;
};

struct core_thread___199 {
	struct task_struct___199 *task;
	struct core_thread___199 *next;
};

struct core_state___199 {
	atomic_t nr_threads;
	struct core_thread___199 dumper;
	struct completion startup;
};

struct signal_struct___199 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___199 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___199 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___23 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___200 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct uart_port;

struct uart_ops {
	unsigned int (*tx_empty)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*stop_tx)(struct uart_port *);
	void (*start_tx)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	void (*send_xchar)(struct uart_port *, char);
	void (*stop_rx)(struct uart_port *);
	void (*enable_ms)(struct uart_port *);
	void (*break_ctl)(struct uart_port *, int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*flush_buffer)(struct uart_port *);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, int);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port *, unsigned int);
	const char * (*type)(struct uart_port *);
	void (*release_port)(struct uart_port *);
	int (*request_port)(struct uart_port *);
	void (*config_port)(struct uart_port *, int);
	int (*verify_port)(struct uart_port *, struct serial_struct *);
	int (*ioctl)(struct uart_port *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port *);
	void (*poll_put_char)(struct uart_port *, unsigned char);
	int (*poll_get_char)(struct uart_port *);
};

struct uart_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 rx;
	__u32 tx;
	__u32 frame;
	__u32 overrun;
	__u32 parity;
	__u32 brk;
	__u32 buf_overrun;
};

typedef unsigned int upf_t;

struct uart_state;

struct uart_port {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state *state;
	struct uart_icount icount;
	struct console___8 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device___174 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

enum uart_pm_state {
	UART_PM_STATE_ON = 0,
	UART_PM_STATE_OFF = 3,
	UART_PM_STATE_UNDEFINED = 4,
};

struct uart_state {
	struct tty_port___23 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port *uart_port;
};

struct uart_driver {
	struct module___112 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___8 *cons;
	struct uart_state *state;
	struct tty_driver___23 *tty_driver;
};

struct baud_rates {
	unsigned int rate;
	unsigned int cflag;
};

struct uart_match {
	struct uart_port *port;
	struct uart_driver *driver;
};

struct page___198;

typedef struct page___198 *pgtable_t___198;

struct address_space___199;

struct kmem_cache___185;

struct page___198 {
	long unsigned int flags;
	struct address_space___199 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___198 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___198 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___185 *slab_cache;
		struct page___198 *first_page;
	};
	long: 64;
};

struct task_struct___200;

struct pv_cpu_ops___200 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___200 *);
	void (*end_context_switch)(struct task_struct___200 *);
};

struct mutex___201 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___200 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___193 {
	struct page___198 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___207;

struct signal_struct___200;

struct task_struct___200 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___200 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___207 *mm;
	struct mm_struct___207 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___200 *real_parent;
	struct task_struct___200 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___200 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___200 = 0,
		VTIME_USER___200 = 1,
		VTIME_SYS___200 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___200 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___201 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___193 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___207 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___207 *, struct mm_struct___207 *);
	void (*dup_mmap)(struct mm_struct___207 *, struct mm_struct___207 *);
	void (*exit_mmap)(struct mm_struct___207 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___207 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___207 *);
	void (*pgd_free)(struct mm_struct___207 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___207 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___207 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___207 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___207 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___207 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___207 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___207 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___207 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___207 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___207 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___207 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___201 lock;
	void *vdso;
} mm_context_t___201;

struct xol_area___198;

struct uprobes_state___198 {
	struct xol_area___198 *xol_area;
};

struct vm_area_struct___207;

struct file___199;

struct core_state___200;

struct mm_struct___207 {
	struct vm_area_struct___207 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___207 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___207 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___201 context;
	long unsigned int flags;
	struct core_state___200 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___200 *owner;
	struct file___199 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___198 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___113;

struct module_kobject___112 {
	struct kobject___20 kobj;
	struct module___113 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___112;

struct module___113 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___112 mkobj;
	struct module_attribute___112 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___200 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___200;

struct lruvec___200 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___200 *zone;
};

struct pglist_data___200;

struct zone___200 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___200 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___200 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___200 {
	struct zone___200 *zone;
	int zone_idx;
};

struct zonelist___200 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___200 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___200 {
	struct zone___200 node_zones[4];
	struct zonelist___200 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___200 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___175;

struct dev_pm_ops___175 {
	int (*prepare)(struct device___175 *);
	void (*complete)(struct device___175 *);
	int (*suspend)(struct device___175 *);
	int (*resume)(struct device___175 *);
	int (*freeze)(struct device___175 *);
	int (*thaw)(struct device___175 *);
	int (*poweroff)(struct device___175 *);
	int (*restore)(struct device___175 *);
	int (*suspend_late)(struct device___175 *);
	int (*resume_early)(struct device___175 *);
	int (*freeze_late)(struct device___175 *);
	int (*thaw_early)(struct device___175 *);
	int (*poweroff_late)(struct device___175 *);
	int (*restore_early)(struct device___175 *);
	int (*suspend_noirq)(struct device___175 *);
	int (*resume_noirq)(struct device___175 *);
	int (*freeze_noirq)(struct device___175 *);
	int (*thaw_noirq)(struct device___175 *);
	int (*poweroff_noirq)(struct device___175 *);
	int (*restore_noirq)(struct device___175 *);
	int (*runtime_suspend)(struct device___175 *);
	int (*runtime_resume)(struct device___175 *);
	int (*runtime_idle)(struct device___175 *);
};

struct device_type___175;

struct bus_type___175;

struct device_driver___175;

struct dev_pm_domain___175;

struct class___175;

struct attribute_group___157;

struct device_rh___175;

struct device___175 {
	struct device___175 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___175 *type;
	struct mutex___201 mutex;
	struct bus_type___175 *bus;
	struct device_driver___175 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___175 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___71 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___26 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___175 *class;
	const struct attribute_group___157 **groups;
	void (*release)(struct device___175 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___175 *device_rh;
};

struct dev_pm_info_rh___175 {
	void (*set_latency_tolerance)(struct device___175 *, s32);
};

struct dev_pm_domain___175 {
	struct dev_pm_ops___175 ops;
};

struct smp_ops___200 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___200 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___159;

struct attribute_group___157 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___159 **bin_attrs;
};

struct bin_attribute___159 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___199 *, struct kobject___20 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___199 *, struct kobject___20 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	int (*mmap)(struct file___199 *, struct kobject___20 *, struct bin_attribute___159 *, struct vm_area_struct___207 *);
};

struct dentry___199;

struct path___199 {
	struct vfsmount *mnt;
	struct dentry___199 *dentry;
};

struct inode___199;

struct file_operations___199;

struct file___199 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___199 f_path;
	struct inode___199 *f_inode;
	const struct file_operations___199 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___199 *f_mapping;
	struct mutex___201 f_pos_lock;
};

struct vm_operations_struct___179;

struct vm_area_struct___207 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___207 *vm_next;
	struct vm_area_struct___207 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___207 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___179 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___199 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___112 *, struct module_kobject___112 *, char *);
	ssize_t (*store)(struct module_attribute___112 *, struct module_kobject___112 *, const char *, size_t);
	void (*setup)(struct module___113 *, const char *);
	int (*test)(struct module___113 *);
	void (*free)(struct module___113 *);
};

struct tty_driver___24;

struct console___9 {
	char name[16];
	void (*write)(struct console___9 *, const char *, unsigned int);
	int (*read)(struct console___9 *, char *, unsigned int);
	struct tty_driver___24 * (*device)(struct console___9 *, int *);
	void (*unblank)();
	int (*setup)(struct console___9 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___9 *next;
};

struct cdev___53;

struct tty_struct___24;

struct tty_port___24;

struct tty_operations___24;

struct tty_driver___24 {
	int magic;
	struct kref kref;
	struct cdev___53 *cdevs;
	struct module___113 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___24 *other;
	struct tty_struct___24 **ttys;
	struct tty_port___24 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___24 *ops;
	struct list_head tty_drivers;
};

struct bus_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___175 *, char *);
	ssize_t (*store)(struct bus_type___175 *, const char *, size_t);
};

struct device_attribute___175;

struct driver_attribute___175;

struct bus_type___175 {
	const char *name;
	const char *dev_name;
	struct device___175 *dev_root;
	struct bus_attribute___175 *bus_attrs;
	struct device_attribute___175 *dev_attrs;
	struct driver_attribute___175 *drv_attrs;
	const struct attribute_group___157 **bus_groups;
	const struct attribute_group___157 **dev_groups;
	const struct attribute_group___157 **drv_groups;
	int (*match)(struct device___175 *, struct device_driver___175 *);
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	int (*probe)(struct device___175 *);
	int (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*online)(struct device___175 *);
	int (*offline)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct device___175 *, struct device_attribute___175 *, char *);
	ssize_t (*store)(struct device___175 *, struct device_attribute___175 *, const char *, size_t);
};

struct driver_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___175 *, char *);
	ssize_t (*store)(struct device_driver___175 *, const char *, size_t);
};

struct device_driver___175 {
	const char *name;
	struct bus_type___175 *bus;
	struct module___113 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___175 *);
	int (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	const struct attribute_group___157 **groups;
	const struct dev_pm_ops___175 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___175 {
	const char *name;
	const struct attribute_group___157 **groups;
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
};

struct class_attribute___175;

struct class___175 {
	const char *name;
	struct module___113 *owner;
	struct class_attribute___175 *class_attrs;
	struct device_attribute___175 *dev_attrs;
	const struct attribute_group___157 **dev_groups;
	struct bin_attribute___159 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *);
	void (*class_release)(struct class___175 *);
	void (*dev_release)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
	struct subsys_private *p;
};

struct class_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct class___175 *, struct class_attribute___175 *, char *);
	ssize_t (*store)(struct class___175 *, struct class_attribute___175 *, const char *, size_t);
	const void * (*namespace)(struct class___175 *, const struct class_attribute___175 *);
};

struct device_rh___175 {
	struct dev_pm_info_rh___175 power;
};

struct platform_device___6 {
	const char *name;
	int id;
	bool id_auto;
	struct device___175 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___4 {
	int (*probe)(struct platform_device___6 *);
	int (*remove)(struct platform_device___6 *);
	void (*shutdown)(struct platform_device___6 *);
	int (*suspend)(struct platform_device___6 *, pm_message_t);
	int (*resume)(struct platform_device___6 *);
	struct device_driver___175 driver;
	const struct platform_device_id *id_table;
};

struct dentry_operations___199;

struct super_block___199;

struct dentry___199 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___199 *d_parent;
	struct qstr d_name;
	struct inode___199 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___199 *d_op;
	struct super_block___199 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___199;

struct address_space___199 {
	struct inode___199 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___201 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___199 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___199;

struct file_lock___199;

struct dquot___199;

struct block_device___199;

struct inode___199 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___199 *i_op;
	struct super_block___199 *i_sb;
	struct address_space___199 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___201 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___199 *i_fop;
	struct file_lock___199 *i_flock;
	struct address_space___199 i_data;
	struct dquot___199 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___199 *i_bdev;
		struct cdev___53 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___199 {
	int (*d_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_hash)(const struct dentry___199 *, struct qstr *);
	int (*d_compare)(const struct dentry___199 *, const struct dentry___199 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___199 *);
	void (*d_release)(struct dentry___199 *);
	void (*d_prune)(struct dentry___199 *);
	void (*d_iput)(struct dentry___199 *, struct inode___199 *);
	char * (*d_dname)(struct dentry___199 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___199 *);
	int (*d_manage)(struct dentry___199 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___199;

struct mem_dqinfo___199 {
	struct quota_format_type___199 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___199;

struct quota_info___199 {
	unsigned int flags;
	struct mutex___201 dqio_mutex;
	struct mutex___201 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___199 *files[2];
	struct mem_dqinfo___199 info[2];
	const struct quota_format_ops___199 *ops[2];
};

struct file_system_type___199;

struct super_operations___199;

struct dquot_operations___199;

struct quotactl_ops___199;

struct super_block___199 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___199 *s_type;
	const struct super_operations___199 *s_op;
	const struct dquot_operations___199 *dq_op;
	const struct quotactl_ops___199 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___199 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___199 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___199 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___201 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___199 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___199 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___199 *bd_inode;
	struct super_block___199 *bd_super;
	struct mutex___201 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___199 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___201 bd_fsfreeze_mutex;
};

struct iattr___199 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___199 *ia_file;
};

struct dquot___199 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___201 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___199 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___199 {
	int qf_fmt_id;
	const struct quota_format_ops___199 *qf_ops;
	struct module___113 *qf_owner;
	struct quota_format_type___199 *qf_next;
};

struct quota_format_ops___199 {
	int (*check_quota_file)(struct super_block___199 *, int);
	int (*read_file_info)(struct super_block___199 *, int);
	int (*write_file_info)(struct super_block___199 *, int);
	int (*free_file_info)(struct super_block___199 *, int);
	int (*read_dqblk)(struct dquot___199 *);
	int (*commit_dqblk)(struct dquot___199 *);
	int (*release_dqblk)(struct dquot___199 *);
};

struct dquot_operations___199 {
	int (*write_dquot)(struct dquot___199 *);
	struct dquot___199 * (*alloc_dquot)(struct super_block___199 *, int);
	void (*destroy_dquot)(struct dquot___199 *);
	int (*acquire_dquot)(struct dquot___199 *);
	int (*release_dquot)(struct dquot___199 *);
	int (*mark_dirty)(struct dquot___199 *);
	int (*write_info)(struct super_block___199 *, int);
	qsize_t * (*get_reserved_space)(struct inode___199 *);
};

struct quotactl_ops___199 {
	int (*quota_on)(struct super_block___199 *, int, int, struct path___199 *);
	int (*quota_on_meta)(struct super_block___199 *, int, int);
	int (*quota_off)(struct super_block___199 *, int);
	int (*quota_sync)(struct super_block___199 *, int);
	int (*get_info)(struct super_block___199 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___199 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___199 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___199 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___199 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___199 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___199 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___199 *, unsigned int);
};

struct address_space_operations___199 {
	int (*writepage)(struct page___198 *, struct writeback_control *);
	int (*readpage)(struct file___199 *, struct page___198 *);
	int (*writepages)(struct address_space___199 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___198 *);
	int (*readpages)(struct file___199 *, struct address_space___199 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___199 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___198 **, void **);
	int (*write_end)(struct file___199 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___198 *, void *);
	sector_t (*bmap)(struct address_space___199 *, sector_t);
	void (*invalidatepage)(struct page___198 *, long unsigned int);
	int (*releasepage)(struct page___198 *, gfp_t);
	void (*freepage)(struct page___198 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___199 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___199 *, struct page___198 *, struct page___198 *, enum migrate_mode);
	int (*launder_page)(struct page___198 *);
	int (*is_partially_uptodate)(struct page___198 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___198 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___199 *, struct page___198 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___199 *, sector_t *);
	void (*swap_deactivate)(struct file___199 *);
	void (*invalidatepage_range)(struct page___198 *, unsigned int, unsigned int);
};

struct cdev___53 {
	struct kobject___20 kobj;
	struct module___113 *owner;
	const struct file_operations___199 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___199 {
	struct dentry___199 * (*lookup)(struct inode___199 *, struct dentry___199 *, unsigned int);
	void * (*follow_link)(struct dentry___199 *, struct nameidata *);
	int (*permission)(struct inode___199 *, int);
	struct posix_acl * (*get_acl)(struct inode___199 *, int);
	int (*readlink)(struct dentry___199 *, char *, int);
	void (*put_link)(struct dentry___199 *, struct nameidata *, void *);
	int (*create)(struct inode___199 *, struct dentry___199 *, umode_t, bool);
	int (*link)(struct dentry___199 *, struct inode___199 *, struct dentry___199 *);
	int (*unlink)(struct inode___199 *, struct dentry___199 *);
	int (*symlink)(struct inode___199 *, struct dentry___199 *, const char *);
	int (*mkdir)(struct inode___199 *, struct dentry___199 *, umode_t);
	int (*rmdir)(struct inode___199 *, struct dentry___199 *);
	int (*mknod)(struct inode___199 *, struct dentry___199 *, umode_t, dev_t);
	int (*rename)(struct inode___199 *, struct dentry___199 *, struct inode___199 *, struct dentry___199 *);
	int (*setattr)(struct dentry___199 *, struct iattr___199 *);
	int (*getattr)(struct vfsmount *, struct dentry___199 *, struct kstat *);
	int (*setxattr)(struct dentry___199 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___199 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___199 *, char *, size_t);
	int (*removexattr)(struct dentry___199 *, const char *);
	int (*fiemap)(struct inode___199 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___199 *, struct timespec *, int);
	int (*atomic_open)(struct inode___199 *, struct dentry___199 *, struct file___199 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___199 {
	struct module___113 *owner;
	loff_t (*llseek)(struct file___199 *, loff_t, int);
	ssize_t (*read)(struct file___199 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___199 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___199 *, void *, filldir_t);
	unsigned int (*poll)(struct file___199 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___199 *, struct vm_area_struct___207 *);
	int (*open)(struct inode___199 *, struct file___199 *);
	int (*flush)(struct file___199 *, fl_owner_t);
	int (*release)(struct inode___199 *, struct file___199 *);
	int (*fsync)(struct file___199 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___199 *, int);
	int (*lock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*sendpage)(struct file___199 *, struct page___198 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___199 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___199 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___199 *, long int, struct file_lock___199 **, void **);
		struct {
			int (*setlease)(struct file___199 *, long int, struct file_lock___199 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___199 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___199 *);
};

struct fasync_struct___199;

struct file_lock_operations___199;

struct lock_manager_operations___199;

struct file_lock___199 {
	struct file_lock___199 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___199 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___199 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___199 *fl_ops;
	const struct lock_manager_operations___199 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___199 {
	void (*fl_copy_lock)(struct file_lock___199 *, struct file_lock___199 *);
	void (*fl_release_private)(struct file_lock___199 *);
};

struct lock_manager_operations___199 {
	int (*lm_compare_owner)(struct file_lock___199 *, struct file_lock___199 *);
	long unsigned int (*lm_owner_key)(struct file_lock___199 *);
	void (*lm_notify)(struct file_lock___199 *);
	int (*lm_grant)(struct file_lock___199 *, struct file_lock___199 *, int);
	void (*lm_break)(struct file_lock___199 *);
	int (*lm_change)(struct file_lock___199 **, int);
};

struct fasync_struct___199 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___199 *fa_next;
	struct file___199 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___199 {
	const char *name;
	int fs_flags;
	struct dentry___199 * (*mount)(struct file_system_type___199 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___199 *);
	struct module___113 *owner;
	struct file_system_type___199 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___199 {
	struct inode___199 * (*alloc_inode)(struct super_block___199 *);
	void (*destroy_inode)(struct inode___199 *);
	void (*dirty_inode)(struct inode___199 *, int);
	int (*write_inode)(struct inode___199 *, struct writeback_control *);
	int (*drop_inode)(struct inode___199 *);
	void (*evict_inode)(struct inode___199 *);
	void (*put_super)(struct super_block___199 *);
	int (*sync_fs)(struct super_block___199 *, int);
	int (*freeze_fs)(struct super_block___199 *);
	int (*unfreeze_fs)(struct super_block___199 *);
	int (*statfs)(struct dentry___199 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___199 *, int *, char *);
	void (*umount_begin)(struct super_block___199 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___199 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___199 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___199 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___199 *);
	ssize_t (*quota_read)(struct super_block___199 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___199 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___199 *);
	int (*bdev_try_to_free_page)(struct super_block___199 *, struct page___198 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___199 *);
	void (*free_cached_objects)(struct super_block___199 *, int);
};

struct tty_operations___24 {
	struct tty_struct___24 * (*lookup)(struct tty_driver___24 *, struct inode___199 *, int);
	int (*install)(struct tty_driver___24 *, struct tty_struct___24 *);
	void (*remove)(struct tty_driver___24 *, struct tty_struct___24 *);
	int (*open)(struct tty_struct___24 *, struct file___199 *);
	void (*close)(struct tty_struct___24 *, struct file___199 *);
	void (*shutdown)(struct tty_struct___24 *);
	void (*cleanup)(struct tty_struct___24 *);
	int (*write)(struct tty_struct___24 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___24 *, unsigned char);
	void (*flush_chars)(struct tty_struct___24 *);
	int (*write_room)(struct tty_struct___24 *);
	int (*chars_in_buffer)(struct tty_struct___24 *);
	int (*ioctl)(struct tty_struct___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___24 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___24 *, struct ktermios *);
	void (*throttle)(struct tty_struct___24 *);
	void (*unthrottle)(struct tty_struct___24 *);
	void (*stop)(struct tty_struct___24 *);
	void (*start)(struct tty_struct___24 *);
	void (*hangup)(struct tty_struct___24 *);
	int (*break_ctl)(struct tty_struct___24 *, int);
	void (*flush_buffer)(struct tty_struct___24 *);
	void (*set_ldisc)(struct tty_struct___24 *);
	void (*wait_until_sent)(struct tty_struct___24 *, int);
	void (*send_xchar)(struct tty_struct___24 *, char);
	int (*tiocmget)(struct tty_struct___24 *);
	int (*tiocmset)(struct tty_struct___24 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___24 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___24 *, struct termiox *);
	int (*get_icount)(struct tty_struct___24 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___24 *, int, char *);
	int (*poll_get_char)(struct tty_driver___24 *, int);
	void (*poll_put_char)(struct tty_driver___24 *, int, char);
	const struct file_operations___199 *proc_fops;
};

struct tty_ldisc___24;

struct tty_struct___24 {
	int magic;
	struct kref kref;
	struct device___175 *dev;
	struct tty_driver___24 *driver;
	const struct tty_operations___24 *ops;
	int index;
	struct mutex___201 ldisc_mutex;
	struct tty_ldisc___24 *ldisc;
	struct mutex___201 atomic_write_lock;
	struct mutex___201 legacy_mutex;
	struct mutex___201 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___24 *link;
	struct fasync_struct___199 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___24 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_port_operations___24;

struct tty_port___24 {
	struct tty_bufhead buf;
	struct tty_struct___24 *tty;
	struct tty_struct___24 *itty;
	const struct tty_port_operations___24 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___201 mutex;
	struct mutex___201 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___24 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___24 *);
	void (*close)(struct tty_struct___24 *);
	void (*flush_buffer)(struct tty_struct___24 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___24 *);
	ssize_t (*read)(struct tty_struct___24 *, struct file___199 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___24 *, struct file___199 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___24 *, struct file___199 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___24 *, struct file___199 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___24 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___24 *, struct file___199 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___24 *);
	void (*receive_buf)(struct tty_struct___24 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___24 *);
	void (*dcd_change)(struct tty_struct___24 *, unsigned int);
	struct module___113 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___24 *, int);
};

struct tty_ldisc___24 {
	struct tty_ldisc_ops___24 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___24 *tty;
};

struct tty_port_operations___24 {
	int (*carrier_raised)(struct tty_port___24 *);
	void (*dtr_rts)(struct tty_port___24 *, int);
	void (*shutdown)(struct tty_port___24 *);
	void (*drop)(struct tty_port___24 *);
	int (*activate)(struct tty_port___24 *, struct tty_struct___24 *);
	void (*destruct)(struct tty_port___24 *);
};

struct xol_area___198 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___198 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___184;

struct memcg_cache_params___185;

struct kmem_cache___185 {
	struct kmem_cache_cpu___184 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___185 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___175;

struct vm_operations_struct___179 {
	void (*open)(struct vm_area_struct___207 *);
	void (*close)(struct vm_area_struct___207 *);
	int (*fault)(struct vm_area_struct___207 *, struct vm_fault___175 *);
	int (*page_mkwrite)(struct vm_area_struct___207 *, struct vm_fault___175 *);
	int (*access)(struct vm_area_struct___207 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___207 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___207 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___207 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___207 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___200 {
	struct task_struct___200 *task;
	struct core_thread___200 *next;
};

struct core_state___200 {
	atomic_t nr_threads;
	struct core_thread___200 dumper;
	struct completion startup;
};

struct signal_struct___200 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___200 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___200 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___24 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___201 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct uart_port___2;

struct uart_ops___2 {
	unsigned int (*tx_empty)(struct uart_port___2 *);
	void (*set_mctrl)(struct uart_port___2 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___2 *);
	void (*stop_tx)(struct uart_port___2 *);
	void (*start_tx)(struct uart_port___2 *);
	void (*throttle)(struct uart_port___2 *);
	void (*unthrottle)(struct uart_port___2 *);
	void (*send_xchar)(struct uart_port___2 *, char);
	void (*stop_rx)(struct uart_port___2 *);
	void (*enable_ms)(struct uart_port___2 *);
	void (*break_ctl)(struct uart_port___2 *, int);
	int (*startup)(struct uart_port___2 *);
	void (*shutdown)(struct uart_port___2 *);
	void (*flush_buffer)(struct uart_port___2 *);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___2 *, int);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port___2 *, unsigned int);
	const char * (*type)(struct uart_port___2 *);
	void (*release_port)(struct uart_port___2 *);
	int (*request_port)(struct uart_port___2 *);
	void (*config_port)(struct uart_port___2 *, int);
	int (*verify_port)(struct uart_port___2 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___2 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___2 *);
	void (*poll_put_char)(struct uart_port___2 *, unsigned char);
	int (*poll_get_char)(struct uart_port___2 *);
};

struct uart_state___2;

struct uart_port___2 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___2 *, int);
	void (*serial_out)(struct uart_port___2 *, int, int);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___2 *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___2 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___2 *state;
	struct uart_icount icount;
	struct console___9 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___2 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device___175 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

struct uart_state___2 {
	struct tty_port___24 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port___2 *uart_port;
};

struct uart_driver___2 {
	struct module___113 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___9 *cons;
	struct uart_state___2 *state;
	struct tty_driver___24 *tty_driver;
};

struct plat_serial8250_port {
	long unsigned int iobase;
	void *membase;
	resource_size_t mapbase;
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	void *private_data;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char hub6;
	upf_t flags;
	unsigned int type;
	unsigned int (*serial_in)(struct uart_port___2 *, int);
	void (*serial_out)(struct uart_port___2 *, int, int);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___2 *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___2 *);
};

enum {
	PLAT8250_DEV_LEGACY = 4294967295,
	PLAT8250_DEV_PLATFORM = 0,
	PLAT8250_DEV_PLATFORM1 = 1,
	PLAT8250_DEV_PLATFORM2 = 2,
	PLAT8250_DEV_FOURPORT = 3,
	PLAT8250_DEV_ACCENT = 4,
	PLAT8250_DEV_BOCA = 5,
	PLAT8250_DEV_EXAR_ST16C554 = 6,
	PLAT8250_DEV_HUB6 = 7,
	PLAT8250_DEV_AU1X00 = 8,
	PLAT8250_DEV_SM501 = 9,
};

struct uart_8250_dma;

struct uart_8250_port {
	struct uart_port___2 port;
	struct timer_list timer;
	struct list_head list;
	short unsigned int capabilities;
	short unsigned int bugs;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma *dma;
	int (*dl_read)(struct uart_8250_port *);
	void (*dl_write)(struct uart_8250_port *, int);
};

struct dma_chan___3;

typedef bool (*dma_filter_fn___2)(struct dma_chan___3 *, void *);

enum dma_slave_buswidth {
	DMA_SLAVE_BUSWIDTH_UNDEFINED = 0,
	DMA_SLAVE_BUSWIDTH_1_BYTE = 1,
	DMA_SLAVE_BUSWIDTH_2_BYTES = 2,
	DMA_SLAVE_BUSWIDTH_4_BYTES = 4,
	DMA_SLAVE_BUSWIDTH_8_BYTES = 8,
};

struct dma_slave_config {
	enum dma_transfer_direction direction;
	dma_addr_t src_addr;
	dma_addr_t dst_addr;
	enum dma_slave_buswidth src_addr_width;
	enum dma_slave_buswidth dst_addr_width;
	u32 src_maxburst;
	u32 dst_maxburst;
	bool device_fc;
	unsigned int slave_id;
};

struct uart_8250_dma {
	dma_filter_fn___2 fn;
	void *rx_param;
	void *tx_param;
	int rx_chan_id;
	int tx_chan_id;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___3 *rxchan;
	struct dma_chan___3 *txchan;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running: 1;
};

struct kmem_cache_cpu___184 {
	void **freelist;
	long unsigned int tid;
	struct page___198 *page;
	struct page___198 *partial;
};

struct memcg_cache_params___185 {
	bool is_root_cache;
	union {
		struct kmem_cache___185 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___185 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct vm_fault___175 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___198 *page;
};

struct dma_device___2;

struct dma_chan_dev___2;

struct dma_chan___3 {
	struct dma_device___2 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___2 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___2;

struct dma_device___2 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___175 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___3 *);
	void (*device_free_chan_resources)(struct dma_chan___3 *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memcpy)(struct dma_chan___3 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor)(struct dma_chan___3 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor_val)(struct dma_chan___3 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq_val)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memset)(struct dma_chan___3 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_interrupt)(struct dma_chan___3 *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_slave_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_cyclic)(struct dma_chan___3 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___2 * (*device_prep_interleaved_dma)(struct dma_chan___3 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___3 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___3 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___3 *);
};

struct dma_chan_dev___2 {
	struct dma_chan___3 *chan;
	struct device___175 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___2 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___3 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___2 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct old_serial_port {
	unsigned int uart;
	unsigned int baud_base;
	unsigned int port;
	unsigned int irq;
	unsigned int flags;
	unsigned char hub6;
	unsigned char io_type;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
	long unsigned int irqflags;
};

struct serial8250_config {
	const char *name;
	short unsigned int fifo_size;
	short unsigned int tx_loadsz;
	unsigned char fcr;
	unsigned int flags;
};

struct irq_info___2 {
	struct hlist_node node;
	int irq;
	spinlock_t lock;
	struct list_head *head;
};

struct page___199;

typedef struct page___199 *pgtable_t___199;

struct address_space___200;

struct kmem_cache___186;

struct page___199 {
	long unsigned int flags;
	struct address_space___200 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___199 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___199 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___186 *slab_cache;
		struct page___199 *first_page;
	};
	long: 64;
};

struct task_struct___201;

struct pv_cpu_ops___201 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___201 *);
	void (*end_context_switch)(struct task_struct___201 *);
};

struct mutex___202 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___201 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___194 {
	struct page___199 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___208;

struct signal_struct___201;

struct task_struct___201 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___201 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___208 *mm;
	struct mm_struct___208 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___201 *real_parent;
	struct task_struct___201 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___201 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___201 = 0,
		VTIME_USER___201 = 1,
		VTIME_SYS___201 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___201 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___202 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___194 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___208 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___208 *, struct mm_struct___208 *);
	void (*dup_mmap)(struct mm_struct___208 *, struct mm_struct___208 *);
	void (*exit_mmap)(struct mm_struct___208 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___208 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___208 *);
	void (*pgd_free)(struct mm_struct___208 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___208 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___208 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___208 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___208 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___208 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___208 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___208 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___208 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___208 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___208 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___208 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___202 lock;
	void *vdso;
} mm_context_t___202;

struct xol_area___199;

struct uprobes_state___199 {
	struct xol_area___199 *xol_area;
};

struct vm_area_struct___208;

struct file___200;

struct core_state___201;

struct mm_struct___208 {
	struct vm_area_struct___208 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___208 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___208 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___202 context;
	long unsigned int flags;
	struct core_state___201 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___201 *owner;
	struct file___200 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___199 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___114;

struct module_kobject___113 {
	struct kobject___20 kobj;
	struct module___114 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___113;

struct module___114 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___113 mkobj;
	struct module_attribute___113 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___201 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___201;

struct lruvec___201 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___201 *zone;
};

struct pglist_data___201;

struct zone___201 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___201 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___201 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___201 {
	struct zone___201 *zone;
	int zone_idx;
};

struct zonelist___201 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___201 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___201 {
	struct zone___201 node_zones[4];
	struct zonelist___201 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___201 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___176;

struct dev_pm_ops___176 {
	int (*prepare)(struct device___176 *);
	void (*complete)(struct device___176 *);
	int (*suspend)(struct device___176 *);
	int (*resume)(struct device___176 *);
	int (*freeze)(struct device___176 *);
	int (*thaw)(struct device___176 *);
	int (*poweroff)(struct device___176 *);
	int (*restore)(struct device___176 *);
	int (*suspend_late)(struct device___176 *);
	int (*resume_early)(struct device___176 *);
	int (*freeze_late)(struct device___176 *);
	int (*thaw_early)(struct device___176 *);
	int (*poweroff_late)(struct device___176 *);
	int (*restore_early)(struct device___176 *);
	int (*suspend_noirq)(struct device___176 *);
	int (*resume_noirq)(struct device___176 *);
	int (*freeze_noirq)(struct device___176 *);
	int (*thaw_noirq)(struct device___176 *);
	int (*poweroff_noirq)(struct device___176 *);
	int (*restore_noirq)(struct device___176 *);
	int (*runtime_suspend)(struct device___176 *);
	int (*runtime_resume)(struct device___176 *);
	int (*runtime_idle)(struct device___176 *);
};

struct dma_map_ops___72;

struct dev_archdata___72 {
	struct dma_map_ops___72 *dma_ops;
	void *iommu;
};

struct device_type___176;

struct bus_type___176;

struct device_driver___176;

struct dev_pm_domain___176;

struct class___176;

struct attribute_group___158;

struct device_rh___176;

struct device___176 {
	struct device___176 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___176 *type;
	struct mutex___202 mutex;
	struct bus_type___176 *bus;
	struct device_driver___176 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___176 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___72 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___26 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___176 *class;
	const struct attribute_group___158 **groups;
	void (*release)(struct device___176 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___176 *device_rh;
};

struct dev_pm_info_rh___176 {
	void (*set_latency_tolerance)(struct device___176 *, s32);
};

struct dev_pm_domain___176 {
	struct dev_pm_ops___176 ops;
};

struct smp_ops___201 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___201 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___160;

struct attribute_group___158 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___160 **bin_attrs;
};

struct bin_attribute___160 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___200 *, struct kobject___20 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___200 *, struct kobject___20 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	int (*mmap)(struct file___200 *, struct kobject___20 *, struct bin_attribute___160 *, struct vm_area_struct___208 *);
};

struct dentry___200;

struct path___200 {
	struct vfsmount *mnt;
	struct dentry___200 *dentry;
};

struct inode___200;

struct file_operations___200;

struct file___200 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___200 f_path;
	struct inode___200 *f_inode;
	const struct file_operations___200 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___200 *f_mapping;
	struct mutex___202 f_pos_lock;
};

struct vm_operations_struct___180;

struct vm_area_struct___208 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___208 *vm_next;
	struct vm_area_struct___208 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___208 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___180 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___200 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___113 *, struct module_kobject___113 *, char *);
	ssize_t (*store)(struct module_attribute___113 *, struct module_kobject___113 *, const char *, size_t);
	void (*setup)(struct module___114 *, const char *);
	int (*test)(struct module___114 *);
	void (*free)(struct module___114 *);
};

struct dma_map_ops___72 {
	void * (*alloc)(struct device___176 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___176 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___176 *, struct vm_area_struct___208 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___176 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___176 *, struct page___199 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___176 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___176 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___176 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___176 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___176 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___176 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___176 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___176 *, dma_addr_t);
	int (*dma_supported)(struct device___176 *, u64);
	int (*set_dma_mask)(struct device___176 *, u64);
	int is_phys;
};

struct bus_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___176 *, char *);
	ssize_t (*store)(struct bus_type___176 *, const char *, size_t);
};

struct device_attribute___176;

struct driver_attribute___176;

struct bus_type___176 {
	const char *name;
	const char *dev_name;
	struct device___176 *dev_root;
	struct bus_attribute___176 *bus_attrs;
	struct device_attribute___176 *dev_attrs;
	struct driver_attribute___176 *drv_attrs;
	const struct attribute_group___158 **bus_groups;
	const struct attribute_group___158 **dev_groups;
	const struct attribute_group___158 **drv_groups;
	int (*match)(struct device___176 *, struct device_driver___176 *);
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	int (*probe)(struct device___176 *);
	int (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*online)(struct device___176 *);
	int (*offline)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct device___176 *, struct device_attribute___176 *, char *);
	ssize_t (*store)(struct device___176 *, struct device_attribute___176 *, const char *, size_t);
};

struct driver_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___176 *, char *);
	ssize_t (*store)(struct device_driver___176 *, const char *, size_t);
};

struct device_driver___176 {
	const char *name;
	struct bus_type___176 *bus;
	struct module___114 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___176 *);
	int (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	const struct attribute_group___158 **groups;
	const struct dev_pm_ops___176 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___176 {
	const char *name;
	const struct attribute_group___158 **groups;
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
};

struct class_attribute___176;

struct class___176 {
	const char *name;
	struct module___114 *owner;
	struct class_attribute___176 *class_attrs;
	struct device_attribute___176 *dev_attrs;
	const struct attribute_group___158 **dev_groups;
	struct bin_attribute___160 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *);
	void (*class_release)(struct class___176 *);
	void (*dev_release)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
	struct subsys_private *p;
};

struct class_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct class___176 *, struct class_attribute___176 *, char *);
	ssize_t (*store)(struct class___176 *, struct class_attribute___176 *, const char *, size_t);
	const void * (*namespace)(struct class___176 *, const struct class_attribute___176 *);
};

struct device_rh___176 {
	struct dev_pm_info_rh___176 power;
};

struct xol_area___199 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___199 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___185;

struct memcg_cache_params___186;

struct kmem_cache___186 {
	struct kmem_cache_cpu___185 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___186 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___200;

struct address_space___200 {
	struct inode___200 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___202 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___200 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___176;

struct vm_operations_struct___180 {
	void (*open)(struct vm_area_struct___208 *);
	void (*close)(struct vm_area_struct___208 *);
	int (*fault)(struct vm_area_struct___208 *, struct vm_fault___176 *);
	int (*page_mkwrite)(struct vm_area_struct___208 *, struct vm_fault___176 *);
	int (*access)(struct vm_area_struct___208 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___208 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___208 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___208 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___208 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___201 {
	struct task_struct___201 *task;
	struct core_thread___201 *next;
};

struct core_state___201 {
	atomic_t nr_threads;
	struct core_thread___201 dumper;
	struct completion startup;
};

struct vm_fault___176 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___199 *page;
};

struct kmem_cache_cpu___185 {
	void **freelist;
	long unsigned int tid;
	struct page___199 *page;
	struct page___199 *partial;
};

struct memcg_cache_params___186 {
	bool is_root_cache;
	union {
		struct kmem_cache___186 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___186 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct pnp_protocol___4;

struct pnp_card___4 {
	struct device___176 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___4 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___4;

struct pnp_protocol___4 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___4 *);
	int (*set)(struct pnp_dev___4 *);
	int (*disable)(struct pnp_dev___4 *);
	bool (*can_wakeup)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	unsigned char number;
	struct device___176 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___4;

struct pnp_card_link___4 {
	struct pnp_card___4 *card;
	struct pnp_card_driver___4 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___4 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___4 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___4 *);
	void (*shutdown)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	struct device_driver___176 driver;
};

struct pnp_card_driver___4 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___4 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___4 *);
	int (*suspend)(struct pnp_card_link___4 *, pm_message_t);
	int (*resume)(struct pnp_card_link___4 *);
	struct pnp_driver___4 link;
};

struct pnp_dev___4 {
	struct device___176 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___4 *protocol;
	struct pnp_card___4 *card;
	struct pnp_driver___4 *driver;
	struct pnp_card_link___4 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct tty_struct___25;

struct signal_struct___201 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___201 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___201 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___25 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___202 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___25;

struct tty_operations___25;

struct tty_ldisc___25;

struct fasync_struct___200;

struct tty_port___25;

struct tty_struct___25 {
	int magic;
	struct kref kref;
	struct device___176 *dev;
	struct tty_driver___25 *driver;
	const struct tty_operations___25 *ops;
	int index;
	struct mutex___202 ldisc_mutex;
	struct tty_ldisc___25 *ldisc;
	struct mutex___202 atomic_write_lock;
	struct mutex___202 legacy_mutex;
	struct mutex___202 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___25 *link;
	struct fasync_struct___200 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___25 *port;
	struct ld_semaphore ldisc_sem;
};

struct dentry_operations___200;

struct super_block___200;

struct dentry___200 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___200 *d_parent;
	struct qstr d_name;
	struct inode___200 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___200 *d_op;
	struct super_block___200 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___200;

struct file_lock___200;

struct dquot___200;

struct block_device___200;

struct cdev___54;

struct inode___200 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___200 *i_op;
	struct super_block___200 *i_sb;
	struct address_space___200 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___202 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___200 *i_fop;
	struct file_lock___200 *i_flock;
	struct address_space___200 i_data;
	struct dquot___200 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___200 *i_bdev;
		struct cdev___54 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___200 {
	int (*d_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_hash)(const struct dentry___200 *, struct qstr *);
	int (*d_compare)(const struct dentry___200 *, const struct dentry___200 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___200 *);
	void (*d_release)(struct dentry___200 *);
	void (*d_prune)(struct dentry___200 *);
	void (*d_iput)(struct dentry___200 *, struct inode___200 *);
	char * (*d_dname)(struct dentry___200 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___200 *);
	int (*d_manage)(struct dentry___200 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___200;

struct mem_dqinfo___200 {
	struct quota_format_type___200 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___200;

struct quota_info___200 {
	unsigned int flags;
	struct mutex___202 dqio_mutex;
	struct mutex___202 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___200 *files[2];
	struct mem_dqinfo___200 info[2];
	const struct quota_format_ops___200 *ops[2];
};

struct file_system_type___200;

struct super_operations___200;

struct dquot_operations___200;

struct quotactl_ops___200;

struct super_block___200 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___200 *s_type;
	const struct super_operations___200 *s_op;
	const struct dquot_operations___200 *dq_op;
	const struct quotactl_ops___200 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___200 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___200 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___200 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___202 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___200 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___200 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___200 *bd_inode;
	struct super_block___200 *bd_super;
	struct mutex___202 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___200 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___202 bd_fsfreeze_mutex;
};

struct iattr___200 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___200 *ia_file;
};

struct dquot___200 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___202 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___200 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___200 {
	int qf_fmt_id;
	const struct quota_format_ops___200 *qf_ops;
	struct module___114 *qf_owner;
	struct quota_format_type___200 *qf_next;
};

struct quota_format_ops___200 {
	int (*check_quota_file)(struct super_block___200 *, int);
	int (*read_file_info)(struct super_block___200 *, int);
	int (*write_file_info)(struct super_block___200 *, int);
	int (*free_file_info)(struct super_block___200 *, int);
	int (*read_dqblk)(struct dquot___200 *);
	int (*commit_dqblk)(struct dquot___200 *);
	int (*release_dqblk)(struct dquot___200 *);
};

struct dquot_operations___200 {
	int (*write_dquot)(struct dquot___200 *);
	struct dquot___200 * (*alloc_dquot)(struct super_block___200 *, int);
	void (*destroy_dquot)(struct dquot___200 *);
	int (*acquire_dquot)(struct dquot___200 *);
	int (*release_dquot)(struct dquot___200 *);
	int (*mark_dirty)(struct dquot___200 *);
	int (*write_info)(struct super_block___200 *, int);
	qsize_t * (*get_reserved_space)(struct inode___200 *);
};

struct quotactl_ops___200 {
	int (*quota_on)(struct super_block___200 *, int, int, struct path___200 *);
	int (*quota_on_meta)(struct super_block___200 *, int, int);
	int (*quota_off)(struct super_block___200 *, int);
	int (*quota_sync)(struct super_block___200 *, int);
	int (*get_info)(struct super_block___200 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___200 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___200 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___200 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___200 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___200 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___200 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___200 *, unsigned int);
};

struct address_space_operations___200 {
	int (*writepage)(struct page___199 *, struct writeback_control *);
	int (*readpage)(struct file___200 *, struct page___199 *);
	int (*writepages)(struct address_space___200 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___199 *);
	int (*readpages)(struct file___200 *, struct address_space___200 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___200 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___199 **, void **);
	int (*write_end)(struct file___200 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___199 *, void *);
	sector_t (*bmap)(struct address_space___200 *, sector_t);
	void (*invalidatepage)(struct page___199 *, long unsigned int);
	int (*releasepage)(struct page___199 *, gfp_t);
	void (*freepage)(struct page___199 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___200 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___200 *, struct page___199 *, struct page___199 *, enum migrate_mode);
	int (*launder_page)(struct page___199 *);
	int (*is_partially_uptodate)(struct page___199 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___199 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___200 *, struct page___199 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___200 *, sector_t *);
	void (*swap_deactivate)(struct file___200 *);
	void (*invalidatepage_range)(struct page___199 *, unsigned int, unsigned int);
};

struct cdev___54 {
	struct kobject___20 kobj;
	struct module___114 *owner;
	const struct file_operations___200 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___200 {
	struct dentry___200 * (*lookup)(struct inode___200 *, struct dentry___200 *, unsigned int);
	void * (*follow_link)(struct dentry___200 *, struct nameidata *);
	int (*permission)(struct inode___200 *, int);
	struct posix_acl * (*get_acl)(struct inode___200 *, int);
	int (*readlink)(struct dentry___200 *, char *, int);
	void (*put_link)(struct dentry___200 *, struct nameidata *, void *);
	int (*create)(struct inode___200 *, struct dentry___200 *, umode_t, bool);
	int (*link)(struct dentry___200 *, struct inode___200 *, struct dentry___200 *);
	int (*unlink)(struct inode___200 *, struct dentry___200 *);
	int (*symlink)(struct inode___200 *, struct dentry___200 *, const char *);
	int (*mkdir)(struct inode___200 *, struct dentry___200 *, umode_t);
	int (*rmdir)(struct inode___200 *, struct dentry___200 *);
	int (*mknod)(struct inode___200 *, struct dentry___200 *, umode_t, dev_t);
	int (*rename)(struct inode___200 *, struct dentry___200 *, struct inode___200 *, struct dentry___200 *);
	int (*setattr)(struct dentry___200 *, struct iattr___200 *);
	int (*getattr)(struct vfsmount *, struct dentry___200 *, struct kstat *);
	int (*setxattr)(struct dentry___200 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___200 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___200 *, char *, size_t);
	int (*removexattr)(struct dentry___200 *, const char *);
	int (*fiemap)(struct inode___200 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___200 *, struct timespec *, int);
	int (*atomic_open)(struct inode___200 *, struct dentry___200 *, struct file___200 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___200 {
	struct module___114 *owner;
	loff_t (*llseek)(struct file___200 *, loff_t, int);
	ssize_t (*read)(struct file___200 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___200 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___200 *, void *, filldir_t);
	unsigned int (*poll)(struct file___200 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___200 *, struct vm_area_struct___208 *);
	int (*open)(struct inode___200 *, struct file___200 *);
	int (*flush)(struct file___200 *, fl_owner_t);
	int (*release)(struct inode___200 *, struct file___200 *);
	int (*fsync)(struct file___200 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___200 *, int);
	int (*lock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*sendpage)(struct file___200 *, struct page___199 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___200 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___200 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___200 *, long int, struct file_lock___200 **, void **);
		struct {
			int (*setlease)(struct file___200 *, long int, struct file_lock___200 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___200 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___200 *);
};

struct file_lock_operations___200;

struct lock_manager_operations___200;

struct file_lock___200 {
	struct file_lock___200 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___200 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___200 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___200 *fl_ops;
	const struct lock_manager_operations___200 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___200 {
	void (*fl_copy_lock)(struct file_lock___200 *, struct file_lock___200 *);
	void (*fl_release_private)(struct file_lock___200 *);
};

struct lock_manager_operations___200 {
	int (*lm_compare_owner)(struct file_lock___200 *, struct file_lock___200 *);
	long unsigned int (*lm_owner_key)(struct file_lock___200 *);
	void (*lm_notify)(struct file_lock___200 *);
	int (*lm_grant)(struct file_lock___200 *, struct file_lock___200 *, int);
	void (*lm_break)(struct file_lock___200 *);
	int (*lm_change)(struct file_lock___200 **, int);
};

struct fasync_struct___200 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___200 *fa_next;
	struct file___200 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___200 {
	const char *name;
	int fs_flags;
	struct dentry___200 * (*mount)(struct file_system_type___200 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___200 *);
	struct module___114 *owner;
	struct file_system_type___200 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___200 {
	struct inode___200 * (*alloc_inode)(struct super_block___200 *);
	void (*destroy_inode)(struct inode___200 *);
	void (*dirty_inode)(struct inode___200 *, int);
	int (*write_inode)(struct inode___200 *, struct writeback_control *);
	int (*drop_inode)(struct inode___200 *);
	void (*evict_inode)(struct inode___200 *);
	void (*put_super)(struct super_block___200 *);
	int (*sync_fs)(struct super_block___200 *, int);
	int (*freeze_fs)(struct super_block___200 *);
	int (*unfreeze_fs)(struct super_block___200 *);
	int (*statfs)(struct dentry___200 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___200 *, int *, char *);
	void (*umount_begin)(struct super_block___200 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___200 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___200 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___200 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___200 *);
	ssize_t (*quota_read)(struct super_block___200 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___200 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___200 *);
	int (*bdev_try_to_free_page)(struct super_block___200 *, struct page___199 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___200 *);
	void (*free_cached_objects)(struct super_block___200 *, int);
};

struct tty_operations___25 {
	struct tty_struct___25 * (*lookup)(struct tty_driver___25 *, struct inode___200 *, int);
	int (*install)(struct tty_driver___25 *, struct tty_struct___25 *);
	void (*remove)(struct tty_driver___25 *, struct tty_struct___25 *);
	int (*open)(struct tty_struct___25 *, struct file___200 *);
	void (*close)(struct tty_struct___25 *, struct file___200 *);
	void (*shutdown)(struct tty_struct___25 *);
	void (*cleanup)(struct tty_struct___25 *);
	int (*write)(struct tty_struct___25 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___25 *, unsigned char);
	void (*flush_chars)(struct tty_struct___25 *);
	int (*write_room)(struct tty_struct___25 *);
	int (*chars_in_buffer)(struct tty_struct___25 *);
	int (*ioctl)(struct tty_struct___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___25 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___25 *, struct ktermios *);
	void (*throttle)(struct tty_struct___25 *);
	void (*unthrottle)(struct tty_struct___25 *);
	void (*stop)(struct tty_struct___25 *);
	void (*start)(struct tty_struct___25 *);
	void (*hangup)(struct tty_struct___25 *);
	int (*break_ctl)(struct tty_struct___25 *, int);
	void (*flush_buffer)(struct tty_struct___25 *);
	void (*set_ldisc)(struct tty_struct___25 *);
	void (*wait_until_sent)(struct tty_struct___25 *, int);
	void (*send_xchar)(struct tty_struct___25 *, char);
	int (*tiocmget)(struct tty_struct___25 *);
	int (*tiocmset)(struct tty_struct___25 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___25 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___25 *, struct termiox *);
	int (*get_icount)(struct tty_struct___25 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___25 *, int, char *);
	int (*poll_get_char)(struct tty_driver___25 *, int);
	void (*poll_put_char)(struct tty_driver___25 *, int, char);
	const struct file_operations___200 *proc_fops;
};

struct tty_driver___25 {
	int magic;
	struct kref kref;
	struct cdev___54 *cdevs;
	struct module___114 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___25 *other;
	struct tty_struct___25 **ttys;
	struct tty_port___25 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___25 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___25;

struct tty_port___25 {
	struct tty_bufhead buf;
	struct tty_struct___25 *tty;
	struct tty_struct___25 *itty;
	const struct tty_port_operations___25 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___202 mutex;
	struct mutex___202 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___25 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___25 *);
	void (*close)(struct tty_struct___25 *);
	void (*flush_buffer)(struct tty_struct___25 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___25 *);
	ssize_t (*read)(struct tty_struct___25 *, struct file___200 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___25 *, struct file___200 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___25 *, struct file___200 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___25 *, struct file___200 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___25 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___25 *, struct file___200 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___25 *);
	void (*receive_buf)(struct tty_struct___25 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___25 *);
	void (*dcd_change)(struct tty_struct___25 *, unsigned int);
	struct module___114 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___25 *, int);
};

struct tty_ldisc___25 {
	struct tty_ldisc_ops___25 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___25 *tty;
};

struct tty_port_operations___25 {
	int (*carrier_raised)(struct tty_port___25 *);
	void (*dtr_rts)(struct tty_port___25 *, int);
	void (*shutdown)(struct tty_port___25 *);
	void (*drop)(struct tty_port___25 *);
	int (*activate)(struct tty_port___25 *, struct tty_struct___25 *);
	void (*destruct)(struct tty_port___25 *);
};

struct uart_port___3;

struct uart_ops___3 {
	unsigned int (*tx_empty)(struct uart_port___3 *);
	void (*set_mctrl)(struct uart_port___3 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___3 *);
	void (*stop_tx)(struct uart_port___3 *);
	void (*start_tx)(struct uart_port___3 *);
	void (*throttle)(struct uart_port___3 *);
	void (*unthrottle)(struct uart_port___3 *);
	void (*send_xchar)(struct uart_port___3 *, char);
	void (*stop_rx)(struct uart_port___3 *);
	void (*enable_ms)(struct uart_port___3 *);
	void (*break_ctl)(struct uart_port___3 *, int);
	int (*startup)(struct uart_port___3 *);
	void (*shutdown)(struct uart_port___3 *);
	void (*flush_buffer)(struct uart_port___3 *);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___3 *, int);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port___3 *, unsigned int);
	const char * (*type)(struct uart_port___3 *);
	void (*release_port)(struct uart_port___3 *);
	int (*request_port)(struct uart_port___3 *);
	void (*config_port)(struct uart_port___3 *, int);
	int (*verify_port)(struct uart_port___3 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___3 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___3 *);
	void (*poll_put_char)(struct uart_port___3 *, unsigned char);
	int (*poll_get_char)(struct uart_port___3 *);
};

struct console___10;

struct uart_state___3;

struct uart_port___3 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___3 *, int);
	void (*serial_out)(struct uart_port___3 *, int, int);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___3 *);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___3 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___3 *state;
	struct uart_icount icount;
	struct console___10 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___3 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device___176 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

struct uart_state___3 {
	struct tty_port___25 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port___3 *uart_port;
};

struct uart_8250_dma___2;

struct uart_8250_port___2 {
	struct uart_port___3 port;
	struct timer_list timer;
	struct list_head list;
	short unsigned int capabilities;
	short unsigned int bugs;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___2 *dma;
	int (*dl_read)(struct uart_8250_port___2 *);
	void (*dl_write)(struct uart_8250_port___2 *, int);
};

struct dma_chan___4;

typedef bool (*dma_filter_fn___3)(struct dma_chan___4 *, void *);

struct uart_8250_dma___2 {
	dma_filter_fn___3 fn;
	void *rx_param;
	void *tx_param;
	int rx_chan_id;
	int tx_chan_id;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___4 *rxchan;
	struct dma_chan___4 *txchan;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running: 1;
};

struct dma_device___3;

struct dma_chan_dev___3;

struct dma_chan___4 {
	struct dma_device___3 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___3 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___3;

struct dma_device___3 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___176 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___4 *);
	void (*device_free_chan_resources)(struct dma_chan___4 *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memcpy)(struct dma_chan___4 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor)(struct dma_chan___4 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor_val)(struct dma_chan___4 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq_val)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memset)(struct dma_chan___4 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_interrupt)(struct dma_chan___4 *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_slave_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_cyclic)(struct dma_chan___4 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___3 * (*device_prep_interleaved_dma)(struct dma_chan___4 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___4 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___4 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___4 *);
};

struct dma_chan_dev___3 {
	struct dma_chan___4 *chan;
	struct device___176 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___3 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___4 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___3 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct page___200;

typedef struct page___200 *pgtable_t___200;

struct address_space___201;

struct page___200 {
	long unsigned int flags;
	struct address_space___201 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___200 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___200 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___200 *first_page;
	};
	long: 64;
};

struct task_struct___202;

struct pv_cpu_ops___202 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___202 *);
	void (*end_context_switch)(struct task_struct___202 *);
};

struct mutex___203 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___202 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___195 {
	struct page___200 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___209;

struct signal_struct___202;

struct task_struct___202 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___202 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___209 *mm;
	struct mm_struct___209 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___202 *real_parent;
	struct task_struct___202 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___202 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___202 = 0,
		VTIME_USER___202 = 1,
		VTIME_SYS___202 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___202 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___203 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___195 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___209 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___209 *, struct mm_struct___209 *);
	void (*dup_mmap)(struct mm_struct___209 *, struct mm_struct___209 *);
	void (*exit_mmap)(struct mm_struct___209 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___209 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___209 *);
	void (*pgd_free)(struct mm_struct___209 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___209 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___209 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___209 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___209 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___209 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___209 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___209 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___209 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___209 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___209 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___209 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___203 lock;
	void *vdso;
} mm_context_t___203;

struct xol_area___200;

struct uprobes_state___200 {
	struct xol_area___200 *xol_area;
};

struct vm_area_struct___209;

struct file___201;

struct core_state___202;

struct mm_struct___209 {
	struct vm_area_struct___209 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___209 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___209 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___203 context;
	long unsigned int flags;
	struct core_state___202 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___202 *owner;
	struct file___201 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___200 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___201;

struct dentry_operations___201;

struct super_block___201;

struct dentry___201 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___201 *d_parent;
	struct qstr d_name;
	struct inode___201 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___201 *d_op;
	struct super_block___201 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___201;

struct address_space___201 {
	struct inode___201 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___203 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___201 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___201;

struct file_operations___201;

struct file_lock___201;

struct dquot___201;

struct block_device___201;

struct cdev___55;

struct inode___201 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___201 *i_op;
	struct super_block___201 *i_sb;
	struct address_space___201 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___203 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___201 *i_fop;
	struct file_lock___201 *i_flock;
	struct address_space___201 i_data;
	struct dquot___201 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___201 *i_bdev;
		struct cdev___55 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___201;

struct dentry_operations___201 {
	int (*d_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_hash)(const struct dentry___201 *, struct qstr *);
	int (*d_compare)(const struct dentry___201 *, const struct dentry___201 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___201 *);
	void (*d_release)(struct dentry___201 *);
	void (*d_prune)(struct dentry___201 *);
	void (*d_iput)(struct dentry___201 *, struct inode___201 *);
	char * (*d_dname)(struct dentry___201 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___201 *);
	int (*d_manage)(struct dentry___201 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___201;

struct mem_dqinfo___201 {
	struct quota_format_type___201 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___201;

struct quota_info___201 {
	unsigned int flags;
	struct mutex___203 dqio_mutex;
	struct mutex___203 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___201 *files[2];
	struct mem_dqinfo___201 info[2];
	const struct quota_format_ops___201 *ops[2];
};

struct file_system_type___201;

struct super_operations___201;

struct dquot_operations___201;

struct quotactl_ops___201;

struct super_block___201 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___201 *s_type;
	const struct super_operations___201 *s_op;
	const struct dquot_operations___201 *dq_op;
	const struct quotactl_ops___201 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___201 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___201 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___201 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___203 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___201 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___201 {
	struct vfsmount *mnt;
	struct dentry___201 *dentry;
};

struct device___177;

struct dev_pm_ops___177 {
	int (*prepare)(struct device___177 *);
	void (*complete)(struct device___177 *);
	int (*suspend)(struct device___177 *);
	int (*resume)(struct device___177 *);
	int (*freeze)(struct device___177 *);
	int (*thaw)(struct device___177 *);
	int (*poweroff)(struct device___177 *);
	int (*restore)(struct device___177 *);
	int (*suspend_late)(struct device___177 *);
	int (*resume_early)(struct device___177 *);
	int (*freeze_late)(struct device___177 *);
	int (*thaw_early)(struct device___177 *);
	int (*poweroff_late)(struct device___177 *);
	int (*restore_early)(struct device___177 *);
	int (*suspend_noirq)(struct device___177 *);
	int (*resume_noirq)(struct device___177 *);
	int (*freeze_noirq)(struct device___177 *);
	int (*thaw_noirq)(struct device___177 *);
	int (*poweroff_noirq)(struct device___177 *);
	int (*restore_noirq)(struct device___177 *);
	int (*runtime_suspend)(struct device___177 *);
	int (*runtime_resume)(struct device___177 *);
	int (*runtime_idle)(struct device___177 *);
};

struct dma_map_ops___73;

struct dev_archdata___73 {
	struct dma_map_ops___73 *dma_ops;
	void *iommu;
};

struct device_type___177;

struct bus_type___177;

struct device_driver___177;

struct dev_pm_domain___177;

struct class___177;

struct attribute_group___159;

struct device_rh___177;

struct device___177 {
	struct device___177 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___177 *type;
	struct mutex___203 mutex;
	struct bus_type___177 *bus;
	struct device_driver___177 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___177 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___73 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___177 *class;
	const struct attribute_group___159 **groups;
	void (*release)(struct device___177 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___177 *device_rh;
};

struct dev_pm_info_rh___177 {
	void (*set_latency_tolerance)(struct device___177 *, s32);
};

struct dev_pm_domain___177 {
	struct dev_pm_ops___177 ops;
};

struct smp_ops___202 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___202 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___201 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___201 *bd_inode;
	struct super_block___201 *bd_super;
	struct mutex___203 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___201 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___203 bd_fsfreeze_mutex;
};

struct iattr___201 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___201 *ia_file;
};

struct file___201 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___201 f_path;
	struct inode___201 *f_inode;
	const struct file_operations___201 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___201 *f_mapping;
	struct mutex___203 f_pos_lock;
};

struct zone___202;

struct lruvec___202 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___202 *zone;
};

struct pglist_data___202;

struct zone___202 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___202 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___202 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___202 {
	struct zone___202 *zone;
	int zone_idx;
};

struct zonelist___202 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___202 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___202 {
	struct zone___202 node_zones[4];
	struct zonelist___202 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___202 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___201 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___203 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___201 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___201 {
	int qf_fmt_id;
	const struct quota_format_ops___201 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___201 *qf_next;
};

struct quota_format_ops___201 {
	int (*check_quota_file)(struct super_block___201 *, int);
	int (*read_file_info)(struct super_block___201 *, int);
	int (*write_file_info)(struct super_block___201 *, int);
	int (*free_file_info)(struct super_block___201 *, int);
	int (*read_dqblk)(struct dquot___201 *);
	int (*commit_dqblk)(struct dquot___201 *);
	int (*release_dqblk)(struct dquot___201 *);
};

struct dquot_operations___201 {
	int (*write_dquot)(struct dquot___201 *);
	struct dquot___201 * (*alloc_dquot)(struct super_block___201 *, int);
	void (*destroy_dquot)(struct dquot___201 *);
	int (*acquire_dquot)(struct dquot___201 *);
	int (*release_dquot)(struct dquot___201 *);
	int (*mark_dirty)(struct dquot___201 *);
	int (*write_info)(struct super_block___201 *, int);
	qsize_t * (*get_reserved_space)(struct inode___201 *);
};

struct quotactl_ops___201 {
	int (*quota_on)(struct super_block___201 *, int, int, struct path___201 *);
	int (*quota_on_meta)(struct super_block___201 *, int, int);
	int (*quota_off)(struct super_block___201 *, int);
	int (*quota_sync)(struct super_block___201 *, int);
	int (*get_info)(struct super_block___201 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___201 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___201 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___201 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___201 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___201 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___201 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___201 *, unsigned int);
};

struct address_space_operations___201 {
	int (*writepage)(struct page___200 *, struct writeback_control *);
	int (*readpage)(struct file___201 *, struct page___200 *);
	int (*writepages)(struct address_space___201 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___200 *);
	int (*readpages)(struct file___201 *, struct address_space___201 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___201 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___200 **, void **);
	int (*write_end)(struct file___201 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___200 *, void *);
	sector_t (*bmap)(struct address_space___201 *, sector_t);
	void (*invalidatepage)(struct page___200 *, long unsigned int);
	int (*releasepage)(struct page___200 *, gfp_t);
	void (*freepage)(struct page___200 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___201 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___201 *, struct page___200 *, struct page___200 *, enum migrate_mode);
	int (*launder_page)(struct page___200 *);
	int (*is_partially_uptodate)(struct page___200 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___200 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___201 *, struct page___200 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___201 *, sector_t *);
	void (*swap_deactivate)(struct file___201 *);
	void (*invalidatepage_range)(struct page___200 *, unsigned int, unsigned int);
};

struct cdev___55 {
	struct kobject___20 kobj;
	struct module *owner;
	const struct file_operations___201 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___201 {
	struct dentry___201 * (*lookup)(struct inode___201 *, struct dentry___201 *, unsigned int);
	void * (*follow_link)(struct dentry___201 *, struct nameidata *);
	int (*permission)(struct inode___201 *, int);
	struct posix_acl * (*get_acl)(struct inode___201 *, int);
	int (*readlink)(struct dentry___201 *, char *, int);
	void (*put_link)(struct dentry___201 *, struct nameidata *, void *);
	int (*create)(struct inode___201 *, struct dentry___201 *, umode_t, bool);
	int (*link)(struct dentry___201 *, struct inode___201 *, struct dentry___201 *);
	int (*unlink)(struct inode___201 *, struct dentry___201 *);
	int (*symlink)(struct inode___201 *, struct dentry___201 *, const char *);
	int (*mkdir)(struct inode___201 *, struct dentry___201 *, umode_t);
	int (*rmdir)(struct inode___201 *, struct dentry___201 *);
	int (*mknod)(struct inode___201 *, struct dentry___201 *, umode_t, dev_t);
	int (*rename)(struct inode___201 *, struct dentry___201 *, struct inode___201 *, struct dentry___201 *);
	int (*setattr)(struct dentry___201 *, struct iattr___201 *);
	int (*getattr)(struct vfsmount *, struct dentry___201 *, struct kstat *);
	int (*setxattr)(struct dentry___201 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___201 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___201 *, char *, size_t);
	int (*removexattr)(struct dentry___201 *, const char *);
	int (*fiemap)(struct inode___201 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___201 *, struct timespec *, int);
	int (*atomic_open)(struct inode___201 *, struct dentry___201 *, struct file___201 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___201 {
	struct module *owner;
	loff_t (*llseek)(struct file___201 *, loff_t, int);
	ssize_t (*read)(struct file___201 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___201 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___201 *, void *, filldir_t);
	unsigned int (*poll)(struct file___201 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___201 *, struct vm_area_struct___209 *);
	int (*open)(struct inode___201 *, struct file___201 *);
	int (*flush)(struct file___201 *, fl_owner_t);
	int (*release)(struct inode___201 *, struct file___201 *);
	int (*fsync)(struct file___201 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___201 *, int);
	int (*lock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*sendpage)(struct file___201 *, struct page___200 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___201 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___201 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___201 *, long int, struct file_lock___201 **, void **);
		struct {
			int (*setlease)(struct file___201 *, long int, struct file_lock___201 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___201 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___201 *);
};

struct fasync_struct___201;

struct file_lock_operations___201;

struct lock_manager_operations___201;

struct file_lock___201 {
	struct file_lock___201 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___201 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___201 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___201 *fl_ops;
	const struct lock_manager_operations___201 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___201 {
	void (*fl_copy_lock)(struct file_lock___201 *, struct file_lock___201 *);
	void (*fl_release_private)(struct file_lock___201 *);
};

struct lock_manager_operations___201 {
	int (*lm_compare_owner)(struct file_lock___201 *, struct file_lock___201 *);
	long unsigned int (*lm_owner_key)(struct file_lock___201 *);
	void (*lm_notify)(struct file_lock___201 *);
	int (*lm_grant)(struct file_lock___201 *, struct file_lock___201 *, int);
	void (*lm_break)(struct file_lock___201 *);
	int (*lm_change)(struct file_lock___201 **, int);
};

struct fasync_struct___201 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___201 *fa_next;
	struct file___201 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___201 {
	const char *name;
	int fs_flags;
	struct dentry___201 * (*mount)(struct file_system_type___201 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___201 *);
	struct module *owner;
	struct file_system_type___201 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___201 {
	struct inode___201 * (*alloc_inode)(struct super_block___201 *);
	void (*destroy_inode)(struct inode___201 *);
	void (*dirty_inode)(struct inode___201 *, int);
	int (*write_inode)(struct inode___201 *, struct writeback_control *);
	int (*drop_inode)(struct inode___201 *);
	void (*evict_inode)(struct inode___201 *);
	void (*put_super)(struct super_block___201 *);
	int (*sync_fs)(struct super_block___201 *, int);
	int (*freeze_fs)(struct super_block___201 *);
	int (*unfreeze_fs)(struct super_block___201 *);
	int (*statfs)(struct dentry___201 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___201 *, int *, char *);
	void (*umount_begin)(struct super_block___201 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___201 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___201 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___201 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___201 *);
	ssize_t (*quota_read)(struct super_block___201 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___201 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___201 *);
	int (*bdev_try_to_free_page)(struct super_block___201 *, struct page___200 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___201 *);
	void (*free_cached_objects)(struct super_block___201 *, int);
};

struct vm_operations_struct___181;

struct vm_area_struct___209 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___209 *vm_next;
	struct vm_area_struct___209 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___209 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___181 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___201 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___161;

struct attribute_group___159 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___161 **bin_attrs;
};

struct bin_attribute___161 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___201 *, struct kobject___20 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___201 *, struct kobject___20 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	int (*mmap)(struct file___201 *, struct kobject___20 *, struct bin_attribute___161 *, struct vm_area_struct___209 *);
};

struct tty_struct___26;

struct tty_driver___26;

struct tty_operations___26 {
	struct tty_struct___26 * (*lookup)(struct tty_driver___26 *, struct inode___201 *, int);
	int (*install)(struct tty_driver___26 *, struct tty_struct___26 *);
	void (*remove)(struct tty_driver___26 *, struct tty_struct___26 *);
	int (*open)(struct tty_struct___26 *, struct file___201 *);
	void (*close)(struct tty_struct___26 *, struct file___201 *);
	void (*shutdown)(struct tty_struct___26 *);
	void (*cleanup)(struct tty_struct___26 *);
	int (*write)(struct tty_struct___26 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___26 *, unsigned char);
	void (*flush_chars)(struct tty_struct___26 *);
	int (*write_room)(struct tty_struct___26 *);
	int (*chars_in_buffer)(struct tty_struct___26 *);
	int (*ioctl)(struct tty_struct___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___26 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___26 *, struct ktermios *);
	void (*throttle)(struct tty_struct___26 *);
	void (*unthrottle)(struct tty_struct___26 *);
	void (*stop)(struct tty_struct___26 *);
	void (*start)(struct tty_struct___26 *);
	void (*hangup)(struct tty_struct___26 *);
	int (*break_ctl)(struct tty_struct___26 *, int);
	void (*flush_buffer)(struct tty_struct___26 *);
	void (*set_ldisc)(struct tty_struct___26 *);
	void (*wait_until_sent)(struct tty_struct___26 *, int);
	void (*send_xchar)(struct tty_struct___26 *, char);
	int (*tiocmget)(struct tty_struct___26 *);
	int (*tiocmset)(struct tty_struct___26 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___26 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___26 *, struct termiox *);
	int (*get_icount)(struct tty_struct___26 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___26 *, int, char *);
	int (*poll_get_char)(struct tty_driver___26 *, int);
	void (*poll_put_char)(struct tty_driver___26 *, int, char);
	const struct file_operations___201 *proc_fops;
};

struct tty_ldisc___26;

struct tty_port___26;

struct tty_struct___26 {
	int magic;
	struct kref kref;
	struct device___177 *dev;
	struct tty_driver___26 *driver;
	const struct tty_operations___26 *ops;
	int index;
	struct mutex___203 ldisc_mutex;
	struct tty_ldisc___26 *ldisc;
	struct mutex___203 atomic_write_lock;
	struct mutex___203 legacy_mutex;
	struct mutex___203 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___26 *link;
	struct fasync_struct___201 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___26 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___26 {
	int magic;
	struct kref kref;
	struct cdev___55 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___26 *other;
	struct tty_struct___26 **ttys;
	struct tty_port___26 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___26 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___26;

struct tty_port___26 {
	struct tty_bufhead buf;
	struct tty_struct___26 *tty;
	struct tty_struct___26 *itty;
	const struct tty_port_operations___26 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___203 mutex;
	struct mutex___203 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___26 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___26 *);
	void (*close)(struct tty_struct___26 *);
	void (*flush_buffer)(struct tty_struct___26 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___26 *);
	ssize_t (*read)(struct tty_struct___26 *, struct file___201 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___26 *, struct file___201 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___26 *, struct file___201 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___26 *, struct file___201 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___26 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___26 *, struct file___201 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___26 *);
	void (*receive_buf)(struct tty_struct___26 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___26 *);
	void (*dcd_change)(struct tty_struct___26 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___26 *, int);
};

struct tty_ldisc___26 {
	struct tty_ldisc_ops___26 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___26 *tty;
};

struct tty_port_operations___26 {
	int (*carrier_raised)(struct tty_port___26 *);
	void (*dtr_rts)(struct tty_port___26 *, int);
	void (*shutdown)(struct tty_port___26 *);
	void (*drop)(struct tty_port___26 *);
	int (*activate)(struct tty_port___26 *, struct tty_struct___26 *);
	void (*destruct)(struct tty_port___26 *);
};

struct dma_map_ops___73 {
	void * (*alloc)(struct device___177 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___177 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___177 *, struct vm_area_struct___209 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___177 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___177 *, struct page___200 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___177 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___177 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___177 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___177 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___177 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___177 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___177 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___177 *, dma_addr_t);
	int (*dma_supported)(struct device___177 *, u64);
	int (*set_dma_mask)(struct device___177 *, u64);
	int is_phys;
};

struct bus_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___177 *, char *);
	ssize_t (*store)(struct bus_type___177 *, const char *, size_t);
};

struct device_attribute___177;

struct driver_attribute___177;

struct bus_type___177 {
	const char *name;
	const char *dev_name;
	struct device___177 *dev_root;
	struct bus_attribute___177 *bus_attrs;
	struct device_attribute___177 *dev_attrs;
	struct driver_attribute___177 *drv_attrs;
	const struct attribute_group___159 **bus_groups;
	const struct attribute_group___159 **dev_groups;
	const struct attribute_group___159 **drv_groups;
	int (*match)(struct device___177 *, struct device_driver___177 *);
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	int (*probe)(struct device___177 *);
	int (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*online)(struct device___177 *);
	int (*offline)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct device___177 *, struct device_attribute___177 *, char *);
	ssize_t (*store)(struct device___177 *, struct device_attribute___177 *, const char *, size_t);
};

struct driver_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___177 *, char *);
	ssize_t (*store)(struct device_driver___177 *, const char *, size_t);
};

struct device_driver___177 {
	const char *name;
	struct bus_type___177 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___177 *);
	int (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	const struct attribute_group___159 **groups;
	const struct dev_pm_ops___177 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___177 {
	const char *name;
	const struct attribute_group___159 **groups;
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
};

struct class_attribute___177;

struct class___177 {
	const char *name;
	struct module *owner;
	struct class_attribute___177 *class_attrs;
	struct device_attribute___177 *dev_attrs;
	const struct attribute_group___159 **dev_groups;
	struct bin_attribute___161 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *);
	void (*class_release)(struct class___177 *);
	void (*dev_release)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
	struct subsys_private *p;
};

struct class_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct class___177 *, struct class_attribute___177 *, char *);
	ssize_t (*store)(struct class___177 *, struct class_attribute___177 *, const char *, size_t);
	const void * (*namespace)(struct class___177 *, const struct class_attribute___177 *);
};

struct device_rh___177 {
	struct dev_pm_info_rh___177 power;
};

struct xol_area___200 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___200 *page;
	long unsigned int vaddr;
};

struct vm_fault___177;

struct vm_operations_struct___181 {
	void (*open)(struct vm_area_struct___209 *);
	void (*close)(struct vm_area_struct___209 *);
	int (*fault)(struct vm_area_struct___209 *, struct vm_fault___177 *);
	int (*page_mkwrite)(struct vm_area_struct___209 *, struct vm_fault___177 *);
	int (*access)(struct vm_area_struct___209 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___209 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___209 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___209 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___209 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___202 {
	struct task_struct___202 *task;
	struct core_thread___202 *next;
};

struct core_state___202 {
	atomic_t nr_threads;
	struct core_thread___202 dumper;
	struct completion startup;
};

struct vm_fault___177 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___200 *page;
};

struct signal_struct___202 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___202 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___202 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___26 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___203 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct uart_port___4;

struct uart_ops___4 {
	unsigned int (*tx_empty)(struct uart_port___4 *);
	void (*set_mctrl)(struct uart_port___4 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___4 *);
	void (*stop_tx)(struct uart_port___4 *);
	void (*start_tx)(struct uart_port___4 *);
	void (*throttle)(struct uart_port___4 *);
	void (*unthrottle)(struct uart_port___4 *);
	void (*send_xchar)(struct uart_port___4 *, char);
	void (*stop_rx)(struct uart_port___4 *);
	void (*enable_ms)(struct uart_port___4 *);
	void (*break_ctl)(struct uart_port___4 *, int);
	int (*startup)(struct uart_port___4 *);
	void (*shutdown)(struct uart_port___4 *);
	void (*flush_buffer)(struct uart_port___4 *);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___4 *, int);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port___4 *, unsigned int);
	const char * (*type)(struct uart_port___4 *);
	void (*release_port)(struct uart_port___4 *);
	int (*request_port)(struct uart_port___4 *);
	void (*config_port)(struct uart_port___4 *, int);
	int (*verify_port)(struct uart_port___4 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___4 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___4 *);
	void (*poll_put_char)(struct uart_port___4 *, unsigned char);
	int (*poll_get_char)(struct uart_port___4 *);
};

struct uart_state___4;

struct uart_port___4 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___4 *, int);
	void (*serial_out)(struct uart_port___4 *, int, int);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___4 *);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___4 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___4 *state;
	struct uart_icount icount;
	struct console___10 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___4 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device___177 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

struct uart_state___4 {
	struct tty_port___26 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port___4 *uart_port;
};

struct uart_8250_dma___3;

struct uart_8250_port___3 {
	struct uart_port___4 port;
	struct timer_list timer;
	struct list_head list;
	short unsigned int capabilities;
	short unsigned int bugs;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___3 *dma;
	int (*dl_read)(struct uart_8250_port___3 *);
	void (*dl_write)(struct uart_8250_port___3 *, int);
};

struct dma_chan___5;

typedef bool (*dma_filter_fn___4)(struct dma_chan___5 *, void *);

struct uart_8250_dma___3 {
	dma_filter_fn___4 fn;
	void *rx_param;
	void *tx_param;
	int rx_chan_id;
	int tx_chan_id;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___5 *rxchan;
	struct dma_chan___5 *txchan;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running: 1;
};

struct dma_device___4;

struct dma_chan_dev___4;

struct dma_chan___5 {
	struct dma_device___4 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___4 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___4;

struct dma_device___4 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___177 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___5 *);
	void (*device_free_chan_resources)(struct dma_chan___5 *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memcpy)(struct dma_chan___5 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor)(struct dma_chan___5 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor_val)(struct dma_chan___5 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq_val)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memset)(struct dma_chan___5 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_interrupt)(struct dma_chan___5 *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_slave_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_cyclic)(struct dma_chan___5 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___4 * (*device_prep_interleaved_dma)(struct dma_chan___5 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___5 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___5 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___5 *);
};

struct dma_chan_dev___4 {
	struct dma_chan___5 *chan;
	struct device___177 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___4 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___5 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___4 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct page___201;

typedef struct page___201 *pgtable_t___201;

struct address_space___202;

struct kmem_cache___187;

struct page___201 {
	long unsigned int flags;
	struct address_space___202 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___201 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___201 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___187 *slab_cache;
		struct page___201 *first_page;
	};
	long: 64;
};

struct task_struct___203;

struct pv_cpu_ops___203 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___203 *);
	void (*end_context_switch)(struct task_struct___203 *);
};

struct mutex___204 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___203 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___196 {
	struct page___201 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___210;

struct signal_struct___203;

struct task_struct___203 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___203 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___210 *mm;
	struct mm_struct___210 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___203 *real_parent;
	struct task_struct___203 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___203 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___203 = 0,
		VTIME_USER___203 = 1,
		VTIME_SYS___203 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___203 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___204 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___196 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___210 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___210 *, struct mm_struct___210 *);
	void (*dup_mmap)(struct mm_struct___210 *, struct mm_struct___210 *);
	void (*exit_mmap)(struct mm_struct___210 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___210 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___210 *);
	void (*pgd_free)(struct mm_struct___210 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___210 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___210 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___210 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___210 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___210 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___210 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___210 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___210 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___210 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___210 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___210 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___204 lock;
	void *vdso;
} mm_context_t___204;

struct xol_area___201;

struct uprobes_state___201 {
	struct xol_area___201 *xol_area;
};

struct vm_area_struct___210;

struct file___202;

struct core_state___203;

struct mm_struct___210 {
	struct vm_area_struct___210 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___210 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___210 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___204 context;
	long unsigned int flags;
	struct core_state___203 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___203 *owner;
	struct file___202 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___201 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___115;

struct module_kobject___114 {
	struct kobject___20 kobj;
	struct module___115 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___114;

struct module___115 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___114 mkobj;
	struct module_attribute___114 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___203 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___203;

struct lruvec___203 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___203 *zone;
};

struct pglist_data___203;

struct zone___203 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___203 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___203 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___203 {
	struct zone___203 *zone;
	int zone_idx;
};

struct zonelist___203 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___203 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___203 {
	struct zone___203 node_zones[4];
	struct zonelist___203 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___203 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___74;

struct dev_archdata___74 {
	struct dma_map_ops___74 *dma_ops;
	void *iommu;
};

struct device_type___178;

struct bus_type___178;

struct device_driver___178;

struct dev_pm_domain___178;

struct class___178;

struct attribute_group___160;

struct device_rh___178;

struct device___178 {
	struct device___178 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___178 *type;
	struct mutex___204 mutex;
	struct bus_type___178 *bus;
	struct device_driver___178 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___178 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___26 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___178 *class;
	const struct attribute_group___160 **groups;
	void (*release)(struct device___178 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___178 *device_rh;
};

struct pci_bus___24;

struct pci_slot___24;

struct pci_driver___24;

struct bin_attribute___162;

struct pci_dev___24 {
	struct list_head bus_list;
	struct pci_bus___24 *bus;
	struct pci_bus___24 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___24 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___24 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___178 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___162 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___162 *res_attr[17];
	struct bin_attribute___162 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___160 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___24 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___178 {
	int (*prepare)(struct device___178 *);
	void (*complete)(struct device___178 *);
	int (*suspend)(struct device___178 *);
	int (*resume)(struct device___178 *);
	int (*freeze)(struct device___178 *);
	int (*thaw)(struct device___178 *);
	int (*poweroff)(struct device___178 *);
	int (*restore)(struct device___178 *);
	int (*suspend_late)(struct device___178 *);
	int (*resume_early)(struct device___178 *);
	int (*freeze_late)(struct device___178 *);
	int (*thaw_early)(struct device___178 *);
	int (*poweroff_late)(struct device___178 *);
	int (*restore_early)(struct device___178 *);
	int (*suspend_noirq)(struct device___178 *);
	int (*resume_noirq)(struct device___178 *);
	int (*freeze_noirq)(struct device___178 *);
	int (*thaw_noirq)(struct device___178 *);
	int (*poweroff_noirq)(struct device___178 *);
	int (*restore_noirq)(struct device___178 *);
	int (*runtime_suspend)(struct device___178 *);
	int (*runtime_resume)(struct device___178 *);
	int (*runtime_idle)(struct device___178 *);
};

struct dev_pm_info_rh___178 {
	void (*set_latency_tolerance)(struct device___178 *, s32);
};

struct dev_pm_domain___178 {
	struct dev_pm_ops___178 ops;
};

struct smp_ops___203 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___203 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct attribute_group___160 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___162 **bin_attrs;
};

struct bin_attribute___162 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___202 *, struct kobject___20 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___202 *, struct kobject___20 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	int (*mmap)(struct file___202 *, struct kobject___20 *, struct bin_attribute___162 *, struct vm_area_struct___210 *);
};

struct dentry___202;

struct path___202 {
	struct vfsmount *mnt;
	struct dentry___202 *dentry;
};

struct inode___202;

struct file_operations___202;

struct file___202 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___202 f_path;
	struct inode___202 *f_inode;
	const struct file_operations___202 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___202 *f_mapping;
	struct mutex___204 f_pos_lock;
};

struct vm_operations_struct___182;

struct vm_area_struct___210 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___210 *vm_next;
	struct vm_area_struct___210 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___210 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___182 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___202 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___114 *, struct module_kobject___114 *, char *);
	ssize_t (*store)(struct module_attribute___114 *, struct module_kobject___114 *, const char *, size_t);
	void (*setup)(struct module___115 *, const char *);
	int (*test)(struct module___115 *);
	void (*free)(struct module___115 *);
};

struct dma_map_ops___74 {
	void * (*alloc)(struct device___178 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___178 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___178 *, struct vm_area_struct___210 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___178 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___178 *, struct page___201 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___178 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___178 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___178 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___178 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___178 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___178 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___178 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___178 *, dma_addr_t);
	int (*dma_supported)(struct device___178 *, u64);
	int (*set_dma_mask)(struct device___178 *, u64);
	int is_phys;
};

struct bus_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___178 *, char *);
	ssize_t (*store)(struct bus_type___178 *, const char *, size_t);
};

struct device_attribute___178;

struct driver_attribute___178;

struct bus_type___178 {
	const char *name;
	const char *dev_name;
	struct device___178 *dev_root;
	struct bus_attribute___178 *bus_attrs;
	struct device_attribute___178 *dev_attrs;
	struct driver_attribute___178 *drv_attrs;
	const struct attribute_group___160 **bus_groups;
	const struct attribute_group___160 **dev_groups;
	const struct attribute_group___160 **drv_groups;
	int (*match)(struct device___178 *, struct device_driver___178 *);
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	int (*probe)(struct device___178 *);
	int (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*online)(struct device___178 *);
	int (*offline)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct device___178 *, struct device_attribute___178 *, char *);
	ssize_t (*store)(struct device___178 *, struct device_attribute___178 *, const char *, size_t);
};

struct driver_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___178 *, char *);
	ssize_t (*store)(struct device_driver___178 *, const char *, size_t);
};

struct device_driver___178 {
	const char *name;
	struct bus_type___178 *bus;
	struct module___115 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___178 *);
	int (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	const struct attribute_group___160 **groups;
	const struct dev_pm_ops___178 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___178 {
	const char *name;
	const struct attribute_group___160 **groups;
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
};

struct class_attribute___178;

struct class___178 {
	const char *name;
	struct module___115 *owner;
	struct class_attribute___178 *class_attrs;
	struct device_attribute___178 *dev_attrs;
	const struct attribute_group___160 **dev_groups;
	struct bin_attribute___162 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *);
	void (*class_release)(struct class___178 *);
	void (*dev_release)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
	struct subsys_private *p;
};

struct class_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct class___178 *, struct class_attribute___178 *, char *);
	ssize_t (*store)(struct class___178 *, struct class_attribute___178 *, const char *, size_t);
	const void * (*namespace)(struct class___178 *, const struct class_attribute___178 *);
};

struct device_rh___178 {
	struct dev_pm_info_rh___178 power;
};

struct pci_slot___24 {
	struct pci_bus___24 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_ops___24;

struct pci_bus___24 {
	struct list_head node;
	struct pci_bus___24 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___24 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___24 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___178 *bridge;
	struct device___178 dev;
	struct bin_attribute___162 *legacy_io;
	struct bin_attribute___162 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___24;

struct pci_driver_rh___24;

struct pci_driver___24 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___24 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___24 *);
	int (*suspend)(struct pci_dev___24 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___24 *, pm_message_t);
	int (*resume_early)(struct pci_dev___24 *);
	int (*resume)(struct pci_dev___24 *);
	void (*shutdown)(struct pci_dev___24 *);
	int (*sriov_configure)(struct pci_dev___24 *, int);
	const struct pci_error_handlers___24 *err_handler;
	struct device_driver___178 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___24 *pci_driver_rh;
};

struct pci_ops___24 {
	int (*read)(struct pci_bus___24 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___24 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___24 {
	pci_ers_result_t (*error_detected)(struct pci_dev___24 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___24 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___24 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___24 *);
	void (*resume)(struct pci_dev___24 *);
};

struct pci_driver_rh___24 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___24 *, bool);
};

struct xol_area___201 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___201 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___186;

struct memcg_cache_params___187;

struct kmem_cache___187 {
	struct kmem_cache_cpu___186 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___187 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___202;

struct address_space___202 {
	struct inode___202 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___204 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___202 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___178;

struct vm_operations_struct___182 {
	void (*open)(struct vm_area_struct___210 *);
	void (*close)(struct vm_area_struct___210 *);
	int (*fault)(struct vm_area_struct___210 *, struct vm_fault___178 *);
	int (*page_mkwrite)(struct vm_area_struct___210 *, struct vm_fault___178 *);
	int (*access)(struct vm_area_struct___210 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___210 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___210 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___210 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___210 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___203 {
	struct task_struct___203 *task;
	struct core_thread___203 *next;
};

struct core_state___203 {
	atomic_t nr_threads;
	struct core_thread___203 dumper;
	struct completion startup;
};

struct vm_fault___178 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___201 *page;
};

struct kmem_cache_cpu___186 {
	void **freelist;
	long unsigned int tid;
	struct page___201 *page;
	struct page___201 *partial;
};

struct memcg_cache_params___187 {
	bool is_root_cache;
	union {
		struct kmem_cache___187 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___187 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___202;

struct super_block___202;

struct dentry___202 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___202 *d_parent;
	struct qstr d_name;
	struct inode___202 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___202 *d_op;
	struct super_block___202 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___202;

struct file_lock___202;

struct dquot___202;

struct block_device___202;

struct cdev___56;

struct inode___202 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___202 *i_op;
	struct super_block___202 *i_sb;
	struct address_space___202 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___204 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___202 *i_fop;
	struct file_lock___202 *i_flock;
	struct address_space___202 i_data;
	struct dquot___202 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___202 *i_bdev;
		struct cdev___56 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___202 {
	int (*d_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_hash)(const struct dentry___202 *, struct qstr *);
	int (*d_compare)(const struct dentry___202 *, const struct dentry___202 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___202 *);
	void (*d_release)(struct dentry___202 *);
	void (*d_prune)(struct dentry___202 *);
	void (*d_iput)(struct dentry___202 *, struct inode___202 *);
	char * (*d_dname)(struct dentry___202 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___202 *);
	int (*d_manage)(struct dentry___202 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___202;

struct mem_dqinfo___202 {
	struct quota_format_type___202 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___202;

struct quota_info___202 {
	unsigned int flags;
	struct mutex___204 dqio_mutex;
	struct mutex___204 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___202 *files[2];
	struct mem_dqinfo___202 info[2];
	const struct quota_format_ops___202 *ops[2];
};

struct file_system_type___202;

struct super_operations___202;

struct dquot_operations___202;

struct quotactl_ops___202;

struct super_block___202 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___202 *s_type;
	const struct super_operations___202 *s_op;
	const struct dquot_operations___202 *dq_op;
	const struct quotactl_ops___202 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___202 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___202 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___202 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___204 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___202 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___202 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___202 *bd_inode;
	struct super_block___202 *bd_super;
	struct mutex___204 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___202 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___204 bd_fsfreeze_mutex;
};

struct iattr___202 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___202 *ia_file;
};

struct dquot___202 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___204 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___202 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___202 {
	int qf_fmt_id;
	const struct quota_format_ops___202 *qf_ops;
	struct module___115 *qf_owner;
	struct quota_format_type___202 *qf_next;
};

struct quota_format_ops___202 {
	int (*check_quota_file)(struct super_block___202 *, int);
	int (*read_file_info)(struct super_block___202 *, int);
	int (*write_file_info)(struct super_block___202 *, int);
	int (*free_file_info)(struct super_block___202 *, int);
	int (*read_dqblk)(struct dquot___202 *);
	int (*commit_dqblk)(struct dquot___202 *);
	int (*release_dqblk)(struct dquot___202 *);
};

struct dquot_operations___202 {
	int (*write_dquot)(struct dquot___202 *);
	struct dquot___202 * (*alloc_dquot)(struct super_block___202 *, int);
	void (*destroy_dquot)(struct dquot___202 *);
	int (*acquire_dquot)(struct dquot___202 *);
	int (*release_dquot)(struct dquot___202 *);
	int (*mark_dirty)(struct dquot___202 *);
	int (*write_info)(struct super_block___202 *, int);
	qsize_t * (*get_reserved_space)(struct inode___202 *);
};

struct quotactl_ops___202 {
	int (*quota_on)(struct super_block___202 *, int, int, struct path___202 *);
	int (*quota_on_meta)(struct super_block___202 *, int, int);
	int (*quota_off)(struct super_block___202 *, int);
	int (*quota_sync)(struct super_block___202 *, int);
	int (*get_info)(struct super_block___202 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___202 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___202 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___202 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___202 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___202 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___202 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___202 *, unsigned int);
};

struct address_space_operations___202 {
	int (*writepage)(struct page___201 *, struct writeback_control *);
	int (*readpage)(struct file___202 *, struct page___201 *);
	int (*writepages)(struct address_space___202 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___201 *);
	int (*readpages)(struct file___202 *, struct address_space___202 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___202 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___201 **, void **);
	int (*write_end)(struct file___202 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___201 *, void *);
	sector_t (*bmap)(struct address_space___202 *, sector_t);
	void (*invalidatepage)(struct page___201 *, long unsigned int);
	int (*releasepage)(struct page___201 *, gfp_t);
	void (*freepage)(struct page___201 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___202 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___202 *, struct page___201 *, struct page___201 *, enum migrate_mode);
	int (*launder_page)(struct page___201 *);
	int (*is_partially_uptodate)(struct page___201 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___201 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___202 *, struct page___201 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___202 *, sector_t *);
	void (*swap_deactivate)(struct file___202 *);
	void (*invalidatepage_range)(struct page___201 *, unsigned int, unsigned int);
};

struct cdev___56 {
	struct kobject___20 kobj;
	struct module___115 *owner;
	const struct file_operations___202 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___202 {
	struct dentry___202 * (*lookup)(struct inode___202 *, struct dentry___202 *, unsigned int);
	void * (*follow_link)(struct dentry___202 *, struct nameidata *);
	int (*permission)(struct inode___202 *, int);
	struct posix_acl * (*get_acl)(struct inode___202 *, int);
	int (*readlink)(struct dentry___202 *, char *, int);
	void (*put_link)(struct dentry___202 *, struct nameidata *, void *);
	int (*create)(struct inode___202 *, struct dentry___202 *, umode_t, bool);
	int (*link)(struct dentry___202 *, struct inode___202 *, struct dentry___202 *);
	int (*unlink)(struct inode___202 *, struct dentry___202 *);
	int (*symlink)(struct inode___202 *, struct dentry___202 *, const char *);
	int (*mkdir)(struct inode___202 *, struct dentry___202 *, umode_t);
	int (*rmdir)(struct inode___202 *, struct dentry___202 *);
	int (*mknod)(struct inode___202 *, struct dentry___202 *, umode_t, dev_t);
	int (*rename)(struct inode___202 *, struct dentry___202 *, struct inode___202 *, struct dentry___202 *);
	int (*setattr)(struct dentry___202 *, struct iattr___202 *);
	int (*getattr)(struct vfsmount *, struct dentry___202 *, struct kstat *);
	int (*setxattr)(struct dentry___202 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___202 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___202 *, char *, size_t);
	int (*removexattr)(struct dentry___202 *, const char *);
	int (*fiemap)(struct inode___202 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___202 *, struct timespec *, int);
	int (*atomic_open)(struct inode___202 *, struct dentry___202 *, struct file___202 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___202 {
	struct module___115 *owner;
	loff_t (*llseek)(struct file___202 *, loff_t, int);
	ssize_t (*read)(struct file___202 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___202 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___202 *, void *, filldir_t);
	unsigned int (*poll)(struct file___202 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___202 *, struct vm_area_struct___210 *);
	int (*open)(struct inode___202 *, struct file___202 *);
	int (*flush)(struct file___202 *, fl_owner_t);
	int (*release)(struct inode___202 *, struct file___202 *);
	int (*fsync)(struct file___202 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___202 *, int);
	int (*lock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*sendpage)(struct file___202 *, struct page___201 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___202 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___202 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___202 *, long int, struct file_lock___202 **, void **);
		struct {
			int (*setlease)(struct file___202 *, long int, struct file_lock___202 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___202 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___202 *);
};

struct fasync_struct___202;

struct file_lock_operations___202;

struct lock_manager_operations___202;

struct file_lock___202 {
	struct file_lock___202 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___202 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___202 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___202 *fl_ops;
	const struct lock_manager_operations___202 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___202 {
	void (*fl_copy_lock)(struct file_lock___202 *, struct file_lock___202 *);
	void (*fl_release_private)(struct file_lock___202 *);
};

struct lock_manager_operations___202 {
	int (*lm_compare_owner)(struct file_lock___202 *, struct file_lock___202 *);
	long unsigned int (*lm_owner_key)(struct file_lock___202 *);
	void (*lm_notify)(struct file_lock___202 *);
	int (*lm_grant)(struct file_lock___202 *, struct file_lock___202 *, int);
	void (*lm_break)(struct file_lock___202 *);
	int (*lm_change)(struct file_lock___202 **, int);
};

struct fasync_struct___202 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___202 *fa_next;
	struct file___202 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___202 {
	const char *name;
	int fs_flags;
	struct dentry___202 * (*mount)(struct file_system_type___202 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___202 *);
	struct module___115 *owner;
	struct file_system_type___202 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___202 {
	struct inode___202 * (*alloc_inode)(struct super_block___202 *);
	void (*destroy_inode)(struct inode___202 *);
	void (*dirty_inode)(struct inode___202 *, int);
	int (*write_inode)(struct inode___202 *, struct writeback_control *);
	int (*drop_inode)(struct inode___202 *);
	void (*evict_inode)(struct inode___202 *);
	void (*put_super)(struct super_block___202 *);
	int (*sync_fs)(struct super_block___202 *, int);
	int (*freeze_fs)(struct super_block___202 *);
	int (*unfreeze_fs)(struct super_block___202 *);
	int (*statfs)(struct dentry___202 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___202 *, int *, char *);
	void (*umount_begin)(struct super_block___202 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___202 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___202 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___202 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___202 *);
	ssize_t (*quota_read)(struct super_block___202 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___202 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___202 *);
	int (*bdev_try_to_free_page)(struct super_block___202 *, struct page___201 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___202 *);
	void (*free_cached_objects)(struct super_block___202 *, int);
};

struct tty_struct___27;

struct tty_driver___27;

struct tty_operations___27 {
	struct tty_struct___27 * (*lookup)(struct tty_driver___27 *, struct inode___202 *, int);
	int (*install)(struct tty_driver___27 *, struct tty_struct___27 *);
	void (*remove)(struct tty_driver___27 *, struct tty_struct___27 *);
	int (*open)(struct tty_struct___27 *, struct file___202 *);
	void (*close)(struct tty_struct___27 *, struct file___202 *);
	void (*shutdown)(struct tty_struct___27 *);
	void (*cleanup)(struct tty_struct___27 *);
	int (*write)(struct tty_struct___27 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___27 *, unsigned char);
	void (*flush_chars)(struct tty_struct___27 *);
	int (*write_room)(struct tty_struct___27 *);
	int (*chars_in_buffer)(struct tty_struct___27 *);
	int (*ioctl)(struct tty_struct___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___27 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___27 *, struct ktermios *);
	void (*throttle)(struct tty_struct___27 *);
	void (*unthrottle)(struct tty_struct___27 *);
	void (*stop)(struct tty_struct___27 *);
	void (*start)(struct tty_struct___27 *);
	void (*hangup)(struct tty_struct___27 *);
	int (*break_ctl)(struct tty_struct___27 *, int);
	void (*flush_buffer)(struct tty_struct___27 *);
	void (*set_ldisc)(struct tty_struct___27 *);
	void (*wait_until_sent)(struct tty_struct___27 *, int);
	void (*send_xchar)(struct tty_struct___27 *, char);
	int (*tiocmget)(struct tty_struct___27 *);
	int (*tiocmset)(struct tty_struct___27 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___27 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___27 *, struct termiox *);
	int (*get_icount)(struct tty_struct___27 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___27 *, int, char *);
	int (*poll_get_char)(struct tty_driver___27 *, int);
	void (*poll_put_char)(struct tty_driver___27 *, int, char);
	const struct file_operations___202 *proc_fops;
};

struct tty_ldisc___27;

struct tty_port___27;

struct tty_struct___27 {
	int magic;
	struct kref kref;
	struct device___178 *dev;
	struct tty_driver___27 *driver;
	const struct tty_operations___27 *ops;
	int index;
	struct mutex___204 ldisc_mutex;
	struct tty_ldisc___27 *ldisc;
	struct mutex___204 atomic_write_lock;
	struct mutex___204 legacy_mutex;
	struct mutex___204 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___27 *link;
	struct fasync_struct___202 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___27 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___27 {
	int magic;
	struct kref kref;
	struct cdev___56 *cdevs;
	struct module___115 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___27 *other;
	struct tty_struct___27 **ttys;
	struct tty_port___27 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___27 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___27;

struct tty_port___27 {
	struct tty_bufhead buf;
	struct tty_struct___27 *tty;
	struct tty_struct___27 *itty;
	const struct tty_port_operations___27 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___204 mutex;
	struct mutex___204 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___27 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___27 *);
	void (*close)(struct tty_struct___27 *);
	void (*flush_buffer)(struct tty_struct___27 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___27 *);
	ssize_t (*read)(struct tty_struct___27 *, struct file___202 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___27 *, struct file___202 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___27 *, struct file___202 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___27 *, struct file___202 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___27 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___27 *, struct file___202 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___27 *);
	void (*receive_buf)(struct tty_struct___27 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___27 *);
	void (*dcd_change)(struct tty_struct___27 *, unsigned int);
	struct module___115 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___27 *, int);
};

struct tty_ldisc___27 {
	struct tty_ldisc_ops___27 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___27 *tty;
};

struct tty_port_operations___27 {
	int (*carrier_raised)(struct tty_port___27 *);
	void (*dtr_rts)(struct tty_port___27 *, int);
	void (*shutdown)(struct tty_port___27 *);
	void (*drop)(struct tty_port___27 *);
	int (*activate)(struct tty_port___27 *, struct tty_struct___27 *);
	void (*destruct)(struct tty_port___27 *);
};

struct signal_struct___203 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___203 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___203 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___27 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___204 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct uart_port___5;

struct uart_ops___5 {
	unsigned int (*tx_empty)(struct uart_port___5 *);
	void (*set_mctrl)(struct uart_port___5 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___5 *);
	void (*stop_tx)(struct uart_port___5 *);
	void (*start_tx)(struct uart_port___5 *);
	void (*throttle)(struct uart_port___5 *);
	void (*unthrottle)(struct uart_port___5 *);
	void (*send_xchar)(struct uart_port___5 *, char);
	void (*stop_rx)(struct uart_port___5 *);
	void (*enable_ms)(struct uart_port___5 *);
	void (*break_ctl)(struct uart_port___5 *, int);
	int (*startup)(struct uart_port___5 *);
	void (*shutdown)(struct uart_port___5 *);
	void (*flush_buffer)(struct uart_port___5 *);
	void (*set_termios)(struct uart_port___5 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___5 *, int);
	void (*pm)(struct uart_port___5 *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port___5 *, unsigned int);
	const char * (*type)(struct uart_port___5 *);
	void (*release_port)(struct uart_port___5 *);
	int (*request_port)(struct uart_port___5 *);
	void (*config_port)(struct uart_port___5 *, int);
	int (*verify_port)(struct uart_port___5 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___5 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___5 *);
	void (*poll_put_char)(struct uart_port___5 *, unsigned char);
	int (*poll_get_char)(struct uart_port___5 *);
};

struct uart_state___5;

struct uart_port___5 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___5 *, int);
	void (*serial_out)(struct uart_port___5 *, int, int);
	void (*set_termios)(struct uart_port___5 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___5 *);
	void (*pm)(struct uart_port___5 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___5 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___5 *state;
	struct uart_icount icount;
	struct console___10 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___5 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device___178 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

struct uart_state___5 {
	struct tty_port___27 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port___5 *uart_port;
};

struct pciserial_board {
	unsigned int flags;
	unsigned int num_ports;
	unsigned int base_baud;
	unsigned int uart_offset;
	unsigned int reg_shift;
	unsigned int first_offset;
};

struct uart_8250_dma___4;

struct uart_8250_port___4 {
	struct uart_port___5 port;
	struct timer_list timer;
	struct list_head list;
	short unsigned int capabilities;
	short unsigned int bugs;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___4 *dma;
	int (*dl_read)(struct uart_8250_port___4 *);
	void (*dl_write)(struct uart_8250_port___4 *, int);
};

struct dma_chan___6;

typedef bool (*dma_filter_fn___5)(struct dma_chan___6 *, void *);

struct uart_8250_dma___4 {
	dma_filter_fn___5 fn;
	void *rx_param;
	void *tx_param;
	int rx_chan_id;
	int tx_chan_id;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___6 *rxchan;
	struct dma_chan___6 *txchan;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running: 1;
};

struct dma_device___5;

struct dma_chan_dev___5;

struct dma_chan___6 {
	struct dma_device___5 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___5 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___5;

struct dma_device___5 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___178 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___6 *);
	void (*device_free_chan_resources)(struct dma_chan___6 *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memcpy)(struct dma_chan___6 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor)(struct dma_chan___6 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor_val)(struct dma_chan___6 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq_val)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memset)(struct dma_chan___6 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_interrupt)(struct dma_chan___6 *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_slave_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_cyclic)(struct dma_chan___6 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___5 * (*device_prep_interleaved_dma)(struct dma_chan___6 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___6 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___6 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___6 *);
};

struct dma_chan_dev___5 {
	struct dma_chan___6 *chan;
	struct device___178 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___5 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___6 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___5 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct serial_private;

struct pci_serial_quirk {
	u32 vendor;
	u32 device;
	u32 subvendor;
	u32 subdevice;
	int (*probe)(struct pci_dev___24 *);
	int (*init)(struct pci_dev___24 *);
	int (*setup)(struct serial_private *, const struct pciserial_board *, struct uart_8250_port___4 *, int);
	void (*exit)(struct pci_dev___24 *);
};

struct serial_private {
	struct pci_dev___24 *dev;
	unsigned int nr;
	void *remapped_bar[6];
	struct pci_serial_quirk *quirk;
	int line[0];
};

struct timedia_struct {
	int num;
	const short unsigned int *ids;
};

struct quatech_feature {
	u16 devid;
	bool amcc;
};

enum pci_board_num_t {
	pbn_default = 0,
	pbn_b0_1_115200 = 1,
	pbn_b0_2_115200 = 2,
	pbn_b0_4_115200 = 3,
	pbn_b0_5_115200 = 4,
	pbn_b0_8_115200 = 5,
	pbn_b0_1_921600 = 6,
	pbn_b0_2_921600 = 7,
	pbn_b0_4_921600 = 8,
	pbn_b0_2_1130000 = 9,
	pbn_b0_4_1152000 = 10,
	pbn_b0_2_1152000_200 = 11,
	pbn_b0_4_1152000_200 = 12,
	pbn_b0_8_1152000_200 = 13,
	pbn_b0_2_1843200 = 14,
	pbn_b0_4_1843200 = 15,
	pbn_b0_2_1843200_200 = 16,
	pbn_b0_4_1843200_200 = 17,
	pbn_b0_8_1843200_200 = 18,
	pbn_b0_1_4000000 = 19,
	pbn_b0_bt_1_115200 = 20,
	pbn_b0_bt_2_115200 = 21,
	pbn_b0_bt_4_115200 = 22,
	pbn_b0_bt_8_115200 = 23,
	pbn_b0_bt_1_460800 = 24,
	pbn_b0_bt_2_460800 = 25,
	pbn_b0_bt_4_460800 = 26,
	pbn_b0_bt_1_921600 = 27,
	pbn_b0_bt_2_921600 = 28,
	pbn_b0_bt_4_921600 = 29,
	pbn_b0_bt_8_921600 = 30,
	pbn_b1_1_115200 = 31,
	pbn_b1_2_115200 = 32,
	pbn_b1_4_115200 = 33,
	pbn_b1_8_115200 = 34,
	pbn_b1_16_115200 = 35,
	pbn_b1_1_921600 = 36,
	pbn_b1_2_921600 = 37,
	pbn_b1_4_921600 = 38,
	pbn_b1_8_921600 = 39,
	pbn_b1_2_1250000 = 40,
	pbn_b1_bt_1_115200 = 41,
	pbn_b1_bt_2_115200 = 42,
	pbn_b1_bt_4_115200 = 43,
	pbn_b1_bt_2_921600 = 44,
	pbn_b1_1_1382400 = 45,
	pbn_b1_2_1382400 = 46,
	pbn_b1_4_1382400 = 47,
	pbn_b1_8_1382400 = 48,
	pbn_b2_1_115200 = 49,
	pbn_b2_2_115200 = 50,
	pbn_b2_4_115200 = 51,
	pbn_b2_8_115200 = 52,
	pbn_b2_1_460800 = 53,
	pbn_b2_4_460800 = 54,
	pbn_b2_8_460800 = 55,
	pbn_b2_16_460800 = 56,
	pbn_b2_1_921600 = 57,
	pbn_b2_4_921600 = 58,
	pbn_b2_8_921600 = 59,
	pbn_b2_8_1152000 = 60,
	pbn_b2_bt_1_115200 = 61,
	pbn_b2_bt_2_115200 = 62,
	pbn_b2_bt_4_115200 = 63,
	pbn_b2_bt_2_921600 = 64,
	pbn_b2_bt_4_921600 = 65,
	pbn_b3_2_115200 = 66,
	pbn_b3_4_115200 = 67,
	pbn_b3_8_115200 = 68,
	pbn_b4_bt_2_921600 = 69,
	pbn_b4_bt_4_921600 = 70,
	pbn_b4_bt_8_921600 = 71,
	pbn_panacom = 72,
	pbn_panacom2 = 73,
	pbn_panacom4 = 74,
	pbn_plx_romulus = 75,
	pbn_oxsemi = 76,
	pbn_oxsemi_1_4000000 = 77,
	pbn_oxsemi_2_4000000 = 78,
	pbn_oxsemi_4_4000000 = 79,
	pbn_oxsemi_8_4000000 = 80,
	pbn_intel_i960 = 81,
	pbn_sgi_ioc3 = 82,
	pbn_computone_4 = 83,
	pbn_computone_6 = 84,
	pbn_computone_8 = 85,
	pbn_sbsxrsio = 86,
	pbn_exar_XR17C152 = 87,
	pbn_exar_XR17C154 = 88,
	pbn_exar_XR17C158 = 89,
	pbn_exar_XR17V352 = 90,
	pbn_exar_XR17V354 = 91,
	pbn_exar_XR17V358 = 92,
	pbn_exar_ibm_saturn = 93,
	pbn_pasemi_1682M = 94,
	pbn_ni8430_2 = 95,
	pbn_ni8430_4 = 96,
	pbn_ni8430_8 = 97,
	pbn_ni8430_16 = 98,
	pbn_ADDIDATA_PCIe_1_3906250 = 99,
	pbn_ADDIDATA_PCIe_2_3906250 = 100,
	pbn_ADDIDATA_PCIe_4_3906250 = 101,
	pbn_ADDIDATA_PCIe_8_3906250 = 102,
	pbn_ce4100_1_115200 = 103,
	pbn_omegapci = 104,
	pbn_NETMOS9900_2s_115200 = 105,
	pbn_brcm_trumanage = 106,
};

struct uart_port___6;

struct uart_ops___6 {
	unsigned int (*tx_empty)(struct uart_port___6 *);
	void (*set_mctrl)(struct uart_port___6 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___6 *);
	void (*stop_tx)(struct uart_port___6 *);
	void (*start_tx)(struct uart_port___6 *);
	void (*throttle)(struct uart_port___6 *);
	void (*unthrottle)(struct uart_port___6 *);
	void (*send_xchar)(struct uart_port___6 *, char);
	void (*stop_rx)(struct uart_port___6 *);
	void (*enable_ms)(struct uart_port___6 *);
	void (*break_ctl)(struct uart_port___6 *, int);
	int (*startup)(struct uart_port___6 *);
	void (*shutdown)(struct uart_port___6 *);
	void (*flush_buffer)(struct uart_port___6 *);
	void (*set_termios)(struct uart_port___6 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___6 *, int);
	void (*pm)(struct uart_port___6 *, unsigned int, unsigned int);
	int (*set_wake)(struct uart_port___6 *, unsigned int);
	const char * (*type)(struct uart_port___6 *);
	void (*release_port)(struct uart_port___6 *);
	int (*request_port)(struct uart_port___6 *);
	void (*config_port)(struct uart_port___6 *, int);
	int (*verify_port)(struct uart_port___6 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___6 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___6 *);
	void (*poll_put_char)(struct uart_port___6 *, unsigned char);
	int (*poll_get_char)(struct uart_port___6 *);
};

struct uart_state___6;

struct uart_port___6 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___6 *, int);
	void (*serial_out)(struct uart_port___6 *, int, int);
	void (*set_termios)(struct uart_port___6 *, struct ktermios *, struct ktermios *);
	int (*handle_irq)(struct uart_port___6 *);
	void (*pm)(struct uart_port___6 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___6 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char unused1;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___6 *state;
	struct uart_icount icount;
	struct console___6 *cons;
	long unsigned int sysrq;
	upf_t flags;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___6 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	resource_size_t mapbase;
	struct device *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char irq_wake;
	unsigned char unused[2];
	void *private_data;
};

struct uart_state___6 {
	struct tty_port port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	struct uart_port___6 *uart_port;
};

struct early_serial8250_device {
	struct uart_port___6 port;
	char options[16];
	unsigned int baud;
};

struct page___202;

typedef struct page___202 *pgtable_t___202;

struct address_space___203;

struct kmem_cache___188;

struct page___202 {
	long unsigned int flags;
	struct address_space___203 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___202 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___202 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___188 *slab_cache;
		struct page___202 *first_page;
	};
	long: 64;
};

struct task_struct___204;

struct pv_cpu_ops___204 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___78 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___78 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___204 *);
	void (*end_context_switch)(struct task_struct___204 *);
};

struct mutex___205 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___204 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___197 {
	struct page___202 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___211;

struct signal_struct___204;

struct backing_dev_info___49;

struct pipe_inode_info___8;

struct task_struct___204 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___204 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___211 *mm;
	struct mm_struct___211 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___204 *real_parent;
	struct task_struct___204 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___204 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___87 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___204 = 0,
		VTIME_USER___204 = 1,
		VTIME_SYS___204 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___78 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___204 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___49 *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___205 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___8 *splice_pipe;
	struct page_frag___197 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___211 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___211 *, struct mm_struct___211 *);
	void (*dup_mmap)(struct mm_struct___211 *, struct mm_struct___211 *);
	void (*exit_mmap)(struct mm_struct___211 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___211 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___211 *);
	void (*pgd_free)(struct mm_struct___211 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___211 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___211 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___211 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___211 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___211 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___211 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___211 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___211 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___211 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___211 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___211 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___205 lock;
	void *vdso;
} mm_context_t___205;

struct xol_area___202;

struct uprobes_state___202 {
	struct xol_area___202 *xol_area;
};

struct vm_area_struct___211;

struct file___203;

struct core_state___204;

struct mm_struct___211 {
	struct vm_area_struct___211 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___211 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___211 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___205 context;
	long unsigned int flags;
	struct core_state___204 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___204 *owner;
	struct file___203 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___202 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___116;

struct exec_domain___52 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___116 *module;
	struct exec_domain___52 *next;
};

struct module_kobject___115 {
	struct kobject___20 kobj;
	struct module___116 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___115;

struct module___116 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___115 mkobj;
	struct module_attribute___115 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___204 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___91 {
	struct task_struct___204 *task;
	struct exec_domain___52 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___204;

struct lruvec___204 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___204 *zone;
};

struct pglist_data___204;

struct zone___204 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___204 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___204 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___204 {
	struct zone___204 *zone;
	int zone_idx;
};

struct zonelist___204 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___204 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___204 {
	struct zone___204 node_zones[4];
	struct zonelist___204 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___204 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___179;

struct dev_pm_ops___179 {
	int (*prepare)(struct device___179 *);
	void (*complete)(struct device___179 *);
	int (*suspend)(struct device___179 *);
	int (*resume)(struct device___179 *);
	int (*freeze)(struct device___179 *);
	int (*thaw)(struct device___179 *);
	int (*poweroff)(struct device___179 *);
	int (*restore)(struct device___179 *);
	int (*suspend_late)(struct device___179 *);
	int (*resume_early)(struct device___179 *);
	int (*freeze_late)(struct device___179 *);
	int (*thaw_early)(struct device___179 *);
	int (*poweroff_late)(struct device___179 *);
	int (*restore_early)(struct device___179 *);
	int (*suspend_noirq)(struct device___179 *);
	int (*resume_noirq)(struct device___179 *);
	int (*freeze_noirq)(struct device___179 *);
	int (*thaw_noirq)(struct device___179 *);
	int (*poweroff_noirq)(struct device___179 *);
	int (*restore_noirq)(struct device___179 *);
	int (*runtime_suspend)(struct device___179 *);
	int (*runtime_resume)(struct device___179 *);
	int (*runtime_idle)(struct device___179 *);
};

struct device_type___179;

struct bus_type___179;

struct device_driver___179;

struct dev_pm_domain___179;

struct class___179;

struct attribute_group___161;

struct device_rh___179;

struct device___179 {
	struct device___179 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___179 *type;
	struct mutex___205 mutex;
	struct bus_type___179 *bus;
	struct device_driver___179 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___179 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___179 *class;
	const struct attribute_group___161 **groups;
	void (*release)(struct device___179 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___179 *device_rh;
};

struct dev_pm_info_rh___179 {
	void (*set_latency_tolerance)(struct device___179 *, s32);
};

struct dev_pm_domain___179 {
	struct dev_pm_ops___179 ops;
};

struct smp_ops___204 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___204 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___202 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___202 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___187;

struct memcg_cache_params___188;

struct kmem_cache___188 {
	struct kmem_cache_cpu___187 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___188 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___203;

struct address_space_operations___203;

struct address_space___203 {
	struct inode___203 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___205 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___203 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___49 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___203;

struct path___203 {
	struct vfsmount *mnt;
	struct dentry___203 *dentry;
};

struct file_operations___203;

struct file___203 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___203 f_path;
	struct inode___203 *f_inode;
	const struct file_operations___203 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___203 *f_mapping;
	struct mutex___205 f_pos_lock;
};

struct vm_operations_struct___183;

struct vm_area_struct___211 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___211 *vm_next;
	struct vm_area_struct___211 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___211 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___183 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___203 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___179;

struct vm_operations_struct___183 {
	void (*open)(struct vm_area_struct___211 *);
	void (*close)(struct vm_area_struct___211 *);
	int (*fault)(struct vm_area_struct___211 *, struct vm_fault___179 *);
	int (*page_mkwrite)(struct vm_area_struct___211 *, struct vm_fault___179 *);
	int (*access)(struct vm_area_struct___211 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___211 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___211 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___211 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___211 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___204 {
	struct task_struct___204 *task;
	struct core_thread___204 *next;
};

struct core_state___204 {
	atomic_t nr_threads;
	struct core_thread___204 dumper;
	struct completion startup;
};

struct vm_fault___179 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___202 *page;
};

struct kiocb___25;

struct file_lock___203;

struct file_operations___203 {
	struct module___116 *owner;
	loff_t (*llseek)(struct file___203 *, loff_t, int);
	ssize_t (*read)(struct file___203 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___203 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___25 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___25 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___203 *, void *, filldir_t);
	unsigned int (*poll)(struct file___203 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___203 *, struct vm_area_struct___211 *);
	int (*open)(struct inode___203 *, struct file___203 *);
	int (*flush)(struct file___203 *, fl_owner_t);
	int (*release)(struct inode___203 *, struct file___203 *);
	int (*fsync)(struct file___203 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___25 *, int);
	int (*fasync)(int, struct file___203 *, int);
	int (*lock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*sendpage)(struct file___203 *, struct page___202 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*splice_write)(struct pipe_inode_info___8 *, struct file___203 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___203 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___203 *, long int, struct file_lock___203 **, void **);
		struct {
			int (*setlease)(struct file___203 *, long int, struct file_lock___203 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___203 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___203 *);
};

struct bin_attribute___163;

struct attribute_group___161 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___163 **bin_attrs;
};

struct bin_attribute___163 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___203 *, struct kobject___20 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___203 *, struct kobject___20 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	int (*mmap)(struct file___203 *, struct kobject___20 *, struct bin_attribute___163 *, struct vm_area_struct___211 *);
};

struct kmem_cache_cpu___187 {
	void **freelist;
	long unsigned int tid;
	struct page___202 *page;
	struct page___202 *partial;
};

struct memcg_cache_params___188 {
	bool is_root_cache;
	union {
		struct kmem_cache___188 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___188 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___203;

struct super_block___203;

struct dentry___203 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___203 *d_parent;
	struct qstr d_name;
	struct inode___203 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___203 *d_op;
	struct super_block___203 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___203;

struct dquot___203;

struct block_device___203;

struct cdev___57;

struct inode___203 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___203 *i_op;
	struct super_block___203 *i_sb;
	struct address_space___203 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___205 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___203 *i_fop;
	struct file_lock___203 *i_flock;
	struct address_space___203 i_data;
	struct dquot___203 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___8 *i_pipe;
		struct block_device___203 *i_bdev;
		struct cdev___57 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___203 {
	int (*d_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_hash)(const struct dentry___203 *, struct qstr *);
	int (*d_compare)(const struct dentry___203 *, const struct dentry___203 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___203 *);
	void (*d_release)(struct dentry___203 *);
	void (*d_prune)(struct dentry___203 *);
	void (*d_iput)(struct dentry___203 *, struct inode___203 *);
	char * (*d_dname)(struct dentry___203 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___203 *);
	int (*d_manage)(struct dentry___203 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___203;

struct mem_dqinfo___203 {
	struct quota_format_type___203 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___203;

struct quota_info___203 {
	unsigned int flags;
	struct mutex___205 dqio_mutex;
	struct mutex___205 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___203 *files[2];
	struct mem_dqinfo___203 info[2];
	const struct quota_format_ops___203 *ops[2];
};

struct file_system_type___203;

struct super_operations___203;

struct dquot_operations___203;

struct quotactl_ops___203;

struct super_block___203 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___203 *s_type;
	const struct super_operations___203 *s_op;
	const struct dquot_operations___203 *dq_op;
	const struct quotactl_ops___203 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___203 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___203 *s_bdev;
	struct backing_dev_info___49 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___203 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___205 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___203 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___203 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___203 *bd_inode;
	struct super_block___203 *bd_super;
	struct mutex___205 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___203 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___205 bd_fsfreeze_mutex;
};

typedef int kiocb_cancel_fn___25(struct kiocb___25 *, struct io_event *);

struct kiocb___25 {
	atomic_t ki_users;
	struct file___203 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___25 *ki_cancel;
	void (*ki_dtor)(struct kiocb___25 *);
	union {
		void *user;
		struct task_struct___204 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___203 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___203 *ia_file;
};

struct dquot___203 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___205 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___203 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___203 {
	int qf_fmt_id;
	const struct quota_format_ops___203 *qf_ops;
	struct module___116 *qf_owner;
	struct quota_format_type___203 *qf_next;
};

struct quota_format_ops___203 {
	int (*check_quota_file)(struct super_block___203 *, int);
	int (*read_file_info)(struct super_block___203 *, int);
	int (*write_file_info)(struct super_block___203 *, int);
	int (*free_file_info)(struct super_block___203 *, int);
	int (*read_dqblk)(struct dquot___203 *);
	int (*commit_dqblk)(struct dquot___203 *);
	int (*release_dqblk)(struct dquot___203 *);
};

struct dquot_operations___203 {
	int (*write_dquot)(struct dquot___203 *);
	struct dquot___203 * (*alloc_dquot)(struct super_block___203 *, int);
	void (*destroy_dquot)(struct dquot___203 *);
	int (*acquire_dquot)(struct dquot___203 *);
	int (*release_dquot)(struct dquot___203 *);
	int (*mark_dirty)(struct dquot___203 *);
	int (*write_info)(struct super_block___203 *, int);
	qsize_t * (*get_reserved_space)(struct inode___203 *);
};

struct quotactl_ops___203 {
	int (*quota_on)(struct super_block___203 *, int, int, struct path___203 *);
	int (*quota_on_meta)(struct super_block___203 *, int, int);
	int (*quota_off)(struct super_block___203 *, int);
	int (*quota_sync)(struct super_block___203 *, int);
	int (*get_info)(struct super_block___203 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___203 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___203 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___203 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___203 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___203 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___203 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___203 *, unsigned int);
};

struct address_space_operations___203 {
	int (*writepage)(struct page___202 *, struct writeback_control *);
	int (*readpage)(struct file___203 *, struct page___202 *);
	int (*writepages)(struct address_space___203 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___202 *);
	int (*readpages)(struct file___203 *, struct address_space___203 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___203 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___202 **, void **);
	int (*write_end)(struct file___203 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___202 *, void *);
	sector_t (*bmap)(struct address_space___203 *, sector_t);
	void (*invalidatepage)(struct page___202 *, long unsigned int);
	int (*releasepage)(struct page___202 *, gfp_t);
	void (*freepage)(struct page___202 *);
	ssize_t (*direct_IO)(int, struct kiocb___25 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___203 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___203 *, struct page___202 *, struct page___202 *, enum migrate_mode);
	int (*launder_page)(struct page___202 *);
	int (*is_partially_uptodate)(struct page___202 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___202 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___203 *, struct page___202 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___203 *, sector_t *);
	void (*swap_deactivate)(struct file___203 *);
	void (*invalidatepage_range)(struct page___202 *, unsigned int, unsigned int);
};

struct bdi_writeback___49 {
	struct backing_dev_info___49 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___49 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___49 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___179 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___203 *debug_dir;
	struct dentry___203 *debug_stats;
};

struct fasync_struct___203;

struct pipe_buffer___8;

struct pipe_inode_info___8 {
	struct mutex___205 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___202 *tmp_page;
	struct fasync_struct___203 *fasync_readers;
	struct fasync_struct___203 *fasync_writers;
	struct pipe_buffer___8 *bufs;
};

struct cdev___57 {
	struct kobject___20 kobj;
	struct module___116 *owner;
	const struct file_operations___203 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___203 {
	struct dentry___203 * (*lookup)(struct inode___203 *, struct dentry___203 *, unsigned int);
	void * (*follow_link)(struct dentry___203 *, struct nameidata *);
	int (*permission)(struct inode___203 *, int);
	struct posix_acl * (*get_acl)(struct inode___203 *, int);
	int (*readlink)(struct dentry___203 *, char *, int);
	void (*put_link)(struct dentry___203 *, struct nameidata *, void *);
	int (*create)(struct inode___203 *, struct dentry___203 *, umode_t, bool);
	int (*link)(struct dentry___203 *, struct inode___203 *, struct dentry___203 *);
	int (*unlink)(struct inode___203 *, struct dentry___203 *);
	int (*symlink)(struct inode___203 *, struct dentry___203 *, const char *);
	int (*mkdir)(struct inode___203 *, struct dentry___203 *, umode_t);
	int (*rmdir)(struct inode___203 *, struct dentry___203 *);
	int (*mknod)(struct inode___203 *, struct dentry___203 *, umode_t, dev_t);
	int (*rename)(struct inode___203 *, struct dentry___203 *, struct inode___203 *, struct dentry___203 *);
	int (*setattr)(struct dentry___203 *, struct iattr___203 *);
	int (*getattr)(struct vfsmount *, struct dentry___203 *, struct kstat *);
	int (*setxattr)(struct dentry___203 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___203 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___203 *, char *, size_t);
	int (*removexattr)(struct dentry___203 *, const char *);
	int (*fiemap)(struct inode___203 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___203 *, struct timespec *, int);
	int (*atomic_open)(struct inode___203 *, struct dentry___203 *, struct file___203 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___203;

struct lock_manager_operations___203;

struct file_lock___203 {
	struct file_lock___203 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___87 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___203 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___203 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___203 *fl_ops;
	const struct lock_manager_operations___203 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___203 {
	void (*fl_copy_lock)(struct file_lock___203 *, struct file_lock___203 *);
	void (*fl_release_private)(struct file_lock___203 *);
};

struct lock_manager_operations___203 {
	int (*lm_compare_owner)(struct file_lock___203 *, struct file_lock___203 *);
	long unsigned int (*lm_owner_key)(struct file_lock___203 *);
	void (*lm_notify)(struct file_lock___203 *);
	int (*lm_grant)(struct file_lock___203 *, struct file_lock___203 *, int);
	void (*lm_break)(struct file_lock___203 *);
	int (*lm_change)(struct file_lock___203 **, int);
};

struct fasync_struct___203 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___203 *fa_next;
	struct file___203 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___203 {
	const char *name;
	int fs_flags;
	struct dentry___203 * (*mount)(struct file_system_type___203 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___203 *);
	struct module___116 *owner;
	struct file_system_type___203 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___203 {
	struct inode___203 * (*alloc_inode)(struct super_block___203 *);
	void (*destroy_inode)(struct inode___203 *);
	void (*dirty_inode)(struct inode___203 *, int);
	int (*write_inode)(struct inode___203 *, struct writeback_control *);
	int (*drop_inode)(struct inode___203 *);
	void (*evict_inode)(struct inode___203 *);
	void (*put_super)(struct super_block___203 *);
	int (*sync_fs)(struct super_block___203 *, int);
	int (*freeze_fs)(struct super_block___203 *);
	int (*unfreeze_fs)(struct super_block___203 *);
	int (*statfs)(struct dentry___203 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___203 *, int *, char *);
	void (*umount_begin)(struct super_block___203 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___203 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___203 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___203 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___203 *);
	ssize_t (*quota_read)(struct super_block___203 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___203 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___203 *);
	int (*bdev_try_to_free_page)(struct super_block___203 *, struct page___202 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___203 *);
	void (*free_cached_objects)(struct super_block___203 *, int);
};

struct tty_struct___28;

struct tty_driver___28;

struct tty_operations___28 {
	struct tty_struct___28 * (*lookup)(struct tty_driver___28 *, struct inode___203 *, int);
	int (*install)(struct tty_driver___28 *, struct tty_struct___28 *);
	void (*remove)(struct tty_driver___28 *, struct tty_struct___28 *);
	int (*open)(struct tty_struct___28 *, struct file___203 *);
	void (*close)(struct tty_struct___28 *, struct file___203 *);
	void (*shutdown)(struct tty_struct___28 *);
	void (*cleanup)(struct tty_struct___28 *);
	int (*write)(struct tty_struct___28 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___28 *, unsigned char);
	void (*flush_chars)(struct tty_struct___28 *);
	int (*write_room)(struct tty_struct___28 *);
	int (*chars_in_buffer)(struct tty_struct___28 *);
	int (*ioctl)(struct tty_struct___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___28 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___28 *, struct ktermios *);
	void (*throttle)(struct tty_struct___28 *);
	void (*unthrottle)(struct tty_struct___28 *);
	void (*stop)(struct tty_struct___28 *);
	void (*start)(struct tty_struct___28 *);
	void (*hangup)(struct tty_struct___28 *);
	int (*break_ctl)(struct tty_struct___28 *, int);
	void (*flush_buffer)(struct tty_struct___28 *);
	void (*set_ldisc)(struct tty_struct___28 *);
	void (*wait_until_sent)(struct tty_struct___28 *, int);
	void (*send_xchar)(struct tty_struct___28 *, char);
	int (*tiocmget)(struct tty_struct___28 *);
	int (*tiocmset)(struct tty_struct___28 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___28 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___28 *, struct termiox *);
	int (*get_icount)(struct tty_struct___28 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___28 *, int, char *);
	int (*poll_get_char)(struct tty_driver___28 *, int);
	void (*poll_put_char)(struct tty_driver___28 *, int, char);
	const struct file_operations___203 *proc_fops;
};

struct tty_ldisc___28;

struct tty_port___28;

struct tty_struct___28 {
	int magic;
	struct kref kref;
	struct device___179 *dev;
	struct tty_driver___28 *driver;
	const struct tty_operations___28 *ops;
	int index;
	struct mutex___205 ldisc_mutex;
	struct tty_ldisc___28 *ldisc;
	struct mutex___205 atomic_write_lock;
	struct mutex___205 legacy_mutex;
	struct mutex___205 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___87 *pgrp;
	struct pid___87 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___28 *link;
	struct fasync_struct___203 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___28 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___28 {
	int magic;
	struct kref kref;
	struct cdev___57 *cdevs;
	struct module___116 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___28 *other;
	struct tty_struct___28 **ttys;
	struct tty_port___28 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___28 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___28;

struct tty_port___28 {
	struct tty_bufhead buf;
	struct tty_struct___28 *tty;
	struct tty_struct___28 *itty;
	const struct tty_port_operations___28 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___205 mutex;
	struct mutex___205 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___28 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___28 *);
	void (*close)(struct tty_struct___28 *);
	void (*flush_buffer)(struct tty_struct___28 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___28 *);
	ssize_t (*read)(struct tty_struct___28 *, struct file___203 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___28 *, struct file___203 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___28 *, struct file___203 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___28 *, struct file___203 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___28 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___28 *, struct file___203 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___28 *);
	void (*receive_buf)(struct tty_struct___28 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___28 *);
	void (*dcd_change)(struct tty_struct___28 *, unsigned int);
	struct module___116 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___28 *, int);
};

struct tty_ldisc___28 {
	struct tty_ldisc_ops___28 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___28 *tty;
};

struct tty_port_operations___28 {
	int (*carrier_raised)(struct tty_port___28 *);
	void (*dtr_rts)(struct tty_port___28 *, int);
	void (*shutdown)(struct tty_port___28 *);
	void (*drop)(struct tty_port___28 *);
	int (*activate)(struct tty_port___28 *, struct tty_struct___28 *);
	void (*destruct)(struct tty_port___28 *);
};

struct signal_struct___204 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___204 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___204 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___87 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct___28 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___205 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___179 *, char *);
	ssize_t (*store)(struct bus_type___179 *, const char *, size_t);
};

struct device_attribute___179;

struct driver_attribute___179;

struct bus_type___179 {
	const char *name;
	const char *dev_name;
	struct device___179 *dev_root;
	struct bus_attribute___179 *bus_attrs;
	struct device_attribute___179 *dev_attrs;
	struct driver_attribute___179 *drv_attrs;
	const struct attribute_group___161 **bus_groups;
	const struct attribute_group___161 **dev_groups;
	const struct attribute_group___161 **drv_groups;
	int (*match)(struct device___179 *, struct device_driver___179 *);
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	int (*probe)(struct device___179 *);
	int (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*online)(struct device___179 *);
	int (*offline)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct device___179 *, struct device_attribute___179 *, char *);
	ssize_t (*store)(struct device___179 *, struct device_attribute___179 *, const char *, size_t);
};

struct driver_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___179 *, char *);
	ssize_t (*store)(struct device_driver___179 *, const char *, size_t);
};

struct device_driver___179 {
	const char *name;
	struct bus_type___179 *bus;
	struct module___116 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___179 *);
	int (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	const struct attribute_group___161 **groups;
	const struct dev_pm_ops___179 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___179 {
	const char *name;
	const struct attribute_group___161 **groups;
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
};

struct class_attribute___179;

struct class___179 {
	const char *name;
	struct module___116 *owner;
	struct class_attribute___179 *class_attrs;
	struct device_attribute___179 *dev_attrs;
	const struct attribute_group___161 **dev_groups;
	struct bin_attribute___163 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *);
	void (*class_release)(struct class___179 *);
	void (*dev_release)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
	struct subsys_private *p;
};

struct class_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct class___179 *, struct class_attribute___179 *, char *);
	ssize_t (*store)(struct class___179 *, struct class_attribute___179 *, const char *, size_t);
	const void * (*namespace)(struct class___179 *, const struct class_attribute___179 *);
};

struct device_rh___179 {
	struct dev_pm_info_rh___179 power;
};

struct module_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___115 *, struct module_kobject___115 *, char *);
	ssize_t (*store)(struct module_attribute___115 *, struct module_kobject___115 *, const char *, size_t);
	void (*setup)(struct module___116 *, const char *);
	int (*test)(struct module___116 *);
	void (*free)(struct module___116 *);
};

struct pipe_buf_operations___8;

struct pipe_buffer___8 {
	struct page___202 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___8 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___8 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *, int);
	void (*unmap)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *, void *);
	int (*confirm)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	void (*release)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	int (*steal)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	void (*get)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
};

struct splice_desc___2 {
	unsigned int len;
	unsigned int total_len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___203 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

typedef int splice_actor___2(struct pipe_inode_info___8 *, struct pipe_buffer___8 *, struct splice_desc___2 *);

struct memdev {
	const char *name;
	umode_t mode;
	const struct file_operations___203 *fops;
	struct backing_dev_info___49 *dev_info;
};

struct page___203;

typedef struct page___203 *pgtable_t___203;

struct address_space___204;

struct kmem_cache___189;

struct page___203 {
	long unsigned int flags;
	struct address_space___204 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___203 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___203 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___189 *slab_cache;
		struct page___203 *first_page;
	};
	long: 64;
};

struct thread_struct___79;

struct task_struct___205;

struct pv_cpu_ops___205 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___79 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___79 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___205 *);
	void (*end_context_switch)(struct task_struct___205 *);
};

struct perf_event___79;

struct thread_struct___79 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___79 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___88;

struct pid_link___88 {
	struct hlist_node node;
	struct pid___88 *pid;
};

struct mutex___206 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___205 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___198 {
	struct page___203 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___212;

struct nsproxy___107;

struct signal_struct___205;

struct css_set___122;

struct perf_event_context___79;

struct task_struct___205 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___205 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___212 *mm;
	struct mm_struct___212 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___205 *real_parent;
	struct task_struct___205 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___205 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___88 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___205 = 0,
		VTIME_USER___205 = 1,
		VTIME_SYS___205 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___79 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___107 *nsproxy;
	struct signal_struct___205 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___122 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___79 *perf_event_ctxp[2];
	struct mutex___206 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___198 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___212 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___212 *, struct mm_struct___212 *);
	void (*dup_mmap)(struct mm_struct___212 *, struct mm_struct___212 *);
	void (*exit_mmap)(struct mm_struct___212 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___212 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___212 *);
	void (*pgd_free)(struct mm_struct___212 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___212 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___212 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___212 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___212 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___212 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___212 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___212 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___212 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___212 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___212 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___212 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___206 lock;
	void *vdso;
} mm_context_t___206;

struct xol_area___203;

struct uprobes_state___203 {
	struct xol_area___203 *xol_area;
};

struct vm_area_struct___212;

struct file___204;

struct core_state___205;

struct mm_struct___212 {
	struct vm_area_struct___212 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___212 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___212 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___206 context;
	long unsigned int flags;
	struct core_state___205 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___205 *owner;
	struct file___204 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___203 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___117;

struct exec_domain___53 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___117 *module;
	struct exec_domain___53 *next;
};

struct module_kobject___116 {
	struct kobject___20 kobj;
	struct module___117 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___116;

struct ftrace_event_call___68;

struct module___117 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___116 mkobj;
	struct module_attribute___116 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___68 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___205 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___79 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___205 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___205 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___205 *target;
};

typedef void (*perf_overflow_handler_t___79)(struct perf_event___79 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___79;

typedef void (*ftrace_func_t___79)(long unsigned int, long unsigned int, struct ftrace_ops___79 *, struct pt_regs *);

struct ftrace_ops___79 {
	ftrace_func_t___79 func;
	struct ftrace_ops___79 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___206 regex_lock;
};

struct pmu___79;

struct fasync_struct___204;

struct pid_namespace___88;

struct perf_cgroup___79;

struct perf_event___79 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___79 *group_leader;
	struct pmu___79 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___79 hw;
	struct perf_event_context___79 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___206 child_mutex;
	struct list_head child_list;
	struct perf_event___79 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___205 *owner;
	struct mutex___206 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___204 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___79 *);
	struct callback_head callback_head;
	struct pid_namespace___88 *ns;
	u64 id;
	perf_overflow_handler_t___79 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___68 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___79 ftrace_ops;
	struct perf_cgroup___79 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___92 {
	struct task_struct___205 *task;
	struct exec_domain___53 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___203 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___203 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___188;

struct memcg_cache_params___189;

struct kmem_cache___189 {
	struct kmem_cache_cpu___188 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___189 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___204;

struct address_space_operations___204;

struct address_space___204 {
	struct inode___204 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___206 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___204 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___204;

struct path___204 {
	struct vfsmount *mnt;
	struct dentry___204 *dentry;
};

struct fown_struct___88 {
	rwlock_t lock;
	struct pid___88 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___204;

struct file___204 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___204 f_path;
	struct inode___204 *f_inode;
	const struct file_operations___204 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___88 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___204 *f_mapping;
	struct mutex___206 f_pos_lock;
};

struct vm_operations_struct___184;

struct vm_area_struct___212 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___212 *vm_next;
	struct vm_area_struct___212 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___212 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___184 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___204 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___180;

struct vm_operations_struct___184 {
	void (*open)(struct vm_area_struct___212 *);
	void (*close)(struct vm_area_struct___212 *);
	int (*fault)(struct vm_area_struct___212 *, struct vm_fault___180 *);
	int (*page_mkwrite)(struct vm_area_struct___212 *, struct vm_fault___180 *);
	int (*access)(struct vm_area_struct___212 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___212 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___212 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___212 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___212 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___205 {
	struct task_struct___205 *task;
	struct core_thread___205 *next;
};

struct core_state___205 {
	atomic_t nr_threads;
	struct core_thread___205 dumper;
	struct completion startup;
};

struct irq_data___133;

struct x86_io_apic_ops___133 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___133 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___133;

struct irq_data___133 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___133 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___180;

struct dev_pm_ops___180 {
	int (*prepare)(struct device___180 *);
	void (*complete)(struct device___180 *);
	int (*suspend)(struct device___180 *);
	int (*resume)(struct device___180 *);
	int (*freeze)(struct device___180 *);
	int (*thaw)(struct device___180 *);
	int (*poweroff)(struct device___180 *);
	int (*restore)(struct device___180 *);
	int (*suspend_late)(struct device___180 *);
	int (*resume_early)(struct device___180 *);
	int (*freeze_late)(struct device___180 *);
	int (*thaw_early)(struct device___180 *);
	int (*poweroff_late)(struct device___180 *);
	int (*restore_early)(struct device___180 *);
	int (*suspend_noirq)(struct device___180 *);
	int (*resume_noirq)(struct device___180 *);
	int (*freeze_noirq)(struct device___180 *);
	int (*thaw_noirq)(struct device___180 *);
	int (*poweroff_noirq)(struct device___180 *);
	int (*restore_noirq)(struct device___180 *);
	int (*runtime_suspend)(struct device___180 *);
	int (*runtime_resume)(struct device___180 *);
	int (*runtime_idle)(struct device___180 *);
};

struct device_type___180;

struct bus_type___180;

struct device_driver___180;

struct dev_pm_domain___180;

struct class___180;

struct attribute_group___162;

struct device_rh___180;

struct device___180 {
	struct device___180 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___180 *type;
	struct mutex___206 mutex;
	struct bus_type___180 *bus;
	struct device_driver___180 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___180 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___180 *class;
	const struct attribute_group___162 **groups;
	void (*release)(struct device___180 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___180 *device_rh;
};

struct dev_pm_info_rh___180 {
	void (*set_latency_tolerance)(struct device___180 *, s32);
};

struct dev_pm_domain___180 {
	struct dev_pm_ops___180 ops;
};

struct smp_ops___205 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___205 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___88 {
	int nr;
	struct pid_namespace___88 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___88 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___205 *child_reaper;
	struct kmem_cache___189 *pid_cachep;
	unsigned int level;
	struct pid_namespace___88 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___204 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___88 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___88 numbers[1];
};

struct zone___205;

struct lruvec___205 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___205 *zone;
};

struct pglist_data___205;

struct zone___205 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___205 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___205 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___205 {
	struct zone___205 *zone;
	int zone_idx;
};

struct zonelist___205 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___205 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___205 {
	struct zone___205 node_zones[4];
	struct zonelist___205 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___205 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___107 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___88 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___205 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___205 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___205 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___88 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___88 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___206 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___122;

struct css_set___122 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___122 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___79 {
	struct pmu___79 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___206 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___205 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___79 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___164;

struct attribute_group___162 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___164 **bin_attrs;
};

struct bin_attribute___164 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___204 *, struct kobject___20 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___204 *, struct kobject___20 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	int (*mmap)(struct file___204 *, struct kobject___20 *, struct bin_attribute___164 *, struct vm_area_struct___212 *);
};

struct module_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___116 *, struct module_kobject___116 *, char *);
	ssize_t (*store)(struct module_attribute___116 *, struct module_kobject___116 *, const char *, size_t);
	void (*setup)(struct module___117 *, const char *);
	int (*test)(struct module___117 *);
	void (*free)(struct module___117 *);
};

struct trace_event_functions___68;

struct trace_event___68 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___68 *funcs;
};

struct ftrace_event_class___68;

struct ftrace_event_call___68 {
	struct list_head list;
	struct ftrace_event_class___68 *class;
	char *name;
	struct trace_event___68 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct kmem_cache_cpu___188 {
	void **freelist;
	long unsigned int tid;
	struct page___203 *page;
	struct page___203 *partial;
};

struct memcg_cache_params___189 {
	bool is_root_cache;
	union {
		struct kmem_cache___189 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___189 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___204;

struct super_block___204;

struct dentry___204 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___204 *d_parent;
	struct qstr d_name;
	struct inode___204 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___204 *d_op;
	struct super_block___204 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___204;

struct file_lock___204;

struct dquot___204;

struct block_device___204;

struct inode___204 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___204 *i_op;
	struct super_block___204 *i_sb;
	struct address_space___204 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___206 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___204 *i_fop;
	struct file_lock___204 *i_flock;
	struct address_space___204 i_data;
	struct dquot___204 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___204 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___204 {
	int (*d_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_hash)(const struct dentry___204 *, struct qstr *);
	int (*d_compare)(const struct dentry___204 *, const struct dentry___204 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___204 *);
	void (*d_release)(struct dentry___204 *);
	void (*d_prune)(struct dentry___204 *);
	void (*d_iput)(struct dentry___204 *, struct inode___204 *);
	char * (*d_dname)(struct dentry___204 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___204 *);
	int (*d_manage)(struct dentry___204 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___204;

struct mem_dqinfo___204 {
	struct quota_format_type___204 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___204;

struct quota_info___204 {
	unsigned int flags;
	struct mutex___206 dqio_mutex;
	struct mutex___206 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___204 *files[2];
	struct mem_dqinfo___204 info[2];
	const struct quota_format_ops___204 *ops[2];
};

struct file_system_type___204;

struct super_operations___204;

struct dquot_operations___204;

struct quotactl_ops___204;

struct xattr_handler___123;

struct super_block___204 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___204 *s_type;
	const struct super_operations___204 *s_op;
	const struct dquot_operations___204 *dq_op;
	const struct quotactl_ops___204 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___204 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___123 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___204 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___204 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___206 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___204 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct hd_struct___40;

struct gendisk___40;

struct block_device___204 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___204 *bd_inode;
	struct super_block___204 *bd_super;
	struct mutex___206 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___204 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___40 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___40 *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___206 bd_fsfreeze_mutex;
};

struct cgroup___122;

struct cgroup_subsys_state___122 {
	struct cgroup___122 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___204 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___204 *ia_file;
};

struct dquot___204 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___206 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___204 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___204 {
	int qf_fmt_id;
	const struct quota_format_ops___204 *qf_ops;
	struct module___117 *qf_owner;
	struct quota_format_type___204 *qf_next;
};

struct quota_format_ops___204 {
	int (*check_quota_file)(struct super_block___204 *, int);
	int (*read_file_info)(struct super_block___204 *, int);
	int (*write_file_info)(struct super_block___204 *, int);
	int (*free_file_info)(struct super_block___204 *, int);
	int (*read_dqblk)(struct dquot___204 *);
	int (*commit_dqblk)(struct dquot___204 *);
	int (*release_dqblk)(struct dquot___204 *);
};

struct dquot_operations___204 {
	int (*write_dquot)(struct dquot___204 *);
	struct dquot___204 * (*alloc_dquot)(struct super_block___204 *, int);
	void (*destroy_dquot)(struct dquot___204 *);
	int (*acquire_dquot)(struct dquot___204 *);
	int (*release_dquot)(struct dquot___204 *);
	int (*mark_dirty)(struct dquot___204 *);
	int (*write_info)(struct super_block___204 *, int);
	qsize_t * (*get_reserved_space)(struct inode___204 *);
};

struct quotactl_ops___204 {
	int (*quota_on)(struct super_block___204 *, int, int, struct path___204 *);
	int (*quota_on_meta)(struct super_block___204 *, int, int);
	int (*quota_off)(struct super_block___204 *, int);
	int (*quota_sync)(struct super_block___204 *, int);
	int (*get_info)(struct super_block___204 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___204 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___204 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___204 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___204 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___204 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___204 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___204 *, unsigned int);
};

struct address_space_operations___204 {
	int (*writepage)(struct page___203 *, struct writeback_control *);
	int (*readpage)(struct file___204 *, struct page___203 *);
	int (*writepages)(struct address_space___204 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___203 *);
	int (*readpages)(struct file___204 *, struct address_space___204 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___204 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___203 **, void **);
	int (*write_end)(struct file___204 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___203 *, void *);
	sector_t (*bmap)(struct address_space___204 *, sector_t);
	void (*invalidatepage)(struct page___203 *, long unsigned int);
	int (*releasepage)(struct page___203 *, gfp_t);
	void (*freepage)(struct page___203 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___204 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___204 *, struct page___203 *, struct page___203 *, enum migrate_mode);
	int (*launder_page)(struct page___203 *);
	int (*is_partially_uptodate)(struct page___203 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___203 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___204 *, struct page___203 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___204 *, sector_t *);
	void (*swap_deactivate)(struct file___204 *);
	void (*invalidatepage_range)(struct page___203 *, unsigned int, unsigned int);
};

struct hd_struct___40 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___180 __dev;
	struct kobject___20 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___40;

struct timer_rand_state___2;

struct gendisk___40 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___40 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___40 *part_tbl;
	struct hd_struct___40 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct device___180 *driverfs_dev;
	struct kobject___20 *slave_dir;
	struct timer_rand_state___2 *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct inode_operations___204 {
	struct dentry___204 * (*lookup)(struct inode___204 *, struct dentry___204 *, unsigned int);
	void * (*follow_link)(struct dentry___204 *, struct nameidata *);
	int (*permission)(struct inode___204 *, int);
	struct posix_acl * (*get_acl)(struct inode___204 *, int);
	int (*readlink)(struct dentry___204 *, char *, int);
	void (*put_link)(struct dentry___204 *, struct nameidata *, void *);
	int (*create)(struct inode___204 *, struct dentry___204 *, umode_t, bool);
	int (*link)(struct dentry___204 *, struct inode___204 *, struct dentry___204 *);
	int (*unlink)(struct inode___204 *, struct dentry___204 *);
	int (*symlink)(struct inode___204 *, struct dentry___204 *, const char *);
	int (*mkdir)(struct inode___204 *, struct dentry___204 *, umode_t);
	int (*rmdir)(struct inode___204 *, struct dentry___204 *);
	int (*mknod)(struct inode___204 *, struct dentry___204 *, umode_t, dev_t);
	int (*rename)(struct inode___204 *, struct dentry___204 *, struct inode___204 *, struct dentry___204 *);
	int (*setattr)(struct dentry___204 *, struct iattr___204 *);
	int (*getattr)(struct vfsmount *, struct dentry___204 *, struct kstat *);
	int (*setxattr)(struct dentry___204 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___204 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___204 *, char *, size_t);
	int (*removexattr)(struct dentry___204 *, const char *);
	int (*fiemap)(struct inode___204 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___204 *, struct timespec *, int);
	int (*atomic_open)(struct inode___204 *, struct dentry___204 *, struct file___204 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___113;

struct seq_file___137;

struct file_operations___204 {
	struct module___117 *owner;
	loff_t (*llseek)(struct file___204 *, loff_t, int);
	ssize_t (*read)(struct file___204 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___204 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___204 *, void *, filldir_t);
	unsigned int (*poll)(struct file___204 *, struct poll_table_struct___113 *);
	long int (*unlocked_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___204 *, struct vm_area_struct___212 *);
	int (*open)(struct inode___204 *, struct file___204 *);
	int (*flush)(struct file___204 *, fl_owner_t);
	int (*release)(struct inode___204 *, struct file___204 *);
	int (*fsync)(struct file___204 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___204 *, int);
	int (*lock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*sendpage)(struct file___204 *, struct page___203 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___204 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___204 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___204 *, long int, struct file_lock___204 **, void **);
		struct {
			int (*setlease)(struct file___204 *, long int, struct file_lock___204 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___204 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___137 *, struct file___204 *);
};

struct file_lock_operations___204;

struct lock_manager_operations___204;

struct file_lock___204 {
	struct file_lock___204 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___88 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___204 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___204 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___204 *fl_ops;
	const struct lock_manager_operations___204 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___204 {
	void (*fl_copy_lock)(struct file_lock___204 *, struct file_lock___204 *);
	void (*fl_release_private)(struct file_lock___204 *);
};

struct lock_manager_operations___204 {
	int (*lm_compare_owner)(struct file_lock___204 *, struct file_lock___204 *);
	long unsigned int (*lm_owner_key)(struct file_lock___204 *);
	void (*lm_notify)(struct file_lock___204 *);
	int (*lm_grant)(struct file_lock___204 *, struct file_lock___204 *, int);
	void (*lm_break)(struct file_lock___204 *);
	int (*lm_change)(struct file_lock___204 **, int);
};

struct fasync_struct___204 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___204 *fa_next;
	struct file___204 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___204 {
	const char *name;
	int fs_flags;
	struct dentry___204 * (*mount)(struct file_system_type___204 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___204 *);
	struct module___117 *owner;
	struct file_system_type___204 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___204 {
	struct inode___204 * (*alloc_inode)(struct super_block___204 *);
	void (*destroy_inode)(struct inode___204 *);
	void (*dirty_inode)(struct inode___204 *, int);
	int (*write_inode)(struct inode___204 *, struct writeback_control *);
	int (*drop_inode)(struct inode___204 *);
	void (*evict_inode)(struct inode___204 *);
	void (*put_super)(struct super_block___204 *);
	int (*sync_fs)(struct super_block___204 *, int);
	int (*freeze_fs)(struct super_block___204 *);
	int (*unfreeze_fs)(struct super_block___204 *);
	int (*statfs)(struct dentry___204 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___204 *, int *, char *);
	void (*umount_begin)(struct super_block___204 *);
	int (*show_options)(struct seq_file___137 *, struct dentry___204 *);
	int (*show_devname)(struct seq_file___137 *, struct dentry___204 *);
	int (*show_path)(struct seq_file___137 *, struct dentry___204 *);
	int (*show_stats)(struct seq_file___137 *, struct dentry___204 *);
	ssize_t (*quota_read)(struct super_block___204 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___204 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___204 *);
	int (*bdev_try_to_free_page)(struct super_block___204 *, struct page___203 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___204 *);
	void (*free_cached_objects)(struct super_block___204 *, int);
};

struct xattr_handler___123 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___204 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___204 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___204 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___115)(struct file___204 *, wait_queue_head_t *, struct poll_table_struct___113 *);

struct poll_table_struct___113 {
	poll_queue_proc___115 _qproc;
	long unsigned int _key;
};

struct seq_operations___137;

struct seq_file___137 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___206 lock;
	const struct seq_operations___137 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

typedef struct poll_table_struct___113 poll_table___24;

struct bus_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___180 *, char *);
	ssize_t (*store)(struct bus_type___180 *, const char *, size_t);
};

struct device_attribute___180;

struct driver_attribute___180;

struct bus_type___180 {
	const char *name;
	const char *dev_name;
	struct device___180 *dev_root;
	struct bus_attribute___180 *bus_attrs;
	struct device_attribute___180 *dev_attrs;
	struct driver_attribute___180 *drv_attrs;
	const struct attribute_group___162 **bus_groups;
	const struct attribute_group___162 **dev_groups;
	const struct attribute_group___162 **drv_groups;
	int (*match)(struct device___180 *, struct device_driver___180 *);
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	int (*probe)(struct device___180 *);
	int (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*online)(struct device___180 *);
	int (*offline)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct device___180 *, struct device_attribute___180 *, char *);
	ssize_t (*store)(struct device___180 *, struct device_attribute___180 *, const char *, size_t);
};

struct driver_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___180 *, char *);
	ssize_t (*store)(struct device_driver___180 *, const char *, size_t);
};

struct device_driver___180 {
	const char *name;
	struct bus_type___180 *bus;
	struct module___117 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___180 *);
	int (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	const struct attribute_group___162 **groups;
	const struct dev_pm_ops___180 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___180 {
	const char *name;
	const struct attribute_group___162 **groups;
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
};

struct class_attribute___180;

struct class___180 {
	const char *name;
	struct module___117 *owner;
	struct class_attribute___180 *class_attrs;
	struct device_attribute___180 *dev_attrs;
	const struct attribute_group___162 **dev_groups;
	struct bin_attribute___164 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *);
	void (*class_release)(struct class___180 *);
	void (*dev_release)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
	struct subsys_private *p;
};

struct class_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct class___180 *, struct class_attribute___180 *, char *);
	ssize_t (*store)(struct class___180 *, struct class_attribute___180 *, const char *, size_t);
	const void * (*namespace)(struct class___180 *, const struct class_attribute___180 *);
};

struct device_rh___180 {
	struct dev_pm_info_rh___180 power;
};

struct disk_part_tbl___40 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___40 *last_lookup;
	struct hd_struct___40 *part[0];
};

struct timer_rand_state___2 {
	cycles_t last_time;
	long int last_delta;
	long int last_delta2;
	unsigned int dont_count_entropy: 1;
};

struct irq_chip___133 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___133 *);
	void (*irq_shutdown)(struct irq_data___133 *);
	void (*irq_enable)(struct irq_data___133 *);
	void (*irq_disable)(struct irq_data___133 *);
	void (*irq_ack)(struct irq_data___133 *);
	void (*irq_mask)(struct irq_data___133 *);
	void (*irq_mask_ack)(struct irq_data___133 *);
	void (*irq_unmask)(struct irq_data___133 *);
	void (*irq_eoi)(struct irq_data___133 *);
	int (*irq_set_affinity)(struct irq_data___133 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___133 *);
	int (*irq_set_type)(struct irq_data___133 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___133 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___133 *);
	void (*irq_bus_sync_unlock)(struct irq_data___133 *);
	void (*irq_cpu_online)(struct irq_data___133 *);
	void (*irq_cpu_offline)(struct irq_data___133 *);
	void (*irq_suspend)(struct irq_data___133 *);
	void (*irq_resume)(struct irq_data___133 *);
	void (*irq_pm_shutdown)(struct irq_data___133 *);
	void (*irq_print_chip)(struct irq_data___133 *, struct seq_file___137 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___133 *, void *);
	long unsigned int flags;
};

struct vm_fault___180 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___203 *page;
};

struct seq_operations___137 {
	void * (*start)(struct seq_file___137 *, loff_t *);
	void (*stop)(struct seq_file___137 *, void *);
	void * (*next)(struct seq_file___137 *, void *, loff_t *);
	int (*show)(struct seq_file___137 *, void *);
};

struct cgroupfs_root___122;

struct cgroup___122 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___122 *parent;
	struct dentry___204 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___122 *subsys[11];
	struct cgroupfs_root___122 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___206 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___122 {
	struct super_block___204 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___122 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___79;

struct pmu___79 {
	struct list_head entry;
	struct device___180 *dev;
	const struct attribute_group___162 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___79 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___79 *);
	void (*pmu_disable)(struct pmu___79 *);
	int (*event_init)(struct perf_event___79 *);
	int (*add)(struct perf_event___79 *, int);
	void (*del)(struct perf_event___79 *, int);
	void (*start)(struct perf_event___79 *, int);
	void (*stop)(struct perf_event___79 *, int);
	void (*read)(struct perf_event___79 *);
	void (*start_txn)(struct pmu___79 *);
	int (*commit_txn)(struct pmu___79 *);
	void (*cancel_txn)(struct pmu___79 *);
	int (*event_idx)(struct perf_event___79 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___117 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___79 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___79 *);
};

struct perf_cpu_context___79 {
	struct perf_event_context___79 ctx;
	struct perf_event_context___79 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___79 *unique_pmu;
	struct perf_cgroup___79 *cgrp;
};

struct perf_cgroup___79 {
	struct cgroup_subsys_state___122 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___68 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___206 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___68)(struct trace_iterator___68 *, int, struct trace_event___68 *);

struct trace_event_functions___68 {
	trace_print_func___68 trace;
	trace_print_func___68 raw;
	trace_print_func___68 hex;
	trace_print_func___68 binary;
};

struct ftrace_event_class___68 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___68 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___68 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___68 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___68 *);
};

struct ftrace_event_file___23 {
	struct list_head list;
	struct ftrace_event_call___68 *event_call;
	struct dentry___204 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_random__mix_pool_bytes {
	struct trace_entry ent;
	const char *pool_name;
	int bytes;
	long unsigned int IP;
	char __data[0];
};

struct ftrace_raw_credit_entropy_bits {
	struct trace_entry ent;
	const char *pool_name;
	int bits;
	int entropy_count;
	int entropy_total;
	long unsigned int IP;
	char __data[0];
};

struct ftrace_raw_get_random_bytes {
	struct trace_entry ent;
	int nbytes;
	long unsigned int IP;
	char __data[0];
};

struct ftrace_raw_random__extract_entropy {
	struct trace_entry ent;
	const char *pool_name;
	int nbytes;
	int entropy_count;
	long unsigned int IP;
	char __data[0];
};

struct ftrace_data_offsets_random__mix_pool_bytes {};

struct ftrace_data_offsets_credit_entropy_bits {};

struct ftrace_data_offsets_get_random_bytes {};

struct ftrace_data_offsets_random__extract_entropy {};

struct poolinfo {
	int poolbitshift;
	int poolwords;
	int poolbytes;
	int poolbits;
	int poolfracbits;
	int tap1;
	int tap2;
	int tap3;
	int tap4;
	int tap5;
};

struct entropy_store {
	const struct poolinfo *poolinfo;
	__u32 *pool;
	const char *name;
	struct entropy_store *pull;
	int limit;
	spinlock_t lock;
	unsigned int add_ptr;
	unsigned int input_rotate;
	int entropy_count;
	int entropy_total;
	unsigned int initialized: 1;
	bool last_data_init;
	__u8 last_data[10];
};

struct fast_pool {
	__u32 pool[4];
	long unsigned int last;
	short unsigned int count;
	unsigned char rotate;
	unsigned char last_timer_intr;
};

struct miscdevice___7 {
	int minor;
	const char *name;
	const struct file_operations___201 *fops;
	struct list_head list;
	struct device___177 *parent;
	struct device___177 *this_device;
	const char *nodename;
	umode_t mode;
};

struct page___204;

typedef struct page___204 *pgtable_t___204;

struct address_space___205;

struct kmem_cache___190;

struct page___204 {
	long unsigned int flags;
	struct address_space___205 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___204 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___204 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___190 *slab_cache;
		struct page___204 *first_page;
	};
	long: 64;
};

struct task_struct___206;

struct pv_cpu_ops___206 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___79 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___79 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___206 *);
	void (*end_context_switch)(struct task_struct___206 *);
};

struct mutex___207 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___206 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___199 {
	struct page___204 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___213;

struct signal_struct___206;

struct bio_list___39;

struct backing_dev_info___50;

struct io_context___39;

struct task_struct___206 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___206 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___213 *mm;
	struct mm_struct___213 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___206 *real_parent;
	struct task_struct___206 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___206 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___88 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___206 = 0,
		VTIME_USER___206 = 1,
		VTIME_SYS___206 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___79 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___206 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___39 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___50 *backing_dev_info;
	struct io_context___39 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___207 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___199 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___213 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___213 *, struct mm_struct___213 *);
	void (*dup_mmap)(struct mm_struct___213 *, struct mm_struct___213 *);
	void (*exit_mmap)(struct mm_struct___213 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___213 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___213 *);
	void (*pgd_free)(struct mm_struct___213 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___213 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___213 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___213 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___213 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___213 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___213 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___213 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___213 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___213 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___213 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___213 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___207 lock;
	void *vdso;
} mm_context_t___207;

struct xol_area___204;

struct uprobes_state___204 {
	struct xol_area___204 *xol_area;
};

struct vm_area_struct___213;

struct file___205;

struct core_state___206;

struct mm_struct___213 {
	struct vm_area_struct___213 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___213 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___213 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___207 context;
	long unsigned int flags;
	struct core_state___206 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___206 *owner;
	struct file___205 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___204 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___118;

struct module_kobject___117 {
	struct kobject___20 kobj;
	struct module___118 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___117;

struct module___118 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___117 mkobj;
	struct module_attribute___117 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___206 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct inode___205;

struct dentry_operations___205;

struct super_block___205;

struct dentry___205 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___205 *d_parent;
	struct qstr d_name;
	struct inode___205 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___205 *d_op;
	struct super_block___205 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___205;

struct address_space___205 {
	struct inode___205 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___207 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___205 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___50 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___205;

struct file_operations___205;

struct file_lock___205;

struct dquot___205;

struct block_device___205;

struct cdev___58;

struct inode___205 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___205 *i_op;
	struct super_block___205 *i_sb;
	struct address_space___205 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___207 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___205 *i_fop;
	struct file_lock___205 *i_flock;
	struct address_space___205 i_data;
	struct dquot___205 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___205 *i_bdev;
		struct cdev___58 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___205;

struct dentry_operations___205 {
	int (*d_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_hash)(const struct dentry___205 *, struct qstr *);
	int (*d_compare)(const struct dentry___205 *, const struct dentry___205 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___205 *);
	void (*d_release)(struct dentry___205 *);
	void (*d_prune)(struct dentry___205 *);
	void (*d_iput)(struct dentry___205 *, struct inode___205 *);
	char * (*d_dname)(struct dentry___205 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___205 *);
	int (*d_manage)(struct dentry___205 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___205;

struct mem_dqinfo___205 {
	struct quota_format_type___205 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___205;

struct quota_info___205 {
	unsigned int flags;
	struct mutex___207 dqio_mutex;
	struct mutex___207 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___205 *files[2];
	struct mem_dqinfo___205 info[2];
	const struct quota_format_ops___205 *ops[2];
};

struct file_system_type___205;

struct super_operations___205;

struct dquot_operations___205;

struct quotactl_ops___205;

struct super_block___205 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___205 *s_type;
	const struct super_operations___205 *s_op;
	const struct dquot_operations___205 *dq_op;
	const struct quotactl_ops___205 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___205 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___205 *s_bdev;
	struct backing_dev_info___50 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___205 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___207 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___205 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___205 {
	struct vfsmount *mnt;
	struct dentry___205 *dentry;
};

struct device___181;

struct dev_pm_ops___181 {
	int (*prepare)(struct device___181 *);
	void (*complete)(struct device___181 *);
	int (*suspend)(struct device___181 *);
	int (*resume)(struct device___181 *);
	int (*freeze)(struct device___181 *);
	int (*thaw)(struct device___181 *);
	int (*poweroff)(struct device___181 *);
	int (*restore)(struct device___181 *);
	int (*suspend_late)(struct device___181 *);
	int (*resume_early)(struct device___181 *);
	int (*freeze_late)(struct device___181 *);
	int (*thaw_early)(struct device___181 *);
	int (*poweroff_late)(struct device___181 *);
	int (*restore_early)(struct device___181 *);
	int (*suspend_noirq)(struct device___181 *);
	int (*resume_noirq)(struct device___181 *);
	int (*freeze_noirq)(struct device___181 *);
	int (*thaw_noirq)(struct device___181 *);
	int (*poweroff_noirq)(struct device___181 *);
	int (*restore_noirq)(struct device___181 *);
	int (*runtime_suspend)(struct device___181 *);
	int (*runtime_resume)(struct device___181 *);
	int (*runtime_idle)(struct device___181 *);
};

struct device_type___181;

struct bus_type___181;

struct device_driver___181;

struct dev_pm_domain___181;

struct class___181;

struct attribute_group___163;

struct device_rh___181;

struct device___181 {
	struct device___181 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___181 *type;
	struct mutex___207 mutex;
	struct bus_type___181 *bus;
	struct device_driver___181 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___181 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___15 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___181 *class;
	const struct attribute_group___163 **groups;
	void (*release)(struct device___181 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___181 *device_rh;
};

struct dev_pm_info_rh___181 {
	void (*set_latency_tolerance)(struct device___181 *, s32);
};

struct dev_pm_domain___181 {
	struct dev_pm_ops___181 ops;
};

struct smp_ops___206 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___206 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___40;

typedef void bio_end_io_t___40(struct bio___40 *, int);

struct bio_vec___40 {
	struct page___204 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___40;

struct bio_set___40;

struct bio___40 {
	sector_t bi_sector;
	struct bio___40 *bi_next;
	struct block_device___205 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___40 *bi_end_io;
	void *bi_private;
	struct io_context___39 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___40 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___40 *bi_io_vec;
	struct bio_set___40 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___40 bi_inline_vecs[0];
};

struct hd_struct___41;

struct gendisk___41;

struct request_queue___39;

struct block_device___205 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___205 *bd_inode;
	struct super_block___205 *bd_super;
	struct mutex___207 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___205 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___41 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___41 *bd_disk;
	struct request_queue___39 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___207 bd_fsfreeze_mutex;
};

struct io_cq___39;

struct io_context___39 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___39 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___40 {
	struct bio___40 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___40 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___40 *bip_vec;
	struct bio_vec___40 bip_inline_vecs[0];
};

struct bio_list___39 {
	struct bio___40 *head;
	struct bio___40 *tail;
};

struct bio_set___40 {
	struct kmem_cache___190 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___39 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___205 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___205 *ia_file;
};

struct file___205 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___205 f_path;
	struct inode___205 *f_inode;
	const struct file_operations___205 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___88 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___205 *f_mapping;
	struct mutex___207 f_pos_lock;
};

struct zone___206;

struct lruvec___206 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___206 *zone;
};

struct pglist_data___206;

struct zone___206 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___206 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___206 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___206 {
	struct zone___206 *zone;
	int zone_idx;
};

struct zonelist___206 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___206 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___206 {
	struct zone___206 node_zones[4];
	struct zonelist___206 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___206 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___205 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___207 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___205 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___205 {
	int qf_fmt_id;
	const struct quota_format_ops___205 *qf_ops;
	struct module___118 *qf_owner;
	struct quota_format_type___205 *qf_next;
};

struct quota_format_ops___205 {
	int (*check_quota_file)(struct super_block___205 *, int);
	int (*read_file_info)(struct super_block___205 *, int);
	int (*write_file_info)(struct super_block___205 *, int);
	int (*free_file_info)(struct super_block___205 *, int);
	int (*read_dqblk)(struct dquot___205 *);
	int (*commit_dqblk)(struct dquot___205 *);
	int (*release_dqblk)(struct dquot___205 *);
};

struct dquot_operations___205 {
	int (*write_dquot)(struct dquot___205 *);
	struct dquot___205 * (*alloc_dquot)(struct super_block___205 *, int);
	void (*destroy_dquot)(struct dquot___205 *);
	int (*acquire_dquot)(struct dquot___205 *);
	int (*release_dquot)(struct dquot___205 *);
	int (*mark_dirty)(struct dquot___205 *);
	int (*write_info)(struct super_block___205 *, int);
	qsize_t * (*get_reserved_space)(struct inode___205 *);
};

struct quotactl_ops___205 {
	int (*quota_on)(struct super_block___205 *, int, int, struct path___205 *);
	int (*quota_on_meta)(struct super_block___205 *, int, int);
	int (*quota_off)(struct super_block___205 *, int);
	int (*quota_sync)(struct super_block___205 *, int);
	int (*get_info)(struct super_block___205 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___205 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___205 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___205 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___205 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___205 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___205 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___205 *, unsigned int);
};

struct address_space_operations___205 {
	int (*writepage)(struct page___204 *, struct writeback_control *);
	int (*readpage)(struct file___205 *, struct page___204 *);
	int (*writepages)(struct address_space___205 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___204 *);
	int (*readpages)(struct file___205 *, struct address_space___205 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___205 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___204 **, void **);
	int (*write_end)(struct file___205 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___204 *, void *);
	sector_t (*bmap)(struct address_space___205 *, sector_t);
	void (*invalidatepage)(struct page___204 *, long unsigned int);
	int (*releasepage)(struct page___204 *, gfp_t);
	void (*freepage)(struct page___204 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___205 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___205 *, struct page___204 *, struct page___204 *, enum migrate_mode);
	int (*launder_page)(struct page___204 *);
	int (*is_partially_uptodate)(struct page___204 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___204 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___205 *, struct page___204 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___205 *, sector_t *);
	void (*swap_deactivate)(struct file___205 *);
	void (*invalidatepage_range)(struct page___204 *, unsigned int, unsigned int);
};

struct bdi_writeback___50 {
	struct backing_dev_info___50 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___50 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___50 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___181 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___205 *debug_dir;
	struct dentry___205 *debug_stats;
};

struct hd_struct___41 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___181 __dev;
	struct kobject___20 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___41;

struct block_device_operations___39;

struct gendisk___41 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___41 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___41 *part_tbl;
	struct hd_struct___41 part0;
	const struct block_device_operations___39 *fops;
	struct request_queue___39 *queue;
	void *private_data;
	int flags;
	struct device___181 *driverfs_dev;
	struct kobject___20 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___39 {
	struct request_queue___39 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___39(struct request_queue___39 *);

typedef void make_request_fn___39(struct request_queue___39 *, struct bio___40 *);

struct request___39;

typedef int prep_rq_fn___39(struct request_queue___39 *, struct request___39 *);

struct bvec_merge_data___39;

typedef int merge_bvec_fn___40(struct request_queue___39 *, struct bvec_merge_data___39 *, struct bio_vec___40 *);

typedef void softirq_done_fn___39(struct request___39 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___39(struct request___39 *);

typedef int dma_drain_needed_fn___39(struct request___39 *);

typedef int lld_busy_fn___39(struct request_queue___39 *);

struct bsg_class_device___39 {
	struct device___181 *class_dev;
	struct device___181 *parent;
	int minor;
	struct request_queue___39 *queue;
	struct kref ref;
	void (*release)(struct device___181 *);
};

typedef void unprep_rq_fn___39(struct request_queue___39 *, struct request___39 *);

struct elevator_queue___39;

struct blk_queue_tag___39;

struct request_queue___39 {
	struct list_head queue_head;
	struct request___39 *last_merge;
	struct elevator_queue___39 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___39 root_rl;
	request_fn_proc___39 *request_fn;
	make_request_fn___39 *make_request_fn;
	prep_rq_fn___39 *prep_rq_fn;
	merge_bvec_fn___40 *merge_bvec_fn;
	softirq_done_fn___39 *softirq_done_fn;
	rq_timed_out_fn___39 *rq_timed_out_fn;
	dma_drain_needed_fn___39 *dma_drain_needed;
	lld_busy_fn___39 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___39 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___50 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___20 kobj;
	struct kobject___20 mq_kobj;
	struct device___181 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___39 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___39 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___207 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___39 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___39 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___40 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___58 {
	struct kobject___20 kobj;
	struct module___118 *owner;
	const struct file_operations___205 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___205 {
	struct dentry___205 * (*lookup)(struct inode___205 *, struct dentry___205 *, unsigned int);
	void * (*follow_link)(struct dentry___205 *, struct nameidata *);
	int (*permission)(struct inode___205 *, int);
	struct posix_acl * (*get_acl)(struct inode___205 *, int);
	int (*readlink)(struct dentry___205 *, char *, int);
	void (*put_link)(struct dentry___205 *, struct nameidata *, void *);
	int (*create)(struct inode___205 *, struct dentry___205 *, umode_t, bool);
	int (*link)(struct dentry___205 *, struct inode___205 *, struct dentry___205 *);
	int (*unlink)(struct inode___205 *, struct dentry___205 *);
	int (*symlink)(struct inode___205 *, struct dentry___205 *, const char *);
	int (*mkdir)(struct inode___205 *, struct dentry___205 *, umode_t);
	int (*rmdir)(struct inode___205 *, struct dentry___205 *);
	int (*mknod)(struct inode___205 *, struct dentry___205 *, umode_t, dev_t);
	int (*rename)(struct inode___205 *, struct dentry___205 *, struct inode___205 *, struct dentry___205 *);
	int (*setattr)(struct dentry___205 *, struct iattr___205 *);
	int (*getattr)(struct vfsmount *, struct dentry___205 *, struct kstat *);
	int (*setxattr)(struct dentry___205 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___205 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___205 *, char *, size_t);
	int (*removexattr)(struct dentry___205 *, const char *);
	int (*fiemap)(struct inode___205 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___205 *, struct timespec *, int);
	int (*atomic_open)(struct inode___205 *, struct dentry___205 *, struct file___205 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___205 {
	struct module___118 *owner;
	loff_t (*llseek)(struct file___205 *, loff_t, int);
	ssize_t (*read)(struct file___205 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___205 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___205 *, void *, filldir_t);
	unsigned int (*poll)(struct file___205 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___205 *, struct vm_area_struct___213 *);
	int (*open)(struct inode___205 *, struct file___205 *);
	int (*flush)(struct file___205 *, fl_owner_t);
	int (*release)(struct inode___205 *, struct file___205 *);
	int (*fsync)(struct file___205 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___205 *, int);
	int (*lock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*sendpage)(struct file___205 *, struct page___204 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___205 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___205 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___205 *, long int, struct file_lock___205 **, void **);
		struct {
			int (*setlease)(struct file___205 *, long int, struct file_lock___205 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___205 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___205 *);
};

struct fasync_struct___205;

struct file_lock_operations___205;

struct lock_manager_operations___205;

struct file_lock___205 {
	struct file_lock___205 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___88 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___205 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___205 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___205 *fl_ops;
	const struct lock_manager_operations___205 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___205 {
	void (*fl_copy_lock)(struct file_lock___205 *, struct file_lock___205 *);
	void (*fl_release_private)(struct file_lock___205 *);
};

struct lock_manager_operations___205 {
	int (*lm_compare_owner)(struct file_lock___205 *, struct file_lock___205 *);
	long unsigned int (*lm_owner_key)(struct file_lock___205 *);
	void (*lm_notify)(struct file_lock___205 *);
	int (*lm_grant)(struct file_lock___205 *, struct file_lock___205 *, int);
	void (*lm_break)(struct file_lock___205 *);
	int (*lm_change)(struct file_lock___205 **, int);
};

struct fasync_struct___205 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___205 *fa_next;
	struct file___205 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___205 {
	const char *name;
	int fs_flags;
	struct dentry___205 * (*mount)(struct file_system_type___205 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___205 *);
	struct module___118 *owner;
	struct file_system_type___205 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___205 {
	struct inode___205 * (*alloc_inode)(struct super_block___205 *);
	void (*destroy_inode)(struct inode___205 *);
	void (*dirty_inode)(struct inode___205 *, int);
	int (*write_inode)(struct inode___205 *, struct writeback_control *);
	int (*drop_inode)(struct inode___205 *);
	void (*evict_inode)(struct inode___205 *);
	void (*put_super)(struct super_block___205 *);
	int (*sync_fs)(struct super_block___205 *, int);
	int (*freeze_fs)(struct super_block___205 *);
	int (*unfreeze_fs)(struct super_block___205 *);
	int (*statfs)(struct dentry___205 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___205 *, int *, char *);
	void (*umount_begin)(struct super_block___205 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___205 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___205 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___205 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___205 *);
	ssize_t (*quota_read)(struct super_block___205 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___205 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___205 *);
	int (*bdev_try_to_free_page)(struct super_block___205 *, struct page___204 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___205 *);
	void (*free_cached_objects)(struct super_block___205 *, int);
};

struct vm_operations_struct___185;

struct vm_area_struct___213 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___213 *vm_next;
	struct vm_area_struct___213 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___213 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___185 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___205 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xol_area___204 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___204 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___189;

struct memcg_cache_params___190;

struct kmem_cache___190 {
	struct kmem_cache_cpu___189 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___20 kobj;
	struct memcg_cache_params___190 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___181;

struct vm_operations_struct___185 {
	void (*open)(struct vm_area_struct___213 *);
	void (*close)(struct vm_area_struct___213 *);
	int (*fault)(struct vm_area_struct___213 *, struct vm_fault___181 *);
	int (*page_mkwrite)(struct vm_area_struct___213 *, struct vm_fault___181 *);
	int (*access)(struct vm_area_struct___213 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___213 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___213 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___213 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___213 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___206 {
	struct task_struct___206 *task;
	struct core_thread___206 *next;
};

struct core_state___206 {
	atomic_t nr_threads;
	struct core_thread___206 dumper;
	struct completion startup;
};

struct signal_struct___206 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___206 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___206 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___88 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___88 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___207 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___165;

struct attribute_group___163 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___165 **bin_attrs;
};

struct bin_attribute___165 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___205 *, struct kobject___20 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___205 *, struct kobject___20 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	int (*mmap)(struct file___205 *, struct kobject___20 *, struct bin_attribute___165 *, struct vm_area_struct___213 *);
};

struct kmem_cache_cpu___189 {
	void **freelist;
	long unsigned int tid;
	struct page___204 *page;
	struct page___204 *partial;
};

struct memcg_cache_params___190 {
	bool is_root_cache;
	union {
		struct kmem_cache___190 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___190 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___181 *, char *);
	ssize_t (*store)(struct bus_type___181 *, const char *, size_t);
};

struct device_attribute___181;

struct driver_attribute___181;

struct bus_type___181 {
	const char *name;
	const char *dev_name;
	struct device___181 *dev_root;
	struct bus_attribute___181 *bus_attrs;
	struct device_attribute___181 *dev_attrs;
	struct driver_attribute___181 *drv_attrs;
	const struct attribute_group___163 **bus_groups;
	const struct attribute_group___163 **dev_groups;
	const struct attribute_group___163 **drv_groups;
	int (*match)(struct device___181 *, struct device_driver___181 *);
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	int (*probe)(struct device___181 *);
	int (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*online)(struct device___181 *);
	int (*offline)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct device___181 *, struct device_attribute___181 *, char *);
	ssize_t (*store)(struct device___181 *, struct device_attribute___181 *, const char *, size_t);
};

struct driver_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___181 *, char *);
	ssize_t (*store)(struct device_driver___181 *, const char *, size_t);
};

struct device_driver___181 {
	const char *name;
	struct bus_type___181 *bus;
	struct module___118 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___181 *);
	int (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	const struct attribute_group___163 **groups;
	const struct dev_pm_ops___181 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___181 {
	const char *name;
	const struct attribute_group___163 **groups;
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
};

struct class_attribute___181;

struct class___181 {
	const char *name;
	struct module___118 *owner;
	struct class_attribute___181 *class_attrs;
	struct device_attribute___181 *dev_attrs;
	const struct attribute_group___163 **dev_groups;
	struct bin_attribute___165 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *);
	void (*class_release)(struct class___181 *);
	void (*dev_release)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
	struct subsys_private *p;
};

struct class_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct class___181 *, struct class_attribute___181 *, char *);
	ssize_t (*store)(struct class___181 *, struct class_attribute___181 *, const char *, size_t);
	const void * (*namespace)(struct class___181 *, const struct class_attribute___181 *);
};

struct device_rh___181 {
	struct dev_pm_info_rh___181 power;
};

struct disk_part_tbl___41 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___41 *last_lookup;
	struct hd_struct___41 *part[0];
};

struct block_device_operations___39 {
	int (*open)(struct block_device___205 *, fmode_t);
	void (*release)(struct gendisk___41 *, fmode_t);
	int (*ioctl)(struct block_device___205 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___205 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___205 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___41 *, unsigned int);
	int (*media_changed)(struct gendisk___41 *);
	void (*unlock_native_capacity)(struct gendisk___41 *);
	int (*revalidate_disk)(struct gendisk___41 *);
	int (*getgeo)(struct block_device___205 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___205 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___118 *owner;
};

struct vm_fault___181 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___204 *page;
};

struct io_cq___39 {
	struct request_queue___39 *q;
	struct io_context___39 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___190 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___39(struct request___39 *, int);

struct request___39 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___39 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___40 *bio;
	struct bio___40 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___39 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___39 *saved_end_io;
		} flush;
	};
	struct gendisk___41 *rq_disk;
	struct hd_struct___41 *part;
	long unsigned int start_time;
	struct request_list___39 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___39 *end_io;
	void *end_io_data;
	struct request___39 *next_rq;
};

typedef int elevator_merge_fn___39(struct request_queue___39 *, struct request___39 **, struct bio___40 *);

typedef void elevator_merge_req_fn___39(struct request_queue___39 *, struct request___39 *, struct request___39 *);

typedef void elevator_merged_fn___39(struct request_queue___39 *, struct request___39 *, int);

typedef int elevator_allow_merge_fn___39(struct request_queue___39 *, struct request___39 *, struct bio___40 *);

typedef void elevator_bio_merged_fn___39(struct request_queue___39 *, struct request___39 *, struct bio___40 *);

typedef int elevator_dispatch_fn___39(struct request_queue___39 *, int);

typedef void elevator_add_req_fn___39(struct request_queue___39 *, struct request___39 *);

typedef struct request___39 *elevator_request_list_fn___39(struct request_queue___39 *, struct request___39 *);

typedef void elevator_completed_req_fn___39(struct request_queue___39 *, struct request___39 *);

typedef int elevator_may_queue_fn___39(struct request_queue___39 *, int);

typedef void elevator_init_icq_fn___39(struct io_cq___39 *);

typedef void elevator_exit_icq_fn___39(struct io_cq___39 *);

typedef int elevator_set_req_fn___39(struct request_queue___39 *, struct request___39 *, struct bio___40 *, gfp_t);

typedef void elevator_put_req_fn___39(struct request___39 *);

typedef void elevator_activate_req_fn___39(struct request_queue___39 *, struct request___39 *);

typedef void elevator_deactivate_req_fn___39(struct request_queue___39 *, struct request___39 *);

struct elevator_type___39;

typedef int elevator_init_fn___40(struct request_queue___39 *, struct elevator_type___39 *);

typedef void elevator_exit_fn___39(struct elevator_queue___39 *);

struct elevator_ops___39 {
	elevator_merge_fn___39 *elevator_merge_fn;
	elevator_merged_fn___39 *elevator_merged_fn;
	elevator_merge_req_fn___39 *elevator_merge_req_fn;
	elevator_allow_merge_fn___39 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___39 *elevator_bio_merged_fn;
	elevator_dispatch_fn___39 *elevator_dispatch_fn;
	elevator_add_req_fn___39 *elevator_add_req_fn;
	elevator_activate_req_fn___39 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___39 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___39 *elevator_completed_req_fn;
	elevator_request_list_fn___39 *elevator_former_req_fn;
	elevator_request_list_fn___39 *elevator_latter_req_fn;
	elevator_init_icq_fn___39 *elevator_init_icq_fn;
	elevator_exit_icq_fn___39 *elevator_exit_icq_fn;
	elevator_set_req_fn___39 *elevator_set_req_fn;
	elevator_put_req_fn___39 *elevator_put_req_fn;
	elevator_may_queue_fn___39 *elevator_may_queue_fn;
	elevator_init_fn___40 *elevator_init_fn;
	elevator_exit_fn___39 *elevator_exit_fn;
};

struct elv_fs_entry___39;

struct elevator_type___39 {
	struct kmem_cache___190 *icq_cache;
	struct elevator_ops___39 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___39 *elevator_attrs;
	char elevator_name[16];
	struct module___118 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___39 {
	struct elevator_type___39 *type;
	void *elevator_data;
	struct kobject___20 kobj;
	struct mutex___207 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___39 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___39 *, char *);
	ssize_t (*store)(struct elevator_queue___39 *, const char *, size_t);
};

struct bvec_merge_data___39 {
	struct block_device___205 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___39 {
	struct request___39 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct module_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___117 *, struct module_kobject___117 *, char *);
	ssize_t (*store)(struct module_attribute___117 *, struct module_kobject___117 *, const char *, size_t);
	void (*setup)(struct module___118 *, const char *);
	int (*test)(struct module___118 *);
	void (*free)(struct module___118 *);
};

struct raw_config_request {
	int raw_minor;
	__u64 block_major;
	__u64 block_minor;
};

struct raw_device_data {
	struct block_device___205 *binding;
	int inuse;
};

struct raw32_config_request {
	compat_int_t raw_minor;
	compat_u64 block_major;
	compat_u64 block_minor;
} __attribute__((packed));

struct exec_domain___54 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___21 *module;
	struct exec_domain___54 *next;
};

struct thread_info___93 {
	struct task_struct___35 *task;
	struct exec_domain___54 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct device___182;

struct dev_pm_ops___182 {
	int (*prepare)(struct device___182 *);
	void (*complete)(struct device___182 *);
	int (*suspend)(struct device___182 *);
	int (*resume)(struct device___182 *);
	int (*freeze)(struct device___182 *);
	int (*thaw)(struct device___182 *);
	int (*poweroff)(struct device___182 *);
	int (*restore)(struct device___182 *);
	int (*suspend_late)(struct device___182 *);
	int (*resume_early)(struct device___182 *);
	int (*freeze_late)(struct device___182 *);
	int (*thaw_early)(struct device___182 *);
	int (*poweroff_late)(struct device___182 *);
	int (*restore_early)(struct device___182 *);
	int (*suspend_noirq)(struct device___182 *);
	int (*resume_noirq)(struct device___182 *);
	int (*freeze_noirq)(struct device___182 *);
	int (*thaw_noirq)(struct device___182 *);
	int (*poweroff_noirq)(struct device___182 *);
	int (*restore_noirq)(struct device___182 *);
	int (*runtime_suspend)(struct device___182 *);
	int (*runtime_resume)(struct device___182 *);
	int (*runtime_idle)(struct device___182 *);
};

struct acpi_device___21;

struct acpi_dev_node___27 {
	union {
		struct acpi_device___21 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct device_type___182;

struct bus_type___182;

struct device_driver___182;

struct dev_pm_domain___182;

struct class___182;

struct device_rh___182;

struct device___182 {
	struct device___182 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___182 *type;
	struct mutex___35 mutex;
	struct bus_type___182 *bus;
	struct device_driver___182 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___182 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___182 *class;
	const struct attribute_group___25 **groups;
	void (*release)(struct device___182 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___182 *device_rh;
};

struct dev_pm_info_rh___182 {
	void (*set_latency_tolerance)(struct device___182 *, s32);
};

struct dev_pm_domain___182 {
	struct dev_pm_ops___182 ops;
};

struct miscdevice___8 {
	int minor;
	const char *name;
	const struct file_operations___34 *fops;
	struct list_head list;
	struct device___182 *parent;
	struct device___182 *this_device;
	const char *nodename;
	umode_t mode;
};

typedef struct poll_table_struct___20 poll_table___25;

struct bus_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___182 *, char *);
	ssize_t (*store)(struct bus_type___182 *, const char *, size_t);
};

struct device_attribute___182;

struct driver_attribute___182;

struct bus_type___182 {
	const char *name;
	const char *dev_name;
	struct device___182 *dev_root;
	struct bus_attribute___182 *bus_attrs;
	struct device_attribute___182 *dev_attrs;
	struct driver_attribute___182 *drv_attrs;
	const struct attribute_group___25 **bus_groups;
	const struct attribute_group___25 **dev_groups;
	const struct attribute_group___25 **drv_groups;
	int (*match)(struct device___182 *, struct device_driver___182 *);
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	int (*probe)(struct device___182 *);
	int (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*online)(struct device___182 *);
	int (*offline)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct device___182 *, struct device_attribute___182 *, char *);
	ssize_t (*store)(struct device___182 *, struct device_attribute___182 *, const char *, size_t);
};

struct driver_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___182 *, char *);
	ssize_t (*store)(struct device_driver___182 *, const char *, size_t);
};

struct device_driver___182 {
	const char *name;
	struct bus_type___182 *bus;
	struct module___21 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___182 *);
	int (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	const struct attribute_group___25 **groups;
	const struct dev_pm_ops___182 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___182 {
	const char *name;
	const struct attribute_group___25 **groups;
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
};

struct class_attribute___182;

struct class___182 {
	const char *name;
	struct module___21 *owner;
	struct class_attribute___182 *class_attrs;
	struct device_attribute___182 *dev_attrs;
	const struct attribute_group___25 **dev_groups;
	struct bin_attribute___25 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *);
	void (*class_release)(struct class___182 *);
	void (*dev_release)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
	struct subsys_private *p;
};

struct class_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct class___182 *, struct class_attribute___182 *, char *);
	ssize_t (*store)(struct class___182 *, struct class_attribute___182 *, const char *, size_t);
	const void * (*namespace)(struct class___182 *, const struct class_attribute___182 *);
};

struct acpi_scan_handler___21;

struct acpi_hotplug_context___21;

struct acpi_driver___21;

struct acpi_device___21 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___21 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___21 *handler;
	struct acpi_hotplug_context___21 *hp;
	struct acpi_driver___21 *driver;
	void *driver_data;
	struct device___182 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___35 physical_node_lock;
	void (*remove)(struct acpi_device___21 *);
};

struct device_rh___182 {
	struct dev_pm_info_rh___182 power;
};

struct acpi_hotplug_profile___21 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___21 *);
	void (*notify_online)(struct acpi_device___21 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___21 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___21 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___21 *);
	void (*bind)(struct device___182 *);
	void (*unbind)(struct device___182 *);
	struct acpi_hotplug_profile___21 hotplug;
};

struct acpi_hotplug_context___21 {
	struct acpi_device___21 *self;
	int (*notify)(struct acpi_device___21 *, u32);
	void (*uevent)(struct acpi_device___21 *, u32);
	void (*fixup)(struct acpi_device___21 *);
};

typedef int (*acpi_op_add___21)(struct acpi_device___21 *);

typedef int (*acpi_op_remove___21)(struct acpi_device___21 *);

typedef void (*acpi_op_notify___21)(struct acpi_device___21 *, u32);

struct acpi_device_ops___21 {
	acpi_op_add___21 add;
	acpi_op_remove___21 remove;
	acpi_op_notify___21 notify;
};

struct acpi_driver___21 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___21 ops;
	struct device_driver___182 drv;
	struct module___21 *owner;
};

struct hpet_info {
	long unsigned int hi_ireqfreq;
	long unsigned int hi_flags;
	short unsigned int hi_hpet;
	short unsigned int hi_timer;
};

struct hpets;

struct hpet_dev___3 {
	struct hpets *hd_hpets;
	struct hpet *hd_hpet;
	struct hpet_timer *hd_timer;
	long unsigned int hd_ireqfreq;
	long unsigned int hd_irqdata;
	wait_queue_head_t hd_waitqueue;
	struct fasync_struct___34 *hd_async_queue;
	unsigned int hd_flags;
	unsigned int hd_irq;
	unsigned int hd_hdwirq;
	char hd_name[7];
};

struct hpets {
	struct hpets *hp_next;
	struct hpet *hp_hpet;
	long unsigned int hp_hpet_phys;
	struct clocksource *hp_clocksource;
	long long unsigned int hp_tick_freq;
	long unsigned int hp_delta;
	unsigned int hp_ntimer;
	unsigned int hp_which;
	struct hpet_dev___3 hp_dev[1];
};

struct compat_hpet_info {
	compat_ulong_t hi_ireqfreq;
	compat_ulong_t hi_flags;
	short unsigned int hi_hpet;
	short unsigned int hi_timer;
};

struct miscdevice___9 {
	int minor;
	const char *name;
	const struct file_operations___178 *fops;
	struct list_head list;
	struct device___143 *parent;
	struct device___143 *this_device;
	const char *nodename;
	umode_t mode;
};

struct hwrng {
	const char *name;
	int (*init)(struct hwrng *);
	void (*cleanup)(struct hwrng *);
	int (*data_present)(struct hwrng *, int);
	int (*data_read)(struct hwrng *, u32 *);
	int (*read)(struct hwrng *, void *, size_t, bool);
	long unsigned int priv;
	short unsigned int quality;
	struct list_head list;
};

struct miscdevice___10 {
	int minor;
	const char *name;
	const struct file_operations___199 *fops;
	struct list_head list;
	struct device___175 *parent;
	struct device___175 *this_device;
	const char *nodename;
	umode_t mode;
};

struct agp_bridge_data___2;

struct agp_memory {
	struct agp_memory *next;
	struct agp_memory *prev;
	struct agp_bridge_data___2 *bridge;
	struct page___201 **pages;
	size_t page_count;
	int key;
	int num_scratch_pages;
	off_t pg_start;
	u32 type;
	u32 physical;
	bool is_bound;
	bool is_flushed;
	struct list_head mapped_list;
	struct scatterlist *sg_list;
	int num_sg;
};

struct agp_bridge_driver;

struct agp_bridge_data___2 {
	const struct agp_version *version;
	const struct agp_bridge_driver *driver;
	const struct vm_operations_struct___182 *vm_ops;
	void *previous_size;
	void *current_size;
	void *dev_private_data;
	struct pci_dev___24 *dev;
	u32 *gatt_table;
	u32 *gatt_table_real;
	long unsigned int scratch_page;
	struct page___201 *scratch_page_page;
	dma_addr_t scratch_page_dma;
	long unsigned int gart_bus_addr;
	long unsigned int gatt_bus_addr;
	u32 mode;
	enum chipset_type type;
	long unsigned int *key_list;
	atomic_t current_memory_agp;
	atomic_t agp_in_use;
	int max_memory_agp;
	int aperture_size_idx;
	int capndx;
	int flags;
	char major_version;
	char minor_version;
	struct list_head list;
	u32 apbase_config;
	struct list_head mapped_list;
	spinlock_t mapped_lock;
};

enum aper_size_type {
	U8_APER_SIZE = 0,
	U16_APER_SIZE = 1,
	U32_APER_SIZE = 2,
	LVL2_APER_SIZE = 3,
	FIXED_APER_SIZE = 4,
};

struct gatt_mask {
	long unsigned int mask;
	u32 type;
};

struct agp_bridge_driver {
	struct module___115 *owner;
	const void *aperture_sizes;
	int num_aperture_sizes;
	enum aper_size_type size_type;
	bool cant_use_aperture;
	bool needs_scratch_page;
	const struct gatt_mask *masks;
	int (*fetch_size)();
	int (*configure)();
	void (*agp_enable)(struct agp_bridge_data___2 *, u32);
	void (*cleanup)();
	void (*tlb_flush)(struct agp_memory *);
	long unsigned int (*mask_memory)(struct agp_bridge_data___2 *, dma_addr_t, int);
	void (*cache_flush)();
	int (*create_gatt_table)(struct agp_bridge_data___2 *);
	int (*free_gatt_table)(struct agp_bridge_data___2 *);
	int (*insert_memory)(struct agp_memory *, off_t, int);
	int (*remove_memory)(struct agp_memory *, off_t, int);
	struct agp_memory * (*alloc_by_type)(size_t, int);
	void (*free_by_type)(struct agp_memory *);
	struct page___201 * (*agp_alloc_page)(struct agp_bridge_data___2 *);
	int (*agp_alloc_pages)(struct agp_bridge_data___2 *, struct agp_memory *, size_t);
	void (*agp_destroy_page)(struct page___201 *, int);
	void (*agp_destroy_pages)(struct agp_memory *);
	int (*agp_type_to_mask_type)(struct agp_bridge_data___2 *, int);
};

struct pci_dev___25 {
	struct list_head bus_list;
	struct pci_bus___20 *bus;
	struct pci_bus___20 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___20 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___20 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___38 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___33 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___33 *res_attr[17];
	struct bin_attribute___33 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset *msi_kset;
	const struct attribute_group___33 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___7 *sriov;
		struct pci_dev___20 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct miscdevice___11 {
	int minor;
	const char *name;
	const struct file_operations___49 *fops;
	struct list_head list;
	struct device___38 *parent;
	struct device___38 *this_device;
	const char *nodename;
	umode_t mode;
};

struct agp_kern_info___2 {
	struct agp_version version;
	struct pci_dev___25 *device;
	enum chipset_type chipset;
	long unsigned int mode;
	long unsigned int aper_base;
	size_t aper_size;
	int max_memory;
	int current_memory;
	bool cant_use_aperture;
	long unsigned int page_mask;
	const struct vm_operations_struct___43 *vm_ops;
};

struct agp_bridge_data___3;

struct agp_memory___2 {
	struct agp_memory___2 *next;
	struct agp_memory___2 *prev;
	struct agp_bridge_data___3 *bridge;
	struct page___49 **pages;
	size_t page_count;
	int key;
	int num_scratch_pages;
	off_t pg_start;
	u32 type;
	u32 physical;
	bool is_bound;
	bool is_flushed;
	struct list_head mapped_list;
	struct scatterlist *sg_list;
	int num_sg;
};

struct agp_bridge_driver___2;

struct agp_bridge_data___3 {
	const struct agp_version *version;
	const struct agp_bridge_driver___2 *driver;
	const struct vm_operations_struct___43 *vm_ops;
	void *previous_size;
	void *current_size;
	void *dev_private_data;
	struct pci_dev___25 *dev;
	u32 *gatt_table;
	u32 *gatt_table_real;
	long unsigned int scratch_page;
	struct page___49 *scratch_page_page;
	dma_addr_t scratch_page_dma;
	long unsigned int gart_bus_addr;
	long unsigned int gatt_bus_addr;
	u32 mode;
	enum chipset_type type;
	long unsigned int *key_list;
	atomic_t current_memory_agp;
	atomic_t agp_in_use;
	int max_memory_agp;
	int aperture_size_idx;
	int capndx;
	int flags;
	char major_version;
	char minor_version;
	struct list_head list;
	u32 apbase_config;
	struct list_head mapped_list;
	spinlock_t mapped_lock;
};

struct agp_info {
	struct agp_version version;
	u32 bridge_id;
	u32 agp_mode;
	long unsigned int aper_base;
	size_t aper_size;
	size_t pg_total;
	size_t pg_system;
	size_t pg_used;
};

struct agp_setup {
	u32 agp_mode;
};

struct agp_segment {
	off_t pg_start;
	size_t pg_count;
	int prot;
};

struct agp_segment_priv {
	off_t pg_start;
	size_t pg_count;
	pgprot_t prot;
};

struct agp_region {
	pid_t pid;
	size_t seg_count;
	struct agp_segment *seg_list;
};

struct agp_allocate {
	int key;
	size_t pg_count;
	u32 type;
	u32 physical;
};

struct agp_bind {
	int key;
	off_t pg_start;
};

struct agp_unbind {
	int key;
	u32 priority;
};

struct agp_client {
	struct agp_client *next;
	struct agp_client *prev;
	pid_t pid;
	int num_segments;
	struct agp_segment_priv **segments;
};

struct agp_controller {
	struct agp_controller *next;
	struct agp_controller *prev;
	pid_t pid;
	int num_clients;
	struct agp_memory___2 *pool;
	struct agp_client *clients;
};

struct agp_file_private {
	struct agp_file_private *next;
	struct agp_file_private *prev;
	pid_t my_pid;
	long unsigned int access_flags;
};

struct agp_front_data {
	struct mutex___50 agp_mutex;
	struct agp_controller *current_controller;
	struct agp_controller *controllers;
	struct agp_file_private *file_priv_list;
	bool used_by_controller;
	bool backend_acquired;
};

struct agp_bridge_driver___2 {
	struct module___32 *owner;
	const void *aperture_sizes;
	int num_aperture_sizes;
	enum aper_size_type size_type;
	bool cant_use_aperture;
	bool needs_scratch_page;
	const struct gatt_mask *masks;
	int (*fetch_size)();
	int (*configure)();
	void (*agp_enable)(struct agp_bridge_data___3 *, u32);
	void (*cleanup)();
	void (*tlb_flush)(struct agp_memory___2 *);
	long unsigned int (*mask_memory)(struct agp_bridge_data___3 *, dma_addr_t, int);
	void (*cache_flush)();
	int (*create_gatt_table)(struct agp_bridge_data___3 *);
	int (*free_gatt_table)(struct agp_bridge_data___3 *);
	int (*insert_memory)(struct agp_memory___2 *, off_t, int);
	int (*remove_memory)(struct agp_memory___2 *, off_t, int);
	struct agp_memory___2 * (*alloc_by_type)(size_t, int);
	void (*free_by_type)(struct agp_memory___2 *);
	struct page___49 * (*agp_alloc_page)(struct agp_bridge_data___3 *);
	int (*agp_alloc_pages)(struct agp_bridge_data___3 *, struct agp_memory___2 *, size_t);
	void (*agp_destroy_page)(struct page___49 *, int);
	void (*agp_destroy_pages)(struct agp_memory___2 *);
	int (*agp_type_to_mask_type)(struct agp_bridge_data___3 *, int);
};

struct agp_kern_info___3 {
	struct agp_version version;
	struct pci_dev___24 *device;
	enum chipset_type chipset;
	long unsigned int mode;
	long unsigned int aper_base;
	size_t aper_size;
	int max_memory;
	int current_memory;
	bool cant_use_aperture;
	long unsigned int page_mask;
	const struct vm_operations_struct___182 *vm_ops;
};

struct aper_size_info_8 {
	int size;
	int num_entries;
	int page_order;
	u8 size_value;
};

struct aper_size_info_16 {
	int size;
	int num_entries;
	int page_order;
	u16 size_value;
};

struct aper_size_info_32 {
	int size;
	int num_entries;
	int page_order;
	u32 size_value;
};

struct aper_size_info_lvl2 {
	int size;
	int num_entries;
	u32 size_value;
};

struct aper_size_info_fixed {
	int size;
	int num_entries;
	int page_order;
};

struct agp_3_5_dev {
	struct list_head list;
	u8 capndx;
	u32 maxbw;
	struct pci_dev___24 *dev;
};

struct isoch_data {
	u32 maxbw;
	u32 n;
	u32 y;
	u32 l;
	u32 rq;
	struct agp_3_5_dev *dev;
};

struct agp_controller___2 {
	struct agp_controller___2 *next;
	struct agp_controller___2 *prev;
	pid_t pid;
	int num_clients;
	struct agp_memory *pool;
	struct agp_client *clients;
};

struct agp_front_data___2 {
	struct mutex___204 agp_mutex;
	struct agp_controller___2 *current_controller;
	struct agp_controller___2 *controllers;
	struct agp_file_private *file_priv_list;
	bool used_by_controller;
	bool backend_acquired;
};

struct agp_info32 {
	struct agp_version version;
	u32 bridge_id;
	u32 agp_mode;
	compat_long_t aper_base;
	compat_size_t aper_size;
	compat_size_t pg_total;
	compat_size_t pg_system;
	compat_size_t pg_used;
};

struct agp_segment32 {
	compat_off_t pg_start;
	compat_size_t pg_count;
	compat_int_t prot;
};

struct agp_region32 {
	compat_pid_t pid;
	compat_size_t seg_count;
	struct agp_segment32 *seg_list;
};

struct agp_allocate32 {
	compat_int_t key;
	compat_size_t pg_count;
	u32 type;
	u32 physical;
};

struct agp_bind32 {
	compat_int_t key;
	compat_off_t pg_start;
};

struct agp_unbind32 {
	compat_int_t key;
	u32 priority;
};

struct intel_agp_driver_description {
	unsigned int chip_id;
	char *name;
	const struct agp_bridge_driver *driver;
};

struct intel_gtt_driver {
	unsigned int gen: 8;
	unsigned int is_g33: 1;
	unsigned int is_pineview: 1;
	unsigned int is_ironlake: 1;
	unsigned int has_pgtbl_enable: 1;
	unsigned int dma_mask_size: 8;
	int (*setup)();
	void (*cleanup)();
	void (*write_entry)(dma_addr_t, unsigned int, unsigned int);
	bool (*check_flags)(unsigned int);
	void (*chipset_flush)();
};

struct _intel_private {
	const struct intel_gtt_driver *driver;
	struct pci_dev___24 *pcidev;
	struct pci_dev___24 *bridge_dev;
	u8 *registers;
	phys_addr_t gtt_phys_addr;
	u32 PGETBL_save;
	u32 *gtt;
	bool clear_fake_agp;
	int num_dcache_entries;
	void *i9xx_flush_page;
	char *i81x_gtt_table;
	struct resource ifp_resource;
	int resource_valid;
	struct page___201 *scratch_page;
	phys_addr_t scratch_page_dma;
	int refcount;
	unsigned int needs_dmar: 1;
	phys_addr_t gma_bus_addr;
	unsigned int stolen_size;
	unsigned int gtt_total_entries;
	unsigned int gtt_mappable_entries;
};

struct intel_gtt_driver_description {
	unsigned int gmch_chip_id;
	char *name;
	const struct intel_gtt_driver *gtt_driver;
};

struct agp_device_ids {
	short unsigned int device_id;
	enum chipset_type chipset;
	const char *chipset_name;
	int (*chipset_setup)(struct pci_dev___24 *);
};

struct module_version_attribute___2 {
	struct module_attribute mattr;
	const char *module_name;
	const char *version;
};

struct tpm_chip;

struct tpm_class_ops {
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip *, u8);
	int (*recv)(struct tpm_chip *, u8 *, size_t);
	int (*send)(struct tpm_chip *, u8 *, size_t);
	void (*cancel)(struct tpm_chip *);
	u8 (*status)(struct tpm_chip *);
	bool (*update_timeouts)(struct tpm_chip *, long unsigned int *);
};

struct tpm_vendor_specific {
	void *iobase;
	long unsigned int base;
	int irq;
	int probed_irq;
	int region_size;
	int have_region;
	struct list_head list;
	int locality;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[3];
	bool duration_adjusted;
	void *priv;
	wait_queue_head_t read_queue;
	wait_queue_head_t int_queue;
	u16 manufacturer_id;
};

struct tpm_chip {
	struct device___158 *pdev;
	struct device___158 dev;
	struct cdev cdev;
	const struct tpm_class_ops *ops;
	unsigned int flags;
	int dev_num;
	char devname[7];
	long unsigned int is_open;
	int time_expired;
	struct mutex___3 tpm_mutex;
	struct tpm_vendor_specific vendor;
	struct dentry___82 **bios_dir;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct list_head list;
};

enum tpm_const {
	TPM_MINOR = 224,
	TPM_BUFSIZE = 4096,
	TPM_NUM_DEVICES = 256,
	TPM_RETRY = 50,
};

enum tpm_timeout {
	TPM_TIMEOUT = 5,
	TPM_TIMEOUT_RETRY = 100,
};

enum tpm_duration {
	TPM_SHORT = 0,
	TPM_MEDIUM = 1,
	TPM_LONG = 2,
	TPM_UNDEFINED = 3,
};

enum tpm2_startup_types {
	TPM2_SU_CLEAR = 0,
	TPM2_SU_STATE = 1,
};

enum tpm_chip_flags {
	TPM_CHIP_FLAG_REGISTERED = 1,
	TPM_CHIP_FLAG_PPI = 2,
	TPM_CHIP_FLAG_TPM2 = 4,
};

struct tpm_input_header {
	__be16 tag;
	__be32 length;
	__be32 ordinal;
} __attribute__((packed));

struct tpm_output_header {
	__be16 tag;
	__be32 length;
	__be32 return_code;
} __attribute__((packed));

struct stclear_flags_t {
	__be16 tag;
	u8 deactivated;
	u8 disableForceClear;
	u8 physicalPresence;
	u8 physicalPresenceLock;
	u8 bGlobalLock;
} __attribute__((packed));

struct tpm_version_t {
	u8 Major;
	u8 Minor;
	u8 revMajor;
	u8 revMinor;
};

struct tpm_version_1_2_t {
	__be16 tag;
	u8 Major;
	u8 Minor;
	u8 revMajor;
	u8 revMinor;
};

struct timeout_t {
	__be32 a;
	__be32 b;
	__be32 c;
	__be32 d;
};

struct duration_t {
	__be32 tpm_short;
	__be32 tpm_medium;
	__be32 tpm_long;
};

struct permanent_flags_t {
	__be16 tag;
	u8 disable;
	u8 ownership;
	u8 deactivated;
	u8 readPubek;
	u8 disableOwnerClear;
	u8 allowMaintenance;
	u8 physicalPresenceLifetimeLock;
	u8 physicalPresenceHWEnable;
	u8 physicalPresenceCMDEnable;
	u8 CEKPUsed;
	u8 TPMpost;
	u8 TPMpostLock;
	u8 FIPS;
	u8 operator;
	u8 enableRevokeEK;
	u8 nvLocked;
	u8 readSRKPub;
	u8 tpmEstablished;
	u8 maintenanceDone;
	u8 disableFullDALogicInfo;
};

typedef union {
	struct permanent_flags_t perm_flags;
	struct stclear_flags_t stclear_flags;
	bool owned;
	__be32 num_pcrs;
	struct tpm_version_t tpm_version;
	struct tpm_version_1_2_t tpm_version_1_2;
	__be32 manufacturer_id;
	struct timeout_t timeout;
	struct duration_t duration;
} cap_t;

enum tpm_capabilities {
	TPM_CAP_FLAG = 67108864,
	TPM_CAP_PROP = 83886080,
	CAP_VERSION_1_1 = 100663296,
	CAP_VERSION_1_2 = 436207616,
};

enum tpm_sub_capabilities {
	TPM_CAP_PROP_PCR = 16842752,
	TPM_CAP_PROP_MANUFACTURER = 50397184,
	TPM_CAP_FLAG_PERM = 134283264,
	TPM_CAP_FLAG_VOL = 151060480,
	TPM_CAP_PROP_OWNER = 285278208,
	TPM_CAP_PROP_TIS_TIMEOUT = 352387072,
	TPM_CAP_PROP_TIS_DURATION = 536936448,
};

struct tpm_getcap_params_in {
	__be32 cap;
	__be32 subcap_size;
	__be32 subcap;
};

struct tpm_getcap_params_out {
	__be32 cap_size;
	cap_t cap;
};

struct tpm_readpubek_params_out {
	u8 algorithm[4];
	u8 encscheme[2];
	u8 sigscheme[2];
	__be32 paramsize;
	u8 parameters[12];
	__be32 keysize;
	u8 modulus[256];
	u8 checksum[20];
};

typedef union {
	struct tpm_input_header in;
	struct tpm_output_header out;
} tpm_cmd_header;

struct tpm_pcrread_out {
	u8 pcr_result[20];
};

struct tpm_pcrread_in {
	__be32 pcr_idx;
};

struct tpm_pcrextend_in {
	__be32 pcr_idx;
	u8 hash[20];
};

struct tpm_getrandom_out {
	__be32 rng_data_len;
	u8 rng_data[128];
};

struct tpm_getrandom_in {
	__be32 num_bytes;
};

struct tpm_startup_in {
	__be16 startup_type;
};

typedef union {
	struct tpm_getcap_params_out getcap_out;
	struct tpm_readpubek_params_out readpubek_out;
	u8 readpubek_out_buffer[304];
	struct tpm_getcap_params_in getcap_in;
	struct tpm_pcrread_in pcrread_in;
	struct tpm_pcrread_out pcrread_out;
	struct tpm_pcrextend_in pcrextend_in;
	struct tpm_getrandom_in getrandom_in;
	struct tpm_getrandom_out getrandom_out;
	struct tpm_startup_in startup_in;
} tpm_cmd_params;

struct tpm_cmd_t {
	tpm_cmd_header header;
	tpm_cmd_params params;
} __attribute__((packed));

struct file_priv {
	struct tpm_chip *chip;
	atomic_t data_pending;
	struct mutex___207 buffer_mutex;
	struct timer_list user_read_timer;
	struct work_struct work;
	u8 data_buffer[4096];
};

struct device___183;

struct dev_pm_ops___183 {
	int (*prepare)(struct device___183 *);
	void (*complete)(struct device___183 *);
	int (*suspend)(struct device___183 *);
	int (*resume)(struct device___183 *);
	int (*freeze)(struct device___183 *);
	int (*thaw)(struct device___183 *);
	int (*poweroff)(struct device___183 *);
	int (*restore)(struct device___183 *);
	int (*suspend_late)(struct device___183 *);
	int (*resume_early)(struct device___183 *);
	int (*freeze_late)(struct device___183 *);
	int (*thaw_early)(struct device___183 *);
	int (*poweroff_late)(struct device___183 *);
	int (*restore_early)(struct device___183 *);
	int (*suspend_noirq)(struct device___183 *);
	int (*resume_noirq)(struct device___183 *);
	int (*freeze_noirq)(struct device___183 *);
	int (*thaw_noirq)(struct device___183 *);
	int (*poweroff_noirq)(struct device___183 *);
	int (*restore_noirq)(struct device___183 *);
	int (*runtime_suspend)(struct device___183 *);
	int (*runtime_resume)(struct device___183 *);
	int (*runtime_idle)(struct device___183 *);
};

struct acpi_device___22;

struct acpi_dev_node___28 {
	union {
		struct acpi_device___22 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___183;

struct bus_type___183;

struct device_driver___183;

struct dev_pm_domain___183;

struct class___183;

struct device_rh___183;

struct device___183 {
	struct device___183 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___183 *type;
	struct mutex___201 mutex;
	struct bus_type___183 *bus;
	struct device_driver___183 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___183 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___74 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___28 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___183 *class;
	const struct attribute_group___157 **groups;
	void (*release)(struct device___183 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___183 *device_rh;
};

struct dev_pm_info_rh___183 {
	void (*set_latency_tolerance)(struct device___183 *, s32);
};

struct dev_pm_domain___183 {
	struct dev_pm_ops___183 ops;
};

struct bus_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___183 *, char *);
	ssize_t (*store)(struct bus_type___183 *, const char *, size_t);
};

struct device_attribute___183;

struct driver_attribute___183;

struct bus_type___183 {
	const char *name;
	const char *dev_name;
	struct device___183 *dev_root;
	struct bus_attribute___183 *bus_attrs;
	struct device_attribute___183 *dev_attrs;
	struct driver_attribute___183 *drv_attrs;
	const struct attribute_group___157 **bus_groups;
	const struct attribute_group___157 **dev_groups;
	const struct attribute_group___157 **drv_groups;
	int (*match)(struct device___183 *, struct device_driver___183 *);
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	int (*probe)(struct device___183 *);
	int (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*online)(struct device___183 *);
	int (*offline)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct device___183 *, struct device_attribute___183 *, char *);
	ssize_t (*store)(struct device___183 *, struct device_attribute___183 *, const char *, size_t);
};

struct driver_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___183 *, char *);
	ssize_t (*store)(struct device_driver___183 *, const char *, size_t);
};

struct device_driver___183 {
	const char *name;
	struct bus_type___183 *bus;
	struct module___113 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___183 *);
	int (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	const struct attribute_group___157 **groups;
	const struct dev_pm_ops___183 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___183 {
	const char *name;
	const struct attribute_group___157 **groups;
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
};

struct class_attribute___183;

struct class___183 {
	const char *name;
	struct module___113 *owner;
	struct class_attribute___183 *class_attrs;
	struct device_attribute___183 *dev_attrs;
	const struct attribute_group___157 **dev_groups;
	struct bin_attribute___159 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *);
	void (*class_release)(struct class___183 *);
	void (*dev_release)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
	struct subsys_private *p;
};

struct class_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct class___183 *, struct class_attribute___183 *, char *);
	ssize_t (*store)(struct class___183 *, struct class_attribute___183 *, const char *, size_t);
	const void * (*namespace)(struct class___183 *, const struct class_attribute___183 *);
};

struct acpi_scan_handler___22;

struct acpi_hotplug_context___22;

struct acpi_driver___22;

struct acpi_device___22 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___22 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___22 *handler;
	struct acpi_hotplug_context___22 *hp;
	struct acpi_driver___22 *driver;
	void *driver_data;
	struct device___183 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___201 physical_node_lock;
	void (*remove)(struct acpi_device___22 *);
};

struct device_rh___183 {
	struct dev_pm_info_rh___183 power;
};

struct tpm_chip___2;

struct tpm_class_ops___2 {
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___2 *, u8);
	int (*recv)(struct tpm_chip___2 *, u8 *, size_t);
	int (*send)(struct tpm_chip___2 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___2 *);
	u8 (*status)(struct tpm_chip___2 *);
	bool (*update_timeouts)(struct tpm_chip___2 *, long unsigned int *);
};

struct tpm_chip___2 {
	struct device___183 *pdev;
	struct device___183 dev;
	struct cdev___53 cdev;
	const struct tpm_class_ops___2 *ops;
	unsigned int flags;
	int dev_num;
	char devname[7];
	long unsigned int is_open;
	int time_expired;
	struct mutex___201 tpm_mutex;
	struct tpm_vendor_specific vendor;
	struct dentry___199 **bios_dir;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct list_head list;
};

struct acpi_hotplug_profile___22 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___22 *);
	void (*notify_online)(struct acpi_device___22 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___22 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___22 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___22 *);
	void (*bind)(struct device___183 *);
	void (*unbind)(struct device___183 *);
	struct acpi_hotplug_profile___22 hotplug;
};

struct acpi_hotplug_context___22 {
	struct acpi_device___22 *self;
	int (*notify)(struct acpi_device___22 *, u32);
	void (*uevent)(struct acpi_device___22 *, u32);
	void (*fixup)(struct acpi_device___22 *);
};

typedef int (*acpi_op_add___22)(struct acpi_device___22 *);

typedef int (*acpi_op_remove___22)(struct acpi_device___22 *);

typedef void (*acpi_op_notify___22)(struct acpi_device___22 *, u32);

struct acpi_device_ops___22 {
	acpi_op_add___22 add;
	acpi_op_remove___22 remove;
	acpi_op_notify___22 notify;
};

struct acpi_driver___22 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___22 ops;
	struct device_driver___183 drv;
	struct module___113 *owner;
};

enum tpm2_const {
	TPM2_PLATFORM_PCR = 24,
	TPM2_PCR_SELECT_MIN = 3,
	TPM2_TIMEOUT_A = 750,
	TPM2_TIMEOUT_B = 2000,
	TPM2_TIMEOUT_C = 200,
	TPM2_TIMEOUT_D = 30,
	TPM2_DURATION_SHORT = 20,
	TPM2_DURATION_MEDIUM = 750,
	TPM2_DURATION_LONG = 2000,
};

enum tpm2_structures {
	TPM2_ST_NO_SESSIONS = 32769,
	TPM2_ST_SESSIONS = 32770,
};

enum tpm2_return_codes {
	TPM2_RC_INITIALIZE = 256,
	TPM2_RC_TESTING = 2314,
	TPM2_RC_DISABLED = 288,
};

enum tpm2_algorithms {
	TPM2_ALG_SHA1 = 4,
};

enum tpm2_command_codes {
	TPM2_CC_FIRST = 287,
	TPM2_CC_SELF_TEST = 323,
	TPM2_CC_STARTUP = 324,
	TPM2_CC_SHUTDOWN = 325,
	TPM2_CC_GET_CAPABILITY = 378,
	TPM2_CC_GET_RANDOM = 379,
	TPM2_CC_PCR_READ = 382,
	TPM2_CC_PCR_EXTEND = 386,
	TPM2_CC_LAST = 399,
};

enum tpm2_permanent_handles {
	TPM2_RS_PW = 1073741833,
};

enum tpm2_capabilities {
	TPM2_CAP_TPM_PROPERTIES = 6,
};

struct tpm2_startup_in {
	__be16 startup_type;
};

struct tpm2_self_test_in {
	u8 full_test;
};

struct tpm2_pcr_read_in {
	__be32 pcr_selects_cnt;
	__be16 hash_alg;
	u8 pcr_select_size;
	u8 pcr_select[3];
} __attribute__((packed));

struct tpm2_pcr_read_out {
	__be32 update_cnt;
	__be32 pcr_selects_cnt;
	__be16 hash_alg;
	u8 pcr_select_size;
	u8 pcr_select[3];
	__be32 digests_cnt;
	__be16 digest_size;
	u8 digest[20];
} __attribute__((packed));

struct tpm2_null_auth_area {
	__be32 handle;
	__be16 nonce_size;
	u8 attributes;
	__be16 auth_size;
} __attribute__((packed));

struct tpm2_pcr_extend_in {
	__be32 pcr_idx;
	__be32 auth_area_size;
	struct tpm2_null_auth_area auth_area;
	__be32 digest_cnt;
	__be16 hash_alg;
	u8 digest[20];
} __attribute__((packed));

struct tpm2_get_tpm_pt_in {
	__be32 cap_id;
	__be32 property_id;
	__be32 property_cnt;
};

struct tpm2_get_tpm_pt_out {
	u8 more_data;
	__be32 subcap_id;
	__be32 property_cnt;
	__be32 property_id;
	__be32 value;
} __attribute__((packed));

struct tpm2_get_random_in {
	__be16 size;
};

struct tpm2_get_random_out {
	__be16 size;
	u8 buffer[128];
};

union tpm2_cmd_params {
	struct tpm2_startup_in startup_in;
	struct tpm2_self_test_in selftest_in;
	struct tpm2_pcr_read_in pcrread_in;
	struct tpm2_pcr_read_out pcrread_out;
	struct tpm2_pcr_extend_in pcrextend_in;
	struct tpm2_get_tpm_pt_in get_tpm_pt_in;
	struct tpm2_get_tpm_pt_out get_tpm_pt_out;
	struct tpm2_get_random_in getrandom_in;
	struct tpm2_get_random_out getrandom_out;
};

struct tpm2_cmd {
	tpm_cmd_header header;
	union tpm2_cmd_params params;
} __attribute__((packed));

struct tpm_chip___3;

struct tpm_class_ops___3 {
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___3 *, u8);
	int (*recv)(struct tpm_chip___3 *, u8 *, size_t);
	int (*send)(struct tpm_chip___3 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___3 *);
	u8 (*status)(struct tpm_chip___3 *);
	bool (*update_timeouts)(struct tpm_chip___3 *, long unsigned int *);
};

struct tpm_chip___3 {
	struct device___25 *pdev;
	struct device___25 dev;
	struct cdev___54 cdev;
	const struct tpm_class_ops___3 *ops;
	unsigned int flags;
	int dev_num;
	char devname[7];
	long unsigned int is_open;
	int time_expired;
	struct mutex___202 tpm_mutex;
	struct tpm_vendor_specific vendor;
	struct dentry___200 **bios_dir;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct list_head list;
};

struct tpm_bios_log {
	void *bios_event_log;
	void *bios_event_log_end;
};

struct tcpa_event {
	u32 pcr_index;
	u32 event_type;
	u8 pcr_value[20];
	u32 event_size;
	u8 event_data[0];
};

enum tcpa_event_types {
	PREBOOT = 0,
	POST_CODE = 1,
	UNUSED = 2,
	NO_ACTION = 3,
	SEPARATOR = 4,
	ACTION = 5,
	EVENT_TAG = 6,
	SCRTM_CONTENTS = 7,
	SCRTM_VERSION = 8,
	CPU_MICROCODE = 9,
	PLATFORM_CONFIG_FLAGS = 10,
	TABLE_OF_DEVICES = 11,
	COMPACT_HASH = 12,
	IPL = 13,
	IPL_PARTITION_DATA = 14,
	NONHOST_CODE = 15,
	NONHOST_CONFIG = 16,
	NONHOST_INFO = 17,
};

struct tcpa_pc_event {
	u32 event_id;
	u32 event_size;
	u8 event_data[0];
};

enum tcpa_pc_event_ids {
	SMBIOS = 1,
	BIS_CERT = 2,
	POST_BIOS_ROM = 3,
	ESCD = 4,
	CMOS = 5,
	NVRAM = 6,
	OPTION_ROM_EXEC = 7,
	OPTION_ROM_CONFIG = 8,
	OPTION_ROM_MICROCODE = 10,
	S_CRTM_VERSION = 11,
	S_CRTM_CONTENTS = 12,
	POST_CONTENTS = 13,
	HOST_TABLE_OF_DEVICES = 14,
};

enum bios_platform_class {
	BIOS_CLIENT = 0,
	BIOS_SERVER = 1,
};

struct client_hdr {
	u32 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct server_hdr {
	u16 reserved;
	u64 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct acpi_tcpa {
	struct acpi_table_header hdr;
	u16 platform_class;
	union {
		struct client_hdr client;
		struct server_hdr server;
	};
} __attribute__((packed));

struct module_version_attribute___3 {
	struct module_attribute___113 mattr;
	const char *module_name;
	const char *version;
};

struct pnp_protocol___5;

struct pnp_card___5 {
	struct device___25 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___5 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___5;

struct pnp_protocol___5 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___5 *);
	int (*set)(struct pnp_dev___5 *);
	int (*disable)(struct pnp_dev___5 *);
	bool (*can_wakeup)(struct pnp_dev___5 *);
	int (*suspend)(struct pnp_dev___5 *, pm_message_t);
	int (*resume)(struct pnp_dev___5 *);
	unsigned char number;
	struct device___25 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___5;

struct pnp_card_link___5 {
	struct pnp_card___5 *card;
	struct pnp_card_driver___5 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___5 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___5 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___5 *);
	void (*shutdown)(struct pnp_dev___5 *);
	int (*suspend)(struct pnp_dev___5 *, pm_message_t);
	int (*resume)(struct pnp_dev___5 *);
	struct device_driver___25 driver;
};

struct pnp_card_driver___5 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___5 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___5 *);
	int (*suspend)(struct pnp_card_link___5 *, pm_message_t);
	int (*resume)(struct pnp_card_link___5 *);
	struct pnp_driver___5 link;
};

struct pnp_dev___5 {
	struct device___25 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___5 *protocol;
	struct pnp_card___5 *card;
	struct pnp_driver___5 *driver;
	struct pnp_card_link___5 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct platform_device___7 {
	const char *name;
	int id;
	bool id_auto;
	struct device___25 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___5 {
	struct device___25 *parent;
	struct acpi_dev_node___9 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct platform_driver___5 {
	int (*probe)(struct platform_device___7 *);
	int (*remove)(struct platform_device___7 *);
	void (*shutdown)(struct platform_device___7 *);
	int (*suspend)(struct platform_device___7 *, pm_message_t);
	int (*resume)(struct platform_device___7 *);
	struct device_driver___25 driver;
	const struct platform_device_id *id_table;
};

enum tis_access {
	TPM_ACCESS_VALID = 128,
	TPM_ACCESS_ACTIVE_LOCALITY = 32,
	TPM_ACCESS_REQUEST_PENDING = 4,
	TPM_ACCESS_REQUEST_USE = 2,
};

enum tis_status {
	TPM_STS_VALID = 128,
	TPM_STS_COMMAND_READY = 64,
	TPM_STS_GO = 32,
	TPM_STS_DATA_AVAIL = 16,
	TPM_STS_DATA_EXPECT = 8,
};

enum tis_int_flags {
	TPM_GLOBAL_INT_ENABLE = 2147483648,
	TPM_INTF_BURST_COUNT_STATIC = 256,
	TPM_INTF_CMD_READY_INT = 128,
	TPM_INTF_INT_EDGE_FALLING = 64,
	TPM_INTF_INT_EDGE_RISING = 32,
	TPM_INTF_INT_LEVEL_LOW = 16,
	TPM_INTF_INT_LEVEL_HIGH = 8,
	TPM_INTF_LOCALITY_CHANGE_INT = 4,
	TPM_INTF_STS_VALID_INT = 2,
	TPM_INTF_DATA_AVAIL_INT = 1,
};

enum tis_defaults {
	TIS_MEM_BASE = 4275306496,
	TIS_MEM_LEN = 20480,
	TIS_SHORT_TIMEOUT = 750,
	TIS_LONG_TIMEOUT = 2000,
};

struct priv_data {
	bool irq_tested;
};

struct tis_vendor_timeout_override {
	u32 did_vid;
	long unsigned int timeout_us[4];
};

struct miscdevice___12 {
	int minor;
	const char *name;
	const struct file_operations___203 *fops;
	struct list_head list;
	struct device___31 *parent;
	struct device___31 *this_device;
	const char *nodename;
	umode_t mode;
};

typedef struct poll_table_struct___48 poll_table___26;

struct miscdevice___13 {
	int minor;
	const char *name;
	const struct file_operations___80 *fops;
	struct list_head list;
	struct device___157 *parent;
	struct device___157 *this_device;
	const char *nodename;
	umode_t mode;
};

struct vga_device {
	struct list_head list;
	struct pci_dev___22 *pdev;
	unsigned int decodes;
	unsigned int owns;
	unsigned int locks;
	unsigned int io_lock_cnt;
	unsigned int mem_lock_cnt;
	unsigned int io_norm_cnt;
	unsigned int mem_norm_cnt;
	bool bridge_has_one_vga;
	void *cookie;
	void (*irq_set_state)(void *, bool);
	unsigned int (*set_vga_decode)(void *, bool);
};

struct vga_arb_user_card {
	struct pci_dev___22 *pdev;
	unsigned int mem_cnt;
	unsigned int io_cnt;
};

struct vga_arb_private {
	struct list_head list;
	struct pci_dev___22 *target;
	struct vga_arb_user_card cards[64];
	spinlock_t lock;
};

struct dma_map_ops___75;

struct dev_archdata___75 {
	struct dma_map_ops___75 *dma_ops;
	void *iommu;
};

struct device_type___184;

struct bus_type___184;

struct device_driver___184;

struct dev_pm_domain___184;

struct device_node___12;

struct class___184;

struct device_rh___184;

struct device___184 {
	struct device___184 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___184 *type;
	struct mutex___178 mutex;
	struct bus_type___184 *bus;
	struct device_driver___184 *driver;
	void *platform_data;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___184 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___75 archdata;
	struct device_node___12 *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___184 *class;
	const struct attribute_group___132 **groups;
	void (*release)(struct device___184 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___184 *device_rh;
};

struct pci_bus___25;

struct pci_slot___25;

struct pci_driver___25;

struct pci_dev___26 {
	struct list_head bus_list;
	struct pci_bus___25 *bus;
	struct pci_bus___25 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___25 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___25 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___184 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___134 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___134 *res_attr[17];
	struct bin_attribute___134 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___4 *msi_kset;
	const struct attribute_group___132 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___26 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct dev_pm_ops___184 {
	int (*prepare)(struct device___184 *);
	void (*complete)(struct device___184 *);
	int (*suspend)(struct device___184 *);
	int (*resume)(struct device___184 *);
	int (*freeze)(struct device___184 *);
	int (*thaw)(struct device___184 *);
	int (*poweroff)(struct device___184 *);
	int (*restore)(struct device___184 *);
	int (*suspend_late)(struct device___184 *);
	int (*resume_early)(struct device___184 *);
	int (*freeze_late)(struct device___184 *);
	int (*thaw_early)(struct device___184 *);
	int (*poweroff_late)(struct device___184 *);
	int (*restore_early)(struct device___184 *);
	int (*suspend_noirq)(struct device___184 *);
	int (*resume_noirq)(struct device___184 *);
	int (*freeze_noirq)(struct device___184 *);
	int (*thaw_noirq)(struct device___184 *);
	int (*poweroff_noirq)(struct device___184 *);
	int (*restore_noirq)(struct device___184 *);
	int (*runtime_suspend)(struct device___184 *);
	int (*runtime_resume)(struct device___184 *);
	int (*runtime_idle)(struct device___184 *);
};

struct dev_pm_info_rh___184 {
	void (*set_latency_tolerance)(struct device___184 *, s32);
};

struct dev_pm_domain___184 {
	struct dev_pm_ops___184 ops;
};

struct property___12;

struct device_node___12 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___12 *properties;
	struct property___12 *deadprops;
	struct device_node___12 *parent;
	struct device_node___12 *child;
	struct device_node___12 *sibling;
	struct device_node___12 *next;
	struct device_node___12 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___4 kobj;
};

struct dma_map_ops___75 {
	void * (*alloc)(struct device___184 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___184 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___184 *, struct vm_area_struct___182 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___184 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___184 *, struct page___174 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___184 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___184 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___184 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___184 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___184 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___184 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___184 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___184 *, dma_addr_t);
	int (*dma_supported)(struct device___184 *, u64);
	int (*set_dma_mask)(struct device___184 *, u64);
	int is_phys;
};

struct bus_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___184 *, char *);
	ssize_t (*store)(struct bus_type___184 *, const char *, size_t);
};

struct device_attribute___184;

struct driver_attribute___184;

struct bus_type___184 {
	const char *name;
	const char *dev_name;
	struct device___184 *dev_root;
	struct bus_attribute___184 *bus_attrs;
	struct device_attribute___184 *dev_attrs;
	struct driver_attribute___184 *drv_attrs;
	const struct attribute_group___132 **bus_groups;
	const struct attribute_group___132 **dev_groups;
	const struct attribute_group___132 **drv_groups;
	int (*match)(struct device___184 *, struct device_driver___184 *);
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	int (*probe)(struct device___184 *);
	int (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*online)(struct device___184 *);
	int (*offline)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct device___184 *, struct device_attribute___184 *, char *);
	ssize_t (*store)(struct device___184 *, struct device_attribute___184 *, const char *, size_t);
};

struct driver_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___184 *, char *);
	ssize_t (*store)(struct device_driver___184 *, const char *, size_t);
};

struct device_driver___184 {
	const char *name;
	struct bus_type___184 *bus;
	struct module___94 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___184 *);
	int (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	const struct attribute_group___132 **groups;
	const struct dev_pm_ops___184 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___184 {
	const char *name;
	const struct attribute_group___132 **groups;
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
};

struct class_attribute___184;

struct class___184 {
	const char *name;
	struct module___94 *owner;
	struct class_attribute___184 *class_attrs;
	struct device_attribute___184 *dev_attrs;
	const struct attribute_group___132 **dev_groups;
	struct bin_attribute___134 *dev_bin_attrs;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *);
	void (*class_release)(struct class___184 *);
	void (*dev_release)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
	struct subsys_private *p;
};

struct class_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct class___184 *, struct class_attribute___184 *, char *);
	ssize_t (*store)(struct class___184 *, struct class_attribute___184 *, const char *, size_t);
	const void * (*namespace)(struct class___184 *, const struct class_attribute___184 *);
};

struct device_rh___184 {
	struct dev_pm_info_rh___184 power;
};

struct property___12 {
	char *name;
	int length;
	void *value;
	struct property___12 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___134 attr;
};

struct backlight_device___6;

struct fb_info___6;

struct backlight_ops___6 {
	unsigned int options;
	int (*update_status)(struct backlight_device___6 *);
	int (*get_brightness)(struct backlight_device___6 *);
	int (*check_fb)(struct backlight_device___6 *, struct fb_info___6 *);
};

struct backlight_device___6 {
	struct backlight_properties props;
	struct mutex___178 update_lock;
	struct mutex___178 ops_lock;
	const struct backlight_ops___6 *ops;
	struct notifier_block fb_notif;
	struct device___184 dev;
	struct list_head entry;
};

struct fb_pixmap___6 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___6 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___6 *, void *, void *, unsigned int);
};

struct fb_deferred_io___6;

struct fb_ops___6;

struct fb_tile_ops___6;

struct fb_info___6 {
	atomic_t count;
	int node;
	int flags;
	struct mutex___178 lock;
	struct mutex___178 mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___6 pixmap;
	struct fb_pixmap___6 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___6 *bl_dev;
	struct mutex___178 bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___6 *fbdefio;
	struct fb_ops___6 *fbops;
	struct device___184 *device;
	struct device___184 *dev;
	int class_flag;
	struct fb_tile_ops___6 *tileops;
	char *screen_base;
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_event___4 {
	struct fb_info___6 *info;
	void *data;
};

struct fb_deferred_io___6 {
	long unsigned int delay;
	struct mutex___178 lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___6 *);
	void (*deferred_io)(struct fb_info___6 *, struct list_head *);
};

struct fb_ops___6 {
	struct module___94 *owner;
	int (*fb_open)(struct fb_info___6 *, int);
	int (*fb_release)(struct fb_info___6 *, int);
	ssize_t (*fb_read)(struct fb_info___6 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___6 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___6 *);
	int (*fb_set_par)(struct fb_info___6 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___6 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___6 *);
	int (*fb_blank)(int, struct fb_info___6 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___6 *);
	void (*fb_fillrect)(struct fb_info___6 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___6 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___6 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___6 *, struct fb_cursor *);
	void (*fb_rotate)(struct fb_info___6 *, int);
	int (*fb_sync)(struct fb_info___6 *);
	int (*fb_ioctl)(struct fb_info___6 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___6 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___6 *, struct vm_area_struct___182 *);
	void (*fb_get_caps)(struct fb_info___6 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___6 *);
	int (*fb_debug_enter)(struct fb_info___6 *);
	int (*fb_debug_leave)(struct fb_info___6 *);
};

struct fb_tile_ops___6 {
	void (*fb_settile)(struct fb_info___6 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___6 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___6 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___6 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___6 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___6 *);
};

struct pci_slot___25 {
	struct pci_bus___25 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___4 kobj;
};

struct pci_ops___25;

struct pci_bus___25 {
	struct list_head node;
	struct pci_bus___25 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___26 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___25 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___184 *bridge;
	struct device___184 dev;
	struct bin_attribute___134 *legacy_io;
	struct bin_attribute___134 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___25;

struct pci_driver_rh___25;

struct pci_driver___25 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___26 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___26 *);
	int (*suspend)(struct pci_dev___26 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___26 *, pm_message_t);
	int (*resume_early)(struct pci_dev___26 *);
	int (*resume)(struct pci_dev___26 *);
	void (*shutdown)(struct pci_dev___26 *);
	int (*sriov_configure)(struct pci_dev___26 *, int);
	const struct pci_error_handlers___25 *err_handler;
	struct device_driver___184 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___25 *pci_driver_rh;
};

struct pci_ops___25 {
	int (*read)(struct pci_bus___25 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___25 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___25 {
	pci_ers_result_t (*error_detected)(struct pci_dev___26 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___26 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___26 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___26 *);
	void (*resume)(struct pci_dev___26 *);
};

struct pci_driver_rh___25 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___26 *, bool);
};

enum vga_switcheroo_state {
	VGA_SWITCHEROO_OFF = 0,
	VGA_SWITCHEROO_ON = 1,
	VGA_SWITCHEROO_INIT = 2,
	VGA_SWITCHEROO_NOT_FOUND = 3,
};

enum vga_switcheroo_client_id {
	VGA_SWITCHEROO_IGD = 0,
	VGA_SWITCHEROO_DIS = 1,
	VGA_SWITCHEROO_MAX_CLIENTS = 2,
};

struct vga_switcheroo_handler {
	int (*switchto)(enum vga_switcheroo_client_id);
	int (*power_state)(enum vga_switcheroo_client_id, enum vga_switcheroo_state);
	int (*init)();
	int (*get_client_id)(struct pci_dev___26 *);
};

struct vga_switcheroo_client_ops {
	void (*set_gpu_state)(struct pci_dev___26 *, enum vga_switcheroo_state);
	void (*reprobe)(struct pci_dev___26 *);
	bool (*can_switch)(struct pci_dev___26 *);
};

struct vga_switcheroo_client {
	struct pci_dev___26 *pdev;
	struct fb_info___6 *fb_info;
	int pwr_state;
	const struct vga_switcheroo_client_ops *ops;
	int id;
	bool active;
	bool driver_power_control;
	struct list_head list;
};

struct vgasr_priv {
	bool active;
	bool delayed_switch_active;
	enum vga_switcheroo_client_id delayed_client_id;
	struct dentry___175 *debugfs_root;
	struct dentry___175 *switch_file;
	int registered_clients;
	struct list_head clients;
	struct vga_switcheroo_handler *handler;
};

struct page___205;

typedef struct page___205 *pgtable_t___205;

struct address_space___206;

struct kmem_cache___191;

struct page___205 {
	long unsigned int flags;
	struct address_space___206 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___205 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___205 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___191 *slab_cache;
		struct page___205 *first_page;
	};
	long: 64;
};

struct task_struct___207;

struct pv_cpu_ops___207 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___79 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___79 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___207 *);
	void (*end_context_switch)(struct task_struct___207 *);
};

struct mutex___208 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___207 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___200 {
	struct page___205 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___214;

struct nsproxy___108;

struct signal_struct___207;

struct css_set___123;

struct task_struct___207 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___207 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___214 *mm;
	struct mm_struct___214 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___207 *real_parent;
	struct task_struct___207 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___207 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___88 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___207 = 0,
		VTIME_USER___207 = 1,
		VTIME_SYS___207 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___79 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___108 *nsproxy;
	struct signal_struct___207 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___123 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___208 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___200 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___214 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___214 *, struct mm_struct___214 *);
	void (*dup_mmap)(struct mm_struct___214 *, struct mm_struct___214 *);
	void (*exit_mmap)(struct mm_struct___214 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___214 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___214 *);
	void (*pgd_free)(struct mm_struct___214 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___214 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___214 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___214 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___214 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___214 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___214 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___214 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___214 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___214 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___214 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___214 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___208 lock;
	void *vdso;
} mm_context_t___208;

struct xol_area___205;

struct uprobes_state___205 {
	struct xol_area___205 *xol_area;
};

struct vm_area_struct___214;

struct file___206;

struct core_state___207;

struct mm_struct___214 {
	struct vm_area_struct___214 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___214 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___214 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___208 context;
	long unsigned int flags;
	struct core_state___207 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___207 *owner;
	struct file___206 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___205 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___21;

struct kobj_type___21;

struct kobject___21 {
	const char *name;
	struct list_head entry;
	struct kobject___21 *parent;
	struct kset___21 *kset;
	struct kobj_type___21 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___119;

struct module_kobject___118 {
	struct kobject___21 kobj;
	struct module___119 *mod;
	struct kobject___21 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___118;

struct module___119 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___118 mkobj;
	struct module_attribute___118 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___21 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___207 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___207;

struct lruvec___207 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___207 *zone;
};

struct pglist_data___207;

struct zone___207 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___207 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___207 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___207 {
	struct zone___207 *zone;
	int zone_idx;
};

struct zonelist___207 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___207 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___207 {
	struct zone___207 node_zones[4];
	struct zonelist___207 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___207 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___134;

struct x86_io_apic_ops___134 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___134 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___134;

struct irq_data___134 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___134 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___185;

struct dev_pm_ops___185 {
	int (*prepare)(struct device___185 *);
	void (*complete)(struct device___185 *);
	int (*suspend)(struct device___185 *);
	int (*resume)(struct device___185 *);
	int (*freeze)(struct device___185 *);
	int (*thaw)(struct device___185 *);
	int (*poweroff)(struct device___185 *);
	int (*restore)(struct device___185 *);
	int (*suspend_late)(struct device___185 *);
	int (*resume_early)(struct device___185 *);
	int (*freeze_late)(struct device___185 *);
	int (*thaw_early)(struct device___185 *);
	int (*poweroff_late)(struct device___185 *);
	int (*restore_early)(struct device___185 *);
	int (*suspend_noirq)(struct device___185 *);
	int (*resume_noirq)(struct device___185 *);
	int (*freeze_noirq)(struct device___185 *);
	int (*thaw_noirq)(struct device___185 *);
	int (*poweroff_noirq)(struct device___185 *);
	int (*restore_noirq)(struct device___185 *);
	int (*runtime_suspend)(struct device___185 *);
	int (*runtime_resume)(struct device___185 *);
	int (*runtime_idle)(struct device___185 *);
};

struct dev_pm_qos___28;

struct dev_pm_info___28 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___28 *qos;
};

struct dma_map_ops___76;

struct dev_archdata___76 {
	struct dma_map_ops___76 *dma_ops;
	void *iommu;
};

struct device_type___185;

struct bus_type___185;

struct device_driver___185;

struct dev_pm_domain___185;

struct class___185;

struct attribute_group___164;

struct device_rh___185;

struct device___185 {
	struct device___185 *parent;
	struct device_private *p;
	struct kobject___21 kobj;
	const char *init_name;
	const struct device_type___185 *type;
	struct mutex___208 mutex;
	struct bus_type___185 *bus;
	struct device_driver___185 *driver;
	void *platform_data;
	struct dev_pm_info___28 power;
	struct dev_pm_domain___185 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___76 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___185 *class;
	const struct attribute_group___164 **groups;
	void (*release)(struct device___185 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___185 *device_rh;
};

struct dev_pm_qos_request___28;

struct dev_pm_qos___28 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___28 *latency_req;
	struct dev_pm_qos_request___28 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___28 *latency_tolerance_req;
};

struct dev_pm_info_rh___185 {
	void (*set_latency_tolerance)(struct device___185 *, s32);
};

struct dev_pm_domain___185 {
	struct dev_pm_ops___185 ops;
};

struct smp_ops___207 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___207 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___37;

struct ctl_node___37 {
	struct rb_node node;
	struct ctl_table_header___37 *header;
};

struct ctl_table_root___37;

struct ctl_table_set___37;

struct ctl_dir___37;

struct ctl_table_header___37 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___37 *root;
	struct ctl_table_set___37 *set;
	struct ctl_dir___37 *parent;
	struct ctl_node___37 *node;
};

struct ctl_dir___37 {
	struct ctl_table_header___37 header;
	struct rb_root root;
};

struct ctl_table_set___37 {
	int (*is_seen)(struct ctl_table_set___37 *);
	struct ctl_dir___37 dir;
};

struct ctl_table_root___37 {
	struct ctl_table_set___37 default_set;
	struct ctl_table_set___37 * (*lookup)(struct ctl_table_root___37 *, struct nsproxy___108 *);
	int (*permissions)(struct ctl_table_header___37 *, struct ctl_table *);
};

struct net___36;

struct nsproxy___108 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___36 *net_ns;
};

struct sock___19;

struct kobj_ns_type_operations___18 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___19 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___18;

struct sock_common___18 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___18 *skc_prot;
	struct net___36 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___26;

struct sk_buff_head___24 {
	struct sk_buff___26 *next;
	struct sk_buff___26 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___19;

struct socket_wq___18;

struct dst_entry___18;

struct socket___19;

struct cg_proto___18;

struct sock___19 {
	struct sock_common___18 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___24 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___26 *head;
		struct sk_buff___26 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___19 *sk_filter;
	struct socket_wq___18 *sk_wq;
	struct sk_buff_head___24 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___18 *sk_rx_dst;
	struct dst_entry___18 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___24 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___24 sk_error_queue;
	struct proto___18 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___88 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___19 *sk_socket;
	void *sk_user_data;
	struct page_frag___200 sk_frag;
	struct sk_buff___26 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___18 *sk_cgrp;
	void (*sk_state_change)(struct sock___19 *);
	void (*sk_data_ready)(struct sock___19 *, int);
	void (*sk_write_space)(struct sock___19 *);
	void (*sk_error_report)(struct sock___19 *);
	int (*sk_backlog_rcv)(struct sock___19 *, struct sk_buff___26 *);
	void (*sk_destruct)(struct sock___19 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___166;

struct attribute_group___164 {
	const char *name;
	umode_t (*is_visible)(struct kobject___21 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___166 **bin_attrs;
};

struct bin_attribute___166 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___206 *, struct kobject___21 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___206 *, struct kobject___21 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	int (*mmap)(struct file___206 *, struct kobject___21 *, struct bin_attribute___166 *, struct vm_area_struct___214 *);
};

struct dentry___206;

struct path___206 {
	struct vfsmount *mnt;
	struct dentry___206 *dentry;
};

struct inode___206;

struct file_operations___206;

struct file___206 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___206 f_path;
	struct inode___206 *f_inode;
	const struct file_operations___206 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___88 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___206 *f_mapping;
	struct mutex___208 f_pos_lock;
};

struct vm_operations_struct___186;

struct vm_area_struct___214 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___214 *vm_next;
	struct vm_area_struct___214 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___214 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___186 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___206 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___21 {
	ssize_t (*show)(struct kobject___21 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___21 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___21 *, const struct attribute *);
};

struct kset_uevent_ops___21;

struct kset___21 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___21 kobj;
	const struct kset_uevent_ops___21 *uevent_ops;
};

struct kobj_type___21 {
	void (*release)(struct kobject___21 *);
	const struct sysfs_ops___21 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___18 * (*child_ns_type)(struct kobject___21 *);
	const void * (*namespace)(struct kobject___21 *);
};

struct kset_uevent_ops___21 {
	int (* const filter)(struct kset___21 *, struct kobject___21 *);
	const char * (* const name)(struct kset___21 *, struct kobject___21 *);
	int (* const uevent)(struct kset___21 *, struct kobject___21 *, struct kobj_uevent_env *);
};

struct module_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___118 *, struct module_kobject___118 *, char *);
	ssize_t (*store)(struct module_attribute___118 *, struct module_kobject___118 *, const char *, size_t);
	void (*setup)(struct module___119 *, const char *);
	int (*test)(struct module___119 *);
	void (*free)(struct module___119 *);
};

struct kmem_cache_cpu___190 {
	void **freelist;
	long unsigned int tid;
	struct page___205 *page;
	struct page___205 *partial;
};

struct memcg_cache_params___191;

struct kmem_cache___191 {
	struct kmem_cache_cpu___190 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___21 kobj;
	struct memcg_cache_params___191 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___191 {
	bool is_root_cache;
	union {
		struct kmem_cache___191 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___191 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___205 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___205 *page;
	long unsigned int vaddr;
};

struct address_space_operations___206;

struct address_space___206 {
	struct inode___206 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___208 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___206 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___182;

struct vm_operations_struct___186 {
	void (*open)(struct vm_area_struct___214 *);
	void (*close)(struct vm_area_struct___214 *);
	int (*fault)(struct vm_area_struct___214 *, struct vm_fault___182 *);
	int (*page_mkwrite)(struct vm_area_struct___214 *, struct vm_fault___182 *);
	int (*access)(struct vm_area_struct___214 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___214 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___214 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___214 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___214 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___207 {
	struct task_struct___207 *task;
	struct core_thread___207 *next;
};

struct core_state___207 {
	atomic_t nr_threads;
	struct core_thread___207 dumper;
	struct completion startup;
};

struct fasync_struct___206;

struct socket_wq___18 {
	wait_queue_head_t wait;
	struct fasync_struct___206 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___206 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___206 *fa_next;
	struct file___206 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___18;

struct socket___19 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___18 *wq;
	struct file___206 *file;
	struct sock___19 *sk;
	const struct proto_ops___18 *ops;
};

struct poll_table_struct___114;

struct kiocb___26;

struct proto_ops___18 {
	int family;
	struct module___119 *owner;
	int (*release)(struct socket___19 *);
	int (*bind)(struct socket___19 *, struct sockaddr *, int);
	int (*connect)(struct socket___19 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___19 *, struct socket___19 *);
	int (*accept)(struct socket___19 *, struct socket___19 *, int);
	int (*getname)(struct socket___19 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___206 *, struct socket___19 *, struct poll_table_struct___114 *);
	int (*ioctl)(struct socket___19 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___19 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___19 *, int);
	int (*shutdown)(struct socket___19 *, int);
	int (*setsockopt)(struct socket___19 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___19 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___19 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___19 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___26 *, struct socket___19 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___26 *, struct socket___19 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___206 *, struct socket___19 *, struct vm_area_struct___214 *);
	ssize_t (*sendpage)(struct socket___19 *, struct page___205 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___19 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___19 *, int);
		struct {
			void (*set_peek_off)(struct sock___19 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___116)(struct file___206 *, wait_queue_head_t *, struct poll_table_struct___114 *);

struct poll_table_struct___114 {
	poll_queue_proc___116 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___26(struct kiocb___26 *, struct io_event *);

struct kiocb___26 {
	atomic_t ki_users;
	struct file___206 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___26 *ki_cancel;
	void (*ki_dtor)(struct kiocb___26 *);
	union {
		void *user;
		struct task_struct___207 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___34 {
	struct ctl_table_header___37 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___34 {
	struct mutex___208 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___34 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___37 *ctl;
};

struct netns_ipv4___34 {
	struct ctl_table_header___37 *forw_hdr;
	struct ctl_table_header___37 *frags_hdr;
	struct ctl_table_header___37 *ipv4_hdr;
	struct ctl_table_header___37 *route_hdr;
	struct ctl_table_header___37 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___19 *fibnl;
	struct sock___19 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___34 {
	struct ctl_table_header___37 *hdr;
	struct ctl_table_header___37 *route_hdr;
	struct ctl_table_header___37 *icmp_hdr;
	struct ctl_table_header___37 *frags_hdr;
	struct ctl_table_header___37 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___25;

struct neighbour___18;

struct dst_ops___35 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___35 *);
	struct dst_entry___18 * (*check)(struct dst_entry___18 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___18 *);
	unsigned int (*mtu)(const struct dst_entry___18 *);
	u32 * (*cow_metrics)(struct dst_entry___18 *, long unsigned int);
	void (*destroy)(struct dst_entry___18 *);
	void (*ifdown)(struct dst_entry___18 *, struct net_device___25 *, int);
	struct dst_entry___18 * (*negative_advice)(struct dst_entry___18 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___26 *, u32);
	void (*redirect)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___26 *);
	int (*local_out)(struct sk_buff___26 *);
	struct neighbour___18 * (*neigh_lookup)(const struct dst_entry___18 *, struct sk_buff___26 *, const void *);
	struct kmem_cache___191 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___35 {
	struct netns_sysctl_ipv6___34 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___35 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___19 **icmp_sk;
	struct sock___19 *ndisc_sk;
	struct sock___19 *tcp_sk;
	struct sock___19 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___34 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___37 *sysctl_header;
	struct sock___19 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___18 {
	struct sock___19 *v4_ctl_sk;
	struct sock___19 *v6_ctl_sk;
};

struct netns_nf___34 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___37 *nf_log_dir_header;
};

struct nf_proto_net___34 {
	struct ctl_table_header___37 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___34 {
	struct nf_proto_net___34 pn;
	unsigned int timeout;
};

struct nf_tcp_net___34 {
	struct nf_proto_net___34 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___34 {
	struct nf_proto_net___34 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___34 {
	struct nf_proto_net___34 pn;
	unsigned int timeout;
};

struct nf_ip_net___34 {
	struct nf_generic_net___34 generic;
	struct nf_tcp_net___34 tcp;
	struct nf_udp_net___34 udp;
	struct nf_icmp_net___34 icmp;
	struct nf_icmp_net___34 icmpv6;
};

struct netns_ct___34 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___37 *sysctl_header;
	struct ctl_table_header___37 *acct_sysctl_header;
	struct ctl_table_header___37 *tstamp_sysctl_header;
	struct ctl_table_header___37 *event_sysctl_header;
	struct ctl_table_header___37 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___191 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___34 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___34 {
	struct netns_sysctl_ipv6___34 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___35 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___19 *nlsk;
	struct sock___19 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___37 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___35 xfrm4_dst_ops;
	struct dst_ops___35 xfrm6_dst_ops;
};

struct net___36 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___37 sysctls;
	struct sock___19 *rtnl;
	struct sock___19 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___25 *loopback_dev;
	struct netns_core___34 core;
	struct netns_mib mib;
	struct netns_packet___34 packet;
	struct netns_unix___34 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___34 ipv4;
	struct netns_ipv6___35 ipv6;
	struct netns_sctp___34 sctp;
	struct netns_dccp___18 dccp;
	struct netns_nf___34 nf;
	struct netns_xt xt;
	struct netns_ct___34 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___34 nf_frag;
	struct sock___19 *nfnl;
	struct sock___19 *nfnl_stash;
	struct sk_buff_head___24 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___35 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___19 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___19 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___208 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___208 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___76 {
	void * (*alloc)(struct device___185 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___185 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___185 *, struct vm_area_struct___214 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___185 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___185 *, struct page___205 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___185 *, dma_addr_t);
	int (*dma_supported)(struct device___185 *, u64);
	int (*set_dma_mask)(struct device___185 *, u64);
	int is_phys;
};

struct bus_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___185 *, char *);
	ssize_t (*store)(struct bus_type___185 *, const char *, size_t);
};

struct device_attribute___185;

struct driver_attribute___185;

struct bus_type___185 {
	const char *name;
	const char *dev_name;
	struct device___185 *dev_root;
	struct bus_attribute___185 *bus_attrs;
	struct device_attribute___185 *dev_attrs;
	struct driver_attribute___185 *drv_attrs;
	const struct attribute_group___164 **bus_groups;
	const struct attribute_group___164 **dev_groups;
	const struct attribute_group___164 **drv_groups;
	int (*match)(struct device___185 *, struct device_driver___185 *);
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	int (*probe)(struct device___185 *);
	int (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*online)(struct device___185 *);
	int (*offline)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct device___185 *, struct device_attribute___185 *, char *);
	ssize_t (*store)(struct device___185 *, struct device_attribute___185 *, const char *, size_t);
};

struct driver_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___185 *, char *);
	ssize_t (*store)(struct device_driver___185 *, const char *, size_t);
};

struct device_driver___185 {
	const char *name;
	struct bus_type___185 *bus;
	struct module___119 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___185 *);
	int (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	const struct attribute_group___164 **groups;
	const struct dev_pm_ops___185 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___185 {
	const char *name;
	const struct attribute_group___164 **groups;
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
};

struct class_attribute___185;

struct class___185 {
	const char *name;
	struct module___119 *owner;
	struct class_attribute___185 *class_attrs;
	struct device_attribute___185 *dev_attrs;
	const struct attribute_group___164 **dev_groups;
	struct bin_attribute___166 *dev_bin_attrs;
	struct kobject___21 *dev_kobj;
	int (*dev_uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *);
	void (*class_release)(struct class___185 *);
	void (*dev_release)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	const struct kobj_ns_type_operations___18 *ns_type;
	const void * (*namespace)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
	struct subsys_private *p;
};

struct class_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct class___185 *, struct class_attribute___185 *, char *);
	ssize_t (*store)(struct class___185 *, struct class_attribute___185 *, const char *, size_t);
	const void * (*namespace)(struct class___185 *, const struct class_attribute___185 *);
};

struct device_rh___185 {
	struct dev_pm_info_rh___185 power;
};

struct vm_fault___182 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___205 *page;
};

struct signal_struct___207 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___207 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___207 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___88 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___88 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___208 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___123;

struct css_set___123 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___123 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___23 {
	atomic_t use;
	unsigned int mask;
	struct net_device___25 *physindev;
	struct net_device___25 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___23(struct sk_buff___26 **);

struct net_device_ops___23;

struct ethtool_ops___23;

struct header_ops___23;

struct netdev_rx_queue___23;

struct netdev_queue___23;

struct rtnl_link_ops___18;

struct dcbnl_rtnl_ops___23;

struct net_device___25 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___23 *netdev_ops;
	const struct ethtool_ops___23 *ethtool_ops;
	const struct header_ops___23 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___21 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___23 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___23 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___23 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___23 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___23 = 0,
		NETREG_REGISTERED___23 = 1,
		NETREG_UNREGISTERING___23 = 2,
		NETREG_UNREGISTERED___23 = 3,
		NETREG_RELEASED___23 = 4,
		NETREG_DUMMY___23 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___23 = 0,
		RTNL_LINK_INITIALIZING___23 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___25 *);
	struct netpoll_info *npinfo;
	struct net___36 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___185 dev;
	const struct attribute_group___164 *sysfs_groups[4];
	const struct rtnl_link_ops___18 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___23 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___26 {
	struct sk_buff___26 *next;
	struct sk_buff___26 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___19 *sk;
	struct net_device___25 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___26 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___23 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xattr_handler___124 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___206 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___206 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___206 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___206;

struct super_block___206;

struct dentry___206 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___206 *d_parent;
	struct qstr d_name;
	struct inode___206 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___206 *d_op;
	struct super_block___206 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___206;

struct file_lock___206;

struct dquot___206;

struct block_device___206;

struct inode___206 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___206 *i_op;
	struct super_block___206 *i_sb;
	struct address_space___206 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___208 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___206 *i_fop;
	struct file_lock___206 *i_flock;
	struct address_space___206 i_data;
	struct dquot___206 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___206 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___206 {
	int (*d_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_hash)(const struct dentry___206 *, struct qstr *);
	int (*d_compare)(const struct dentry___206 *, const struct dentry___206 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___206 *);
	void (*d_release)(struct dentry___206 *);
	void (*d_prune)(struct dentry___206 *);
	void (*d_iput)(struct dentry___206 *, struct inode___206 *);
	char * (*d_dname)(struct dentry___206 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___206 *);
	int (*d_manage)(struct dentry___206 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___206;

struct mem_dqinfo___206 {
	struct quota_format_type___206 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___206;

struct quota_info___206 {
	unsigned int flags;
	struct mutex___208 dqio_mutex;
	struct mutex___208 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___206 *files[2];
	struct mem_dqinfo___206 info[2];
	const struct quota_format_ops___206 *ops[2];
};

struct file_system_type___206;

struct super_operations___206;

struct dquot_operations___206;

struct quotactl_ops___206;

struct super_block___206 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___206 *s_type;
	const struct super_operations___206 *s_op;
	const struct dquot_operations___206 *dq_op;
	const struct quotactl_ops___206 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___206 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___124 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___206 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___206 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___208 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___206 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___206 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___206 *bd_inode;
	struct super_block___206 *bd_super;
	struct mutex___208 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___206 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___208 bd_fsfreeze_mutex;
};

struct cgroup___123;

struct cgroup_subsys_state___123 {
	struct cgroup___123 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___206 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___206 *ia_file;
};

struct dquot___206 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___208 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___206 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___206 {
	int qf_fmt_id;
	const struct quota_format_ops___206 *qf_ops;
	struct module___119 *qf_owner;
	struct quota_format_type___206 *qf_next;
};

struct quota_format_ops___206 {
	int (*check_quota_file)(struct super_block___206 *, int);
	int (*read_file_info)(struct super_block___206 *, int);
	int (*write_file_info)(struct super_block___206 *, int);
	int (*free_file_info)(struct super_block___206 *, int);
	int (*read_dqblk)(struct dquot___206 *);
	int (*commit_dqblk)(struct dquot___206 *);
	int (*release_dqblk)(struct dquot___206 *);
};

struct dquot_operations___206 {
	int (*write_dquot)(struct dquot___206 *);
	struct dquot___206 * (*alloc_dquot)(struct super_block___206 *, int);
	void (*destroy_dquot)(struct dquot___206 *);
	int (*acquire_dquot)(struct dquot___206 *);
	int (*release_dquot)(struct dquot___206 *);
	int (*mark_dirty)(struct dquot___206 *);
	int (*write_info)(struct super_block___206 *, int);
	qsize_t * (*get_reserved_space)(struct inode___206 *);
};

struct quotactl_ops___206 {
	int (*quota_on)(struct super_block___206 *, int, int, struct path___206 *);
	int (*quota_on_meta)(struct super_block___206 *, int, int);
	int (*quota_off)(struct super_block___206 *, int);
	int (*quota_sync)(struct super_block___206 *, int);
	int (*get_info)(struct super_block___206 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___206 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___206 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___206 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___206 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___206 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___206 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___206 *, unsigned int);
};

struct swap_info_struct___44;

struct address_space_operations___206 {
	int (*writepage)(struct page___205 *, struct writeback_control *);
	int (*readpage)(struct file___206 *, struct page___205 *);
	int (*writepages)(struct address_space___206 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___205 *);
	int (*readpages)(struct file___206 *, struct address_space___206 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___206 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___205 **, void **);
	int (*write_end)(struct file___206 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___205 *, void *);
	sector_t (*bmap)(struct address_space___206 *, sector_t);
	void (*invalidatepage)(struct page___205 *, long unsigned int);
	int (*releasepage)(struct page___205 *, gfp_t);
	void (*freepage)(struct page___205 *);
	ssize_t (*direct_IO)(int, struct kiocb___26 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___206 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___206 *, struct page___205 *, struct page___205 *, enum migrate_mode);
	int (*launder_page)(struct page___205 *);
	int (*is_partially_uptodate)(struct page___205 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___205 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___206 *, struct page___205 *);
	int (*swap_activate)(struct swap_info_struct___44 *, struct file___206 *, sector_t *);
	void (*swap_deactivate)(struct file___206 *);
	void (*invalidatepage_range)(struct page___205 *, unsigned int, unsigned int);
};

struct swap_info_struct___44 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___206 *bdev;
	struct file___206 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___206 {
	struct dentry___206 * (*lookup)(struct inode___206 *, struct dentry___206 *, unsigned int);
	void * (*follow_link)(struct dentry___206 *, struct nameidata *);
	int (*permission)(struct inode___206 *, int);
	struct posix_acl * (*get_acl)(struct inode___206 *, int);
	int (*readlink)(struct dentry___206 *, char *, int);
	void (*put_link)(struct dentry___206 *, struct nameidata *, void *);
	int (*create)(struct inode___206 *, struct dentry___206 *, umode_t, bool);
	int (*link)(struct dentry___206 *, struct inode___206 *, struct dentry___206 *);
	int (*unlink)(struct inode___206 *, struct dentry___206 *);
	int (*symlink)(struct inode___206 *, struct dentry___206 *, const char *);
	int (*mkdir)(struct inode___206 *, struct dentry___206 *, umode_t);
	int (*rmdir)(struct inode___206 *, struct dentry___206 *);
	int (*mknod)(struct inode___206 *, struct dentry___206 *, umode_t, dev_t);
	int (*rename)(struct inode___206 *, struct dentry___206 *, struct inode___206 *, struct dentry___206 *);
	int (*setattr)(struct dentry___206 *, struct iattr___206 *);
	int (*getattr)(struct vfsmount *, struct dentry___206 *, struct kstat *);
	int (*setxattr)(struct dentry___206 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___206 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___206 *, char *, size_t);
	int (*removexattr)(struct dentry___206 *, const char *);
	int (*fiemap)(struct inode___206 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___206 *, struct timespec *, int);
	int (*atomic_open)(struct inode___206 *, struct dentry___206 *, struct file___206 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___138;

struct file_operations___206 {
	struct module___119 *owner;
	loff_t (*llseek)(struct file___206 *, loff_t, int);
	ssize_t (*read)(struct file___206 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___206 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___26 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___26 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___206 *, void *, filldir_t);
	unsigned int (*poll)(struct file___206 *, struct poll_table_struct___114 *);
	long int (*unlocked_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___206 *, struct vm_area_struct___214 *);
	int (*open)(struct inode___206 *, struct file___206 *);
	int (*flush)(struct file___206 *, fl_owner_t);
	int (*release)(struct inode___206 *, struct file___206 *);
	int (*fsync)(struct file___206 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___26 *, int);
	int (*fasync)(int, struct file___206 *, int);
	int (*lock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*sendpage)(struct file___206 *, struct page___205 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___206 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___206 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___206 *, long int, struct file_lock___206 **, void **);
		struct {
			int (*setlease)(struct file___206 *, long int, struct file_lock___206 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___206 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___138 *, struct file___206 *);
};

struct file_lock_operations___206;

struct lock_manager_operations___206;

struct file_lock___206 {
	struct file_lock___206 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___88 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___206 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___206 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___206 *fl_ops;
	const struct lock_manager_operations___206 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___206 {
	void (*fl_copy_lock)(struct file_lock___206 *, struct file_lock___206 *);
	void (*fl_release_private)(struct file_lock___206 *);
};

struct lock_manager_operations___206 {
	int (*lm_compare_owner)(struct file_lock___206 *, struct file_lock___206 *);
	long unsigned int (*lm_owner_key)(struct file_lock___206 *);
	void (*lm_notify)(struct file_lock___206 *);
	int (*lm_grant)(struct file_lock___206 *, struct file_lock___206 *, int);
	void (*lm_break)(struct file_lock___206 *);
	int (*lm_change)(struct file_lock___206 **, int);
};

struct file_system_type___206 {
	const char *name;
	int fs_flags;
	struct dentry___206 * (*mount)(struct file_system_type___206 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___206 *);
	struct module___119 *owner;
	struct file_system_type___206 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___206 {
	struct inode___206 * (*alloc_inode)(struct super_block___206 *);
	void (*destroy_inode)(struct inode___206 *);
	void (*dirty_inode)(struct inode___206 *, int);
	int (*write_inode)(struct inode___206 *, struct writeback_control *);
	int (*drop_inode)(struct inode___206 *);
	void (*evict_inode)(struct inode___206 *);
	void (*put_super)(struct super_block___206 *);
	int (*sync_fs)(struct super_block___206 *, int);
	int (*freeze_fs)(struct super_block___206 *);
	int (*unfreeze_fs)(struct super_block___206 *);
	int (*statfs)(struct dentry___206 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___206 *, int *, char *);
	void (*umount_begin)(struct super_block___206 *);
	int (*show_options)(struct seq_file___138 *, struct dentry___206 *);
	int (*show_devname)(struct seq_file___138 *, struct dentry___206 *);
	int (*show_path)(struct seq_file___138 *, struct dentry___206 *);
	int (*show_stats)(struct seq_file___138 *, struct dentry___206 *);
	ssize_t (*quota_read)(struct super_block___206 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___206 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___206 *);
	int (*bdev_try_to_free_page)(struct super_block___206 *, struct page___205 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___206 *);
	void (*free_cached_objects)(struct super_block___206 *, int);
};

struct seq_operations___138;

struct seq_file___138 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___208 lock;
	const struct seq_operations___138 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___123;

struct cgroup___123 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___123 *parent;
	struct dentry___206 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___123 *subsys[11];
	struct cgroupfs_root___123 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___208 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___123 {
	struct super_block___206 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___123 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___68 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___206 *, struct file___206 *);
	ssize_t (*read)(struct cgroup___123 *, struct cftype___68 *, struct file___206 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___123 *, struct cftype___68 *);
	s64 (*read_s64)(struct cgroup___123 *, struct cftype___68 *);
	int (*read_map)(struct cgroup___123 *, struct cftype___68 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___123 *, struct cftype___68 *, struct seq_file___138 *);
	ssize_t (*write)(struct cgroup___123 *, struct cftype___68 *, struct file___206 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___123 *, struct cftype___68 *, u64);
	int (*write_s64)(struct cgroup___123 *, struct cftype___68 *, s64);
	int (*write_string)(struct cgroup___123 *, struct cftype___68 *, const char *);
	int (*trigger)(struct cgroup___123 *, unsigned int);
	int (*release)(struct inode___206 *, struct file___206 *);
	int (*register_event)(struct cgroup___123 *, struct cftype___68 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___123 *, struct cftype___68 *, struct eventfd_ctx *);
};

struct cftype_set___64 {
	struct list_head node;
	struct cftype___68 *cfts;
};

struct task_and_cgroup___64 {
	struct task_struct___207 *task;
	struct cgroup___123 *cgrp;
	struct css_set___123 *cg;
};

struct cgroup_taskset___64 {
	struct task_and_cgroup___64 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___123 *cur_cgrp;
};

struct cgroup_subsys___64 {
	struct cgroup_subsys_state___123 * (*css_alloc)(struct cgroup___123 *);
	int (*css_online)(struct cgroup___123 *);
	void (*css_offline)(struct cgroup___123 *);
	void (*css_free)(struct cgroup___123 *);
	int (*can_attach)(struct cgroup___123 *, struct cgroup_taskset___64 *);
	void (*cancel_attach)(struct cgroup___123 *, struct cgroup_taskset___64 *);
	void (*attach)(struct cgroup___123 *, struct cgroup_taskset___64 *);
	void (*fork)(struct task_struct___207 *);
	void (*exit)(struct cgroup___123 *, struct cgroup___123 *, struct task_struct___207 *);
	void (*bind)(struct cgroup___123 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___123 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___68 *base_cftypes;
	struct cftype_set___64 base_cftset;
	struct module___119 *module;
};

struct irq_chip___134 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___134 *);
	void (*irq_shutdown)(struct irq_data___134 *);
	void (*irq_enable)(struct irq_data___134 *);
	void (*irq_disable)(struct irq_data___134 *);
	void (*irq_ack)(struct irq_data___134 *);
	void (*irq_mask)(struct irq_data___134 *);
	void (*irq_mask_ack)(struct irq_data___134 *);
	void (*irq_unmask)(struct irq_data___134 *);
	void (*irq_eoi)(struct irq_data___134 *);
	int (*irq_set_affinity)(struct irq_data___134 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___134 *);
	int (*irq_set_type)(struct irq_data___134 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___134 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___134 *);
	void (*irq_bus_sync_unlock)(struct irq_data___134 *);
	void (*irq_cpu_online)(struct irq_data___134 *);
	void (*irq_cpu_offline)(struct irq_data___134 *);
	void (*irq_suspend)(struct irq_data___134 *);
	void (*irq_resume)(struct irq_data___134 *);
	void (*irq_pm_shutdown)(struct irq_data___134 *);
	void (*irq_print_chip)(struct irq_data___134 *, struct seq_file___138 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___134 *, void *);
	long unsigned int flags;
};

struct dev_pm_qos_request___28 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___185 *dev;
};

struct ethtool_ops___23 {
	int (*get_settings)(struct net_device___25 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___25 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___25 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___25 *);
	void (*get_regs)(struct net_device___25 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___25 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___25 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___25 *);
	void (*set_msglevel)(struct net_device___25 *, u32);
	int (*nway_reset)(struct net_device___25 *);
	u32 (*get_link)(struct net_device___25 *);
	int (*get_eeprom_len)(struct net_device___25 *);
	int (*get_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___25 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___25 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___25 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___25 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___25 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___25 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___25 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___25 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___25 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___25 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___25 *);
	void (*complete)(struct net_device___25 *);
	u32 (*get_priv_flags)(struct net_device___25 *);
	int (*set_priv_flags)(struct net_device___25 *, u32);
	int (*get_sset_count)(struct net_device___25 *, int);
	int (*get_rxnfc)(struct net_device___25 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___25 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___25 *, struct ethtool_flash *);
	int (*reset)(struct net_device___25 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___25 *);
	int (*get_rxfh_indir)(struct net_device___25 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___25 *, const u32 *);
	void (*get_channels)(struct net_device___25 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___25 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___25 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___25 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___25 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___25 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___25 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___25 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___25 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___25 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___25 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___25 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___18 {
	struct callback_head callback_head;
	struct dst_entry___18 *child;
	struct net_device___25 *dev;
	struct dst_ops___35 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___18 *path;
	struct dst_entry___18 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___26 *);
	union {
		int (*output)(struct sock___19 *, struct sk_buff___26 *);
		struct {
			int (*output)(struct sk_buff___26 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___18 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___18;

struct neigh_parms___18;

struct neigh_ops___18;

struct neighbour___18 {
	struct neighbour___18 *next;
	struct neigh_table___18 *tbl;
	struct neigh_parms___18 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___24 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___18 *, struct sk_buff___26 *);
	const struct neigh_ops___18 *ops;
	struct callback_head rcu;
	struct net_device___25 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___35 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___26 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___26 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___36 *, struct dst_entry___18 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___26 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___26 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___138 {
	void * (*start)(struct seq_file___138 *, loff_t *);
	void (*stop)(struct seq_file___138 *, void *);
	void * (*next)(struct seq_file___138 *, void *, loff_t *);
	int (*show)(struct seq_file___138 *, void *);
};

struct dcbnl_rtnl_ops___23 {
	int (*ieee_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___25 *);
	u8 (*setstate)(struct net_device___25 *, u8);
	void (*getpermhwaddr)(struct net_device___25 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___25 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___25 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___25 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___25 *, int, u8 *);
	void (*setpfccfg)(struct net_device___25 *, int, u8);
	void (*getpfccfg)(struct net_device___25 *, int, u8 *);
	u8 (*setall)(struct net_device___25 *);
	u8 (*getcap)(struct net_device___25 *, int, u8 *);
	int (*getnumtcs)(struct net_device___25 *, int, u8 *);
	int (*setnumtcs)(struct net_device___25 *, int, u8);
	u8 (*getpfcstate)(struct net_device___25 *);
	void (*setpfcstate)(struct net_device___25 *, u8);
	void (*getbcncfg)(struct net_device___25 *, int, u32 *);
	void (*setbcncfg)(struct net_device___25 *, int, u32);
	void (*getbcnrp)(struct net_device___25 *, int, u8 *);
	void (*setbcnrp)(struct net_device___25 *, int, u8);
	u8 (*setapp)(struct net_device___25 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___25 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___25 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___25 *, int, u8);
	u8 (*getdcbx)(struct net_device___25 *);
	u8 (*setdcbx)(struct net_device___25 *, u8);
	int (*peer_getappinfo)(struct net_device___25 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___25 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___25 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___25 *, struct cee_pfc *);
};

struct netlink_skb_parms___3 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___19 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___24 {
	struct sk_buff___26 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___26 *, struct netlink_callback___24 *);
	int (*done)(struct netlink_callback___24 *);
	void *data;
	struct module___119 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___23 {
	int (*create)(struct sk_buff___26 *, struct net_device___25 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___26 *, unsigned char *);
	int (*rebuild)(struct sk_buff___26 *);
	int (*cache)(const struct neighbour___18 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___25 *, const unsigned char *);
};

struct napi_struct___23 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___23 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___25 *dev;
	struct sk_buff___26 *gro_list;
	struct sk_buff___26 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___23 {
	struct net_device___25 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___21 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___23 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___21 kobj;
	struct net_device___25 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___23 {
	int (*ndo_init)(struct net_device___25 *);
	void (*ndo_uninit)(struct net_device___25 *);
	int (*ndo_open)(struct net_device___25 *);
	int (*ndo_stop)(struct net_device___25 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___26 *, struct net_device___25 *);
	u16 (*ndo_select_queue)(struct net_device___25 *, struct sk_buff___26 *);
	void (*ndo_change_rx_flags)(struct net_device___25 *, int);
	void (*ndo_set_rx_mode)(struct net_device___25 *);
	int (*ndo_set_mac_address)(struct net_device___25 *, void *);
	int (*ndo_validate_addr)(struct net_device___25 *);
	int (*ndo_do_ioctl)(struct net_device___25 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___25 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___25 *, int);
	int (*ndo_neigh_setup)(struct net_device___25 *, struct neigh_parms___18 *);
	void (*ndo_tx_timeout)(struct net_device___25 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___25 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___25 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___25 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___25 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___25 *);
	int (*ndo_netpoll_setup)(struct net_device___25 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___25 *);
	int (*ndo_busy_poll)(struct napi_struct___23 *);
	int (*ndo_set_vf_mac)(struct net_device___25 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___25 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___25 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___25 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___25 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___25 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___25 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___25 *, int, struct sk_buff___26 *);
	int (*ndo_setup_tc)(struct net_device___25 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___25 *);
	int (*ndo_fcoe_disable)(struct net_device___25 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___25 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___25 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___25 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___25 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___25 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___25 *, const struct sk_buff___26 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___25 *, struct net_device___25 *);
	int (*ndo_del_slave)(struct net_device___25 *, struct net_device___25 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___18 *);
	void (*ndo_neigh_destroy)(struct neighbour___18 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___26 *, struct netlink_callback___24 *, struct net_device___25 *, int);
	int (*ndo_bridge_setlink)(struct net_device___25 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___26 *, u32, u32, struct net_device___25 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___25 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___25 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___25 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___25 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___25 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___25 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___26 *, struct net_device___25 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___25 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___25 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___25 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___18 {
	struct net___36 *net;
	struct net_device___25 *dev;
	struct neigh_parms___18 *next;
	int (*neigh_setup)(struct neighbour___18 *);
	void (*neigh_cleanup)(struct neighbour___18 *);
	struct neigh_table___18 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___18 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___25 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___36 *, struct net_device___25 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___25 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___25 *, struct list_head *);
	size_t (*get_size)(const struct net_device___25 *);
	int (*fill_info)(struct sk_buff___26 *, const struct net_device___25 *);
	size_t (*get_xstats_size)(const struct net_device___25 *);
	int (*fill_xstats)(struct sk_buff___26 *, const struct net_device___25 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___36 * (*get_link_net)(const struct net_device___25 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___25 *, struct net_device___25 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___25 *, const struct net_device___25 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___26 *, const struct net_device___25 *, const struct net_device___25 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___19 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___26 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___18;

struct neigh_hash_table___18;

struct neigh_table___18 {
	struct neigh_table___18 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___25 *, __u32 *);
	int (*constructor)(struct neighbour___18 *);
	int (*pconstructor)(struct pneigh_entry___18 *);
	void (*pdestructor)(struct pneigh_entry___18 *);
	void (*proxy_redo)(struct sk_buff___26 *);
	char *id;
	struct neigh_parms___18 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___24 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___18 *nht;
	struct pneigh_entry___18 **phash_buckets;
};

struct neigh_ops___18 {
	int family;
	void (*solicit)(struct neighbour___18 *, struct sk_buff___26 *);
	void (*error_report)(struct neighbour___18 *, struct sk_buff___26 *);
	int (*output)(struct neighbour___18 *, struct sk_buff___26 *);
	int (*connected_output)(struct neighbour___18 *, struct sk_buff___26 *);
};

struct pneigh_entry___18 {
	struct pneigh_entry___18 *next;
	struct net___36 *net;
	struct net_device___25 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___18 {
	struct neighbour___18 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___18 {
	void (*close)(struct sock___19 *, long int);
	int (*connect)(struct sock___19 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___19 *, int);
	struct sock___19 * (*accept)(struct sock___19 *, int, int *);
	int (*ioctl)(struct sock___19 *, int, long unsigned int);
	int (*init)(struct sock___19 *);
	void (*destroy)(struct sock___19 *);
	void (*shutdown)(struct sock___19 *, int);
	int (*setsockopt)(struct sock___19 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___19 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___19 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___19 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___19 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___26 *, struct sock___19 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___26 *, struct sock___19 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___19 *, struct page___205 *, int, size_t, int);
	int (*bind)(struct sock___19 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___19 *, struct sk_buff___26 *);
	void (*release_cb)(struct sock___19 *);
	void (*mtu_reduced)(struct sock___19 *);
	void (*hash)(struct sock___19 *);
	void (*unhash)(struct sock___19 *);
	void (*rehash)(struct sock___19 *);
	int (*get_port)(struct sock___19 *, short unsigned int);
	void (*clear_sk)(struct sock___19 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___19 *);
	void (*enter_memory_pressure)(struct sock___19 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___191 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___119 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___64 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___18 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___18 {
	void (*enter_memory_pressure)(struct sock___19 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct cb_id {
	__u32 idx;
	__u32 val;
};

struct cn_msg {
	struct cb_id id;
	__u32 seq;
	__u32 ack;
	__u16 len;
	__u16 flags;
	__u8 data[0];
};

struct cn_queue_dev {
	atomic_t refcnt;
	unsigned char name[32];
	struct list_head queue_list;
	spinlock_t queue_lock;
	struct sock___19 *nls;
};

struct cn_callback_id {
	unsigned char name[32];
	struct cb_id id;
};

struct cn_callback_entry {
	struct list_head callback_entry;
	atomic_t refcnt;
	struct cn_queue_dev *pdev;
	struct cn_callback_id id;
	void (*callback)(struct cn_msg *, struct netlink_skb_parms___3 *);
	u32 seq;
	u32 group;
};

struct netlink_kernel_cfg___4 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___26 *);
	struct mutex___208 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___36 *, struct sock___19 *);
};

struct cn_dev {
	struct cb_id id;
	u32 seq;
	u32 groups;
	struct sock___19 *nls;
	void (*input)(struct sk_buff___26 *);
	struct cn_queue_dev *cbdev;
};

struct page___206;

typedef struct page___206 *pgtable_t___206;

struct address_space___207;

struct kmem_cache___192;

struct page___206 {
	long unsigned int flags;
	struct address_space___207 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___206 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___206 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___192 *slab_cache;
		struct page___206 *first_page;
	};
	long: 64;
};

struct task_struct___208;

struct pv_cpu_ops___208 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___79 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___79 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___208 *);
	void (*end_context_switch)(struct task_struct___208 *);
};

struct pid___89;

struct pid_link___89 {
	struct hlist_node node;
	struct pid___89 *pid;
};

struct mutex___209 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___208 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___201 {
	struct page___206 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___215;

struct nsproxy___109;

struct signal_struct___208;

struct css_set___124;

struct task_struct___208 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___208 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___215 *mm;
	struct mm_struct___215 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___208 *real_parent;
	struct task_struct___208 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___208 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___89 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___208 = 0,
		VTIME_USER___208 = 1,
		VTIME_SYS___208 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___79 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___109 *nsproxy;
	struct signal_struct___208 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___124 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___209 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___201 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___215 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___215 *, struct mm_struct___215 *);
	void (*dup_mmap)(struct mm_struct___215 *, struct mm_struct___215 *);
	void (*exit_mmap)(struct mm_struct___215 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___215 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___215 *);
	void (*pgd_free)(struct mm_struct___215 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___215 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___215 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___215 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___215 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___215 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___215 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___215 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___215 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___215 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___215 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___215 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___209 lock;
	void *vdso;
} mm_context_t___209;

struct xol_area___206;

struct uprobes_state___206 {
	struct xol_area___206 *xol_area;
};

struct vm_area_struct___215;

struct file___207;

struct core_state___208;

struct mm_struct___215 {
	struct vm_area_struct___215 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___215 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___215 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___209 context;
	long unsigned int flags;
	struct core_state___208 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___208 *owner;
	struct file___207 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___206 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___22;

struct kobj_type___22;

struct kobject___22 {
	const char *name;
	struct list_head entry;
	struct kobject___22 *parent;
	struct kset___22 *kset;
	struct kobj_type___22 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___120;

struct module_kobject___119 {
	struct kobject___22 kobj;
	struct module___120 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___119;

struct module___120 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___119 mkobj;
	struct module_attribute___119 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___208 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___208;

struct lruvec___208 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___208 *zone;
};

struct pglist_data___208;

struct zone___208 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___208 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___208 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___208 {
	struct zone___208 *zone;
	int zone_idx;
};

struct zonelist___208 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___208 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___208 {
	struct zone___208 node_zones[4];
	struct zonelist___208 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___208 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___135;

struct x86_io_apic_ops___135 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___135 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___135;

struct irq_data___135 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___135 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___186;

struct dev_pm_ops___186 {
	int (*prepare)(struct device___186 *);
	void (*complete)(struct device___186 *);
	int (*suspend)(struct device___186 *);
	int (*resume)(struct device___186 *);
	int (*freeze)(struct device___186 *);
	int (*thaw)(struct device___186 *);
	int (*poweroff)(struct device___186 *);
	int (*restore)(struct device___186 *);
	int (*suspend_late)(struct device___186 *);
	int (*resume_early)(struct device___186 *);
	int (*freeze_late)(struct device___186 *);
	int (*thaw_early)(struct device___186 *);
	int (*poweroff_late)(struct device___186 *);
	int (*restore_early)(struct device___186 *);
	int (*suspend_noirq)(struct device___186 *);
	int (*resume_noirq)(struct device___186 *);
	int (*freeze_noirq)(struct device___186 *);
	int (*thaw_noirq)(struct device___186 *);
	int (*poweroff_noirq)(struct device___186 *);
	int (*restore_noirq)(struct device___186 *);
	int (*runtime_suspend)(struct device___186 *);
	int (*runtime_resume)(struct device___186 *);
	int (*runtime_idle)(struct device___186 *);
};

struct dev_pm_qos___29;

struct dev_pm_info___29 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___29 *qos;
};

struct dma_map_ops___77;

struct dev_archdata___77 {
	struct dma_map_ops___77 *dma_ops;
	void *iommu;
};

struct device_type___186;

struct bus_type___186;

struct device_driver___186;

struct dev_pm_domain___186;

struct class___186;

struct attribute_group___165;

struct device_rh___186;

struct device___186 {
	struct device___186 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___186 *type;
	struct mutex___209 mutex;
	struct bus_type___186 *bus;
	struct device_driver___186 *driver;
	void *platform_data;
	struct dev_pm_info___29 power;
	struct dev_pm_domain___186 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___77 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___28 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___186 *class;
	const struct attribute_group___165 **groups;
	void (*release)(struct device___186 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___186 *device_rh;
};

struct dev_pm_qos_request___29;

struct dev_pm_qos___29 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___29 *latency_req;
	struct dev_pm_qos_request___29 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___29 *latency_tolerance_req;
};

struct dev_pm_info_rh___186 {
	void (*set_latency_tolerance)(struct device___186 *, s32);
};

struct dev_pm_domain___186 {
	struct dev_pm_ops___186 ops;
};

struct smp_ops___208 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___208 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___38;

struct ctl_node___38 {
	struct rb_node node;
	struct ctl_table_header___38 *header;
};

struct ctl_table_root___38;

struct ctl_table_set___38;

struct ctl_dir___38;

struct ctl_table_header___38 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___38 *root;
	struct ctl_table_set___38 *set;
	struct ctl_dir___38 *parent;
	struct ctl_node___38 *node;
};

struct ctl_dir___38 {
	struct ctl_table_header___38 header;
	struct rb_root root;
};

struct ctl_table_set___38 {
	int (*is_seen)(struct ctl_table_set___38 *);
	struct ctl_dir___38 dir;
};

struct ctl_table_root___38 {
	struct ctl_table_set___38 default_set;
	struct ctl_table_set___38 * (*lookup)(struct ctl_table_root___38 *, struct nsproxy___109 *);
	int (*permissions)(struct ctl_table_header___38 *, struct ctl_table *);
};

struct pid_namespace___89;

struct net___37;

struct nsproxy___109 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___89 *pid_ns;
	struct net___37 *net_ns;
};

struct sock___20;

struct kobj_ns_type_operations___19 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___20 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___19;

struct sock_common___19 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___19 *skc_prot;
	struct net___37 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___27;

struct sk_buff_head___25 {
	struct sk_buff___27 *next;
	struct sk_buff___27 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___20;

struct socket_wq___19;

struct dst_entry___19;

struct socket___20;

struct cg_proto___19;

struct sock___20 {
	struct sock_common___19 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___25 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___27 *head;
		struct sk_buff___27 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___20 *sk_filter;
	struct socket_wq___19 *sk_wq;
	struct sk_buff_head___25 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___19 *sk_rx_dst;
	struct dst_entry___19 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___25 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___25 sk_error_queue;
	struct proto___19 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___89 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___20 *sk_socket;
	void *sk_user_data;
	struct page_frag___201 sk_frag;
	struct sk_buff___27 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___19 *sk_cgrp;
	void (*sk_state_change)(struct sock___20 *);
	void (*sk_data_ready)(struct sock___20 *, int);
	void (*sk_write_space)(struct sock___20 *);
	void (*sk_error_report)(struct sock___20 *);
	int (*sk_backlog_rcv)(struct sock___20 *, struct sk_buff___27 *);
	void (*sk_destruct)(struct sock___20 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___167;

struct attribute_group___165 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___167 **bin_attrs;
};

struct bin_attribute___167 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___207 *, struct kobject___22 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___207 *, struct kobject___22 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	int (*mmap)(struct file___207 *, struct kobject___22 *, struct bin_attribute___167 *, struct vm_area_struct___215 *);
};

struct dentry___207;

struct path___207 {
	struct vfsmount *mnt;
	struct dentry___207 *dentry;
};

struct fown_struct___89 {
	rwlock_t lock;
	struct pid___89 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___207;

struct file_operations___207;

struct file___207 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___207 f_path;
	struct inode___207 *f_inode;
	const struct file_operations___207 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___89 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___207 *f_mapping;
	struct mutex___209 f_pos_lock;
};

struct vm_operations_struct___187;

struct vm_area_struct___215 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___215 *vm_next;
	struct vm_area_struct___215 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___215 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___187 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___207 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___22 {
	ssize_t (*show)(struct kobject___22 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___22 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___22 *, const struct attribute *);
};

struct kset_uevent_ops___22;

struct kset___22 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___22 kobj;
	const struct kset_uevent_ops___22 *uevent_ops;
};

struct kobj_type___22 {
	void (*release)(struct kobject___22 *);
	const struct sysfs_ops___22 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___19 * (*child_ns_type)(struct kobject___22 *);
	const void * (*namespace)(struct kobject___22 *);
};

struct kset_uevent_ops___22 {
	int (* const filter)(struct kset___22 *, struct kobject___22 *);
	const char * (* const name)(struct kset___22 *, struct kobject___22 *);
	int (* const uevent)(struct kset___22 *, struct kobject___22 *, struct kobj_uevent_env *);
};

struct module_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___119 *, struct module_kobject___119 *, char *);
	ssize_t (*store)(struct module_attribute___119 *, struct module_kobject___119 *, const char *, size_t);
	void (*setup)(struct module___120 *, const char *);
	int (*test)(struct module___120 *);
	void (*free)(struct module___120 *);
};

struct seq_file___139;

struct irq_chip___135 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___135 *);
	void (*irq_shutdown)(struct irq_data___135 *);
	void (*irq_enable)(struct irq_data___135 *);
	void (*irq_disable)(struct irq_data___135 *);
	void (*irq_ack)(struct irq_data___135 *);
	void (*irq_mask)(struct irq_data___135 *);
	void (*irq_mask_ack)(struct irq_data___135 *);
	void (*irq_unmask)(struct irq_data___135 *);
	void (*irq_eoi)(struct irq_data___135 *);
	int (*irq_set_affinity)(struct irq_data___135 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___135 *);
	int (*irq_set_type)(struct irq_data___135 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___135 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___135 *);
	void (*irq_bus_sync_unlock)(struct irq_data___135 *);
	void (*irq_cpu_online)(struct irq_data___135 *);
	void (*irq_cpu_offline)(struct irq_data___135 *);
	void (*irq_suspend)(struct irq_data___135 *);
	void (*irq_resume)(struct irq_data___135 *);
	void (*irq_pm_shutdown)(struct irq_data___135 *);
	void (*irq_print_chip)(struct irq_data___135 *, struct seq_file___139 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___135 *, void *);
	long unsigned int flags;
};

struct seq_operations___139;

struct seq_file___139 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___209 lock;
	const struct seq_operations___139 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kiocb___27;

struct poll_table_struct___115;

struct file_lock___207;

struct file_operations___207 {
	struct module___120 *owner;
	loff_t (*llseek)(struct file___207 *, loff_t, int);
	ssize_t (*read)(struct file___207 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___207 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___27 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___27 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___207 *, void *, filldir_t);
	unsigned int (*poll)(struct file___207 *, struct poll_table_struct___115 *);
	long int (*unlocked_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___207 *, struct vm_area_struct___215 *);
	int (*open)(struct inode___207 *, struct file___207 *);
	int (*flush)(struct file___207 *, fl_owner_t);
	int (*release)(struct inode___207 *, struct file___207 *);
	int (*fsync)(struct file___207 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___27 *, int);
	int (*fasync)(int, struct file___207 *, int);
	int (*lock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*sendpage)(struct file___207 *, struct page___206 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___207 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___207 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___207 *, long int, struct file_lock___207 **, void **);
		struct {
			int (*setlease)(struct file___207 *, long int, struct file_lock___207 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___207 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___139 *, struct file___207 *);
};

struct dma_map_ops___77 {
	void * (*alloc)(struct device___186 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___186 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___186 *, struct vm_area_struct___215 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___186 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___186 *, struct page___206 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___186 *, dma_addr_t);
	int (*dma_supported)(struct device___186 *, u64);
	int (*set_dma_mask)(struct device___186 *, u64);
	int is_phys;
};

struct bus_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___186 *, char *);
	ssize_t (*store)(struct bus_type___186 *, const char *, size_t);
};

struct device_attribute___186;

struct driver_attribute___186;

struct bus_type___186 {
	const char *name;
	const char *dev_name;
	struct device___186 *dev_root;
	struct bus_attribute___186 *bus_attrs;
	struct device_attribute___186 *dev_attrs;
	struct driver_attribute___186 *drv_attrs;
	const struct attribute_group___165 **bus_groups;
	const struct attribute_group___165 **dev_groups;
	const struct attribute_group___165 **drv_groups;
	int (*match)(struct device___186 *, struct device_driver___186 *);
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	int (*probe)(struct device___186 *);
	int (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*online)(struct device___186 *);
	int (*offline)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct device___186 *, struct device_attribute___186 *, char *);
	ssize_t (*store)(struct device___186 *, struct device_attribute___186 *, const char *, size_t);
};

struct driver_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___186 *, char *);
	ssize_t (*store)(struct device_driver___186 *, const char *, size_t);
};

struct device_driver___186 {
	const char *name;
	struct bus_type___186 *bus;
	struct module___120 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___186 *);
	int (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	const struct attribute_group___165 **groups;
	const struct dev_pm_ops___186 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___186 {
	const char *name;
	const struct attribute_group___165 **groups;
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
};

struct class_attribute___186;

struct class___186 {
	const char *name;
	struct module___120 *owner;
	struct class_attribute___186 *class_attrs;
	struct device_attribute___186 *dev_attrs;
	const struct attribute_group___165 **dev_groups;
	struct bin_attribute___167 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *);
	void (*class_release)(struct class___186 *);
	void (*dev_release)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
	struct subsys_private *p;
};

struct class_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct class___186 *, struct class_attribute___186 *, char *);
	ssize_t (*store)(struct class___186 *, struct class_attribute___186 *, const char *, size_t);
	const void * (*namespace)(struct class___186 *, const struct class_attribute___186 *);
};

struct device_rh___186 {
	struct dev_pm_info_rh___186 power;
};

struct dev_pm_qos_request___29 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___186 *dev;
};

struct xol_area___206 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___206 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___191;

struct memcg_cache_params___192;

struct kmem_cache___192 {
	struct kmem_cache_cpu___191 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___192 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___207;

struct address_space___207 {
	struct inode___207 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___209 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___207 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___183;

struct vm_operations_struct___187 {
	void (*open)(struct vm_area_struct___215 *);
	void (*close)(struct vm_area_struct___215 *);
	int (*fault)(struct vm_area_struct___215 *, struct vm_fault___183 *);
	int (*page_mkwrite)(struct vm_area_struct___215 *, struct vm_fault___183 *);
	int (*access)(struct vm_area_struct___215 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___215 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___215 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___215 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___215 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___208 {
	struct task_struct___208 *task;
	struct core_thread___208 *next;
};

struct core_state___208 {
	atomic_t nr_threads;
	struct core_thread___208 dumper;
	struct completion startup;
};

struct vm_fault___183 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___206 *page;
};

struct dentry_operations___207;

struct super_block___207;

struct dentry___207 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___207 *d_parent;
	struct qstr d_name;
	struct inode___207 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___207 *d_op;
	struct super_block___207 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___207;

struct dquot___207;

struct block_device___207;

struct inode___207 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___207 *i_op;
	struct super_block___207 *i_sb;
	struct address_space___207 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___209 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___207 *i_fop;
	struct file_lock___207 *i_flock;
	struct address_space___207 i_data;
	struct dquot___207 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___207 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___207 {
	int (*d_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_hash)(const struct dentry___207 *, struct qstr *);
	int (*d_compare)(const struct dentry___207 *, const struct dentry___207 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___207 *);
	void (*d_release)(struct dentry___207 *);
	void (*d_prune)(struct dentry___207 *);
	void (*d_iput)(struct dentry___207 *, struct inode___207 *);
	char * (*d_dname)(struct dentry___207 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___207 *);
	int (*d_manage)(struct dentry___207 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___207;

struct mem_dqinfo___207 {
	struct quota_format_type___207 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___207;

struct quota_info___207 {
	unsigned int flags;
	struct mutex___209 dqio_mutex;
	struct mutex___209 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___207 *files[2];
	struct mem_dqinfo___207 info[2];
	const struct quota_format_ops___207 *ops[2];
};

struct file_system_type___207;

struct super_operations___207;

struct dquot_operations___207;

struct quotactl_ops___207;

struct xattr_handler___125;

struct super_block___207 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___207 *s_type;
	const struct super_operations___207 *s_op;
	const struct dquot_operations___207 *dq_op;
	const struct quotactl_ops___207 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___207 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___125 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___207 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___207 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___209 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___207 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___89 {
	int nr;
	struct pid_namespace___89 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___89 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___208 *child_reaper;
	struct kmem_cache___192 *pid_cachep;
	unsigned int level;
	struct pid_namespace___89 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___207 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___89 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___89 numbers[1];
};

struct block_device___207 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___207 *bd_inode;
	struct super_block___207 *bd_super;
	struct mutex___209 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___207 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___209 bd_fsfreeze_mutex;
};

struct cgroup___124;

struct cgroup_subsys_state___124 {
	struct cgroup___124 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___27(struct kiocb___27 *, struct io_event *);

struct kiocb___27 {
	atomic_t ki_users;
	struct file___207 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___27 *ki_cancel;
	void (*ki_dtor)(struct kiocb___27 *);
	union {
		void *user;
		struct task_struct___208 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___207 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___207 *ia_file;
};

struct dquot___207 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___209 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___207 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___207 {
	int qf_fmt_id;
	const struct quota_format_ops___207 *qf_ops;
	struct module___120 *qf_owner;
	struct quota_format_type___207 *qf_next;
};

struct quota_format_ops___207 {
	int (*check_quota_file)(struct super_block___207 *, int);
	int (*read_file_info)(struct super_block___207 *, int);
	int (*write_file_info)(struct super_block___207 *, int);
	int (*free_file_info)(struct super_block___207 *, int);
	int (*read_dqblk)(struct dquot___207 *);
	int (*commit_dqblk)(struct dquot___207 *);
	int (*release_dqblk)(struct dquot___207 *);
};

struct dquot_operations___207 {
	int (*write_dquot)(struct dquot___207 *);
	struct dquot___207 * (*alloc_dquot)(struct super_block___207 *, int);
	void (*destroy_dquot)(struct dquot___207 *);
	int (*acquire_dquot)(struct dquot___207 *);
	int (*release_dquot)(struct dquot___207 *);
	int (*mark_dirty)(struct dquot___207 *);
	int (*write_info)(struct super_block___207 *, int);
	qsize_t * (*get_reserved_space)(struct inode___207 *);
};

struct quotactl_ops___207 {
	int (*quota_on)(struct super_block___207 *, int, int, struct path___207 *);
	int (*quota_on_meta)(struct super_block___207 *, int, int);
	int (*quota_off)(struct super_block___207 *, int);
	int (*quota_sync)(struct super_block___207 *, int);
	int (*get_info)(struct super_block___207 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___207 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___207 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___207 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___207 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___207 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___207 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___207 *, unsigned int);
};

struct address_space_operations___207 {
	int (*writepage)(struct page___206 *, struct writeback_control *);
	int (*readpage)(struct file___207 *, struct page___206 *);
	int (*writepages)(struct address_space___207 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___206 *);
	int (*readpages)(struct file___207 *, struct address_space___207 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___207 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___206 **, void **);
	int (*write_end)(struct file___207 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___206 *, void *);
	sector_t (*bmap)(struct address_space___207 *, sector_t);
	void (*invalidatepage)(struct page___206 *, long unsigned int);
	int (*releasepage)(struct page___206 *, gfp_t);
	void (*freepage)(struct page___206 *);
	ssize_t (*direct_IO)(int, struct kiocb___27 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___207 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___207 *, struct page___206 *, struct page___206 *, enum migrate_mode);
	int (*launder_page)(struct page___206 *);
	int (*is_partially_uptodate)(struct page___206 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___206 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___207 *, struct page___206 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___207 *, sector_t *);
	void (*swap_deactivate)(struct file___207 *);
	void (*invalidatepage_range)(struct page___206 *, unsigned int, unsigned int);
};

struct inode_operations___207 {
	struct dentry___207 * (*lookup)(struct inode___207 *, struct dentry___207 *, unsigned int);
	void * (*follow_link)(struct dentry___207 *, struct nameidata *);
	int (*permission)(struct inode___207 *, int);
	struct posix_acl * (*get_acl)(struct inode___207 *, int);
	int (*readlink)(struct dentry___207 *, char *, int);
	void (*put_link)(struct dentry___207 *, struct nameidata *, void *);
	int (*create)(struct inode___207 *, struct dentry___207 *, umode_t, bool);
	int (*link)(struct dentry___207 *, struct inode___207 *, struct dentry___207 *);
	int (*unlink)(struct inode___207 *, struct dentry___207 *);
	int (*symlink)(struct inode___207 *, struct dentry___207 *, const char *);
	int (*mkdir)(struct inode___207 *, struct dentry___207 *, umode_t);
	int (*rmdir)(struct inode___207 *, struct dentry___207 *);
	int (*mknod)(struct inode___207 *, struct dentry___207 *, umode_t, dev_t);
	int (*rename)(struct inode___207 *, struct dentry___207 *, struct inode___207 *, struct dentry___207 *);
	int (*setattr)(struct dentry___207 *, struct iattr___207 *);
	int (*getattr)(struct vfsmount *, struct dentry___207 *, struct kstat *);
	int (*setxattr)(struct dentry___207 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___207 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___207 *, char *, size_t);
	int (*removexattr)(struct dentry___207 *, const char *);
	int (*fiemap)(struct inode___207 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___207 *, struct timespec *, int);
	int (*atomic_open)(struct inode___207 *, struct dentry___207 *, struct file___207 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___207;

struct file_lock_operations___207;

struct lock_manager_operations___207;

struct file_lock___207 {
	struct file_lock___207 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___89 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___207 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___207 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___207 *fl_ops;
	const struct lock_manager_operations___207 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___207 {
	void (*fl_copy_lock)(struct file_lock___207 *, struct file_lock___207 *);
	void (*fl_release_private)(struct file_lock___207 *);
};

struct lock_manager_operations___207 {
	int (*lm_compare_owner)(struct file_lock___207 *, struct file_lock___207 *);
	long unsigned int (*lm_owner_key)(struct file_lock___207 *);
	void (*lm_notify)(struct file_lock___207 *);
	int (*lm_grant)(struct file_lock___207 *, struct file_lock___207 *, int);
	void (*lm_break)(struct file_lock___207 *);
	int (*lm_change)(struct file_lock___207 **, int);
};

struct fasync_struct___207 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___207 *fa_next;
	struct file___207 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___207 {
	const char *name;
	int fs_flags;
	struct dentry___207 * (*mount)(struct file_system_type___207 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___207 *);
	struct module___120 *owner;
	struct file_system_type___207 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___207 {
	struct inode___207 * (*alloc_inode)(struct super_block___207 *);
	void (*destroy_inode)(struct inode___207 *);
	void (*dirty_inode)(struct inode___207 *, int);
	int (*write_inode)(struct inode___207 *, struct writeback_control *);
	int (*drop_inode)(struct inode___207 *);
	void (*evict_inode)(struct inode___207 *);
	void (*put_super)(struct super_block___207 *);
	int (*sync_fs)(struct super_block___207 *, int);
	int (*freeze_fs)(struct super_block___207 *);
	int (*unfreeze_fs)(struct super_block___207 *);
	int (*statfs)(struct dentry___207 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___207 *, int *, char *);
	void (*umount_begin)(struct super_block___207 *);
	int (*show_options)(struct seq_file___139 *, struct dentry___207 *);
	int (*show_devname)(struct seq_file___139 *, struct dentry___207 *);
	int (*show_path)(struct seq_file___139 *, struct dentry___207 *);
	int (*show_stats)(struct seq_file___139 *, struct dentry___207 *);
	ssize_t (*quota_read)(struct super_block___207 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___207 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___207 *);
	int (*bdev_try_to_free_page)(struct super_block___207 *, struct page___206 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___207 *);
	void (*free_cached_objects)(struct super_block___207 *, int);
};

struct xattr_handler___125 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___207 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___207 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___207 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___117)(struct file___207 *, wait_queue_head_t *, struct poll_table_struct___115 *);

struct poll_table_struct___115 {
	poll_queue_proc___117 _qproc;
	long unsigned int _key;
};

struct signal_struct___208 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___208 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___208 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___89 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___89 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___209 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___124 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___124 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___19 {
	wait_queue_head_t wait;
	struct fasync_struct___207 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___19;

struct socket___20 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___19 *wq;
	struct file___207 *file;
	struct sock___20 *sk;
	const struct proto_ops___19 *ops;
};

struct proto_ops___19 {
	int family;
	struct module___120 *owner;
	int (*release)(struct socket___20 *);
	int (*bind)(struct socket___20 *, struct sockaddr *, int);
	int (*connect)(struct socket___20 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___20 *, struct socket___20 *);
	int (*accept)(struct socket___20 *, struct socket___20 *, int);
	int (*getname)(struct socket___20 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___207 *, struct socket___20 *, struct poll_table_struct___115 *);
	int (*ioctl)(struct socket___20 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___20 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___20 *, int);
	int (*shutdown)(struct socket___20 *, int);
	int (*setsockopt)(struct socket___20 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___20 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___20 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___20 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___27 *, struct socket___20 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___27 *, struct socket___20 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___207 *, struct socket___20 *, struct vm_area_struct___215 *);
	ssize_t (*sendpage)(struct socket___20 *, struct page___206 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___20 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___20 *, int);
		struct {
			void (*set_peek_off)(struct sock___20 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___35 {
	struct ctl_table_header___38 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___35 {
	struct mutex___209 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___35 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___38 *ctl;
};

struct netns_ipv4___35 {
	struct ctl_table_header___38 *forw_hdr;
	struct ctl_table_header___38 *frags_hdr;
	struct ctl_table_header___38 *ipv4_hdr;
	struct ctl_table_header___38 *route_hdr;
	struct ctl_table_header___38 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___20 *fibnl;
	struct sock___20 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___35 {
	struct ctl_table_header___38 *hdr;
	struct ctl_table_header___38 *route_hdr;
	struct ctl_table_header___38 *icmp_hdr;
	struct ctl_table_header___38 *frags_hdr;
	struct ctl_table_header___38 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___26;

struct neighbour___19;

struct dst_ops___36 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___36 *);
	struct dst_entry___19 * (*check)(struct dst_entry___19 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___19 *);
	unsigned int (*mtu)(const struct dst_entry___19 *);
	u32 * (*cow_metrics)(struct dst_entry___19 *, long unsigned int);
	void (*destroy)(struct dst_entry___19 *);
	void (*ifdown)(struct dst_entry___19 *, struct net_device___26 *, int);
	struct dst_entry___19 * (*negative_advice)(struct dst_entry___19 *);
	void (*link_failure)(struct sk_buff___27 *);
	void (*update_pmtu)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___27 *, u32);
	void (*redirect)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___27 *);
	int (*local_out)(struct sk_buff___27 *);
	struct neighbour___19 * (*neigh_lookup)(const struct dst_entry___19 *, struct sk_buff___27 *, const void *);
	struct kmem_cache___192 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___36 {
	struct netns_sysctl_ipv6___35 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___36 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___20 **icmp_sk;
	struct sock___20 *ndisc_sk;
	struct sock___20 *tcp_sk;
	struct sock___20 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___35 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___38 *sysctl_header;
	struct sock___20 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___19 {
	struct sock___20 *v4_ctl_sk;
	struct sock___20 *v6_ctl_sk;
};

struct netns_nf___35 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___38 *nf_log_dir_header;
};

struct nf_proto_net___35 {
	struct ctl_table_header___38 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___35 {
	struct nf_proto_net___35 pn;
	unsigned int timeout;
};

struct nf_tcp_net___35 {
	struct nf_proto_net___35 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___35 {
	struct nf_proto_net___35 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___35 {
	struct nf_proto_net___35 pn;
	unsigned int timeout;
};

struct nf_ip_net___35 {
	struct nf_generic_net___35 generic;
	struct nf_tcp_net___35 tcp;
	struct nf_udp_net___35 udp;
	struct nf_icmp_net___35 icmp;
	struct nf_icmp_net___35 icmpv6;
};

struct netns_ct___35 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___38 *sysctl_header;
	struct ctl_table_header___38 *acct_sysctl_header;
	struct ctl_table_header___38 *tstamp_sysctl_header;
	struct ctl_table_header___38 *event_sysctl_header;
	struct ctl_table_header___38 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___192 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___35 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___35 {
	struct netns_sysctl_ipv6___35 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___36 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___20 *nlsk;
	struct sock___20 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___38 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___36 xfrm4_dst_ops;
	struct dst_ops___36 xfrm6_dst_ops;
};

struct net___37 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___38 sysctls;
	struct sock___20 *rtnl;
	struct sock___20 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___26 *loopback_dev;
	struct netns_core___35 core;
	struct netns_mib mib;
	struct netns_packet___35 packet;
	struct netns_unix___35 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___35 ipv4;
	struct netns_ipv6___36 ipv6;
	struct netns_sctp___35 sctp;
	struct netns_dccp___19 dccp;
	struct netns_nf___35 nf;
	struct netns_xt xt;
	struct netns_ct___35 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___35 nf_frag;
	struct sock___20 *nfnl;
	struct sock___20 *nfnl_stash;
	struct sk_buff_head___25 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___36 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___20 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___20 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___209 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___209 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___191 {
	void **freelist;
	long unsigned int tid;
	struct page___206 *page;
	struct page___206 *partial;
};

struct memcg_cache_params___192 {
	bool is_root_cache;
	union {
		struct kmem_cache___192 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___192 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___24 {
	atomic_t use;
	unsigned int mask;
	struct net_device___26 *physindev;
	struct net_device___26 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___24(struct sk_buff___27 **);

struct net_device_ops___24;

struct ethtool_ops___24;

struct header_ops___24;

struct netdev_rx_queue___24;

struct netdev_queue___24;

struct rtnl_link_ops___19;

struct dcbnl_rtnl_ops___24;

struct net_device___26 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___24 *netdev_ops;
	const struct ethtool_ops___24 *ethtool_ops;
	const struct header_ops___24 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___22 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___24 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___24 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___24 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___24 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___24 = 0,
		NETREG_REGISTERED___24 = 1,
		NETREG_UNREGISTERING___24 = 2,
		NETREG_UNREGISTERED___24 = 3,
		NETREG_RELEASED___24 = 4,
		NETREG_DUMMY___24 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___24 = 0,
		RTNL_LINK_INITIALIZING___24 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___26 *);
	struct netpoll_info *npinfo;
	struct net___37 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___186 dev;
	const struct attribute_group___165 *sysfs_groups[4];
	const struct rtnl_link_ops___19 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___24 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___27 {
	struct sk_buff___27 *next;
	struct sk_buff___27 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___20 *sk;
	struct net_device___26 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___27 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___24 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___24 {
	int (*get_settings)(struct net_device___26 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___26 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___26 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___26 *);
	void (*get_regs)(struct net_device___26 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___26 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___26 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___26 *);
	void (*set_msglevel)(struct net_device___26 *, u32);
	int (*nway_reset)(struct net_device___26 *);
	u32 (*get_link)(struct net_device___26 *);
	int (*get_eeprom_len)(struct net_device___26 *);
	int (*get_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___26 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___26 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___26 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___26 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___26 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___26 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___26 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___26 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___26 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___26 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___26 *);
	void (*complete)(struct net_device___26 *);
	u32 (*get_priv_flags)(struct net_device___26 *);
	int (*set_priv_flags)(struct net_device___26 *, u32);
	int (*get_sset_count)(struct net_device___26 *, int);
	int (*get_rxnfc)(struct net_device___26 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___26 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___26 *, struct ethtool_flash *);
	int (*reset)(struct net_device___26 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___26 *);
	int (*get_rxfh_indir)(struct net_device___26 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___26 *, const u32 *);
	void (*get_channels)(struct net_device___26 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___26 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___26 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___26 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___26 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___26 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___26 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___26 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___26 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___26 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___26 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___26 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___19 {
	struct callback_head callback_head;
	struct dst_entry___19 *child;
	struct net_device___26 *dev;
	struct dst_ops___36 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___19 *path;
	struct dst_entry___19 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___27 *);
	union {
		int (*output)(struct sock___20 *, struct sk_buff___27 *);
		struct {
			int (*output)(struct sk_buff___27 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___19 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___19;

struct neigh_parms___19;

struct neigh_ops___19;

struct neighbour___19 {
	struct neighbour___19 *next;
	struct neigh_table___19 *tbl;
	struct neigh_parms___19 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___25 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___19 *, struct sk_buff___27 *);
	const struct neigh_ops___19 *ops;
	struct callback_head rcu;
	struct net_device___26 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___36 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___27 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___27 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___37 *, struct dst_entry___19 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___27 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___27 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___139 {
	void * (*start)(struct seq_file___139 *, loff_t *);
	void (*stop)(struct seq_file___139 *, void *);
	void * (*next)(struct seq_file___139 *, void *, loff_t *);
	int (*show)(struct seq_file___139 *, void *);
};

struct dcbnl_rtnl_ops___24 {
	int (*ieee_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___26 *);
	u8 (*setstate)(struct net_device___26 *, u8);
	void (*getpermhwaddr)(struct net_device___26 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___26 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___26 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___26 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___26 *, int, u8 *);
	void (*setpfccfg)(struct net_device___26 *, int, u8);
	void (*getpfccfg)(struct net_device___26 *, int, u8 *);
	u8 (*setall)(struct net_device___26 *);
	u8 (*getcap)(struct net_device___26 *, int, u8 *);
	int (*getnumtcs)(struct net_device___26 *, int, u8 *);
	int (*setnumtcs)(struct net_device___26 *, int, u8);
	u8 (*getpfcstate)(struct net_device___26 *);
	void (*setpfcstate)(struct net_device___26 *, u8);
	void (*getbcncfg)(struct net_device___26 *, int, u32 *);
	void (*setbcncfg)(struct net_device___26 *, int, u32);
	void (*getbcnrp)(struct net_device___26 *, int, u8 *);
	void (*setbcnrp)(struct net_device___26 *, int, u8);
	u8 (*setapp)(struct net_device___26 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___26 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___26 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___26 *, int, u8);
	u8 (*getdcbx)(struct net_device___26 *);
	u8 (*setdcbx)(struct net_device___26 *, u8);
	int (*peer_getappinfo)(struct net_device___26 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___26 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___26 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___26 *, struct cee_pfc *);
};

struct cgroupfs_root___124;

struct cgroup___124 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___124 *parent;
	struct dentry___207 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___124 *subsys[11];
	struct cgroupfs_root___124 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___209 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___124 {
	struct super_block___207 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___124 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___69 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___207 *, struct file___207 *);
	ssize_t (*read)(struct cgroup___124 *, struct cftype___69 *, struct file___207 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___124 *, struct cftype___69 *);
	s64 (*read_s64)(struct cgroup___124 *, struct cftype___69 *);
	int (*read_map)(struct cgroup___124 *, struct cftype___69 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___124 *, struct cftype___69 *, struct seq_file___139 *);
	ssize_t (*write)(struct cgroup___124 *, struct cftype___69 *, struct file___207 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___124 *, struct cftype___69 *, u64);
	int (*write_s64)(struct cgroup___124 *, struct cftype___69 *, s64);
	int (*write_string)(struct cgroup___124 *, struct cftype___69 *, const char *);
	int (*trigger)(struct cgroup___124 *, unsigned int);
	int (*release)(struct inode___207 *, struct file___207 *);
	int (*register_event)(struct cgroup___124 *, struct cftype___69 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___124 *, struct cftype___69 *, struct eventfd_ctx *);
};

struct cftype_set___65 {
	struct list_head node;
	struct cftype___69 *cfts;
};

struct task_and_cgroup___65 {
	struct task_struct___208 *task;
	struct cgroup___124 *cgrp;
	struct css_set___124 *cg;
};

struct cgroup_taskset___65 {
	struct task_and_cgroup___65 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___124 *cur_cgrp;
};

struct cgroup_subsys___65 {
	struct cgroup_subsys_state___124 * (*css_alloc)(struct cgroup___124 *);
	int (*css_online)(struct cgroup___124 *);
	void (*css_offline)(struct cgroup___124 *);
	void (*css_free)(struct cgroup___124 *);
	int (*can_attach)(struct cgroup___124 *, struct cgroup_taskset___65 *);
	void (*cancel_attach)(struct cgroup___124 *, struct cgroup_taskset___65 *);
	void (*attach)(struct cgroup___124 *, struct cgroup_taskset___65 *);
	void (*fork)(struct task_struct___208 *);
	void (*exit)(struct cgroup___124 *, struct cgroup___124 *, struct task_struct___208 *);
	void (*bind)(struct cgroup___124 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___124 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___69 *base_cftypes;
	struct cftype_set___65 base_cftset;
	struct module___120 *module;
};

struct netlink_skb_parms___4 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___20 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___25 {
	struct sk_buff___27 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___27 *, struct netlink_callback___25 *);
	int (*done)(struct netlink_callback___25 *);
	void *data;
	struct module___120 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___24 {
	int (*create)(struct sk_buff___27 *, struct net_device___26 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___27 *, unsigned char *);
	int (*rebuild)(struct sk_buff___27 *);
	int (*cache)(const struct neighbour___19 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___26 *, const unsigned char *);
};

struct napi_struct___24 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___24 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___26 *dev;
	struct sk_buff___27 *gro_list;
	struct sk_buff___27 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___24 {
	struct net_device___26 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___22 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___24 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___22 kobj;
	struct net_device___26 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___24 {
	int (*ndo_init)(struct net_device___26 *);
	void (*ndo_uninit)(struct net_device___26 *);
	int (*ndo_open)(struct net_device___26 *);
	int (*ndo_stop)(struct net_device___26 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___27 *, struct net_device___26 *);
	u16 (*ndo_select_queue)(struct net_device___26 *, struct sk_buff___27 *);
	void (*ndo_change_rx_flags)(struct net_device___26 *, int);
	void (*ndo_set_rx_mode)(struct net_device___26 *);
	int (*ndo_set_mac_address)(struct net_device___26 *, void *);
	int (*ndo_validate_addr)(struct net_device___26 *);
	int (*ndo_do_ioctl)(struct net_device___26 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___26 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___26 *, int);
	int (*ndo_neigh_setup)(struct net_device___26 *, struct neigh_parms___19 *);
	void (*ndo_tx_timeout)(struct net_device___26 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___26 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___26 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___26 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___26 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___26 *);
	int (*ndo_netpoll_setup)(struct net_device___26 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___26 *);
	int (*ndo_busy_poll)(struct napi_struct___24 *);
	int (*ndo_set_vf_mac)(struct net_device___26 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___26 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___26 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___26 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___26 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___26 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___26 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___26 *, int, struct sk_buff___27 *);
	int (*ndo_setup_tc)(struct net_device___26 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___26 *);
	int (*ndo_fcoe_disable)(struct net_device___26 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___26 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___26 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___26 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___26 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___26 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___26 *, const struct sk_buff___27 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___26 *, struct net_device___26 *);
	int (*ndo_del_slave)(struct net_device___26 *, struct net_device___26 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___19 *);
	void (*ndo_neigh_destroy)(struct neighbour___19 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___27 *, struct netlink_callback___25 *, struct net_device___26 *, int);
	int (*ndo_bridge_setlink)(struct net_device___26 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___27 *, u32, u32, struct net_device___26 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___26 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___26 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___26 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___26 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___26 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___26 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___27 *, struct net_device___26 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___26 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___26 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___26 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___19 {
	struct net___37 *net;
	struct net_device___26 *dev;
	struct neigh_parms___19 *next;
	int (*neigh_setup)(struct neighbour___19 *);
	void (*neigh_cleanup)(struct neighbour___19 *);
	struct neigh_table___19 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___19 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___26 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___37 *, struct net_device___26 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___26 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___26 *, struct list_head *);
	size_t (*get_size)(const struct net_device___26 *);
	int (*fill_info)(struct sk_buff___27 *, const struct net_device___26 *);
	size_t (*get_xstats_size)(const struct net_device___26 *);
	int (*fill_xstats)(struct sk_buff___27 *, const struct net_device___26 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___37 * (*get_link_net)(const struct net_device___26 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___26 *, struct net_device___26 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___26 *, const struct net_device___26 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___27 *, const struct net_device___26 *, const struct net_device___26 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___20 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___27 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___19;

struct neigh_hash_table___19;

struct neigh_table___19 {
	struct neigh_table___19 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___26 *, __u32 *);
	int (*constructor)(struct neighbour___19 *);
	int (*pconstructor)(struct pneigh_entry___19 *);
	void (*pdestructor)(struct pneigh_entry___19 *);
	void (*proxy_redo)(struct sk_buff___27 *);
	char *id;
	struct neigh_parms___19 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___25 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___19 *nht;
	struct pneigh_entry___19 **phash_buckets;
};

struct neigh_ops___19 {
	int family;
	void (*solicit)(struct neighbour___19 *, struct sk_buff___27 *);
	void (*error_report)(struct neighbour___19 *, struct sk_buff___27 *);
	int (*output)(struct neighbour___19 *, struct sk_buff___27 *);
	int (*connected_output)(struct neighbour___19 *, struct sk_buff___27 *);
};

struct pneigh_entry___19 {
	struct pneigh_entry___19 *next;
	struct net___37 *net;
	struct net_device___26 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___19 {
	struct neighbour___19 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___19 {
	void (*close)(struct sock___20 *, long int);
	int (*connect)(struct sock___20 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___20 *, int);
	struct sock___20 * (*accept)(struct sock___20 *, int, int *);
	int (*ioctl)(struct sock___20 *, int, long unsigned int);
	int (*init)(struct sock___20 *);
	void (*destroy)(struct sock___20 *);
	void (*shutdown)(struct sock___20 *, int);
	int (*setsockopt)(struct sock___20 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___20 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___20 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___20 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___20 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___27 *, struct sock___20 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___27 *, struct sock___20 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___20 *, struct page___206 *, int, size_t, int);
	int (*bind)(struct sock___20 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___20 *, struct sk_buff___27 *);
	void (*release_cb)(struct sock___20 *);
	void (*mtu_reduced)(struct sock___20 *);
	void (*hash)(struct sock___20 *);
	void (*unhash)(struct sock___20 *);
	void (*rehash)(struct sock___20 *);
	int (*get_port)(struct sock___20 *, short unsigned int);
	void (*clear_sk)(struct sock___20 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___20 *);
	void (*enter_memory_pressure)(struct sock___20 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___192 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___120 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___65 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___19 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___19 {
	void (*enter_memory_pressure)(struct sock___20 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

enum proc_cn_mcast_op {
	PROC_CN_MCAST_LISTEN = 1,
	PROC_CN_MCAST_IGNORE = 2,
};

struct fork_proc_event {
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
	__kernel_pid_t child_pid;
	__kernel_pid_t child_tgid;
};

struct exec_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct id_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	union {
		__u32 ruid;
		__u32 rgid;
	} r;
	union {
		__u32 euid;
		__u32 egid;
	} e;
};

struct sid_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct ptrace_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__kernel_pid_t tracer_pid;
	__kernel_pid_t tracer_tgid;
};

struct comm_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	char comm[16];
};

struct coredump_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct exit_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__u32 exit_code;
	__u32 exit_signal;
};

struct proc_event {
	enum what what;
	__u32 cpu;
	__u64 timestamp_ns;
	union {
		struct {
			__u32 err;
		} ack;
		struct fork_proc_event fork;
		struct exec_proc_event exec;
		struct id_proc_event id;
		struct sid_proc_event sid;
		struct ptrace_proc_event ptrace;
		struct comm_proc_event comm;
		struct coredump_proc_event coredump;
		struct exit_proc_event exit;
	} event_data;
};

struct component_ops {
	int (*bind)(struct device___186 *, struct device___186 *, void *);
	void (*unbind)(struct device___186 *, struct device___186 *, void *);
};

struct master;

struct component_master_ops {
	int (*add_components)(struct device___186 *, struct master *);
	int (*bind)(struct device___186 *);
	void (*unbind)(struct device___186 *);
};

struct component_match;

struct master {
	struct list_head node;
	struct list_head components;
	bool bound;
	const struct component_master_ops *ops;
	struct device___186 *dev;
	struct component_match *match;
};

struct component_match {
	size_t alloc;
	size_t num;
	struct {
		void *data;
		int (*fn)(struct device___186 *, void *);
	} compare[0];
};

struct component {
	struct list_head node;
	struct list_head master_node;
	struct master *master;
	bool bound;
	const struct component_ops *ops;
	struct device___186 *dev;
};

struct page___207;

typedef struct page___207 *pgtable_t___207;

struct address_space___208;

struct kmem_cache___193;

struct page___207 {
	long unsigned int flags;
	struct address_space___208 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___207 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___207 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___193 *slab_cache;
		struct page___207 *first_page;
	};
	long: 64;
};

struct task_struct___209;

struct pv_cpu_ops___209 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___79 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___79 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___209 *);
	void (*end_context_switch)(struct task_struct___209 *);
};

struct mutex___210 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___209 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___202 {
	struct page___207 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___216;

struct nsproxy___110;

struct signal_struct___209;

struct css_set___125;

struct task_struct___209 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___209 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___216 *mm;
	struct mm_struct___216 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___209 *real_parent;
	struct task_struct___209 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___209 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___89 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___209 = 0,
		VTIME_USER___209 = 1,
		VTIME_SYS___209 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___79 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___110 *nsproxy;
	struct signal_struct___209 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___125 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___210 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___202 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___216 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___216 *, struct mm_struct___216 *);
	void (*dup_mmap)(struct mm_struct___216 *, struct mm_struct___216 *);
	void (*exit_mmap)(struct mm_struct___216 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___216 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___216 *);
	void (*pgd_free)(struct mm_struct___216 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___216 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___216 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___216 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___216 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___216 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___216 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___216 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___216 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___216 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___216 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___216 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___210 lock;
	void *vdso;
} mm_context_t___210;

struct xol_area___207;

struct uprobes_state___207 {
	struct xol_area___207 *xol_area;
};

struct vm_area_struct___216;

struct file___208;

struct core_state___209;

struct mm_struct___216 {
	struct vm_area_struct___216 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___216 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___216 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___210 context;
	long unsigned int flags;
	struct core_state___209 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___209 *owner;
	struct file___208 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___207 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___121;

struct exec_domain___55 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___121 *module;
	struct exec_domain___55 *next;
};

struct module_kobject___120 {
	struct kobject___22 kobj;
	struct module___121 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___120;

struct module___121 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___120 mkobj;
	struct module_attribute___120 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___209 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___94 {
	struct task_struct___209 *task;
	struct exec_domain___55 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___168;

struct attribute_group___166 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___168 **bin_attrs;
};

struct bin_attribute___168 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___208 *, struct kobject___22 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___208 *, struct kobject___22 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	int (*mmap)(struct file___208 *, struct kobject___22 *, struct bin_attribute___168 *, struct vm_area_struct___216 *);
};

struct dentry___208;

struct path___208 {
	struct vfsmount *mnt;
	struct dentry___208 *dentry;
};

struct inode___208;

struct file_operations___208;

struct file___208 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___208 f_path;
	struct inode___208 *f_inode;
	const struct file_operations___208 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___89 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___208 *f_mapping;
	struct mutex___210 f_pos_lock;
};

struct vm_operations_struct___188;

struct vm_area_struct___216 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___216 *vm_next;
	struct vm_area_struct___216 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___216 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___188 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___208 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___187;

struct dev_pm_ops___187 {
	int (*prepare)(struct device___187 *);
	void (*complete)(struct device___187 *);
	int (*suspend)(struct device___187 *);
	int (*resume)(struct device___187 *);
	int (*freeze)(struct device___187 *);
	int (*thaw)(struct device___187 *);
	int (*poweroff)(struct device___187 *);
	int (*restore)(struct device___187 *);
	int (*suspend_late)(struct device___187 *);
	int (*resume_early)(struct device___187 *);
	int (*freeze_late)(struct device___187 *);
	int (*thaw_early)(struct device___187 *);
	int (*poweroff_late)(struct device___187 *);
	int (*restore_early)(struct device___187 *);
	int (*suspend_noirq)(struct device___187 *);
	int (*resume_noirq)(struct device___187 *);
	int (*freeze_noirq)(struct device___187 *);
	int (*thaw_noirq)(struct device___187 *);
	int (*poweroff_noirq)(struct device___187 *);
	int (*restore_noirq)(struct device___187 *);
	int (*runtime_suspend)(struct device___187 *);
	int (*runtime_resume)(struct device___187 *);
	int (*runtime_idle)(struct device___187 *);
};

struct dev_pm_qos___30;

struct dev_pm_info___30 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___30 *qos;
};

struct dma_map_ops___78;

struct dev_archdata___78 {
	struct dma_map_ops___78 *dma_ops;
	void *iommu;
};

struct device_private___2;

struct device_type___187;

struct bus_type___187;

struct device_driver___187;

struct dev_pm_domain___187;

struct device_node___13;

struct class___187;

struct device_rh___187;

struct device___187 {
	struct device___187 *parent;
	struct device_private___2 *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___187 *type;
	struct mutex___210 mutex;
	struct bus_type___187 *bus;
	struct device_driver___187 *driver;
	void *platform_data;
	struct dev_pm_info___30 power;
	struct dev_pm_domain___187 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___78 archdata;
	struct device_node___13 *of_node;
	struct acpi_dev_node___28 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___187 *class;
	const struct attribute_group___166 **groups;
	void (*release)(struct device___187 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___187 *device_rh;
};

struct dev_pm_qos_request___30;

struct dev_pm_qos___30 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___30 *latency_req;
	struct dev_pm_qos_request___30 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___30 *latency_tolerance_req;
};

struct dev_pm_info_rh___187 {
	void (*set_latency_tolerance)(struct device___187 *, s32);
};

struct dev_pm_domain___187 {
	struct dev_pm_ops___187 ops;
};

enum dpm_order {
	DPM_ORDER_NONE = 0,
	DPM_ORDER_DEV_AFTER_PARENT = 1,
	DPM_ORDER_PARENT_BEFORE_DEV = 2,
	DPM_ORDER_DEV_LAST = 3,
};

struct zone___209;

struct lruvec___209 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___209 *zone;
};

struct pglist_data___209;

struct zone___209 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___209 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___209 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___209 {
	struct zone___209 *zone;
	int zone_idx;
};

struct zonelist___209 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___209 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___209 {
	struct zone___209 node_zones[4];
	struct zonelist___209 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___209 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___136;

struct x86_io_apic_ops___136 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___136 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___136;

struct irq_data___136 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___136 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct property___13;

struct device_node___13 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___13 *properties;
	struct property___13 *deadprops;
	struct device_node___13 *parent;
	struct device_node___13 *child;
	struct device_node___13 *sibling;
	struct device_node___13 *next;
	struct device_node___13 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___22 kobj;
};

struct smp_ops___209 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___209 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___78 {
	void * (*alloc)(struct device___187 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___187 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___187 *, struct vm_area_struct___216 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___187 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___187 *, struct page___207 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___187 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___187 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___187 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___187 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___187 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___187 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___187 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___187 *, dma_addr_t);
	int (*dma_supported)(struct device___187 *, u64);
	int (*set_dma_mask)(struct device___187 *, u64);
	int is_phys;
};

struct bus_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___187 *, char *);
	ssize_t (*store)(struct bus_type___187 *, const char *, size_t);
};

struct device_attribute___187;

struct driver_attribute___187;

struct subsys_private___2;

struct bus_type___187 {
	const char *name;
	const char *dev_name;
	struct device___187 *dev_root;
	struct bus_attribute___187 *bus_attrs;
	struct device_attribute___187 *dev_attrs;
	struct driver_attribute___187 *drv_attrs;
	const struct attribute_group___166 **bus_groups;
	const struct attribute_group___166 **dev_groups;
	const struct attribute_group___166 **drv_groups;
	int (*match)(struct device___187 *, struct device_driver___187 *);
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	int (*probe)(struct device___187 *);
	int (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*online)(struct device___187 *);
	int (*offline)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___2 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct device___187 *, struct device_attribute___187 *, char *);
	ssize_t (*store)(struct device___187 *, struct device_attribute___187 *, const char *, size_t);
};

struct driver_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___187 *, char *);
	ssize_t (*store)(struct device_driver___187 *, const char *, size_t);
};

struct driver_private___2;

struct device_driver___187 {
	const char *name;
	struct bus_type___187 *bus;
	struct module___121 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___187 *);
	int (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	const struct attribute_group___166 **groups;
	const struct dev_pm_ops___187 *pm;
	struct driver_private___2 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___2 {
	struct kset___22 subsys;
	struct kset___22 *devices_kset;
	struct list_head interfaces;
	struct mutex___210 mutex;
	struct kset___22 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___187 *bus;
	struct kset___22 glue_dirs;
	struct class___187 *class;
};

struct device_type___187 {
	const char *name;
	const struct attribute_group___166 **groups;
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
};

struct driver_private___2 {
	struct kobject___22 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___120 *mkobj;
	struct device_driver___187 *driver;
};

struct class_attribute___187;

struct class___187 {
	const char *name;
	struct module___121 *owner;
	struct class_attribute___187 *class_attrs;
	struct device_attribute___187 *dev_attrs;
	const struct attribute_group___166 **dev_groups;
	struct bin_attribute___168 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *);
	void (*class_release)(struct class___187 *);
	void (*dev_release)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
	struct subsys_private___2 *p;
};

struct class_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct class___187 *, struct class_attribute___187 *, char *);
	ssize_t (*store)(struct class___187 *, struct class_attribute___187 *, const char *, size_t);
	const void * (*namespace)(struct class___187 *, const struct class_attribute___187 *);
};

struct class_interface___2 {
	struct list_head node;
	struct class___187 *class;
	int (*add_dev)(struct device___187 *, struct class_interface___2 *);
	void (*remove_dev)(struct device___187 *, struct class_interface___2 *);
};

struct dev_ext_attribute___2 {
	struct device_attribute___187 attr;
	void *var;
};

struct device_private___2 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___187 *device;
};

struct device_rh___187 {
	struct dev_pm_info_rh___187 power;
};

struct ctl_table_header___39;

struct ctl_node___39 {
	struct rb_node node;
	struct ctl_table_header___39 *header;
};

struct ctl_table_root___39;

struct ctl_table_set___39;

struct ctl_dir___39;

struct ctl_table_header___39 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___39 *root;
	struct ctl_table_set___39 *set;
	struct ctl_dir___39 *parent;
	struct ctl_node___39 *node;
};

struct ctl_dir___39 {
	struct ctl_table_header___39 header;
	struct rb_root root;
};

struct ctl_table_set___39 {
	int (*is_seen)(struct ctl_table_set___39 *);
	struct ctl_dir___39 dir;
};

struct ctl_table_root___39 {
	struct ctl_table_set___39 default_set;
	struct ctl_table_set___39 * (*lookup)(struct ctl_table_root___39 *, struct nsproxy___110 *);
	int (*permissions)(struct ctl_table_header___39 *, struct ctl_table *);
};

struct net___38;

struct nsproxy___110 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___38 *net_ns;
};

struct module_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___120 *, struct module_kobject___120 *, char *);
	ssize_t (*store)(struct module_attribute___120 *, struct module_kobject___120 *, const char *, size_t);
	void (*setup)(struct module___121 *, const char *);
	int (*test)(struct module___121 *);
	void (*free)(struct module___121 *);
};

struct kmem_cache_cpu___192 {
	void **freelist;
	long unsigned int tid;
	struct page___207 *page;
	struct page___207 *partial;
};

struct memcg_cache_params___193;

struct kmem_cache___193 {
	struct kmem_cache_cpu___192 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___193 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___193 {
	bool is_root_cache;
	union {
		struct kmem_cache___193 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___193 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct property___13 {
	char *name;
	int length;
	void *value;
	struct property___13 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___168 attr;
};

struct dentry_operations___208;

struct super_block___208;

struct dentry___208 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___208 *d_parent;
	struct qstr d_name;
	struct inode___208 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___208 *d_op;
	struct super_block___208 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___208;

struct address_space___208 {
	struct inode___208 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___210 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___208 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___208;

struct file_lock___208;

struct dquot___208;

struct block_device___208;

struct inode___208 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___208 *i_op;
	struct super_block___208 *i_sb;
	struct address_space___208 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___210 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___208 *i_fop;
	struct file_lock___208 *i_flock;
	struct address_space___208 i_data;
	struct dquot___208 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___208 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___208 {
	int (*d_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_hash)(const struct dentry___208 *, struct qstr *);
	int (*d_compare)(const struct dentry___208 *, const struct dentry___208 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___208 *);
	void (*d_release)(struct dentry___208 *);
	void (*d_prune)(struct dentry___208 *);
	void (*d_iput)(struct dentry___208 *, struct inode___208 *);
	char * (*d_dname)(struct dentry___208 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___208 *);
	int (*d_manage)(struct dentry___208 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___208;

struct mem_dqinfo___208 {
	struct quota_format_type___208 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___208;

struct quota_info___208 {
	unsigned int flags;
	struct mutex___210 dqio_mutex;
	struct mutex___210 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___208 *files[2];
	struct mem_dqinfo___208 info[2];
	const struct quota_format_ops___208 *ops[2];
};

struct file_system_type___208;

struct super_operations___208;

struct dquot_operations___208;

struct quotactl_ops___208;

struct xattr_handler___126;

struct super_block___208 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___208 *s_type;
	const struct super_operations___208 *s_op;
	const struct dquot_operations___208 *dq_op;
	const struct quotactl_ops___208 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___208 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___126 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___208 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___208 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___210 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___208 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct hd_struct___42;

struct gendisk___42;

struct block_device___208 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___208 *bd_inode;
	struct super_block___208 *bd_super;
	struct mutex___210 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___208 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___42 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___42 *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___210 bd_fsfreeze_mutex;
};

struct cgroup___125;

struct cgroup_subsys_state___125 {
	struct cgroup___125 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___208 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___208 *ia_file;
};

struct dquot___208 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___210 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___208 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___208 {
	int qf_fmt_id;
	const struct quota_format_ops___208 *qf_ops;
	struct module___121 *qf_owner;
	struct quota_format_type___208 *qf_next;
};

struct quota_format_ops___208 {
	int (*check_quota_file)(struct super_block___208 *, int);
	int (*read_file_info)(struct super_block___208 *, int);
	int (*write_file_info)(struct super_block___208 *, int);
	int (*free_file_info)(struct super_block___208 *, int);
	int (*read_dqblk)(struct dquot___208 *);
	int (*commit_dqblk)(struct dquot___208 *);
	int (*release_dqblk)(struct dquot___208 *);
};

struct dquot_operations___208 {
	int (*write_dquot)(struct dquot___208 *);
	struct dquot___208 * (*alloc_dquot)(struct super_block___208 *, int);
	void (*destroy_dquot)(struct dquot___208 *);
	int (*acquire_dquot)(struct dquot___208 *);
	int (*release_dquot)(struct dquot___208 *);
	int (*mark_dirty)(struct dquot___208 *);
	int (*write_info)(struct super_block___208 *, int);
	qsize_t * (*get_reserved_space)(struct inode___208 *);
};

struct quotactl_ops___208 {
	int (*quota_on)(struct super_block___208 *, int, int, struct path___208 *);
	int (*quota_on_meta)(struct super_block___208 *, int, int);
	int (*quota_off)(struct super_block___208 *, int);
	int (*quota_sync)(struct super_block___208 *, int);
	int (*get_info)(struct super_block___208 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___208 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___208 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___208 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___208 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___208 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___208 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___208 *, unsigned int);
};

struct address_space_operations___208 {
	int (*writepage)(struct page___207 *, struct writeback_control *);
	int (*readpage)(struct file___208 *, struct page___207 *);
	int (*writepages)(struct address_space___208 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___207 *);
	int (*readpages)(struct file___208 *, struct address_space___208 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___208 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___207 **, void **);
	int (*write_end)(struct file___208 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___207 *, void *);
	sector_t (*bmap)(struct address_space___208 *, sector_t);
	void (*invalidatepage)(struct page___207 *, long unsigned int);
	int (*releasepage)(struct page___207 *, gfp_t);
	void (*freepage)(struct page___207 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___208 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___208 *, struct page___207 *, struct page___207 *, enum migrate_mode);
	int (*launder_page)(struct page___207 *);
	int (*is_partially_uptodate)(struct page___207 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___207 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___208 *, struct page___207 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___208 *, sector_t *);
	void (*swap_deactivate)(struct file___208 *);
	void (*invalidatepage_range)(struct page___207 *, unsigned int, unsigned int);
};

struct hd_struct___42 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___187 __dev;
	struct kobject___22 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___42;

struct gendisk___42 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___42 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___42 *part_tbl;
	struct hd_struct___42 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct device___187 *driverfs_dev;
	struct kobject___22 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct inode_operations___208 {
	struct dentry___208 * (*lookup)(struct inode___208 *, struct dentry___208 *, unsigned int);
	void * (*follow_link)(struct dentry___208 *, struct nameidata *);
	int (*permission)(struct inode___208 *, int);
	struct posix_acl * (*get_acl)(struct inode___208 *, int);
	int (*readlink)(struct dentry___208 *, char *, int);
	void (*put_link)(struct dentry___208 *, struct nameidata *, void *);
	int (*create)(struct inode___208 *, struct dentry___208 *, umode_t, bool);
	int (*link)(struct dentry___208 *, struct inode___208 *, struct dentry___208 *);
	int (*unlink)(struct inode___208 *, struct dentry___208 *);
	int (*symlink)(struct inode___208 *, struct dentry___208 *, const char *);
	int (*mkdir)(struct inode___208 *, struct dentry___208 *, umode_t);
	int (*rmdir)(struct inode___208 *, struct dentry___208 *);
	int (*mknod)(struct inode___208 *, struct dentry___208 *, umode_t, dev_t);
	int (*rename)(struct inode___208 *, struct dentry___208 *, struct inode___208 *, struct dentry___208 *);
	int (*setattr)(struct dentry___208 *, struct iattr___208 *);
	int (*getattr)(struct vfsmount *, struct dentry___208 *, struct kstat *);
	int (*setxattr)(struct dentry___208 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___208 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___208 *, char *, size_t);
	int (*removexattr)(struct dentry___208 *, const char *);
	int (*fiemap)(struct inode___208 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___208 *, struct timespec *, int);
	int (*atomic_open)(struct inode___208 *, struct dentry___208 *, struct file___208 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___140;

struct file_operations___208 {
	struct module___121 *owner;
	loff_t (*llseek)(struct file___208 *, loff_t, int);
	ssize_t (*read)(struct file___208 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___208 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___208 *, void *, filldir_t);
	unsigned int (*poll)(struct file___208 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___208 *, struct vm_area_struct___216 *);
	int (*open)(struct inode___208 *, struct file___208 *);
	int (*flush)(struct file___208 *, fl_owner_t);
	int (*release)(struct inode___208 *, struct file___208 *);
	int (*fsync)(struct file___208 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___208 *, int);
	int (*lock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*sendpage)(struct file___208 *, struct page___207 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___208 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___208 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___208 *, long int, struct file_lock___208 **, void **);
		struct {
			int (*setlease)(struct file___208 *, long int, struct file_lock___208 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___208 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___140 *, struct file___208 *);
};

struct fasync_struct___208;

struct file_lock_operations___208;

struct lock_manager_operations___208;

struct file_lock___208 {
	struct file_lock___208 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___89 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___208 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___208 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___208 *fl_ops;
	const struct lock_manager_operations___208 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___208 {
	void (*fl_copy_lock)(struct file_lock___208 *, struct file_lock___208 *);
	void (*fl_release_private)(struct file_lock___208 *);
};

struct lock_manager_operations___208 {
	int (*lm_compare_owner)(struct file_lock___208 *, struct file_lock___208 *);
	long unsigned int (*lm_owner_key)(struct file_lock___208 *);
	void (*lm_notify)(struct file_lock___208 *);
	int (*lm_grant)(struct file_lock___208 *, struct file_lock___208 *, int);
	void (*lm_break)(struct file_lock___208 *);
	int (*lm_change)(struct file_lock___208 **, int);
};

struct fasync_struct___208 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___208 *fa_next;
	struct file___208 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___208 {
	const char *name;
	int fs_flags;
	struct dentry___208 * (*mount)(struct file_system_type___208 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___208 *);
	struct module___121 *owner;
	struct file_system_type___208 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___208 {
	struct inode___208 * (*alloc_inode)(struct super_block___208 *);
	void (*destroy_inode)(struct inode___208 *);
	void (*dirty_inode)(struct inode___208 *, int);
	int (*write_inode)(struct inode___208 *, struct writeback_control *);
	int (*drop_inode)(struct inode___208 *);
	void (*evict_inode)(struct inode___208 *);
	void (*put_super)(struct super_block___208 *);
	int (*sync_fs)(struct super_block___208 *, int);
	int (*freeze_fs)(struct super_block___208 *);
	int (*unfreeze_fs)(struct super_block___208 *);
	int (*statfs)(struct dentry___208 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___208 *, int *, char *);
	void (*umount_begin)(struct super_block___208 *);
	int (*show_options)(struct seq_file___140 *, struct dentry___208 *);
	int (*show_devname)(struct seq_file___140 *, struct dentry___208 *);
	int (*show_path)(struct seq_file___140 *, struct dentry___208 *);
	int (*show_stats)(struct seq_file___140 *, struct dentry___208 *);
	ssize_t (*quota_read)(struct super_block___208 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___208 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___208 *);
	int (*bdev_try_to_free_page)(struct super_block___208 *, struct page___207 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___208 *);
	void (*free_cached_objects)(struct super_block___208 *, int);
};

struct xattr_handler___126 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___208 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___208 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___208 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___140;

struct seq_file___140 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___210 lock;
	const struct seq_operations___140 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___42 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___42 *last_lookup;
	struct hd_struct___42 *part[0];
};

struct dev_pm_qos_request___30 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___187 *dev;
};

struct xol_area___207 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___207 *page;
	long unsigned int vaddr;
};

struct vm_fault___184;

struct vm_operations_struct___188 {
	void (*open)(struct vm_area_struct___216 *);
	void (*close)(struct vm_area_struct___216 *);
	int (*fault)(struct vm_area_struct___216 *, struct vm_fault___184 *);
	int (*page_mkwrite)(struct vm_area_struct___216 *, struct vm_fault___184 *);
	int (*access)(struct vm_area_struct___216 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___216 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___216 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___216 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___216 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___209 {
	struct task_struct___209 *task;
	struct core_thread___209 *next;
};

struct core_state___209 {
	atomic_t nr_threads;
	struct core_thread___209 dumper;
	struct completion startup;
};

struct vm_fault___184 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___207 *page;
};

struct signal_struct___209 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___209 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___209 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___89 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___89 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___210 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___125 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___125 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___36 {
	struct ctl_table_header___39 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___36 {
	struct mutex___210 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___36 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___39 *ctl;
};

struct netns_ipv4___36 {
	struct ctl_table_header___39 *forw_hdr;
	struct ctl_table_header___39 *frags_hdr;
	struct ctl_table_header___39 *ipv4_hdr;
	struct ctl_table_header___39 *route_hdr;
	struct ctl_table_header___39 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___36 {
	struct ctl_table_header___39 *hdr;
	struct ctl_table_header___39 *route_hdr;
	struct ctl_table_header___39 *icmp_hdr;
	struct ctl_table_header___39 *frags_hdr;
	struct ctl_table_header___39 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___27;

struct sk_buff___28;

struct dst_ops___37 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___37 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___27 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___28 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___28 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___28 *);
	int (*local_out)(struct sk_buff___28 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___28 *, const void *);
	struct kmem_cache___193 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___37 {
	struct netns_sysctl_ipv6___36 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___37 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___36 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___39 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___36 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___39 *nf_log_dir_header;
};

struct nf_proto_net___36 {
	struct ctl_table_header___39 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___36 {
	struct nf_proto_net___36 pn;
	unsigned int timeout;
};

struct nf_tcp_net___36 {
	struct nf_proto_net___36 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___36 {
	struct nf_proto_net___36 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___36 {
	struct nf_proto_net___36 pn;
	unsigned int timeout;
};

struct nf_ip_net___36 {
	struct nf_generic_net___36 generic;
	struct nf_tcp_net___36 tcp;
	struct nf_udp_net___36 udp;
	struct nf_icmp_net___36 icmp;
	struct nf_icmp_net___36 icmpv6;
};

struct netns_ct___36 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___39 *sysctl_header;
	struct ctl_table_header___39 *acct_sysctl_header;
	struct ctl_table_header___39 *tstamp_sysctl_header;
	struct ctl_table_header___39 *event_sysctl_header;
	struct ctl_table_header___39 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___193 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___36 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___36 {
	struct netns_sysctl_ipv6___36 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___26 {
	struct sk_buff___28 *next;
	struct sk_buff___28 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___37 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___39 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___37 xfrm4_dst_ops;
	struct dst_ops___37 xfrm6_dst_ops;
};

struct net___38 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___39 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___27 *loopback_dev;
	struct netns_core___36 core;
	struct netns_mib mib;
	struct netns_packet___36 packet;
	struct netns_unix___36 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___36 ipv4;
	struct netns_ipv6___37 ipv6;
	struct netns_sctp___36 sctp;
	struct netns_dccp___19 dccp;
	struct netns_nf___36 nf;
	struct netns_xt xt;
	struct netns_ct___36 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___36 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___26 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___37 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___210 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___210 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___25 {
	atomic_t use;
	unsigned int mask;
	struct net_device___27 *physindev;
	struct net_device___27 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___25(struct sk_buff___28 **);

struct net_device_ops___25;

struct ethtool_ops___25;

struct header_ops___25;

struct netdev_rx_queue___25;

struct netdev_queue___25;

struct dcbnl_rtnl_ops___25;

struct net_device___27 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___25 *netdev_ops;
	const struct ethtool_ops___25 *ethtool_ops;
	const struct header_ops___25 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___22 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___25 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___25 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___25 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___25 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___25 = 0,
		NETREG_REGISTERED___25 = 1,
		NETREG_UNREGISTERING___25 = 2,
		NETREG_UNREGISTERED___25 = 3,
		NETREG_RELEASED___25 = 4,
		NETREG_DUMMY___25 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___25 = 0,
		RTNL_LINK_INITIALIZING___25 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___27 *);
	struct netpoll_info *npinfo;
	struct net___38 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___187 dev;
	const struct attribute_group___166 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___25 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___28 {
	struct sk_buff___28 *next;
	struct sk_buff___28 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___27 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___28 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___25 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___25 {
	int (*get_settings)(struct net_device___27 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___27 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___27 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___27 *);
	void (*get_regs)(struct net_device___27 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___27 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___27 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___27 *);
	void (*set_msglevel)(struct net_device___27 *, u32);
	int (*nway_reset)(struct net_device___27 *);
	u32 (*get_link)(struct net_device___27 *);
	int (*get_eeprom_len)(struct net_device___27 *);
	int (*get_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___27 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___27 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___27 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___27 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___27 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___27 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___27 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___27 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___27 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___27 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___27 *);
	void (*complete)(struct net_device___27 *);
	u32 (*get_priv_flags)(struct net_device___27 *);
	int (*set_priv_flags)(struct net_device___27 *, u32);
	int (*get_sset_count)(struct net_device___27 *, int);
	int (*get_rxnfc)(struct net_device___27 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___27 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___27 *, struct ethtool_flash *);
	int (*reset)(struct net_device___27 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___27 *);
	int (*get_rxfh_indir)(struct net_device___27 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___27 *, const u32 *);
	void (*get_channels)(struct net_device___27 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___27 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___27 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___27 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___27 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___27 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___27 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___27 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___27 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___27 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___27 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___27 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___37 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___28 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___28 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___38 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___28 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___28 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___136 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___136 *);
	void (*irq_shutdown)(struct irq_data___136 *);
	void (*irq_enable)(struct irq_data___136 *);
	void (*irq_disable)(struct irq_data___136 *);
	void (*irq_ack)(struct irq_data___136 *);
	void (*irq_mask)(struct irq_data___136 *);
	void (*irq_mask_ack)(struct irq_data___136 *);
	void (*irq_unmask)(struct irq_data___136 *);
	void (*irq_eoi)(struct irq_data___136 *);
	int (*irq_set_affinity)(struct irq_data___136 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___136 *);
	int (*irq_set_type)(struct irq_data___136 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___136 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___136 *);
	void (*irq_bus_sync_unlock)(struct irq_data___136 *);
	void (*irq_cpu_online)(struct irq_data___136 *);
	void (*irq_cpu_offline)(struct irq_data___136 *);
	void (*irq_suspend)(struct irq_data___136 *);
	void (*irq_resume)(struct irq_data___136 *);
	void (*irq_pm_shutdown)(struct irq_data___136 *);
	void (*irq_print_chip)(struct irq_data___136 *, struct seq_file___140 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___136 *, void *);
	long unsigned int flags;
};

struct seq_operations___140 {
	void * (*start)(struct seq_file___140 *, loff_t *);
	void (*stop)(struct seq_file___140 *, void *);
	void * (*next)(struct seq_file___140 *, void *, loff_t *);
	int (*show)(struct seq_file___140 *, void *);
};

struct dcbnl_rtnl_ops___25 {
	int (*ieee_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___27 *);
	u8 (*setstate)(struct net_device___27 *, u8);
	void (*getpermhwaddr)(struct net_device___27 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___27 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___27 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___27 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___27 *, int, u8 *);
	void (*setpfccfg)(struct net_device___27 *, int, u8);
	void (*getpfccfg)(struct net_device___27 *, int, u8 *);
	u8 (*setall)(struct net_device___27 *);
	u8 (*getcap)(struct net_device___27 *, int, u8 *);
	int (*getnumtcs)(struct net_device___27 *, int, u8 *);
	int (*setnumtcs)(struct net_device___27 *, int, u8);
	u8 (*getpfcstate)(struct net_device___27 *);
	void (*setpfcstate)(struct net_device___27 *, u8);
	void (*getbcncfg)(struct net_device___27 *, int, u32 *);
	void (*setbcncfg)(struct net_device___27 *, int, u32);
	void (*getbcnrp)(struct net_device___27 *, int, u8 *);
	void (*setbcnrp)(struct net_device___27 *, int, u8);
	u8 (*setapp)(struct net_device___27 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___27 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___27 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___27 *, int, u8);
	u8 (*getdcbx)(struct net_device___27 *);
	u8 (*setdcbx)(struct net_device___27 *, u8);
	int (*peer_getappinfo)(struct net_device___27 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___27 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___27 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___27 *, struct cee_pfc *);
};

struct cgroupfs_root___125;

struct cgroup___125 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___125 *parent;
	struct dentry___208 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___125 *subsys[11];
	struct cgroupfs_root___125 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___210 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___125 {
	struct super_block___208 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___125 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___26 {
	struct sk_buff___28 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___28 *, struct netlink_callback___26 *);
	int (*done)(struct netlink_callback___26 *);
	void *data;
	struct module___121 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___25 {
	int (*create)(struct sk_buff___28 *, struct net_device___27 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___28 *, unsigned char *);
	int (*rebuild)(struct sk_buff___28 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___27 *, const unsigned char *);
};

struct napi_struct___25 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___25 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___27 *dev;
	struct sk_buff___28 *gro_list;
	struct sk_buff___28 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___25 {
	struct net_device___27 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___22 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___25 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___22 kobj;
	struct net_device___27 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___25 {
	int (*ndo_init)(struct net_device___27 *);
	void (*ndo_uninit)(struct net_device___27 *);
	int (*ndo_open)(struct net_device___27 *);
	int (*ndo_stop)(struct net_device___27 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___28 *, struct net_device___27 *);
	u16 (*ndo_select_queue)(struct net_device___27 *, struct sk_buff___28 *);
	void (*ndo_change_rx_flags)(struct net_device___27 *, int);
	void (*ndo_set_rx_mode)(struct net_device___27 *);
	int (*ndo_set_mac_address)(struct net_device___27 *, void *);
	int (*ndo_validate_addr)(struct net_device___27 *);
	int (*ndo_do_ioctl)(struct net_device___27 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___27 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___27 *, int);
	int (*ndo_neigh_setup)(struct net_device___27 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___27 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___27 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___27 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___27 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___27 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___27 *);
	int (*ndo_netpoll_setup)(struct net_device___27 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___27 *);
	int (*ndo_busy_poll)(struct napi_struct___25 *);
	int (*ndo_set_vf_mac)(struct net_device___27 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___27 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___27 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___27 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___27 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___27 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___27 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___27 *, int, struct sk_buff___28 *);
	int (*ndo_setup_tc)(struct net_device___27 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___27 *);
	int (*ndo_fcoe_disable)(struct net_device___27 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___27 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___27 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___27 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___27 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___27 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___27 *, const struct sk_buff___28 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___27 *, struct net_device___27 *);
	int (*ndo_del_slave)(struct net_device___27 *, struct net_device___27 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___28 *, struct netlink_callback___26 *, struct net_device___27 *, int);
	int (*ndo_bridge_setlink)(struct net_device___27 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___28 *, u32, u32, struct net_device___27 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___27 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___27 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___27 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___27 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___27 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___27 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___28 *, struct net_device___27 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___27 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___27 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___27 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct class_dir {
	struct kobject___22 kobj;
	struct class___187 *class;
};

struct root_device {
	struct device___187 dev;
	struct module___121 *owner;
};

struct subsys_dev_iter {
	struct klist_iter ki;
	const struct device_type___187 *type;
};

struct subsys_interface___2 {
	const char *name;
	struct bus_type___187 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___187 *, struct subsys_interface___2 *);
	int (*remove_dev)(struct device___187 *, struct subsys_interface___2 *);
};

struct subsys_private {
	struct kset___20 subsys;
	struct kset___20 *devices_kset;
	struct list_head interfaces;
	struct mutex___202 mutex;
	struct kset___20 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___157 *bus;
	struct kset___20 glue_dirs;
	struct class___157 *class;
};

struct driver_private {
	struct kobject___20 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___113 *mkobj;
	struct device_driver___157 *driver;
};

struct device_private {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___157 *device;
};

struct class_dev_iter___2 {
	struct klist_iter ki;
	const struct device_type___187 *type;
};

struct class_attribute_string {
	struct class_attribute___187 attr;
	char *str;
};

struct class_compat {
	struct kobject___22 *kobj;
};

struct device___188;

struct dev_pm_ops___188 {
	int (*prepare)(struct device___188 *);
	void (*complete)(struct device___188 *);
	int (*suspend)(struct device___188 *);
	int (*resume)(struct device___188 *);
	int (*freeze)(struct device___188 *);
	int (*thaw)(struct device___188 *);
	int (*poweroff)(struct device___188 *);
	int (*restore)(struct device___188 *);
	int (*suspend_late)(struct device___188 *);
	int (*resume_early)(struct device___188 *);
	int (*freeze_late)(struct device___188 *);
	int (*thaw_early)(struct device___188 *);
	int (*poweroff_late)(struct device___188 *);
	int (*restore_early)(struct device___188 *);
	int (*suspend_noirq)(struct device___188 *);
	int (*resume_noirq)(struct device___188 *);
	int (*freeze_noirq)(struct device___188 *);
	int (*thaw_noirq)(struct device___188 *);
	int (*poweroff_noirq)(struct device___188 *);
	int (*restore_noirq)(struct device___188 *);
	int (*runtime_suspend)(struct device___188 *);
	int (*runtime_resume)(struct device___188 *);
	int (*runtime_idle)(struct device___188 *);
};

struct dev_pm_qos___31;

struct dev_pm_info___31 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___31 *qos;
};

struct dma_map_ops___79;

struct dev_archdata___79 {
	struct dma_map_ops___79 *dma_ops;
	void *iommu;
};

struct acpi_device___23;

struct acpi_dev_node___29 {
	union {
		struct acpi_device___23 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_private___3;

struct device_type___188;

struct bus_type___188;

struct device_driver___188;

struct dev_pm_domain___188;

struct class___188;

struct device_rh___188;

struct device___188 {
	struct device___188 *parent;
	struct device_private___3 *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___188 *type;
	struct mutex___202 mutex;
	struct bus_type___188 *bus;
	struct device_driver___188 *driver;
	void *platform_data;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___188 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___79 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___188 *class;
	const struct attribute_group___158 **groups;
	void (*release)(struct device___188 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___188 *device_rh;
};

struct dev_pm_qos_request___31;

struct dev_pm_qos___31 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___31 *latency_req;
	struct dev_pm_qos_request___31 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___31 *latency_tolerance_req;
};

struct dev_pm_info_rh___188 {
	void (*set_latency_tolerance)(struct device___188 *, s32);
};

struct dev_pm_domain___188 {
	struct dev_pm_ops___188 ops;
};

struct dma_map_ops___79 {
	void * (*alloc)(struct device___188 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___188 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___188 *, struct vm_area_struct___208 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___188 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___188 *, struct page___199 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___188 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___188 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___188 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___188 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___188 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___188 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___188 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___188 *, dma_addr_t);
	int (*dma_supported)(struct device___188 *, u64);
	int (*set_dma_mask)(struct device___188 *, u64);
	int is_phys;
};

struct bus_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___188 *, char *);
	ssize_t (*store)(struct bus_type___188 *, const char *, size_t);
};

struct device_attribute___188;

struct driver_attribute___188;

struct subsys_private___3;

struct bus_type___188 {
	const char *name;
	const char *dev_name;
	struct device___188 *dev_root;
	struct bus_attribute___188 *bus_attrs;
	struct device_attribute___188 *dev_attrs;
	struct driver_attribute___188 *drv_attrs;
	const struct attribute_group___158 **bus_groups;
	const struct attribute_group___158 **dev_groups;
	const struct attribute_group___158 **drv_groups;
	int (*match)(struct device___188 *, struct device_driver___188 *);
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	int (*probe)(struct device___188 *);
	int (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*online)(struct device___188 *);
	int (*offline)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___3 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct device___188 *, struct device_attribute___188 *, char *);
	ssize_t (*store)(struct device___188 *, struct device_attribute___188 *, const char *, size_t);
};

struct driver_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___188 *, char *);
	ssize_t (*store)(struct device_driver___188 *, const char *, size_t);
};

struct driver_private___3;

struct device_driver___188 {
	const char *name;
	struct bus_type___188 *bus;
	struct module___114 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___188 *);
	int (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	const struct attribute_group___158 **groups;
	const struct dev_pm_ops___188 *pm;
	struct driver_private___3 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___3 {
	struct kset___20 subsys;
	struct kset___20 *devices_kset;
	struct list_head interfaces;
	struct mutex___202 mutex;
	struct kset___20 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___188 *bus;
	struct kset___20 glue_dirs;
	struct class___188 *class;
};

struct device_type___188 {
	const char *name;
	const struct attribute_group___158 **groups;
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
};

struct driver_private___3 {
	struct kobject___20 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___113 *mkobj;
	struct device_driver___188 *driver;
};

struct class_attribute___188;

struct class___188 {
	const char *name;
	struct module___114 *owner;
	struct class_attribute___188 *class_attrs;
	struct device_attribute___188 *dev_attrs;
	const struct attribute_group___158 **dev_groups;
	struct bin_attribute___160 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *);
	void (*class_release)(struct class___188 *);
	void (*dev_release)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
	struct subsys_private___3 *p;
};

struct class_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct class___188 *, struct class_attribute___188 *, char *);
	ssize_t (*store)(struct class___188 *, struct class_attribute___188 *, const char *, size_t);
	const void * (*namespace)(struct class___188 *, const struct class_attribute___188 *);
};

struct acpi_scan_handler___23;

struct acpi_hotplug_context___23;

struct acpi_driver___23;

struct acpi_device___23 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___23 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___23 *handler;
	struct acpi_hotplug_context___23 *hp;
	struct acpi_driver___23 *driver;
	void *driver_data;
	struct device___188 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___202 physical_node_lock;
	void (*remove)(struct acpi_device___23 *);
};

struct device_private___3 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___188 *device;
};

struct device_rh___188 {
	struct dev_pm_info_rh___188 power;
};

struct platform_device___8 {
	const char *name;
	int id;
	bool id_auto;
	struct device___188 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___6 {
	struct device___188 *parent;
	struct acpi_dev_node___29 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct platform_driver___6 {
	int (*probe)(struct platform_device___8 *);
	int (*remove)(struct platform_device___8 *);
	void (*shutdown)(struct platform_device___8 *);
	int (*suspend)(struct platform_device___8 *, pm_message_t);
	int (*resume)(struct platform_device___8 *);
	struct device_driver___188 driver;
	const struct platform_device_id *id_table;
};

struct early_platform_driver {
	const char *class_str;
	struct platform_driver___6 *pdrv;
	struct list_head list;
	int requested_id;
	char *buffer;
	int bufsize;
};

struct acpi_hotplug_profile___23 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___23 *);
	void (*notify_online)(struct acpi_device___23 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___23 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___23 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___23 *);
	void (*bind)(struct device___188 *);
	void (*unbind)(struct device___188 *);
	struct acpi_hotplug_profile___23 hotplug;
};

struct acpi_hotplug_context___23 {
	struct acpi_device___23 *self;
	int (*notify)(struct acpi_device___23 *, u32);
	void (*uevent)(struct acpi_device___23 *, u32);
	void (*fixup)(struct acpi_device___23 *);
};

typedef int (*acpi_op_add___23)(struct acpi_device___23 *);

typedef int (*acpi_op_remove___23)(struct acpi_device___23 *);

typedef void (*acpi_op_notify___23)(struct acpi_device___23 *, u32);

struct acpi_device_ops___23 {
	acpi_op_add___23 add;
	acpi_op_remove___23 remove;
	acpi_op_notify___23 notify;
};

struct acpi_driver___23 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___23 ops;
	struct device_driver___188 drv;
	struct module___114 *owner;
};

struct dev_pm_qos_request___31 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___188 *dev;
};

struct platform_object {
	struct platform_device___8 pdev;
	char name[1];
};

struct device___189;

struct dev_pm_ops___189 {
	int (*prepare)(struct device___189 *);
	void (*complete)(struct device___189 *);
	int (*suspend)(struct device___189 *);
	int (*resume)(struct device___189 *);
	int (*freeze)(struct device___189 *);
	int (*thaw)(struct device___189 *);
	int (*poweroff)(struct device___189 *);
	int (*restore)(struct device___189 *);
	int (*suspend_late)(struct device___189 *);
	int (*resume_early)(struct device___189 *);
	int (*freeze_late)(struct device___189 *);
	int (*thaw_early)(struct device___189 *);
	int (*poweroff_late)(struct device___189 *);
	int (*restore_early)(struct device___189 *);
	int (*suspend_noirq)(struct device___189 *);
	int (*resume_noirq)(struct device___189 *);
	int (*freeze_noirq)(struct device___189 *);
	int (*thaw_noirq)(struct device___189 *);
	int (*poweroff_noirq)(struct device___189 *);
	int (*restore_noirq)(struct device___189 *);
	int (*runtime_suspend)(struct device___189 *);
	int (*runtime_resume)(struct device___189 *);
	int (*runtime_idle)(struct device___189 *);
};

struct acpi_device___24;

struct acpi_dev_node___30 {
	union {
		struct acpi_device___24 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_private___4;

struct device_type___189;

struct bus_type___189;

struct device_driver___189;

struct dev_pm_domain___189;

struct class___189;

struct device_rh___189;

struct device___189 {
	struct device___189 *parent;
	struct device_private___4 *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___189 *type;
	struct mutex___21 mutex;
	struct bus_type___189 *bus;
	struct device_driver___189 *driver;
	void *platform_data;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___189 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___79 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___30 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___189 *class;
	const struct attribute_group___14 **groups;
	void (*release)(struct device___189 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___189 *device_rh;
};

struct dev_pm_info_rh___189 {
	void (*set_latency_tolerance)(struct device___189 *, s32);
};

struct dev_pm_domain___189 {
	struct dev_pm_ops___189 ops;
};

struct bus_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___189 *, char *);
	ssize_t (*store)(struct bus_type___189 *, const char *, size_t);
};

struct device_attribute___189;

struct driver_attribute___189;

struct subsys_private___4;

struct bus_type___189 {
	const char *name;
	const char *dev_name;
	struct device___189 *dev_root;
	struct bus_attribute___189 *bus_attrs;
	struct device_attribute___189 *dev_attrs;
	struct driver_attribute___189 *drv_attrs;
	const struct attribute_group___14 **bus_groups;
	const struct attribute_group___14 **dev_groups;
	const struct attribute_group___14 **drv_groups;
	int (*match)(struct device___189 *, struct device_driver___189 *);
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	int (*probe)(struct device___189 *);
	int (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*online)(struct device___189 *);
	int (*offline)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___4 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct device___189 *, struct device_attribute___189 *, char *);
	ssize_t (*store)(struct device___189 *, struct device_attribute___189 *, const char *, size_t);
};

struct driver_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___189 *, char *);
	ssize_t (*store)(struct device_driver___189 *, const char *, size_t);
};

struct driver_private___4;

struct device_driver___189 {
	const char *name;
	struct bus_type___189 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___189 *);
	int (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	const struct attribute_group___14 **groups;
	const struct dev_pm_ops___189 *pm;
	struct driver_private___4 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___4 {
	struct kset subsys;
	struct kset *devices_kset;
	struct list_head interfaces;
	struct mutex___21 mutex;
	struct kset *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___189 *bus;
	struct kset glue_dirs;
	struct class___189 *class;
};

struct device_type___189 {
	const char *name;
	const struct attribute_group___14 **groups;
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
};

struct driver_private___4 {
	struct kobject kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___9 *mkobj;
	struct device_driver___189 *driver;
};

struct class_attribute___189;

struct class___189 {
	const char *name;
	struct module___10 *owner;
	struct class_attribute___189 *class_attrs;
	struct device_attribute___189 *dev_attrs;
	const struct attribute_group___14 **dev_groups;
	struct bin_attribute___14 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *);
	void (*class_release)(struct class___189 *);
	void (*dev_release)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
	struct subsys_private___4 *p;
};

struct class_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct class___189 *, struct class_attribute___189 *, char *);
	ssize_t (*store)(struct class___189 *, struct class_attribute___189 *, const char *, size_t);
	const void * (*namespace)(struct class___189 *, const struct class_attribute___189 *);
};

struct acpi_scan_handler___24;

struct acpi_hotplug_context___24;

struct acpi_driver___24;

struct acpi_device___24 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___24 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___24 *handler;
	struct acpi_hotplug_context___24 *hp;
	struct acpi_driver___24 *driver;
	void *driver_data;
	struct device___189 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___21 physical_node_lock;
	void (*remove)(struct acpi_device___24 *);
};

struct device_private___4 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___189 *device;
};

struct device_rh___189 {
	struct dev_pm_info_rh___189 power;
};

struct cpu___2 {
	int node_id;
	int hotpluggable;
	struct device___189 dev;
};

struct acpi_hotplug_profile___24 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___24 *);
	void (*notify_online)(struct acpi_device___24 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___24 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___24 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___24 *);
	void (*bind)(struct device___189 *);
	void (*unbind)(struct device___189 *);
	struct acpi_hotplug_profile___24 hotplug;
};

struct acpi_hotplug_context___24 {
	struct acpi_device___24 *self;
	int (*notify)(struct acpi_device___24 *, u32);
	void (*uevent)(struct acpi_device___24 *, u32);
	void (*fixup)(struct acpi_device___24 *);
};

typedef int (*acpi_op_add___24)(struct acpi_device___24 *);

typedef int (*acpi_op_remove___24)(struct acpi_device___24 *);

typedef void (*acpi_op_notify___24)(struct acpi_device___24 *, u32);

struct acpi_device_ops___24 {
	acpi_op_add___24 add;
	acpi_op_remove___24 remove;
	acpi_op_notify___24 notify;
};

struct acpi_driver___24 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___24 ops;
	struct device_driver___189 drv;
	struct module___10 *owner;
};

struct cpu_attr {
	struct device_attribute___189 attr;
	const struct cpumask * const * const map;
};

typedef struct kobject___22 *kobj_probe_t___3(dev_t, int *, void *);

struct probe {
	struct probe *next;
	dev_t dev;
	long unsigned int range;
	struct module___121 *owner;
	kobj_probe_t___3 *get;
	int (*lock)(dev_t, void *);
	void *data;
};

struct kobj_map___2 {
	struct probe *probes[255];
	struct mutex___210 *lock;
};

typedef void (*dr_release_t___6)(struct device___188 *, void *);

typedef int (*dr_match_t___6)(struct device___188 *, void *, void *);

struct devres_node {
	struct list_head entry;
	dr_release_t___6 release;
};

struct devres {
	struct devres_node node;
	long long unsigned int data[0];
};

struct devres_group {
	struct devres_node node[2];
	void *id;
	int color;
};

struct action_devres {
	void *data;
	void (*action)(void *);
};

struct attribute_container {
	struct list_head node;
	struct klist containers;
	struct class___188 *class;
	const struct attribute_group___158 *grp;
	struct device_attribute___188 **attrs;
	int (*match)(struct attribute_container *, struct device___188 *);
	long unsigned int flags;
};

struct internal_container {
	struct klist_node node;
	struct attribute_container *cont;
	struct device___188 classdev;
};

struct transport_container;

struct transport_class {
	struct class___188 class;
	int (*setup)(struct transport_container *, struct device___188 *, struct device___188 *);
	int (*configure)(struct transport_container *, struct device___188 *, struct device___188 *);
	int (*remove)(struct transport_container *, struct device___188 *, struct device___188 *);
};

struct transport_container {
	struct attribute_container ac;
	const struct attribute_group___158 *statistics;
};

struct anon_transport_class {
	struct transport_class tclass;
	struct attribute_container container;
};

struct page___208;

typedef struct page___208 *pgtable_t___208;

struct address_space___209;

struct kmem_cache___194;

struct page___208 {
	long unsigned int flags;
	struct address_space___209 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___208 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___208 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___194 *slab_cache;
		struct page___208 *first_page;
	};
	long: 64;
};

struct thread_struct___80;

struct task_struct___210;

struct pv_cpu_ops___210 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___80 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___80 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___210 *);
	void (*end_context_switch)(struct task_struct___210 *);
};

struct perf_event___80;

struct thread_struct___80 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___80 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___90;

struct pid_link___90 {
	struct hlist_node node;
	struct pid___90 *pid;
};

struct mutex___211 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___210 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___203 {
	struct page___208 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___217;

struct nsproxy___111;

struct signal_struct___210;

struct css_set___126;

struct perf_event_context___80;

struct task_struct___210 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___210 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___217 *mm;
	struct mm_struct___217 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___210 *real_parent;
	struct task_struct___210 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___210 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___90 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___210 = 0,
		VTIME_USER___210 = 1,
		VTIME_SYS___210 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___80 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___111 *nsproxy;
	struct signal_struct___210 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___126 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___80 *perf_event_ctxp[2];
	struct mutex___211 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___203 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___217 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___217 *, struct mm_struct___217 *);
	void (*dup_mmap)(struct mm_struct___217 *, struct mm_struct___217 *);
	void (*exit_mmap)(struct mm_struct___217 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___217 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___217 *);
	void (*pgd_free)(struct mm_struct___217 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___217 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___217 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___217 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___217 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___217 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___217 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___217 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___217 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___217 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___217 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___217 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___211 lock;
	void *vdso;
} mm_context_t___211;

struct xol_area___208;

struct uprobes_state___208 {
	struct xol_area___208 *xol_area;
};

struct vm_area_struct___217;

struct file___209;

struct core_state___210;

struct mm_struct___217 {
	struct vm_area_struct___217 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___217 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___217 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___211 context;
	long unsigned int flags;
	struct core_state___210 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___210 *owner;
	struct file___209 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___208 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___80 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___210 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___210 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___210 *target;
};

typedef void (*perf_overflow_handler_t___80)(struct perf_event___80 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___80;

typedef void (*ftrace_func_t___80)(long unsigned int, long unsigned int, struct ftrace_ops___80 *, struct pt_regs *);

struct ftrace_ops___80 {
	ftrace_func_t___80 func;
	struct ftrace_ops___80 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___211 regex_lock;
};

struct pmu___80;

struct fasync_struct___209;

struct pid_namespace___90;

struct ftrace_event_call___69;

struct perf_cgroup___80;

struct perf_event___80 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___80 *group_leader;
	struct pmu___80 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___80 hw;
	struct perf_event_context___80 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___211 child_mutex;
	struct list_head child_list;
	struct perf_event___80 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___210 *owner;
	struct mutex___211 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___209 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___80 *);
	struct callback_head callback_head;
	struct pid_namespace___90 *ns;
	u64 id;
	perf_overflow_handler_t___80 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___69 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___80 ftrace_ops;
	struct perf_cgroup___80 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct irq_data___137;

struct x86_io_apic_ops___137 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___137 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___137;

struct irq_data___137 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___137 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___190;

struct dev_pm_ops___190 {
	int (*prepare)(struct device___190 *);
	void (*complete)(struct device___190 *);
	int (*suspend)(struct device___190 *);
	int (*resume)(struct device___190 *);
	int (*freeze)(struct device___190 *);
	int (*thaw)(struct device___190 *);
	int (*poweroff)(struct device___190 *);
	int (*restore)(struct device___190 *);
	int (*suspend_late)(struct device___190 *);
	int (*resume_early)(struct device___190 *);
	int (*freeze_late)(struct device___190 *);
	int (*thaw_early)(struct device___190 *);
	int (*poweroff_late)(struct device___190 *);
	int (*restore_early)(struct device___190 *);
	int (*suspend_noirq)(struct device___190 *);
	int (*resume_noirq)(struct device___190 *);
	int (*freeze_noirq)(struct device___190 *);
	int (*thaw_noirq)(struct device___190 *);
	int (*poweroff_noirq)(struct device___190 *);
	int (*restore_noirq)(struct device___190 *);
	int (*runtime_suspend)(struct device___190 *);
	int (*runtime_resume)(struct device___190 *);
	int (*runtime_idle)(struct device___190 *);
};

struct device_private___5;

struct device_type___190;

struct bus_type___190;

struct device_driver___190;

struct dev_pm_domain___190;

struct class___190;

struct attribute_group___167;

struct device_rh___190;

struct device___190 {
	struct device___190 *parent;
	struct device_private___5 *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___190 *type;
	struct mutex___211 mutex;
	struct bus_type___190 *bus;
	struct device_driver___190 *driver;
	void *platform_data;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___190 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___79 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___190 *class;
	const struct attribute_group___167 **groups;
	void (*release)(struct device___190 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___190 *device_rh;
};

struct dev_pm_info_rh___190 {
	void (*set_latency_tolerance)(struct device___190 *, s32);
};

struct dev_pm_domain___190 {
	struct dev_pm_ops___190 ops;
};

struct smp_ops___210 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___210 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___210;

struct lruvec___210 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___210 *zone;
};

struct pglist_data___210;

struct zone___210 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___210 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___210 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___210 {
	struct zone___210 *zone;
	int zone_idx;
};

struct zonelist___210 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___210 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___210 {
	struct zone___210 node_zones[4];
	struct zonelist___210 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___210 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct super_block___209;

struct dquot___209 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___211 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___209 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___209;

struct mem_dqinfo___209 {
	struct quota_format_type___209 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct inode___209;

struct quota_format_ops___209;

struct quota_info___209 {
	unsigned int flags;
	struct mutex___211 dqio_mutex;
	struct mutex___211 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___209 *files[2];
	struct mem_dqinfo___209 info[2];
	const struct quota_format_ops___209 *ops[2];
};

struct file_system_type___209;

struct super_operations___209;

struct dquot_operations___209;

struct quotactl_ops___209;

struct dentry___209;

struct xattr_handler___127;

struct block_device___209;

struct dentry_operations___209;

struct super_block___209 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___209 *s_type;
	const struct super_operations___209 *s_op;
	const struct dquot_operations___209 *dq_op;
	const struct quotactl_ops___209 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___209 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___127 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___209 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___209 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___211 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___209 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct quota_format_type___209 {
	int qf_fmt_id;
	const struct quota_format_ops___209 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___209 *qf_next;
};

struct quota_format_ops___209 {
	int (*check_quota_file)(struct super_block___209 *, int);
	int (*read_file_info)(struct super_block___209 *, int);
	int (*write_file_info)(struct super_block___209 *, int);
	int (*free_file_info)(struct super_block___209 *, int);
	int (*read_dqblk)(struct dquot___209 *);
	int (*commit_dqblk)(struct dquot___209 *);
	int (*release_dqblk)(struct dquot___209 *);
};

struct dquot_operations___209 {
	int (*write_dquot)(struct dquot___209 *);
	struct dquot___209 * (*alloc_dquot)(struct super_block___209 *, int);
	void (*destroy_dquot)(struct dquot___209 *);
	int (*acquire_dquot)(struct dquot___209 *);
	int (*release_dquot)(struct dquot___209 *);
	int (*mark_dirty)(struct dquot___209 *);
	int (*write_info)(struct super_block___209 *, int);
	qsize_t * (*get_reserved_space)(struct inode___209 *);
};

struct address_space_operations___209;

struct address_space___209 {
	struct inode___209 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___211 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___209 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___209;

struct file_operations___209;

struct file_lock___209;

struct inode___209 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___209 *i_op;
	struct super_block___209 *i_sb;
	struct address_space___209 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___211 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___209 *i_fop;
	struct file_lock___209 *i_flock;
	struct address_space___209 i_data;
	struct dquot___209 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___209 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___209;

struct quotactl_ops___209 {
	int (*quota_on)(struct super_block___209 *, int, int, struct path___209 *);
	int (*quota_on_meta)(struct super_block___209 *, int, int);
	int (*quota_off)(struct super_block___209 *, int);
	int (*quota_sync)(struct super_block___209 *, int);
	int (*get_info)(struct super_block___209 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___209 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___209 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___209 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___209 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___209 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___209 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___209 *, unsigned int);
};

struct vfsmount___43;

struct path___209 {
	struct vfsmount___43 *mnt;
	struct dentry___209 *dentry;
};

struct nsproxy___111 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___90 *pid_ns;
	struct net *net_ns;
};

struct xol_area___208 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___208 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___193;

struct memcg_cache_params___194;

struct kmem_cache___194 {
	struct kmem_cache_cpu___193 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___194 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct fown_struct___90 {
	rwlock_t lock;
	struct pid___90 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___209 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___209 f_path;
	struct inode___209 *f_inode;
	const struct file_operations___209 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___209 *f_mapping;
	struct mutex___211 f_pos_lock;
};

struct vm_operations_struct___189;

struct vm_area_struct___217 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___217 *vm_next;
	struct vm_area_struct___217 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___217 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___189 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___209 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___185;

struct vm_operations_struct___189 {
	void (*open)(struct vm_area_struct___217 *);
	void (*close)(struct vm_area_struct___217 *);
	int (*fault)(struct vm_area_struct___217 *, struct vm_fault___185 *);
	int (*page_mkwrite)(struct vm_area_struct___217 *, struct vm_fault___185 *);
	int (*access)(struct vm_area_struct___217 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___217 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___217 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___217 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___217 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___210 {
	struct task_struct___210 *task;
	struct core_thread___210 *next;
};

struct core_state___210 {
	atomic_t nr_threads;
	struct core_thread___210 dumper;
	struct completion startup;
};

struct vm_fault___185 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___208 *page;
};

struct seq_operations___141;

struct seq_file___141 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___211 lock;
	const struct seq_operations___141 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___141 {
	void * (*start)(struct seq_file___141 *, loff_t *);
	void (*stop)(struct seq_file___141 *, void *);
	void * (*next)(struct seq_file___141 *, void *, loff_t *);
	int (*show)(struct seq_file___141 *, void *);
};

struct dentry___209 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___209 *d_parent;
	struct qstr d_name;
	struct inode___209 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___209 *d_op;
	struct super_block___209 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct dentry_operations___209 {
	int (*d_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_hash)(const struct dentry___209 *, struct qstr *);
	int (*d_compare)(const struct dentry___209 *, const struct dentry___209 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___209 *);
	void (*d_release)(struct dentry___209 *);
	void (*d_prune)(struct dentry___209 *);
	void (*d_iput)(struct dentry___209 *, struct inode___209 *);
	char * (*d_dname)(struct dentry___209 *, char *, int);
	struct vfsmount___43 * (*d_automount)(struct path___209 *);
	int (*d_manage)(struct dentry___209 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___43 {
	struct dentry___209 *mnt_root;
	struct super_block___209 *mnt_sb;
	int mnt_flags;
};

struct upid___90 {
	int nr;
	struct pid_namespace___90 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___90 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___210 *child_reaper;
	struct kmem_cache___194 *pid_cachep;
	unsigned int level;
	struct pid_namespace___90 *parent;
	struct vfsmount___43 *proc_mnt;
	struct dentry___209 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___90 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___90 numbers[1];
};

struct hd_struct___43;

struct gendisk___43;

struct block_device___209 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___209 *bd_inode;
	struct super_block___209 *bd_super;
	struct mutex___211 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___209 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___43 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___43 *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___211 bd_fsfreeze_mutex;
};

struct cgroup___126;

struct cgroup_subsys_state___126 {
	struct cgroup___126 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___209 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___209 *ia_file;
};

struct swap_info_struct___45;

struct address_space_operations___209 {
	int (*writepage)(struct page___208 *, struct writeback_control *);
	int (*readpage)(struct file___209 *, struct page___208 *);
	int (*writepages)(struct address_space___209 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___208 *);
	int (*readpages)(struct file___209 *, struct address_space___209 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___209 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___208 **, void **);
	int (*write_end)(struct file___209 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___208 *, void *);
	sector_t (*bmap)(struct address_space___209 *, sector_t);
	void (*invalidatepage)(struct page___208 *, long unsigned int);
	int (*releasepage)(struct page___208 *, gfp_t);
	void (*freepage)(struct page___208 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___209 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___209 *, struct page___208 *, struct page___208 *, enum migrate_mode);
	int (*launder_page)(struct page___208 *);
	int (*is_partially_uptodate)(struct page___208 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___208 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___209 *, struct page___208 *);
	int (*swap_activate)(struct swap_info_struct___45 *, struct file___209 *, sector_t *);
	void (*swap_deactivate)(struct file___209 *);
	void (*invalidatepage_range)(struct page___208 *, unsigned int, unsigned int);
};

struct swap_info_struct___45 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___209 *bdev;
	struct file___209 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct hd_struct___43 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___190 __dev;
	struct kobject___22 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___43;

struct gendisk___43 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___43 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___43 *part_tbl;
	struct hd_struct___43 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct device___190 *driverfs_dev;
	struct kobject___22 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct nameidata___26;

struct inode_operations___209 {
	struct dentry___209 * (*lookup)(struct inode___209 *, struct dentry___209 *, unsigned int);
	void * (*follow_link)(struct dentry___209 *, struct nameidata___26 *);
	int (*permission)(struct inode___209 *, int);
	struct posix_acl * (*get_acl)(struct inode___209 *, int);
	int (*readlink)(struct dentry___209 *, char *, int);
	void (*put_link)(struct dentry___209 *, struct nameidata___26 *, void *);
	int (*create)(struct inode___209 *, struct dentry___209 *, umode_t, bool);
	int (*link)(struct dentry___209 *, struct inode___209 *, struct dentry___209 *);
	int (*unlink)(struct inode___209 *, struct dentry___209 *);
	int (*symlink)(struct inode___209 *, struct dentry___209 *, const char *);
	int (*mkdir)(struct inode___209 *, struct dentry___209 *, umode_t);
	int (*rmdir)(struct inode___209 *, struct dentry___209 *);
	int (*mknod)(struct inode___209 *, struct dentry___209 *, umode_t, dev_t);
	int (*rename)(struct inode___209 *, struct dentry___209 *, struct inode___209 *, struct dentry___209 *);
	int (*setattr)(struct dentry___209 *, struct iattr___209 *);
	int (*getattr)(struct vfsmount___43 *, struct dentry___209 *, struct kstat *);
	int (*setxattr)(struct dentry___209 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___209 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___209 *, char *, size_t);
	int (*removexattr)(struct dentry___209 *, const char *);
	int (*fiemap)(struct inode___209 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___209 *, struct timespec *, int);
	int (*atomic_open)(struct inode___209 *, struct dentry___209 *, struct file___209 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___116;

struct file_operations___209 {
	struct module *owner;
	loff_t (*llseek)(struct file___209 *, loff_t, int);
	ssize_t (*read)(struct file___209 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___209 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___209 *, void *, filldir_t);
	unsigned int (*poll)(struct file___209 *, struct poll_table_struct___116 *);
	long int (*unlocked_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___209 *, struct vm_area_struct___217 *);
	int (*open)(struct inode___209 *, struct file___209 *);
	int (*flush)(struct file___209 *, fl_owner_t);
	int (*release)(struct inode___209 *, struct file___209 *);
	int (*fsync)(struct file___209 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___209 *, int);
	int (*lock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*sendpage)(struct file___209 *, struct page___208 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___209 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___209 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___209 *, long int, struct file_lock___209 **, void **);
		struct {
			int (*setlease)(struct file___209 *, long int, struct file_lock___209 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___209 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___141 *, struct file___209 *);
};

struct file_lock_operations___209;

struct lock_manager_operations___209;

struct file_lock___209 {
	struct file_lock___209 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___90 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___209 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___209 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___209 *fl_ops;
	const struct lock_manager_operations___209 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___209 {
	void (*fl_copy_lock)(struct file_lock___209 *, struct file_lock___209 *);
	void (*fl_release_private)(struct file_lock___209 *);
};

struct lock_manager_operations___209 {
	int (*lm_compare_owner)(struct file_lock___209 *, struct file_lock___209 *);
	long unsigned int (*lm_owner_key)(struct file_lock___209 *);
	void (*lm_notify)(struct file_lock___209 *);
	int (*lm_grant)(struct file_lock___209 *, struct file_lock___209 *, int);
	void (*lm_break)(struct file_lock___209 *);
	int (*lm_change)(struct file_lock___209 **, int);
};

struct fasync_struct___209 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___209 *fa_next;
	struct file___209 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___209 {
	const char *name;
	int fs_flags;
	struct dentry___209 * (*mount)(struct file_system_type___209 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___209 *);
	struct module *owner;
	struct file_system_type___209 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___209 {
	struct inode___209 * (*alloc_inode)(struct super_block___209 *);
	void (*destroy_inode)(struct inode___209 *);
	void (*dirty_inode)(struct inode___209 *, int);
	int (*write_inode)(struct inode___209 *, struct writeback_control *);
	int (*drop_inode)(struct inode___209 *);
	void (*evict_inode)(struct inode___209 *);
	void (*put_super)(struct super_block___209 *);
	int (*sync_fs)(struct super_block___209 *, int);
	int (*freeze_fs)(struct super_block___209 *);
	int (*unfreeze_fs)(struct super_block___209 *);
	int (*statfs)(struct dentry___209 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___209 *, int *, char *);
	void (*umount_begin)(struct super_block___209 *);
	int (*show_options)(struct seq_file___141 *, struct dentry___209 *);
	int (*show_devname)(struct seq_file___141 *, struct dentry___209 *);
	int (*show_path)(struct seq_file___141 *, struct dentry___209 *);
	int (*show_stats)(struct seq_file___141 *, struct dentry___209 *);
	ssize_t (*quota_read)(struct super_block___209 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___209 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___209 *);
	int (*bdev_try_to_free_page)(struct super_block___209 *, struct page___208 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___209 *);
	void (*free_cached_objects)(struct super_block___209 *, int);
};

struct xattr_handler___127 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___209 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___209 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___209 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___118)(struct file___209 *, wait_queue_head_t *, struct poll_table_struct___116 *);

struct poll_table_struct___116 {
	poll_queue_proc___118 _qproc;
	long unsigned int _key;
};

struct nameidata___26 {
	struct path___209 path;
	struct qstr last;
	struct path___209 root;
	struct inode___209 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct irq_chip___137 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___137 *);
	void (*irq_shutdown)(struct irq_data___137 *);
	void (*irq_enable)(struct irq_data___137 *);
	void (*irq_disable)(struct irq_data___137 *);
	void (*irq_ack)(struct irq_data___137 *);
	void (*irq_mask)(struct irq_data___137 *);
	void (*irq_mask_ack)(struct irq_data___137 *);
	void (*irq_unmask)(struct irq_data___137 *);
	void (*irq_eoi)(struct irq_data___137 *);
	int (*irq_set_affinity)(struct irq_data___137 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___137 *);
	int (*irq_set_type)(struct irq_data___137 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___137 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___137 *);
	void (*irq_bus_sync_unlock)(struct irq_data___137 *);
	void (*irq_cpu_online)(struct irq_data___137 *);
	void (*irq_cpu_offline)(struct irq_data___137 *);
	void (*irq_suspend)(struct irq_data___137 *);
	void (*irq_resume)(struct irq_data___137 *);
	void (*irq_pm_shutdown)(struct irq_data___137 *);
	void (*irq_print_chip)(struct irq_data___137 *, struct seq_file___141 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___137 *, void *);
	long unsigned int flags;
};

struct signal_struct___210 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___210 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___210 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___90 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___211 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___126 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___126 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___80 {
	struct pmu___80 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___211 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___210 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___80 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct bin_attribute___169;

struct attribute_group___167 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___169 **bin_attrs;
};

struct bin_attribute___169 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___209 *, struct kobject___22 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___209 *, struct kobject___22 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	int (*mmap)(struct file___209 *, struct kobject___22 *, struct bin_attribute___169 *, struct vm_area_struct___217 *);
};

struct bus_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___190 *, char *);
	ssize_t (*store)(struct bus_type___190 *, const char *, size_t);
};

struct device_attribute___190;

struct driver_attribute___190;

struct subsys_private___5;

struct bus_type___190 {
	const char *name;
	const char *dev_name;
	struct device___190 *dev_root;
	struct bus_attribute___190 *bus_attrs;
	struct device_attribute___190 *dev_attrs;
	struct driver_attribute___190 *drv_attrs;
	const struct attribute_group___167 **bus_groups;
	const struct attribute_group___167 **dev_groups;
	const struct attribute_group___167 **drv_groups;
	int (*match)(struct device___190 *, struct device_driver___190 *);
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	int (*probe)(struct device___190 *);
	int (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*online)(struct device___190 *);
	int (*offline)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___5 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct device___190 *, struct device_attribute___190 *, char *);
	ssize_t (*store)(struct device___190 *, struct device_attribute___190 *, const char *, size_t);
};

struct driver_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___190 *, char *);
	ssize_t (*store)(struct device_driver___190 *, const char *, size_t);
};

struct driver_private___5;

struct device_driver___190 {
	const char *name;
	struct bus_type___190 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___190 *);
	int (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	const struct attribute_group___167 **groups;
	const struct dev_pm_ops___190 *pm;
	struct driver_private___5 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___5 {
	struct kset___22 subsys;
	struct kset___22 *devices_kset;
	struct list_head interfaces;
	struct mutex___211 mutex;
	struct kset___22 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___190 *bus;
	struct kset___22 glue_dirs;
	struct class___190 *class;
};

struct device_type___190 {
	const char *name;
	const struct attribute_group___167 **groups;
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
};

struct driver_private___5 {
	struct kobject___22 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___113 *mkobj;
	struct device_driver___190 *driver;
};

struct class_attribute___190;

struct class___190 {
	const char *name;
	struct module *owner;
	struct class_attribute___190 *class_attrs;
	struct device_attribute___190 *dev_attrs;
	const struct attribute_group___167 **dev_groups;
	struct bin_attribute___169 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *);
	void (*class_release)(struct class___190 *);
	void (*dev_release)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
	struct subsys_private___5 *p;
};

struct class_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct class___190 *, struct class_attribute___190 *, char *);
	ssize_t (*store)(struct class___190 *, struct class_attribute___190 *, const char *, size_t);
	const void * (*namespace)(struct class___190 *, const struct class_attribute___190 *);
};

struct device_private___5 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___190 *device;
};

struct device_rh___190 {
	struct dev_pm_info_rh___190 power;
};

struct kmem_cache_cpu___193 {
	void **freelist;
	long unsigned int tid;
	struct page___208 *page;
	struct page___208 *partial;
};

struct memcg_cache_params___194 {
	bool is_root_cache;
	union {
		struct kmem_cache___194 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___194 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___126;

struct cgroup___126 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___126 *parent;
	struct dentry___209 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___126 *subsys[11];
	struct cgroupfs_root___126 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___211 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___126 {
	struct super_block___209 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___126 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___70 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___209 *, struct file___209 *);
	ssize_t (*read)(struct cgroup___126 *, struct cftype___70 *, struct file___209 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___126 *, struct cftype___70 *);
	s64 (*read_s64)(struct cgroup___126 *, struct cftype___70 *);
	int (*read_map)(struct cgroup___126 *, struct cftype___70 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___126 *, struct cftype___70 *, struct seq_file___141 *);
	ssize_t (*write)(struct cgroup___126 *, struct cftype___70 *, struct file___209 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___126 *, struct cftype___70 *, u64);
	int (*write_s64)(struct cgroup___126 *, struct cftype___70 *, s64);
	int (*write_string)(struct cgroup___126 *, struct cftype___70 *, const char *);
	int (*trigger)(struct cgroup___126 *, unsigned int);
	int (*release)(struct inode___209 *, struct file___209 *);
	int (*register_event)(struct cgroup___126 *, struct cftype___70 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___126 *, struct cftype___70 *, struct eventfd_ctx *);
};

struct cftype_set___66 {
	struct list_head node;
	struct cftype___70 *cfts;
};

struct task_and_cgroup___66 {
	struct task_struct___210 *task;
	struct cgroup___126 *cgrp;
	struct css_set___126 *cg;
};

struct cgroup_taskset___66 {
	struct task_and_cgroup___66 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___126 *cur_cgrp;
};

struct cgroup_subsys___66 {
	struct cgroup_subsys_state___126 * (*css_alloc)(struct cgroup___126 *);
	int (*css_online)(struct cgroup___126 *);
	void (*css_offline)(struct cgroup___126 *);
	void (*css_free)(struct cgroup___126 *);
	int (*can_attach)(struct cgroup___126 *, struct cgroup_taskset___66 *);
	void (*cancel_attach)(struct cgroup___126 *, struct cgroup_taskset___66 *);
	void (*attach)(struct cgroup___126 *, struct cgroup_taskset___66 *);
	void (*fork)(struct task_struct___210 *);
	void (*exit)(struct cgroup___126 *, struct cgroup___126 *, struct task_struct___210 *);
	void (*bind)(struct cgroup___126 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___126 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___70 *base_cftypes;
	struct cftype_set___66 base_cftset;
	struct module *module;
};

struct perf_cpu_context___80;

struct pmu___80 {
	struct list_head entry;
	struct device___190 *dev;
	const struct attribute_group___167 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___80 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___80 *);
	void (*pmu_disable)(struct pmu___80 *);
	int (*event_init)(struct perf_event___80 *);
	int (*add)(struct perf_event___80 *, int);
	void (*del)(struct perf_event___80 *, int);
	void (*start)(struct perf_event___80 *, int);
	void (*stop)(struct perf_event___80 *, int);
	void (*read)(struct perf_event___80 *);
	void (*start_txn)(struct pmu___80 *);
	int (*commit_txn)(struct pmu___80 *);
	void (*cancel_txn)(struct pmu___80 *);
	int (*event_idx)(struct perf_event___80 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___80 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___80 *);
};

struct perf_cpu_context___80 {
	struct perf_event_context___80 ctx;
	struct perf_event_context___80 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___80 *unique_pmu;
	struct perf_cgroup___80 *cgrp;
};

struct trace_event_functions___69;

struct trace_event___69 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___69 *funcs;
};

struct ftrace_event_class___69;

struct ftrace_event_call___69 {
	struct list_head list;
	struct ftrace_event_class___69 *class;
	char *name;
	struct trace_event___69 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___80 {
	struct cgroup_subsys_state___126 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___69 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___211 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___69)(struct trace_iterator___69 *, int, struct trace_event___69 *);

struct trace_event_functions___69 {
	trace_print_func___69 trace;
	trace_print_func___69 raw;
	trace_print_func___69 hex;
	trace_print_func___69 binary;
};

struct ftrace_event_class___69 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___69 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___69 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___69 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___69 *);
};

struct disk_part_tbl___43 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___43 *last_lookup;
	struct hd_struct___43 *part[0];
};

struct req {
	struct req *next;
	struct completion done;
	int err;
	const char *name;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	struct device___190 *dev;
};

struct device___191;

struct dev_pm_ops___191 {
	int (*prepare)(struct device___191 *);
	void (*complete)(struct device___191 *);
	int (*suspend)(struct device___191 *);
	int (*resume)(struct device___191 *);
	int (*freeze)(struct device___191 *);
	int (*thaw)(struct device___191 *);
	int (*poweroff)(struct device___191 *);
	int (*restore)(struct device___191 *);
	int (*suspend_late)(struct device___191 *);
	int (*resume_early)(struct device___191 *);
	int (*freeze_late)(struct device___191 *);
	int (*thaw_early)(struct device___191 *);
	int (*poweroff_late)(struct device___191 *);
	int (*restore_early)(struct device___191 *);
	int (*suspend_noirq)(struct device___191 *);
	int (*resume_noirq)(struct device___191 *);
	int (*freeze_noirq)(struct device___191 *);
	int (*thaw_noirq)(struct device___191 *);
	int (*poweroff_noirq)(struct device___191 *);
	int (*restore_noirq)(struct device___191 *);
	int (*runtime_suspend)(struct device___191 *);
	int (*runtime_resume)(struct device___191 *);
	int (*runtime_idle)(struct device___191 *);
};

struct dev_pm_qos___32;

struct dev_pm_info___32 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___32 *qos;
};

struct device_private___6;

struct device_type___191;

struct bus_type___191;

struct device_driver___191;

struct dev_pm_domain___191;

struct class___191;

struct device_rh___191;

struct device___191 {
	struct device___191 *parent;
	struct device_private___6 *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___191 *type;
	struct mutex___91 mutex;
	struct bus_type___191 *bus;
	struct device_driver___191 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___191 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___79 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___191 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___191 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___191 *device_rh;
};

struct dev_pm_qos_request___32;

struct dev_pm_qos___32 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___32 *latency_req;
	struct dev_pm_qos_request___32 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___32 *latency_tolerance_req;
};

struct dev_pm_info_rh___191 {
	void (*set_latency_tolerance)(struct device___191 *, s32);
};

struct dev_pm_domain___191 {
	struct dev_pm_ops___191 ops;
};

struct bus_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___191 *, char *);
	ssize_t (*store)(struct bus_type___191 *, const char *, size_t);
};

struct device_attribute___191;

struct driver_attribute___191;

struct subsys_private___6;

struct bus_type___191 {
	const char *name;
	const char *dev_name;
	struct device___191 *dev_root;
	struct bus_attribute___191 *bus_attrs;
	struct device_attribute___191 *dev_attrs;
	struct driver_attribute___191 *drv_attrs;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___191 *, struct device_driver___191 *);
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	int (*probe)(struct device___191 *);
	int (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*online)(struct device___191 *);
	int (*offline)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___6 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct device___191 *, struct device_attribute___191 *, char *);
	ssize_t (*store)(struct device___191 *, struct device_attribute___191 *, const char *, size_t);
};

struct driver_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___191 *, char *);
	ssize_t (*store)(struct device_driver___191 *, const char *, size_t);
};

struct driver_private___6;

struct device_driver___191 {
	const char *name;
	struct bus_type___191 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___191 *);
	int (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___191 *pm;
	struct driver_private___6 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___6 {
	struct kset subsys;
	struct kset *devices_kset;
	struct list_head interfaces;
	struct mutex___91 mutex;
	struct kset *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___191 *bus;
	struct kset glue_dirs;
	struct class___191 *class;
};

struct device_type___191 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
};

struct driver_private___6 {
	struct kobject kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___113 *mkobj;
	struct device_driver___191 *driver;
};

struct class_attribute___191;

struct class___191 {
	const char *name;
	struct module *owner;
	struct class_attribute___191 *class_attrs;
	struct device_attribute___191 *dev_attrs;
	const struct attribute_group___62 **dev_groups;
	struct bin_attribute___62 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *);
	void (*class_release)(struct class___191 *);
	void (*dev_release)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
	struct subsys_private___6 *p;
};

struct class_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct class___191 *, struct class_attribute___191 *, char *);
	ssize_t (*store)(struct class___191 *, struct class_attribute___191 *, const char *, size_t);
	const void * (*namespace)(struct class___191 *, const struct class_attribute___191 *);
};

struct device_private___6 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___191 *device;
};

struct device_rh___191 {
	struct dev_pm_info_rh___191 power;
};

struct dev_pm_qos_request___32 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___191 *dev;
};

typedef int (*pm_callback_t)(struct device___191 *);

struct dma_devres {
	size_t size;
	void *vaddr;
	dma_addr_t dma_handle;
};

struct device___192;

struct dev_pm_ops___192 {
	int (*prepare)(struct device___192 *);
	void (*complete)(struct device___192 *);
	int (*suspend)(struct device___192 *);
	int (*resume)(struct device___192 *);
	int (*freeze)(struct device___192 *);
	int (*thaw)(struct device___192 *);
	int (*poweroff)(struct device___192 *);
	int (*restore)(struct device___192 *);
	int (*suspend_late)(struct device___192 *);
	int (*resume_early)(struct device___192 *);
	int (*freeze_late)(struct device___192 *);
	int (*thaw_early)(struct device___192 *);
	int (*poweroff_late)(struct device___192 *);
	int (*restore_early)(struct device___192 *);
	int (*suspend_noirq)(struct device___192 *);
	int (*resume_noirq)(struct device___192 *);
	int (*freeze_noirq)(struct device___192 *);
	int (*thaw_noirq)(struct device___192 *);
	int (*poweroff_noirq)(struct device___192 *);
	int (*restore_noirq)(struct device___192 *);
	int (*runtime_suspend)(struct device___192 *);
	int (*runtime_resume)(struct device___192 *);
	int (*runtime_idle)(struct device___192 *);
};

struct dma_map_ops___80;

struct dev_archdata___80 {
	struct dma_map_ops___80 *dma_ops;
	void *iommu;
};

struct device_type___192;

struct bus_type___192;

struct device_driver___192;

struct dev_pm_domain___192;

struct class___192;

struct device_rh___192;

struct device___192 {
	struct device___192 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___192 *type;
	struct mutex___101 mutex;
	struct bus_type___192 *bus;
	struct device_driver___192 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___192 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___80 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___21 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___192 *class;
	const struct attribute_group___72 **groups;
	void (*release)(struct device___192 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___192 *device_rh;
};

struct dev_pm_info_rh___192 {
	void (*set_latency_tolerance)(struct device___192 *, s32);
};

struct dev_pm_domain___192 {
	struct dev_pm_ops___192 ops;
};

struct dma_map_ops___80 {
	void * (*alloc)(struct device___192 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___192 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___192 *, struct vm_area_struct___105 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___192 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___192 *, struct page___100 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___192 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___192 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___192 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___192 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___192 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___192 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___192 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___192 *, dma_addr_t);
	int (*dma_supported)(struct device___192 *, u64);
	int (*set_dma_mask)(struct device___192 *, u64);
	int is_phys;
};

struct bus_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___192 *, char *);
	ssize_t (*store)(struct bus_type___192 *, const char *, size_t);
};

struct device_attribute___192;

struct driver_attribute___192;

struct bus_type___192 {
	const char *name;
	const char *dev_name;
	struct device___192 *dev_root;
	struct bus_attribute___192 *bus_attrs;
	struct device_attribute___192 *dev_attrs;
	struct driver_attribute___192 *drv_attrs;
	const struct attribute_group___72 **bus_groups;
	const struct attribute_group___72 **dev_groups;
	const struct attribute_group___72 **drv_groups;
	int (*match)(struct device___192 *, struct device_driver___192 *);
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	int (*probe)(struct device___192 *);
	int (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*online)(struct device___192 *);
	int (*offline)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct device___192 *, struct device_attribute___192 *, char *);
	ssize_t (*store)(struct device___192 *, struct device_attribute___192 *, const char *, size_t);
};

struct driver_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___192 *, char *);
	ssize_t (*store)(struct device_driver___192 *, const char *, size_t);
};

struct device_driver___192 {
	const char *name;
	struct bus_type___192 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___192 *);
	int (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	const struct attribute_group___72 **groups;
	const struct dev_pm_ops___192 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___192 {
	const char *name;
	const struct attribute_group___72 **groups;
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
};

struct class_attribute___192;

struct class___192 {
	const char *name;
	struct module *owner;
	struct class_attribute___192 *class_attrs;
	struct device_attribute___192 *dev_attrs;
	const struct attribute_group___72 **dev_groups;
	struct bin_attribute___72 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *);
	void (*class_release)(struct class___192 *);
	void (*dev_release)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
	struct subsys_private *p;
};

struct class_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct class___192 *, struct class_attribute___192 *, char *);
	ssize_t (*store)(struct class___192 *, struct class_attribute___192 *, const char *, size_t);
	const void * (*namespace)(struct class___192 *, const struct class_attribute___192 *);
};

struct device_rh___192 {
	struct dev_pm_info_rh___192 power;
};

struct fence_ops;

struct fence {
	struct kref refcount;
	const struct fence_ops *ops;
	struct callback_head rcu;
	struct list_head cb_list;
	spinlock_t *lock;
	unsigned int context;
	unsigned int seqno;
	long unsigned int flags;
	ktime_t timestamp;
	int status;
};

struct fence_ops {
	const char * (*get_driver_name)(struct fence *);
	const char * (*get_timeline_name)(struct fence *);
	bool (*enable_signaling)(struct fence *);
	bool (*signaled)(struct fence *);
	long int (*wait)(struct fence *, bool, long int);
	void (*release)(struct fence *);
	int (*fill_driver_data)(struct fence *, void *, int);
	void (*fence_value_str)(struct fence *, char *, int);
	void (*timeline_value_str)(struct fence *, char *, int);
};

struct fence_cb;

typedef void (*fence_func_t)(struct fence *, struct fence_cb *);

struct fence_cb {
	struct list_head node;
	fence_func_t func;
};

struct dma_buf;

struct dma_buf_attachment;

struct dma_buf_ops {
	int (*attach)(struct dma_buf *, struct device___192 *, struct dma_buf_attachment *);
	void (*detach)(struct dma_buf *, struct dma_buf_attachment *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf *);
	int (*begin_cpu_access)(struct dma_buf *, size_t, size_t, enum dma_data_direction);
	void (*end_cpu_access)(struct dma_buf *, size_t, size_t, enum dma_data_direction);
	void * (*kmap_atomic)(struct dma_buf *, long unsigned int);
	void (*kunmap_atomic)(struct dma_buf *, long unsigned int, void *);
	void * (*kmap)(struct dma_buf *, long unsigned int);
	void (*kunmap)(struct dma_buf *, long unsigned int, void *);
	int (*mmap)(struct dma_buf *, struct vm_area_struct___105 *);
	void * (*vmap)(struct dma_buf *);
	void (*vunmap)(struct dma_buf *, void *);
};

struct dma_buf_poll_cb_t {
	struct fence_cb cb;
	wait_queue_head_t *poll;
	long unsigned int active;
};

struct reservation_object;

struct dma_buf {
	size_t size;
	struct file___100 *file;
	struct list_head attachments;
	const struct dma_buf_ops *ops;
	struct mutex___101 lock;
	unsigned int vmapping_counter;
	void *vmap_ptr;
	const char *exp_name;
	struct list_head list_node;
	void *priv;
	struct reservation_object *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_excl;
	struct dma_buf_poll_cb_t cb_shared;
};

struct dma_buf_attachment {
	struct dma_buf *dmabuf;
	struct device___192 *dev;
	struct list_head node;
	void *priv;
};

struct ww_acquire_ctx___2;

struct ww_mutex___2 {
	struct mutex___101 base;
	struct ww_acquire_ctx___2 *ctx;
};

struct reservation_object_list;

struct reservation_object {
	struct ww_mutex___2 lock;
	seqcount_t seq;
	struct fence *fence_excl;
	struct reservation_object_list *fence;
	struct reservation_object_list *staged;
};

struct dma_buf_export_info {
	const char *exp_name;
	const struct dma_buf_ops *ops;
	size_t size;
	int flags;
	struct reservation_object *resv;
	void *priv;
};

struct ww_class {
	atomic_long_t stamp;
	struct lock_class_key acquire_key;
	struct lock_class_key mutex_key;
	const char *acquire_name;
	const char *mutex_name;
};

struct ww_acquire_ctx___2 {
	struct task_struct___100 *task;
	long unsigned int stamp;
	unsigned int acquired;
};

struct reservation_object_list {
	struct callback_head rcu;
	u32 shared_count;
	u32 shared_max;
	struct fence *shared[0];
};

struct dma_buf_list {
	struct list_head head;
	struct mutex___101 lock;
};

enum fence_flag_bits {
	FENCE_FLAG_SIGNALED_BIT = 0,
	FENCE_FLAG_ENABLE_SIGNAL_BIT = 1,
	FENCE_FLAG_USER_BITS = 2,
};

struct reservation_object___2 {
	struct ww_mutex lock;
	seqcount_t seq;
	struct fence *fence_excl;
	struct reservation_object_list *fence;
	struct reservation_object_list *staged;
};

struct ftrace_raw_fence_annotate_wait_on {
	struct trace_entry ent;
	u32 __data_loc_driver;
	u32 __data_loc_timeline;
	unsigned int context;
	unsigned int seqno;
	u32 __data_loc_waiting_driver;
	u32 __data_loc_waiting_timeline;
	unsigned int waiting_context;
	unsigned int waiting_seqno;
	char __data[0];
};

struct ftrace_raw_fence {
	struct trace_entry ent;
	u32 __data_loc_driver;
	u32 __data_loc_timeline;
	unsigned int context;
	unsigned int seqno;
	char __data[0];
};

struct ftrace_data_offsets_fence_annotate_wait_on {
	u32 driver;
	u32 timeline;
	u32 waiting_driver;
	u32 waiting_timeline;
};

struct ftrace_data_offsets_fence {
	u32 driver;
	u32 timeline;
};

struct default_wait_cb {
	struct fence_cb base;
	struct task_struct___86 *task;
};

struct device___193;

struct dev_pm_ops___193 {
	int (*prepare)(struct device___193 *);
	void (*complete)(struct device___193 *);
	int (*suspend)(struct device___193 *);
	int (*resume)(struct device___193 *);
	int (*freeze)(struct device___193 *);
	int (*thaw)(struct device___193 *);
	int (*poweroff)(struct device___193 *);
	int (*restore)(struct device___193 *);
	int (*suspend_late)(struct device___193 *);
	int (*resume_early)(struct device___193 *);
	int (*freeze_late)(struct device___193 *);
	int (*thaw_early)(struct device___193 *);
	int (*poweroff_late)(struct device___193 *);
	int (*restore_early)(struct device___193 *);
	int (*suspend_noirq)(struct device___193 *);
	int (*resume_noirq)(struct device___193 *);
	int (*freeze_noirq)(struct device___193 *);
	int (*thaw_noirq)(struct device___193 *);
	int (*poweroff_noirq)(struct device___193 *);
	int (*restore_noirq)(struct device___193 *);
	int (*runtime_suspend)(struct device___193 *);
	int (*runtime_resume)(struct device___193 *);
	int (*runtime_idle)(struct device___193 *);
};

struct device_private___7;

struct device_type___193;

struct bus_type___193;

struct device_driver___193;

struct dev_pm_domain___193;

struct class___193;

struct device_rh___193;

struct device___193 {
	struct device___193 *parent;
	struct device_private___7 *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___193 *type;
	struct mutex___76 mutex;
	struct bus_type___193 *bus;
	struct device_driver___193 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___193 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___80 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___193 *class;
	const struct attribute_group___52 **groups;
	void (*release)(struct device___193 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___193 *device_rh;
};

struct dev_pm_info_rh___193 {
	void (*set_latency_tolerance)(struct device___193 *, s32);
};

struct dev_pm_domain___193 {
	struct dev_pm_ops___193 ops;
};

struct bus_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___193 *, char *);
	ssize_t (*store)(struct bus_type___193 *, const char *, size_t);
};

struct device_attribute___193;

struct driver_attribute___193;

struct subsys_private___7;

struct bus_type___193 {
	const char *name;
	const char *dev_name;
	struct device___193 *dev_root;
	struct bus_attribute___193 *bus_attrs;
	struct device_attribute___193 *dev_attrs;
	struct driver_attribute___193 *drv_attrs;
	const struct attribute_group___52 **bus_groups;
	const struct attribute_group___52 **dev_groups;
	const struct attribute_group___52 **drv_groups;
	int (*match)(struct device___193 *, struct device_driver___193 *);
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	int (*probe)(struct device___193 *);
	int (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*online)(struct device___193 *);
	int (*offline)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private___7 *p;
	struct lock_class_key lock_key;
};

struct device_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct device___193 *, struct device_attribute___193 *, char *);
	ssize_t (*store)(struct device___193 *, struct device_attribute___193 *, const char *, size_t);
};

struct driver_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___193 *, char *);
	ssize_t (*store)(struct device_driver___193 *, const char *, size_t);
};

struct driver_private___7;

struct device_driver___193 {
	const char *name;
	struct bus_type___193 *bus;
	struct module___42 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___193 *);
	int (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	const struct attribute_group___52 **groups;
	const struct dev_pm_ops___193 *pm;
	struct driver_private___7 *p;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___7 {
	struct kset___3 subsys;
	struct kset___3 *devices_kset;
	struct list_head interfaces;
	struct mutex___76 mutex;
	struct kset___3 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___193 *bus;
	struct kset___3 glue_dirs;
	struct class___193 *class;
};

struct device_type___193 {
	const char *name;
	const struct attribute_group___52 **groups;
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
};

struct driver_private___7 {
	struct kobject___3 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___41 *mkobj;
	struct device_driver___193 *driver;
};

struct class_attribute___193;

struct class___193 {
	const char *name;
	struct module___42 *owner;
	struct class_attribute___193 *class_attrs;
	struct device_attribute___193 *dev_attrs;
	const struct attribute_group___52 **dev_groups;
	struct bin_attribute___52 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *);
	void (*class_release)(struct class___193 *);
	void (*dev_release)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
	struct subsys_private___7 *p;
};

struct class_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct class___193 *, struct class_attribute___193 *, char *);
	ssize_t (*store)(struct class___193 *, struct class_attribute___193 *, const char *, size_t);
	const void * (*namespace)(struct class___193 *, const struct class_attribute___193 *);
};

typedef void (*dr_release_t___7)(struct device___193 *, void *);

typedef int (*dr_match_t___7)(struct device___193 *, void *, void *);

struct device_private___7 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	void *driver_data;
	struct device___193 *device;
};

struct device_rh___193 {
	struct dev_pm_info_rh___193 power;
};

struct firmware___2 {
	size_t size;
	const u8 *data;
	struct page___75 **pages;
	void *priv;
};

struct builtin_fw {
	char *name;
	void *data;
	long unsigned int size;
};

enum {
	FW_STATUS_LOADING = 0,
	FW_STATUS_DONE = 1,
	FW_STATUS_ABORT = 2,
};

struct firmware_cache {
	spinlock_t lock;
	struct list_head head;
	int state;
	spinlock_t name_lock;
	struct list_head fw_names;
	struct delayed_work work;
	struct notifier_block pm_notify;
};

struct firmware_buf {
	struct kref ref;
	struct list_head list;
	struct completion completion;
	struct firmware_cache *fwc;
	long unsigned int status;
	void *data;
	size_t size;
	char fw_id[0];
};

struct fw_cache_entry {
	struct list_head list;
	char name[0];
};

struct fw_name_devm {
	long unsigned int magic;
	char name[0];
};

struct firmware_work {
	struct work_struct work;
	struct module___42 *module;
	const char *name;
	struct device___193 *device;
	void *context;
	void (*cont)(const struct firmware___2 *, void *);
	bool uevent;
};

struct page___209;

typedef struct page___209 *pgtable_t___209;

struct address_space___210;

struct kmem_cache___195;

struct page___209 {
	long unsigned int flags;
	struct address_space___210 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___209 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___209 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___195 *slab_cache;
		struct page___209 *first_page;
	};
	long: 64;
};

struct task_struct___211;

struct pv_cpu_ops___211 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___80 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___80 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___211 *);
	void (*end_context_switch)(struct task_struct___211 *);
};

struct mutex___212 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___211 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___204 {
	struct page___209 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___218;

struct signal_struct___211;

struct css_set___127;

struct task_struct___211 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___211 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___218 *mm;
	struct mm_struct___218 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___211 *real_parent;
	struct task_struct___211 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___211 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___90 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___211 = 0,
		VTIME_USER___211 = 1,
		VTIME_SYS___211 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___80 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___211 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___127 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___212 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___204 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___218 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___218 *, struct mm_struct___218 *);
	void (*dup_mmap)(struct mm_struct___218 *, struct mm_struct___218 *);
	void (*exit_mmap)(struct mm_struct___218 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___218 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___218 *);
	void (*pgd_free)(struct mm_struct___218 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___218 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___218 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___218 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___218 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___218 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___218 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___218 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___218 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___218 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___218 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___218 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___212 lock;
	void *vdso;
} mm_context_t___212;

struct xol_area___209;

struct uprobes_state___209 {
	struct xol_area___209 *xol_area;
};

struct vm_area_struct___218;

struct file___210;

struct core_state___211;

struct mm_struct___218 {
	struct vm_area_struct___218 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___218 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___218 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___212 context;
	long unsigned int flags;
	struct core_state___211 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___211 *owner;
	struct file___210 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___209 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___122;

struct module_kobject___121 {
	struct kobject___22 kobj;
	struct module___122 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___121;

struct module___122 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___121 mkobj;
	struct module_attribute___121 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___211 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___211;

struct lruvec___211 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___211 *zone;
};

struct pglist_data___211;

struct zone___211 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___211 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___211 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___211 {
	struct zone___211 *zone;
	int zone_idx;
};

struct zonelist___211 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___211 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___211 {
	struct zone___211 node_zones[4];
	struct zonelist___211 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___211 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___194;

struct dev_pm_ops___194 {
	int (*prepare)(struct device___194 *);
	void (*complete)(struct device___194 *);
	int (*suspend)(struct device___194 *);
	int (*resume)(struct device___194 *);
	int (*freeze)(struct device___194 *);
	int (*thaw)(struct device___194 *);
	int (*poweroff)(struct device___194 *);
	int (*restore)(struct device___194 *);
	int (*suspend_late)(struct device___194 *);
	int (*resume_early)(struct device___194 *);
	int (*freeze_late)(struct device___194 *);
	int (*thaw_early)(struct device___194 *);
	int (*poweroff_late)(struct device___194 *);
	int (*restore_early)(struct device___194 *);
	int (*suspend_noirq)(struct device___194 *);
	int (*resume_noirq)(struct device___194 *);
	int (*freeze_noirq)(struct device___194 *);
	int (*thaw_noirq)(struct device___194 *);
	int (*poweroff_noirq)(struct device___194 *);
	int (*restore_noirq)(struct device___194 *);
	int (*runtime_suspend)(struct device___194 *);
	int (*runtime_resume)(struct device___194 *);
	int (*runtime_idle)(struct device___194 *);
};

struct device_type___194;

struct bus_type___194;

struct device_driver___194;

struct dev_pm_domain___194;

struct class___194;

struct attribute_group___168;

struct device_rh___194;

struct device___194 {
	struct device___194 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___194 *type;
	struct mutex___212 mutex;
	struct bus_type___194 *bus;
	struct device_driver___194 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___194 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___80 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___194 *class;
	const struct attribute_group___168 **groups;
	void (*release)(struct device___194 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___194 *device_rh;
};

struct dev_pm_info_rh___194 {
	void (*set_latency_tolerance)(struct device___194 *, s32);
};

struct dev_pm_domain___194 {
	struct dev_pm_ops___194 ops;
};

struct smp_ops___211 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___211 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___170;

struct attribute_group___168 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___170 **bin_attrs;
};

struct bin_attribute___170 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___210 *, struct kobject___22 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___210 *, struct kobject___22 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	int (*mmap)(struct file___210 *, struct kobject___22 *, struct bin_attribute___170 *, struct vm_area_struct___218 *);
};

struct dentry___210;

struct path___210 {
	struct vfsmount *mnt;
	struct dentry___210 *dentry;
};

struct inode___210;

struct file_operations___210;

struct file___210 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___210 f_path;
	struct inode___210 *f_inode;
	const struct file_operations___210 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___210 *f_mapping;
	struct mutex___212 f_pos_lock;
};

struct vm_operations_struct___190;

struct vm_area_struct___218 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___218 *vm_next;
	struct vm_area_struct___218 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___218 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___190 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___210 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___121 *, struct module_kobject___121 *, char *);
	ssize_t (*store)(struct module_attribute___121 *, struct module_kobject___121 *, const char *, size_t);
	void (*setup)(struct module___122 *, const char *);
	int (*test)(struct module___122 *);
	void (*free)(struct module___122 *);
};

struct xol_area___209 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___209 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___194;

struct memcg_cache_params___195;

struct kmem_cache___195 {
	struct kmem_cache_cpu___194 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___195 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___210;

struct address_space___210 {
	struct inode___210 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___212 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___210 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___186;

struct vm_operations_struct___190 {
	void (*open)(struct vm_area_struct___218 *);
	void (*close)(struct vm_area_struct___218 *);
	int (*fault)(struct vm_area_struct___218 *, struct vm_fault___186 *);
	int (*page_mkwrite)(struct vm_area_struct___218 *, struct vm_fault___186 *);
	int (*access)(struct vm_area_struct___218 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___218 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___218 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___218 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___218 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___211 {
	struct task_struct___211 *task;
	struct core_thread___211 *next;
};

struct core_state___211 {
	atomic_t nr_threads;
	struct core_thread___211 dumper;
	struct completion startup;
};

struct vm_fault___186 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___209 *page;
};

struct bus_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___194 *, char *);
	ssize_t (*store)(struct bus_type___194 *, const char *, size_t);
};

struct device_attribute___194;

struct driver_attribute___194;

struct bus_type___194 {
	const char *name;
	const char *dev_name;
	struct device___194 *dev_root;
	struct bus_attribute___194 *bus_attrs;
	struct device_attribute___194 *dev_attrs;
	struct driver_attribute___194 *drv_attrs;
	const struct attribute_group___168 **bus_groups;
	const struct attribute_group___168 **dev_groups;
	const struct attribute_group___168 **drv_groups;
	int (*match)(struct device___194 *, struct device_driver___194 *);
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	int (*probe)(struct device___194 *);
	int (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*online)(struct device___194 *);
	int (*offline)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct device___194 *, struct device_attribute___194 *, char *);
	ssize_t (*store)(struct device___194 *, struct device_attribute___194 *, const char *, size_t);
};

struct driver_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___194 *, char *);
	ssize_t (*store)(struct device_driver___194 *, const char *, size_t);
};

struct device_driver___194 {
	const char *name;
	struct bus_type___194 *bus;
	struct module___122 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___194 *);
	int (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	const struct attribute_group___168 **groups;
	const struct dev_pm_ops___194 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___194 {
	const char *name;
	const struct attribute_group___168 **groups;
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
};

struct class_attribute___194;

struct class___194 {
	const char *name;
	struct module___122 *owner;
	struct class_attribute___194 *class_attrs;
	struct device_attribute___194 *dev_attrs;
	const struct attribute_group___168 **dev_groups;
	struct bin_attribute___170 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *);
	void (*class_release)(struct class___194 *);
	void (*dev_release)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
	struct subsys_private *p;
};

struct class_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct class___194 *, struct class_attribute___194 *, char *);
	ssize_t (*store)(struct class___194 *, struct class_attribute___194 *, const char *, size_t);
	const void * (*namespace)(struct class___194 *, const struct class_attribute___194 *);
};

struct device_rh___194 {
	struct dev_pm_info_rh___194 power;
};

struct node___4 {
	struct device___194 dev;
	struct work_struct node_work;
};

typedef void (*node_registration_func_t___2)(struct node___4 *);

struct memory_block___3 {
	long unsigned int start_section_nr;
	long unsigned int end_section_nr;
	long unsigned int state;
	int section_count;
	int online_type;
	int phys_device;
	void *hw;
	int (*phys_callback)(struct memory_block___3 *);
	struct device___194 dev;
};

struct dentry_operations___210;

struct super_block___210;

struct dentry___210 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___210 *d_parent;
	struct qstr d_name;
	struct inode___210 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___210 *d_op;
	struct super_block___210 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___210;

struct file_lock___210;

struct dquot___210;

struct block_device___210;

struct inode___210 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___210 *i_op;
	struct super_block___210 *i_sb;
	struct address_space___210 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___212 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___210 *i_fop;
	struct file_lock___210 *i_flock;
	struct address_space___210 i_data;
	struct dquot___210 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___210 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___210 {
	int (*d_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_hash)(const struct dentry___210 *, struct qstr *);
	int (*d_compare)(const struct dentry___210 *, const struct dentry___210 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___210 *);
	void (*d_release)(struct dentry___210 *);
	void (*d_prune)(struct dentry___210 *);
	void (*d_iput)(struct dentry___210 *, struct inode___210 *);
	char * (*d_dname)(struct dentry___210 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___210 *);
	int (*d_manage)(struct dentry___210 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___210;

struct mem_dqinfo___210 {
	struct quota_format_type___210 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___210;

struct quota_info___210 {
	unsigned int flags;
	struct mutex___212 dqio_mutex;
	struct mutex___212 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___210 *files[2];
	struct mem_dqinfo___210 info[2];
	const struct quota_format_ops___210 *ops[2];
};

struct file_system_type___210;

struct super_operations___210;

struct dquot_operations___210;

struct quotactl_ops___210;

struct xattr_handler___128;

struct super_block___210 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___210 *s_type;
	const struct super_operations___210 *s_op;
	const struct dquot_operations___210 *dq_op;
	const struct quotactl_ops___210 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___210 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___128 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___210 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___210 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___212 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___210 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___210 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___210 *bd_inode;
	struct super_block___210 *bd_super;
	struct mutex___212 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___210 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___212 bd_fsfreeze_mutex;
};

struct cgroup___127;

struct cgroup_subsys_state___127 {
	struct cgroup___127 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___210 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___210 *ia_file;
};

struct dquot___210 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___212 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___210 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___210 {
	int qf_fmt_id;
	const struct quota_format_ops___210 *qf_ops;
	struct module___122 *qf_owner;
	struct quota_format_type___210 *qf_next;
};

struct quota_format_ops___210 {
	int (*check_quota_file)(struct super_block___210 *, int);
	int (*read_file_info)(struct super_block___210 *, int);
	int (*write_file_info)(struct super_block___210 *, int);
	int (*free_file_info)(struct super_block___210 *, int);
	int (*read_dqblk)(struct dquot___210 *);
	int (*commit_dqblk)(struct dquot___210 *);
	int (*release_dqblk)(struct dquot___210 *);
};

struct dquot_operations___210 {
	int (*write_dquot)(struct dquot___210 *);
	struct dquot___210 * (*alloc_dquot)(struct super_block___210 *, int);
	void (*destroy_dquot)(struct dquot___210 *);
	int (*acquire_dquot)(struct dquot___210 *);
	int (*release_dquot)(struct dquot___210 *);
	int (*mark_dirty)(struct dquot___210 *);
	int (*write_info)(struct super_block___210 *, int);
	qsize_t * (*get_reserved_space)(struct inode___210 *);
};

struct quotactl_ops___210 {
	int (*quota_on)(struct super_block___210 *, int, int, struct path___210 *);
	int (*quota_on_meta)(struct super_block___210 *, int, int);
	int (*quota_off)(struct super_block___210 *, int);
	int (*quota_sync)(struct super_block___210 *, int);
	int (*get_info)(struct super_block___210 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___210 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___210 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___210 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___210 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___210 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___210 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___210 *, unsigned int);
};

struct swap_info_struct___46;

struct address_space_operations___210 {
	int (*writepage)(struct page___209 *, struct writeback_control *);
	int (*readpage)(struct file___210 *, struct page___209 *);
	int (*writepages)(struct address_space___210 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___209 *);
	int (*readpages)(struct file___210 *, struct address_space___210 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___210 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___209 **, void **);
	int (*write_end)(struct file___210 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___209 *, void *);
	sector_t (*bmap)(struct address_space___210 *, sector_t);
	void (*invalidatepage)(struct page___209 *, long unsigned int);
	int (*releasepage)(struct page___209 *, gfp_t);
	void (*freepage)(struct page___209 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___210 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___210 *, struct page___209 *, struct page___209 *, enum migrate_mode);
	int (*launder_page)(struct page___209 *);
	int (*is_partially_uptodate)(struct page___209 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___209 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___210 *, struct page___209 *);
	int (*swap_activate)(struct swap_info_struct___46 *, struct file___210 *, sector_t *);
	void (*swap_deactivate)(struct file___210 *);
	void (*invalidatepage_range)(struct page___209 *, unsigned int, unsigned int);
};

struct swap_info_struct___46 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___210 *bdev;
	struct file___210 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___210 {
	struct dentry___210 * (*lookup)(struct inode___210 *, struct dentry___210 *, unsigned int);
	void * (*follow_link)(struct dentry___210 *, struct nameidata *);
	int (*permission)(struct inode___210 *, int);
	struct posix_acl * (*get_acl)(struct inode___210 *, int);
	int (*readlink)(struct dentry___210 *, char *, int);
	void (*put_link)(struct dentry___210 *, struct nameidata *, void *);
	int (*create)(struct inode___210 *, struct dentry___210 *, umode_t, bool);
	int (*link)(struct dentry___210 *, struct inode___210 *, struct dentry___210 *);
	int (*unlink)(struct inode___210 *, struct dentry___210 *);
	int (*symlink)(struct inode___210 *, struct dentry___210 *, const char *);
	int (*mkdir)(struct inode___210 *, struct dentry___210 *, umode_t);
	int (*rmdir)(struct inode___210 *, struct dentry___210 *);
	int (*mknod)(struct inode___210 *, struct dentry___210 *, umode_t, dev_t);
	int (*rename)(struct inode___210 *, struct dentry___210 *, struct inode___210 *, struct dentry___210 *);
	int (*setattr)(struct dentry___210 *, struct iattr___210 *);
	int (*getattr)(struct vfsmount *, struct dentry___210 *, struct kstat *);
	int (*setxattr)(struct dentry___210 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___210 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___210 *, char *, size_t);
	int (*removexattr)(struct dentry___210 *, const char *);
	int (*fiemap)(struct inode___210 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___210 *, struct timespec *, int);
	int (*atomic_open)(struct inode___210 *, struct dentry___210 *, struct file___210 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___210 {
	struct module___122 *owner;
	loff_t (*llseek)(struct file___210 *, loff_t, int);
	ssize_t (*read)(struct file___210 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___210 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___210 *, void *, filldir_t);
	unsigned int (*poll)(struct file___210 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___210 *, struct vm_area_struct___218 *);
	int (*open)(struct inode___210 *, struct file___210 *);
	int (*flush)(struct file___210 *, fl_owner_t);
	int (*release)(struct inode___210 *, struct file___210 *);
	int (*fsync)(struct file___210 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___210 *, int);
	int (*lock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*sendpage)(struct file___210 *, struct page___209 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___210 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___210 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___210 *, long int, struct file_lock___210 **, void **);
		struct {
			int (*setlease)(struct file___210 *, long int, struct file_lock___210 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___210 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___210 *);
};

struct fasync_struct___210;

struct file_lock_operations___210;

struct lock_manager_operations___210;

struct file_lock___210 {
	struct file_lock___210 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___90 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___210 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___210 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___210 *fl_ops;
	const struct lock_manager_operations___210 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___210 {
	void (*fl_copy_lock)(struct file_lock___210 *, struct file_lock___210 *);
	void (*fl_release_private)(struct file_lock___210 *);
};

struct lock_manager_operations___210 {
	int (*lm_compare_owner)(struct file_lock___210 *, struct file_lock___210 *);
	long unsigned int (*lm_owner_key)(struct file_lock___210 *);
	void (*lm_notify)(struct file_lock___210 *);
	int (*lm_grant)(struct file_lock___210 *, struct file_lock___210 *, int);
	void (*lm_break)(struct file_lock___210 *);
	int (*lm_change)(struct file_lock___210 **, int);
};

struct fasync_struct___210 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___210 *fa_next;
	struct file___210 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___210 {
	const char *name;
	int fs_flags;
	struct dentry___210 * (*mount)(struct file_system_type___210 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___210 *);
	struct module___122 *owner;
	struct file_system_type___210 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___210 {
	struct inode___210 * (*alloc_inode)(struct super_block___210 *);
	void (*destroy_inode)(struct inode___210 *);
	void (*dirty_inode)(struct inode___210 *, int);
	int (*write_inode)(struct inode___210 *, struct writeback_control *);
	int (*drop_inode)(struct inode___210 *);
	void (*evict_inode)(struct inode___210 *);
	void (*put_super)(struct super_block___210 *);
	int (*sync_fs)(struct super_block___210 *, int);
	int (*freeze_fs)(struct super_block___210 *);
	int (*unfreeze_fs)(struct super_block___210 *);
	int (*statfs)(struct dentry___210 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___210 *, int *, char *);
	void (*umount_begin)(struct super_block___210 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___210 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___210 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___210 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___210 *);
	ssize_t (*quota_read)(struct super_block___210 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___210 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___210 *);
	int (*bdev_try_to_free_page)(struct super_block___210 *, struct page___209 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___210 *);
	void (*free_cached_objects)(struct super_block___210 *, int);
};

struct xattr_handler___128 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___210 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___210 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___210 *, const char *, const void *, size_t, int, int);
};

struct signal_struct___211 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___211 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___211 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___90 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___212 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___127 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___127 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___194 {
	void **freelist;
	long unsigned int tid;
	struct page___209 *page;
	struct page___209 *partial;
};

struct memcg_cache_params___195 {
	bool is_root_cache;
	union {
		struct kmem_cache___195 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___195 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___127;

struct cgroup___127 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___127 *parent;
	struct dentry___210 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___127 *subsys[11];
	struct cgroupfs_root___127 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___212 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___127 {
	struct super_block___210 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___127 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___71 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___210 *, struct file___210 *);
	ssize_t (*read)(struct cgroup___127 *, struct cftype___71 *, struct file___210 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___127 *, struct cftype___71 *);
	s64 (*read_s64)(struct cgroup___127 *, struct cftype___71 *);
	int (*read_map)(struct cgroup___127 *, struct cftype___71 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___127 *, struct cftype___71 *, struct seq_file___5 *);
	ssize_t (*write)(struct cgroup___127 *, struct cftype___71 *, struct file___210 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___127 *, struct cftype___71 *, u64);
	int (*write_s64)(struct cgroup___127 *, struct cftype___71 *, s64);
	int (*write_string)(struct cgroup___127 *, struct cftype___71 *, const char *);
	int (*trigger)(struct cgroup___127 *, unsigned int);
	int (*release)(struct inode___210 *, struct file___210 *);
	int (*register_event)(struct cgroup___127 *, struct cftype___71 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___127 *, struct cftype___71 *, struct eventfd_ctx *);
};

struct cftype_set___67 {
	struct list_head node;
	struct cftype___71 *cfts;
};

struct task_and_cgroup___67 {
	struct task_struct___211 *task;
	struct cgroup___127 *cgrp;
	struct css_set___127 *cg;
};

struct cgroup_taskset___67 {
	struct task_and_cgroup___67 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___127 *cur_cgrp;
};

struct cgroup_subsys___67 {
	struct cgroup_subsys_state___127 * (*css_alloc)(struct cgroup___127 *);
	int (*css_online)(struct cgroup___127 *);
	void (*css_offline)(struct cgroup___127 *);
	void (*css_free)(struct cgroup___127 *);
	int (*can_attach)(struct cgroup___127 *, struct cgroup_taskset___67 *);
	void (*cancel_attach)(struct cgroup___127 *, struct cgroup_taskset___67 *);
	void (*attach)(struct cgroup___127 *, struct cgroup_taskset___67 *);
	void (*fork)(struct task_struct___211 *);
	void (*exit)(struct cgroup___127 *, struct cgroup___127 *, struct task_struct___211 *);
	void (*bind)(struct cgroup___127 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___127 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___71 *base_cftypes;
	struct cftype_set___67 base_cftset;
	struct module___122 *module;
};

struct tlb_state___39 {
	struct mm_struct___218 *active_mm;
	int state;
};

struct hstate___17 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	struct cftype___71 cgroup_files[5];
	char name[32];
};

struct node_attr {
	struct device_attribute___194 attr;
	enum node_states state;
};

struct memory_block___4 {
	long unsigned int start_section_nr;
	long unsigned int end_section_nr;
	long unsigned int state;
	int section_count;
	int online_type;
	int phys_device;
	void *hw;
	int (*phys_callback)(struct memory_block___4 *);
	struct device___191 dev;
};

typedef void (*dr_release_t___8)(struct device___8 *, void *);

typedef int (*dr_match_t___8)(struct device___8 *, void *, void *);

struct ftrace_raw_regmap_reg {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	unsigned int val;
	char __data[0];
};

struct ftrace_raw_regmap_block {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	int count;
	char __data[0];
};

struct ftrace_raw_regcache_sync {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_status;
	u32 __data_loc_type;
	int type;
	char __data[0];
};

struct ftrace_raw_regmap_bool {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flag;
	char __data[0];
};

struct ftrace_raw_regmap_async {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_regcache_drop_region {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int from;
	unsigned int to;
	char __data[0];
};

struct ftrace_data_offsets_regmap_reg {
	u32 name;
};

struct ftrace_data_offsets_regmap_block {
	u32 name;
};

struct ftrace_data_offsets_regcache_sync {
	u32 name;
	u32 status;
	u32 type;
};

struct ftrace_data_offsets_regmap_bool {
	u32 name;
};

struct ftrace_data_offsets_regmap_async {
	u32 name;
};

struct ftrace_data_offsets_regcache_drop_region {
	u32 name;
};

enum regcache_type {
	REGCACHE_NONE = 0,
	REGCACHE_RBTREE = 1,
	REGCACHE_COMPRESSED = 2,
	REGCACHE_FLAT = 3,
};

struct reg_default {
	unsigned int reg;
	unsigned int def;
};

enum regmap_endian {
	REGMAP_ENDIAN_DEFAULT = 0,
	REGMAP_ENDIAN_BIG = 1,
	REGMAP_ENDIAN_LITTLE = 2,
	REGMAP_ENDIAN_NATIVE = 3,
};

struct regmap_range {
	unsigned int range_min;
	unsigned int range_max;
};

struct regmap_access_table {
	const struct regmap_range *yes_ranges;
	unsigned int n_yes_ranges;
	const struct regmap_range *no_ranges;
	unsigned int n_no_ranges;
};

typedef void (*regmap_lock)(void *);

typedef void (*regmap_unlock)(void *);

struct regmap_range_cfg;

struct regmap_config {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___8 *, unsigned int);
	bool (*readable_reg)(struct device___8 *, unsigned int);
	bool (*volatile_reg)(struct device___8 *, unsigned int);
	bool (*precious_reg)(struct device___8 *, unsigned int);
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	u8 read_flag_mask;
	u8 write_flag_mask;
	bool use_single_rw;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
};

struct regmap_range_cfg {
	const char *name;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

typedef int (*regmap_hw_write)(void *, const void *, size_t);

typedef int (*regmap_hw_gather_write)(void *, const void *, size_t, const void *, size_t);

struct regmap_async;

typedef int (*regmap_hw_async_write)(void *, const void *, size_t, const void *, size_t, struct regmap_async *);

struct regmap;

struct regmap_async {
	struct list_head list;
	struct work_struct cleanup;
	struct regmap *map;
	void *work_buf;
};

typedef int (*regmap_hw_read)(void *, const void *, size_t, void *, size_t);

typedef struct regmap_async * (*regmap_hw_async_alloc)();

typedef void (*regmap_hw_free_context)(void *);

struct regmap_bus {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write async_write;
	regmap_hw_read read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
};

struct regmap_format {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops;

struct regmap {
	struct mutex___14 mutex;
	spinlock_t spinlock;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	struct device___8 *dev;
	void *work_buf;
	struct regmap_format format;
	const struct regmap_bus *bus;
	void *bus_context;
	const char *name;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	int async_ret;
	struct dentry___13 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex___14 cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___8 *, unsigned int);
	bool (*readable_reg)(struct device___8 *, unsigned int);
	bool (*volatile_reg)(struct device___8 *, unsigned int);
	bool (*precious_reg)(struct device___8 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool defer_caching;
	u8 read_flag_mask;
	u8 write_flag_mask;
	int reg_shift;
	int reg_stride;
	const struct regcache_ops *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	u32 cache_only;
	u32 cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	u32 cache_dirty;
	struct reg_default *patch;
	int patch_regs;
	bool use_single_rw;
	struct rb_root range_tree;
	void *selector_work_buf;
};

struct regcache_ops {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap *);
	int (*exit)(struct regmap *);
	int (*read)(struct regmap *, unsigned int, unsigned int *);
	int (*write)(struct regmap *, unsigned int, unsigned int);
	int (*sync)(struct regmap *, unsigned int, unsigned int);
	int (*drop)(struct regmap *, unsigned int, unsigned int);
};

struct regmap_range_node {
	struct rb_node node;
	const char *name;
	struct regmap *map;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

struct regmap_config___2 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___193 *, unsigned int);
	bool (*readable_reg)(struct device___193 *, unsigned int);
	bool (*volatile_reg)(struct device___193 *, unsigned int);
	bool (*precious_reg)(struct device___193 *, unsigned int);
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	u8 read_flag_mask;
	u8 write_flag_mask;
	bool use_single_rw;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
};

struct regmap_async___2;

typedef int (*regmap_hw_async_write___2)(void *, const void *, size_t, const void *, size_t, struct regmap_async___2 *);

struct regmap___2;

struct regmap_async___2 {
	struct list_head list;
	struct work_struct cleanup;
	struct regmap___2 *map;
	void *work_buf;
};

typedef struct regmap_async___2 * (*regmap_hw_async_alloc___2)();

struct regmap_bus___2 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___2 async_write;
	regmap_hw_read read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___2 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
};

struct regmap_format___2 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___2 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___2;

struct regmap___2 {
	struct mutex___212 mutex;
	spinlock_t spinlock;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	struct device___193 *dev;
	void *work_buf;
	struct regmap_format___2 format;
	const struct regmap_bus___2 *bus;
	void *bus_context;
	const char *name;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	int async_ret;
	struct dentry___76 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex___212 cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___193 *, unsigned int);
	bool (*readable_reg)(struct device___193 *, unsigned int);
	bool (*volatile_reg)(struct device___193 *, unsigned int);
	bool (*precious_reg)(struct device___193 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool defer_caching;
	u8 read_flag_mask;
	u8 write_flag_mask;
	int reg_shift;
	int reg_stride;
	const struct regcache_ops___2 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	u32 cache_only;
	u32 cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	u32 cache_dirty;
	struct reg_default *patch;
	int patch_regs;
	bool use_single_rw;
	struct rb_root range_tree;
	void *selector_work_buf;
};

struct regcache_ops___2 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___2 *);
	int (*exit)(struct regmap___2 *);
	int (*read)(struct regmap___2 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___2 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___2 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___2 *, unsigned int, unsigned int);
};

struct regcache_rbtree_node {
	void *block;
	long int *cache_present;
	unsigned int base_reg;
	unsigned int blklen;
	struct rb_node node;
};

struct regcache_rbtree_ctx {
	struct rb_root root;
	struct regcache_rbtree_node *cached_rbnode;
};

struct regcache_lzo_ctx {
	void *wmem;
	void *dst;
	const void *src;
	size_t src_len;
	size_t dst_len;
	size_t decompressed_size;
	long unsigned int *sync_bmp;
	int sync_bmp_nbits;
};

struct regmap_async___3;

typedef int (*regmap_hw_async_write___3)(void *, const void *, size_t, const void *, size_t, struct regmap_async___3 *);

struct regmap___3;

struct regmap_async___3 {
	struct list_head list;
	struct work_struct cleanup;
	struct regmap___3 *map;
	void *work_buf;
};

typedef struct regmap_async___3 * (*regmap_hw_async_alloc___3)();

struct regmap_bus___3 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___3 async_write;
	regmap_hw_read read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___3 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
};

struct regmap_debugfs_off_cache {
	struct list_head list;
	off_t min;
	off_t max;
	unsigned int base_reg;
	unsigned int max_reg;
};

struct regmap_format___3 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___3 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___3;

struct regmap___3 {
	struct mutex___212 mutex;
	spinlock_t spinlock;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	struct device___184 *dev;
	void *work_buf;
	struct regmap_format___3 format;
	const struct regmap_bus___3 *bus;
	void *bus_context;
	const char *name;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	int async_ret;
	struct dentry___175 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex___212 cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___184 *, unsigned int);
	bool (*readable_reg)(struct device___184 *, unsigned int);
	bool (*volatile_reg)(struct device___184 *, unsigned int);
	bool (*precious_reg)(struct device___184 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool defer_caching;
	u8 read_flag_mask;
	u8 write_flag_mask;
	int reg_shift;
	int reg_stride;
	const struct regcache_ops___3 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	u32 cache_only;
	u32 cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	u32 cache_dirty;
	struct reg_default *patch;
	int patch_regs;
	bool use_single_rw;
	struct rb_root range_tree;
	void *selector_work_buf;
};

struct regcache_ops___3 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___3 *);
	int (*exit)(struct regmap___3 *);
	int (*read)(struct regmap___3 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___3 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___3 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___3 *, unsigned int, unsigned int);
};

struct regmap_range_node___2 {
	struct rb_node node;
	const char *name;
	struct regmap___3 *map;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

struct test_struct {
	char *get;
	char *put;
	void (*get_handler)(char *);
	int (*put_handler)(char *, char *);
};

struct test_state {
	char *name;
	struct test_struct *tst;
	int idx;
	int (*run_test)(int, int);
	int (*validate_put)(char *);
};

struct page___210;

typedef struct page___210 *pgtable_t___210;

struct address_space___211;

struct kmem_cache___196;

struct page___210 {
	long unsigned int flags;
	struct address_space___211 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___210 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___210 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___196 *slab_cache;
		struct page___210 *first_page;
	};
	long: 64;
};

struct thread_struct___81;

struct task_struct___212;

struct pv_cpu_ops___212 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___212 *);
	void (*end_context_switch)(struct task_struct___212 *);
};

struct perf_event___81;

struct thread_struct___81 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___81 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___91;

struct pid_link___91 {
	struct hlist_node node;
	struct pid___91 *pid;
};

struct mutex___213 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___212 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___205 {
	struct page___210 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___219;

struct nsproxy___112;

struct signal_struct___212;

struct bio_list___40;

struct backing_dev_info___51;

struct io_context___40;

struct css_set___128;

struct perf_event_context___81;

struct task_struct___212 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___212 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___219 *mm;
	struct mm_struct___219 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___212 *real_parent;
	struct task_struct___212 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___212 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___212 = 0,
		VTIME_USER___212 = 1,
		VTIME_SYS___212 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___112 *nsproxy;
	struct signal_struct___212 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___40 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___51 *backing_dev_info;
	struct io_context___40 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___128 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___81 *perf_event_ctxp[2];
	struct mutex___213 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___205 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___219 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___219 *, struct mm_struct___219 *);
	void (*dup_mmap)(struct mm_struct___219 *, struct mm_struct___219 *);
	void (*exit_mmap)(struct mm_struct___219 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___219 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___219 *);
	void (*pgd_free)(struct mm_struct___219 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___219 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___219 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___219 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___219 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___219 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___219 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___219 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___219 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___219 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___219 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___219 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___213 lock;
	void *vdso;
} mm_context_t___213;

struct xol_area___210;

struct uprobes_state___210 {
	struct xol_area___210 *xol_area;
};

struct vm_area_struct___219;

struct file___211;

struct core_state___212;

struct mm_struct___219 {
	struct vm_area_struct___219 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___219 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___219 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___213 context;
	long unsigned int flags;
	struct core_state___212 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___212 *owner;
	struct file___211 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___210 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___123;

struct exec_domain___56 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___123 *module;
	struct exec_domain___56 *next;
};

struct module_kobject___122 {
	struct kobject___22 kobj;
	struct module___123 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___122;

struct ftrace_event_call___70;

struct module___123 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___122 mkobj;
	struct module_attribute___122 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___70 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___212 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___81 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___212 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___212 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___212 *target;
};

typedef void (*perf_overflow_handler_t___81)(struct perf_event___81 *, struct perf_sample_data___5 *, struct pt_regs *);

struct ftrace_ops___81;

typedef void (*ftrace_func_t___81)(long unsigned int, long unsigned int, struct ftrace_ops___81 *, struct pt_regs *);

struct ftrace_ops___81 {
	ftrace_func_t___81 func;
	struct ftrace_ops___81 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___213 regex_lock;
};

struct pmu___81;

struct fasync_struct___211;

struct pid_namespace___91;

struct perf_cgroup___81;

struct perf_event___81 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___81 *group_leader;
	struct pmu___81 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___81 hw;
	struct perf_event_context___81 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___213 child_mutex;
	struct list_head child_list;
	struct perf_event___81 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___212 *owner;
	struct mutex___213 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___211 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___81 *);
	struct callback_head callback_head;
	struct pid_namespace___91 *ns;
	u64 id;
	perf_overflow_handler_t___81 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___70 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___81 ftrace_ops;
	struct perf_cgroup___81 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___95 {
	struct task_struct___212 *task;
	struct exec_domain___56 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___212;

struct lruvec___212 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___212 *zone;
};

struct pglist_data___212;

struct zone___212 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___212 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___212 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___212 {
	struct zone___212 *zone;
	int zone_idx;
};

struct zonelist___212 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___212 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___212 {
	struct zone___212 node_zones[4];
	struct zonelist___212 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___212 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___138;

struct x86_io_apic_ops___138 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___138 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___138;

struct irq_data___138 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___138 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___195;

struct dev_pm_ops___195 {
	int (*prepare)(struct device___195 *);
	void (*complete)(struct device___195 *);
	int (*suspend)(struct device___195 *);
	int (*resume)(struct device___195 *);
	int (*freeze)(struct device___195 *);
	int (*thaw)(struct device___195 *);
	int (*poweroff)(struct device___195 *);
	int (*restore)(struct device___195 *);
	int (*suspend_late)(struct device___195 *);
	int (*resume_early)(struct device___195 *);
	int (*freeze_late)(struct device___195 *);
	int (*thaw_early)(struct device___195 *);
	int (*poweroff_late)(struct device___195 *);
	int (*restore_early)(struct device___195 *);
	int (*suspend_noirq)(struct device___195 *);
	int (*resume_noirq)(struct device___195 *);
	int (*freeze_noirq)(struct device___195 *);
	int (*thaw_noirq)(struct device___195 *);
	int (*poweroff_noirq)(struct device___195 *);
	int (*restore_noirq)(struct device___195 *);
	int (*runtime_suspend)(struct device___195 *);
	int (*runtime_resume)(struct device___195 *);
	int (*runtime_idle)(struct device___195 *);
};

struct dma_map_ops___81;

struct dev_archdata___81 {
	struct dma_map_ops___81 *dma_ops;
	void *iommu;
};

struct device_type___195;

struct bus_type___195;

struct device_driver___195;

struct dev_pm_domain___195;

struct class___195;

struct attribute_group___169;

struct device_rh___195;

struct device___195 {
	struct device___195 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___195 *type;
	struct mutex___213 mutex;
	struct bus_type___195 *bus;
	struct device_driver___195 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___195 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___81 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___30 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___195 *class;
	const struct attribute_group___169 **groups;
	void (*release)(struct device___195 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___195 *device_rh;
};

struct dev_pm_info_rh___195 {
	void (*set_latency_tolerance)(struct device___195 *, s32);
};

struct dev_pm_domain___195 {
	struct dev_pm_ops___195 ops;
};

struct smp_ops___212 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___212 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct nsproxy___112 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___91 *pid_ns;
	struct net *net_ns;
};

struct bin_attribute___171;

struct attribute_group___169 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___171 **bin_attrs;
};

struct bin_attribute___171 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___211 *, struct kobject___22 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___211 *, struct kobject___22 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	int (*mmap)(struct file___211 *, struct kobject___22 *, struct bin_attribute___171 *, struct vm_area_struct___219 *);
};

struct dentry___211;

struct path___211 {
	struct vfsmount *mnt;
	struct dentry___211 *dentry;
};

struct fown_struct___91 {
	rwlock_t lock;
	struct pid___91 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___211;

struct file_operations___211;

struct file___211 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___211 f_path;
	struct inode___211 *f_inode;
	const struct file_operations___211 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___211 *f_mapping;
	struct mutex___213 f_pos_lock;
};

struct vm_operations_struct___191;

struct vm_area_struct___219 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___219 *vm_next;
	struct vm_area_struct___219 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___219 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___191 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___211 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___122 *, struct module_kobject___122 *, char *);
	ssize_t (*store)(struct module_attribute___122 *, struct module_kobject___122 *, const char *, size_t);
	void (*setup)(struct module___123 *, const char *);
	int (*test)(struct module___123 *);
	void (*free)(struct module___123 *);
};

struct trace_event_functions___70;

struct trace_event___70 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___70 *funcs;
};

struct ftrace_event_class___70;

struct ftrace_event_call___70 {
	struct list_head list;
	struct ftrace_event_class___70 *class;
	char *name;
	struct trace_event___70 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct kmem_cache_cpu___195 {
	void **freelist;
	long unsigned int tid;
	struct page___210 *page;
	struct page___210 *partial;
};

struct memcg_cache_params___196;

struct kmem_cache___196 {
	struct kmem_cache_cpu___195 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___196 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___196 {
	bool is_root_cache;
	union {
		struct kmem_cache___196 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___196 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___210 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___210 *page;
	long unsigned int vaddr;
};

struct address_space_operations___211;

struct address_space___211 {
	struct inode___211 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___213 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___211 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___51 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___187;

struct vm_operations_struct___191 {
	void (*open)(struct vm_area_struct___219 *);
	void (*close)(struct vm_area_struct___219 *);
	int (*fault)(struct vm_area_struct___219 *, struct vm_fault___187 *);
	int (*page_mkwrite)(struct vm_area_struct___219 *, struct vm_fault___187 *);
	int (*access)(struct vm_area_struct___219 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___219 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___219 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___219 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___219 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___212 {
	struct task_struct___212 *task;
	struct core_thread___212 *next;
};

struct core_state___212 {
	atomic_t nr_threads;
	struct core_thread___212 dumper;
	struct completion startup;
};

struct upid___91 {
	int nr;
	struct pid_namespace___91 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___91 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___212 *child_reaper;
	struct kmem_cache___196 *pid_cachep;
	unsigned int level;
	struct pid_namespace___91 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___211 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___91 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___91 numbers[1];
};

struct signal_struct___212 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___212 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___212 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___213 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___41;

struct bio_list___40 {
	struct bio___41 *head;
	struct bio___41 *tail;
};

struct bdi_writeback___51 {
	struct backing_dev_info___51 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___51 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___51 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___195 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___211 *debug_dir;
	struct dentry___211 *debug_stats;
};

struct io_cq___40;

struct io_context___40 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___40 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___128;

struct css_set___128 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___128 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___81 {
	struct pmu___81 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___213 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___212 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___81 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct dma_map_ops___81 {
	void * (*alloc)(struct device___195 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___195 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___195 *, struct vm_area_struct___219 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___195 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___195 *, struct page___210 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___195 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___195 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___195 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___195 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___195 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___195 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___195 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___195 *, dma_addr_t);
	int (*dma_supported)(struct device___195 *, u64);
	int (*set_dma_mask)(struct device___195 *, u64);
	int is_phys;
};

struct bus_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___195 *, char *);
	ssize_t (*store)(struct bus_type___195 *, const char *, size_t);
};

struct device_attribute___195;

struct driver_attribute___195;

struct bus_type___195 {
	const char *name;
	const char *dev_name;
	struct device___195 *dev_root;
	struct bus_attribute___195 *bus_attrs;
	struct device_attribute___195 *dev_attrs;
	struct driver_attribute___195 *drv_attrs;
	const struct attribute_group___169 **bus_groups;
	const struct attribute_group___169 **dev_groups;
	const struct attribute_group___169 **drv_groups;
	int (*match)(struct device___195 *, struct device_driver___195 *);
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	int (*probe)(struct device___195 *);
	int (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*online)(struct device___195 *);
	int (*offline)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct device___195 *, struct device_attribute___195 *, char *);
	ssize_t (*store)(struct device___195 *, struct device_attribute___195 *, const char *, size_t);
};

struct driver_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___195 *, char *);
	ssize_t (*store)(struct device_driver___195 *, const char *, size_t);
};

struct device_driver___195 {
	const char *name;
	struct bus_type___195 *bus;
	struct module___123 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___195 *);
	int (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	const struct attribute_group___169 **groups;
	const struct dev_pm_ops___195 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___195 {
	const char *name;
	const struct attribute_group___169 **groups;
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
};

struct class_attribute___195;

struct class___195 {
	const char *name;
	struct module___123 *owner;
	struct class_attribute___195 *class_attrs;
	struct device_attribute___195 *dev_attrs;
	const struct attribute_group___169 **dev_groups;
	struct bin_attribute___171 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *);
	void (*class_release)(struct class___195 *);
	void (*dev_release)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
	struct subsys_private *p;
};

struct class_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct class___195 *, struct class_attribute___195 *, char *);
	ssize_t (*store)(struct class___195 *, struct class_attribute___195 *, const char *, size_t);
	const void * (*namespace)(struct class___195 *, const struct class_attribute___195 *);
};

struct device_rh___195 {
	struct dev_pm_info_rh___195 power;
};

struct dentry_operations___211;

struct super_block___211;

struct dentry___211 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___211 *d_parent;
	struct qstr d_name;
	struct inode___211 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___211 *d_op;
	struct super_block___211 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___211;

struct file_lock___211;

struct dquot___211;

struct block_device___211;

struct inode___211 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___211 *i_op;
	struct super_block___211 *i_sb;
	struct address_space___211 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___213 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___211 *i_fop;
	struct file_lock___211 *i_flock;
	struct address_space___211 i_data;
	struct dquot___211 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___211 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___211 {
	int (*d_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_hash)(const struct dentry___211 *, struct qstr *);
	int (*d_compare)(const struct dentry___211 *, const struct dentry___211 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___211 *);
	void (*d_release)(struct dentry___211 *);
	void (*d_prune)(struct dentry___211 *);
	void (*d_iput)(struct dentry___211 *, struct inode___211 *);
	char * (*d_dname)(struct dentry___211 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___211 *);
	int (*d_manage)(struct dentry___211 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___211;

struct mem_dqinfo___211 {
	struct quota_format_type___211 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___211;

struct quota_info___211 {
	unsigned int flags;
	struct mutex___213 dqio_mutex;
	struct mutex___213 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___211 *files[2];
	struct mem_dqinfo___211 info[2];
	const struct quota_format_ops___211 *ops[2];
};

struct file_system_type___211;

struct super_operations___211;

struct dquot_operations___211;

struct quotactl_ops___211;

struct xattr_handler___129;

struct super_block___211 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___211 *s_type;
	const struct super_operations___211 *s_op;
	const struct dquot_operations___211 *dq_op;
	const struct quotactl_ops___211 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___211 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___129 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___211 *s_bdev;
	struct backing_dev_info___51 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___211 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___213 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___211 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___41(struct bio___41 *, int);

struct bio_vec___41 {
	struct page___210 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___41;

struct bio_set___41;

struct bio___41 {
	sector_t bi_sector;
	struct bio___41 *bi_next;
	struct block_device___211 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___41 *bi_end_io;
	void *bi_private;
	struct io_context___40 *bi_ioc;
	struct cgroup_subsys_state___128 *bi_css;
	struct bio_integrity_payload___41 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___41 *bi_io_vec;
	struct bio_set___41 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___41 bi_inline_vecs[0];
};

struct hd_struct___44;

struct gendisk___44;

struct request_queue___40;

struct block_device___211 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___211 *bd_inode;
	struct super_block___211 *bd_super;
	struct mutex___213 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___211 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___44 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___44 *bd_disk;
	struct request_queue___40 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___213 bd_fsfreeze_mutex;
};

struct cgroup___128;

struct cgroup_subsys_state___128 {
	struct cgroup___128 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___41 {
	struct bio___41 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___41 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___41 *bip_vec;
	struct bio_vec___41 bip_inline_vecs[0];
};

struct bio_set___41 {
	struct kmem_cache___196 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___40 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___211 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___211 *ia_file;
};

struct dquot___211 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___213 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___211 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___211 {
	int qf_fmt_id;
	const struct quota_format_ops___211 *qf_ops;
	struct module___123 *qf_owner;
	struct quota_format_type___211 *qf_next;
};

struct quota_format_ops___211 {
	int (*check_quota_file)(struct super_block___211 *, int);
	int (*read_file_info)(struct super_block___211 *, int);
	int (*write_file_info)(struct super_block___211 *, int);
	int (*free_file_info)(struct super_block___211 *, int);
	int (*read_dqblk)(struct dquot___211 *);
	int (*commit_dqblk)(struct dquot___211 *);
	int (*release_dqblk)(struct dquot___211 *);
};

struct dquot_operations___211 {
	int (*write_dquot)(struct dquot___211 *);
	struct dquot___211 * (*alloc_dquot)(struct super_block___211 *, int);
	void (*destroy_dquot)(struct dquot___211 *);
	int (*acquire_dquot)(struct dquot___211 *);
	int (*release_dquot)(struct dquot___211 *);
	int (*mark_dirty)(struct dquot___211 *);
	int (*write_info)(struct super_block___211 *, int);
	qsize_t * (*get_reserved_space)(struct inode___211 *);
};

struct quotactl_ops___211 {
	int (*quota_on)(struct super_block___211 *, int, int, struct path___211 *);
	int (*quota_on_meta)(struct super_block___211 *, int, int);
	int (*quota_off)(struct super_block___211 *, int);
	int (*quota_sync)(struct super_block___211 *, int);
	int (*get_info)(struct super_block___211 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___211 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___211 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___211 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___211 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___211 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___211 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___211 *, unsigned int);
};

struct address_space_operations___211 {
	int (*writepage)(struct page___210 *, struct writeback_control *);
	int (*readpage)(struct file___211 *, struct page___210 *);
	int (*writepages)(struct address_space___211 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___210 *);
	int (*readpages)(struct file___211 *, struct address_space___211 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___211 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___210 **, void **);
	int (*write_end)(struct file___211 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___210 *, void *);
	sector_t (*bmap)(struct address_space___211 *, sector_t);
	void (*invalidatepage)(struct page___210 *, long unsigned int);
	int (*releasepage)(struct page___210 *, gfp_t);
	void (*freepage)(struct page___210 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___211 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___211 *, struct page___210 *, struct page___210 *, enum migrate_mode);
	int (*launder_page)(struct page___210 *);
	int (*is_partially_uptodate)(struct page___210 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___210 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___211 *, struct page___210 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___211 *, sector_t *);
	void (*swap_deactivate)(struct file___211 *);
	void (*invalidatepage_range)(struct page___210 *, unsigned int, unsigned int);
};

struct hd_struct___44 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___195 __dev;
	struct kobject___22 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___44;

struct block_device_operations___40;

struct gendisk___44 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___44 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___44 *part_tbl;
	struct hd_struct___44 part0;
	const struct block_device_operations___40 *fops;
	struct request_queue___40 *queue;
	void *private_data;
	int flags;
	struct device___195 *driverfs_dev;
	struct kobject___22 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___40 {
	struct request_queue___40 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___40(struct request_queue___40 *);

typedef void make_request_fn___40(struct request_queue___40 *, struct bio___41 *);

struct request___40;

typedef int prep_rq_fn___40(struct request_queue___40 *, struct request___40 *);

struct bvec_merge_data___40;

typedef int merge_bvec_fn___41(struct request_queue___40 *, struct bvec_merge_data___40 *, struct bio_vec___41 *);

typedef void softirq_done_fn___40(struct request___40 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___40(struct request___40 *);

typedef int dma_drain_needed_fn___40(struct request___40 *);

typedef int lld_busy_fn___40(struct request_queue___40 *);

struct bsg_class_device___40 {
	struct device___195 *class_dev;
	struct device___195 *parent;
	int minor;
	struct request_queue___40 *queue;
	struct kref ref;
	void (*release)(struct device___195 *);
};

typedef void unprep_rq_fn___40(struct request_queue___40 *, struct request___40 *);

struct elevator_queue___40;

struct blk_mq_ops___13;

struct blk_mq_hw_ctx___13;

struct blk_queue_tag___40;

struct blk_mq_tag_set___13;

struct request_queue___40 {
	struct list_head queue_head;
	struct request___40 *last_merge;
	struct elevator_queue___40 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___40 root_rl;
	request_fn_proc___40 *request_fn;
	make_request_fn___40 *make_request_fn;
	prep_rq_fn___40 *prep_rq_fn;
	merge_bvec_fn___41 *merge_bvec_fn;
	softirq_done_fn___40 *softirq_done_fn;
	rq_timed_out_fn___40 *rq_timed_out_fn;
	dma_drain_needed_fn___40 *dma_drain_needed;
	lld_busy_fn___40 *lld_busy_fn;
	struct blk_mq_ops___13 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___13 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___40 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___51 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___22 kobj;
	struct kobject___22 mq_kobj;
	struct device___195 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___40 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___40 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___213 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___40 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___40 *unprep_rq_fn;
	struct blk_mq_tag_set___13 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___41 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___211 {
	struct dentry___211 * (*lookup)(struct inode___211 *, struct dentry___211 *, unsigned int);
	void * (*follow_link)(struct dentry___211 *, struct nameidata *);
	int (*permission)(struct inode___211 *, int);
	struct posix_acl * (*get_acl)(struct inode___211 *, int);
	int (*readlink)(struct dentry___211 *, char *, int);
	void (*put_link)(struct dentry___211 *, struct nameidata *, void *);
	int (*create)(struct inode___211 *, struct dentry___211 *, umode_t, bool);
	int (*link)(struct dentry___211 *, struct inode___211 *, struct dentry___211 *);
	int (*unlink)(struct inode___211 *, struct dentry___211 *);
	int (*symlink)(struct inode___211 *, struct dentry___211 *, const char *);
	int (*mkdir)(struct inode___211 *, struct dentry___211 *, umode_t);
	int (*rmdir)(struct inode___211 *, struct dentry___211 *);
	int (*mknod)(struct inode___211 *, struct dentry___211 *, umode_t, dev_t);
	int (*rename)(struct inode___211 *, struct dentry___211 *, struct inode___211 *, struct dentry___211 *);
	int (*setattr)(struct dentry___211 *, struct iattr___211 *);
	int (*getattr)(struct vfsmount *, struct dentry___211 *, struct kstat *);
	int (*setxattr)(struct dentry___211 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___211 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___211 *, char *, size_t);
	int (*removexattr)(struct dentry___211 *, const char *);
	int (*fiemap)(struct inode___211 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___211 *, struct timespec *, int);
	int (*atomic_open)(struct inode___211 *, struct dentry___211 *, struct file___211 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___117;

struct seq_file___142;

struct file_operations___211 {
	struct module___123 *owner;
	loff_t (*llseek)(struct file___211 *, loff_t, int);
	ssize_t (*read)(struct file___211 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___211 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___211 *, void *, filldir_t);
	unsigned int (*poll)(struct file___211 *, struct poll_table_struct___117 *);
	long int (*unlocked_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___211 *, struct vm_area_struct___219 *);
	int (*open)(struct inode___211 *, struct file___211 *);
	int (*flush)(struct file___211 *, fl_owner_t);
	int (*release)(struct inode___211 *, struct file___211 *);
	int (*fsync)(struct file___211 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___211 *, int);
	int (*lock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*sendpage)(struct file___211 *, struct page___210 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___211 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___211 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___211 *, long int, struct file_lock___211 **, void **);
		struct {
			int (*setlease)(struct file___211 *, long int, struct file_lock___211 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___211 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___142 *, struct file___211 *);
};

struct file_lock_operations___211;

struct lock_manager_operations___211;

struct file_lock___211 {
	struct file_lock___211 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___211 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___211 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___211 *fl_ops;
	const struct lock_manager_operations___211 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___211 {
	void (*fl_copy_lock)(struct file_lock___211 *, struct file_lock___211 *);
	void (*fl_release_private)(struct file_lock___211 *);
};

struct lock_manager_operations___211 {
	int (*lm_compare_owner)(struct file_lock___211 *, struct file_lock___211 *);
	long unsigned int (*lm_owner_key)(struct file_lock___211 *);
	void (*lm_notify)(struct file_lock___211 *);
	int (*lm_grant)(struct file_lock___211 *, struct file_lock___211 *, int);
	void (*lm_break)(struct file_lock___211 *);
	int (*lm_change)(struct file_lock___211 **, int);
};

struct fasync_struct___211 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___211 *fa_next;
	struct file___211 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___211 {
	const char *name;
	int fs_flags;
	struct dentry___211 * (*mount)(struct file_system_type___211 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___211 *);
	struct module___123 *owner;
	struct file_system_type___211 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___211 {
	struct inode___211 * (*alloc_inode)(struct super_block___211 *);
	void (*destroy_inode)(struct inode___211 *);
	void (*dirty_inode)(struct inode___211 *, int);
	int (*write_inode)(struct inode___211 *, struct writeback_control *);
	int (*drop_inode)(struct inode___211 *);
	void (*evict_inode)(struct inode___211 *);
	void (*put_super)(struct super_block___211 *);
	int (*sync_fs)(struct super_block___211 *, int);
	int (*freeze_fs)(struct super_block___211 *);
	int (*unfreeze_fs)(struct super_block___211 *);
	int (*statfs)(struct dentry___211 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___211 *, int *, char *);
	void (*umount_begin)(struct super_block___211 *);
	int (*show_options)(struct seq_file___142 *, struct dentry___211 *);
	int (*show_devname)(struct seq_file___142 *, struct dentry___211 *);
	int (*show_path)(struct seq_file___142 *, struct dentry___211 *);
	int (*show_stats)(struct seq_file___142 *, struct dentry___211 *);
	ssize_t (*quota_read)(struct super_block___211 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___211 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___211 *);
	int (*bdev_try_to_free_page)(struct super_block___211 *, struct page___210 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___211 *);
	void (*free_cached_objects)(struct super_block___211 *, int);
};

struct xattr_handler___129 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___211 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___211 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___211 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___119)(struct file___211 *, wait_queue_head_t *, struct poll_table_struct___117 *);

struct poll_table_struct___117 {
	poll_queue_proc___119 _qproc;
	long unsigned int _key;
};

struct seq_operations___142;

struct seq_file___142 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___213 lock;
	const struct seq_operations___142 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___44 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___44 *last_lookup;
	struct hd_struct___44 *part[0];
};

struct block_device_operations___40 {
	int (*open)(struct block_device___211 *, fmode_t);
	void (*release)(struct gendisk___44 *, fmode_t);
	int (*ioctl)(struct block_device___211 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___211 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___211 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___44 *, unsigned int);
	int (*media_changed)(struct gendisk___44 *);
	void (*unlock_native_capacity)(struct gendisk___44 *);
	int (*revalidate_disk)(struct gendisk___44 *);
	int (*getgeo)(struct block_device___211 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___211 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___123 *owner;
};

struct vm_fault___187 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___210 *page;
};

struct irq_chip___138 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___138 *);
	void (*irq_shutdown)(struct irq_data___138 *);
	void (*irq_enable)(struct irq_data___138 *);
	void (*irq_disable)(struct irq_data___138 *);
	void (*irq_ack)(struct irq_data___138 *);
	void (*irq_mask)(struct irq_data___138 *);
	void (*irq_mask_ack)(struct irq_data___138 *);
	void (*irq_unmask)(struct irq_data___138 *);
	void (*irq_eoi)(struct irq_data___138 *);
	int (*irq_set_affinity)(struct irq_data___138 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___138 *);
	int (*irq_set_type)(struct irq_data___138 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___138 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___138 *);
	void (*irq_bus_sync_unlock)(struct irq_data___138 *);
	void (*irq_cpu_online)(struct irq_data___138 *);
	void (*irq_cpu_offline)(struct irq_data___138 *);
	void (*irq_suspend)(struct irq_data___138 *);
	void (*irq_resume)(struct irq_data___138 *);
	void (*irq_pm_shutdown)(struct irq_data___138 *);
	void (*irq_print_chip)(struct irq_data___138 *, struct seq_file___142 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___138 *, void *);
	long unsigned int flags;
};

struct io_cq___40 {
	struct request_queue___40 *q;
	struct io_context___40 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___196 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___40(struct request___40 *, int);

struct request___40 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___40 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___41 *bio;
	struct bio___41 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___40 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___40 *saved_end_io;
		} flush;
	};
	struct gendisk___44 *rq_disk;
	struct hd_struct___44 *part;
	long unsigned int start_time;
	struct request_list___40 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___40 *end_io;
	void *end_io_data;
	struct request___40 *next_rq;
};

typedef int elevator_merge_fn___40(struct request_queue___40 *, struct request___40 **, struct bio___41 *);

typedef void elevator_merge_req_fn___40(struct request_queue___40 *, struct request___40 *, struct request___40 *);

typedef void elevator_merged_fn___40(struct request_queue___40 *, struct request___40 *, int);

typedef int elevator_allow_merge_fn___40(struct request_queue___40 *, struct request___40 *, struct bio___41 *);

typedef void elevator_bio_merged_fn___40(struct request_queue___40 *, struct request___40 *, struct bio___41 *);

typedef int elevator_dispatch_fn___40(struct request_queue___40 *, int);

typedef void elevator_add_req_fn___40(struct request_queue___40 *, struct request___40 *);

typedef struct request___40 *elevator_request_list_fn___40(struct request_queue___40 *, struct request___40 *);

typedef void elevator_completed_req_fn___40(struct request_queue___40 *, struct request___40 *);

typedef int elevator_may_queue_fn___40(struct request_queue___40 *, int);

typedef void elevator_init_icq_fn___40(struct io_cq___40 *);

typedef void elevator_exit_icq_fn___40(struct io_cq___40 *);

typedef int elevator_set_req_fn___40(struct request_queue___40 *, struct request___40 *, struct bio___41 *, gfp_t);

typedef void elevator_put_req_fn___40(struct request___40 *);

typedef void elevator_activate_req_fn___40(struct request_queue___40 *, struct request___40 *);

typedef void elevator_deactivate_req_fn___40(struct request_queue___40 *, struct request___40 *);

struct elevator_type___40;

typedef int elevator_init_fn___41(struct request_queue___40 *, struct elevator_type___40 *);

typedef void elevator_exit_fn___40(struct elevator_queue___40 *);

struct elevator_ops___40 {
	elevator_merge_fn___40 *elevator_merge_fn;
	elevator_merged_fn___40 *elevator_merged_fn;
	elevator_merge_req_fn___40 *elevator_merge_req_fn;
	elevator_allow_merge_fn___40 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___40 *elevator_bio_merged_fn;
	elevator_dispatch_fn___40 *elevator_dispatch_fn;
	elevator_add_req_fn___40 *elevator_add_req_fn;
	elevator_activate_req_fn___40 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___40 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___40 *elevator_completed_req_fn;
	elevator_request_list_fn___40 *elevator_former_req_fn;
	elevator_request_list_fn___40 *elevator_latter_req_fn;
	elevator_init_icq_fn___40 *elevator_init_icq_fn;
	elevator_exit_icq_fn___40 *elevator_exit_icq_fn;
	elevator_set_req_fn___40 *elevator_set_req_fn;
	elevator_put_req_fn___40 *elevator_put_req_fn;
	elevator_may_queue_fn___40 *elevator_may_queue_fn;
	elevator_init_fn___41 *elevator_init_fn;
	elevator_exit_fn___40 *elevator_exit_fn;
};

struct elv_fs_entry___40;

struct elevator_type___40 {
	struct kmem_cache___196 *icq_cache;
	struct elevator_ops___40 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___40 *elevator_attrs;
	char elevator_name[16];
	struct module___123 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___40 {
	struct elevator_type___40 *type;
	void *elevator_data;
	struct kobject___22 kobj;
	struct mutex___213 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___40 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___40 *, char *);
	ssize_t (*store)(struct elevator_queue___40 *, const char *, size_t);
};

struct bvec_merge_data___40 {
	struct block_device___211 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___40 {
	struct request___40 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___13;

typedef int queue_rq_fn___14(struct blk_mq_hw_ctx___13 *, const struct blk_mq_queue_data___13 *);

typedef struct blk_mq_hw_ctx___13 *map_queue_fn___14(struct request_queue___40 *, const int);

typedef enum blk_eh_timer_return timeout_fn___14(struct request___40 *, bool);

typedef int init_request_fn___14(void *, struct request___40 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___14(void *, struct request___40 *, unsigned int, unsigned int);

typedef int init_hctx_fn___13(struct blk_mq_hw_ctx___13 *, void *, unsigned int);

typedef void exit_hctx_fn___13(struct blk_mq_hw_ctx___13 *, unsigned int);

struct blk_mq_ops___13 {
	queue_rq_fn___14 *queue_rq;
	map_queue_fn___14 *map_queue;
	union {
		timeout_fn___14 *timeout;
		struct {
			rq_timed_out_fn___40 *timeout;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	softirq_done_fn___40 *complete;
	init_request_fn___14 *init_request;
	exit_request_fn___14 *exit_request;
	init_hctx_fn___13 *init_hctx;
	exit_hctx_fn___13 *exit_hctx;
};

struct blk_mq_cpu_notifier___3 {
	struct list_head list;
	void *data;
	union {
		int (*notify)(void *, long unsigned int, unsigned int);
		struct {
			void (*notify)(void *, long unsigned int, unsigned int);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct blk_mq_hw_ctx___13 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___40 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct request___40 **padding2;
		struct {
			struct request___40 **rqs;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___3 cpu_notifier;
	struct kobject___22 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___13 {
	struct blk_mq_ops___13 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___213 tag_list_lock;
	struct list_head tag_list;
};

enum scsi_device_state {
	SDEV_CREATED = 1,
	SDEV_RUNNING = 2,
	SDEV_CANCEL = 3,
	SDEV_DEL = 4,
	SDEV_QUIESCE = 5,
	SDEV_OFFLINE = 6,
	SDEV_TRANSPORT_OFFLINE = 7,
	SDEV_BLOCK = 8,
	SDEV_CREATED_BLOCK = 9,
};

struct Scsi_Host;

struct scsi_cmnd;

struct scsi_target;

struct scsi_dh_data;

struct scsi_device {
	struct Scsi_Host *host;
	struct request_queue___40 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___195 sdev_gendev;
	struct device___195 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

enum scsi_host_state {
	SHOST_CREATED = 1,
	SHOST_RUNNING = 2,
	SHOST_CANCEL = 3,
	SHOST_DEL = 4,
	SHOST_RECOVERY = 5,
	SHOST_CANCEL_RECOVERY = 6,
	SHOST_DEL_RECOVERY = 7,
};

struct scsi_host_cmd_pool;

struct scsi_host_template;

struct scsi_transport_template;

struct Scsi_Host {
	struct list_head __devices;
	struct list_head __targets;
	struct scsi_host_cmd_pool *cmd_pool;
	spinlock_t free_list_lock;
	struct list_head free_list;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex___213 scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___212 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template *hostt;
	struct scsi_transport_template *transportt;
	union {
		struct blk_queue_tag___40 *bqt;
		struct blk_mq_tag_set___13 *tag_set;
	};
	union {
		atomic_t host_busy;
		struct {
			unsigned int host_busy;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_id;
	unsigned int max_lun;
	unsigned int max_channel;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int use_blk_tcq: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int ordered_tag: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_blk_mq: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	union {
		atomic_t host_blocked;
		struct {
			unsigned int host_blocked;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	struct request_queue___40 *uspace_req_q;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___195 shost_gendev;
	struct device___195 shost_dev;
	struct list_head sht_legacy_list;
	void *shost_data;
	struct device___195 *dma_dev;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	unsigned int scsi_mq_reserved1;
	unsigned int scsi_mq_reserved2;
	void *scsi_mq_reserved3;
	void *scsi_mq_reserved4;
	atomic_t scsi_mq_reserved5;
	atomic_t scsi_mq_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_data_buffer {
	struct sg_table table;
	unsigned int length;
	int resid;
};

struct scsi_pointer {
	char *ptr;
	int this_residual;
	struct scatterlist *buffer;
	int buffers_residual;
	dma_addr_t dma_handle;
	volatile int Status;
	volatile int Message;
	volatile int have_data_in;
	volatile int sent_command;
	volatile int phase;
};

struct scsi_cmnd {
	struct scsi_device *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___40 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	unsigned char tag;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
};

enum scsi_target_state {
	STARGET_CREATED = 1,
	STARGET_RUNNING = 2,
	STARGET_DEL = 3,
};

struct scsi_target {
	struct scsi_device *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___195 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler;

struct scsi_dh_data {
	struct scsi_device_handler *scsi_dh;
	struct scsi_device *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_dh_devlist {
	char *vendor;
	char *model;
};

typedef void (*activate_complete)(void *, int);

struct scsi_sense_hdr;

struct scsi_device_handler {
	struct list_head list;
	struct module___123 *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device *);
	void (*detach)(struct scsi_device *);
	int (*activate)(struct scsi_device *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device *, struct request___40 *);
	int (*set_params)(struct scsi_device *, const char *);
	bool (*match)(struct scsi_device *);
};

struct scsi_sense_hdr {
	u8 response_code;
	u8 sense_key;
	u8 asc;
	u8 ascq;
	u8 byte4;
	u8 byte5;
	u8 byte6;
	u8 additional_length;
};

enum scsi_prot_operations {
	SCSI_PROT_NORMAL = 0,
	SCSI_PROT_READ_INSERT = 1,
	SCSI_PROT_WRITE_STRIP = 2,
	SCSI_PROT_READ_STRIP = 3,
	SCSI_PROT_WRITE_INSERT = 4,
	SCSI_PROT_READ_PASS = 5,
	SCSI_PROT_WRITE_PASS = 6,
};

struct scsi_driver {
	struct module___123 *owner;
	struct device_driver___195 gendrv;
	void (*rescan)(struct device___195 *);
	int (*init_command)(struct scsi_cmnd *);
	void (*uninit_command)(struct scsi_cmnd *);
	int (*done)(struct scsi_cmnd *);
	int (*eh_action)(struct scsi_cmnd *, int);
	int (*scsi_mq_reserved1)(struct scsi_cmnd *);
	void (*scsi_mq_reserved2)(struct scsi_cmnd *);
	void (*rh_reserved)();
};

struct seq_operations___142 {
	void * (*start)(struct seq_file___142 *, loff_t *);
	void (*stop)(struct seq_file___142 *, void *);
	void * (*next)(struct seq_file___142 *, void *, loff_t *);
	int (*show)(struct seq_file___142 *, void *);
};

struct blk_mq_queue_data___13 {
	struct request___40 *rq;
	struct list_head *list;
	bool last;
};

struct scsi_host_cmd_pool {
	struct kmem_cache___196 *cmd_slab;
	struct kmem_cache___196 *sense_slab;
	unsigned int users;
	char *cmd_name;
	char *sense_name;
	unsigned int slab_flags;
	gfp_t gfp_mask;
};

struct scsi_host_template {
	struct module___123 *module;
	const char *name;
	int (*detect)(struct scsi_host_template *);
	int (*release)(struct Scsi_Host *);
	const char * (*info)(struct Scsi_Host *);
	int (*ioctl)(struct scsi_device *, int, void *);
	int (*compat_ioctl)(struct scsi_device *, int, void *);
	int (*queuecommand)(struct Scsi_Host *, struct scsi_cmnd *);
	int (*transfer_response)(struct scsi_cmnd *, void (*)(struct scsi_cmnd *));
	int (*eh_abort_handler)(struct scsi_cmnd *);
	int (*eh_device_reset_handler)(struct scsi_cmnd *);
	int (*eh_target_reset_handler)(struct scsi_cmnd *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd *);
	int (*eh_host_reset_handler)(struct scsi_cmnd *);
	int (*slave_alloc)(struct scsi_device *);
	int (*slave_configure)(struct scsi_device *);
	void (*slave_destroy)(struct scsi_device *);
	int (*target_alloc)(struct scsi_target *);
	void (*target_destroy)(struct scsi_target *);
	int (*scan_finished)(struct Scsi_Host *, long unsigned int);
	void (*scan_start)(struct Scsi_Host *);
	int (*change_queue_depth)(struct scsi_device *, int, int);
	int (*change_queue_type)(struct scsi_device *, int);
	int (*bios_param)(struct scsi_device *, struct block_device___211 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device *);
	int (*show_info)(struct seq_file___142 *, struct Scsi_Host *);
	int (*write_info)(struct Scsi_Host *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*host_reset)(struct Scsi_Host *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int ordered_tag: 1;
	unsigned int no_write_same: 1;
	unsigned int no_async_abort: 1;
	unsigned int disable_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___195 **shost_attrs;
	struct device_attribute___195 **sdev_attrs;
	struct list_head legacy_hosts;
	u64 vendor_id;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	union {
		unsigned int cmd_size;
		struct {
			unsigned int scsi_mq_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	unsigned int scsi_mq_reserved2;
	union {
		struct scsi_host_cmd_pool *cmd_pool;
		struct {
			void *scsi_mq_reserved3;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void *scsi_mq_reserved4;
};

enum scsi_host_prot_capabilities {
	SHOST_DIF_TYPE1_PROTECTION = 1,
	SHOST_DIF_TYPE2_PROTECTION = 2,
	SHOST_DIF_TYPE3_PROTECTION = 4,
	SHOST_DIX_TYPE0_PROTECTION = 8,
	SHOST_DIX_TYPE1_PROTECTION = 16,
	SHOST_DIX_TYPE2_PROTECTION = 32,
	SHOST_DIX_TYPE3_PROTECTION = 64,
};

struct cgroupfs_root___128;

struct cgroup___128 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___128 *parent;
	struct dentry___211 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___128 *subsys[11];
	struct cgroupfs_root___128 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___213 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___128 {
	struct super_block___211 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___128 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___81;

struct pmu___81 {
	struct list_head entry;
	struct device___195 *dev;
	const struct attribute_group___169 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___81 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___81 *);
	void (*pmu_disable)(struct pmu___81 *);
	int (*event_init)(struct perf_event___81 *);
	int (*add)(struct perf_event___81 *, int);
	void (*del)(struct perf_event___81 *, int);
	void (*start)(struct perf_event___81 *, int);
	void (*stop)(struct perf_event___81 *, int);
	void (*read)(struct perf_event___81 *);
	void (*start_txn)(struct pmu___81 *);
	int (*commit_txn)(struct pmu___81 *);
	void (*cancel_txn)(struct pmu___81 *);
	int (*event_idx)(struct perf_event___81 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___123 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___81 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___81 *);
};

struct perf_cpu_context___81 {
	struct perf_event_context___81 ctx;
	struct perf_event_context___81 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___81 *unique_pmu;
	struct perf_cgroup___81 *cgrp;
};

struct perf_cgroup___81 {
	struct cgroup_subsys_state___128 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___70 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___213 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___70)(struct trace_iterator___70 *, int, struct trace_event___70 *);

struct trace_event_functions___70 {
	trace_print_func___70 trace;
	trace_print_func___70 raw;
	trace_print_func___70 hex;
	trace_print_func___70 binary;
};

struct ftrace_event_class___70 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___70 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___70 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___70 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___70 *);
};

struct ftrace_event_file___24 {
	struct list_head list;
	struct ftrace_event_call___70 *event_call;
	struct dentry___211 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_scsi_dispatch_cmd_start {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct ftrace_raw_scsi_dispatch_cmd_error {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int rtn;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct ftrace_raw_scsi_cmd_done_timeout_template {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int result;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct ftrace_raw_scsi_eh_wakeup {
	struct trace_entry ent;
	unsigned int host_no;
	char __data[0];
};

struct ftrace_data_offsets_scsi_dispatch_cmd_start {
	u32 cmnd;
};

struct ftrace_data_offsets_scsi_dispatch_cmd_error {
	u32 cmnd;
};

struct ftrace_data_offsets_scsi_cmd_done_timeout_template {
	u32 cmnd;
};

struct ftrace_data_offsets_scsi_eh_wakeup {};

struct attribute_container___2 {
	struct list_head node;
	struct klist containers;
	struct class___195 *class;
	const struct attribute_group___169 *grp;
	struct device_attribute___195 **attrs;
	int (*match)(struct attribute_container___2 *, struct device___195 *);
	long unsigned int flags;
};

struct transport_container___2 {
	struct attribute_container___2 ac;
	const struct attribute_group___169 *statistics;
};

struct scsi_transport_template {
	struct transport_container___2 host_attrs;
	struct transport_container___2 target_attrs;
	struct transport_container___2 device_attrs;
	int (*user_scan)(struct Scsi_Host *, uint, uint, uint);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host *);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*it_nexus_response)(struct Scsi_Host *, u64, int);
	int (*tsk_mgmt_response)(struct Scsi_Host *, u64, u64, int);
};

struct scsi_idlun {
	__u32 dev_id;
	__u32 host_unique_id;
};

struct scsi_eh_save {
	int result;
	enum dma_data_direction data_direction;
	unsigned int underflow;
	unsigned char cmd_len;
	unsigned char prot_op;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct request___40 *next_rq;
	unsigned char eh_cmnd[16];
	struct scatterlist sense_sgl;
};

enum {
	SCSI_QDEPTH_DEFAULT = 0,
	SCSI_QDEPTH_QFULL = 1,
	SCSI_QDEPTH_RAMP_UP = 2,
};

struct page___211;

typedef struct page___211 *pgtable_t___211;

struct address_space___212;

struct kmem_cache___197;

struct page___211 {
	long unsigned int flags;
	struct address_space___212 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___211 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___211 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___197 *slab_cache;
		struct page___211 *first_page;
	};
	long: 64;
};

struct task_struct___213;

struct pv_cpu_ops___213 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___213 *);
	void (*end_context_switch)(struct task_struct___213 *);
};

struct mutex___214 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___213 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___206 {
	struct page___211 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___220;

struct signal_struct___213;

struct bio_list___41;

struct backing_dev_info___52;

struct io_context___41;

struct task_struct___213 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___213 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___220 *mm;
	struct mm_struct___220 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___213 *real_parent;
	struct task_struct___213 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___213 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___213 = 0,
		VTIME_USER___213 = 1,
		VTIME_SYS___213 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___213 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___41 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___52 *backing_dev_info;
	struct io_context___41 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___214 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___206 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___220 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___220 *, struct mm_struct___220 *);
	void (*dup_mmap)(struct mm_struct___220 *, struct mm_struct___220 *);
	void (*exit_mmap)(struct mm_struct___220 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___220 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___220 *);
	void (*pgd_free)(struct mm_struct___220 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___220 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___220 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___220 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___220 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___220 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___220 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___220 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___220 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___220 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___220 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___220 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___214 lock;
	void *vdso;
} mm_context_t___214;

struct xol_area___211;

struct uprobes_state___211 {
	struct xol_area___211 *xol_area;
};

struct vm_area_struct___220;

struct file___212;

struct core_state___213;

struct mm_struct___220 {
	struct vm_area_struct___220 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___220 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___220 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___214 context;
	long unsigned int flags;
	struct core_state___213 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___213 *owner;
	struct file___212 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___211 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___96 {
	struct task_struct___213 *task;
	struct exec_domain___56 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___212;

struct dentry_operations___212;

struct super_block___212;

struct dentry___212 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___212 *d_parent;
	struct qstr d_name;
	struct inode___212 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___212 *d_op;
	struct super_block___212 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___212;

struct address_space___212 {
	struct inode___212 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___214 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___212 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___52 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___212;

struct file_operations___212;

struct file_lock___212;

struct dquot___212;

struct block_device___212;

struct inode___212 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___212 *i_op;
	struct super_block___212 *i_sb;
	struct address_space___212 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___214 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___212 *i_fop;
	struct file_lock___212 *i_flock;
	struct address_space___212 i_data;
	struct dquot___212 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___212 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___212;

struct dentry_operations___212 {
	int (*d_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_hash)(const struct dentry___212 *, struct qstr *);
	int (*d_compare)(const struct dentry___212 *, const struct dentry___212 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___212 *);
	void (*d_release)(struct dentry___212 *);
	void (*d_prune)(struct dentry___212 *);
	void (*d_iput)(struct dentry___212 *, struct inode___212 *);
	char * (*d_dname)(struct dentry___212 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___212 *);
	int (*d_manage)(struct dentry___212 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___212;

struct mem_dqinfo___212 {
	struct quota_format_type___212 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___212;

struct quota_info___212 {
	unsigned int flags;
	struct mutex___214 dqio_mutex;
	struct mutex___214 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___212 *files[2];
	struct mem_dqinfo___212 info[2];
	const struct quota_format_ops___212 *ops[2];
};

struct file_system_type___212;

struct super_operations___212;

struct dquot_operations___212;

struct quotactl_ops___212;

struct super_block___212 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___212 *s_type;
	const struct super_operations___212 *s_op;
	const struct dquot_operations___212 *dq_op;
	const struct quotactl_ops___212 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___212 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___212 *s_bdev;
	struct backing_dev_info___52 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___212 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___214 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___212 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___212 {
	struct vfsmount *mnt;
	struct dentry___212 *dentry;
};

struct irq_data___139;

struct x86_io_apic_ops___139 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___139 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___139;

struct irq_data___139 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___139 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___196;

struct dev_pm_ops___196 {
	int (*prepare)(struct device___196 *);
	void (*complete)(struct device___196 *);
	int (*suspend)(struct device___196 *);
	int (*resume)(struct device___196 *);
	int (*freeze)(struct device___196 *);
	int (*thaw)(struct device___196 *);
	int (*poweroff)(struct device___196 *);
	int (*restore)(struct device___196 *);
	int (*suspend_late)(struct device___196 *);
	int (*resume_early)(struct device___196 *);
	int (*freeze_late)(struct device___196 *);
	int (*thaw_early)(struct device___196 *);
	int (*poweroff_late)(struct device___196 *);
	int (*restore_early)(struct device___196 *);
	int (*suspend_noirq)(struct device___196 *);
	int (*resume_noirq)(struct device___196 *);
	int (*freeze_noirq)(struct device___196 *);
	int (*thaw_noirq)(struct device___196 *);
	int (*poweroff_noirq)(struct device___196 *);
	int (*restore_noirq)(struct device___196 *);
	int (*runtime_suspend)(struct device___196 *);
	int (*runtime_resume)(struct device___196 *);
	int (*runtime_idle)(struct device___196 *);
};

struct dma_map_ops___82;

struct dev_archdata___82 {
	struct dma_map_ops___82 *dma_ops;
	void *iommu;
};

struct device_type___196;

struct bus_type___196;

struct device_driver___196;

struct dev_pm_domain___196;

struct class___196;

struct attribute_group___170;

struct device_rh___196;

struct device___196 {
	struct device___196 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___196 *type;
	struct mutex___214 mutex;
	struct bus_type___196 *bus;
	struct device_driver___196 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___196 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___82 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___196 *class;
	const struct attribute_group___170 **groups;
	void (*release)(struct device___196 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___196 *device_rh;
};

struct dev_pm_info_rh___196 {
	void (*set_latency_tolerance)(struct device___196 *, s32);
};

struct dev_pm_domain___196 {
	struct dev_pm_ops___196 ops;
};

struct smp_ops___213 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___213 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___42;

typedef void bio_end_io_t___42(struct bio___42 *, int);

struct bio_vec___42 {
	struct page___211 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___42;

struct bio_set___42;

struct bio___42 {
	sector_t bi_sector;
	struct bio___42 *bi_next;
	struct block_device___212 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___42 *bi_end_io;
	void *bi_private;
	struct io_context___41 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___42 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___42 *bi_io_vec;
	struct bio_set___42 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___42 bi_inline_vecs[0];
};

struct hd_struct___45;

struct gendisk___45;

struct request_queue___41;

struct block_device___212 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___212 *bd_inode;
	struct super_block___212 *bd_super;
	struct mutex___214 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___212 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___45 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___45 *bd_disk;
	struct request_queue___41 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___214 bd_fsfreeze_mutex;
};

struct io_cq___41;

struct io_context___41 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___41 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___42 {
	struct bio___42 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___42 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___42 *bip_vec;
	struct bio_vec___42 bip_inline_vecs[0];
};

struct bio_list___41 {
	struct bio___42 *head;
	struct bio___42 *tail;
};

struct bio_set___42 {
	struct kmem_cache___197 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___41 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___212 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___212 *ia_file;
};

struct file___212 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___212 f_path;
	struct inode___212 *f_inode;
	const struct file_operations___212 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___212 *f_mapping;
	struct mutex___214 f_pos_lock;
};

struct zone___213;

struct lruvec___213 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___213 *zone;
};

struct pglist_data___213;

struct zone___213 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___213 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___213 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___213 {
	struct zone___213 *zone;
	int zone_idx;
};

struct zonelist___213 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___213 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___213 {
	struct zone___213 node_zones[4];
	struct zonelist___213 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___213 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___212 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___214 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___212 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___212 {
	int qf_fmt_id;
	const struct quota_format_ops___212 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___212 *qf_next;
};

struct quota_format_ops___212 {
	int (*check_quota_file)(struct super_block___212 *, int);
	int (*read_file_info)(struct super_block___212 *, int);
	int (*write_file_info)(struct super_block___212 *, int);
	int (*free_file_info)(struct super_block___212 *, int);
	int (*read_dqblk)(struct dquot___212 *);
	int (*commit_dqblk)(struct dquot___212 *);
	int (*release_dqblk)(struct dquot___212 *);
};

struct dquot_operations___212 {
	int (*write_dquot)(struct dquot___212 *);
	struct dquot___212 * (*alloc_dquot)(struct super_block___212 *, int);
	void (*destroy_dquot)(struct dquot___212 *);
	int (*acquire_dquot)(struct dquot___212 *);
	int (*release_dquot)(struct dquot___212 *);
	int (*mark_dirty)(struct dquot___212 *);
	int (*write_info)(struct super_block___212 *, int);
	qsize_t * (*get_reserved_space)(struct inode___212 *);
};

struct quotactl_ops___212 {
	int (*quota_on)(struct super_block___212 *, int, int, struct path___212 *);
	int (*quota_on_meta)(struct super_block___212 *, int, int);
	int (*quota_off)(struct super_block___212 *, int);
	int (*quota_sync)(struct super_block___212 *, int);
	int (*get_info)(struct super_block___212 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___212 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___212 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___212 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___212 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___212 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___212 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___212 *, unsigned int);
};

struct address_space_operations___212 {
	int (*writepage)(struct page___211 *, struct writeback_control *);
	int (*readpage)(struct file___212 *, struct page___211 *);
	int (*writepages)(struct address_space___212 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___211 *);
	int (*readpages)(struct file___212 *, struct address_space___212 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___212 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___211 **, void **);
	int (*write_end)(struct file___212 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___211 *, void *);
	sector_t (*bmap)(struct address_space___212 *, sector_t);
	void (*invalidatepage)(struct page___211 *, long unsigned int);
	int (*releasepage)(struct page___211 *, gfp_t);
	void (*freepage)(struct page___211 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___212 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___212 *, struct page___211 *, struct page___211 *, enum migrate_mode);
	int (*launder_page)(struct page___211 *);
	int (*is_partially_uptodate)(struct page___211 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___211 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___212 *, struct page___211 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___212 *, sector_t *);
	void (*swap_deactivate)(struct file___212 *);
	void (*invalidatepage_range)(struct page___211 *, unsigned int, unsigned int);
};

struct bdi_writeback___52 {
	struct backing_dev_info___52 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___52 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___52 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___196 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___212 *debug_dir;
	struct dentry___212 *debug_stats;
};

struct hd_struct___45 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___196 __dev;
	struct kobject___22 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___45;

struct block_device_operations___41;

struct gendisk___45 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___45 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___45 *part_tbl;
	struct hd_struct___45 part0;
	const struct block_device_operations___41 *fops;
	struct request_queue___41 *queue;
	void *private_data;
	int flags;
	struct device___196 *driverfs_dev;
	struct kobject___22 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___41 {
	struct request_queue___41 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___41(struct request_queue___41 *);

typedef void make_request_fn___41(struct request_queue___41 *, struct bio___42 *);

struct request___41;

typedef int prep_rq_fn___41(struct request_queue___41 *, struct request___41 *);

struct bvec_merge_data___41;

typedef int merge_bvec_fn___42(struct request_queue___41 *, struct bvec_merge_data___41 *, struct bio_vec___42 *);

typedef void softirq_done_fn___41(struct request___41 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___41(struct request___41 *);

typedef int dma_drain_needed_fn___41(struct request___41 *);

typedef int lld_busy_fn___41(struct request_queue___41 *);

struct bsg_class_device___41 {
	struct device___196 *class_dev;
	struct device___196 *parent;
	int minor;
	struct request_queue___41 *queue;
	struct kref ref;
	void (*release)(struct device___196 *);
};

typedef void unprep_rq_fn___41(struct request_queue___41 *, struct request___41 *);

struct elevator_queue___41;

struct blk_mq_ops___14;

struct blk_mq_hw_ctx___14;

struct blk_queue_tag___41;

struct blk_mq_tag_set___14;

struct request_queue___41 {
	struct list_head queue_head;
	struct request___41 *last_merge;
	struct elevator_queue___41 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___41 root_rl;
	request_fn_proc___41 *request_fn;
	make_request_fn___41 *make_request_fn;
	prep_rq_fn___41 *prep_rq_fn;
	merge_bvec_fn___42 *merge_bvec_fn;
	softirq_done_fn___41 *softirq_done_fn;
	rq_timed_out_fn___41 *rq_timed_out_fn;
	dma_drain_needed_fn___41 *dma_drain_needed;
	lld_busy_fn___41 *lld_busy_fn;
	struct blk_mq_ops___14 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___14 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___41 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___52 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___22 kobj;
	struct kobject___22 mq_kobj;
	struct device___196 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___41 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___41 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___214 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___41 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___41 *unprep_rq_fn;
	struct blk_mq_tag_set___14 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___42 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___212 {
	struct dentry___212 * (*lookup)(struct inode___212 *, struct dentry___212 *, unsigned int);
	void * (*follow_link)(struct dentry___212 *, struct nameidata *);
	int (*permission)(struct inode___212 *, int);
	struct posix_acl * (*get_acl)(struct inode___212 *, int);
	int (*readlink)(struct dentry___212 *, char *, int);
	void (*put_link)(struct dentry___212 *, struct nameidata *, void *);
	int (*create)(struct inode___212 *, struct dentry___212 *, umode_t, bool);
	int (*link)(struct dentry___212 *, struct inode___212 *, struct dentry___212 *);
	int (*unlink)(struct inode___212 *, struct dentry___212 *);
	int (*symlink)(struct inode___212 *, struct dentry___212 *, const char *);
	int (*mkdir)(struct inode___212 *, struct dentry___212 *, umode_t);
	int (*rmdir)(struct inode___212 *, struct dentry___212 *);
	int (*mknod)(struct inode___212 *, struct dentry___212 *, umode_t, dev_t);
	int (*rename)(struct inode___212 *, struct dentry___212 *, struct inode___212 *, struct dentry___212 *);
	int (*setattr)(struct dentry___212 *, struct iattr___212 *);
	int (*getattr)(struct vfsmount *, struct dentry___212 *, struct kstat *);
	int (*setxattr)(struct dentry___212 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___212 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___212 *, char *, size_t);
	int (*removexattr)(struct dentry___212 *, const char *);
	int (*fiemap)(struct inode___212 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___212 *, struct timespec *, int);
	int (*atomic_open)(struct inode___212 *, struct dentry___212 *, struct file___212 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___143;

struct file_operations___212 {
	struct module *owner;
	loff_t (*llseek)(struct file___212 *, loff_t, int);
	ssize_t (*read)(struct file___212 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___212 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___212 *, void *, filldir_t);
	unsigned int (*poll)(struct file___212 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___212 *, struct vm_area_struct___220 *);
	int (*open)(struct inode___212 *, struct file___212 *);
	int (*flush)(struct file___212 *, fl_owner_t);
	int (*release)(struct inode___212 *, struct file___212 *);
	int (*fsync)(struct file___212 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___212 *, int);
	int (*lock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*sendpage)(struct file___212 *, struct page___211 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___212 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___212 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___212 *, long int, struct file_lock___212 **, void **);
		struct {
			int (*setlease)(struct file___212 *, long int, struct file_lock___212 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___212 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___143 *, struct file___212 *);
};

struct fasync_struct___212;

struct file_lock_operations___212;

struct lock_manager_operations___212;

struct file_lock___212 {
	struct file_lock___212 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___212 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___212 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___212 *fl_ops;
	const struct lock_manager_operations___212 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___212 {
	void (*fl_copy_lock)(struct file_lock___212 *, struct file_lock___212 *);
	void (*fl_release_private)(struct file_lock___212 *);
};

struct lock_manager_operations___212 {
	int (*lm_compare_owner)(struct file_lock___212 *, struct file_lock___212 *);
	long unsigned int (*lm_owner_key)(struct file_lock___212 *);
	void (*lm_notify)(struct file_lock___212 *);
	int (*lm_grant)(struct file_lock___212 *, struct file_lock___212 *, int);
	void (*lm_break)(struct file_lock___212 *);
	int (*lm_change)(struct file_lock___212 **, int);
};

struct fasync_struct___212 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___212 *fa_next;
	struct file___212 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___212 {
	const char *name;
	int fs_flags;
	struct dentry___212 * (*mount)(struct file_system_type___212 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___212 *);
	struct module *owner;
	struct file_system_type___212 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___212 {
	struct inode___212 * (*alloc_inode)(struct super_block___212 *);
	void (*destroy_inode)(struct inode___212 *);
	void (*dirty_inode)(struct inode___212 *, int);
	int (*write_inode)(struct inode___212 *, struct writeback_control *);
	int (*drop_inode)(struct inode___212 *);
	void (*evict_inode)(struct inode___212 *);
	void (*put_super)(struct super_block___212 *);
	int (*sync_fs)(struct super_block___212 *, int);
	int (*freeze_fs)(struct super_block___212 *);
	int (*unfreeze_fs)(struct super_block___212 *);
	int (*statfs)(struct dentry___212 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___212 *, int *, char *);
	void (*umount_begin)(struct super_block___212 *);
	int (*show_options)(struct seq_file___143 *, struct dentry___212 *);
	int (*show_devname)(struct seq_file___143 *, struct dentry___212 *);
	int (*show_path)(struct seq_file___143 *, struct dentry___212 *);
	int (*show_stats)(struct seq_file___143 *, struct dentry___212 *);
	ssize_t (*quota_read)(struct super_block___212 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___212 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___212 *);
	int (*bdev_try_to_free_page)(struct super_block___212 *, struct page___211 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___212 *);
	void (*free_cached_objects)(struct super_block___212 *, int);
};

struct vm_operations_struct___192;

struct vm_area_struct___220 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___220 *vm_next;
	struct vm_area_struct___220 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___220 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___192 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___212 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___143;

struct seq_file___143 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___214 lock;
	const struct seq_operations___143 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___211 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___211 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___196;

struct memcg_cache_params___197;

struct kmem_cache___197 {
	struct kmem_cache_cpu___196 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___197 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___188;

struct vm_operations_struct___192 {
	void (*open)(struct vm_area_struct___220 *);
	void (*close)(struct vm_area_struct___220 *);
	int (*fault)(struct vm_area_struct___220 *, struct vm_fault___188 *);
	int (*page_mkwrite)(struct vm_area_struct___220 *, struct vm_fault___188 *);
	int (*access)(struct vm_area_struct___220 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___220 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___220 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___220 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___220 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___213 {
	struct task_struct___213 *task;
	struct core_thread___213 *next;
};

struct core_state___213 {
	atomic_t nr_threads;
	struct core_thread___213 dumper;
	struct completion startup;
};

struct vm_fault___188 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___211 *page;
};

struct irq_chip___139 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___139 *);
	void (*irq_shutdown)(struct irq_data___139 *);
	void (*irq_enable)(struct irq_data___139 *);
	void (*irq_disable)(struct irq_data___139 *);
	void (*irq_ack)(struct irq_data___139 *);
	void (*irq_mask)(struct irq_data___139 *);
	void (*irq_mask_ack)(struct irq_data___139 *);
	void (*irq_unmask)(struct irq_data___139 *);
	void (*irq_eoi)(struct irq_data___139 *);
	int (*irq_set_affinity)(struct irq_data___139 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___139 *);
	int (*irq_set_type)(struct irq_data___139 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___139 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___139 *);
	void (*irq_bus_sync_unlock)(struct irq_data___139 *);
	void (*irq_cpu_online)(struct irq_data___139 *);
	void (*irq_cpu_offline)(struct irq_data___139 *);
	void (*irq_suspend)(struct irq_data___139 *);
	void (*irq_resume)(struct irq_data___139 *);
	void (*irq_pm_shutdown)(struct irq_data___139 *);
	void (*irq_print_chip)(struct irq_data___139 *, struct seq_file___143 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___139 *, void *);
	long unsigned int flags;
};

struct signal_struct___213 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___213 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___213 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___214 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___41 {
	struct request_queue___41 *q;
	struct io_context___41 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___197 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct bin_attribute___172;

struct attribute_group___170 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___172 **bin_attrs;
};

struct bin_attribute___172 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___212 *, struct kobject___22 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___212 *, struct kobject___22 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	int (*mmap)(struct file___212 *, struct kobject___22 *, struct bin_attribute___172 *, struct vm_area_struct___220 *);
};

struct kmem_cache_cpu___196 {
	void **freelist;
	long unsigned int tid;
	struct page___211 *page;
	struct page___211 *partial;
};

struct memcg_cache_params___197 {
	bool is_root_cache;
	union {
		struct kmem_cache___197 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___197 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___82 {
	void * (*alloc)(struct device___196 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___196 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___196 *, struct vm_area_struct___220 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___196 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___196 *, struct page___211 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___196 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___196 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___196 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___196 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___196 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___196 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___196 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___196 *, dma_addr_t);
	int (*dma_supported)(struct device___196 *, u64);
	int (*set_dma_mask)(struct device___196 *, u64);
	int is_phys;
};

struct bus_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___196 *, char *);
	ssize_t (*store)(struct bus_type___196 *, const char *, size_t);
};

struct device_attribute___196;

struct driver_attribute___196;

struct bus_type___196 {
	const char *name;
	const char *dev_name;
	struct device___196 *dev_root;
	struct bus_attribute___196 *bus_attrs;
	struct device_attribute___196 *dev_attrs;
	struct driver_attribute___196 *drv_attrs;
	const struct attribute_group___170 **bus_groups;
	const struct attribute_group___170 **dev_groups;
	const struct attribute_group___170 **drv_groups;
	int (*match)(struct device___196 *, struct device_driver___196 *);
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	int (*probe)(struct device___196 *);
	int (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*online)(struct device___196 *);
	int (*offline)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct device___196 *, struct device_attribute___196 *, char *);
	ssize_t (*store)(struct device___196 *, struct device_attribute___196 *, const char *, size_t);
};

struct driver_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___196 *, char *);
	ssize_t (*store)(struct device_driver___196 *, const char *, size_t);
};

struct device_driver___196 {
	const char *name;
	struct bus_type___196 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___196 *);
	int (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	const struct attribute_group___170 **groups;
	const struct dev_pm_ops___196 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___196 {
	const char *name;
	const struct attribute_group___170 **groups;
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
};

struct class_attribute___196;

struct class___196 {
	const char *name;
	struct module *owner;
	struct class_attribute___196 *class_attrs;
	struct device_attribute___196 *dev_attrs;
	const struct attribute_group___170 **dev_groups;
	struct bin_attribute___172 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *);
	void (*class_release)(struct class___196 *);
	void (*dev_release)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
	struct subsys_private *p;
};

struct class_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct class___196 *, struct class_attribute___196 *, char *);
	ssize_t (*store)(struct class___196 *, struct class_attribute___196 *, const char *, size_t);
	const void * (*namespace)(struct class___196 *, const struct class_attribute___196 *);
};

struct device_rh___196 {
	struct dev_pm_info_rh___196 power;
};

struct disk_part_tbl___45 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___45 *last_lookup;
	struct hd_struct___45 *part[0];
};

struct block_device_operations___41 {
	int (*open)(struct block_device___212 *, fmode_t);
	void (*release)(struct gendisk___45 *, fmode_t);
	int (*ioctl)(struct block_device___212 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___212 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___212 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___45 *, unsigned int);
	int (*media_changed)(struct gendisk___45 *);
	void (*unlock_native_capacity)(struct gendisk___45 *);
	int (*revalidate_disk)(struct gendisk___45 *);
	int (*getgeo)(struct block_device___212 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___212 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

typedef void rq_end_io_fn___41(struct request___41 *, int);

struct request___41 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___41 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___42 *bio;
	struct bio___42 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___41 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___41 *saved_end_io;
		} flush;
	};
	struct gendisk___45 *rq_disk;
	struct hd_struct___45 *part;
	long unsigned int start_time;
	struct request_list___41 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___41 *end_io;
	void *end_io_data;
	struct request___41 *next_rq;
};

typedef int elevator_merge_fn___41(struct request_queue___41 *, struct request___41 **, struct bio___42 *);

typedef void elevator_merge_req_fn___41(struct request_queue___41 *, struct request___41 *, struct request___41 *);

typedef void elevator_merged_fn___41(struct request_queue___41 *, struct request___41 *, int);

typedef int elevator_allow_merge_fn___41(struct request_queue___41 *, struct request___41 *, struct bio___42 *);

typedef void elevator_bio_merged_fn___41(struct request_queue___41 *, struct request___41 *, struct bio___42 *);

typedef int elevator_dispatch_fn___41(struct request_queue___41 *, int);

typedef void elevator_add_req_fn___41(struct request_queue___41 *, struct request___41 *);

typedef struct request___41 *elevator_request_list_fn___41(struct request_queue___41 *, struct request___41 *);

typedef void elevator_completed_req_fn___41(struct request_queue___41 *, struct request___41 *);

typedef int elevator_may_queue_fn___41(struct request_queue___41 *, int);

typedef void elevator_init_icq_fn___41(struct io_cq___41 *);

typedef void elevator_exit_icq_fn___41(struct io_cq___41 *);

typedef int elevator_set_req_fn___41(struct request_queue___41 *, struct request___41 *, struct bio___42 *, gfp_t);

typedef void elevator_put_req_fn___41(struct request___41 *);

typedef void elevator_activate_req_fn___41(struct request_queue___41 *, struct request___41 *);

typedef void elevator_deactivate_req_fn___41(struct request_queue___41 *, struct request___41 *);

struct elevator_type___41;

typedef int elevator_init_fn___42(struct request_queue___41 *, struct elevator_type___41 *);

typedef void elevator_exit_fn___41(struct elevator_queue___41 *);

struct elevator_ops___41 {
	elevator_merge_fn___41 *elevator_merge_fn;
	elevator_merged_fn___41 *elevator_merged_fn;
	elevator_merge_req_fn___41 *elevator_merge_req_fn;
	elevator_allow_merge_fn___41 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___41 *elevator_bio_merged_fn;
	elevator_dispatch_fn___41 *elevator_dispatch_fn;
	elevator_add_req_fn___41 *elevator_add_req_fn;
	elevator_activate_req_fn___41 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___41 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___41 *elevator_completed_req_fn;
	elevator_request_list_fn___41 *elevator_former_req_fn;
	elevator_request_list_fn___41 *elevator_latter_req_fn;
	elevator_init_icq_fn___41 *elevator_init_icq_fn;
	elevator_exit_icq_fn___41 *elevator_exit_icq_fn;
	elevator_set_req_fn___41 *elevator_set_req_fn;
	elevator_put_req_fn___41 *elevator_put_req_fn;
	elevator_may_queue_fn___41 *elevator_may_queue_fn;
	elevator_init_fn___42 *elevator_init_fn;
	elevator_exit_fn___41 *elevator_exit_fn;
};

struct elv_fs_entry___41;

struct elevator_type___41 {
	struct kmem_cache___197 *icq_cache;
	struct elevator_ops___41 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___41 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___41 {
	struct elevator_type___41 *type;
	void *elevator_data;
	struct kobject___22 kobj;
	struct mutex___214 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___41 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___41 *, char *);
	ssize_t (*store)(struct elevator_queue___41 *, const char *, size_t);
};

struct bvec_merge_data___41 {
	struct block_device___212 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___41 {
	struct request___41 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___14;

typedef int queue_rq_fn___15(struct blk_mq_hw_ctx___14 *, const struct blk_mq_queue_data___14 *);

typedef struct blk_mq_hw_ctx___14 *map_queue_fn___15(struct request_queue___41 *, const int);

typedef enum blk_eh_timer_return timeout_fn___15(struct request___41 *, bool);

typedef int init_request_fn___15(void *, struct request___41 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___15(void *, struct request___41 *, unsigned int, unsigned int);

typedef int init_hctx_fn___14(struct blk_mq_hw_ctx___14 *, void *, unsigned int);

typedef void exit_hctx_fn___14(struct blk_mq_hw_ctx___14 *, unsigned int);

struct blk_mq_ops___14 {
	queue_rq_fn___15 *queue_rq;
	map_queue_fn___15 *map_queue;
	union {
		timeout_fn___15 *timeout;
		struct {
			rq_timed_out_fn___41 *timeout;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	softirq_done_fn___41 *complete;
	init_request_fn___15 *init_request;
	exit_request_fn___15 *exit_request;
	init_hctx_fn___14 *init_hctx;
	exit_hctx_fn___14 *exit_hctx;
};

struct blk_mq_hw_ctx___14 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___41 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct request___41 **padding2;
		struct {
			struct request___41 **rqs;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier cpu_notifier;
	struct kobject___22 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___14 {
	struct blk_mq_ops___14 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___214 tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___14 {
	struct request___41 *rq;
	struct list_head *list;
	bool last;
};

struct scsi_varlen_cdb_hdr {
	__u8 opcode;
	__u8 control;
	__u8 misc[5];
	__u8 additional_cdb_length;
	__be16 service_action;
};

struct scsi_mode_data {
	__u32 length;
	__u16 block_descriptor_length;
	__u8 medium_type;
	__u8 device_specific;
	__u8 header_length;
	__u8 longlba: 1;
};

struct scsi_event {
	enum scsi_device_event evt_type;
	struct list_head node;
};

struct Scsi_Host___2;

struct scsi_cmnd___2;

struct scsi_target___2;

struct scsi_dh_data___2;

struct scsi_device___2 {
	struct Scsi_Host___2 *host;
	struct request_queue___41 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd___2 *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___2 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___196 sdev_gendev;
	struct device___196 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___2 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___2;

struct Scsi_Host___2 {
	struct list_head __devices;
	struct list_head __targets;
	struct scsi_host_cmd_pool *cmd_pool;
	spinlock_t free_list_lock;
	struct list_head free_list;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex___214 scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___213 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___2 *hostt;
	struct scsi_transport_template *transportt;
	union {
		struct blk_queue_tag___41 *bqt;
		struct blk_mq_tag_set___14 *tag_set;
	};
	union {
		atomic_t host_busy;
		struct {
			unsigned int host_busy;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_id;
	unsigned int max_lun;
	unsigned int max_channel;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int use_blk_tcq: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int ordered_tag: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_blk_mq: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	union {
		atomic_t host_blocked;
		struct {
			unsigned int host_blocked;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	struct request_queue___41 *uspace_req_q;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___196 shost_gendev;
	struct device___196 shost_dev;
	struct list_head sht_legacy_list;
	void *shost_data;
	struct device___196 *dma_dev;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	unsigned int scsi_mq_reserved1;
	unsigned int scsi_mq_reserved2;
	void *scsi_mq_reserved3;
	void *scsi_mq_reserved4;
	atomic_t scsi_mq_reserved5;
	atomic_t scsi_mq_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_cmnd___2 {
	struct scsi_device___2 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___41 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___2 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	unsigned char tag;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
};

struct scsi_target___2 {
	struct scsi_device___2 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___196 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___2;

struct scsi_dh_data___2 {
	struct scsi_device_handler___2 *scsi_dh;
	struct scsi_device___2 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___2 {
	struct list_head list;
	struct module *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___2 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___2 *);
	void (*detach)(struct scsi_device___2 *);
	int (*activate)(struct scsi_device___2 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___2 *, struct request___41 *);
	int (*set_params)(struct scsi_device___2 *, const char *);
	bool (*match)(struct scsi_device___2 *);
};

struct scsi_driver___2 {
	struct module *owner;
	struct device_driver___196 gendrv;
	void (*rescan)(struct device___196 *);
	int (*init_command)(struct scsi_cmnd___2 *);
	void (*uninit_command)(struct scsi_cmnd___2 *);
	int (*done)(struct scsi_cmnd___2 *);
	int (*eh_action)(struct scsi_cmnd___2 *, int);
	int (*scsi_mq_reserved1)(struct scsi_cmnd___2 *);
	void (*scsi_mq_reserved2)(struct scsi_cmnd___2 *);
	void (*rh_reserved)();
};

struct seq_operations___143 {
	void * (*start)(struct seq_file___143 *, loff_t *);
	void (*stop)(struct seq_file___143 *, void *);
	void * (*next)(struct seq_file___143 *, void *, loff_t *);
	int (*show)(struct seq_file___143 *, void *);
};

struct scsi_host_template___2 {
	struct module *module;
	const char *name;
	int (*detect)(struct scsi_host_template___2 *);
	int (*release)(struct Scsi_Host___2 *);
	const char * (*info)(struct Scsi_Host___2 *);
	int (*ioctl)(struct scsi_device___2 *, int, void *);
	int (*compat_ioctl)(struct scsi_device___2 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___2 *, struct scsi_cmnd___2 *);
	int (*transfer_response)(struct scsi_cmnd___2 *, void (*)(struct scsi_cmnd___2 *));
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___2 *);
	int (*slave_configure)(struct scsi_device___2 *);
	void (*slave_destroy)(struct scsi_device___2 *);
	int (*target_alloc)(struct scsi_target___2 *);
	void (*target_destroy)(struct scsi_target___2 *);
	int (*scan_finished)(struct Scsi_Host___2 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___2 *);
	int (*change_queue_depth)(struct scsi_device___2 *, int, int);
	int (*change_queue_type)(struct scsi_device___2 *, int);
	int (*bios_param)(struct scsi_device___2 *, struct block_device___212 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___2 *);
	int (*show_info)(struct seq_file___143 *, struct Scsi_Host___2 *);
	int (*write_info)(struct Scsi_Host___2 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___2 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int ordered_tag: 1;
	unsigned int no_write_same: 1;
	unsigned int no_async_abort: 1;
	unsigned int disable_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___196 **shost_attrs;
	struct device_attribute___196 **sdev_attrs;
	struct list_head legacy_hosts;
	u64 vendor_id;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	union {
		unsigned int cmd_size;
		struct {
			unsigned int scsi_mq_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	unsigned int scsi_mq_reserved2;
	union {
		struct scsi_host_cmd_pool *cmd_pool;
		struct {
			void *scsi_mq_reserved3;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void *scsi_mq_reserved4;
};

struct scsi_host_sg_pool {
	size_t size;
	char *name;
	struct kmem_cache___197 *slab;
	mempool_t *pool;
};

enum {
	ACTION_FAIL = 0,
	ACTION_REPREP = 1,
	ACTION_RETRY = 2,
	ACTION_DELAYED_RETRY = 3,
};

struct page___212;

typedef struct page___212 *pgtable_t___212;

struct address_space___213;

struct kmem_cache___198;

struct page___212 {
	long unsigned int flags;
	struct address_space___213 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___212 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___212 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___198 *slab_cache;
		struct page___212 *first_page;
	};
	long: 64;
};

struct task_struct___214;

struct pv_cpu_ops___214 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___214 *);
	void (*end_context_switch)(struct task_struct___214 *);
};

struct mutex___215 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___214 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___207 {
	struct page___212 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___221;

struct signal_struct___214;

struct bio_list___42;

struct backing_dev_info___53;

struct io_context___42;

struct task_struct___214 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___214 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___221 *mm;
	struct mm_struct___221 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___214 *real_parent;
	struct task_struct___214 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___214 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___214 = 0,
		VTIME_USER___214 = 1,
		VTIME_SYS___214 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___214 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___42 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___53 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___215 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___207 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___221 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___221 *, struct mm_struct___221 *);
	void (*dup_mmap)(struct mm_struct___221 *, struct mm_struct___221 *);
	void (*exit_mmap)(struct mm_struct___221 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___221 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___221 *);
	void (*pgd_free)(struct mm_struct___221 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___221 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___221 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___221 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___221 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___221 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___221 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___221 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___221 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___221 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___221 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___221 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___215 lock;
	void *vdso;
} mm_context_t___215;

struct xol_area___212;

struct uprobes_state___212 {
	struct xol_area___212 *xol_area;
};

struct vm_area_struct___221;

struct file___213;

struct core_state___214;

struct mm_struct___221 {
	struct vm_area_struct___221 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___221 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___221 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___215 context;
	long unsigned int flags;
	struct core_state___214 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___214 *owner;
	struct file___213 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___212 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___124;

struct module_kobject___123 {
	struct kobject___22 kobj;
	struct module___124 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___123;

struct module___124 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___123 mkobj;
	struct module_attribute___123 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___214 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___212 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___212 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___197;

struct memcg_cache_params___198;

struct kmem_cache___198 {
	struct kmem_cache_cpu___197 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___22 kobj;
	struct memcg_cache_params___198 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___213;

struct address_space_operations___213;

struct address_space___213 {
	struct inode___213 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___215 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___213 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___53 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___213;

struct path___213 {
	struct vfsmount *mnt;
	struct dentry___213 *dentry;
};

struct file_operations___213;

struct file___213 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___213 f_path;
	struct inode___213 *f_inode;
	const struct file_operations___213 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___213 *f_mapping;
	struct mutex___215 f_pos_lock;
};

struct vm_operations_struct___193;

struct vm_area_struct___221 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___221 *vm_next;
	struct vm_area_struct___221 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___221 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___193 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___213 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___189;

struct vm_operations_struct___193 {
	void (*open)(struct vm_area_struct___221 *);
	void (*close)(struct vm_area_struct___221 *);
	int (*fault)(struct vm_area_struct___221 *, struct vm_fault___189 *);
	int (*page_mkwrite)(struct vm_area_struct___221 *, struct vm_fault___189 *);
	int (*access)(struct vm_area_struct___221 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___221 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___221 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___221 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___221 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___214 {
	struct task_struct___214 *task;
	struct core_thread___214 *next;
};

struct core_state___214 {
	atomic_t nr_threads;
	struct core_thread___214 dumper;
	struct completion startup;
};

struct irq_data___140;

struct x86_io_apic_ops___140 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___140 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___140;

struct irq_data___140 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___140 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___197;

struct dev_pm_ops___197 {
	int (*prepare)(struct device___197 *);
	void (*complete)(struct device___197 *);
	int (*suspend)(struct device___197 *);
	int (*resume)(struct device___197 *);
	int (*freeze)(struct device___197 *);
	int (*thaw)(struct device___197 *);
	int (*poweroff)(struct device___197 *);
	int (*restore)(struct device___197 *);
	int (*suspend_late)(struct device___197 *);
	int (*resume_early)(struct device___197 *);
	int (*freeze_late)(struct device___197 *);
	int (*thaw_early)(struct device___197 *);
	int (*poweroff_late)(struct device___197 *);
	int (*restore_early)(struct device___197 *);
	int (*suspend_noirq)(struct device___197 *);
	int (*resume_noirq)(struct device___197 *);
	int (*freeze_noirq)(struct device___197 *);
	int (*thaw_noirq)(struct device___197 *);
	int (*poweroff_noirq)(struct device___197 *);
	int (*restore_noirq)(struct device___197 *);
	int (*runtime_suspend)(struct device___197 *);
	int (*runtime_resume)(struct device___197 *);
	int (*runtime_idle)(struct device___197 *);
};

struct dma_map_ops___83;

struct dev_archdata___83 {
	struct dma_map_ops___83 *dma_ops;
	void *iommu;
};

struct device_type___197;

struct bus_type___197;

struct device_driver___197;

struct dev_pm_domain___197;

struct class___197;

struct attribute_group___171;

struct device_rh___197;

struct device___197 {
	struct device___197 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___197 *type;
	struct mutex___215 mutex;
	struct bus_type___197 *bus;
	struct device_driver___197 *driver;
	void *platform_data;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___197 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___83 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___30 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___197 *class;
	const struct attribute_group___171 **groups;
	void (*release)(struct device___197 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___197 *device_rh;
};

struct dev_pm_info_rh___197 {
	void (*set_latency_tolerance)(struct device___197 *, s32);
};

struct dev_pm_domain___197 {
	struct dev_pm_ops___197 ops;
};

struct smp_ops___214 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___214 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___214;

struct lruvec___214 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___214 *zone;
};

struct pglist_data___214;

struct zone___214 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___214 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___214 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___214 {
	struct zone___214 *zone;
	int zone_idx;
};

struct zonelist___214 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___214 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___214 {
	struct zone___214 node_zones[4];
	struct zonelist___214 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___214 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___214 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___214 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___214 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___215 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___43;

struct bio_list___42 {
	struct bio___43 *head;
	struct bio___43 *tail;
};

struct bdi_writeback___53 {
	struct backing_dev_info___53 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___53 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___53 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___197 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___213 *debug_dir;
	struct dentry___213 *debug_stats;
};

struct io_cq___42;

struct io_context___42 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___42 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bin_attribute___173;

struct attribute_group___171 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___173 **bin_attrs;
};

struct bin_attribute___173 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___213 *, struct kobject___22 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___213 *, struct kobject___22 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	int (*mmap)(struct file___213 *, struct kobject___22 *, struct bin_attribute___173 *, struct vm_area_struct___221 *);
};

struct kmem_cache_cpu___197 {
	void **freelist;
	long unsigned int tid;
	struct page___212 *page;
	struct page___212 *partial;
};

struct memcg_cache_params___198 {
	bool is_root_cache;
	union {
		struct kmem_cache___198 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___198 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___83 {
	void * (*alloc)(struct device___197 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___197 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___197 *, struct vm_area_struct___221 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___197 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___197 *, struct page___212 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___197 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___197 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___197 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___197 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___197 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___197 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___197 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___197 *, dma_addr_t);
	int (*dma_supported)(struct device___197 *, u64);
	int (*set_dma_mask)(struct device___197 *, u64);
	int is_phys;
};

struct bus_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___197 *, char *);
	ssize_t (*store)(struct bus_type___197 *, const char *, size_t);
};

struct device_attribute___197;

struct driver_attribute___197;

struct bus_type___197 {
	const char *name;
	const char *dev_name;
	struct device___197 *dev_root;
	struct bus_attribute___197 *bus_attrs;
	struct device_attribute___197 *dev_attrs;
	struct driver_attribute___197 *drv_attrs;
	const struct attribute_group___171 **bus_groups;
	const struct attribute_group___171 **dev_groups;
	const struct attribute_group___171 **drv_groups;
	int (*match)(struct device___197 *, struct device_driver___197 *);
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	int (*probe)(struct device___197 *);
	int (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*online)(struct device___197 *);
	int (*offline)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct device___197 *, struct device_attribute___197 *, char *);
	ssize_t (*store)(struct device___197 *, struct device_attribute___197 *, const char *, size_t);
};

struct driver_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___197 *, char *);
	ssize_t (*store)(struct device_driver___197 *, const char *, size_t);
};

struct device_driver___197 {
	const char *name;
	struct bus_type___197 *bus;
	struct module___124 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___197 *);
	int (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	const struct attribute_group___171 **groups;
	const struct dev_pm_ops___197 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___197 {
	const char *name;
	const struct attribute_group___171 **groups;
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
};

struct class_attribute___197;

struct class___197 {
	const char *name;
	struct module___124 *owner;
	struct class_attribute___197 *class_attrs;
	struct device_attribute___197 *dev_attrs;
	const struct attribute_group___171 **dev_groups;
	struct bin_attribute___173 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *);
	void (*class_release)(struct class___197 *);
	void (*dev_release)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
	struct subsys_private *p;
};

struct class_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct class___197 *, struct class_attribute___197 *, char *);
	ssize_t (*store)(struct class___197 *, struct class_attribute___197 *, const char *, size_t);
	const void * (*namespace)(struct class___197 *, const struct class_attribute___197 *);
};

struct device_rh___197 {
	struct dev_pm_info_rh___197 power;
};

struct dentry_operations___213;

struct super_block___213;

struct dentry___213 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___213 *d_parent;
	struct qstr d_name;
	struct inode___213 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___213 *d_op;
	struct super_block___213 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___213;

struct file_lock___213;

struct dquot___213;

struct block_device___213;

struct inode___213 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___213 *i_op;
	struct super_block___213 *i_sb;
	struct address_space___213 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___215 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___213 *i_fop;
	struct file_lock___213 *i_flock;
	struct address_space___213 i_data;
	struct dquot___213 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___213 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___213 {
	int (*d_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_hash)(const struct dentry___213 *, struct qstr *);
	int (*d_compare)(const struct dentry___213 *, const struct dentry___213 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___213 *);
	void (*d_release)(struct dentry___213 *);
	void (*d_prune)(struct dentry___213 *);
	void (*d_iput)(struct dentry___213 *, struct inode___213 *);
	char * (*d_dname)(struct dentry___213 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___213 *);
	int (*d_manage)(struct dentry___213 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___213;

struct mem_dqinfo___213 {
	struct quota_format_type___213 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___213;

struct quota_info___213 {
	unsigned int flags;
	struct mutex___215 dqio_mutex;
	struct mutex___215 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___213 *files[2];
	struct mem_dqinfo___213 info[2];
	const struct quota_format_ops___213 *ops[2];
};

struct file_system_type___213;

struct super_operations___213;

struct dquot_operations___213;

struct quotactl_ops___213;

struct super_block___213 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___213 *s_type;
	const struct super_operations___213 *s_op;
	const struct dquot_operations___213 *dq_op;
	const struct quotactl_ops___213 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___213 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___213 *s_bdev;
	struct backing_dev_info___53 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___213 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___215 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___213 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___43(struct bio___43 *, int);

struct bio_vec___43 {
	struct page___212 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___43;

struct bio_set___43;

struct bio___43 {
	sector_t bi_sector;
	struct bio___43 *bi_next;
	struct block_device___213 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___43 *bi_end_io;
	void *bi_private;
	struct io_context___42 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___43 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___43 *bi_io_vec;
	struct bio_set___43 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___43 bi_inline_vecs[0];
};

struct hd_struct___46;

struct gendisk___46;

struct request_queue___42;

struct block_device___213 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___213 *bd_inode;
	struct super_block___213 *bd_super;
	struct mutex___215 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___213 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___46 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___46 *bd_disk;
	struct request_queue___42 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___215 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___43 {
	struct bio___43 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___43 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___43 *bip_vec;
	struct bio_vec___43 bip_inline_vecs[0];
};

struct bio_set___43 {
	struct kmem_cache___198 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___42 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___213 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___213 *ia_file;
};

struct dquot___213 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___215 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___213 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___213 {
	int qf_fmt_id;
	const struct quota_format_ops___213 *qf_ops;
	struct module___124 *qf_owner;
	struct quota_format_type___213 *qf_next;
};

struct quota_format_ops___213 {
	int (*check_quota_file)(struct super_block___213 *, int);
	int (*read_file_info)(struct super_block___213 *, int);
	int (*write_file_info)(struct super_block___213 *, int);
	int (*free_file_info)(struct super_block___213 *, int);
	int (*read_dqblk)(struct dquot___213 *);
	int (*commit_dqblk)(struct dquot___213 *);
	int (*release_dqblk)(struct dquot___213 *);
};

struct dquot_operations___213 {
	int (*write_dquot)(struct dquot___213 *);
	struct dquot___213 * (*alloc_dquot)(struct super_block___213 *, int);
	void (*destroy_dquot)(struct dquot___213 *);
	int (*acquire_dquot)(struct dquot___213 *);
	int (*release_dquot)(struct dquot___213 *);
	int (*mark_dirty)(struct dquot___213 *);
	int (*write_info)(struct super_block___213 *, int);
	qsize_t * (*get_reserved_space)(struct inode___213 *);
};

struct quotactl_ops___213 {
	int (*quota_on)(struct super_block___213 *, int, int, struct path___213 *);
	int (*quota_on_meta)(struct super_block___213 *, int, int);
	int (*quota_off)(struct super_block___213 *, int);
	int (*quota_sync)(struct super_block___213 *, int);
	int (*get_info)(struct super_block___213 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___213 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___213 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___213 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___213 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___213 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___213 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___213 *, unsigned int);
};

struct address_space_operations___213 {
	int (*writepage)(struct page___212 *, struct writeback_control *);
	int (*readpage)(struct file___213 *, struct page___212 *);
	int (*writepages)(struct address_space___213 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___212 *);
	int (*readpages)(struct file___213 *, struct address_space___213 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___213 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___212 **, void **);
	int (*write_end)(struct file___213 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___212 *, void *);
	sector_t (*bmap)(struct address_space___213 *, sector_t);
	void (*invalidatepage)(struct page___212 *, long unsigned int);
	int (*releasepage)(struct page___212 *, gfp_t);
	void (*freepage)(struct page___212 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___213 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___213 *, struct page___212 *, struct page___212 *, enum migrate_mode);
	int (*launder_page)(struct page___212 *);
	int (*is_partially_uptodate)(struct page___212 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___212 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___213 *, struct page___212 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___213 *, sector_t *);
	void (*swap_deactivate)(struct file___213 *);
	void (*invalidatepage_range)(struct page___212 *, unsigned int, unsigned int);
};

struct hd_struct___46 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___197 __dev;
	struct kobject___22 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___46;

struct block_device_operations___42;

struct gendisk___46 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___46 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___46 *part_tbl;
	struct hd_struct___46 part0;
	const struct block_device_operations___42 *fops;
	struct request_queue___42 *queue;
	void *private_data;
	int flags;
	struct device___197 *driverfs_dev;
	struct kobject___22 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity *integrity;
	int node_id;
};

struct request_list___42 {
	struct request_queue___42 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___42(struct request_queue___42 *);

typedef void make_request_fn___42(struct request_queue___42 *, struct bio___43 *);

struct request___42;

typedef int prep_rq_fn___42(struct request_queue___42 *, struct request___42 *);

struct bvec_merge_data___42;

typedef int merge_bvec_fn___43(struct request_queue___42 *, struct bvec_merge_data___42 *, struct bio_vec___43 *);

typedef void softirq_done_fn___42(struct request___42 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___42(struct request___42 *);

typedef int dma_drain_needed_fn___42(struct request___42 *);

typedef int lld_busy_fn___42(struct request_queue___42 *);

struct bsg_class_device___42 {
	struct device___197 *class_dev;
	struct device___197 *parent;
	int minor;
	struct request_queue___42 *queue;
	struct kref ref;
	void (*release)(struct device___197 *);
};

typedef void unprep_rq_fn___42(struct request_queue___42 *, struct request___42 *);

struct elevator_queue___42;

struct blk_mq_ops___15;

struct blk_mq_hw_ctx___15;

struct blk_queue_tag___42;

struct blk_mq_tag_set___15;

struct request_queue___42 {
	struct list_head queue_head;
	struct request___42 *last_merge;
	struct elevator_queue___42 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___42 root_rl;
	request_fn_proc___42 *request_fn;
	make_request_fn___42 *make_request_fn;
	prep_rq_fn___42 *prep_rq_fn;
	merge_bvec_fn___43 *merge_bvec_fn;
	softirq_done_fn___42 *softirq_done_fn;
	rq_timed_out_fn___42 *rq_timed_out_fn;
	dma_drain_needed_fn___42 *dma_drain_needed;
	lld_busy_fn___42 *lld_busy_fn;
	struct blk_mq_ops___15 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___15 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___42 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___53 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___22 kobj;
	struct kobject___22 mq_kobj;
	struct device___197 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___42 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___42 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___215 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___42 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___42 *unprep_rq_fn;
	struct blk_mq_tag_set___15 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___43 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___213 {
	struct dentry___213 * (*lookup)(struct inode___213 *, struct dentry___213 *, unsigned int);
	void * (*follow_link)(struct dentry___213 *, struct nameidata *);
	int (*permission)(struct inode___213 *, int);
	struct posix_acl * (*get_acl)(struct inode___213 *, int);
	int (*readlink)(struct dentry___213 *, char *, int);
	void (*put_link)(struct dentry___213 *, struct nameidata *, void *);
	int (*create)(struct inode___213 *, struct dentry___213 *, umode_t, bool);
	int (*link)(struct dentry___213 *, struct inode___213 *, struct dentry___213 *);
	int (*unlink)(struct inode___213 *, struct dentry___213 *);
	int (*symlink)(struct inode___213 *, struct dentry___213 *, const char *);
	int (*mkdir)(struct inode___213 *, struct dentry___213 *, umode_t);
	int (*rmdir)(struct inode___213 *, struct dentry___213 *);
	int (*mknod)(struct inode___213 *, struct dentry___213 *, umode_t, dev_t);
	int (*rename)(struct inode___213 *, struct dentry___213 *, struct inode___213 *, struct dentry___213 *);
	int (*setattr)(struct dentry___213 *, struct iattr___213 *);
	int (*getattr)(struct vfsmount *, struct dentry___213 *, struct kstat *);
	int (*setxattr)(struct dentry___213 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___213 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___213 *, char *, size_t);
	int (*removexattr)(struct dentry___213 *, const char *);
	int (*fiemap)(struct inode___213 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___213 *, struct timespec *, int);
	int (*atomic_open)(struct inode___213 *, struct dentry___213 *, struct file___213 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___144;

struct file_operations___213 {
	struct module___124 *owner;
	loff_t (*llseek)(struct file___213 *, loff_t, int);
	ssize_t (*read)(struct file___213 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___213 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___213 *, void *, filldir_t);
	unsigned int (*poll)(struct file___213 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___213 *, struct vm_area_struct___221 *);
	int (*open)(struct inode___213 *, struct file___213 *);
	int (*flush)(struct file___213 *, fl_owner_t);
	int (*release)(struct inode___213 *, struct file___213 *);
	int (*fsync)(struct file___213 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___213 *, int);
	int (*lock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*sendpage)(struct file___213 *, struct page___212 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___213 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___213 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___213 *, long int, struct file_lock___213 **, void **);
		struct {
			int (*setlease)(struct file___213 *, long int, struct file_lock___213 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___213 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___144 *, struct file___213 *);
};

struct fasync_struct___213;

struct file_lock_operations___213;

struct lock_manager_operations___213;

struct file_lock___213 {
	struct file_lock___213 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___213 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___213 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___213 *fl_ops;
	const struct lock_manager_operations___213 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___213 {
	void (*fl_copy_lock)(struct file_lock___213 *, struct file_lock___213 *);
	void (*fl_release_private)(struct file_lock___213 *);
};

struct lock_manager_operations___213 {
	int (*lm_compare_owner)(struct file_lock___213 *, struct file_lock___213 *);
	long unsigned int (*lm_owner_key)(struct file_lock___213 *);
	void (*lm_notify)(struct file_lock___213 *);
	int (*lm_grant)(struct file_lock___213 *, struct file_lock___213 *, int);
	void (*lm_break)(struct file_lock___213 *);
	int (*lm_change)(struct file_lock___213 **, int);
};

struct fasync_struct___213 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___213 *fa_next;
	struct file___213 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___213 {
	const char *name;
	int fs_flags;
	struct dentry___213 * (*mount)(struct file_system_type___213 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___213 *);
	struct module___124 *owner;
	struct file_system_type___213 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___213 {
	struct inode___213 * (*alloc_inode)(struct super_block___213 *);
	void (*destroy_inode)(struct inode___213 *);
	void (*dirty_inode)(struct inode___213 *, int);
	int (*write_inode)(struct inode___213 *, struct writeback_control *);
	int (*drop_inode)(struct inode___213 *);
	void (*evict_inode)(struct inode___213 *);
	void (*put_super)(struct super_block___213 *);
	int (*sync_fs)(struct super_block___213 *, int);
	int (*freeze_fs)(struct super_block___213 *);
	int (*unfreeze_fs)(struct super_block___213 *);
	int (*statfs)(struct dentry___213 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___213 *, int *, char *);
	void (*umount_begin)(struct super_block___213 *);
	int (*show_options)(struct seq_file___144 *, struct dentry___213 *);
	int (*show_devname)(struct seq_file___144 *, struct dentry___213 *);
	int (*show_path)(struct seq_file___144 *, struct dentry___213 *);
	int (*show_stats)(struct seq_file___144 *, struct dentry___213 *);
	ssize_t (*quota_read)(struct super_block___213 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___213 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___213 *);
	int (*bdev_try_to_free_page)(struct super_block___213 *, struct page___212 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___213 *);
	void (*free_cached_objects)(struct super_block___213 *, int);
};

struct seq_operations___144;

struct seq_file___144 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___215 lock;
	const struct seq_operations___144 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___46 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___46 *last_lookup;
	struct hd_struct___46 *part[0];
};

struct block_device_operations___42 {
	int (*open)(struct block_device___213 *, fmode_t);
	void (*release)(struct gendisk___46 *, fmode_t);
	int (*ioctl)(struct block_device___213 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___213 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___213 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___46 *, unsigned int);
	int (*media_changed)(struct gendisk___46 *);
	void (*unlock_native_capacity)(struct gendisk___46 *);
	int (*revalidate_disk)(struct gendisk___46 *);
	int (*getgeo)(struct block_device___213 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___213 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___124 *owner;
};

struct vm_fault___189 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___212 *page;
};

struct irq_chip___140 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___140 *);
	void (*irq_shutdown)(struct irq_data___140 *);
	void (*irq_enable)(struct irq_data___140 *);
	void (*irq_disable)(struct irq_data___140 *);
	void (*irq_ack)(struct irq_data___140 *);
	void (*irq_mask)(struct irq_data___140 *);
	void (*irq_mask_ack)(struct irq_data___140 *);
	void (*irq_unmask)(struct irq_data___140 *);
	void (*irq_eoi)(struct irq_data___140 *);
	int (*irq_set_affinity)(struct irq_data___140 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___140 *);
	int (*irq_set_type)(struct irq_data___140 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___140 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___140 *);
	void (*irq_bus_sync_unlock)(struct irq_data___140 *);
	void (*irq_cpu_online)(struct irq_data___140 *);
	void (*irq_cpu_offline)(struct irq_data___140 *);
	void (*irq_suspend)(struct irq_data___140 *);
	void (*irq_resume)(struct irq_data___140 *);
	void (*irq_pm_shutdown)(struct irq_data___140 *);
	void (*irq_print_chip)(struct irq_data___140 *, struct seq_file___144 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___140 *, void *);
	long unsigned int flags;
};

struct io_cq___42 {
	struct request_queue___42 *q;
	struct io_context___42 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___198 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___42(struct request___42 *, int);

struct request___42 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___42 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___43 *bio;
	struct bio___43 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___42 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___42 *saved_end_io;
		} flush;
	};
	struct gendisk___46 *rq_disk;
	struct hd_struct___46 *part;
	long unsigned int start_time;
	struct request_list___42 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___42 *end_io;
	void *end_io_data;
	struct request___42 *next_rq;
};

typedef int elevator_merge_fn___42(struct request_queue___42 *, struct request___42 **, struct bio___43 *);

typedef void elevator_merge_req_fn___42(struct request_queue___42 *, struct request___42 *, struct request___42 *);

typedef void elevator_merged_fn___42(struct request_queue___42 *, struct request___42 *, int);

typedef int elevator_allow_merge_fn___42(struct request_queue___42 *, struct request___42 *, struct bio___43 *);

typedef void elevator_bio_merged_fn___42(struct request_queue___42 *, struct request___42 *, struct bio___43 *);

typedef int elevator_dispatch_fn___42(struct request_queue___42 *, int);

typedef void elevator_add_req_fn___42(struct request_queue___42 *, struct request___42 *);

typedef struct request___42 *elevator_request_list_fn___42(struct request_queue___42 *, struct request___42 *);

typedef void elevator_completed_req_fn___42(struct request_queue___42 *, struct request___42 *);

typedef int elevator_may_queue_fn___42(struct request_queue___42 *, int);

typedef void elevator_init_icq_fn___42(struct io_cq___42 *);

typedef void elevator_exit_icq_fn___42(struct io_cq___42 *);

typedef int elevator_set_req_fn___42(struct request_queue___42 *, struct request___42 *, struct bio___43 *, gfp_t);

typedef void elevator_put_req_fn___42(struct request___42 *);

typedef void elevator_activate_req_fn___42(struct request_queue___42 *, struct request___42 *);

typedef void elevator_deactivate_req_fn___42(struct request_queue___42 *, struct request___42 *);

struct elevator_type___42;

typedef int elevator_init_fn___43(struct request_queue___42 *, struct elevator_type___42 *);

typedef void elevator_exit_fn___42(struct elevator_queue___42 *);

struct elevator_ops___42 {
	elevator_merge_fn___42 *elevator_merge_fn;
	elevator_merged_fn___42 *elevator_merged_fn;
	elevator_merge_req_fn___42 *elevator_merge_req_fn;
	elevator_allow_merge_fn___42 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___42 *elevator_bio_merged_fn;
	elevator_dispatch_fn___42 *elevator_dispatch_fn;
	elevator_add_req_fn___42 *elevator_add_req_fn;
	elevator_activate_req_fn___42 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___42 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___42 *elevator_completed_req_fn;
	elevator_request_list_fn___42 *elevator_former_req_fn;
	elevator_request_list_fn___42 *elevator_latter_req_fn;
	elevator_init_icq_fn___42 *elevator_init_icq_fn;
	elevator_exit_icq_fn___42 *elevator_exit_icq_fn;
	elevator_set_req_fn___42 *elevator_set_req_fn;
	elevator_put_req_fn___42 *elevator_put_req_fn;
	elevator_may_queue_fn___42 *elevator_may_queue_fn;
	elevator_init_fn___43 *elevator_init_fn;
	elevator_exit_fn___42 *elevator_exit_fn;
};

struct elv_fs_entry___42;

struct elevator_type___42 {
	struct kmem_cache___198 *icq_cache;
	struct elevator_ops___42 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___42 *elevator_attrs;
	char elevator_name[16];
	struct module___124 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___42 {
	struct elevator_type___42 *type;
	void *elevator_data;
	struct kobject___22 kobj;
	struct mutex___215 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___42 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___42 *, char *);
	ssize_t (*store)(struct elevator_queue___42 *, const char *, size_t);
};

struct bvec_merge_data___42 {
	struct block_device___213 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___42 {
	struct request___42 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___15;

typedef int queue_rq_fn___16(struct blk_mq_hw_ctx___15 *, const struct blk_mq_queue_data___15 *);

typedef struct blk_mq_hw_ctx___15 *map_queue_fn___16(struct request_queue___42 *, const int);

typedef enum blk_eh_timer_return timeout_fn___16(struct request___42 *, bool);

typedef int init_request_fn___16(void *, struct request___42 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___16(void *, struct request___42 *, unsigned int, unsigned int);

typedef int init_hctx_fn___15(struct blk_mq_hw_ctx___15 *, void *, unsigned int);

typedef void exit_hctx_fn___15(struct blk_mq_hw_ctx___15 *, unsigned int);

struct blk_mq_ops___15 {
	queue_rq_fn___16 *queue_rq;
	map_queue_fn___16 *map_queue;
	union {
		timeout_fn___16 *timeout;
		struct {
			rq_timed_out_fn___42 *timeout;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	softirq_done_fn___42 *complete;
	init_request_fn___16 *init_request;
	exit_request_fn___16 *exit_request;
	init_hctx_fn___15 *init_hctx;
	exit_hctx_fn___15 *exit_hctx;
};

struct blk_mq_hw_ctx___15 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___42 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct request___42 **padding2;
		struct {
			struct request___42 **rqs;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___3 cpu_notifier;
	struct kobject___22 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___15 {
	struct blk_mq_ops___15 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___215 tag_list_lock;
	struct list_head tag_list;
};

struct module_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___123 *, struct module_kobject___123 *, char *);
	ssize_t (*store)(struct module_attribute___123 *, struct module_kobject___123 *, const char *, size_t);
	void (*setup)(struct module___124 *, const char *);
	int (*test)(struct module___124 *);
	void (*free)(struct module___124 *);
};

struct seq_operations___144 {
	void * (*start)(struct seq_file___144 *, loff_t *);
	void (*stop)(struct seq_file___144 *, void *);
	void * (*next)(struct seq_file___144 *, void *, loff_t *);
	int (*show)(struct seq_file___144 *, void *);
};

struct blk_mq_queue_data___15 {
	struct request___42 *rq;
	struct list_head *list;
	bool last;
};

struct value_name_pair;

struct sa_name_list {
	int opcode;
	const struct value_name_pair *arr;
	int arr_sz;
};

struct value_name_pair {
	int value;
	const char *name;
};

struct error_info {
	short unsigned int code12;
	const char *text;
};

struct error_info2 {
	unsigned char code1;
	unsigned char code2_min;
	unsigned char code2_max;
	const char *str;
	const char *fmt;
};

struct Scsi_Host___3;

struct scsi_cmnd___3;

struct scsi_target___3;

struct scsi_dh_data___3;

struct scsi_device___3 {
	struct Scsi_Host___3 *host;
	struct request_queue___42 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd___3 *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___3 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___197 sdev_gendev;
	struct device___197 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___3 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___3;

struct Scsi_Host___3 {
	struct list_head __devices;
	struct list_head __targets;
	struct scsi_host_cmd_pool *cmd_pool;
	spinlock_t free_list_lock;
	struct list_head free_list;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex___215 scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___214 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___3 *hostt;
	struct scsi_transport_template *transportt;
	union {
		struct blk_queue_tag___42 *bqt;
		struct blk_mq_tag_set___15 *tag_set;
	};
	union {
		atomic_t host_busy;
		struct {
			unsigned int host_busy;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_id;
	unsigned int max_lun;
	unsigned int max_channel;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int use_blk_tcq: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int ordered_tag: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_blk_mq: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	union {
		atomic_t host_blocked;
		struct {
			unsigned int host_blocked;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	struct request_queue___42 *uspace_req_q;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___197 shost_gendev;
	struct device___197 shost_dev;
	struct list_head sht_legacy_list;
	void *shost_data;
	struct device___197 *dma_dev;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	unsigned int scsi_mq_reserved1;
	unsigned int scsi_mq_reserved2;
	void *scsi_mq_reserved3;
	void *scsi_mq_reserved4;
	atomic_t scsi_mq_reserved5;
	atomic_t scsi_mq_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_cmnd___3 {
	struct scsi_device___3 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___42 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___3 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	unsigned char tag;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
};

struct scsi_target___3 {
	struct scsi_device___3 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___197 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___3;

struct scsi_dh_data___3 {
	struct scsi_device_handler___3 *scsi_dh;
	struct scsi_device___3 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___3 {
	struct list_head list;
	struct module *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___3 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___3 *);
	void (*detach)(struct scsi_device___3 *);
	int (*activate)(struct scsi_device___3 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___3 *, struct request___42 *);
	int (*set_params)(struct scsi_device___3 *, const char *);
	bool (*match)(struct scsi_device___3 *);
};

struct scsi_host_template___3 {
	struct module *module;
	const char *name;
	int (*detect)(struct scsi_host_template___3 *);
	int (*release)(struct Scsi_Host___3 *);
	const char * (*info)(struct Scsi_Host___3 *);
	int (*ioctl)(struct scsi_device___3 *, int, void *);
	int (*compat_ioctl)(struct scsi_device___3 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___3 *, struct scsi_cmnd___3 *);
	int (*transfer_response)(struct scsi_cmnd___3 *, void (*)(struct scsi_cmnd___3 *));
	int (*eh_abort_handler)(struct scsi_cmnd___3 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___3 *);
	int (*slave_alloc)(struct scsi_device___3 *);
	int (*slave_configure)(struct scsi_device___3 *);
	void (*slave_destroy)(struct scsi_device___3 *);
	int (*target_alloc)(struct scsi_target___3 *);
	void (*target_destroy)(struct scsi_target___3 *);
	int (*scan_finished)(struct Scsi_Host___3 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___3 *);
	int (*change_queue_depth)(struct scsi_device___3 *, int, int);
	int (*change_queue_type)(struct scsi_device___3 *, int);
	int (*bios_param)(struct scsi_device___3 *, struct block_device___213 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___3 *);
	int (*show_info)(struct seq_file___144 *, struct Scsi_Host___3 *);
	int (*write_info)(struct Scsi_Host___3 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___3 *);
	int (*host_reset)(struct Scsi_Host___3 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int ordered_tag: 1;
	unsigned int no_write_same: 1;
	unsigned int no_async_abort: 1;
	unsigned int disable_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___197 **shost_attrs;
	struct device_attribute___197 **sdev_attrs;
	struct list_head legacy_hosts;
	u64 vendor_id;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	union {
		unsigned int cmd_size;
		struct {
			unsigned int scsi_mq_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	unsigned int scsi_mq_reserved2;
	union {
		struct scsi_host_cmd_pool *cmd_pool;
		struct {
			void *scsi_mq_reserved3;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void *scsi_mq_reserved4;
};

enum scsi_timeouts {
	SCSI_DEFAULT_EH_TIMEOUT = 10000,
};

struct scsi_lun {
	__u8 scsi_lun[8];
};

struct async_scan_data {
	struct list_head list;
	struct Scsi_Host *shost;
	struct completion prev_finished;
};

struct class_interface___3 {
	struct list_head node;
	struct class___195 *class;
	int (*add_dev)(struct device___195 *, struct class_interface___3 *);
	void (*remove_dev)(struct device___195 *, struct class_interface___3 *);
};

struct scsi_target___4;

struct scsi_dh_data___4;

struct scsi_device___4 {
	struct Scsi_Host *host;
	struct request_queue___42 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___4 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___197 sdev_gendev;
	struct device___197 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___4 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_target___4 {
	struct scsi_device___4 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___197 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___4;

struct scsi_dh_data___4 {
	struct scsi_device_handler___4 *scsi_dh;
	struct scsi_device___4 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___4 {
	struct list_head list;
	struct module___124 *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___4 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___4 *);
	void (*detach)(struct scsi_device___4 *);
	int (*activate)(struct scsi_device___4 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___4 *, struct request___42 *);
	int (*set_params)(struct scsi_device___4 *, const char *);
	bool (*match)(struct scsi_device___4 *);
};

enum {
	SCSI_DEVINFO_GLOBAL = 0,
	SCSI_DEVINFO_SPI = 1,
};

struct scsi_dev_info_list {
	struct list_head dev_info_list;
	char vendor[8];
	char model[16];
	unsigned int flags;
	unsigned int compatible;
};

struct scsi_dev_info_list_table {
	struct list_head node;
	struct list_head scsi_dev_info_list;
	const char *name;
	int key;
};

struct double_list {
	struct list_head *top;
	struct list_head *bottom;
};

struct page___213;

typedef struct page___213 *pgtable_t___213;

struct address_space___214;

struct kmem_cache___199;

struct page___213 {
	long unsigned int flags;
	struct address_space___214 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___213 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___213 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___199 *slab_cache;
		struct page___213 *first_page;
	};
	long: 64;
};

struct task_struct___215;

struct pv_cpu_ops___215 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___215 *);
	void (*end_context_switch)(struct task_struct___215 *);
};

struct mutex___216 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___215 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___208 {
	struct page___213 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___222;

struct nsproxy___113;

struct signal_struct___215;

struct bio_list___43;

struct backing_dev_info___54;

struct io_context___43;

struct css_set___129;

struct task_struct___215 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___215 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___222 *mm;
	struct mm_struct___222 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___215 *real_parent;
	struct task_struct___215 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___215 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___215 = 0,
		VTIME_USER___215 = 1,
		VTIME_SYS___215 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___113 *nsproxy;
	struct signal_struct___215 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___43 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___54 *backing_dev_info;
	struct io_context___43 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___129 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___216 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___208 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___222 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___222 *, struct mm_struct___222 *);
	void (*dup_mmap)(struct mm_struct___222 *, struct mm_struct___222 *);
	void (*exit_mmap)(struct mm_struct___222 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___222 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___222 *);
	void (*pgd_free)(struct mm_struct___222 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___222 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___222 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___222 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___222 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___222 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___222 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___222 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___222 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___222 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___222 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___222 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___216 lock;
	void *vdso;
} mm_context_t___216;

struct xol_area___213;

struct uprobes_state___213 {
	struct xol_area___213 *xol_area;
};

struct vm_area_struct___222;

struct file___214;

struct core_state___215;

struct mm_struct___222 {
	struct vm_area_struct___222 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___222 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___222 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___216 context;
	long unsigned int flags;
	struct core_state___215 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___215 *owner;
	struct file___214 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___213 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct ctl_table_header___40;

struct ctl_node___40 {
	struct rb_node node;
	struct ctl_table_header___40 *header;
};

struct ctl_table_root___40;

struct ctl_table_set___40;

struct ctl_dir___40;

struct ctl_table_header___40 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___40 *root;
	struct ctl_table_set___40 *set;
	struct ctl_dir___40 *parent;
	struct ctl_node___40 *node;
};

struct ctl_dir___40 {
	struct ctl_table_header___40 header;
	struct rb_root root;
};

struct ctl_table_set___40 {
	int (*is_seen)(struct ctl_table_set___40 *);
	struct ctl_dir___40 dir;
};

struct ctl_table_root___40 {
	struct ctl_table_set___40 default_set;
	struct ctl_table_set___40 * (*lookup)(struct ctl_table_root___40 *, struct nsproxy___113 *);
	int (*permissions)(struct ctl_table_header___40 *, struct ctl_table *);
};

struct net___39;

struct nsproxy___113 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___39 *net_ns;
};

struct zone___215;

struct lruvec___215 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___215 *zone;
};

struct pglist_data___215;

struct zone___215 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___215 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___215 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___215 {
	struct zone___215 *zone;
	int zone_idx;
};

struct zonelist___215 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___215 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___215 {
	struct zone___215 node_zones[4];
	struct zonelist___215 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___215 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___141;

struct x86_io_apic_ops___141 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___141 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___141;

struct irq_data___141 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___141 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___198;

struct dev_pm_ops___198 {
	int (*prepare)(struct device___198 *);
	void (*complete)(struct device___198 *);
	int (*suspend)(struct device___198 *);
	int (*resume)(struct device___198 *);
	int (*freeze)(struct device___198 *);
	int (*thaw)(struct device___198 *);
	int (*poweroff)(struct device___198 *);
	int (*restore)(struct device___198 *);
	int (*suspend_late)(struct device___198 *);
	int (*resume_early)(struct device___198 *);
	int (*freeze_late)(struct device___198 *);
	int (*thaw_early)(struct device___198 *);
	int (*poweroff_late)(struct device___198 *);
	int (*restore_early)(struct device___198 *);
	int (*suspend_noirq)(struct device___198 *);
	int (*resume_noirq)(struct device___198 *);
	int (*freeze_noirq)(struct device___198 *);
	int (*thaw_noirq)(struct device___198 *);
	int (*poweroff_noirq)(struct device___198 *);
	int (*restore_noirq)(struct device___198 *);
	int (*runtime_suspend)(struct device___198 *);
	int (*runtime_resume)(struct device___198 *);
	int (*runtime_idle)(struct device___198 *);
};

struct kset___23;

struct kobj_type___23;

struct kobject___23 {
	const char *name;
	struct list_head entry;
	struct kobject___23 *parent;
	struct kset___23 *kset;
	struct kobj_type___23 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___33;

struct dev_pm_info___33 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___33 *qos;
};

struct dma_map_ops___84;

struct dev_archdata___84 {
	struct dma_map_ops___84 *dma_ops;
	void *iommu;
};

struct device_type___198;

struct bus_type___198;

struct device_driver___198;

struct dev_pm_domain___198;

struct class___198;

struct attribute_group___172;

struct device_rh___198;

struct device___198 {
	struct device___198 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___198 *type;
	struct mutex___216 mutex;
	struct bus_type___198 *bus;
	struct device_driver___198 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___198 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___84 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___198 *class;
	const struct attribute_group___172 **groups;
	void (*release)(struct device___198 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___198 *device_rh;
};

struct dev_pm_qos_request___33;

struct dev_pm_qos___33 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___33 *latency_req;
	struct dev_pm_qos_request___33 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___33 *latency_tolerance_req;
};

struct dev_pm_info_rh___198 {
	void (*set_latency_tolerance)(struct device___198 *, s32);
};

struct dev_pm_domain___198 {
	struct dev_pm_ops___198 ops;
};

struct smp_ops___215 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___215 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___21;

struct kobj_ns_type_operations___20 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___21 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___20;

struct sock_common___20 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___20 *skc_prot;
	struct net___39 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___29;

struct sk_buff_head___27 {
	struct sk_buff___29 *next;
	struct sk_buff___29 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___21;

struct socket_wq___20;

struct dst_entry___20;

struct socket___21;

struct cg_proto___20;

struct sock___21 {
	struct sock_common___20 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___27 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___29 *head;
		struct sk_buff___29 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___21 *sk_filter;
	struct socket_wq___20 *sk_wq;
	struct sk_buff_head___27 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___20 *sk_rx_dst;
	struct dst_entry___20 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___27 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___27 sk_error_queue;
	struct proto___20 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___91 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___21 *sk_socket;
	void *sk_user_data;
	struct page_frag___208 sk_frag;
	struct sk_buff___29 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___20 *sk_cgrp;
	void (*sk_state_change)(struct sock___21 *);
	void (*sk_data_ready)(struct sock___21 *, int);
	void (*sk_write_space)(struct sock___21 *);
	void (*sk_error_report)(struct sock___21 *);
	int (*sk_backlog_rcv)(struct sock___21 *, struct sk_buff___29 *);
	void (*sk_destruct)(struct sock___21 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___174;

struct attribute_group___172 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___174 **bin_attrs;
};

struct bin_attribute___174 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___214 *, struct kobject___23 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___214 *, struct kobject___23 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	int (*mmap)(struct file___214 *, struct kobject___23 *, struct bin_attribute___174 *, struct vm_area_struct___222 *);
};

struct dentry___214;

struct path___214 {
	struct vfsmount *mnt;
	struct dentry___214 *dentry;
};

struct inode___214;

struct file_operations___214;

struct file___214 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___214 f_path;
	struct inode___214 *f_inode;
	const struct file_operations___214 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___214 *f_mapping;
	struct mutex___216 f_pos_lock;
};

struct vm_operations_struct___194;

struct vm_area_struct___222 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___222 *vm_next;
	struct vm_area_struct___222 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___222 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___194 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___214 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___23 {
	ssize_t (*show)(struct kobject___23 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___23 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___23 *, const struct attribute *);
};

struct kset_uevent_ops___23;

struct kset___23 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___23 kobj;
	const struct kset_uevent_ops___23 *uevent_ops;
};

struct kobj_type___23 {
	void (*release)(struct kobject___23 *);
	const struct sysfs_ops___23 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___20 * (*child_ns_type)(struct kobject___23 *);
	const void * (*namespace)(struct kobject___23 *);
};

struct kset_uevent_ops___23 {
	int (* const filter)(struct kset___23 *, struct kobject___23 *);
	const char * (* const name)(struct kset___23 *, struct kobject___23 *);
	int (* const uevent)(struct kset___23 *, struct kobject___23 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___198 {
	void **freelist;
	long unsigned int tid;
	struct page___213 *page;
	struct page___213 *partial;
};

struct memcg_cache_params___199;

struct kmem_cache___199 {
	struct kmem_cache_cpu___198 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___199 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___199 {
	bool is_root_cache;
	union {
		struct kmem_cache___199 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___199 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct address_space_operations___214;

struct address_space___214 {
	struct inode___214 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___216 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___214 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___54 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___214;

struct super_block___214;

struct file_lock___214;

struct dquot___214;

struct block_device___214;

struct inode___214 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___214 *i_op;
	struct super_block___214 *i_sb;
	struct address_space___214 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___216 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___214 *i_fop;
	struct file_lock___214 *i_flock;
	struct address_space___214 i_data;
	struct dquot___214 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___214 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___214;

struct mem_dqinfo___214 {
	struct quota_format_type___214 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___214;

struct quota_info___214 {
	unsigned int flags;
	struct mutex___216 dqio_mutex;
	struct mutex___216 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___214 *files[2];
	struct mem_dqinfo___214 info[2];
	const struct quota_format_ops___214 *ops[2];
};

struct file_system_type___214;

struct super_operations___214;

struct dquot_operations___214;

struct quotactl_ops___214;

struct xattr_handler___130;

struct dentry_operations___214;

struct super_block___214 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___214 *s_type;
	const struct super_operations___214 *s_op;
	const struct dquot_operations___214 *dq_op;
	const struct quotactl_ops___214 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___214 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___130 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___214 *s_bdev;
	struct backing_dev_info___54 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___214 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___216 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___214 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___214 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___214 *d_parent;
	struct qstr d_name;
	struct inode___214 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___214 *d_op;
	struct super_block___214 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct seq_operations___145;

struct seq_file___145 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___216 lock;
	const struct seq_operations___145 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct iattr___214 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___214 *ia_file;
};

struct net_device___28;

struct nf_bridge_info___26;

struct sk_buff___29 {
	struct sk_buff___29 *next;
	struct sk_buff___29 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___21 *sk;
	struct net_device___28 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___29 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___26 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct proto_ops___20;

struct socket___21 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___20 *wq;
	struct file___214 *file;
	struct sock___21 *sk;
	const struct proto_ops___20 *ops;
};

struct irq_chip___141 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___141 *);
	void (*irq_shutdown)(struct irq_data___141 *);
	void (*irq_enable)(struct irq_data___141 *);
	void (*irq_disable)(struct irq_data___141 *);
	void (*irq_ack)(struct irq_data___141 *);
	void (*irq_mask)(struct irq_data___141 *);
	void (*irq_mask_ack)(struct irq_data___141 *);
	void (*irq_unmask)(struct irq_data___141 *);
	void (*irq_eoi)(struct irq_data___141 *);
	int (*irq_set_affinity)(struct irq_data___141 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___141 *);
	int (*irq_set_type)(struct irq_data___141 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___141 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___141 *);
	void (*irq_bus_sync_unlock)(struct irq_data___141 *);
	void (*irq_cpu_online)(struct irq_data___141 *);
	void (*irq_cpu_offline)(struct irq_data___141 *);
	void (*irq_suspend)(struct irq_data___141 *);
	void (*irq_resume)(struct irq_data___141 *);
	void (*irq_pm_shutdown)(struct irq_data___141 *);
	void (*irq_print_chip)(struct irq_data___141 *, struct seq_file___145 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___141 *, void *);
	long unsigned int flags;
};

struct kiocb___28;

struct poll_table_struct___118;

struct file_operations___214 {
	struct module *owner;
	loff_t (*llseek)(struct file___214 *, loff_t, int);
	ssize_t (*read)(struct file___214 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___214 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___28 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___28 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___214 *, void *, filldir_t);
	unsigned int (*poll)(struct file___214 *, struct poll_table_struct___118 *);
	long int (*unlocked_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___214 *, struct vm_area_struct___222 *);
	int (*open)(struct inode___214 *, struct file___214 *);
	int (*flush)(struct file___214 *, fl_owner_t);
	int (*release)(struct inode___214 *, struct file___214 *);
	int (*fsync)(struct file___214 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___28 *, int);
	int (*fasync)(int, struct file___214 *, int);
	int (*lock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*sendpage)(struct file___214 *, struct page___213 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___214 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___214 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___214 *, long int, struct file_lock___214 **, void **);
		struct {
			int (*setlease)(struct file___214 *, long int, struct file_lock___214 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___214 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___145 *, struct file___214 *);
};

struct dma_map_ops___84 {
	void * (*alloc)(struct device___198 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___198 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___198 *, struct vm_area_struct___222 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___198 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___198 *, struct page___213 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___198 *, dma_addr_t);
	int (*dma_supported)(struct device___198 *, u64);
	int (*set_dma_mask)(struct device___198 *, u64);
	int is_phys;
};

struct bus_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___198 *, char *);
	ssize_t (*store)(struct bus_type___198 *, const char *, size_t);
};

struct device_attribute___198;

struct driver_attribute___198;

struct bus_type___198 {
	const char *name;
	const char *dev_name;
	struct device___198 *dev_root;
	struct bus_attribute___198 *bus_attrs;
	struct device_attribute___198 *dev_attrs;
	struct driver_attribute___198 *drv_attrs;
	const struct attribute_group___172 **bus_groups;
	const struct attribute_group___172 **dev_groups;
	const struct attribute_group___172 **drv_groups;
	int (*match)(struct device___198 *, struct device_driver___198 *);
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	int (*probe)(struct device___198 *);
	int (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*online)(struct device___198 *);
	int (*offline)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct device___198 *, struct device_attribute___198 *, char *);
	ssize_t (*store)(struct device___198 *, struct device_attribute___198 *, const char *, size_t);
};

struct driver_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___198 *, char *);
	ssize_t (*store)(struct device_driver___198 *, const char *, size_t);
};

struct device_driver___198 {
	const char *name;
	struct bus_type___198 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___198 *);
	int (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	const struct attribute_group___172 **groups;
	const struct dev_pm_ops___198 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___198 {
	const char *name;
	const struct attribute_group___172 **groups;
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
};

struct class_attribute___198;

struct class___198 {
	const char *name;
	struct module *owner;
	struct class_attribute___198 *class_attrs;
	struct device_attribute___198 *dev_attrs;
	const struct attribute_group___172 **dev_groups;
	struct bin_attribute___174 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *);
	void (*class_release)(struct class___198 *);
	void (*dev_release)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
	struct subsys_private *p;
};

struct class_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct class___198 *, struct class_attribute___198 *, char *);
	ssize_t (*store)(struct class___198 *, struct class_attribute___198 *, const char *, size_t);
	const void * (*namespace)(struct class___198 *, const struct class_attribute___198 *);
};

struct device_rh___198 {
	struct dev_pm_info_rh___198 power;
};

struct dev_pm_qos_request___33 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___198 *dev;
};

struct xol_area___213 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___213 *page;
	long unsigned int vaddr;
};

struct vm_fault___190;

struct vm_operations_struct___194 {
	void (*open)(struct vm_area_struct___222 *);
	void (*close)(struct vm_area_struct___222 *);
	int (*fault)(struct vm_area_struct___222 *, struct vm_fault___190 *);
	int (*page_mkwrite)(struct vm_area_struct___222 *, struct vm_fault___190 *);
	int (*access)(struct vm_area_struct___222 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___222 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___222 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___222 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___222 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___215 {
	struct task_struct___215 *task;
	struct core_thread___215 *next;
};

struct core_state___215 {
	atomic_t nr_threads;
	struct core_thread___215 dumper;
	struct completion startup;
};

struct vm_fault___190 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___213 *page;
};

struct dentry_operations___214 {
	int (*d_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_hash)(const struct dentry___214 *, struct qstr *);
	int (*d_compare)(const struct dentry___214 *, const struct dentry___214 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___214 *);
	void (*d_release)(struct dentry___214 *);
	void (*d_prune)(struct dentry___214 *);
	void (*d_iput)(struct dentry___214 *, struct inode___214 *);
	char * (*d_dname)(struct dentry___214 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___214 *);
	int (*d_manage)(struct dentry___214 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio___44;

typedef void bio_end_io_t___44(struct bio___44 *, int);

struct bio_vec___44 {
	struct page___213 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_subsys_state___129;

struct bio_integrity_payload___44;

struct bio_set___44;

struct bio___44 {
	sector_t bi_sector;
	struct bio___44 *bi_next;
	struct block_device___214 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___44 *bi_end_io;
	void *bi_private;
	struct io_context___43 *bi_ioc;
	struct cgroup_subsys_state___129 *bi_css;
	struct bio_integrity_payload___44 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___44 *bi_io_vec;
	struct bio_set___44 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	struct bio_vec___44 bi_inline_vecs[0];
};

struct hd_struct___47;

struct gendisk___47;

struct request_queue___43;

struct block_device___214 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___214 *bd_inode;
	struct super_block___214 *bd_super;
	struct mutex___216 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___214 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___47 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___47 *bd_disk;
	struct request_queue___43 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___216 bd_fsfreeze_mutex;
};

struct io_cq___43;

struct io_context___43 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___43 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___129;

struct cgroup_subsys_state___129 {
	struct cgroup___129 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct bio_integrity_payload___44 {
	struct bio___44 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___44 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___44 *bip_vec;
	struct bio_vec___44 bip_inline_vecs[0];
};

struct bio_list___43 {
	struct bio___44 *head;
	struct bio___44 *tail;
};

struct bio_set___44 {
	struct kmem_cache___199 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___43 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

typedef int kiocb_cancel_fn___28(struct kiocb___28 *, struct io_event *);

struct kiocb___28 {
	atomic_t ki_users;
	struct file___214 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___28 *ki_cancel;
	void (*ki_dtor)(struct kiocb___28 *);
	union {
		void *user;
		struct task_struct___215 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct dquot___214 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___216 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___214 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___214 {
	int qf_fmt_id;
	const struct quota_format_ops___214 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___214 *qf_next;
};

struct quota_format_ops___214 {
	int (*check_quota_file)(struct super_block___214 *, int);
	int (*read_file_info)(struct super_block___214 *, int);
	int (*write_file_info)(struct super_block___214 *, int);
	int (*free_file_info)(struct super_block___214 *, int);
	int (*read_dqblk)(struct dquot___214 *);
	int (*commit_dqblk)(struct dquot___214 *);
	int (*release_dqblk)(struct dquot___214 *);
};

struct dquot_operations___214 {
	int (*write_dquot)(struct dquot___214 *);
	struct dquot___214 * (*alloc_dquot)(struct super_block___214 *, int);
	void (*destroy_dquot)(struct dquot___214 *);
	int (*acquire_dquot)(struct dquot___214 *);
	int (*release_dquot)(struct dquot___214 *);
	int (*mark_dirty)(struct dquot___214 *);
	int (*write_info)(struct super_block___214 *, int);
	qsize_t * (*get_reserved_space)(struct inode___214 *);
};

struct quotactl_ops___214 {
	int (*quota_on)(struct super_block___214 *, int, int, struct path___214 *);
	int (*quota_on_meta)(struct super_block___214 *, int, int);
	int (*quota_off)(struct super_block___214 *, int);
	int (*quota_sync)(struct super_block___214 *, int);
	int (*get_info)(struct super_block___214 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___214 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___214 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___214 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___214 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___214 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___214 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___214 *, unsigned int);
};

struct address_space_operations___214 {
	int (*writepage)(struct page___213 *, struct writeback_control *);
	int (*readpage)(struct file___214 *, struct page___213 *);
	int (*writepages)(struct address_space___214 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___213 *);
	int (*readpages)(struct file___214 *, struct address_space___214 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___214 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___213 **, void **);
	int (*write_end)(struct file___214 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___213 *, void *);
	sector_t (*bmap)(struct address_space___214 *, sector_t);
	void (*invalidatepage)(struct page___213 *, long unsigned int);
	int (*releasepage)(struct page___213 *, gfp_t);
	void (*freepage)(struct page___213 *);
	ssize_t (*direct_IO)(int, struct kiocb___28 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___214 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___214 *, struct page___213 *, struct page___213 *, enum migrate_mode);
	int (*launder_page)(struct page___213 *);
	int (*is_partially_uptodate)(struct page___213 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___213 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___214 *, struct page___213 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___214 *, sector_t *);
	void (*swap_deactivate)(struct file___214 *);
	void (*invalidatepage_range)(struct page___213 *, unsigned int, unsigned int);
};

struct bdi_writeback___54 {
	struct backing_dev_info___54 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___54 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___54 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___198 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___214 *debug_dir;
	struct dentry___214 *debug_stats;
};

struct hd_struct___47 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___198 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___47;

struct block_device_operations___43;

struct blk_integrity___4;

struct gendisk___47 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___47 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___47 *part_tbl;
	struct hd_struct___47 part0;
	const struct block_device_operations___43 *fops;
	struct request_queue___43 *queue;
	void *private_data;
	int flags;
	struct device___198 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___43 {
	struct request_queue___43 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___43(struct request_queue___43 *);

typedef void make_request_fn___43(struct request_queue___43 *, struct bio___44 *);

struct request___43;

typedef int prep_rq_fn___43(struct request_queue___43 *, struct request___43 *);

struct bvec_merge_data___43;

typedef int merge_bvec_fn___44(struct request_queue___43 *, struct bvec_merge_data___43 *, struct bio_vec___44 *);

typedef void softirq_done_fn___43(struct request___43 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___43(struct request___43 *);

typedef int dma_drain_needed_fn___43(struct request___43 *);

typedef int lld_busy_fn___43(struct request_queue___43 *);

struct bsg_class_device___43 {
	struct device___198 *class_dev;
	struct device___198 *parent;
	int minor;
	struct request_queue___43 *queue;
	struct kref ref;
	void (*release)(struct device___198 *);
};

typedef void unprep_rq_fn___43(struct request_queue___43 *, struct request___43 *);

struct elevator_queue___43;

struct blk_queue_tag___43;

struct request_queue___43 {
	struct list_head queue_head;
	struct request___43 *last_merge;
	struct elevator_queue___43 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___43 root_rl;
	request_fn_proc___43 *request_fn;
	make_request_fn___43 *make_request_fn;
	prep_rq_fn___43 *prep_rq_fn;
	merge_bvec_fn___44 *merge_bvec_fn;
	softirq_done_fn___43 *softirq_done_fn;
	rq_timed_out_fn___43 *rq_timed_out_fn;
	dma_drain_needed_fn___43 *dma_drain_needed;
	lld_busy_fn___43 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx *queue_ctx;
		struct {
			struct blk_mq_ctx *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___43 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___54 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___198 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___43 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___2 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___43 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___216 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___43 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___43 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___44 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___214 {
	struct dentry___214 * (*lookup)(struct inode___214 *, struct dentry___214 *, unsigned int);
	void * (*follow_link)(struct dentry___214 *, struct nameidata *);
	int (*permission)(struct inode___214 *, int);
	struct posix_acl * (*get_acl)(struct inode___214 *, int);
	int (*readlink)(struct dentry___214 *, char *, int);
	void (*put_link)(struct dentry___214 *, struct nameidata *, void *);
	int (*create)(struct inode___214 *, struct dentry___214 *, umode_t, bool);
	int (*link)(struct dentry___214 *, struct inode___214 *, struct dentry___214 *);
	int (*unlink)(struct inode___214 *, struct dentry___214 *);
	int (*symlink)(struct inode___214 *, struct dentry___214 *, const char *);
	int (*mkdir)(struct inode___214 *, struct dentry___214 *, umode_t);
	int (*rmdir)(struct inode___214 *, struct dentry___214 *);
	int (*mknod)(struct inode___214 *, struct dentry___214 *, umode_t, dev_t);
	int (*rename)(struct inode___214 *, struct dentry___214 *, struct inode___214 *, struct dentry___214 *);
	int (*setattr)(struct dentry___214 *, struct iattr___214 *);
	int (*getattr)(struct vfsmount *, struct dentry___214 *, struct kstat *);
	int (*setxattr)(struct dentry___214 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___214 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___214 *, char *, size_t);
	int (*removexattr)(struct dentry___214 *, const char *);
	int (*fiemap)(struct inode___214 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___214 *, struct timespec *, int);
	int (*atomic_open)(struct inode___214 *, struct dentry___214 *, struct file___214 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___214;

struct file_lock_operations___214;

struct lock_manager_operations___214;

struct file_lock___214 {
	struct file_lock___214 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___214 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___214 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___214 *fl_ops;
	const struct lock_manager_operations___214 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___214 {
	void (*fl_copy_lock)(struct file_lock___214 *, struct file_lock___214 *);
	void (*fl_release_private)(struct file_lock___214 *);
};

struct lock_manager_operations___214 {
	int (*lm_compare_owner)(struct file_lock___214 *, struct file_lock___214 *);
	long unsigned int (*lm_owner_key)(struct file_lock___214 *);
	void (*lm_notify)(struct file_lock___214 *);
	int (*lm_grant)(struct file_lock___214 *, struct file_lock___214 *, int);
	void (*lm_break)(struct file_lock___214 *);
	int (*lm_change)(struct file_lock___214 **, int);
};

struct fasync_struct___214 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___214 *fa_next;
	struct file___214 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___214 {
	const char *name;
	int fs_flags;
	struct dentry___214 * (*mount)(struct file_system_type___214 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___214 *);
	struct module *owner;
	struct file_system_type___214 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___214 {
	struct inode___214 * (*alloc_inode)(struct super_block___214 *);
	void (*destroy_inode)(struct inode___214 *);
	void (*dirty_inode)(struct inode___214 *, int);
	int (*write_inode)(struct inode___214 *, struct writeback_control *);
	int (*drop_inode)(struct inode___214 *);
	void (*evict_inode)(struct inode___214 *);
	void (*put_super)(struct super_block___214 *);
	int (*sync_fs)(struct super_block___214 *, int);
	int (*freeze_fs)(struct super_block___214 *);
	int (*unfreeze_fs)(struct super_block___214 *);
	int (*statfs)(struct dentry___214 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___214 *, int *, char *);
	void (*umount_begin)(struct super_block___214 *);
	int (*show_options)(struct seq_file___145 *, struct dentry___214 *);
	int (*show_devname)(struct seq_file___145 *, struct dentry___214 *);
	int (*show_path)(struct seq_file___145 *, struct dentry___214 *);
	int (*show_stats)(struct seq_file___145 *, struct dentry___214 *);
	ssize_t (*quota_read)(struct super_block___214 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___214 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___214 *);
	int (*bdev_try_to_free_page)(struct super_block___214 *, struct page___213 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___214 *);
	void (*free_cached_objects)(struct super_block___214 *, int);
};

struct xattr_handler___130 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___214 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___214 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___214 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___120)(struct file___214 *, wait_queue_head_t *, struct poll_table_struct___118 *);

struct poll_table_struct___118 {
	poll_queue_proc___120 _qproc;
	long unsigned int _key;
};

struct signal_struct___215 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___215 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___215 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___216 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___129 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___129 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___20 {
	wait_queue_head_t wait;
	struct fasync_struct___214 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___20 {
	int family;
	struct module *owner;
	int (*release)(struct socket___21 *);
	int (*bind)(struct socket___21 *, struct sockaddr *, int);
	int (*connect)(struct socket___21 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___21 *, struct socket___21 *);
	int (*accept)(struct socket___21 *, struct socket___21 *, int);
	int (*getname)(struct socket___21 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___214 *, struct socket___21 *, struct poll_table_struct___118 *);
	int (*ioctl)(struct socket___21 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___21 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___21 *, int);
	int (*shutdown)(struct socket___21 *, int);
	int (*setsockopt)(struct socket___21 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___21 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___21 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___21 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___28 *, struct socket___21 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___28 *, struct socket___21 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___214 *, struct socket___21 *, struct vm_area_struct___222 *);
	ssize_t (*sendpage)(struct socket___21 *, struct page___213 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___21 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___21 *, int);
		struct {
			void (*set_peek_off)(struct sock___21 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___37 {
	struct ctl_table_header___40 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___37 {
	struct mutex___216 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___37 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___40 *ctl;
};

struct netns_ipv4___37 {
	struct ctl_table_header___40 *forw_hdr;
	struct ctl_table_header___40 *frags_hdr;
	struct ctl_table_header___40 *ipv4_hdr;
	struct ctl_table_header___40 *route_hdr;
	struct ctl_table_header___40 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___21 *fibnl;
	struct sock___21 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___37 {
	struct ctl_table_header___40 *hdr;
	struct ctl_table_header___40 *route_hdr;
	struct ctl_table_header___40 *icmp_hdr;
	struct ctl_table_header___40 *frags_hdr;
	struct ctl_table_header___40 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___20;

struct dst_ops___38 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___38 *);
	struct dst_entry___20 * (*check)(struct dst_entry___20 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___20 *);
	unsigned int (*mtu)(const struct dst_entry___20 *);
	u32 * (*cow_metrics)(struct dst_entry___20 *, long unsigned int);
	void (*destroy)(struct dst_entry___20 *);
	void (*ifdown)(struct dst_entry___20 *, struct net_device___28 *, int);
	struct dst_entry___20 * (*negative_advice)(struct dst_entry___20 *);
	void (*link_failure)(struct sk_buff___29 *);
	void (*update_pmtu)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___29 *, u32);
	void (*redirect)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___29 *);
	int (*local_out)(struct sk_buff___29 *);
	struct neighbour___20 * (*neigh_lookup)(const struct dst_entry___20 *, struct sk_buff___29 *, const void *);
	struct kmem_cache___199 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___38 {
	struct netns_sysctl_ipv6___37 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___38 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___21 **icmp_sk;
	struct sock___21 *ndisc_sk;
	struct sock___21 *tcp_sk;
	struct sock___21 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___37 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___40 *sysctl_header;
	struct sock___21 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___20 {
	struct sock___21 *v4_ctl_sk;
	struct sock___21 *v6_ctl_sk;
};

struct netns_nf___37 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___40 *nf_log_dir_header;
};

struct nf_proto_net___37 {
	struct ctl_table_header___40 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___37 {
	struct nf_proto_net___37 pn;
	unsigned int timeout;
};

struct nf_tcp_net___37 {
	struct nf_proto_net___37 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___37 {
	struct nf_proto_net___37 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___37 {
	struct nf_proto_net___37 pn;
	unsigned int timeout;
};

struct nf_ip_net___37 {
	struct nf_generic_net___37 generic;
	struct nf_tcp_net___37 tcp;
	struct nf_udp_net___37 udp;
	struct nf_icmp_net___37 icmp;
	struct nf_icmp_net___37 icmpv6;
};

struct netns_ct___37 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___40 *sysctl_header;
	struct ctl_table_header___40 *acct_sysctl_header;
	struct ctl_table_header___40 *tstamp_sysctl_header;
	struct ctl_table_header___40 *event_sysctl_header;
	struct ctl_table_header___40 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___199 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___37 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___37 {
	struct netns_sysctl_ipv6___37 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___38 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___21 *nlsk;
	struct sock___21 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___40 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___38 xfrm4_dst_ops;
	struct dst_ops___38 xfrm6_dst_ops;
};

struct net___39 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___40 sysctls;
	struct sock___21 *rtnl;
	struct sock___21 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___28 *loopback_dev;
	struct netns_core___37 core;
	struct netns_mib mib;
	struct netns_packet___37 packet;
	struct netns_unix___37 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___37 ipv4;
	struct netns_ipv6___38 ipv6;
	struct netns_sctp___37 sctp;
	struct netns_dccp___20 dccp;
	struct netns_nf___37 nf;
	struct netns_xt xt;
	struct netns_ct___37 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___37 nf_frag;
	struct sock___21 *nfnl;
	struct sock___21 *nfnl_stash;
	struct sk_buff_head___27 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___38 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___21 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___21 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___216 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___216 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___26 {
	atomic_t use;
	unsigned int mask;
	struct net_device___28 *physindev;
	struct net_device___28 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___26(struct sk_buff___29 **);

struct net_device_ops___26;

struct ethtool_ops___26;

struct header_ops___26;

struct netdev_rx_queue___26;

struct netdev_queue___26;

struct rtnl_link_ops___20;

struct dcbnl_rtnl_ops___26;

struct net_device___28 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___26 *netdev_ops;
	const struct ethtool_ops___26 *ethtool_ops;
	const struct header_ops___26 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___23 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___26 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___26 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___26 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___26 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___26 = 0,
		NETREG_REGISTERED___26 = 1,
		NETREG_UNREGISTERING___26 = 2,
		NETREG_UNREGISTERED___26 = 3,
		NETREG_RELEASED___26 = 4,
		NETREG_DUMMY___26 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___26 = 0,
		RTNL_LINK_INITIALIZING___26 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___28 *);
	struct netpoll_info *npinfo;
	struct net___39 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___198 dev;
	const struct attribute_group___172 *sysfs_groups[4];
	const struct rtnl_link_ops___20 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___26 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ethtool_ops___26 {
	int (*get_settings)(struct net_device___28 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___28 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___28 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___28 *);
	void (*get_regs)(struct net_device___28 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___28 *);
	void (*set_msglevel)(struct net_device___28 *, u32);
	int (*nway_reset)(struct net_device___28 *);
	u32 (*get_link)(struct net_device___28 *);
	int (*get_eeprom_len)(struct net_device___28 *);
	int (*get_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___28 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___28 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___28 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___28 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___28 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___28 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___28 *);
	void (*complete)(struct net_device___28 *);
	u32 (*get_priv_flags)(struct net_device___28 *);
	int (*set_priv_flags)(struct net_device___28 *, u32);
	int (*get_sset_count)(struct net_device___28 *, int);
	int (*get_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___28 *, struct ethtool_flash *);
	int (*reset)(struct net_device___28 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___28 *);
	int (*get_rxfh_indir)(struct net_device___28 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___28 *, const u32 *);
	void (*get_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___28 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___28 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___28 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___28 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___28 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___28 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___28 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___28 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___20 {
	struct callback_head callback_head;
	struct dst_entry___20 *child;
	struct net_device___28 *dev;
	struct dst_ops___38 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___20 *path;
	struct dst_entry___20 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___29 *);
	union {
		int (*output)(struct sock___21 *, struct sk_buff___29 *);
		struct {
			int (*output)(struct sk_buff___29 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___20 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___20;

struct neigh_parms___20;

struct neigh_ops___20;

struct neighbour___20 {
	struct neighbour___20 *next;
	struct neigh_table___20 *tbl;
	struct neigh_parms___20 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___27 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___20 *, struct sk_buff___29 *);
	const struct neigh_ops___20 *ops;
	struct callback_head rcu;
	struct net_device___28 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___38 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___29 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___29 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___39 *, struct dst_entry___20 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___29 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___29 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___145 {
	void * (*start)(struct seq_file___145 *, loff_t *);
	void (*stop)(struct seq_file___145 *, void *);
	void * (*next)(struct seq_file___145 *, void *, loff_t *);
	int (*show)(struct seq_file___145 *, void *);
};

struct dcbnl_rtnl_ops___26 {
	int (*ieee_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___28 *);
	u8 (*setstate)(struct net_device___28 *, u8);
	void (*getpermhwaddr)(struct net_device___28 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___28 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___28 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___28 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___28 *, int, u8 *);
	void (*setpfccfg)(struct net_device___28 *, int, u8);
	void (*getpfccfg)(struct net_device___28 *, int, u8 *);
	u8 (*setall)(struct net_device___28 *);
	u8 (*getcap)(struct net_device___28 *, int, u8 *);
	int (*getnumtcs)(struct net_device___28 *, int, u8 *);
	int (*setnumtcs)(struct net_device___28 *, int, u8);
	u8 (*getpfcstate)(struct net_device___28 *);
	void (*setpfcstate)(struct net_device___28 *, u8);
	void (*getbcncfg)(struct net_device___28 *, int, u32 *);
	void (*setbcncfg)(struct net_device___28 *, int, u32);
	void (*getbcnrp)(struct net_device___28 *, int, u8 *);
	void (*setbcnrp)(struct net_device___28 *, int, u8);
	u8 (*setapp)(struct net_device___28 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___28 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___28 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___28 *, int, u8);
	u8 (*getdcbx)(struct net_device___28 *);
	u8 (*setdcbx)(struct net_device___28 *, u8);
	int (*peer_getappinfo)(struct net_device___28 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___28 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___28 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___28 *, struct cee_pfc *);
};

struct cgroupfs_root___129;

struct cgroup___129 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___129 *parent;
	struct dentry___214 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___129 *subsys[11];
	struct cgroupfs_root___129 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___216 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___129 {
	struct super_block___214 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___129 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___72 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___214 *, struct file___214 *);
	ssize_t (*read)(struct cgroup___129 *, struct cftype___72 *, struct file___214 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___129 *, struct cftype___72 *);
	s64 (*read_s64)(struct cgroup___129 *, struct cftype___72 *);
	int (*read_map)(struct cgroup___129 *, struct cftype___72 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___129 *, struct cftype___72 *, struct seq_file___145 *);
	ssize_t (*write)(struct cgroup___129 *, struct cftype___72 *, struct file___214 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___129 *, struct cftype___72 *, u64);
	int (*write_s64)(struct cgroup___129 *, struct cftype___72 *, s64);
	int (*write_string)(struct cgroup___129 *, struct cftype___72 *, const char *);
	int (*trigger)(struct cgroup___129 *, unsigned int);
	int (*release)(struct inode___214 *, struct file___214 *);
	int (*register_event)(struct cgroup___129 *, struct cftype___72 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___129 *, struct cftype___72 *, struct eventfd_ctx *);
};

struct cftype_set___68 {
	struct list_head node;
	struct cftype___72 *cfts;
};

struct task_and_cgroup___68 {
	struct task_struct___215 *task;
	struct cgroup___129 *cgrp;
	struct css_set___129 *cg;
};

struct cgroup_taskset___68 {
	struct task_and_cgroup___68 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___129 *cur_cgrp;
};

struct cgroup_subsys___68 {
	struct cgroup_subsys_state___129 * (*css_alloc)(struct cgroup___129 *);
	int (*css_online)(struct cgroup___129 *);
	void (*css_offline)(struct cgroup___129 *);
	void (*css_free)(struct cgroup___129 *);
	int (*can_attach)(struct cgroup___129 *, struct cgroup_taskset___68 *);
	void (*cancel_attach)(struct cgroup___129 *, struct cgroup_taskset___68 *);
	void (*attach)(struct cgroup___129 *, struct cgroup_taskset___68 *);
	void (*fork)(struct task_struct___215 *);
	void (*exit)(struct cgroup___129 *, struct cgroup___129 *, struct task_struct___215 *);
	void (*bind)(struct cgroup___129 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___129 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___72 *base_cftypes;
	struct cftype_set___68 base_cftset;
	struct module *module;
};

struct netlink_kernel_cfg___5 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___29 *);
	struct mutex___216 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___39 *, struct sock___21 *);
};

struct netlink_callback___27 {
	struct sk_buff___29 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___29 *, struct netlink_callback___27 *);
	int (*done)(struct netlink_callback___27 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___26 {
	int (*create)(struct sk_buff___29 *, struct net_device___28 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___29 *, unsigned char *);
	int (*rebuild)(struct sk_buff___29 *);
	int (*cache)(const struct neighbour___20 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___28 *, const unsigned char *);
};

struct napi_struct___26 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___26 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___28 *dev;
	struct sk_buff___29 *gro_list;
	struct sk_buff___29 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___26 {
	struct net_device___28 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___23 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___26 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___23 kobj;
	struct net_device___28 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___26 {
	int (*ndo_init)(struct net_device___28 *);
	void (*ndo_uninit)(struct net_device___28 *);
	int (*ndo_open)(struct net_device___28 *);
	int (*ndo_stop)(struct net_device___28 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___29 *, struct net_device___28 *);
	u16 (*ndo_select_queue)(struct net_device___28 *, struct sk_buff___29 *);
	void (*ndo_change_rx_flags)(struct net_device___28 *, int);
	void (*ndo_set_rx_mode)(struct net_device___28 *);
	int (*ndo_set_mac_address)(struct net_device___28 *, void *);
	int (*ndo_validate_addr)(struct net_device___28 *);
	int (*ndo_do_ioctl)(struct net_device___28 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___28 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___28 *, int);
	int (*ndo_neigh_setup)(struct net_device___28 *, struct neigh_parms___20 *);
	void (*ndo_tx_timeout)(struct net_device___28 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___28 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___28 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___28 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___28 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___28 *);
	int (*ndo_netpoll_setup)(struct net_device___28 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___28 *);
	int (*ndo_busy_poll)(struct napi_struct___26 *);
	int (*ndo_set_vf_mac)(struct net_device___28 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___28 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___28 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___28 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___28 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___28 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___28 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___28 *, int, struct sk_buff___29 *);
	int (*ndo_setup_tc)(struct net_device___28 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___28 *);
	int (*ndo_fcoe_disable)(struct net_device___28 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___28 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___28 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___28 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___28 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___28 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___28 *, const struct sk_buff___29 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___28 *, struct net_device___28 *);
	int (*ndo_del_slave)(struct net_device___28 *, struct net_device___28 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___20 *);
	void (*ndo_neigh_destroy)(struct neighbour___20 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___29 *, struct netlink_callback___27 *, struct net_device___28 *, int);
	int (*ndo_bridge_setlink)(struct net_device___28 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___29 *, u32, u32, struct net_device___28 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___28 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___28 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___28 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___28 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___28 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___28 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___29 *, struct net_device___28 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___28 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___28 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___28 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___20 {
	struct net___39 *net;
	struct net_device___28 *dev;
	struct neigh_parms___20 *next;
	int (*neigh_setup)(struct neighbour___20 *);
	void (*neigh_cleanup)(struct neighbour___20 *);
	struct neigh_table___20 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___20 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___28 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___39 *, struct net_device___28 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___28 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___28 *, struct list_head *);
	size_t (*get_size)(const struct net_device___28 *);
	int (*fill_info)(struct sk_buff___29 *, const struct net_device___28 *);
	size_t (*get_xstats_size)(const struct net_device___28 *);
	int (*fill_xstats)(struct sk_buff___29 *, const struct net_device___28 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___39 * (*get_link_net)(const struct net_device___28 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___28 *, struct net_device___28 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___28 *, const struct net_device___28 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___29 *, const struct net_device___28 *, const struct net_device___28 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___21 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___29 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___20;

struct neigh_hash_table___20;

struct neigh_table___20 {
	struct neigh_table___20 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___28 *, __u32 *);
	int (*constructor)(struct neighbour___20 *);
	int (*pconstructor)(struct pneigh_entry___20 *);
	void (*pdestructor)(struct pneigh_entry___20 *);
	void (*proxy_redo)(struct sk_buff___29 *);
	char *id;
	struct neigh_parms___20 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___27 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___20 *nht;
	struct pneigh_entry___20 **phash_buckets;
};

struct neigh_ops___20 {
	int family;
	void (*solicit)(struct neighbour___20 *, struct sk_buff___29 *);
	void (*error_report)(struct neighbour___20 *, struct sk_buff___29 *);
	int (*output)(struct neighbour___20 *, struct sk_buff___29 *);
	int (*connected_output)(struct neighbour___20 *, struct sk_buff___29 *);
};

struct pneigh_entry___20 {
	struct pneigh_entry___20 *next;
	struct net___39 *net;
	struct net_device___28 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___20 {
	struct neighbour___20 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___20 {
	void (*close)(struct sock___21 *, long int);
	int (*connect)(struct sock___21 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___21 *, int);
	struct sock___21 * (*accept)(struct sock___21 *, int, int *);
	int (*ioctl)(struct sock___21 *, int, long unsigned int);
	int (*init)(struct sock___21 *);
	void (*destroy)(struct sock___21 *);
	void (*shutdown)(struct sock___21 *, int);
	int (*setsockopt)(struct sock___21 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___21 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___21 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___21 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___21 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___28 *, struct sock___21 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___28 *, struct sock___21 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___21 *, struct page___213 *, int, size_t, int);
	int (*bind)(struct sock___21 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___21 *, struct sk_buff___29 *);
	void (*release_cb)(struct sock___21 *);
	void (*mtu_reduced)(struct sock___21 *);
	void (*hash)(struct sock___21 *);
	void (*unhash)(struct sock___21 *);
	void (*rehash)(struct sock___21 *);
	int (*get_port)(struct sock___21 *, short unsigned int);
	void (*clear_sk)(struct sock___21 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___21 *);
	void (*enter_memory_pressure)(struct sock___21 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___199 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___68 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___20 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___20 {
	void (*enter_memory_pressure)(struct sock___21 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct scsi_nl_hdr {
	uint8_t version;
	uint8_t transport;
	uint16_t magic;
	uint16_t msgtype;
	uint16_t msglen;
};

struct disk_part_tbl___47 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___47 *last_lookup;
	struct hd_struct___47 *part[0];
};

struct block_device_operations___43 {
	int (*open)(struct block_device___214 *, fmode_t);
	void (*release)(struct gendisk___47 *, fmode_t);
	int (*ioctl)(struct block_device___214 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___214 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___214 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___47 *, unsigned int);
	int (*media_changed)(struct gendisk___47 *);
	void (*unlock_native_capacity)(struct gendisk___47 *);
	int (*revalidate_disk)(struct gendisk___47 *);
	int (*getgeo)(struct block_device___214 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___214 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct blk_integrity___4 {
	integrity_gen_fn *generate_fn;
	integrity_vrfy_fn *verify_fn;
	integrity_set_tag_fn *set_tag_fn;
	integrity_get_tag_fn *get_tag_fn;
	short unsigned int flags;
	short unsigned int tuple_size;
	short unsigned int sector_size;
	short unsigned int tag_size;
	const char *name;
	struct kobject___23 kobj;
};

struct io_cq___43 {
	struct request_queue___43 *q;
	struct io_context___43 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___199 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___43(struct request___43 *, int);

struct request___43 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide32;
			union {			};
		};
	};
	struct request_queue___43 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___44 *bio;
	struct bio___44 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___43 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___43 *saved_end_io;
		} flush;
	};
	struct gendisk___47 *rq_disk;
	struct hd_struct___47 *part;
	long unsigned int start_time;
	struct request_list___43 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___43 *end_io;
	void *end_io_data;
	struct request___43 *next_rq;
};

typedef int elevator_merge_fn___43(struct request_queue___43 *, struct request___43 **, struct bio___44 *);

typedef void elevator_merge_req_fn___43(struct request_queue___43 *, struct request___43 *, struct request___43 *);

typedef void elevator_merged_fn___43(struct request_queue___43 *, struct request___43 *, int);

typedef int elevator_allow_merge_fn___43(struct request_queue___43 *, struct request___43 *, struct bio___44 *);

typedef void elevator_bio_merged_fn___43(struct request_queue___43 *, struct request___43 *, struct bio___44 *);

typedef int elevator_dispatch_fn___43(struct request_queue___43 *, int);

typedef void elevator_add_req_fn___43(struct request_queue___43 *, struct request___43 *);

typedef struct request___43 *elevator_request_list_fn___43(struct request_queue___43 *, struct request___43 *);

typedef void elevator_completed_req_fn___43(struct request_queue___43 *, struct request___43 *);

typedef int elevator_may_queue_fn___43(struct request_queue___43 *, int);

typedef void elevator_init_icq_fn___43(struct io_cq___43 *);

typedef void elevator_exit_icq_fn___43(struct io_cq___43 *);

typedef int elevator_set_req_fn___43(struct request_queue___43 *, struct request___43 *, struct bio___44 *, gfp_t);

typedef void elevator_put_req_fn___43(struct request___43 *);

typedef void elevator_activate_req_fn___43(struct request_queue___43 *, struct request___43 *);

typedef void elevator_deactivate_req_fn___43(struct request_queue___43 *, struct request___43 *);

struct elevator_type___43;

typedef int elevator_init_fn___44(struct request_queue___43 *, struct elevator_type___43 *);

typedef void elevator_exit_fn___43(struct elevator_queue___43 *);

struct elevator_ops___43 {
	elevator_merge_fn___43 *elevator_merge_fn;
	elevator_merged_fn___43 *elevator_merged_fn;
	elevator_merge_req_fn___43 *elevator_merge_req_fn;
	elevator_allow_merge_fn___43 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___43 *elevator_bio_merged_fn;
	elevator_dispatch_fn___43 *elevator_dispatch_fn;
	elevator_add_req_fn___43 *elevator_add_req_fn;
	elevator_activate_req_fn___43 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___43 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___43 *elevator_completed_req_fn;
	elevator_request_list_fn___43 *elevator_former_req_fn;
	elevator_request_list_fn___43 *elevator_latter_req_fn;
	elevator_init_icq_fn___43 *elevator_init_icq_fn;
	elevator_exit_icq_fn___43 *elevator_exit_icq_fn;
	elevator_set_req_fn___43 *elevator_set_req_fn;
	elevator_put_req_fn___43 *elevator_put_req_fn;
	elevator_may_queue_fn___43 *elevator_may_queue_fn;
	elevator_init_fn___44 *elevator_init_fn;
	elevator_exit_fn___43 *elevator_exit_fn;
};

struct elv_fs_entry___43;

struct elevator_type___43 {
	struct kmem_cache___199 *icq_cache;
	struct elevator_ops___43 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___43 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___43 {
	struct elevator_type___43 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___216 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___43 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___43 *, char *);
	ssize_t (*store)(struct elevator_queue___43 *, const char *, size_t);
};

struct bvec_merge_data___43 {
	struct block_device___214 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___43 {
	struct request___43 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct page___214;

typedef struct page___214 *pgtable_t___214;

struct address_space___215;

struct kmem_cache___200;

struct page___214 {
	long unsigned int flags;
	struct address_space___215 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___214 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___214 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___200 *slab_cache;
		struct page___214 *first_page;
	};
	long: 64;
};

struct task_struct___216;

struct pv_cpu_ops___216 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___216 *);
	void (*end_context_switch)(struct task_struct___216 *);
};

struct mutex___217 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___216 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___209 {
	struct page___214 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___223;

struct signal_struct___216;

struct bio_list___44;

struct backing_dev_info___55;

struct io_context___44;

struct task_struct___216 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___216 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___223 *mm;
	struct mm_struct___223 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___216 *real_parent;
	struct task_struct___216 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___216 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___216 = 0,
		VTIME_USER___216 = 1,
		VTIME_SYS___216 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___216 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___44 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___55 *backing_dev_info;
	struct io_context___44 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___217 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___209 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___223 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___223 *, struct mm_struct___223 *);
	void (*dup_mmap)(struct mm_struct___223 *, struct mm_struct___223 *);
	void (*exit_mmap)(struct mm_struct___223 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___223 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___223 *);
	void (*pgd_free)(struct mm_struct___223 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___223 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___223 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___223 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___223 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___223 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___223 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___223 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___223 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___223 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___223 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___223 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___217 lock;
	void *vdso;
} mm_context_t___217;

struct xol_area___214;

struct uprobes_state___214 {
	struct xol_area___214 *xol_area;
};

struct vm_area_struct___223;

struct file___215;

struct core_state___216;

struct mm_struct___223 {
	struct vm_area_struct___223 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___223 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___223 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___217 context;
	long unsigned int flags;
	struct core_state___216 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___216 *owner;
	struct file___215 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___214 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct bin_attribute___175;

struct attribute_group___173 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___175 **bin_attrs;
};

struct bin_attribute___175 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___215 *, struct kobject___23 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___215 *, struct kobject___23 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	int (*mmap)(struct file___215 *, struct kobject___23 *, struct bin_attribute___175 *, struct vm_area_struct___223 *);
};

struct dentry___215;

struct path___215 {
	struct vfsmount *mnt;
	struct dentry___215 *dentry;
};

struct inode___215;

struct file_operations___215;

struct file___215 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___215 f_path;
	struct inode___215 *f_inode;
	const struct file_operations___215 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___215 *f_mapping;
	struct mutex___217 f_pos_lock;
};

struct vm_operations_struct___195;

struct vm_area_struct___223 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___223 *vm_next;
	struct vm_area_struct___223 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___223 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___195 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___215 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___199;

struct dev_pm_ops___199 {
	int (*prepare)(struct device___199 *);
	void (*complete)(struct device___199 *);
	int (*suspend)(struct device___199 *);
	int (*resume)(struct device___199 *);
	int (*freeze)(struct device___199 *);
	int (*thaw)(struct device___199 *);
	int (*poweroff)(struct device___199 *);
	int (*restore)(struct device___199 *);
	int (*suspend_late)(struct device___199 *);
	int (*resume_early)(struct device___199 *);
	int (*freeze_late)(struct device___199 *);
	int (*thaw_early)(struct device___199 *);
	int (*poweroff_late)(struct device___199 *);
	int (*restore_early)(struct device___199 *);
	int (*suspend_noirq)(struct device___199 *);
	int (*resume_noirq)(struct device___199 *);
	int (*freeze_noirq)(struct device___199 *);
	int (*thaw_noirq)(struct device___199 *);
	int (*poweroff_noirq)(struct device___199 *);
	int (*restore_noirq)(struct device___199 *);
	int (*runtime_suspend)(struct device___199 *);
	int (*runtime_resume)(struct device___199 *);
	int (*runtime_idle)(struct device___199 *);
};

struct device_type___199;

struct bus_type___199;

struct device_driver___199;

struct dev_pm_domain___199;

struct class___199;

struct device_rh___199;

struct device___199 {
	struct device___199 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___199 *type;
	struct mutex___217 mutex;
	struct bus_type___199 *bus;
	struct device_driver___199 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___199 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___84 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___199 *class;
	const struct attribute_group___173 **groups;
	void (*release)(struct device___199 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___199 *device_rh;
};

struct dev_pm_info_rh___199 {
	void (*set_latency_tolerance)(struct device___199 *, s32);
};

struct dev_pm_domain___199 {
	struct dev_pm_ops___199 ops;
};

struct zone___216;

struct lruvec___216 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___216 *zone;
};

struct pglist_data___216;

struct zone___216 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___216 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___216 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___216 {
	struct zone___216 *zone;
	int zone_idx;
};

struct zonelist___216 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___216 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___216 {
	struct zone___216 node_zones[4];
	struct zonelist___216 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___216 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___216 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___216 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___199 *, char *);
	ssize_t (*store)(struct bus_type___199 *, const char *, size_t);
};

struct device_attribute___199;

struct driver_attribute___199;

struct bus_type___199 {
	const char *name;
	const char *dev_name;
	struct device___199 *dev_root;
	struct bus_attribute___199 *bus_attrs;
	struct device_attribute___199 *dev_attrs;
	struct driver_attribute___199 *drv_attrs;
	const struct attribute_group___173 **bus_groups;
	const struct attribute_group___173 **dev_groups;
	const struct attribute_group___173 **drv_groups;
	int (*match)(struct device___199 *, struct device_driver___199 *);
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	int (*probe)(struct device___199 *);
	int (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*online)(struct device___199 *);
	int (*offline)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct device___199 *, struct device_attribute___199 *, char *);
	ssize_t (*store)(struct device___199 *, struct device_attribute___199 *, const char *, size_t);
};

struct driver_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___199 *, char *);
	ssize_t (*store)(struct device_driver___199 *, const char *, size_t);
};

struct device_driver___199 {
	const char *name;
	struct bus_type___199 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___199 *);
	int (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	const struct attribute_group___173 **groups;
	const struct dev_pm_ops___199 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___199 {
	const char *name;
	const struct attribute_group___173 **groups;
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
};

struct class_attribute___199;

struct class___199 {
	const char *name;
	struct module *owner;
	struct class_attribute___199 *class_attrs;
	struct device_attribute___199 *dev_attrs;
	const struct attribute_group___173 **dev_groups;
	struct bin_attribute___175 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *);
	void (*class_release)(struct class___199 *);
	void (*dev_release)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
	struct subsys_private *p;
};

struct class_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct class___199 *, struct class_attribute___199 *, char *);
	ssize_t (*store)(struct class___199 *, struct class_attribute___199 *, const char *, size_t);
	const void * (*namespace)(struct class___199 *, const struct class_attribute___199 *);
};

struct device_rh___199 {
	struct dev_pm_info_rh___199 power;
};

struct xol_area___214 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___214 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___199;

struct memcg_cache_params___200;

struct kmem_cache___200 {
	struct kmem_cache_cpu___199 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___200 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___215;

struct address_space___215 {
	struct inode___215 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___217 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___215 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___55 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___191;

struct vm_operations_struct___195 {
	void (*open)(struct vm_area_struct___223 *);
	void (*close)(struct vm_area_struct___223 *);
	int (*fault)(struct vm_area_struct___223 *, struct vm_fault___191 *);
	int (*page_mkwrite)(struct vm_area_struct___223 *, struct vm_fault___191 *);
	int (*access)(struct vm_area_struct___223 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___223 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___223 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___223 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___223 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___216 {
	struct task_struct___216 *task;
	struct core_thread___216 *next;
};

struct core_state___216 {
	atomic_t nr_threads;
	struct core_thread___216 dumper;
	struct completion startup;
};

struct signal_struct___216 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___216 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___216 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___217 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___45;

struct bio_list___44 {
	struct bio___45 *head;
	struct bio___45 *tail;
};

struct bdi_writeback___55 {
	struct backing_dev_info___55 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___55 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___55 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___199 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___215 *debug_dir;
	struct dentry___215 *debug_stats;
};

struct io_cq___44;

struct io_context___44 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___44 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___199 {
	void **freelist;
	long unsigned int tid;
	struct page___214 *page;
	struct page___214 *partial;
};

struct memcg_cache_params___200 {
	bool is_root_cache;
	union {
		struct kmem_cache___200 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___200 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___215;

struct super_block___215;

struct dentry___215 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___215 *d_parent;
	struct qstr d_name;
	struct inode___215 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___215 *d_op;
	struct super_block___215 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___215;

struct file_lock___215;

struct dquot___215;

struct block_device___215;

struct inode___215 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___215 *i_op;
	struct super_block___215 *i_sb;
	struct address_space___215 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___217 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___215 *i_fop;
	struct file_lock___215 *i_flock;
	struct address_space___215 i_data;
	struct dquot___215 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___215 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___215 {
	int (*d_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_hash)(const struct dentry___215 *, struct qstr *);
	int (*d_compare)(const struct dentry___215 *, const struct dentry___215 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___215 *);
	void (*d_release)(struct dentry___215 *);
	void (*d_prune)(struct dentry___215 *);
	void (*d_iput)(struct dentry___215 *, struct inode___215 *);
	char * (*d_dname)(struct dentry___215 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___215 *);
	int (*d_manage)(struct dentry___215 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___215;

struct mem_dqinfo___215 {
	struct quota_format_type___215 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___215;

struct quota_info___215 {
	unsigned int flags;
	struct mutex___217 dqio_mutex;
	struct mutex___217 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___215 *files[2];
	struct mem_dqinfo___215 info[2];
	const struct quota_format_ops___215 *ops[2];
};

struct file_system_type___215;

struct super_operations___215;

struct dquot_operations___215;

struct quotactl_ops___215;

struct super_block___215 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___215 *s_type;
	const struct super_operations___215 *s_op;
	const struct dquot_operations___215 *dq_op;
	const struct quotactl_ops___215 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___215 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___215 *s_bdev;
	struct backing_dev_info___55 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___215 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___217 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___215 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___45(struct bio___45 *, int);

struct bio_vec___45 {
	struct page___214 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___45;

struct bio_set___45;

struct bio___45 {
	sector_t bi_sector;
	struct bio___45 *bi_next;
	struct block_device___215 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___45 *bi_end_io;
	void *bi_private;
	struct io_context___44 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___45 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___45 *bi_io_vec;
	struct bio_set___45 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___45 bi_inline_vecs[0];
};

struct hd_struct___48;

struct gendisk___48;

struct request_queue___44;

struct block_device___215 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___215 *bd_inode;
	struct super_block___215 *bd_super;
	struct mutex___217 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___215 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___48 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___48 *bd_disk;
	struct request_queue___44 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___217 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___45 {
	struct bio___45 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___45 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___45 *bip_vec;
	struct bio_vec___45 bip_inline_vecs[0];
};

struct bio_set___45 {
	struct kmem_cache___200 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___44 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___215 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___215 *ia_file;
};

struct dquot___215 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___217 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___215 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___215 {
	int qf_fmt_id;
	const struct quota_format_ops___215 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___215 *qf_next;
};

struct quota_format_ops___215 {
	int (*check_quota_file)(struct super_block___215 *, int);
	int (*read_file_info)(struct super_block___215 *, int);
	int (*write_file_info)(struct super_block___215 *, int);
	int (*free_file_info)(struct super_block___215 *, int);
	int (*read_dqblk)(struct dquot___215 *);
	int (*commit_dqblk)(struct dquot___215 *);
	int (*release_dqblk)(struct dquot___215 *);
};

struct dquot_operations___215 {
	int (*write_dquot)(struct dquot___215 *);
	struct dquot___215 * (*alloc_dquot)(struct super_block___215 *, int);
	void (*destroy_dquot)(struct dquot___215 *);
	int (*acquire_dquot)(struct dquot___215 *);
	int (*release_dquot)(struct dquot___215 *);
	int (*mark_dirty)(struct dquot___215 *);
	int (*write_info)(struct super_block___215 *, int);
	qsize_t * (*get_reserved_space)(struct inode___215 *);
};

struct quotactl_ops___215 {
	int (*quota_on)(struct super_block___215 *, int, int, struct path___215 *);
	int (*quota_on_meta)(struct super_block___215 *, int, int);
	int (*quota_off)(struct super_block___215 *, int);
	int (*quota_sync)(struct super_block___215 *, int);
	int (*get_info)(struct super_block___215 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___215 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___215 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___215 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___215 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___215 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___215 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___215 *, unsigned int);
};

struct address_space_operations___215 {
	int (*writepage)(struct page___214 *, struct writeback_control *);
	int (*readpage)(struct file___215 *, struct page___214 *);
	int (*writepages)(struct address_space___215 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___214 *);
	int (*readpages)(struct file___215 *, struct address_space___215 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___215 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___214 **, void **);
	int (*write_end)(struct file___215 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___214 *, void *);
	sector_t (*bmap)(struct address_space___215 *, sector_t);
	void (*invalidatepage)(struct page___214 *, long unsigned int);
	int (*releasepage)(struct page___214 *, gfp_t);
	void (*freepage)(struct page___214 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___215 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___215 *, struct page___214 *, struct page___214 *, enum migrate_mode);
	int (*launder_page)(struct page___214 *);
	int (*is_partially_uptodate)(struct page___214 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___214 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___215 *, struct page___214 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___215 *, sector_t *);
	void (*swap_deactivate)(struct file___215 *);
	void (*invalidatepage_range)(struct page___214 *, unsigned int, unsigned int);
};

struct hd_struct___48 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___199 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___48;

struct block_device_operations___44;

struct gendisk___48 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___48 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___48 *part_tbl;
	struct hd_struct___48 part0;
	const struct block_device_operations___44 *fops;
	struct request_queue___44 *queue;
	void *private_data;
	int flags;
	struct device___199 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___44 {
	struct request_queue___44 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___44(struct request_queue___44 *);

typedef void make_request_fn___44(struct request_queue___44 *, struct bio___45 *);

struct request___44;

typedef int prep_rq_fn___44(struct request_queue___44 *, struct request___44 *);

struct bvec_merge_data___44;

typedef int merge_bvec_fn___45(struct request_queue___44 *, struct bvec_merge_data___44 *, struct bio_vec___45 *);

typedef void softirq_done_fn___44(struct request___44 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___44(struct request___44 *);

typedef int dma_drain_needed_fn___44(struct request___44 *);

typedef int lld_busy_fn___44(struct request_queue___44 *);

struct bsg_class_device___44 {
	struct device___199 *class_dev;
	struct device___199 *parent;
	int minor;
	struct request_queue___44 *queue;
	struct kref ref;
	void (*release)(struct device___199 *);
};

typedef void unprep_rq_fn___44(struct request_queue___44 *, struct request___44 *);

struct elevator_queue___44;

struct blk_queue_tag___44;

struct request_queue___44 {
	struct list_head queue_head;
	struct request___44 *last_merge;
	struct elevator_queue___44 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___44 root_rl;
	request_fn_proc___44 *request_fn;
	make_request_fn___44 *make_request_fn;
	prep_rq_fn___44 *prep_rq_fn;
	merge_bvec_fn___45 *merge_bvec_fn;
	softirq_done_fn___44 *softirq_done_fn;
	rq_timed_out_fn___44 *rq_timed_out_fn;
	dma_drain_needed_fn___44 *dma_drain_needed;
	lld_busy_fn___44 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___44 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___55 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___199 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___44 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___44 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___217 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___44 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___44 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___45 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___215 {
	struct dentry___215 * (*lookup)(struct inode___215 *, struct dentry___215 *, unsigned int);
	void * (*follow_link)(struct dentry___215 *, struct nameidata *);
	int (*permission)(struct inode___215 *, int);
	struct posix_acl * (*get_acl)(struct inode___215 *, int);
	int (*readlink)(struct dentry___215 *, char *, int);
	void (*put_link)(struct dentry___215 *, struct nameidata *, void *);
	int (*create)(struct inode___215 *, struct dentry___215 *, umode_t, bool);
	int (*link)(struct dentry___215 *, struct inode___215 *, struct dentry___215 *);
	int (*unlink)(struct inode___215 *, struct dentry___215 *);
	int (*symlink)(struct inode___215 *, struct dentry___215 *, const char *);
	int (*mkdir)(struct inode___215 *, struct dentry___215 *, umode_t);
	int (*rmdir)(struct inode___215 *, struct dentry___215 *);
	int (*mknod)(struct inode___215 *, struct dentry___215 *, umode_t, dev_t);
	int (*rename)(struct inode___215 *, struct dentry___215 *, struct inode___215 *, struct dentry___215 *);
	int (*setattr)(struct dentry___215 *, struct iattr___215 *);
	int (*getattr)(struct vfsmount *, struct dentry___215 *, struct kstat *);
	int (*setxattr)(struct dentry___215 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___215 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___215 *, char *, size_t);
	int (*removexattr)(struct dentry___215 *, const char *);
	int (*fiemap)(struct inode___215 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___215 *, struct timespec *, int);
	int (*atomic_open)(struct inode___215 *, struct dentry___215 *, struct file___215 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___215 {
	struct module *owner;
	loff_t (*llseek)(struct file___215 *, loff_t, int);
	ssize_t (*read)(struct file___215 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___215 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___215 *, void *, filldir_t);
	unsigned int (*poll)(struct file___215 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___215 *, struct vm_area_struct___223 *);
	int (*open)(struct inode___215 *, struct file___215 *);
	int (*flush)(struct file___215 *, fl_owner_t);
	int (*release)(struct inode___215 *, struct file___215 *);
	int (*fsync)(struct file___215 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___215 *, int);
	int (*lock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*sendpage)(struct file___215 *, struct page___214 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___215 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___215 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___215 *, long int, struct file_lock___215 **, void **);
		struct {
			int (*setlease)(struct file___215 *, long int, struct file_lock___215 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___215 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___215 *);
};

struct fasync_struct___215;

struct file_lock_operations___215;

struct lock_manager_operations___215;

struct file_lock___215 {
	struct file_lock___215 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___215 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___215 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___215 *fl_ops;
	const struct lock_manager_operations___215 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___215 {
	void (*fl_copy_lock)(struct file_lock___215 *, struct file_lock___215 *);
	void (*fl_release_private)(struct file_lock___215 *);
};

struct lock_manager_operations___215 {
	int (*lm_compare_owner)(struct file_lock___215 *, struct file_lock___215 *);
	long unsigned int (*lm_owner_key)(struct file_lock___215 *);
	void (*lm_notify)(struct file_lock___215 *);
	int (*lm_grant)(struct file_lock___215 *, struct file_lock___215 *, int);
	void (*lm_break)(struct file_lock___215 *);
	int (*lm_change)(struct file_lock___215 **, int);
};

struct fasync_struct___215 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___215 *fa_next;
	struct file___215 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___215 {
	const char *name;
	int fs_flags;
	struct dentry___215 * (*mount)(struct file_system_type___215 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___215 *);
	struct module *owner;
	struct file_system_type___215 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___215 {
	struct inode___215 * (*alloc_inode)(struct super_block___215 *);
	void (*destroy_inode)(struct inode___215 *);
	void (*dirty_inode)(struct inode___215 *, int);
	int (*write_inode)(struct inode___215 *, struct writeback_control *);
	int (*drop_inode)(struct inode___215 *);
	void (*evict_inode)(struct inode___215 *);
	void (*put_super)(struct super_block___215 *);
	int (*sync_fs)(struct super_block___215 *, int);
	int (*freeze_fs)(struct super_block___215 *);
	int (*unfreeze_fs)(struct super_block___215 *);
	int (*statfs)(struct dentry___215 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___215 *, int *, char *);
	void (*umount_begin)(struct super_block___215 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___215 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___215 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___215 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___215 *);
	ssize_t (*quota_read)(struct super_block___215 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___215 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___215 *);
	int (*bdev_try_to_free_page)(struct super_block___215 *, struct page___214 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___215 *);
	void (*free_cached_objects)(struct super_block___215 *, int);
};

struct disk_part_tbl___48 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___48 *last_lookup;
	struct hd_struct___48 *part[0];
};

struct block_device_operations___44 {
	int (*open)(struct block_device___215 *, fmode_t);
	void (*release)(struct gendisk___48 *, fmode_t);
	int (*ioctl)(struct block_device___215 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___215 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___215 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___48 *, unsigned int);
	int (*media_changed)(struct gendisk___48 *);
	void (*unlock_native_capacity)(struct gendisk___48 *);
	int (*revalidate_disk)(struct gendisk___48 *);
	int (*getgeo)(struct block_device___215 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___215 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct vm_fault___191 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___214 *page;
};

struct io_cq___44 {
	struct request_queue___44 *q;
	struct io_context___44 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___200 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___44(struct request___44 *, int);

struct request___44 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___44 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___45 *bio;
	struct bio___45 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___44 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___44 *saved_end_io;
		} flush;
	};
	struct gendisk___48 *rq_disk;
	struct hd_struct___48 *part;
	long unsigned int start_time;
	struct request_list___44 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___44 *end_io;
	void *end_io_data;
	struct request___44 *next_rq;
};

typedef int elevator_merge_fn___44(struct request_queue___44 *, struct request___44 **, struct bio___45 *);

typedef void elevator_merge_req_fn___44(struct request_queue___44 *, struct request___44 *, struct request___44 *);

typedef void elevator_merged_fn___44(struct request_queue___44 *, struct request___44 *, int);

typedef int elevator_allow_merge_fn___44(struct request_queue___44 *, struct request___44 *, struct bio___45 *);

typedef void elevator_bio_merged_fn___44(struct request_queue___44 *, struct request___44 *, struct bio___45 *);

typedef int elevator_dispatch_fn___44(struct request_queue___44 *, int);

typedef void elevator_add_req_fn___44(struct request_queue___44 *, struct request___44 *);

typedef struct request___44 *elevator_request_list_fn___44(struct request_queue___44 *, struct request___44 *);

typedef void elevator_completed_req_fn___44(struct request_queue___44 *, struct request___44 *);

typedef int elevator_may_queue_fn___44(struct request_queue___44 *, int);

typedef void elevator_init_icq_fn___44(struct io_cq___44 *);

typedef void elevator_exit_icq_fn___44(struct io_cq___44 *);

typedef int elevator_set_req_fn___44(struct request_queue___44 *, struct request___44 *, struct bio___45 *, gfp_t);

typedef void elevator_put_req_fn___44(struct request___44 *);

typedef void elevator_activate_req_fn___44(struct request_queue___44 *, struct request___44 *);

typedef void elevator_deactivate_req_fn___44(struct request_queue___44 *, struct request___44 *);

struct elevator_type___44;

typedef int elevator_init_fn___45(struct request_queue___44 *, struct elevator_type___44 *);

typedef void elevator_exit_fn___44(struct elevator_queue___44 *);

struct elevator_ops___44 {
	elevator_merge_fn___44 *elevator_merge_fn;
	elevator_merged_fn___44 *elevator_merged_fn;
	elevator_merge_req_fn___44 *elevator_merge_req_fn;
	elevator_allow_merge_fn___44 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___44 *elevator_bio_merged_fn;
	elevator_dispatch_fn___44 *elevator_dispatch_fn;
	elevator_add_req_fn___44 *elevator_add_req_fn;
	elevator_activate_req_fn___44 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___44 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___44 *elevator_completed_req_fn;
	elevator_request_list_fn___44 *elevator_former_req_fn;
	elevator_request_list_fn___44 *elevator_latter_req_fn;
	elevator_init_icq_fn___44 *elevator_init_icq_fn;
	elevator_exit_icq_fn___44 *elevator_exit_icq_fn;
	elevator_set_req_fn___44 *elevator_set_req_fn;
	elevator_put_req_fn___44 *elevator_put_req_fn;
	elevator_may_queue_fn___44 *elevator_may_queue_fn;
	elevator_init_fn___45 *elevator_init_fn;
	elevator_exit_fn___44 *elevator_exit_fn;
};

struct elv_fs_entry___44;

struct elevator_type___44 {
	struct kmem_cache___200 *icq_cache;
	struct elevator_ops___44 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___44 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___44 {
	struct elevator_type___44 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___217 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___44 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___44 *, char *);
	ssize_t (*store)(struct elevator_queue___44 *, const char *, size_t);
};

struct bvec_merge_data___44 {
	struct block_device___215 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___44 {
	struct request___44 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct page___215;

typedef struct page___215 *pgtable_t___215;

struct address_space___216;

struct kmem_cache___201;

struct page___215 {
	long unsigned int flags;
	struct address_space___216 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___215 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___215 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___201 *slab_cache;
		struct page___215 *first_page;
	};
	long: 64;
};

struct task_struct___217;

struct pv_cpu_ops___217 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___217 *);
	void (*end_context_switch)(struct task_struct___217 *);
};

struct mutex___218 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___217 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___210 {
	struct page___215 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___224;

struct signal_struct___217;

struct bio_list___45;

struct backing_dev_info___56;

struct io_context___45;

struct task_struct___217 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___217 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___224 *mm;
	struct mm_struct___224 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___217 *real_parent;
	struct task_struct___217 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___217 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___217 = 0,
		VTIME_USER___217 = 1,
		VTIME_SYS___217 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___217 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___45 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___56 *backing_dev_info;
	struct io_context___45 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___218 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___210 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___224 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___224 *, struct mm_struct___224 *);
	void (*dup_mmap)(struct mm_struct___224 *, struct mm_struct___224 *);
	void (*exit_mmap)(struct mm_struct___224 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___224 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___224 *);
	void (*pgd_free)(struct mm_struct___224 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___224 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___224 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___224 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___224 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___224 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___224 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___224 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___224 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___224 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___224 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___224 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___218 lock;
	void *vdso;
} mm_context_t___218;

struct xol_area___215;

struct uprobes_state___215 {
	struct xol_area___215 *xol_area;
};

struct vm_area_struct___224;

struct file___216;

struct core_state___217;

struct mm_struct___224 {
	struct vm_area_struct___224 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___224 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___224 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___218 context;
	long unsigned int flags;
	struct core_state___217 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___217 *owner;
	struct file___216 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___215 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___125;

struct module_kobject___124 {
	struct kobject___23 kobj;
	struct module___125 *mod;
	struct kobject___23 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___124;

struct module___125 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___124 mkobj;
	struct module_attribute___124 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___23 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___217 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___217;

struct lruvec___217 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___217 *zone;
};

struct pglist_data___217;

struct zone___217 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___217 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___217 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___217 {
	struct zone___217 *zone;
	int zone_idx;
};

struct zonelist___217 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___217 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___217 {
	struct zone___217 node_zones[4];
	struct zonelist___217 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___217 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___142;

struct x86_io_apic_ops___142 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___142 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___142;

struct irq_data___142 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___142 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___200;

struct dev_pm_ops___200 {
	int (*prepare)(struct device___200 *);
	void (*complete)(struct device___200 *);
	int (*suspend)(struct device___200 *);
	int (*resume)(struct device___200 *);
	int (*freeze)(struct device___200 *);
	int (*thaw)(struct device___200 *);
	int (*poweroff)(struct device___200 *);
	int (*restore)(struct device___200 *);
	int (*suspend_late)(struct device___200 *);
	int (*resume_early)(struct device___200 *);
	int (*freeze_late)(struct device___200 *);
	int (*thaw_early)(struct device___200 *);
	int (*poweroff_late)(struct device___200 *);
	int (*restore_early)(struct device___200 *);
	int (*suspend_noirq)(struct device___200 *);
	int (*resume_noirq)(struct device___200 *);
	int (*freeze_noirq)(struct device___200 *);
	int (*thaw_noirq)(struct device___200 *);
	int (*poweroff_noirq)(struct device___200 *);
	int (*restore_noirq)(struct device___200 *);
	int (*runtime_suspend)(struct device___200 *);
	int (*runtime_resume)(struct device___200 *);
	int (*runtime_idle)(struct device___200 *);
};

struct device_type___200;

struct bus_type___200;

struct device_driver___200;

struct dev_pm_domain___200;

struct class___200;

struct attribute_group___174;

struct device_rh___200;

struct device___200 {
	struct device___200 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___200 *type;
	struct mutex___218 mutex;
	struct bus_type___200 *bus;
	struct device_driver___200 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___200 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___84 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___200 *class;
	const struct attribute_group___174 **groups;
	void (*release)(struct device___200 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___200 *device_rh;
};

struct dev_pm_info_rh___200 {
	void (*set_latency_tolerance)(struct device___200 *, s32);
};

struct dev_pm_domain___200 {
	struct dev_pm_ops___200 ops;
};

struct smp_ops___217 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___217 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___176;

struct attribute_group___174 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___176 **bin_attrs;
};

struct bin_attribute___176 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___216 *, struct kobject___23 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___216 *, struct kobject___23 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	int (*mmap)(struct file___216 *, struct kobject___23 *, struct bin_attribute___176 *, struct vm_area_struct___224 *);
};

struct dentry___216;

struct path___216 {
	struct vfsmount *mnt;
	struct dentry___216 *dentry;
};

struct inode___216;

struct file_operations___216;

struct file___216 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___216 f_path;
	struct inode___216 *f_inode;
	const struct file_operations___216 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___216 *f_mapping;
	struct mutex___218 f_pos_lock;
};

struct vm_operations_struct___196;

struct vm_area_struct___224 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___224 *vm_next;
	struct vm_area_struct___224 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___224 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___196 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___216 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___124 *, struct module_kobject___124 *, char *);
	ssize_t (*store)(struct module_attribute___124 *, struct module_kobject___124 *, const char *, size_t);
	void (*setup)(struct module___125 *, const char *);
	int (*test)(struct module___125 *);
	void (*free)(struct module___125 *);
};

struct xol_area___215 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___215 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___200;

struct memcg_cache_params___201;

struct kmem_cache___201 {
	struct kmem_cache_cpu___200 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___201 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___216;

struct address_space___216 {
	struct inode___216 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___218 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___216 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___56 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___192;

struct vm_operations_struct___196 {
	void (*open)(struct vm_area_struct___224 *);
	void (*close)(struct vm_area_struct___224 *);
	int (*fault)(struct vm_area_struct___224 *, struct vm_fault___192 *);
	int (*page_mkwrite)(struct vm_area_struct___224 *, struct vm_fault___192 *);
	int (*access)(struct vm_area_struct___224 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___224 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___224 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___224 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___224 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___217 {
	struct task_struct___217 *task;
	struct core_thread___217 *next;
};

struct core_state___217 {
	atomic_t nr_threads;
	struct core_thread___217 dumper;
	struct completion startup;
};

struct vm_fault___192 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___215 *page;
};

struct dentry_operations___216;

struct super_block___216;

struct dentry___216 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___216 *d_parent;
	struct qstr d_name;
	struct inode___216 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___216 *d_op;
	struct super_block___216 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___216;

struct file_lock___216;

struct dquot___216;

struct block_device___216;

struct inode___216 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___216 *i_op;
	struct super_block___216 *i_sb;
	struct address_space___216 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___218 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___216 *i_fop;
	struct file_lock___216 *i_flock;
	struct address_space___216 i_data;
	struct dquot___216 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___216 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___216 {
	int (*d_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_hash)(const struct dentry___216 *, struct qstr *);
	int (*d_compare)(const struct dentry___216 *, const struct dentry___216 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___216 *);
	void (*d_release)(struct dentry___216 *);
	void (*d_prune)(struct dentry___216 *);
	void (*d_iput)(struct dentry___216 *, struct inode___216 *);
	char * (*d_dname)(struct dentry___216 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___216 *);
	int (*d_manage)(struct dentry___216 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___216;

struct mem_dqinfo___216 {
	struct quota_format_type___216 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___216;

struct quota_info___216 {
	unsigned int flags;
	struct mutex___218 dqio_mutex;
	struct mutex___218 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___216 *files[2];
	struct mem_dqinfo___216 info[2];
	const struct quota_format_ops___216 *ops[2];
};

struct file_system_type___216;

struct super_operations___216;

struct dquot_operations___216;

struct quotactl_ops___216;

struct super_block___216 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___216 *s_type;
	const struct super_operations___216 *s_op;
	const struct dquot_operations___216 *dq_op;
	const struct quotactl_ops___216 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___216 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___216 *s_bdev;
	struct backing_dev_info___56 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___216 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___218 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___216 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct bio___46;

typedef void bio_end_io_t___46(struct bio___46 *, int);

struct bio_vec___46 {
	struct page___215 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___46;

struct bio_set___46;

struct bio___46 {
	sector_t bi_sector;
	struct bio___46 *bi_next;
	struct block_device___216 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___46 *bi_end_io;
	void *bi_private;
	struct io_context___45 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___46 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___46 *bi_io_vec;
	struct bio_set___46 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	struct bio_vec___46 bi_inline_vecs[0];
};

struct hd_struct___49;

struct gendisk___49;

struct request_queue___45;

struct block_device___216 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___216 *bd_inode;
	struct super_block___216 *bd_super;
	struct mutex___218 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___216 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___49 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___49 *bd_disk;
	struct request_queue___45 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___218 bd_fsfreeze_mutex;
};

struct io_cq___45;

struct io_context___45 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___45 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___46 {
	struct bio___46 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___46 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___46 *bip_vec;
	struct bio_vec___46 bip_inline_vecs[0];
};

struct bio_list___45 {
	struct bio___46 *head;
	struct bio___46 *tail;
};

struct bio_set___46 {
	struct kmem_cache___201 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___45 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___216 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___216 *ia_file;
};

struct dquot___216 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___218 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___216 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___216 {
	int qf_fmt_id;
	const struct quota_format_ops___216 *qf_ops;
	struct module___125 *qf_owner;
	struct quota_format_type___216 *qf_next;
};

struct quota_format_ops___216 {
	int (*check_quota_file)(struct super_block___216 *, int);
	int (*read_file_info)(struct super_block___216 *, int);
	int (*write_file_info)(struct super_block___216 *, int);
	int (*free_file_info)(struct super_block___216 *, int);
	int (*read_dqblk)(struct dquot___216 *);
	int (*commit_dqblk)(struct dquot___216 *);
	int (*release_dqblk)(struct dquot___216 *);
};

struct dquot_operations___216 {
	int (*write_dquot)(struct dquot___216 *);
	struct dquot___216 * (*alloc_dquot)(struct super_block___216 *, int);
	void (*destroy_dquot)(struct dquot___216 *);
	int (*acquire_dquot)(struct dquot___216 *);
	int (*release_dquot)(struct dquot___216 *);
	int (*mark_dirty)(struct dquot___216 *);
	int (*write_info)(struct super_block___216 *, int);
	qsize_t * (*get_reserved_space)(struct inode___216 *);
};

struct quotactl_ops___216 {
	int (*quota_on)(struct super_block___216 *, int, int, struct path___216 *);
	int (*quota_on_meta)(struct super_block___216 *, int, int);
	int (*quota_off)(struct super_block___216 *, int);
	int (*quota_sync)(struct super_block___216 *, int);
	int (*get_info)(struct super_block___216 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___216 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___216 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___216 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___216 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___216 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___216 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___216 *, unsigned int);
};

struct address_space_operations___216 {
	int (*writepage)(struct page___215 *, struct writeback_control *);
	int (*readpage)(struct file___216 *, struct page___215 *);
	int (*writepages)(struct address_space___216 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___215 *);
	int (*readpages)(struct file___216 *, struct address_space___216 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___216 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___215 **, void **);
	int (*write_end)(struct file___216 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___215 *, void *);
	sector_t (*bmap)(struct address_space___216 *, sector_t);
	void (*invalidatepage)(struct page___215 *, long unsigned int);
	int (*releasepage)(struct page___215 *, gfp_t);
	void (*freepage)(struct page___215 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___216 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___216 *, struct page___215 *, struct page___215 *, enum migrate_mode);
	int (*launder_page)(struct page___215 *);
	int (*is_partially_uptodate)(struct page___215 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___215 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___216 *, struct page___215 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___216 *, sector_t *);
	void (*swap_deactivate)(struct file___216 *);
	void (*invalidatepage_range)(struct page___215 *, unsigned int, unsigned int);
};

struct bdi_writeback___56 {
	struct backing_dev_info___56 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___56 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___56 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___200 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___216 *debug_dir;
	struct dentry___216 *debug_stats;
};

struct hd_struct___49 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___200 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___49;

struct block_device_operations___45;

struct gendisk___49 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___49 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___49 *part_tbl;
	struct hd_struct___49 part0;
	const struct block_device_operations___45 *fops;
	struct request_queue___45 *queue;
	void *private_data;
	int flags;
	struct device___200 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___45 {
	struct request_queue___45 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___45(struct request_queue___45 *);

typedef void make_request_fn___45(struct request_queue___45 *, struct bio___46 *);

struct request___45;

typedef int prep_rq_fn___45(struct request_queue___45 *, struct request___45 *);

struct bvec_merge_data___45;

typedef int merge_bvec_fn___46(struct request_queue___45 *, struct bvec_merge_data___45 *, struct bio_vec___46 *);

typedef void softirq_done_fn___45(struct request___45 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___45(struct request___45 *);

typedef int dma_drain_needed_fn___45(struct request___45 *);

typedef int lld_busy_fn___45(struct request_queue___45 *);

struct bsg_class_device___45 {
	struct device___200 *class_dev;
	struct device___200 *parent;
	int minor;
	struct request_queue___45 *queue;
	struct kref ref;
	void (*release)(struct device___200 *);
};

typedef void unprep_rq_fn___45(struct request_queue___45 *, struct request___45 *);

struct elevator_queue___45;

struct blk_mq_ops___16;

struct blk_mq_hw_ctx___16;

struct blk_queue_tag___45;

struct blk_mq_tag_set___16;

struct request_queue___45 {
	struct list_head queue_head;
	struct request___45 *last_merge;
	struct elevator_queue___45 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___45 root_rl;
	request_fn_proc___45 *request_fn;
	make_request_fn___45 *make_request_fn;
	prep_rq_fn___45 *prep_rq_fn;
	merge_bvec_fn___46 *merge_bvec_fn;
	softirq_done_fn___45 *softirq_done_fn;
	rq_timed_out_fn___45 *rq_timed_out_fn;
	dma_drain_needed_fn___45 *dma_drain_needed;
	lld_busy_fn___45 *lld_busy_fn;
	struct blk_mq_ops___16 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___16 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___45 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___56 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___200 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___45 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___45 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___218 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___45 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___45 *unprep_rq_fn;
	struct blk_mq_tag_set___16 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___46 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___216 {
	struct dentry___216 * (*lookup)(struct inode___216 *, struct dentry___216 *, unsigned int);
	void * (*follow_link)(struct dentry___216 *, struct nameidata *);
	int (*permission)(struct inode___216 *, int);
	struct posix_acl * (*get_acl)(struct inode___216 *, int);
	int (*readlink)(struct dentry___216 *, char *, int);
	void (*put_link)(struct dentry___216 *, struct nameidata *, void *);
	int (*create)(struct inode___216 *, struct dentry___216 *, umode_t, bool);
	int (*link)(struct dentry___216 *, struct inode___216 *, struct dentry___216 *);
	int (*unlink)(struct inode___216 *, struct dentry___216 *);
	int (*symlink)(struct inode___216 *, struct dentry___216 *, const char *);
	int (*mkdir)(struct inode___216 *, struct dentry___216 *, umode_t);
	int (*rmdir)(struct inode___216 *, struct dentry___216 *);
	int (*mknod)(struct inode___216 *, struct dentry___216 *, umode_t, dev_t);
	int (*rename)(struct inode___216 *, struct dentry___216 *, struct inode___216 *, struct dentry___216 *);
	int (*setattr)(struct dentry___216 *, struct iattr___216 *);
	int (*getattr)(struct vfsmount *, struct dentry___216 *, struct kstat *);
	int (*setxattr)(struct dentry___216 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___216 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___216 *, char *, size_t);
	int (*removexattr)(struct dentry___216 *, const char *);
	int (*fiemap)(struct inode___216 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___216 *, struct timespec *, int);
	int (*atomic_open)(struct inode___216 *, struct dentry___216 *, struct file___216 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___146;

struct file_operations___216 {
	struct module___125 *owner;
	loff_t (*llseek)(struct file___216 *, loff_t, int);
	ssize_t (*read)(struct file___216 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___216 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___216 *, void *, filldir_t);
	unsigned int (*poll)(struct file___216 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___216 *, struct vm_area_struct___224 *);
	int (*open)(struct inode___216 *, struct file___216 *);
	int (*flush)(struct file___216 *, fl_owner_t);
	int (*release)(struct inode___216 *, struct file___216 *);
	int (*fsync)(struct file___216 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___216 *, int);
	int (*lock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*sendpage)(struct file___216 *, struct page___215 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___216 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___216 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___216 *, long int, struct file_lock___216 **, void **);
		struct {
			int (*setlease)(struct file___216 *, long int, struct file_lock___216 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___216 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___146 *, struct file___216 *);
};

struct fasync_struct___216;

struct file_lock_operations___216;

struct lock_manager_operations___216;

struct file_lock___216 {
	struct file_lock___216 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___216 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___216 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___216 *fl_ops;
	const struct lock_manager_operations___216 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___216 {
	void (*fl_copy_lock)(struct file_lock___216 *, struct file_lock___216 *);
	void (*fl_release_private)(struct file_lock___216 *);
};

struct lock_manager_operations___216 {
	int (*lm_compare_owner)(struct file_lock___216 *, struct file_lock___216 *);
	long unsigned int (*lm_owner_key)(struct file_lock___216 *);
	void (*lm_notify)(struct file_lock___216 *);
	int (*lm_grant)(struct file_lock___216 *, struct file_lock___216 *, int);
	void (*lm_break)(struct file_lock___216 *);
	int (*lm_change)(struct file_lock___216 **, int);
};

struct fasync_struct___216 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___216 *fa_next;
	struct file___216 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___216 {
	const char *name;
	int fs_flags;
	struct dentry___216 * (*mount)(struct file_system_type___216 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___216 *);
	struct module___125 *owner;
	struct file_system_type___216 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___216 {
	struct inode___216 * (*alloc_inode)(struct super_block___216 *);
	void (*destroy_inode)(struct inode___216 *);
	void (*dirty_inode)(struct inode___216 *, int);
	int (*write_inode)(struct inode___216 *, struct writeback_control *);
	int (*drop_inode)(struct inode___216 *);
	void (*evict_inode)(struct inode___216 *);
	void (*put_super)(struct super_block___216 *);
	int (*sync_fs)(struct super_block___216 *, int);
	int (*freeze_fs)(struct super_block___216 *);
	int (*unfreeze_fs)(struct super_block___216 *);
	int (*statfs)(struct dentry___216 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___216 *, int *, char *);
	void (*umount_begin)(struct super_block___216 *);
	int (*show_options)(struct seq_file___146 *, struct dentry___216 *);
	int (*show_devname)(struct seq_file___146 *, struct dentry___216 *);
	int (*show_path)(struct seq_file___146 *, struct dentry___216 *);
	int (*show_stats)(struct seq_file___146 *, struct dentry___216 *);
	ssize_t (*quota_read)(struct super_block___216 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___216 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___216 *);
	int (*bdev_try_to_free_page)(struct super_block___216 *, struct page___215 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___216 *);
	void (*free_cached_objects)(struct super_block___216 *, int);
};

struct seq_operations___146;

struct seq_file___146 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___218 lock;
	const struct seq_operations___146 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___217 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___217 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___217 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___218 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___200 {
	void **freelist;
	long unsigned int tid;
	struct page___215 *page;
	struct page___215 *partial;
};

struct memcg_cache_params___201 {
	bool is_root_cache;
	union {
		struct kmem_cache___201 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___201 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___200 *, char *);
	ssize_t (*store)(struct bus_type___200 *, const char *, size_t);
};

struct device_attribute___200;

struct driver_attribute___200;

struct bus_type___200 {
	const char *name;
	const char *dev_name;
	struct device___200 *dev_root;
	struct bus_attribute___200 *bus_attrs;
	struct device_attribute___200 *dev_attrs;
	struct driver_attribute___200 *drv_attrs;
	const struct attribute_group___174 **bus_groups;
	const struct attribute_group___174 **dev_groups;
	const struct attribute_group___174 **drv_groups;
	int (*match)(struct device___200 *, struct device_driver___200 *);
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	int (*probe)(struct device___200 *);
	int (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*online)(struct device___200 *);
	int (*offline)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct device___200 *, struct device_attribute___200 *, char *);
	ssize_t (*store)(struct device___200 *, struct device_attribute___200 *, const char *, size_t);
};

struct driver_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___200 *, char *);
	ssize_t (*store)(struct device_driver___200 *, const char *, size_t);
};

struct device_driver___200 {
	const char *name;
	struct bus_type___200 *bus;
	struct module___125 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___200 *);
	int (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	const struct attribute_group___174 **groups;
	const struct dev_pm_ops___200 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___200 {
	const char *name;
	const struct attribute_group___174 **groups;
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
};

struct class_attribute___200;

struct class___200 {
	const char *name;
	struct module___125 *owner;
	struct class_attribute___200 *class_attrs;
	struct device_attribute___200 *dev_attrs;
	const struct attribute_group___174 **dev_groups;
	struct bin_attribute___176 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *);
	void (*class_release)(struct class___200 *);
	void (*dev_release)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
	struct subsys_private *p;
};

struct class_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct class___200 *, struct class_attribute___200 *, char *);
	ssize_t (*store)(struct class___200 *, struct class_attribute___200 *, const char *, size_t);
	const void * (*namespace)(struct class___200 *, const struct class_attribute___200 *);
};

struct device_rh___200 {
	struct dev_pm_info_rh___200 power;
};

struct disk_part_tbl___49 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___49 *last_lookup;
	struct hd_struct___49 *part[0];
};

struct block_device_operations___45 {
	int (*open)(struct block_device___216 *, fmode_t);
	void (*release)(struct gendisk___49 *, fmode_t);
	int (*ioctl)(struct block_device___216 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___216 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___216 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___49 *, unsigned int);
	int (*media_changed)(struct gendisk___49 *);
	void (*unlock_native_capacity)(struct gendisk___49 *);
	int (*revalidate_disk)(struct gendisk___49 *);
	int (*getgeo)(struct block_device___216 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___216 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___125 *owner;
};

struct irq_chip___142 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___142 *);
	void (*irq_shutdown)(struct irq_data___142 *);
	void (*irq_enable)(struct irq_data___142 *);
	void (*irq_disable)(struct irq_data___142 *);
	void (*irq_ack)(struct irq_data___142 *);
	void (*irq_mask)(struct irq_data___142 *);
	void (*irq_mask_ack)(struct irq_data___142 *);
	void (*irq_unmask)(struct irq_data___142 *);
	void (*irq_eoi)(struct irq_data___142 *);
	int (*irq_set_affinity)(struct irq_data___142 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___142 *);
	int (*irq_set_type)(struct irq_data___142 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___142 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___142 *);
	void (*irq_bus_sync_unlock)(struct irq_data___142 *);
	void (*irq_cpu_online)(struct irq_data___142 *);
	void (*irq_cpu_offline)(struct irq_data___142 *);
	void (*irq_suspend)(struct irq_data___142 *);
	void (*irq_resume)(struct irq_data___142 *);
	void (*irq_pm_shutdown)(struct irq_data___142 *);
	void (*irq_print_chip)(struct irq_data___142 *, struct seq_file___146 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___142 *, void *);
	long unsigned int flags;
};

struct io_cq___45 {
	struct request_queue___45 *q;
	struct io_context___45 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___201 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___45(struct request___45 *, int);

struct request___45 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___45 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___46 *bio;
	struct bio___46 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___45 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___45 *saved_end_io;
		} flush;
	};
	struct gendisk___49 *rq_disk;
	struct hd_struct___49 *part;
	long unsigned int start_time;
	struct request_list___45 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___45 *end_io;
	void *end_io_data;
	struct request___45 *next_rq;
};

typedef int elevator_merge_fn___45(struct request_queue___45 *, struct request___45 **, struct bio___46 *);

typedef void elevator_merge_req_fn___45(struct request_queue___45 *, struct request___45 *, struct request___45 *);

typedef void elevator_merged_fn___45(struct request_queue___45 *, struct request___45 *, int);

typedef int elevator_allow_merge_fn___45(struct request_queue___45 *, struct request___45 *, struct bio___46 *);

typedef void elevator_bio_merged_fn___45(struct request_queue___45 *, struct request___45 *, struct bio___46 *);

typedef int elevator_dispatch_fn___45(struct request_queue___45 *, int);

typedef void elevator_add_req_fn___45(struct request_queue___45 *, struct request___45 *);

typedef struct request___45 *elevator_request_list_fn___45(struct request_queue___45 *, struct request___45 *);

typedef void elevator_completed_req_fn___45(struct request_queue___45 *, struct request___45 *);

typedef int elevator_may_queue_fn___45(struct request_queue___45 *, int);

typedef void elevator_init_icq_fn___45(struct io_cq___45 *);

typedef void elevator_exit_icq_fn___45(struct io_cq___45 *);

typedef int elevator_set_req_fn___45(struct request_queue___45 *, struct request___45 *, struct bio___46 *, gfp_t);

typedef void elevator_put_req_fn___45(struct request___45 *);

typedef void elevator_activate_req_fn___45(struct request_queue___45 *, struct request___45 *);

typedef void elevator_deactivate_req_fn___45(struct request_queue___45 *, struct request___45 *);

struct elevator_type___45;

typedef int elevator_init_fn___46(struct request_queue___45 *, struct elevator_type___45 *);

typedef void elevator_exit_fn___45(struct elevator_queue___45 *);

struct elevator_ops___45 {
	elevator_merge_fn___45 *elevator_merge_fn;
	elevator_merged_fn___45 *elevator_merged_fn;
	elevator_merge_req_fn___45 *elevator_merge_req_fn;
	elevator_allow_merge_fn___45 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___45 *elevator_bio_merged_fn;
	elevator_dispatch_fn___45 *elevator_dispatch_fn;
	elevator_add_req_fn___45 *elevator_add_req_fn;
	elevator_activate_req_fn___45 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___45 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___45 *elevator_completed_req_fn;
	elevator_request_list_fn___45 *elevator_former_req_fn;
	elevator_request_list_fn___45 *elevator_latter_req_fn;
	elevator_init_icq_fn___45 *elevator_init_icq_fn;
	elevator_exit_icq_fn___45 *elevator_exit_icq_fn;
	elevator_set_req_fn___45 *elevator_set_req_fn;
	elevator_put_req_fn___45 *elevator_put_req_fn;
	elevator_may_queue_fn___45 *elevator_may_queue_fn;
	elevator_init_fn___46 *elevator_init_fn;
	elevator_exit_fn___45 *elevator_exit_fn;
};

struct elv_fs_entry___45;

struct elevator_type___45 {
	struct kmem_cache___201 *icq_cache;
	struct elevator_ops___45 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___45 *elevator_attrs;
	char elevator_name[16];
	struct module___125 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___45 {
	struct elevator_type___45 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___218 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___45 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___45 *, char *);
	ssize_t (*store)(struct elevator_queue___45 *, const char *, size_t);
};

struct bvec_merge_data___45 {
	struct block_device___216 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___45 {
	struct request___45 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___16;

typedef int queue_rq_fn___17(struct blk_mq_hw_ctx___16 *, const struct blk_mq_queue_data___16 *);

typedef struct blk_mq_hw_ctx___16 *map_queue_fn___17(struct request_queue___45 *, const int);

typedef enum blk_eh_timer_return timeout_fn___17(struct request___45 *, bool);

typedef int init_request_fn___17(void *, struct request___45 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___17(void *, struct request___45 *, unsigned int, unsigned int);

typedef int init_hctx_fn___16(struct blk_mq_hw_ctx___16 *, void *, unsigned int);

typedef void exit_hctx_fn___16(struct blk_mq_hw_ctx___16 *, unsigned int);

struct blk_mq_ops___16 {
	queue_rq_fn___17 *queue_rq;
	map_queue_fn___17 *map_queue;
	union {
		timeout_fn___17 *timeout;
		struct {
			rq_timed_out_fn___45 *timeout;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	softirq_done_fn___45 *complete;
	init_request_fn___17 *init_request;
	exit_request_fn___17 *exit_request;
	init_hctx_fn___16 *init_hctx;
	exit_hctx_fn___16 *exit_hctx;
};

struct blk_mq_hw_ctx___16 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___45 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct request___45 **padding2;
		struct {
			struct request___45 **rqs;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___3 cpu_notifier;
	struct kobject___23 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___16 {
	struct blk_mq_ops___16 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___218 tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___146 {
	void * (*start)(struct seq_file___146 *, loff_t *);
	void (*stop)(struct seq_file___146 *, void *);
	void * (*next)(struct seq_file___146 *, void *, loff_t *);
	int (*show)(struct seq_file___146 *, void *);
};

struct Scsi_Host___4;

struct scsi_target___5;

struct scsi_dh_data___5;

struct scsi_device___5 {
	struct Scsi_Host___4 *host;
	struct request_queue___45 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___5 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___200 sdev_gendev;
	struct device___200 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___5 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___4;

struct scsi_transport_template___2;

struct Scsi_Host___4 {
	struct list_head __devices;
	struct list_head __targets;
	struct scsi_host_cmd_pool *cmd_pool;
	spinlock_t free_list_lock;
	struct list_head free_list;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex___218 scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___217 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___4 *hostt;
	struct scsi_transport_template___2 *transportt;
	union {
		struct blk_queue_tag___45 *bqt;
		struct blk_mq_tag_set___16 *tag_set;
	};
	union {
		atomic_t host_busy;
		struct {
			unsigned int host_busy;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_id;
	unsigned int max_lun;
	unsigned int max_channel;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int use_blk_tcq: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int ordered_tag: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_blk_mq: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	union {
		atomic_t host_blocked;
		struct {
			unsigned int host_blocked;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	struct request_queue___45 *uspace_req_q;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___200 shost_gendev;
	struct device___200 shost_dev;
	struct list_head sht_legacy_list;
	void *shost_data;
	struct device___200 *dma_dev;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	unsigned int scsi_mq_reserved1;
	unsigned int scsi_mq_reserved2;
	void *scsi_mq_reserved3;
	void *scsi_mq_reserved4;
	atomic_t scsi_mq_reserved5;
	atomic_t scsi_mq_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___5 {
	struct scsi_device___5 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___200 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___5;

struct scsi_dh_data___5 {
	struct scsi_device_handler___5 *scsi_dh;
	struct scsi_device___5 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___5 {
	struct list_head list;
	struct module___125 *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___5 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___5 *);
	void (*detach)(struct scsi_device___5 *);
	int (*activate)(struct scsi_device___5 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___5 *, struct request___45 *);
	int (*set_params)(struct scsi_device___5 *, const char *);
	bool (*match)(struct scsi_device___5 *);
};

struct blk_mq_queue_data___16 {
	struct request___45 *rq;
	struct list_head *list;
	bool last;
};

struct scsi_host_template___4 {
	struct module___125 *module;
	const char *name;
	int (*detect)(struct scsi_host_template___4 *);
	int (*release)(struct Scsi_Host___4 *);
	const char * (*info)(struct Scsi_Host___4 *);
	int (*ioctl)(struct scsi_device___5 *, int, void *);
	int (*compat_ioctl)(struct scsi_device___5 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___4 *, struct scsi_cmnd *);
	int (*transfer_response)(struct scsi_cmnd *, void (*)(struct scsi_cmnd *));
	int (*eh_abort_handler)(struct scsi_cmnd *);
	int (*eh_device_reset_handler)(struct scsi_cmnd *);
	int (*eh_target_reset_handler)(struct scsi_cmnd *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd *);
	int (*eh_host_reset_handler)(struct scsi_cmnd *);
	int (*slave_alloc)(struct scsi_device___5 *);
	int (*slave_configure)(struct scsi_device___5 *);
	void (*slave_destroy)(struct scsi_device___5 *);
	int (*target_alloc)(struct scsi_target___5 *);
	void (*target_destroy)(struct scsi_target___5 *);
	int (*scan_finished)(struct Scsi_Host___4 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___4 *);
	int (*change_queue_depth)(struct scsi_device___5 *, int, int);
	int (*change_queue_type)(struct scsi_device___5 *, int);
	int (*bios_param)(struct scsi_device___5 *, struct block_device___216 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___5 *);
	int (*show_info)(struct seq_file___146 *, struct Scsi_Host___4 *);
	int (*write_info)(struct Scsi_Host___4 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*host_reset)(struct Scsi_Host___4 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int ordered_tag: 1;
	unsigned int no_write_same: 1;
	unsigned int no_async_abort: 1;
	unsigned int disable_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___200 **shost_attrs;
	struct device_attribute___200 **sdev_attrs;
	struct list_head legacy_hosts;
	u64 vendor_id;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	union {
		unsigned int cmd_size;
		struct {
			unsigned int scsi_mq_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	unsigned int scsi_mq_reserved2;
	union {
		struct scsi_host_cmd_pool *cmd_pool;
		struct {
			void *scsi_mq_reserved3;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void *scsi_mq_reserved4;
};

struct attribute_container___3 {
	struct list_head node;
	struct klist containers;
	struct class___200 *class;
	const struct attribute_group___174 *grp;
	struct device_attribute___200 **attrs;
	int (*match)(struct attribute_container___3 *, struct device___200 *);
	long unsigned int flags;
};

struct transport_container___3 {
	struct attribute_container___3 ac;
	const struct attribute_group___174 *statistics;
};

struct scsi_transport_template___2 {
	struct transport_container___3 host_attrs;
	struct transport_container___3 target_attrs;
	struct transport_container___3 device_attrs;
	int (*user_scan)(struct Scsi_Host___4 *, uint, uint, uint);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host___4 *);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*it_nexus_response)(struct Scsi_Host___4 *, u64, int);
	int (*tsk_mgmt_response)(struct Scsi_Host___4 *, u64, u64, int);
};

struct page___216;

typedef struct page___216 *pgtable_t___216;

struct address_space___217;

struct kmem_cache___202;

struct page___216 {
	long unsigned int flags;
	struct address_space___217 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___216 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___216 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___202 *slab_cache;
		struct page___216 *first_page;
	};
	long: 64;
};

struct task_struct___218;

struct pv_cpu_ops___218 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___218 *);
	void (*end_context_switch)(struct task_struct___218 *);
};

struct mutex___219 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___218 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___211 {
	struct page___216 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___225;

struct signal_struct___218;

struct bio_list___46;

struct backing_dev_info___57;

struct io_context___46;

struct task_struct___218 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___218 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___225 *mm;
	struct mm_struct___225 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___218 *real_parent;
	struct task_struct___218 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___218 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___218 = 0,
		VTIME_USER___218 = 1,
		VTIME_SYS___218 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___218 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___46 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___57 *backing_dev_info;
	struct io_context___46 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___219 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___211 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___225 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___225 *, struct mm_struct___225 *);
	void (*dup_mmap)(struct mm_struct___225 *, struct mm_struct___225 *);
	void (*exit_mmap)(struct mm_struct___225 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___225 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___225 *);
	void (*pgd_free)(struct mm_struct___225 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___225 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___225 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___225 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___225 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___225 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___225 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___225 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___225 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___225 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___225 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___225 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___219 lock;
	void *vdso;
} mm_context_t___219;

struct xol_area___216;

struct uprobes_state___216 {
	struct xol_area___216 *xol_area;
};

struct vm_area_struct___225;

struct file___217;

struct core_state___218;

struct mm_struct___225 {
	struct vm_area_struct___225 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___225 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___225 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___219 context;
	long unsigned int flags;
	struct core_state___218 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___218 *owner;
	struct file___217 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___216 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct inode___217;

struct dentry_operations___217;

struct super_block___217;

struct dentry___217 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___217 *d_parent;
	struct qstr d_name;
	struct inode___217 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___217 *d_op;
	struct super_block___217 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___217;

struct address_space___217 {
	struct inode___217 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___219 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___217 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___57 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___217;

struct file_operations___217;

struct file_lock___217;

struct dquot___217;

struct block_device___217;

struct inode___217 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___217 *i_op;
	struct super_block___217 *i_sb;
	struct address_space___217 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___219 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___217 *i_fop;
	struct file_lock___217 *i_flock;
	struct address_space___217 i_data;
	struct dquot___217 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___217 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___217;

struct dentry_operations___217 {
	int (*d_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_hash)(const struct dentry___217 *, struct qstr *);
	int (*d_compare)(const struct dentry___217 *, const struct dentry___217 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___217 *);
	void (*d_release)(struct dentry___217 *);
	void (*d_prune)(struct dentry___217 *);
	void (*d_iput)(struct dentry___217 *, struct inode___217 *);
	char * (*d_dname)(struct dentry___217 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___217 *);
	int (*d_manage)(struct dentry___217 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___217;

struct mem_dqinfo___217 {
	struct quota_format_type___217 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___217;

struct quota_info___217 {
	unsigned int flags;
	struct mutex___219 dqio_mutex;
	struct mutex___219 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___217 *files[2];
	struct mem_dqinfo___217 info[2];
	const struct quota_format_ops___217 *ops[2];
};

struct file_system_type___217;

struct super_operations___217;

struct dquot_operations___217;

struct quotactl_ops___217;

struct super_block___217 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___217 *s_type;
	const struct super_operations___217 *s_op;
	const struct dquot_operations___217 *dq_op;
	const struct quotactl_ops___217 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___217 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___217 *s_bdev;
	struct backing_dev_info___57 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___217 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___219 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___217 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___217 {
	struct vfsmount *mnt;
	struct dentry___217 *dentry;
};

struct irq_data___143;

struct x86_io_apic_ops___143 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___143 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___143;

struct irq_data___143 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___143 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___201;

struct dev_pm_ops___201 {
	int (*prepare)(struct device___201 *);
	void (*complete)(struct device___201 *);
	int (*suspend)(struct device___201 *);
	int (*resume)(struct device___201 *);
	int (*freeze)(struct device___201 *);
	int (*thaw)(struct device___201 *);
	int (*poweroff)(struct device___201 *);
	int (*restore)(struct device___201 *);
	int (*suspend_late)(struct device___201 *);
	int (*resume_early)(struct device___201 *);
	int (*freeze_late)(struct device___201 *);
	int (*thaw_early)(struct device___201 *);
	int (*poweroff_late)(struct device___201 *);
	int (*restore_early)(struct device___201 *);
	int (*suspend_noirq)(struct device___201 *);
	int (*resume_noirq)(struct device___201 *);
	int (*freeze_noirq)(struct device___201 *);
	int (*thaw_noirq)(struct device___201 *);
	int (*poweroff_noirq)(struct device___201 *);
	int (*restore_noirq)(struct device___201 *);
	int (*runtime_suspend)(struct device___201 *);
	int (*runtime_resume)(struct device___201 *);
	int (*runtime_idle)(struct device___201 *);
};

struct dma_map_ops___85;

struct dev_archdata___85 {
	struct dma_map_ops___85 *dma_ops;
	void *iommu;
};

struct device_type___201;

struct bus_type___201;

struct device_driver___201;

struct dev_pm_domain___201;

struct class___201;

struct attribute_group___175;

struct device_rh___201;

struct device___201 {
	struct device___201 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___201 *type;
	struct mutex___219 mutex;
	struct bus_type___201 *bus;
	struct device_driver___201 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___201 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___85 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___201 *class;
	const struct attribute_group___175 **groups;
	void (*release)(struct device___201 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___201 *device_rh;
};

struct dev_pm_info_rh___201 {
	void (*set_latency_tolerance)(struct device___201 *, s32);
};

struct dev_pm_domain___201 {
	struct dev_pm_ops___201 ops;
};

struct smp_ops___218 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___218 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bio___47;

typedef void bio_end_io_t___47(struct bio___47 *, int);

struct bio_vec___47 {
	struct page___216 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___47;

struct bio_set___47;

struct bio___47 {
	sector_t bi_sector;
	struct bio___47 *bi_next;
	struct block_device___217 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___47 *bi_end_io;
	void *bi_private;
	struct io_context___46 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___47 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___47 *bi_io_vec;
	struct bio_set___47 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	struct bio_vec___47 bi_inline_vecs[0];
};

struct hd_struct___50;

struct gendisk___50;

struct request_queue___46;

struct block_device___217 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___217 *bd_inode;
	struct super_block___217 *bd_super;
	struct mutex___219 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___217 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___50 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___50 *bd_disk;
	struct request_queue___46 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___219 bd_fsfreeze_mutex;
};

struct io_cq___46;

struct io_context___46 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___46 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bio_integrity_payload___47 {
	struct bio___47 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___47 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___47 *bip_vec;
	struct bio_vec___47 bip_inline_vecs[0];
};

struct bio_list___46 {
	struct bio___47 *head;
	struct bio___47 *tail;
};

struct bio_set___47 {
	struct kmem_cache___202 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___46 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___217 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___217 *ia_file;
};

struct file___217 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___217 f_path;
	struct inode___217 *f_inode;
	const struct file_operations___217 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___217 *f_mapping;
	struct mutex___219 f_pos_lock;
};

struct zone___218;

struct lruvec___218 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___218 *zone;
};

struct pglist_data___218;

struct zone___218 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___218 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___218 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___218 {
	struct zone___218 *zone;
	int zone_idx;
};

struct zonelist___218 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___218 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___218 {
	struct zone___218 node_zones[4];
	struct zonelist___218 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___218 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___217 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___219 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___217 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___217 {
	int qf_fmt_id;
	const struct quota_format_ops___217 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___217 *qf_next;
};

struct quota_format_ops___217 {
	int (*check_quota_file)(struct super_block___217 *, int);
	int (*read_file_info)(struct super_block___217 *, int);
	int (*write_file_info)(struct super_block___217 *, int);
	int (*free_file_info)(struct super_block___217 *, int);
	int (*read_dqblk)(struct dquot___217 *);
	int (*commit_dqblk)(struct dquot___217 *);
	int (*release_dqblk)(struct dquot___217 *);
};

struct dquot_operations___217 {
	int (*write_dquot)(struct dquot___217 *);
	struct dquot___217 * (*alloc_dquot)(struct super_block___217 *, int);
	void (*destroy_dquot)(struct dquot___217 *);
	int (*acquire_dquot)(struct dquot___217 *);
	int (*release_dquot)(struct dquot___217 *);
	int (*mark_dirty)(struct dquot___217 *);
	int (*write_info)(struct super_block___217 *, int);
	qsize_t * (*get_reserved_space)(struct inode___217 *);
};

struct quotactl_ops___217 {
	int (*quota_on)(struct super_block___217 *, int, int, struct path___217 *);
	int (*quota_on_meta)(struct super_block___217 *, int, int);
	int (*quota_off)(struct super_block___217 *, int);
	int (*quota_sync)(struct super_block___217 *, int);
	int (*get_info)(struct super_block___217 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___217 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___217 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___217 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___217 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___217 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___217 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___217 *, unsigned int);
};

struct address_space_operations___217 {
	int (*writepage)(struct page___216 *, struct writeback_control *);
	int (*readpage)(struct file___217 *, struct page___216 *);
	int (*writepages)(struct address_space___217 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___216 *);
	int (*readpages)(struct file___217 *, struct address_space___217 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___217 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___216 **, void **);
	int (*write_end)(struct file___217 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___216 *, void *);
	sector_t (*bmap)(struct address_space___217 *, sector_t);
	void (*invalidatepage)(struct page___216 *, long unsigned int);
	int (*releasepage)(struct page___216 *, gfp_t);
	void (*freepage)(struct page___216 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___217 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___217 *, struct page___216 *, struct page___216 *, enum migrate_mode);
	int (*launder_page)(struct page___216 *);
	int (*is_partially_uptodate)(struct page___216 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___216 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___217 *, struct page___216 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___217 *, sector_t *);
	void (*swap_deactivate)(struct file___217 *);
	void (*invalidatepage_range)(struct page___216 *, unsigned int, unsigned int);
};

struct bdi_writeback___57 {
	struct backing_dev_info___57 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___57 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___57 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___201 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___217 *debug_dir;
	struct dentry___217 *debug_stats;
};

struct hd_struct___50 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___201 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___50;

struct block_device_operations___46;

struct gendisk___50 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___50 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___50 *part_tbl;
	struct hd_struct___50 part0;
	const struct block_device_operations___46 *fops;
	struct request_queue___46 *queue;
	void *private_data;
	int flags;
	struct device___201 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___46 {
	struct request_queue___46 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___46(struct request_queue___46 *);

typedef void make_request_fn___46(struct request_queue___46 *, struct bio___47 *);

struct request___46;

typedef int prep_rq_fn___46(struct request_queue___46 *, struct request___46 *);

struct bvec_merge_data___46;

typedef int merge_bvec_fn___47(struct request_queue___46 *, struct bvec_merge_data___46 *, struct bio_vec___47 *);

typedef void softirq_done_fn___46(struct request___46 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___46(struct request___46 *);

typedef int dma_drain_needed_fn___46(struct request___46 *);

typedef int lld_busy_fn___46(struct request_queue___46 *);

struct bsg_class_device___46 {
	struct device___201 *class_dev;
	struct device___201 *parent;
	int minor;
	struct request_queue___46 *queue;
	struct kref ref;
	void (*release)(struct device___201 *);
};

typedef void unprep_rq_fn___46(struct request_queue___46 *, struct request___46 *);

struct elevator_queue___46;

struct blk_mq_ops___17;

struct blk_mq_hw_ctx___17;

struct blk_queue_tag___46;

struct blk_mq_tag_set___17;

struct request_queue___46 {
	struct list_head queue_head;
	struct request___46 *last_merge;
	struct elevator_queue___46 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___46 root_rl;
	request_fn_proc___46 *request_fn;
	make_request_fn___46 *make_request_fn;
	prep_rq_fn___46 *prep_rq_fn;
	merge_bvec_fn___47 *merge_bvec_fn;
	softirq_done_fn___46 *softirq_done_fn;
	rq_timed_out_fn___46 *rq_timed_out_fn;
	dma_drain_needed_fn___46 *dma_drain_needed;
	lld_busy_fn___46 *lld_busy_fn;
	struct blk_mq_ops___17 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___17 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___46 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___57 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___201 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___46 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___46 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___219 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___46 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___46 *unprep_rq_fn;
	struct blk_mq_tag_set___17 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___47 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___217 {
	struct dentry___217 * (*lookup)(struct inode___217 *, struct dentry___217 *, unsigned int);
	void * (*follow_link)(struct dentry___217 *, struct nameidata *);
	int (*permission)(struct inode___217 *, int);
	struct posix_acl * (*get_acl)(struct inode___217 *, int);
	int (*readlink)(struct dentry___217 *, char *, int);
	void (*put_link)(struct dentry___217 *, struct nameidata *, void *);
	int (*create)(struct inode___217 *, struct dentry___217 *, umode_t, bool);
	int (*link)(struct dentry___217 *, struct inode___217 *, struct dentry___217 *);
	int (*unlink)(struct inode___217 *, struct dentry___217 *);
	int (*symlink)(struct inode___217 *, struct dentry___217 *, const char *);
	int (*mkdir)(struct inode___217 *, struct dentry___217 *, umode_t);
	int (*rmdir)(struct inode___217 *, struct dentry___217 *);
	int (*mknod)(struct inode___217 *, struct dentry___217 *, umode_t, dev_t);
	int (*rename)(struct inode___217 *, struct dentry___217 *, struct inode___217 *, struct dentry___217 *);
	int (*setattr)(struct dentry___217 *, struct iattr___217 *);
	int (*getattr)(struct vfsmount *, struct dentry___217 *, struct kstat *);
	int (*setxattr)(struct dentry___217 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___217 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___217 *, char *, size_t);
	int (*removexattr)(struct dentry___217 *, const char *);
	int (*fiemap)(struct inode___217 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___217 *, struct timespec *, int);
	int (*atomic_open)(struct inode___217 *, struct dentry___217 *, struct file___217 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___147;

struct file_operations___217 {
	struct module *owner;
	loff_t (*llseek)(struct file___217 *, loff_t, int);
	ssize_t (*read)(struct file___217 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___217 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___217 *, void *, filldir_t);
	unsigned int (*poll)(struct file___217 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___217 *, struct vm_area_struct___225 *);
	int (*open)(struct inode___217 *, struct file___217 *);
	int (*flush)(struct file___217 *, fl_owner_t);
	int (*release)(struct inode___217 *, struct file___217 *);
	int (*fsync)(struct file___217 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___217 *, int);
	int (*lock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*sendpage)(struct file___217 *, struct page___216 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___217 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___217 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___217 *, long int, struct file_lock___217 **, void **);
		struct {
			int (*setlease)(struct file___217 *, long int, struct file_lock___217 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___217 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___147 *, struct file___217 *);
};

struct fasync_struct___217;

struct file_lock_operations___217;

struct lock_manager_operations___217;

struct file_lock___217 {
	struct file_lock___217 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___217 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___217 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___217 *fl_ops;
	const struct lock_manager_operations___217 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___217 {
	void (*fl_copy_lock)(struct file_lock___217 *, struct file_lock___217 *);
	void (*fl_release_private)(struct file_lock___217 *);
};

struct lock_manager_operations___217 {
	int (*lm_compare_owner)(struct file_lock___217 *, struct file_lock___217 *);
	long unsigned int (*lm_owner_key)(struct file_lock___217 *);
	void (*lm_notify)(struct file_lock___217 *);
	int (*lm_grant)(struct file_lock___217 *, struct file_lock___217 *, int);
	void (*lm_break)(struct file_lock___217 *);
	int (*lm_change)(struct file_lock___217 **, int);
};

struct fasync_struct___217 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___217 *fa_next;
	struct file___217 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___217 {
	const char *name;
	int fs_flags;
	struct dentry___217 * (*mount)(struct file_system_type___217 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___217 *);
	struct module *owner;
	struct file_system_type___217 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___217 {
	struct inode___217 * (*alloc_inode)(struct super_block___217 *);
	void (*destroy_inode)(struct inode___217 *);
	void (*dirty_inode)(struct inode___217 *, int);
	int (*write_inode)(struct inode___217 *, struct writeback_control *);
	int (*drop_inode)(struct inode___217 *);
	void (*evict_inode)(struct inode___217 *);
	void (*put_super)(struct super_block___217 *);
	int (*sync_fs)(struct super_block___217 *, int);
	int (*freeze_fs)(struct super_block___217 *);
	int (*unfreeze_fs)(struct super_block___217 *);
	int (*statfs)(struct dentry___217 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___217 *, int *, char *);
	void (*umount_begin)(struct super_block___217 *);
	int (*show_options)(struct seq_file___147 *, struct dentry___217 *);
	int (*show_devname)(struct seq_file___147 *, struct dentry___217 *);
	int (*show_path)(struct seq_file___147 *, struct dentry___217 *);
	int (*show_stats)(struct seq_file___147 *, struct dentry___217 *);
	ssize_t (*quota_read)(struct super_block___217 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___217 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___217 *);
	int (*bdev_try_to_free_page)(struct super_block___217 *, struct page___216 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___217 *);
	void (*free_cached_objects)(struct super_block___217 *, int);
};

struct vm_operations_struct___197;

struct vm_area_struct___225 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___225 *vm_next;
	struct vm_area_struct___225 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___225 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___197 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___217 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___147;

struct seq_file___147 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___219 lock;
	const struct seq_operations___147 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___177;

struct attribute_group___175 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___177 **bin_attrs;
};

struct bin_attribute___177 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___217 *, struct kobject___23 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___217 *, struct kobject___23 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	int (*mmap)(struct file___217 *, struct kobject___23 *, struct bin_attribute___177 *, struct vm_area_struct___225 *);
};

struct dma_map_ops___85 {
	void * (*alloc)(struct device___201 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___201 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___201 *, struct vm_area_struct___225 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___201 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___201 *, struct page___216 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___201 *, dma_addr_t);
	int (*dma_supported)(struct device___201 *, u64);
	int (*set_dma_mask)(struct device___201 *, u64);
	int is_phys;
};

struct bus_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___201 *, char *);
	ssize_t (*store)(struct bus_type___201 *, const char *, size_t);
};

struct device_attribute___201;

struct driver_attribute___201;

struct bus_type___201 {
	const char *name;
	const char *dev_name;
	struct device___201 *dev_root;
	struct bus_attribute___201 *bus_attrs;
	struct device_attribute___201 *dev_attrs;
	struct driver_attribute___201 *drv_attrs;
	const struct attribute_group___175 **bus_groups;
	const struct attribute_group___175 **dev_groups;
	const struct attribute_group___175 **drv_groups;
	int (*match)(struct device___201 *, struct device_driver___201 *);
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	int (*probe)(struct device___201 *);
	int (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*online)(struct device___201 *);
	int (*offline)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct device___201 *, struct device_attribute___201 *, char *);
	ssize_t (*store)(struct device___201 *, struct device_attribute___201 *, const char *, size_t);
};

struct driver_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___201 *, char *);
	ssize_t (*store)(struct device_driver___201 *, const char *, size_t);
};

struct device_driver___201 {
	const char *name;
	struct bus_type___201 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___201 *);
	int (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	const struct attribute_group___175 **groups;
	const struct dev_pm_ops___201 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___201 {
	const char *name;
	const struct attribute_group___175 **groups;
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
};

struct class_attribute___201;

struct class___201 {
	const char *name;
	struct module *owner;
	struct class_attribute___201 *class_attrs;
	struct device_attribute___201 *dev_attrs;
	const struct attribute_group___175 **dev_groups;
	struct bin_attribute___177 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *);
	void (*class_release)(struct class___201 *);
	void (*dev_release)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
	struct subsys_private *p;
};

struct class_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct class___201 *, struct class_attribute___201 *, char *);
	ssize_t (*store)(struct class___201 *, struct class_attribute___201 *, const char *, size_t);
	const void * (*namespace)(struct class___201 *, const struct class_attribute___201 *);
};

struct device_rh___201 {
	struct dev_pm_info_rh___201 power;
};

struct xol_area___216 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___216 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___201;

struct memcg_cache_params___202;

struct kmem_cache___202 {
	struct kmem_cache_cpu___201 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___202 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___193;

struct vm_operations_struct___197 {
	void (*open)(struct vm_area_struct___225 *);
	void (*close)(struct vm_area_struct___225 *);
	int (*fault)(struct vm_area_struct___225 *, struct vm_fault___193 *);
	int (*page_mkwrite)(struct vm_area_struct___225 *, struct vm_fault___193 *);
	int (*access)(struct vm_area_struct___225 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___225 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___225 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___225 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___225 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___218 {
	struct task_struct___218 *task;
	struct core_thread___218 *next;
};

struct core_state___218 {
	atomic_t nr_threads;
	struct core_thread___218 dumper;
	struct completion startup;
};

struct vm_fault___193 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___216 *page;
};

struct signal_struct___218 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___218 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___218 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___219 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___201 {
	void **freelist;
	long unsigned int tid;
	struct page___216 *page;
	struct page___216 *partial;
};

struct memcg_cache_params___202 {
	bool is_root_cache;
	union {
		struct kmem_cache___202 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___202 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct disk_part_tbl___50 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___50 *last_lookup;
	struct hd_struct___50 *part[0];
};

struct block_device_operations___46 {
	int (*open)(struct block_device___217 *, fmode_t);
	void (*release)(struct gendisk___50 *, fmode_t);
	int (*ioctl)(struct block_device___217 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___217 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___217 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___50 *, unsigned int);
	int (*media_changed)(struct gendisk___50 *);
	void (*unlock_native_capacity)(struct gendisk___50 *);
	int (*revalidate_disk)(struct gendisk___50 *);
	int (*getgeo)(struct block_device___217 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___217 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct irq_chip___143 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___143 *);
	void (*irq_shutdown)(struct irq_data___143 *);
	void (*irq_enable)(struct irq_data___143 *);
	void (*irq_disable)(struct irq_data___143 *);
	void (*irq_ack)(struct irq_data___143 *);
	void (*irq_mask)(struct irq_data___143 *);
	void (*irq_mask_ack)(struct irq_data___143 *);
	void (*irq_unmask)(struct irq_data___143 *);
	void (*irq_eoi)(struct irq_data___143 *);
	int (*irq_set_affinity)(struct irq_data___143 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___143 *);
	int (*irq_set_type)(struct irq_data___143 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___143 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___143 *);
	void (*irq_bus_sync_unlock)(struct irq_data___143 *);
	void (*irq_cpu_online)(struct irq_data___143 *);
	void (*irq_cpu_offline)(struct irq_data___143 *);
	void (*irq_suspend)(struct irq_data___143 *);
	void (*irq_resume)(struct irq_data___143 *);
	void (*irq_pm_shutdown)(struct irq_data___143 *);
	void (*irq_print_chip)(struct irq_data___143 *, struct seq_file___147 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___143 *, void *);
	long unsigned int flags;
};

struct io_cq___46 {
	struct request_queue___46 *q;
	struct io_context___46 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___202 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___46(struct request___46 *, int);

struct request___46 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___46 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___47 *bio;
	struct bio___47 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___46 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___46 *saved_end_io;
		} flush;
	};
	struct gendisk___50 *rq_disk;
	struct hd_struct___50 *part;
	long unsigned int start_time;
	struct request_list___46 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___46 *end_io;
	void *end_io_data;
	struct request___46 *next_rq;
};

typedef int elevator_merge_fn___46(struct request_queue___46 *, struct request___46 **, struct bio___47 *);

typedef void elevator_merge_req_fn___46(struct request_queue___46 *, struct request___46 *, struct request___46 *);

typedef void elevator_merged_fn___46(struct request_queue___46 *, struct request___46 *, int);

typedef int elevator_allow_merge_fn___46(struct request_queue___46 *, struct request___46 *, struct bio___47 *);

typedef void elevator_bio_merged_fn___46(struct request_queue___46 *, struct request___46 *, struct bio___47 *);

typedef int elevator_dispatch_fn___46(struct request_queue___46 *, int);

typedef void elevator_add_req_fn___46(struct request_queue___46 *, struct request___46 *);

typedef struct request___46 *elevator_request_list_fn___46(struct request_queue___46 *, struct request___46 *);

typedef void elevator_completed_req_fn___46(struct request_queue___46 *, struct request___46 *);

typedef int elevator_may_queue_fn___46(struct request_queue___46 *, int);

typedef void elevator_init_icq_fn___46(struct io_cq___46 *);

typedef void elevator_exit_icq_fn___46(struct io_cq___46 *);

typedef int elevator_set_req_fn___46(struct request_queue___46 *, struct request___46 *, struct bio___47 *, gfp_t);

typedef void elevator_put_req_fn___46(struct request___46 *);

typedef void elevator_activate_req_fn___46(struct request_queue___46 *, struct request___46 *);

typedef void elevator_deactivate_req_fn___46(struct request_queue___46 *, struct request___46 *);

struct elevator_type___46;

typedef int elevator_init_fn___47(struct request_queue___46 *, struct elevator_type___46 *);

typedef void elevator_exit_fn___46(struct elevator_queue___46 *);

struct elevator_ops___46 {
	elevator_merge_fn___46 *elevator_merge_fn;
	elevator_merged_fn___46 *elevator_merged_fn;
	elevator_merge_req_fn___46 *elevator_merge_req_fn;
	elevator_allow_merge_fn___46 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___46 *elevator_bio_merged_fn;
	elevator_dispatch_fn___46 *elevator_dispatch_fn;
	elevator_add_req_fn___46 *elevator_add_req_fn;
	elevator_activate_req_fn___46 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___46 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___46 *elevator_completed_req_fn;
	elevator_request_list_fn___46 *elevator_former_req_fn;
	elevator_request_list_fn___46 *elevator_latter_req_fn;
	elevator_init_icq_fn___46 *elevator_init_icq_fn;
	elevator_exit_icq_fn___46 *elevator_exit_icq_fn;
	elevator_set_req_fn___46 *elevator_set_req_fn;
	elevator_put_req_fn___46 *elevator_put_req_fn;
	elevator_may_queue_fn___46 *elevator_may_queue_fn;
	elevator_init_fn___47 *elevator_init_fn;
	elevator_exit_fn___46 *elevator_exit_fn;
};

struct elv_fs_entry___46;

struct elevator_type___46 {
	struct kmem_cache___202 *icq_cache;
	struct elevator_ops___46 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___46 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___46 {
	struct elevator_type___46 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___219 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___46 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___46 *, char *);
	ssize_t (*store)(struct elevator_queue___46 *, const char *, size_t);
};

struct bvec_merge_data___46 {
	struct block_device___217 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___46 {
	struct request___46 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___17;

typedef int queue_rq_fn___18(struct blk_mq_hw_ctx___17 *, const struct blk_mq_queue_data___17 *);

typedef struct blk_mq_hw_ctx___17 *map_queue_fn___18(struct request_queue___46 *, const int);

typedef enum blk_eh_timer_return timeout_fn___18(struct request___46 *, bool);

typedef int init_request_fn___18(void *, struct request___46 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___18(void *, struct request___46 *, unsigned int, unsigned int);

typedef int init_hctx_fn___17(struct blk_mq_hw_ctx___17 *, void *, unsigned int);

typedef void exit_hctx_fn___17(struct blk_mq_hw_ctx___17 *, unsigned int);

struct blk_mq_ops___17 {
	queue_rq_fn___18 *queue_rq;
	map_queue_fn___18 *map_queue;
	union {
		timeout_fn___18 *timeout;
		struct {
			rq_timed_out_fn___46 *timeout;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	softirq_done_fn___46 *complete;
	init_request_fn___18 *init_request;
	exit_request_fn___18 *exit_request;
	init_hctx_fn___17 *init_hctx;
	exit_hctx_fn___17 *exit_hctx;
};

struct blk_mq_hw_ctx___17 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___46 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct request___46 **padding2;
		struct {
			struct request___46 **rqs;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___3 cpu_notifier;
	struct kobject___23 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___17 {
	struct blk_mq_ops___17 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___219 tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___147 {
	void * (*start)(struct seq_file___147 *, loff_t *);
	void (*stop)(struct seq_file___147 *, void *);
	void * (*next)(struct seq_file___147 *, void *, loff_t *);
	int (*show)(struct seq_file___147 *, void *);
};

struct blk_mq_queue_data___17 {
	struct request___46 *rq;
	struct list_head *list;
	bool last;
};

struct page___217;

typedef struct page___217 *pgtable_t___217;

struct address_space___218;

struct kmem_cache___203;

struct page___217 {
	long unsigned int flags;
	struct address_space___218 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___217 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___217 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___203 *slab_cache;
		struct page___217 *first_page;
	};
	long: 64;
};

struct task_struct___219;

struct pv_cpu_ops___219 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___219 *);
	void (*end_context_switch)(struct task_struct___219 *);
};

struct mutex___220 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___219 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___212 {
	struct page___217 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___226;

struct signal_struct___219;

struct bio_list___47;

struct backing_dev_info___58;

struct io_context___47;

struct task_struct___219 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___219 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___226 *mm;
	struct mm_struct___226 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___219 *real_parent;
	struct task_struct___219 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___219 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___219 = 0,
		VTIME_USER___219 = 1,
		VTIME_SYS___219 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___219 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___47 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___58 *backing_dev_info;
	struct io_context___47 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___220 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___212 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___226 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___226 *, struct mm_struct___226 *);
	void (*dup_mmap)(struct mm_struct___226 *, struct mm_struct___226 *);
	void (*exit_mmap)(struct mm_struct___226 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___226 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___226 *);
	void (*pgd_free)(struct mm_struct___226 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___226 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___226 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___226 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___226 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___226 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___226 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___226 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___226 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___226 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___226 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___226 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___220 lock;
	void *vdso;
} mm_context_t___220;

struct xol_area___217;

struct uprobes_state___217 {
	struct xol_area___217 *xol_area;
};

struct vm_area_struct___226;

struct file___218;

struct core_state___219;

struct mm_struct___226 {
	struct vm_area_struct___226 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___226 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___226 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___220 context;
	long unsigned int flags;
	struct core_state___219 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___219 *owner;
	struct file___218 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___217 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___219;

struct lruvec___219 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___219 *zone;
};

struct pglist_data___219;

struct zone___219 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___219 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___219 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___219 {
	struct zone___219 *zone;
	int zone_idx;
};

struct zonelist___219 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___219 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___219 {
	struct zone___219 node_zones[4];
	struct zonelist___219 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___219 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___202;

struct dev_pm_ops___202 {
	int (*prepare)(struct device___202 *);
	void (*complete)(struct device___202 *);
	int (*suspend)(struct device___202 *);
	int (*resume)(struct device___202 *);
	int (*freeze)(struct device___202 *);
	int (*thaw)(struct device___202 *);
	int (*poweroff)(struct device___202 *);
	int (*restore)(struct device___202 *);
	int (*suspend_late)(struct device___202 *);
	int (*resume_early)(struct device___202 *);
	int (*freeze_late)(struct device___202 *);
	int (*thaw_early)(struct device___202 *);
	int (*poweroff_late)(struct device___202 *);
	int (*restore_early)(struct device___202 *);
	int (*suspend_noirq)(struct device___202 *);
	int (*resume_noirq)(struct device___202 *);
	int (*freeze_noirq)(struct device___202 *);
	int (*thaw_noirq)(struct device___202 *);
	int (*poweroff_noirq)(struct device___202 *);
	int (*restore_noirq)(struct device___202 *);
	int (*runtime_suspend)(struct device___202 *);
	int (*runtime_resume)(struct device___202 *);
	int (*runtime_idle)(struct device___202 *);
};

struct dma_map_ops___86;

struct dev_archdata___86 {
	struct dma_map_ops___86 *dma_ops;
	void *iommu;
};

struct device_type___202;

struct bus_type___202;

struct device_driver___202;

struct dev_pm_domain___202;

struct class___202;

struct attribute_group___176;

struct device_rh___202;

struct device___202 {
	struct device___202 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___202 *type;
	struct mutex___220 mutex;
	struct bus_type___202 *bus;
	struct device_driver___202 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___202 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___86 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___202 *class;
	const struct attribute_group___176 **groups;
	void (*release)(struct device___202 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___202 *device_rh;
};

struct dev_pm_info_rh___202 {
	void (*set_latency_tolerance)(struct device___202 *, s32);
};

struct dev_pm_domain___202 {
	struct dev_pm_ops___202 ops;
};

struct smp_ops___219 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___219 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___217 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___217 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___202;

struct memcg_cache_params___203;

struct kmem_cache___203 {
	struct kmem_cache_cpu___202 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___203 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___218;

struct address_space_operations___218;

struct address_space___218 {
	struct inode___218 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___220 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___218 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___58 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___218;

struct path___218 {
	struct vfsmount *mnt;
	struct dentry___218 *dentry;
};

struct file_operations___218;

struct file___218 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___218 f_path;
	struct inode___218 *f_inode;
	const struct file_operations___218 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___218 *f_mapping;
	struct mutex___220 f_pos_lock;
};

struct vm_operations_struct___198;

struct vm_area_struct___226 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___226 *vm_next;
	struct vm_area_struct___226 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___226 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___198 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___218 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___194;

struct vm_operations_struct___198 {
	void (*open)(struct vm_area_struct___226 *);
	void (*close)(struct vm_area_struct___226 *);
	int (*fault)(struct vm_area_struct___226 *, struct vm_fault___194 *);
	int (*page_mkwrite)(struct vm_area_struct___226 *, struct vm_fault___194 *);
	int (*access)(struct vm_area_struct___226 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___226 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___226 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___226 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___226 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___219 {
	struct task_struct___219 *task;
	struct core_thread___219 *next;
};

struct core_state___219 {
	atomic_t nr_threads;
	struct core_thread___219 dumper;
	struct completion startup;
};

struct vm_fault___194 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___217 *page;
};

struct bin_attribute___178;

struct attribute_group___176 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___178 **bin_attrs;
};

struct bin_attribute___178 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___218 *, struct kobject___23 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___218 *, struct kobject___23 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	int (*mmap)(struct file___218 *, struct kobject___23 *, struct bin_attribute___178 *, struct vm_area_struct___226 *);
};

struct dma_map_ops___86 {
	void * (*alloc)(struct device___202 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___202 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___202 *, struct vm_area_struct___226 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___202 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___202 *, struct page___217 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___202 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___202 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___202 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___202 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___202 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___202 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___202 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___202 *, dma_addr_t);
	int (*dma_supported)(struct device___202 *, u64);
	int (*set_dma_mask)(struct device___202 *, u64);
	int is_phys;
};

struct bus_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___202 *, char *);
	ssize_t (*store)(struct bus_type___202 *, const char *, size_t);
};

struct device_attribute___202;

struct driver_attribute___202;

struct bus_type___202 {
	const char *name;
	const char *dev_name;
	struct device___202 *dev_root;
	struct bus_attribute___202 *bus_attrs;
	struct device_attribute___202 *dev_attrs;
	struct driver_attribute___202 *drv_attrs;
	const struct attribute_group___176 **bus_groups;
	const struct attribute_group___176 **dev_groups;
	const struct attribute_group___176 **drv_groups;
	int (*match)(struct device___202 *, struct device_driver___202 *);
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	int (*probe)(struct device___202 *);
	int (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*online)(struct device___202 *);
	int (*offline)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct device___202 *, struct device_attribute___202 *, char *);
	ssize_t (*store)(struct device___202 *, struct device_attribute___202 *, const char *, size_t);
};

struct driver_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___202 *, char *);
	ssize_t (*store)(struct device_driver___202 *, const char *, size_t);
};

struct device_driver___202 {
	const char *name;
	struct bus_type___202 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___202 *);
	int (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	const struct attribute_group___176 **groups;
	const struct dev_pm_ops___202 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___202 {
	const char *name;
	const struct attribute_group___176 **groups;
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
};

struct class_attribute___202;

struct class___202 {
	const char *name;
	struct module *owner;
	struct class_attribute___202 *class_attrs;
	struct device_attribute___202 *dev_attrs;
	const struct attribute_group___176 **dev_groups;
	struct bin_attribute___178 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *);
	void (*class_release)(struct class___202 *);
	void (*dev_release)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
	struct subsys_private *p;
};

struct class_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct class___202 *, struct class_attribute___202 *, char *);
	ssize_t (*store)(struct class___202 *, struct class_attribute___202 *, const char *, size_t);
	const void * (*namespace)(struct class___202 *, const struct class_attribute___202 *);
};

struct device_rh___202 {
	struct dev_pm_info_rh___202 power;
};

struct signal_struct___219 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___219 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___219 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___220 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___48;

struct bio_list___47 {
	struct bio___48 *head;
	struct bio___48 *tail;
};

struct bdi_writeback___58 {
	struct backing_dev_info___58 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___58 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___58 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___202 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___218 *debug_dir;
	struct dentry___218 *debug_stats;
};

struct io_cq___47;

struct io_context___47 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___47 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___202 {
	void **freelist;
	long unsigned int tid;
	struct page___217 *page;
	struct page___217 *partial;
};

struct memcg_cache_params___203 {
	bool is_root_cache;
	union {
		struct kmem_cache___203 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___203 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___218;

struct super_block___218;

struct dentry___218 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___218 *d_parent;
	struct qstr d_name;
	struct inode___218 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___218 *d_op;
	struct super_block___218 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___218;

struct file_lock___218;

struct dquot___218;

struct block_device___218;

struct inode___218 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___218 *i_op;
	struct super_block___218 *i_sb;
	struct address_space___218 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___220 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___218 *i_fop;
	struct file_lock___218 *i_flock;
	struct address_space___218 i_data;
	struct dquot___218 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___218 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___218 {
	int (*d_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_hash)(const struct dentry___218 *, struct qstr *);
	int (*d_compare)(const struct dentry___218 *, const struct dentry___218 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___218 *);
	void (*d_release)(struct dentry___218 *);
	void (*d_prune)(struct dentry___218 *);
	void (*d_iput)(struct dentry___218 *, struct inode___218 *);
	char * (*d_dname)(struct dentry___218 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___218 *);
	int (*d_manage)(struct dentry___218 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___218;

struct mem_dqinfo___218 {
	struct quota_format_type___218 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___218;

struct quota_info___218 {
	unsigned int flags;
	struct mutex___220 dqio_mutex;
	struct mutex___220 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___218 *files[2];
	struct mem_dqinfo___218 info[2];
	const struct quota_format_ops___218 *ops[2];
};

struct file_system_type___218;

struct super_operations___218;

struct dquot_operations___218;

struct quotactl_ops___218;

struct super_block___218 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___218 *s_type;
	const struct super_operations___218 *s_op;
	const struct dquot_operations___218 *dq_op;
	const struct quotactl_ops___218 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___218 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___218 *s_bdev;
	struct backing_dev_info___58 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___218 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___220 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___218 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___48(struct bio___48 *, int);

struct bio_vec___48 {
	struct page___217 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___48;

struct bio_set___48;

struct bio___48 {
	sector_t bi_sector;
	struct bio___48 *bi_next;
	struct block_device___218 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___48 *bi_end_io;
	void *bi_private;
	struct io_context___47 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___48 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___48 *bi_io_vec;
	struct bio_set___48 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___48 bi_inline_vecs[0];
};

struct hd_struct___51;

struct gendisk___51;

struct request_queue___47;

struct block_device___218 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___218 *bd_inode;
	struct super_block___218 *bd_super;
	struct mutex___220 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___218 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___51 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___51 *bd_disk;
	struct request_queue___47 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___220 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___48 {
	struct bio___48 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___48 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___48 *bip_vec;
	struct bio_vec___48 bip_inline_vecs[0];
};

struct bio_set___48 {
	struct kmem_cache___203 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___47 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___218 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___218 *ia_file;
};

struct dquot___218 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___220 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___218 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___218 {
	int qf_fmt_id;
	const struct quota_format_ops___218 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___218 *qf_next;
};

struct quota_format_ops___218 {
	int (*check_quota_file)(struct super_block___218 *, int);
	int (*read_file_info)(struct super_block___218 *, int);
	int (*write_file_info)(struct super_block___218 *, int);
	int (*free_file_info)(struct super_block___218 *, int);
	int (*read_dqblk)(struct dquot___218 *);
	int (*commit_dqblk)(struct dquot___218 *);
	int (*release_dqblk)(struct dquot___218 *);
};

struct dquot_operations___218 {
	int (*write_dquot)(struct dquot___218 *);
	struct dquot___218 * (*alloc_dquot)(struct super_block___218 *, int);
	void (*destroy_dquot)(struct dquot___218 *);
	int (*acquire_dquot)(struct dquot___218 *);
	int (*release_dquot)(struct dquot___218 *);
	int (*mark_dirty)(struct dquot___218 *);
	int (*write_info)(struct super_block___218 *, int);
	qsize_t * (*get_reserved_space)(struct inode___218 *);
};

struct quotactl_ops___218 {
	int (*quota_on)(struct super_block___218 *, int, int, struct path___218 *);
	int (*quota_on_meta)(struct super_block___218 *, int, int);
	int (*quota_off)(struct super_block___218 *, int);
	int (*quota_sync)(struct super_block___218 *, int);
	int (*get_info)(struct super_block___218 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___218 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___218 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___218 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___218 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___218 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___218 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___218 *, unsigned int);
};

struct address_space_operations___218 {
	int (*writepage)(struct page___217 *, struct writeback_control *);
	int (*readpage)(struct file___218 *, struct page___217 *);
	int (*writepages)(struct address_space___218 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___217 *);
	int (*readpages)(struct file___218 *, struct address_space___218 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___218 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___217 **, void **);
	int (*write_end)(struct file___218 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___217 *, void *);
	sector_t (*bmap)(struct address_space___218 *, sector_t);
	void (*invalidatepage)(struct page___217 *, long unsigned int);
	int (*releasepage)(struct page___217 *, gfp_t);
	void (*freepage)(struct page___217 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___218 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___218 *, struct page___217 *, struct page___217 *, enum migrate_mode);
	int (*launder_page)(struct page___217 *);
	int (*is_partially_uptodate)(struct page___217 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___217 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___218 *, struct page___217 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___218 *, sector_t *);
	void (*swap_deactivate)(struct file___218 *);
	void (*invalidatepage_range)(struct page___217 *, unsigned int, unsigned int);
};

struct hd_struct___51 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___202 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___51;

struct block_device_operations___47;

struct gendisk___51 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___51 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___51 *part_tbl;
	struct hd_struct___51 part0;
	const struct block_device_operations___47 *fops;
	struct request_queue___47 *queue;
	void *private_data;
	int flags;
	struct device___202 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___47 {
	struct request_queue___47 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___47(struct request_queue___47 *);

typedef void make_request_fn___47(struct request_queue___47 *, struct bio___48 *);

struct request___47;

typedef int prep_rq_fn___47(struct request_queue___47 *, struct request___47 *);

struct bvec_merge_data___47;

typedef int merge_bvec_fn___48(struct request_queue___47 *, struct bvec_merge_data___47 *, struct bio_vec___48 *);

typedef void softirq_done_fn___47(struct request___47 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___47(struct request___47 *);

typedef int dma_drain_needed_fn___47(struct request___47 *);

typedef int lld_busy_fn___47(struct request_queue___47 *);

struct bsg_class_device___47 {
	struct device___202 *class_dev;
	struct device___202 *parent;
	int minor;
	struct request_queue___47 *queue;
	struct kref ref;
	void (*release)(struct device___202 *);
};

typedef void unprep_rq_fn___47(struct request_queue___47 *, struct request___47 *);

struct elevator_queue___47;

struct blk_queue_tag___47;

struct request_queue___47 {
	struct list_head queue_head;
	struct request___47 *last_merge;
	struct elevator_queue___47 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___47 root_rl;
	request_fn_proc___47 *request_fn;
	make_request_fn___47 *make_request_fn;
	prep_rq_fn___47 *prep_rq_fn;
	merge_bvec_fn___48 *merge_bvec_fn;
	softirq_done_fn___47 *softirq_done_fn;
	rq_timed_out_fn___47 *rq_timed_out_fn;
	dma_drain_needed_fn___47 *dma_drain_needed;
	lld_busy_fn___47 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___47 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___58 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___202 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___47 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___47 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___220 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___47 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___47 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___48 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___218 {
	struct dentry___218 * (*lookup)(struct inode___218 *, struct dentry___218 *, unsigned int);
	void * (*follow_link)(struct dentry___218 *, struct nameidata *);
	int (*permission)(struct inode___218 *, int);
	struct posix_acl * (*get_acl)(struct inode___218 *, int);
	int (*readlink)(struct dentry___218 *, char *, int);
	void (*put_link)(struct dentry___218 *, struct nameidata *, void *);
	int (*create)(struct inode___218 *, struct dentry___218 *, umode_t, bool);
	int (*link)(struct dentry___218 *, struct inode___218 *, struct dentry___218 *);
	int (*unlink)(struct inode___218 *, struct dentry___218 *);
	int (*symlink)(struct inode___218 *, struct dentry___218 *, const char *);
	int (*mkdir)(struct inode___218 *, struct dentry___218 *, umode_t);
	int (*rmdir)(struct inode___218 *, struct dentry___218 *);
	int (*mknod)(struct inode___218 *, struct dentry___218 *, umode_t, dev_t);
	int (*rename)(struct inode___218 *, struct dentry___218 *, struct inode___218 *, struct dentry___218 *);
	int (*setattr)(struct dentry___218 *, struct iattr___218 *);
	int (*getattr)(struct vfsmount *, struct dentry___218 *, struct kstat *);
	int (*setxattr)(struct dentry___218 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___218 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___218 *, char *, size_t);
	int (*removexattr)(struct dentry___218 *, const char *);
	int (*fiemap)(struct inode___218 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___218 *, struct timespec *, int);
	int (*atomic_open)(struct inode___218 *, struct dentry___218 *, struct file___218 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___218 {
	struct module *owner;
	loff_t (*llseek)(struct file___218 *, loff_t, int);
	ssize_t (*read)(struct file___218 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___218 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___218 *, void *, filldir_t);
	unsigned int (*poll)(struct file___218 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___218 *, struct vm_area_struct___226 *);
	int (*open)(struct inode___218 *, struct file___218 *);
	int (*flush)(struct file___218 *, fl_owner_t);
	int (*release)(struct inode___218 *, struct file___218 *);
	int (*fsync)(struct file___218 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___218 *, int);
	int (*lock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*sendpage)(struct file___218 *, struct page___217 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___218 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___218 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___218 *, long int, struct file_lock___218 **, void **);
		struct {
			int (*setlease)(struct file___218 *, long int, struct file_lock___218 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___218 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___218 *);
};

struct fasync_struct___218;

struct file_lock_operations___218;

struct lock_manager_operations___218;

struct file_lock___218 {
	struct file_lock___218 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___218 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___218 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___218 *fl_ops;
	const struct lock_manager_operations___218 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___218 {
	void (*fl_copy_lock)(struct file_lock___218 *, struct file_lock___218 *);
	void (*fl_release_private)(struct file_lock___218 *);
};

struct lock_manager_operations___218 {
	int (*lm_compare_owner)(struct file_lock___218 *, struct file_lock___218 *);
	long unsigned int (*lm_owner_key)(struct file_lock___218 *);
	void (*lm_notify)(struct file_lock___218 *);
	int (*lm_grant)(struct file_lock___218 *, struct file_lock___218 *, int);
	void (*lm_break)(struct file_lock___218 *);
	int (*lm_change)(struct file_lock___218 **, int);
};

struct fasync_struct___218 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___218 *fa_next;
	struct file___218 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___218 {
	const char *name;
	int fs_flags;
	struct dentry___218 * (*mount)(struct file_system_type___218 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___218 *);
	struct module *owner;
	struct file_system_type___218 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___218 {
	struct inode___218 * (*alloc_inode)(struct super_block___218 *);
	void (*destroy_inode)(struct inode___218 *);
	void (*dirty_inode)(struct inode___218 *, int);
	int (*write_inode)(struct inode___218 *, struct writeback_control *);
	int (*drop_inode)(struct inode___218 *);
	void (*evict_inode)(struct inode___218 *);
	void (*put_super)(struct super_block___218 *);
	int (*sync_fs)(struct super_block___218 *, int);
	int (*freeze_fs)(struct super_block___218 *);
	int (*unfreeze_fs)(struct super_block___218 *);
	int (*statfs)(struct dentry___218 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___218 *, int *, char *);
	void (*umount_begin)(struct super_block___218 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___218 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___218 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___218 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___218 *);
	ssize_t (*quota_read)(struct super_block___218 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___218 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___218 *);
	int (*bdev_try_to_free_page)(struct super_block___218 *, struct page___217 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___218 *);
	void (*free_cached_objects)(struct super_block___218 *, int);
};

struct disk_part_tbl___51 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___51 *last_lookup;
	struct hd_struct___51 *part[0];
};

struct block_device_operations___47 {
	int (*open)(struct block_device___218 *, fmode_t);
	void (*release)(struct gendisk___51 *, fmode_t);
	int (*ioctl)(struct block_device___218 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___218 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___218 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___51 *, unsigned int);
	int (*media_changed)(struct gendisk___51 *);
	void (*unlock_native_capacity)(struct gendisk___51 *);
	int (*revalidate_disk)(struct gendisk___51 *);
	int (*getgeo)(struct block_device___218 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___218 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct io_cq___47 {
	struct request_queue___47 *q;
	struct io_context___47 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___203 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___47(struct request___47 *, int);

struct request___47 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___47 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___48 *bio;
	struct bio___48 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___47 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___47 *saved_end_io;
		} flush;
	};
	struct gendisk___51 *rq_disk;
	struct hd_struct___51 *part;
	long unsigned int start_time;
	struct request_list___47 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___47 *end_io;
	void *end_io_data;
	struct request___47 *next_rq;
};

typedef int elevator_merge_fn___47(struct request_queue___47 *, struct request___47 **, struct bio___48 *);

typedef void elevator_merge_req_fn___47(struct request_queue___47 *, struct request___47 *, struct request___47 *);

typedef void elevator_merged_fn___47(struct request_queue___47 *, struct request___47 *, int);

typedef int elevator_allow_merge_fn___47(struct request_queue___47 *, struct request___47 *, struct bio___48 *);

typedef void elevator_bio_merged_fn___47(struct request_queue___47 *, struct request___47 *, struct bio___48 *);

typedef int elevator_dispatch_fn___47(struct request_queue___47 *, int);

typedef void elevator_add_req_fn___47(struct request_queue___47 *, struct request___47 *);

typedef struct request___47 *elevator_request_list_fn___47(struct request_queue___47 *, struct request___47 *);

typedef void elevator_completed_req_fn___47(struct request_queue___47 *, struct request___47 *);

typedef int elevator_may_queue_fn___47(struct request_queue___47 *, int);

typedef void elevator_init_icq_fn___47(struct io_cq___47 *);

typedef void elevator_exit_icq_fn___47(struct io_cq___47 *);

typedef int elevator_set_req_fn___47(struct request_queue___47 *, struct request___47 *, struct bio___48 *, gfp_t);

typedef void elevator_put_req_fn___47(struct request___47 *);

typedef void elevator_activate_req_fn___47(struct request_queue___47 *, struct request___47 *);

typedef void elevator_deactivate_req_fn___47(struct request_queue___47 *, struct request___47 *);

struct elevator_type___47;

typedef int elevator_init_fn___48(struct request_queue___47 *, struct elevator_type___47 *);

typedef void elevator_exit_fn___47(struct elevator_queue___47 *);

struct elevator_ops___47 {
	elevator_merge_fn___47 *elevator_merge_fn;
	elevator_merged_fn___47 *elevator_merged_fn;
	elevator_merge_req_fn___47 *elevator_merge_req_fn;
	elevator_allow_merge_fn___47 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___47 *elevator_bio_merged_fn;
	elevator_dispatch_fn___47 *elevator_dispatch_fn;
	elevator_add_req_fn___47 *elevator_add_req_fn;
	elevator_activate_req_fn___47 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___47 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___47 *elevator_completed_req_fn;
	elevator_request_list_fn___47 *elevator_former_req_fn;
	elevator_request_list_fn___47 *elevator_latter_req_fn;
	elevator_init_icq_fn___47 *elevator_init_icq_fn;
	elevator_exit_icq_fn___47 *elevator_exit_icq_fn;
	elevator_set_req_fn___47 *elevator_set_req_fn;
	elevator_put_req_fn___47 *elevator_put_req_fn;
	elevator_may_queue_fn___47 *elevator_may_queue_fn;
	elevator_init_fn___48 *elevator_init_fn;
	elevator_exit_fn___47 *elevator_exit_fn;
};

struct elv_fs_entry___47;

struct elevator_type___47 {
	struct kmem_cache___203 *icq_cache;
	struct elevator_ops___47 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___47 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___47 {
	struct elevator_type___47 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___220 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___47 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___47 *, char *);
	ssize_t (*store)(struct elevator_queue___47 *, const char *, size_t);
};

struct bvec_merge_data___47 {
	struct block_device___218 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___47 {
	struct request___47 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct scsi_cmnd___4;

struct scsi_target___6;

struct scsi_dh_data___6;

struct scsi_device___6 {
	struct Scsi_Host *host;
	struct request_queue___47 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd___4 *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___6 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___202 sdev_gendev;
	struct device___202 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___6 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___4 {
	struct scsi_device___6 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___47 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___4 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	unsigned char tag;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
};

struct scsi_target___6 {
	struct scsi_device___6 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___202 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___6;

struct scsi_dh_data___6 {
	struct scsi_device_handler___6 *scsi_dh;
	struct scsi_device___6 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___6 {
	struct list_head list;
	struct module *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___6 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___6 *);
	void (*detach)(struct scsi_device___6 *);
	int (*activate)(struct scsi_device___6 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___6 *, struct request___47 *);
	int (*set_params)(struct scsi_device___6 *, const char *);
	bool (*match)(struct scsi_device___6 *);
};

struct scsi_log_buf {
	char buffer[4096];
	long unsigned int map;
};

struct page___218;

typedef struct page___218 *pgtable_t___218;

struct address_space___219;

struct kmem_cache___204;

struct page___218 {
	long unsigned int flags;
	struct address_space___219 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___218 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___218 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___204 *slab_cache;
		struct page___218 *first_page;
	};
	long: 64;
};

struct task_struct___220;

struct pv_cpu_ops___220 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___220 *);
	void (*end_context_switch)(struct task_struct___220 *);
};

struct mutex___221 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___220 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___213 {
	struct page___218 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___227;

struct signal_struct___220;

struct bio_list___48;

struct backing_dev_info___59;

struct io_context___48;

struct task_struct___220 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___220 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___227 *mm;
	struct mm_struct___227 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___220 *real_parent;
	struct task_struct___220 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___220 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___220 = 0,
		VTIME_USER___220 = 1,
		VTIME_SYS___220 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___220 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___48 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___59 *backing_dev_info;
	struct io_context___48 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___221 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___213 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___227 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___227 *, struct mm_struct___227 *);
	void (*dup_mmap)(struct mm_struct___227 *, struct mm_struct___227 *);
	void (*exit_mmap)(struct mm_struct___227 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___227 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___227 *);
	void (*pgd_free)(struct mm_struct___227 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___227 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___227 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___227 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___227 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___227 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___227 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___227 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___227 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___227 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___227 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___227 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___221 lock;
	void *vdso;
} mm_context_t___221;

struct xol_area___218;

struct uprobes_state___218 {
	struct xol_area___218 *xol_area;
};

struct vm_area_struct___227;

struct file___219;

struct core_state___220;

struct mm_struct___227 {
	struct vm_area_struct___227 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___227 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___227 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___221 context;
	long unsigned int flags;
	struct core_state___220 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___220 *owner;
	struct file___219 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___218 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct bin_attribute___179;

struct attribute_group___177 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___179 **bin_attrs;
};

struct bin_attribute___179 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___219 *, struct kobject___23 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___219 *, struct kobject___23 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	int (*mmap)(struct file___219 *, struct kobject___23 *, struct bin_attribute___179 *, struct vm_area_struct___227 *);
};

struct dentry___219;

struct path___219 {
	struct vfsmount *mnt;
	struct dentry___219 *dentry;
};

struct inode___219;

struct file_operations___219;

struct file___219 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___219 f_path;
	struct inode___219 *f_inode;
	const struct file_operations___219 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___219 *f_mapping;
	struct mutex___221 f_pos_lock;
};

struct vm_operations_struct___199;

struct vm_area_struct___227 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___227 *vm_next;
	struct vm_area_struct___227 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___227 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___199 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___219 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___203;

struct dev_pm_ops___203 {
	int (*prepare)(struct device___203 *);
	void (*complete)(struct device___203 *);
	int (*suspend)(struct device___203 *);
	int (*resume)(struct device___203 *);
	int (*freeze)(struct device___203 *);
	int (*thaw)(struct device___203 *);
	int (*poweroff)(struct device___203 *);
	int (*restore)(struct device___203 *);
	int (*suspend_late)(struct device___203 *);
	int (*resume_early)(struct device___203 *);
	int (*freeze_late)(struct device___203 *);
	int (*thaw_early)(struct device___203 *);
	int (*poweroff_late)(struct device___203 *);
	int (*restore_early)(struct device___203 *);
	int (*suspend_noirq)(struct device___203 *);
	int (*resume_noirq)(struct device___203 *);
	int (*freeze_noirq)(struct device___203 *);
	int (*thaw_noirq)(struct device___203 *);
	int (*poweroff_noirq)(struct device___203 *);
	int (*restore_noirq)(struct device___203 *);
	int (*runtime_suspend)(struct device___203 *);
	int (*runtime_resume)(struct device___203 *);
	int (*runtime_idle)(struct device___203 *);
};

struct device_type___203;

struct bus_type___203;

struct device_driver___203;

struct dev_pm_domain___203;

struct class___203;

struct device_rh___203;

struct device___203 {
	struct device___203 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___203 *type;
	struct mutex___221 mutex;
	struct bus_type___203 *bus;
	struct device_driver___203 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___203 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___86 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___203 *class;
	const struct attribute_group___177 **groups;
	void (*release)(struct device___203 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___203 *device_rh;
};

struct dev_pm_info_rh___203 {
	void (*set_latency_tolerance)(struct device___203 *, s32);
};

struct dev_pm_domain___203 {
	struct dev_pm_ops___203 ops;
};

struct zone___220;

struct lruvec___220 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___220 *zone;
};

struct pglist_data___220;

struct zone___220 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___220 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___220 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___220 {
	struct zone___220 *zone;
	int zone_idx;
};

struct zonelist___220 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___220 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___220 {
	struct zone___220 node_zones[4];
	struct zonelist___220 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___220 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___144;

struct x86_io_apic_ops___144 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___144 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___144;

struct irq_data___144 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___144 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___220 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___220 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___203 *, char *);
	ssize_t (*store)(struct bus_type___203 *, const char *, size_t);
};

struct device_attribute___203;

struct driver_attribute___203;

struct bus_type___203 {
	const char *name;
	const char *dev_name;
	struct device___203 *dev_root;
	struct bus_attribute___203 *bus_attrs;
	struct device_attribute___203 *dev_attrs;
	struct driver_attribute___203 *drv_attrs;
	const struct attribute_group___177 **bus_groups;
	const struct attribute_group___177 **dev_groups;
	const struct attribute_group___177 **drv_groups;
	int (*match)(struct device___203 *, struct device_driver___203 *);
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	int (*probe)(struct device___203 *);
	int (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*online)(struct device___203 *);
	int (*offline)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct device___203 *, struct device_attribute___203 *, char *);
	ssize_t (*store)(struct device___203 *, struct device_attribute___203 *, const char *, size_t);
};

struct driver_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___203 *, char *);
	ssize_t (*store)(struct device_driver___203 *, const char *, size_t);
};

struct device_driver___203 {
	const char *name;
	struct bus_type___203 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___203 *);
	int (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	const struct attribute_group___177 **groups;
	const struct dev_pm_ops___203 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___203 {
	const char *name;
	const struct attribute_group___177 **groups;
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
};

struct class_attribute___203;

struct class___203 {
	const char *name;
	struct module *owner;
	struct class_attribute___203 *class_attrs;
	struct device_attribute___203 *dev_attrs;
	const struct attribute_group___177 **dev_groups;
	struct bin_attribute___179 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *);
	void (*class_release)(struct class___203 *);
	void (*dev_release)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
	struct subsys_private *p;
};

struct class_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct class___203 *, struct class_attribute___203 *, char *);
	ssize_t (*store)(struct class___203 *, struct class_attribute___203 *, const char *, size_t);
	const void * (*namespace)(struct class___203 *, const struct class_attribute___203 *);
};

struct device_rh___203 {
	struct dev_pm_info_rh___203 power;
};

struct xol_area___218 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___218 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___203;

struct memcg_cache_params___204;

struct kmem_cache___204 {
	struct kmem_cache_cpu___203 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___204 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___219;

struct address_space___219 {
	struct inode___219 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___221 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___219 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___59 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___195;

struct vm_operations_struct___199 {
	void (*open)(struct vm_area_struct___227 *);
	void (*close)(struct vm_area_struct___227 *);
	int (*fault)(struct vm_area_struct___227 *, struct vm_fault___195 *);
	int (*page_mkwrite)(struct vm_area_struct___227 *, struct vm_fault___195 *);
	int (*access)(struct vm_area_struct___227 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___227 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___227 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___227 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___227 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___220 {
	struct task_struct___220 *task;
	struct core_thread___220 *next;
};

struct core_state___220 {
	atomic_t nr_threads;
	struct core_thread___220 dumper;
	struct completion startup;
};

struct vm_fault___195 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___218 *page;
};

struct signal_struct___220 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___220 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___220 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___221 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___49;

struct bio_list___48 {
	struct bio___49 *head;
	struct bio___49 *tail;
};

struct bdi_writeback___59 {
	struct backing_dev_info___59 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___59 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___59 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___203 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___219 *debug_dir;
	struct dentry___219 *debug_stats;
};

struct io_cq___48;

struct io_context___48 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___48 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___203 {
	void **freelist;
	long unsigned int tid;
	struct page___218 *page;
	struct page___218 *partial;
};

struct memcg_cache_params___204 {
	bool is_root_cache;
	union {
		struct kmem_cache___204 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___204 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___219;

struct super_block___219;

struct dentry___219 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___219 *d_parent;
	struct qstr d_name;
	struct inode___219 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___219 *d_op;
	struct super_block___219 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___219;

struct file_lock___219;

struct dquot___219;

struct block_device___219;

struct inode___219 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___219 *i_op;
	struct super_block___219 *i_sb;
	struct address_space___219 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___221 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___219 *i_fop;
	struct file_lock___219 *i_flock;
	struct address_space___219 i_data;
	struct dquot___219 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___219 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___219 {
	int (*d_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_hash)(const struct dentry___219 *, struct qstr *);
	int (*d_compare)(const struct dentry___219 *, const struct dentry___219 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___219 *);
	void (*d_release)(struct dentry___219 *);
	void (*d_prune)(struct dentry___219 *);
	void (*d_iput)(struct dentry___219 *, struct inode___219 *);
	char * (*d_dname)(struct dentry___219 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___219 *);
	int (*d_manage)(struct dentry___219 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___219;

struct mem_dqinfo___219 {
	struct quota_format_type___219 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___219;

struct quota_info___219 {
	unsigned int flags;
	struct mutex___221 dqio_mutex;
	struct mutex___221 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___219 *files[2];
	struct mem_dqinfo___219 info[2];
	const struct quota_format_ops___219 *ops[2];
};

struct file_system_type___219;

struct super_operations___219;

struct dquot_operations___219;

struct quotactl_ops___219;

struct super_block___219 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___219 *s_type;
	const struct super_operations___219 *s_op;
	const struct dquot_operations___219 *dq_op;
	const struct quotactl_ops___219 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___219 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___219 *s_bdev;
	struct backing_dev_info___59 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___219 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___221 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___219 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___49(struct bio___49 *, int);

struct bio_vec___49 {
	struct page___218 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___49;

struct bio_set___49;

struct bio___49 {
	sector_t bi_sector;
	struct bio___49 *bi_next;
	struct block_device___219 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___49 *bi_end_io;
	void *bi_private;
	struct io_context___48 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___49 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___49 *bi_io_vec;
	struct bio_set___49 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___49 bi_inline_vecs[0];
};

struct hd_struct___52;

struct gendisk___52;

struct request_queue___48;

struct block_device___219 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___219 *bd_inode;
	struct super_block___219 *bd_super;
	struct mutex___221 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___219 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___52 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___52 *bd_disk;
	struct request_queue___48 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___221 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___49 {
	struct bio___49 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___49 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___49 *bip_vec;
	struct bio_vec___49 bip_inline_vecs[0];
};

struct bio_set___49 {
	struct kmem_cache___204 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___48 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___219 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___219 *ia_file;
};

struct dquot___219 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___221 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___219 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___219 {
	int qf_fmt_id;
	const struct quota_format_ops___219 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___219 *qf_next;
};

struct quota_format_ops___219 {
	int (*check_quota_file)(struct super_block___219 *, int);
	int (*read_file_info)(struct super_block___219 *, int);
	int (*write_file_info)(struct super_block___219 *, int);
	int (*free_file_info)(struct super_block___219 *, int);
	int (*read_dqblk)(struct dquot___219 *);
	int (*commit_dqblk)(struct dquot___219 *);
	int (*release_dqblk)(struct dquot___219 *);
};

struct dquot_operations___219 {
	int (*write_dquot)(struct dquot___219 *);
	struct dquot___219 * (*alloc_dquot)(struct super_block___219 *, int);
	void (*destroy_dquot)(struct dquot___219 *);
	int (*acquire_dquot)(struct dquot___219 *);
	int (*release_dquot)(struct dquot___219 *);
	int (*mark_dirty)(struct dquot___219 *);
	int (*write_info)(struct super_block___219 *, int);
	qsize_t * (*get_reserved_space)(struct inode___219 *);
};

struct quotactl_ops___219 {
	int (*quota_on)(struct super_block___219 *, int, int, struct path___219 *);
	int (*quota_on_meta)(struct super_block___219 *, int, int);
	int (*quota_off)(struct super_block___219 *, int);
	int (*quota_sync)(struct super_block___219 *, int);
	int (*get_info)(struct super_block___219 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___219 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___219 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___219 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___219 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___219 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___219 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___219 *, unsigned int);
};

struct address_space_operations___219 {
	int (*writepage)(struct page___218 *, struct writeback_control *);
	int (*readpage)(struct file___219 *, struct page___218 *);
	int (*writepages)(struct address_space___219 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___218 *);
	int (*readpages)(struct file___219 *, struct address_space___219 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___219 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___218 **, void **);
	int (*write_end)(struct file___219 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___218 *, void *);
	sector_t (*bmap)(struct address_space___219 *, sector_t);
	void (*invalidatepage)(struct page___218 *, long unsigned int);
	int (*releasepage)(struct page___218 *, gfp_t);
	void (*freepage)(struct page___218 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___219 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___219 *, struct page___218 *, struct page___218 *, enum migrate_mode);
	int (*launder_page)(struct page___218 *);
	int (*is_partially_uptodate)(struct page___218 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___218 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___219 *, struct page___218 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___219 *, sector_t *);
	void (*swap_deactivate)(struct file___219 *);
	void (*invalidatepage_range)(struct page___218 *, unsigned int, unsigned int);
};

struct hd_struct___52 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___203 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___52;

struct block_device_operations___48;

struct gendisk___52 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___52 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___52 *part_tbl;
	struct hd_struct___52 part0;
	const struct block_device_operations___48 *fops;
	struct request_queue___48 *queue;
	void *private_data;
	int flags;
	struct device___203 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___48 {
	struct request_queue___48 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___48(struct request_queue___48 *);

typedef void make_request_fn___48(struct request_queue___48 *, struct bio___49 *);

struct request___48;

typedef int prep_rq_fn___48(struct request_queue___48 *, struct request___48 *);

struct bvec_merge_data___48;

typedef int merge_bvec_fn___49(struct request_queue___48 *, struct bvec_merge_data___48 *, struct bio_vec___49 *);

typedef void softirq_done_fn___48(struct request___48 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___48(struct request___48 *);

typedef int dma_drain_needed_fn___48(struct request___48 *);

typedef int lld_busy_fn___48(struct request_queue___48 *);

struct bsg_class_device___48 {
	struct device___203 *class_dev;
	struct device___203 *parent;
	int minor;
	struct request_queue___48 *queue;
	struct kref ref;
	void (*release)(struct device___203 *);
};

typedef void unprep_rq_fn___48(struct request_queue___48 *, struct request___48 *);

struct elevator_queue___48;

struct blk_mq_ops___18;

struct blk_mq_hw_ctx___18;

struct blk_queue_tag___48;

struct blk_mq_tag_set___18;

struct request_queue___48 {
	struct list_head queue_head;
	struct request___48 *last_merge;
	struct elevator_queue___48 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___48 root_rl;
	request_fn_proc___48 *request_fn;
	make_request_fn___48 *make_request_fn;
	prep_rq_fn___48 *prep_rq_fn;
	merge_bvec_fn___49 *merge_bvec_fn;
	softirq_done_fn___48 *softirq_done_fn;
	rq_timed_out_fn___48 *rq_timed_out_fn;
	dma_drain_needed_fn___48 *dma_drain_needed;
	lld_busy_fn___48 *lld_busy_fn;
	struct blk_mq_ops___18 *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx___18 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___48 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___59 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___203 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___48 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___48 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___221 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___48 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___48 *unprep_rq_fn;
	struct blk_mq_tag_set___18 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___49 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___219 {
	struct dentry___219 * (*lookup)(struct inode___219 *, struct dentry___219 *, unsigned int);
	void * (*follow_link)(struct dentry___219 *, struct nameidata *);
	int (*permission)(struct inode___219 *, int);
	struct posix_acl * (*get_acl)(struct inode___219 *, int);
	int (*readlink)(struct dentry___219 *, char *, int);
	void (*put_link)(struct dentry___219 *, struct nameidata *, void *);
	int (*create)(struct inode___219 *, struct dentry___219 *, umode_t, bool);
	int (*link)(struct dentry___219 *, struct inode___219 *, struct dentry___219 *);
	int (*unlink)(struct inode___219 *, struct dentry___219 *);
	int (*symlink)(struct inode___219 *, struct dentry___219 *, const char *);
	int (*mkdir)(struct inode___219 *, struct dentry___219 *, umode_t);
	int (*rmdir)(struct inode___219 *, struct dentry___219 *);
	int (*mknod)(struct inode___219 *, struct dentry___219 *, umode_t, dev_t);
	int (*rename)(struct inode___219 *, struct dentry___219 *, struct inode___219 *, struct dentry___219 *);
	int (*setattr)(struct dentry___219 *, struct iattr___219 *);
	int (*getattr)(struct vfsmount *, struct dentry___219 *, struct kstat *);
	int (*setxattr)(struct dentry___219 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___219 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___219 *, char *, size_t);
	int (*removexattr)(struct dentry___219 *, const char *);
	int (*fiemap)(struct inode___219 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___219 *, struct timespec *, int);
	int (*atomic_open)(struct inode___219 *, struct dentry___219 *, struct file___219 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___148;

struct file_operations___219 {
	struct module *owner;
	loff_t (*llseek)(struct file___219 *, loff_t, int);
	ssize_t (*read)(struct file___219 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___219 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___219 *, void *, filldir_t);
	unsigned int (*poll)(struct file___219 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___219 *, struct vm_area_struct___227 *);
	int (*open)(struct inode___219 *, struct file___219 *);
	int (*flush)(struct file___219 *, fl_owner_t);
	int (*release)(struct inode___219 *, struct file___219 *);
	int (*fsync)(struct file___219 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___219 *, int);
	int (*lock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*sendpage)(struct file___219 *, struct page___218 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___219 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___219 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___219 *, long int, struct file_lock___219 **, void **);
		struct {
			int (*setlease)(struct file___219 *, long int, struct file_lock___219 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___219 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___148 *, struct file___219 *);
};

struct fasync_struct___219;

struct file_lock_operations___219;

struct lock_manager_operations___219;

struct file_lock___219 {
	struct file_lock___219 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___219 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___219 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___219 *fl_ops;
	const struct lock_manager_operations___219 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___219 {
	void (*fl_copy_lock)(struct file_lock___219 *, struct file_lock___219 *);
	void (*fl_release_private)(struct file_lock___219 *);
};

struct lock_manager_operations___219 {
	int (*lm_compare_owner)(struct file_lock___219 *, struct file_lock___219 *);
	long unsigned int (*lm_owner_key)(struct file_lock___219 *);
	void (*lm_notify)(struct file_lock___219 *);
	int (*lm_grant)(struct file_lock___219 *, struct file_lock___219 *, int);
	void (*lm_break)(struct file_lock___219 *);
	int (*lm_change)(struct file_lock___219 **, int);
};

struct fasync_struct___219 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___219 *fa_next;
	struct file___219 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___219 {
	const char *name;
	int fs_flags;
	struct dentry___219 * (*mount)(struct file_system_type___219 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___219 *);
	struct module *owner;
	struct file_system_type___219 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___219 {
	struct inode___219 * (*alloc_inode)(struct super_block___219 *);
	void (*destroy_inode)(struct inode___219 *);
	void (*dirty_inode)(struct inode___219 *, int);
	int (*write_inode)(struct inode___219 *, struct writeback_control *);
	int (*drop_inode)(struct inode___219 *);
	void (*evict_inode)(struct inode___219 *);
	void (*put_super)(struct super_block___219 *);
	int (*sync_fs)(struct super_block___219 *, int);
	int (*freeze_fs)(struct super_block___219 *);
	int (*unfreeze_fs)(struct super_block___219 *);
	int (*statfs)(struct dentry___219 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___219 *, int *, char *);
	void (*umount_begin)(struct super_block___219 *);
	int (*show_options)(struct seq_file___148 *, struct dentry___219 *);
	int (*show_devname)(struct seq_file___148 *, struct dentry___219 *);
	int (*show_path)(struct seq_file___148 *, struct dentry___219 *);
	int (*show_stats)(struct seq_file___148 *, struct dentry___219 *);
	ssize_t (*quota_read)(struct super_block___219 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___219 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___219 *);
	int (*bdev_try_to_free_page)(struct super_block___219 *, struct page___218 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___219 *);
	void (*free_cached_objects)(struct super_block___219 *, int);
};

struct seq_operations___148;

struct seq_file___148 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___221 lock;
	const struct seq_operations___148 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___52 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___52 *last_lookup;
	struct hd_struct___52 *part[0];
};

struct block_device_operations___48 {
	int (*open)(struct block_device___219 *, fmode_t);
	void (*release)(struct gendisk___52 *, fmode_t);
	int (*ioctl)(struct block_device___219 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___219 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___219 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___52 *, unsigned int);
	int (*media_changed)(struct gendisk___52 *);
	void (*unlock_native_capacity)(struct gendisk___52 *);
	int (*revalidate_disk)(struct gendisk___52 *);
	int (*getgeo)(struct block_device___219 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___219 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module *owner;
};

struct irq_chip___144 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___144 *);
	void (*irq_shutdown)(struct irq_data___144 *);
	void (*irq_enable)(struct irq_data___144 *);
	void (*irq_disable)(struct irq_data___144 *);
	void (*irq_ack)(struct irq_data___144 *);
	void (*irq_mask)(struct irq_data___144 *);
	void (*irq_mask_ack)(struct irq_data___144 *);
	void (*irq_unmask)(struct irq_data___144 *);
	void (*irq_eoi)(struct irq_data___144 *);
	int (*irq_set_affinity)(struct irq_data___144 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___144 *);
	int (*irq_set_type)(struct irq_data___144 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___144 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___144 *);
	void (*irq_bus_sync_unlock)(struct irq_data___144 *);
	void (*irq_cpu_online)(struct irq_data___144 *);
	void (*irq_cpu_offline)(struct irq_data___144 *);
	void (*irq_suspend)(struct irq_data___144 *);
	void (*irq_resume)(struct irq_data___144 *);
	void (*irq_pm_shutdown)(struct irq_data___144 *);
	void (*irq_print_chip)(struct irq_data___144 *, struct seq_file___148 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___144 *, void *);
	long unsigned int flags;
};

struct io_cq___48 {
	struct request_queue___48 *q;
	struct io_context___48 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___204 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___48(struct request___48 *, int);

struct request___48 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___48 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___49 *bio;
	struct bio___49 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___48 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___48 *saved_end_io;
		} flush;
	};
	struct gendisk___52 *rq_disk;
	struct hd_struct___52 *part;
	long unsigned int start_time;
	struct request_list___48 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___48 *end_io;
	void *end_io_data;
	struct request___48 *next_rq;
};

typedef int elevator_merge_fn___48(struct request_queue___48 *, struct request___48 **, struct bio___49 *);

typedef void elevator_merge_req_fn___48(struct request_queue___48 *, struct request___48 *, struct request___48 *);

typedef void elevator_merged_fn___48(struct request_queue___48 *, struct request___48 *, int);

typedef int elevator_allow_merge_fn___48(struct request_queue___48 *, struct request___48 *, struct bio___49 *);

typedef void elevator_bio_merged_fn___48(struct request_queue___48 *, struct request___48 *, struct bio___49 *);

typedef int elevator_dispatch_fn___48(struct request_queue___48 *, int);

typedef void elevator_add_req_fn___48(struct request_queue___48 *, struct request___48 *);

typedef struct request___48 *elevator_request_list_fn___48(struct request_queue___48 *, struct request___48 *);

typedef void elevator_completed_req_fn___48(struct request_queue___48 *, struct request___48 *);

typedef int elevator_may_queue_fn___48(struct request_queue___48 *, int);

typedef void elevator_init_icq_fn___48(struct io_cq___48 *);

typedef void elevator_exit_icq_fn___48(struct io_cq___48 *);

typedef int elevator_set_req_fn___48(struct request_queue___48 *, struct request___48 *, struct bio___49 *, gfp_t);

typedef void elevator_put_req_fn___48(struct request___48 *);

typedef void elevator_activate_req_fn___48(struct request_queue___48 *, struct request___48 *);

typedef void elevator_deactivate_req_fn___48(struct request_queue___48 *, struct request___48 *);

struct elevator_type___48;

typedef int elevator_init_fn___49(struct request_queue___48 *, struct elevator_type___48 *);

typedef void elevator_exit_fn___48(struct elevator_queue___48 *);

struct elevator_ops___48 {
	elevator_merge_fn___48 *elevator_merge_fn;
	elevator_merged_fn___48 *elevator_merged_fn;
	elevator_merge_req_fn___48 *elevator_merge_req_fn;
	elevator_allow_merge_fn___48 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___48 *elevator_bio_merged_fn;
	elevator_dispatch_fn___48 *elevator_dispatch_fn;
	elevator_add_req_fn___48 *elevator_add_req_fn;
	elevator_activate_req_fn___48 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___48 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___48 *elevator_completed_req_fn;
	elevator_request_list_fn___48 *elevator_former_req_fn;
	elevator_request_list_fn___48 *elevator_latter_req_fn;
	elevator_init_icq_fn___48 *elevator_init_icq_fn;
	elevator_exit_icq_fn___48 *elevator_exit_icq_fn;
	elevator_set_req_fn___48 *elevator_set_req_fn;
	elevator_put_req_fn___48 *elevator_put_req_fn;
	elevator_may_queue_fn___48 *elevator_may_queue_fn;
	elevator_init_fn___49 *elevator_init_fn;
	elevator_exit_fn___48 *elevator_exit_fn;
};

struct elv_fs_entry___48;

struct elevator_type___48 {
	struct kmem_cache___204 *icq_cache;
	struct elevator_ops___48 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___48 *elevator_attrs;
	char elevator_name[16];
	struct module *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___48 {
	struct elevator_type___48 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___221 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___48 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___48 *, char *);
	ssize_t (*store)(struct elevator_queue___48 *, const char *, size_t);
};

struct bvec_merge_data___48 {
	struct block_device___219 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___48 {
	struct request___48 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct blk_mq_queue_data___18;

typedef int queue_rq_fn___19(struct blk_mq_hw_ctx___18 *, const struct blk_mq_queue_data___18 *);

typedef struct blk_mq_hw_ctx___18 *map_queue_fn___19(struct request_queue___48 *, const int);

typedef enum blk_eh_timer_return timeout_fn___19(struct request___48 *, bool);

typedef int init_request_fn___19(void *, struct request___48 *, unsigned int, unsigned int, unsigned int);

typedef void exit_request_fn___19(void *, struct request___48 *, unsigned int, unsigned int);

typedef int init_hctx_fn___18(struct blk_mq_hw_ctx___18 *, void *, unsigned int);

typedef void exit_hctx_fn___18(struct blk_mq_hw_ctx___18 *, unsigned int);

struct blk_mq_ops___18 {
	queue_rq_fn___19 *queue_rq;
	map_queue_fn___19 *map_queue;
	union {
		timeout_fn___19 *timeout;
		struct {
			rq_timed_out_fn___48 *timeout;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	softirq_done_fn___48 *complete;
	init_request_fn___19 *init_request;
	exit_request_fn___19 *exit_request;
	init_hctx_fn___18 *init_hctx;
	exit_hctx_fn___18 *exit_hctx;
};

struct blk_mq_hw_ctx___18 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	long unsigned int state;
	union {
		struct delayed_work delay_work;
		struct {
			struct delayed_work delayed_work;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int flags;
	struct request_queue___48 *queue;
	unsigned int queue_num;
	void *driver_data;
	unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	union {
		atomic_t wait_index;
		struct {
			unsigned int nr_ctx_map;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		long unsigned int *padding1;
		struct {
			long unsigned int *ctx_map;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct request___48 **padding2;
		struct {
			struct request___48 **rqs;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		struct list_head padding3;
		struct {
			struct list_head page_list;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	struct blk_mq_tags *tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[10];
	unsigned int queue_depth;
	unsigned int numa_node;
	unsigned int rh_reserved_cmd_size;
	struct blk_mq_cpu_notifier___3 cpu_notifier;
	struct kobject___23 kobj;
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	struct blk_mq_ctxmap ctx_map;
	atomic_t nr_active;
	struct blk_flush_queue *fq;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tag_set___18 {
	struct blk_mq_ops___18 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex___221 tag_list_lock;
	struct list_head tag_list;
};

struct Scsi_Host___5;

struct scsi_target___7;

struct scsi_dh_data___7;

struct scsi_device___7 {
	struct Scsi_Host___5 *host;
	struct request_queue___48 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___7 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___203 sdev_gendev;
	struct device___203 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___7 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___5;

struct Scsi_Host___5 {
	struct list_head __devices;
	struct list_head __targets;
	struct scsi_host_cmd_pool *cmd_pool;
	spinlock_t free_list_lock;
	struct list_head free_list;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex___221 scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___220 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___5 *hostt;
	struct scsi_transport_template *transportt;
	union {
		struct blk_queue_tag___48 *bqt;
		struct blk_mq_tag_set___18 *tag_set;
	};
	union {
		atomic_t host_busy;
		struct {
			unsigned int host_busy;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_id;
	unsigned int max_lun;
	unsigned int max_channel;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int use_blk_tcq: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int ordered_tag: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_blk_mq: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	union {
		atomic_t host_blocked;
		struct {
			unsigned int host_blocked;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	struct request_queue___48 *uspace_req_q;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___203 shost_gendev;
	struct device___203 shost_dev;
	struct list_head sht_legacy_list;
	void *shost_data;
	struct device___203 *dma_dev;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	unsigned int scsi_mq_reserved1;
	unsigned int scsi_mq_reserved2;
	void *scsi_mq_reserved3;
	void *scsi_mq_reserved4;
	atomic_t scsi_mq_reserved5;
	atomic_t scsi_mq_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___7 {
	struct scsi_device___7 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___203 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___7;

struct scsi_dh_data___7 {
	struct scsi_device_handler___7 *scsi_dh;
	struct scsi_device___7 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___7 {
	struct list_head list;
	struct module *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___7 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___7 *);
	void (*detach)(struct scsi_device___7 *);
	int (*activate)(struct scsi_device___7 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___7 *, struct request___48 *);
	int (*set_params)(struct scsi_device___7 *, const char *);
	bool (*match)(struct scsi_device___7 *);
};

struct seq_operations___148 {
	void * (*start)(struct seq_file___148 *, loff_t *);
	void (*stop)(struct seq_file___148 *, void *);
	void * (*next)(struct seq_file___148 *, void *, loff_t *);
	int (*show)(struct seq_file___148 *, void *);
};

struct blk_mq_queue_data___18 {
	struct request___48 *rq;
	struct list_head *list;
	bool last;
};

struct scsi_host_template___5 {
	struct module *module;
	const char *name;
	int (*detect)(struct scsi_host_template___5 *);
	int (*release)(struct Scsi_Host___5 *);
	const char * (*info)(struct Scsi_Host___5 *);
	int (*ioctl)(struct scsi_device___7 *, int, void *);
	int (*compat_ioctl)(struct scsi_device___7 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___5 *, struct scsi_cmnd *);
	int (*transfer_response)(struct scsi_cmnd *, void (*)(struct scsi_cmnd *));
	int (*eh_abort_handler)(struct scsi_cmnd *);
	int (*eh_device_reset_handler)(struct scsi_cmnd *);
	int (*eh_target_reset_handler)(struct scsi_cmnd *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd *);
	int (*eh_host_reset_handler)(struct scsi_cmnd *);
	int (*slave_alloc)(struct scsi_device___7 *);
	int (*slave_configure)(struct scsi_device___7 *);
	void (*slave_destroy)(struct scsi_device___7 *);
	int (*target_alloc)(struct scsi_target___7 *);
	void (*target_destroy)(struct scsi_target___7 *);
	int (*scan_finished)(struct Scsi_Host___5 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___5 *);
	int (*change_queue_depth)(struct scsi_device___7 *, int, int);
	int (*change_queue_type)(struct scsi_device___7 *, int);
	int (*bios_param)(struct scsi_device___7 *, struct block_device___219 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___7 *);
	int (*show_info)(struct seq_file___148 *, struct Scsi_Host___5 *);
	int (*write_info)(struct Scsi_Host___5 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*host_reset)(struct Scsi_Host___5 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	short unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int ordered_tag: 1;
	unsigned int no_write_same: 1;
	unsigned int no_async_abort: 1;
	unsigned int disable_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___203 **shost_attrs;
	struct device_attribute___203 **sdev_attrs;
	struct list_head legacy_hosts;
	u64 vendor_id;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	union {
		unsigned int cmd_size;
		struct {
			unsigned int scsi_mq_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	unsigned int scsi_mq_reserved2;
	union {
		struct scsi_host_cmd_pool *cmd_pool;
		struct {
			void *scsi_mq_reserved3;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void *scsi_mq_reserved4;
};

enum {
	SCSI_DH_OK = 0,
	SCSI_DH_DEV_FAILED = 1,
	SCSI_DH_DEV_TEMP_BUSY = 2,
	SCSI_DH_DEV_UNSUPP = 3,
	SCSI_DH_DEVICE_MAX = 4,
	SCSI_DH_NOTCONN = 5,
	SCSI_DH_CONN_FAILURE = 6,
	SCSI_DH_TRANSPORT_MAX = 7,
	SCSI_DH_IO = 8,
	SCSI_DH_INVALID_IO = 9,
	SCSI_DH_RETRY = 10,
	SCSI_DH_IMM_RETRY = 11,
	SCSI_DH_TIMED_OUT = 12,
	SCSI_DH_RES_TEMP_UNAVAIL = 13,
	SCSI_DH_DEV_OFFLINED = 14,
	SCSI_DH_NOSYS = 15,
	SCSI_DH_DRIVER_MAX = 16,
};

struct page___219;

typedef struct page___219 *pgtable_t___219;

struct address_space___220;

struct kmem_cache___205;

struct page___219 {
	long unsigned int flags;
	struct address_space___220 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___219 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___219 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___205 *slab_cache;
		struct page___219 *first_page;
	};
	long: 64;
};

struct task_struct___221;

struct pv_cpu_ops___221 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___221 *);
	void (*end_context_switch)(struct task_struct___221 *);
};

struct mutex___222 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___221 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___214 {
	struct page___219 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___228;

struct signal_struct___221;

struct bio_list___49;

struct backing_dev_info___60;

struct io_context___49;

struct task_struct___221 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___221 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___228 *mm;
	struct mm_struct___228 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___221 *real_parent;
	struct task_struct___221 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___221 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___221 = 0,
		VTIME_USER___221 = 1,
		VTIME_SYS___221 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___221 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___49 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___60 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___222 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___214 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___228 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___228 *, struct mm_struct___228 *);
	void (*dup_mmap)(struct mm_struct___228 *, struct mm_struct___228 *);
	void (*exit_mmap)(struct mm_struct___228 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___228 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___228 *);
	void (*pgd_free)(struct mm_struct___228 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___228 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___228 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___228 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___228 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___228 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___228 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___228 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___228 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___228 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___228 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___228 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___222 lock;
	void *vdso;
} mm_context_t___222;

struct xol_area___219;

struct uprobes_state___219 {
	struct xol_area___219 *xol_area;
};

struct vm_area_struct___228;

struct file___220;

struct core_state___221;

struct mm_struct___228 {
	struct vm_area_struct___228 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___228 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___228 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___222 context;
	long unsigned int flags;
	struct core_state___221 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___221 *owner;
	struct file___220 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___219 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___126;

struct module_kobject___125 {
	struct kobject___23 kobj;
	struct module___126 *mod;
	struct kobject___23 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___125;

struct module___126 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___125 mkobj;
	struct module_attribute___125 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___23 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___221 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___221;

struct lruvec___221 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___221 *zone;
};

struct pglist_data___221;

struct zone___221 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___221 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___221 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___221 {
	struct zone___221 *zone;
	int zone_idx;
};

struct zonelist___221 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___221 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___221 {
	struct zone___221 node_zones[4];
	struct zonelist___221 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___221 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___204;

struct dev_pm_ops___204 {
	int (*prepare)(struct device___204 *);
	void (*complete)(struct device___204 *);
	int (*suspend)(struct device___204 *);
	int (*resume)(struct device___204 *);
	int (*freeze)(struct device___204 *);
	int (*thaw)(struct device___204 *);
	int (*poweroff)(struct device___204 *);
	int (*restore)(struct device___204 *);
	int (*suspend_late)(struct device___204 *);
	int (*resume_early)(struct device___204 *);
	int (*freeze_late)(struct device___204 *);
	int (*thaw_early)(struct device___204 *);
	int (*poweroff_late)(struct device___204 *);
	int (*restore_early)(struct device___204 *);
	int (*suspend_noirq)(struct device___204 *);
	int (*resume_noirq)(struct device___204 *);
	int (*freeze_noirq)(struct device___204 *);
	int (*thaw_noirq)(struct device___204 *);
	int (*poweroff_noirq)(struct device___204 *);
	int (*restore_noirq)(struct device___204 *);
	int (*runtime_suspend)(struct device___204 *);
	int (*runtime_resume)(struct device___204 *);
	int (*runtime_idle)(struct device___204 *);
};

struct dma_map_ops___87;

struct dev_archdata___87 {
	struct dma_map_ops___87 *dma_ops;
	void *iommu;
};

struct device_type___204;

struct bus_type___204;

struct device_driver___204;

struct dev_pm_domain___204;

struct class___204;

struct attribute_group___178;

struct device_rh___204;

struct device___204 {
	struct device___204 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___204 *type;
	struct mutex___222 mutex;
	struct bus_type___204 *bus;
	struct device_driver___204 *driver;
	void *platform_data;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___204 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___87 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___204 *class;
	const struct attribute_group___178 **groups;
	void (*release)(struct device___204 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___204 *device_rh;
};

struct dev_pm_info_rh___204 {
	void (*set_latency_tolerance)(struct device___204 *, s32);
};

struct dev_pm_domain___204 {
	struct dev_pm_ops___204 ops;
};

struct smp_ops___221 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___221 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___219 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___219 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___204;

struct memcg_cache_params___205;

struct kmem_cache___205 {
	struct kmem_cache_cpu___204 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___23 kobj;
	struct memcg_cache_params___205 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___220;

struct address_space_operations___220;

struct address_space___220 {
	struct inode___220 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___222 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___220 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___60 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___220;

struct path___220 {
	struct vfsmount *mnt;
	struct dentry___220 *dentry;
};

struct file_operations___220;

struct file___220 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___220 f_path;
	struct inode___220 *f_inode;
	const struct file_operations___220 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___220 *f_mapping;
	struct mutex___222 f_pos_lock;
};

struct vm_operations_struct___200;

struct vm_area_struct___228 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___228 *vm_next;
	struct vm_area_struct___228 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___228 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___200 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___220 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___196;

struct vm_operations_struct___200 {
	void (*open)(struct vm_area_struct___228 *);
	void (*close)(struct vm_area_struct___228 *);
	int (*fault)(struct vm_area_struct___228 *, struct vm_fault___196 *);
	int (*page_mkwrite)(struct vm_area_struct___228 *, struct vm_fault___196 *);
	int (*access)(struct vm_area_struct___228 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___228 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___228 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___228 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___228 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___221 {
	struct task_struct___221 *task;
	struct core_thread___221 *next;
};

struct core_state___221 {
	atomic_t nr_threads;
	struct core_thread___221 dumper;
	struct completion startup;
};

struct vm_fault___196 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___219 *page;
};

struct bin_attribute___180;

struct attribute_group___178 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___180 **bin_attrs;
};

struct bin_attribute___180 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___220 *, struct kobject___23 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___220 *, struct kobject___23 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	int (*mmap)(struct file___220 *, struct kobject___23 *, struct bin_attribute___180 *, struct vm_area_struct___228 *);
};

struct dma_map_ops___87 {
	void * (*alloc)(struct device___204 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___204 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___204 *, struct vm_area_struct___228 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___204 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___204 *, struct page___219 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___204 *, dma_addr_t);
	int (*dma_supported)(struct device___204 *, u64);
	int (*set_dma_mask)(struct device___204 *, u64);
	int is_phys;
};

struct bus_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___204 *, char *);
	ssize_t (*store)(struct bus_type___204 *, const char *, size_t);
};

struct device_attribute___204;

struct driver_attribute___204;

struct bus_type___204 {
	const char *name;
	const char *dev_name;
	struct device___204 *dev_root;
	struct bus_attribute___204 *bus_attrs;
	struct device_attribute___204 *dev_attrs;
	struct driver_attribute___204 *drv_attrs;
	const struct attribute_group___178 **bus_groups;
	const struct attribute_group___178 **dev_groups;
	const struct attribute_group___178 **drv_groups;
	int (*match)(struct device___204 *, struct device_driver___204 *);
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	int (*probe)(struct device___204 *);
	int (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*online)(struct device___204 *);
	int (*offline)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct device___204 *, struct device_attribute___204 *, char *);
	ssize_t (*store)(struct device___204 *, struct device_attribute___204 *, const char *, size_t);
};

struct driver_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___204 *, char *);
	ssize_t (*store)(struct device_driver___204 *, const char *, size_t);
};

struct device_driver___204 {
	const char *name;
	struct bus_type___204 *bus;
	struct module___126 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___204 *);
	int (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	const struct attribute_group___178 **groups;
	const struct dev_pm_ops___204 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___204 {
	const char *name;
	const struct attribute_group___178 **groups;
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
};

struct class_attribute___204;

struct class___204 {
	const char *name;
	struct module___126 *owner;
	struct class_attribute___204 *class_attrs;
	struct device_attribute___204 *dev_attrs;
	const struct attribute_group___178 **dev_groups;
	struct bin_attribute___180 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *);
	void (*class_release)(struct class___204 *);
	void (*dev_release)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
	struct subsys_private *p;
};

struct class_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct class___204 *, struct class_attribute___204 *, char *);
	ssize_t (*store)(struct class___204 *, struct class_attribute___204 *, const char *, size_t);
	const void * (*namespace)(struct class___204 *, const struct class_attribute___204 *);
};

struct device_rh___204 {
	struct dev_pm_info_rh___204 power;
};

struct signal_struct___221 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___221 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___221 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___222 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___50;

struct bio_list___49 {
	struct bio___50 *head;
	struct bio___50 *tail;
};

struct bdi_writeback___60 {
	struct backing_dev_info___60 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___60 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___60 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___204 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___220 *debug_dir;
	struct dentry___220 *debug_stats;
};

struct io_cq___49;

struct io_context___49 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___49 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct kmem_cache_cpu___204 {
	void **freelist;
	long unsigned int tid;
	struct page___219 *page;
	struct page___219 *partial;
};

struct memcg_cache_params___205 {
	bool is_root_cache;
	union {
		struct kmem_cache___205 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___205 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___220;

struct super_block___220;

struct dentry___220 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___220 *d_parent;
	struct qstr d_name;
	struct inode___220 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___220 *d_op;
	struct super_block___220 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___220;

struct file_lock___220;

struct dquot___220;

struct block_device___220;

struct inode___220 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___220 *i_op;
	struct super_block___220 *i_sb;
	struct address_space___220 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___222 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___220 *i_fop;
	struct file_lock___220 *i_flock;
	struct address_space___220 i_data;
	struct dquot___220 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___220 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___220 {
	int (*d_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_hash)(const struct dentry___220 *, struct qstr *);
	int (*d_compare)(const struct dentry___220 *, const struct dentry___220 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___220 *);
	void (*d_release)(struct dentry___220 *);
	void (*d_prune)(struct dentry___220 *);
	void (*d_iput)(struct dentry___220 *, struct inode___220 *);
	char * (*d_dname)(struct dentry___220 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___220 *);
	int (*d_manage)(struct dentry___220 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___220;

struct mem_dqinfo___220 {
	struct quota_format_type___220 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___220;

struct quota_info___220 {
	unsigned int flags;
	struct mutex___222 dqio_mutex;
	struct mutex___222 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___220 *files[2];
	struct mem_dqinfo___220 info[2];
	const struct quota_format_ops___220 *ops[2];
};

struct file_system_type___220;

struct super_operations___220;

struct dquot_operations___220;

struct quotactl_ops___220;

struct super_block___220 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___220 *s_type;
	const struct super_operations___220 *s_op;
	const struct dquot_operations___220 *dq_op;
	const struct quotactl_ops___220 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___220 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___220 *s_bdev;
	struct backing_dev_info___60 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___220 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___222 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___220 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___50(struct bio___50 *, int);

struct bio_vec___50 {
	struct page___219 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___50;

struct bio_set___50;

struct bio___50 {
	sector_t bi_sector;
	struct bio___50 *bi_next;
	struct block_device___220 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___50 *bi_end_io;
	void *bi_private;
	struct io_context___49 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___50 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___50 *bi_io_vec;
	struct bio_set___50 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___50 bi_inline_vecs[0];
};

struct hd_struct___53;

struct gendisk___53;

struct request_queue___49;

struct block_device___220 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___220 *bd_inode;
	struct super_block___220 *bd_super;
	struct mutex___222 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___220 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___53 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___53 *bd_disk;
	struct request_queue___49 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___222 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___50 {
	struct bio___50 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___50 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___50 *bip_vec;
	struct bio_vec___50 bip_inline_vecs[0];
};

struct bio_set___50 {
	struct kmem_cache___205 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___49 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___220 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___220 *ia_file;
};

struct dquot___220 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___222 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___220 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___220 {
	int qf_fmt_id;
	const struct quota_format_ops___220 *qf_ops;
	struct module___126 *qf_owner;
	struct quota_format_type___220 *qf_next;
};

struct quota_format_ops___220 {
	int (*check_quota_file)(struct super_block___220 *, int);
	int (*read_file_info)(struct super_block___220 *, int);
	int (*write_file_info)(struct super_block___220 *, int);
	int (*free_file_info)(struct super_block___220 *, int);
	int (*read_dqblk)(struct dquot___220 *);
	int (*commit_dqblk)(struct dquot___220 *);
	int (*release_dqblk)(struct dquot___220 *);
};

struct dquot_operations___220 {
	int (*write_dquot)(struct dquot___220 *);
	struct dquot___220 * (*alloc_dquot)(struct super_block___220 *, int);
	void (*destroy_dquot)(struct dquot___220 *);
	int (*acquire_dquot)(struct dquot___220 *);
	int (*release_dquot)(struct dquot___220 *);
	int (*mark_dirty)(struct dquot___220 *);
	int (*write_info)(struct super_block___220 *, int);
	qsize_t * (*get_reserved_space)(struct inode___220 *);
};

struct quotactl_ops___220 {
	int (*quota_on)(struct super_block___220 *, int, int, struct path___220 *);
	int (*quota_on_meta)(struct super_block___220 *, int, int);
	int (*quota_off)(struct super_block___220 *, int);
	int (*quota_sync)(struct super_block___220 *, int);
	int (*get_info)(struct super_block___220 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___220 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___220 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___220 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___220 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___220 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___220 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___220 *, unsigned int);
};

struct address_space_operations___220 {
	int (*writepage)(struct page___219 *, struct writeback_control *);
	int (*readpage)(struct file___220 *, struct page___219 *);
	int (*writepages)(struct address_space___220 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___219 *);
	int (*readpages)(struct file___220 *, struct address_space___220 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___220 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___219 **, void **);
	int (*write_end)(struct file___220 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___219 *, void *);
	sector_t (*bmap)(struct address_space___220 *, sector_t);
	void (*invalidatepage)(struct page___219 *, long unsigned int);
	int (*releasepage)(struct page___219 *, gfp_t);
	void (*freepage)(struct page___219 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___220 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___220 *, struct page___219 *, struct page___219 *, enum migrate_mode);
	int (*launder_page)(struct page___219 *);
	int (*is_partially_uptodate)(struct page___219 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___219 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___220 *, struct page___219 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___220 *, sector_t *);
	void (*swap_deactivate)(struct file___220 *);
	void (*invalidatepage_range)(struct page___219 *, unsigned int, unsigned int);
};

struct hd_struct___53 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___204 __dev;
	struct kobject___23 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___53;

struct block_device_operations___49;

struct gendisk___53 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___53 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___53 *part_tbl;
	struct hd_struct___53 part0;
	const struct block_device_operations___49 *fops;
	struct request_queue___49 *queue;
	void *private_data;
	int flags;
	struct device___204 *driverfs_dev;
	struct kobject___23 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___49 {
	struct request_queue___49 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___49(struct request_queue___49 *);

typedef void make_request_fn___49(struct request_queue___49 *, struct bio___50 *);

struct request___49;

typedef int prep_rq_fn___49(struct request_queue___49 *, struct request___49 *);

struct bvec_merge_data___49;

typedef int merge_bvec_fn___50(struct request_queue___49 *, struct bvec_merge_data___49 *, struct bio_vec___50 *);

typedef void softirq_done_fn___49(struct request___49 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___49(struct request___49 *);

typedef int dma_drain_needed_fn___49(struct request___49 *);

typedef int lld_busy_fn___49(struct request_queue___49 *);

struct bsg_class_device___49 {
	struct device___204 *class_dev;
	struct device___204 *parent;
	int minor;
	struct request_queue___49 *queue;
	struct kref ref;
	void (*release)(struct device___204 *);
};

typedef void unprep_rq_fn___49(struct request_queue___49 *, struct request___49 *);

struct elevator_queue___49;

struct blk_queue_tag___49;

struct request_queue___49 {
	struct list_head queue_head;
	struct request___49 *last_merge;
	struct elevator_queue___49 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___49 root_rl;
	request_fn_proc___49 *request_fn;
	make_request_fn___49 *make_request_fn;
	prep_rq_fn___49 *prep_rq_fn;
	merge_bvec_fn___50 *merge_bvec_fn;
	softirq_done_fn___49 *softirq_done_fn;
	rq_timed_out_fn___49 *rq_timed_out_fn;
	dma_drain_needed_fn___49 *dma_drain_needed;
	lld_busy_fn___49 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___49 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___60 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___23 kobj;
	struct kobject___23 mq_kobj;
	struct device___204 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___49 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___49 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___222 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___49 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___49 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___50 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___220 {
	struct dentry___220 * (*lookup)(struct inode___220 *, struct dentry___220 *, unsigned int);
	void * (*follow_link)(struct dentry___220 *, struct nameidata *);
	int (*permission)(struct inode___220 *, int);
	struct posix_acl * (*get_acl)(struct inode___220 *, int);
	int (*readlink)(struct dentry___220 *, char *, int);
	void (*put_link)(struct dentry___220 *, struct nameidata *, void *);
	int (*create)(struct inode___220 *, struct dentry___220 *, umode_t, bool);
	int (*link)(struct dentry___220 *, struct inode___220 *, struct dentry___220 *);
	int (*unlink)(struct inode___220 *, struct dentry___220 *);
	int (*symlink)(struct inode___220 *, struct dentry___220 *, const char *);
	int (*mkdir)(struct inode___220 *, struct dentry___220 *, umode_t);
	int (*rmdir)(struct inode___220 *, struct dentry___220 *);
	int (*mknod)(struct inode___220 *, struct dentry___220 *, umode_t, dev_t);
	int (*rename)(struct inode___220 *, struct dentry___220 *, struct inode___220 *, struct dentry___220 *);
	int (*setattr)(struct dentry___220 *, struct iattr___220 *);
	int (*getattr)(struct vfsmount *, struct dentry___220 *, struct kstat *);
	int (*setxattr)(struct dentry___220 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___220 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___220 *, char *, size_t);
	int (*removexattr)(struct dentry___220 *, const char *);
	int (*fiemap)(struct inode___220 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___220 *, struct timespec *, int);
	int (*atomic_open)(struct inode___220 *, struct dentry___220 *, struct file___220 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___220 {
	struct module___126 *owner;
	loff_t (*llseek)(struct file___220 *, loff_t, int);
	ssize_t (*read)(struct file___220 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___220 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___220 *, void *, filldir_t);
	unsigned int (*poll)(struct file___220 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___220 *, struct vm_area_struct___228 *);
	int (*open)(struct inode___220 *, struct file___220 *);
	int (*flush)(struct file___220 *, fl_owner_t);
	int (*release)(struct inode___220 *, struct file___220 *);
	int (*fsync)(struct file___220 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___220 *, int);
	int (*lock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*sendpage)(struct file___220 *, struct page___219 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___220 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___220 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___220 *, long int, struct file_lock___220 **, void **);
		struct {
			int (*setlease)(struct file___220 *, long int, struct file_lock___220 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___220 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___220 *);
};

struct fasync_struct___220;

struct file_lock_operations___220;

struct lock_manager_operations___220;

struct file_lock___220 {
	struct file_lock___220 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___220 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___220 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___220 *fl_ops;
	const struct lock_manager_operations___220 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___220 {
	void (*fl_copy_lock)(struct file_lock___220 *, struct file_lock___220 *);
	void (*fl_release_private)(struct file_lock___220 *);
};

struct lock_manager_operations___220 {
	int (*lm_compare_owner)(struct file_lock___220 *, struct file_lock___220 *);
	long unsigned int (*lm_owner_key)(struct file_lock___220 *);
	void (*lm_notify)(struct file_lock___220 *);
	int (*lm_grant)(struct file_lock___220 *, struct file_lock___220 *, int);
	void (*lm_break)(struct file_lock___220 *);
	int (*lm_change)(struct file_lock___220 **, int);
};

struct fasync_struct___220 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___220 *fa_next;
	struct file___220 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___220 {
	const char *name;
	int fs_flags;
	struct dentry___220 * (*mount)(struct file_system_type___220 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___220 *);
	struct module___126 *owner;
	struct file_system_type___220 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___220 {
	struct inode___220 * (*alloc_inode)(struct super_block___220 *);
	void (*destroy_inode)(struct inode___220 *);
	void (*dirty_inode)(struct inode___220 *, int);
	int (*write_inode)(struct inode___220 *, struct writeback_control *);
	int (*drop_inode)(struct inode___220 *);
	void (*evict_inode)(struct inode___220 *);
	void (*put_super)(struct super_block___220 *);
	int (*sync_fs)(struct super_block___220 *, int);
	int (*freeze_fs)(struct super_block___220 *);
	int (*unfreeze_fs)(struct super_block___220 *);
	int (*statfs)(struct dentry___220 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___220 *, int *, char *);
	void (*umount_begin)(struct super_block___220 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___220 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___220 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___220 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___220 *);
	ssize_t (*quota_read)(struct super_block___220 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___220 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___220 *);
	int (*bdev_try_to_free_page)(struct super_block___220 *, struct page___219 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___220 *);
	void (*free_cached_objects)(struct super_block___220 *, int);
};

struct disk_part_tbl___53 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___53 *last_lookup;
	struct hd_struct___53 *part[0];
};

struct block_device_operations___49 {
	int (*open)(struct block_device___220 *, fmode_t);
	void (*release)(struct gendisk___53 *, fmode_t);
	int (*ioctl)(struct block_device___220 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___220 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___220 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___53 *, unsigned int);
	int (*media_changed)(struct gendisk___53 *);
	void (*unlock_native_capacity)(struct gendisk___53 *);
	int (*revalidate_disk)(struct gendisk___53 *);
	int (*getgeo)(struct block_device___220 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___220 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___126 *owner;
};

struct io_cq___49 {
	struct request_queue___49 *q;
	struct io_context___49 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___205 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___49(struct request___49 *, int);

struct request___49 {
	struct list_head queuelist;
	union {
		struct call_single_data csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___49 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___50 *bio;
	struct bio___50 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___49 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___49 *saved_end_io;
		} flush;
	};
	struct gendisk___53 *rq_disk;
	struct hd_struct___53 *part;
	long unsigned int start_time;
	struct request_list___49 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___49 *end_io;
	void *end_io_data;
	struct request___49 *next_rq;
};

typedef int elevator_merge_fn___49(struct request_queue___49 *, struct request___49 **, struct bio___50 *);

typedef void elevator_merge_req_fn___49(struct request_queue___49 *, struct request___49 *, struct request___49 *);

typedef void elevator_merged_fn___49(struct request_queue___49 *, struct request___49 *, int);

typedef int elevator_allow_merge_fn___49(struct request_queue___49 *, struct request___49 *, struct bio___50 *);

typedef void elevator_bio_merged_fn___49(struct request_queue___49 *, struct request___49 *, struct bio___50 *);

typedef int elevator_dispatch_fn___49(struct request_queue___49 *, int);

typedef void elevator_add_req_fn___49(struct request_queue___49 *, struct request___49 *);

typedef struct request___49 *elevator_request_list_fn___49(struct request_queue___49 *, struct request___49 *);

typedef void elevator_completed_req_fn___49(struct request_queue___49 *, struct request___49 *);

typedef int elevator_may_queue_fn___49(struct request_queue___49 *, int);

typedef void elevator_init_icq_fn___49(struct io_cq___49 *);

typedef void elevator_exit_icq_fn___49(struct io_cq___49 *);

typedef int elevator_set_req_fn___49(struct request_queue___49 *, struct request___49 *, struct bio___50 *, gfp_t);

typedef void elevator_put_req_fn___49(struct request___49 *);

typedef void elevator_activate_req_fn___49(struct request_queue___49 *, struct request___49 *);

typedef void elevator_deactivate_req_fn___49(struct request_queue___49 *, struct request___49 *);

struct elevator_type___49;

typedef int elevator_init_fn___50(struct request_queue___49 *, struct elevator_type___49 *);

typedef void elevator_exit_fn___49(struct elevator_queue___49 *);

struct elevator_ops___49 {
	elevator_merge_fn___49 *elevator_merge_fn;
	elevator_merged_fn___49 *elevator_merged_fn;
	elevator_merge_req_fn___49 *elevator_merge_req_fn;
	elevator_allow_merge_fn___49 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___49 *elevator_bio_merged_fn;
	elevator_dispatch_fn___49 *elevator_dispatch_fn;
	elevator_add_req_fn___49 *elevator_add_req_fn;
	elevator_activate_req_fn___49 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___49 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___49 *elevator_completed_req_fn;
	elevator_request_list_fn___49 *elevator_former_req_fn;
	elevator_request_list_fn___49 *elevator_latter_req_fn;
	elevator_init_icq_fn___49 *elevator_init_icq_fn;
	elevator_exit_icq_fn___49 *elevator_exit_icq_fn;
	elevator_set_req_fn___49 *elevator_set_req_fn;
	elevator_put_req_fn___49 *elevator_put_req_fn;
	elevator_may_queue_fn___49 *elevator_may_queue_fn;
	elevator_init_fn___50 *elevator_init_fn;
	elevator_exit_fn___49 *elevator_exit_fn;
};

struct elv_fs_entry___49;

struct elevator_type___49 {
	struct kmem_cache___205 *icq_cache;
	struct elevator_ops___49 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___49 *elevator_attrs;
	char elevator_name[16];
	struct module___126 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___49 {
	struct elevator_type___49 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex___222 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___49 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___49 *, char *);
	ssize_t (*store)(struct elevator_queue___49 *, const char *, size_t);
};

struct bvec_merge_data___49 {
	struct block_device___220 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___49 {
	struct request___49 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct scsi_cmnd___5;

struct scsi_target___8;

struct scsi_dh_data___8;

struct scsi_device___8 {
	struct Scsi_Host *host;
	struct request_queue___49 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	union {
		atomic_t device_busy;
		struct {
			unsigned int device_busy;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	struct scsi_cmnd___5 *current_cmnd;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int lun;
	unsigned int channel;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	char type;
	char scsi_level;
	char inq_periph_qual;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	unsigned char current_tag;
	struct scsi_target___8 *sdev_target;
	unsigned int sdev_bflags;
	unsigned int eh_timeout;
	unsigned int writeable: 1;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int ordered_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int vpd_reserved: 1;
	unsigned int xcopy_reserved: 1;
	unsigned int lun_in_cdb: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	union {
		atomic_t device_blocked;
		struct {
			unsigned int device_blocked;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___204 sdev_gendev;
	struct device___204 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_dh_data___8 *scsi_dh_data;
	enum scsi_device_state sdev_state;
	union {
		unsigned char *vpd_pg83;
		struct {
			void *vpd_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		int vpd_pg83_len;
		struct {
			void *vpd_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		unsigned char *vpd_pg80;
		struct {
			void *vpd_reserved3;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int vpd_pg80_len;
		struct {
			void *vpd_reserved4;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	char vpd_reserved5;
	char vpd_reserved6;
	char vpd_reserved7;
	char vpd_reserved8;
	spinlock_t vpd_reserved9;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___5 {
	struct scsi_device___8 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___49 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___5 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	unsigned char tag;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
};

struct scsi_target___8 {
	struct scsi_device___8 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___204 dev;
	unsigned int reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	union {
		atomic_t target_busy;
		struct {
			unsigned int target_busy;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	unsigned int can_queue;
	union {
		atomic_t target_blocked;
		struct {
			unsigned int target_blocked;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	unsigned int max_target_blocked;
	char scsi_level;
	struct execute_work ew;
	enum scsi_target_state state;
	void *hostdata;
	void (*rh_reserved1)();
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	atomic_t scsi_mq_reserved1;
	atomic_t scsi_mq_reserved2;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___8;

struct scsi_dh_data___8 {
	struct scsi_device_handler___8 *scsi_dh;
	struct scsi_device___8 *sdev;
	struct kref kref;
	char buf[0];
};

struct scsi_device_handler___8 {
	struct list_head list;
	struct module___126 *module;
	const char *name;
	const struct scsi_dh_devlist *devlist;
	int (*check_sense)(struct scsi_device___8 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___8 *);
	void (*detach)(struct scsi_device___8 *);
	int (*activate)(struct scsi_device___8 *, activate_complete, void *);
	int (*prep_fn)(struct scsi_device___8 *, struct request___49 *);
	int (*set_params)(struct scsi_device___8 *, const char *);
	bool (*match)(struct scsi_device___8 *);
};

struct module_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___125 *, struct module_kobject___125 *, char *);
	ssize_t (*store)(struct module_attribute___125 *, struct module_kobject___125 *, const char *, size_t);
	void (*setup)(struct module___126 *, const char *);
	int (*test)(struct module___126 *);
	void (*free)(struct module___126 *);
};

struct module_version_attribute___4 {
	struct module_attribute___125 mattr;
	const char *module_name;
	const char *version;
};

struct rdac_mode_6_hdr {
	u8 data_len;
	u8 medium_type;
	u8 device_params;
	u8 block_desc_len;
};

struct rdac_mode_10_hdr {
	u16 data_len;
	u8 medium_type;
	u8 device_params;
	u16 reserved;
	u16 block_desc_len;
};

struct rdac_mode_common {
	u8 controller_serial[16];
	u8 alt_controller_serial[16];
	u8 rdac_mode[2];
	u8 alt_rdac_mode[2];
	u8 quiescence_timeout;
	u8 rdac_options;
};

struct rdac_pg_legacy {
	struct rdac_mode_6_hdr hdr;
	u8 page_code;
	u8 page_len;
	struct rdac_mode_common common;
	u8 lun_table[32];
	u8 reserved2[32];
	u8 reserved3;
	u8 reserved4;
};

struct rdac_pg_expanded {
	struct rdac_mode_10_hdr hdr;
	u8 page_code;
	u8 subpage_code;
	u8 page_len[2];
	struct rdac_mode_common common;
	u8 lun_table[256];
	u8 reserved3;
	u8 reserved4;
};

struct c9_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 avte_cvp;
	u8 path_prio;
	u8 reserved2[38];
};

struct c4_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 subsys_id[16];
	u8 revision[4];
	u8 slot_id[2];
	u8 reserved[2];
};

struct c8_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 reserved2[3];
	u8 vol_uniq_id_len;
	u8 vol_uniq_id[16];
	u8 vol_user_label_len;
	u8 vol_user_label[60];
	u8 array_uniq_id_len;
	u8 array_unique_id[16];
	u8 array_user_label_len;
	u8 array_user_label[60];
	u8 lun[8];
};

struct rdac_controller {
	u8 array_id[16];
	int use_ms10;
	struct kref kref;
	struct list_head node;
	union {
		struct rdac_pg_legacy legacy;
		struct rdac_pg_expanded expanded;
	} mode_select;
	u8 index;
	u8 array_name[31];
	struct Scsi_Host *host;
	spinlock_t ms_lock;
	int ms_queued;
	struct work_struct ms_work;
	struct scsi_device___8 *ms_sdev;
	struct list_head ms_head;
};

struct c2_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 sw_version[3];
	u8 sw_date[3];
	u8 features_enabled;
	u8 max_lun_supported;
	u8 partitions[239];
};

struct rdac_dh_data {
	struct rdac_controller *ctlr;
	unsigned int lun;
	unsigned char mode;
	unsigned char state;
	char lun_state;
	char preferred;
	unsigned char sense[96];
	union {
		struct c2_inquiry c2;
		struct c4_inquiry c4;
		struct c8_inquiry c8;
		struct c9_inquiry c9;
	} inq;
};

struct rdac_queue_data {
	struct list_head entry;
	struct rdac_dh_data *h;
	activate_complete callback_fn;
	void *callback_data;
};

struct hp_sw_dh_data {
	unsigned char sense[96];
	int path_state;
	int retries;
	int retry_cnt;
	struct scsi_device___8 *sdev;
	activate_complete callback_fn;
	void *callback_data;
};

struct clariion_dh_data {
	unsigned int flags;
	unsigned char buffer[252];
	unsigned char sense[96];
	unsigned int senselen;
	int lun_state;
	int port;
	int default_sp;
	int current_sp;
};

struct alua_dh_data {
	int group_id;
	int rel_port;
	int tpgs;
	int state;
	int pref;
	unsigned int flags;
	unsigned char inq[36];
	unsigned char *buff;
	int bufflen;
	unsigned char transition_tmo;
	unsigned char sense[96];
	int senselen;
	struct scsi_device___8 *sdev;
	activate_complete callback_fn;
	void *callback_data;
};

struct devprobe2 {
	struct net_device___28 * (*probe)(int);
	int status;
};

struct page___220;

typedef struct page___220 *pgtable_t___220;

struct address_space___221;

struct kmem_cache___206;

struct page___220 {
	long unsigned int flags;
	struct address_space___221 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___220 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___220 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___206 *slab_cache;
		struct page___220 *first_page;
	};
	long: 64;
};

struct task_struct___222;

struct pv_cpu_ops___222 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___222 *);
	void (*end_context_switch)(struct task_struct___222 *);
};

struct mutex___223 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___222 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___215 {
	struct page___220 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___229;

struct nsproxy___114;

struct signal_struct___222;

struct css_set___130;

struct task_struct___222 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___222 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___229 *mm;
	struct mm_struct___229 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___222 *real_parent;
	struct task_struct___222 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___222 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___222 = 0,
		VTIME_USER___222 = 1,
		VTIME_SYS___222 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___114 *nsproxy;
	struct signal_struct___222 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___130 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___223 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___215 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___229 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___229 *, struct mm_struct___229 *);
	void (*dup_mmap)(struct mm_struct___229 *, struct mm_struct___229 *);
	void (*exit_mmap)(struct mm_struct___229 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___229 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___229 *);
	void (*pgd_free)(struct mm_struct___229 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___229 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___229 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___229 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___229 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___229 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___229 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___229 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___229 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___229 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___229 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___229 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___223 lock;
	void *vdso;
} mm_context_t___223;

struct xol_area___220;

struct uprobes_state___220 {
	struct xol_area___220 *xol_area;
};

struct vm_area_struct___229;

struct file___221;

struct core_state___222;

struct mm_struct___229 {
	struct vm_area_struct___229 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___229 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___229 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___223 context;
	long unsigned int flags;
	struct core_state___222 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___222 *owner;
	struct file___221 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___220 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___24;

struct kobj_type___24;

struct kobject___24 {
	const char *name;
	struct list_head entry;
	struct kobject___24 *parent;
	struct kset___24 *kset;
	struct kobj_type___24 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___127;

struct module_kobject___126 {
	struct kobject___24 kobj;
	struct module___127 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___126;

struct module___127 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___126 mkobj;
	struct module_attribute___126 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___222 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___222;

struct lruvec___222 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___222 *zone;
};

struct pglist_data___222;

struct zone___222 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___222 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___222 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___222 {
	struct zone___222 *zone;
	int zone_idx;
};

struct zonelist___222 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___222 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___222 {
	struct zone___222 node_zones[4];
	struct zonelist___222 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___222 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___145;

struct x86_io_apic_ops___145 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___145 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___145;

struct irq_data___145 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___145 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___205;

struct dev_pm_ops___205 {
	int (*prepare)(struct device___205 *);
	void (*complete)(struct device___205 *);
	int (*suspend)(struct device___205 *);
	int (*resume)(struct device___205 *);
	int (*freeze)(struct device___205 *);
	int (*thaw)(struct device___205 *);
	int (*poweroff)(struct device___205 *);
	int (*restore)(struct device___205 *);
	int (*suspend_late)(struct device___205 *);
	int (*resume_early)(struct device___205 *);
	int (*freeze_late)(struct device___205 *);
	int (*thaw_early)(struct device___205 *);
	int (*poweroff_late)(struct device___205 *);
	int (*restore_early)(struct device___205 *);
	int (*suspend_noirq)(struct device___205 *);
	int (*resume_noirq)(struct device___205 *);
	int (*freeze_noirq)(struct device___205 *);
	int (*thaw_noirq)(struct device___205 *);
	int (*poweroff_noirq)(struct device___205 *);
	int (*restore_noirq)(struct device___205 *);
	int (*runtime_suspend)(struct device___205 *);
	int (*runtime_resume)(struct device___205 *);
	int (*runtime_idle)(struct device___205 *);
};

struct dev_pm_qos___34;

struct dev_pm_info___34 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___34 *qos;
};

struct dma_map_ops___88;

struct dev_archdata___88 {
	struct dma_map_ops___88 *dma_ops;
	void *iommu;
};

struct device_type___205;

struct bus_type___205;

struct device_driver___205;

struct dev_pm_domain___205;

struct class___205;

struct attribute_group___179;

struct device_rh___205;

struct device___205 {
	struct device___205 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___205 *type;
	struct mutex___223 mutex;
	struct bus_type___205 *bus;
	struct device_driver___205 *driver;
	void *platform_data;
	struct dev_pm_info___34 power;
	struct dev_pm_domain___205 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___88 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___205 *class;
	const struct attribute_group___179 **groups;
	void (*release)(struct device___205 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___205 *device_rh;
};

struct dev_pm_qos_request___34;

struct dev_pm_qos___34 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___34 *latency_req;
	struct dev_pm_qos_request___34 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___34 *latency_tolerance_req;
};

struct dev_pm_info_rh___205 {
	void (*set_latency_tolerance)(struct device___205 *, s32);
};

struct dev_pm_domain___205 {
	struct dev_pm_ops___205 ops;
};

struct smp_ops___222 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___222 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___41;

struct ctl_node___41 {
	struct rb_node node;
	struct ctl_table_header___41 *header;
};

struct ctl_table_root___41;

struct ctl_table_set___41;

struct ctl_dir___41;

struct ctl_table_header___41 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___41 *root;
	struct ctl_table_set___41 *set;
	struct ctl_dir___41 *parent;
	struct ctl_node___41 *node;
};

struct ctl_dir___41 {
	struct ctl_table_header___41 header;
	struct rb_root root;
};

struct ctl_table_set___41 {
	int (*is_seen)(struct ctl_table_set___41 *);
	struct ctl_dir___41 dir;
};

struct ctl_table_root___41 {
	struct ctl_table_set___41 default_set;
	struct ctl_table_set___41 * (*lookup)(struct ctl_table_root___41 *, struct nsproxy___114 *);
	int (*permissions)(struct ctl_table_header___41 *, struct ctl_table *);
};

struct net___40;

struct nsproxy___114 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___40 *net_ns;
};

struct sock___22;

struct kobj_ns_type_operations___21 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___22 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___21;

struct sock_common___21 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___21 *skc_prot;
	struct net___40 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___30;

struct sk_buff_head___28 {
	struct sk_buff___30 *next;
	struct sk_buff___30 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___22;

struct socket_wq___21;

struct dst_entry___21;

struct socket___22;

struct cg_proto___21;

struct sock___22 {
	struct sock_common___21 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___28 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___30 *head;
		struct sk_buff___30 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___22 *sk_filter;
	struct socket_wq___21 *sk_wq;
	struct sk_buff_head___28 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___21 *sk_rx_dst;
	struct dst_entry___21 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___28 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___28 sk_error_queue;
	struct proto___21 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___91 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___22 *sk_socket;
	void *sk_user_data;
	struct page_frag___215 sk_frag;
	struct sk_buff___30 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___21 *sk_cgrp;
	void (*sk_state_change)(struct sock___22 *);
	void (*sk_data_ready)(struct sock___22 *, int);
	void (*sk_write_space)(struct sock___22 *);
	void (*sk_error_report)(struct sock___22 *);
	int (*sk_backlog_rcv)(struct sock___22 *, struct sk_buff___30 *);
	void (*sk_destruct)(struct sock___22 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___181;

struct attribute_group___179 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___181 **bin_attrs;
};

struct bin_attribute___181 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___221 *, struct kobject___24 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___221 *, struct kobject___24 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	int (*mmap)(struct file___221 *, struct kobject___24 *, struct bin_attribute___181 *, struct vm_area_struct___229 *);
};

struct dentry___221;

struct path___221 {
	struct vfsmount *mnt;
	struct dentry___221 *dentry;
};

struct inode___221;

struct file_operations___221;

struct file___221 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___221 f_path;
	struct inode___221 *f_inode;
	const struct file_operations___221 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___221 *f_mapping;
	struct mutex___223 f_pos_lock;
};

struct vm_operations_struct___201;

struct vm_area_struct___229 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___229 *vm_next;
	struct vm_area_struct___229 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___229 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___201 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___221 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___24 {
	ssize_t (*show)(struct kobject___24 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___24 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___24 *, const struct attribute *);
};

struct kset_uevent_ops___24;

struct kset___24 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___24 kobj;
	const struct kset_uevent_ops___24 *uevent_ops;
};

struct kobj_type___24 {
	void (*release)(struct kobject___24 *);
	const struct sysfs_ops___24 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___21 * (*child_ns_type)(struct kobject___24 *);
	const void * (*namespace)(struct kobject___24 *);
};

struct kset_uevent_ops___24 {
	int (* const filter)(struct kset___24 *, struct kobject___24 *);
	const char * (* const name)(struct kset___24 *, struct kobject___24 *);
	int (* const uevent)(struct kset___24 *, struct kobject___24 *, struct kobj_uevent_env *);
};

struct module_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___126 *, struct module_kobject___126 *, char *);
	ssize_t (*store)(struct module_attribute___126 *, struct module_kobject___126 *, const char *, size_t);
	void (*setup)(struct module___127 *, const char *);
	int (*test)(struct module___127 *);
	void (*free)(struct module___127 *);
};

struct seq_file___149;

struct irq_chip___145 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___145 *);
	void (*irq_shutdown)(struct irq_data___145 *);
	void (*irq_enable)(struct irq_data___145 *);
	void (*irq_disable)(struct irq_data___145 *);
	void (*irq_ack)(struct irq_data___145 *);
	void (*irq_mask)(struct irq_data___145 *);
	void (*irq_mask_ack)(struct irq_data___145 *);
	void (*irq_unmask)(struct irq_data___145 *);
	void (*irq_eoi)(struct irq_data___145 *);
	int (*irq_set_affinity)(struct irq_data___145 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___145 *);
	int (*irq_set_type)(struct irq_data___145 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___145 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___145 *);
	void (*irq_bus_sync_unlock)(struct irq_data___145 *);
	void (*irq_cpu_online)(struct irq_data___145 *);
	void (*irq_cpu_offline)(struct irq_data___145 *);
	void (*irq_suspend)(struct irq_data___145 *);
	void (*irq_resume)(struct irq_data___145 *);
	void (*irq_pm_shutdown)(struct irq_data___145 *);
	void (*irq_print_chip)(struct irq_data___145 *, struct seq_file___149 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___145 *, void *);
	long unsigned int flags;
};

struct seq_operations___149;

struct seq_file___149 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___223 lock;
	const struct seq_operations___149 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___221;

struct super_block___221;

struct dentry___221 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___221 *d_parent;
	struct qstr d_name;
	struct inode___221 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___221 *d_op;
	struct super_block___221 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___221;

struct address_space___221 {
	struct inode___221 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___223 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___221 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___221;

struct file_lock___221;

struct dquot___221;

struct block_device___221;

struct inode___221 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___221 *i_op;
	struct super_block___221 *i_sb;
	struct address_space___221 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___223 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___221 *i_fop;
	struct file_lock___221 *i_flock;
	struct address_space___221 i_data;
	struct dquot___221 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___221 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___221 {
	int (*d_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_hash)(const struct dentry___221 *, struct qstr *);
	int (*d_compare)(const struct dentry___221 *, const struct dentry___221 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___221 *);
	void (*d_release)(struct dentry___221 *);
	void (*d_prune)(struct dentry___221 *);
	void (*d_iput)(struct dentry___221 *, struct inode___221 *);
	char * (*d_dname)(struct dentry___221 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___221 *);
	int (*d_manage)(struct dentry___221 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___221;

struct mem_dqinfo___221 {
	struct quota_format_type___221 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___221;

struct quota_info___221 {
	unsigned int flags;
	struct mutex___223 dqio_mutex;
	struct mutex___223 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___221 *files[2];
	struct mem_dqinfo___221 info[2];
	const struct quota_format_ops___221 *ops[2];
};

struct file_system_type___221;

struct super_operations___221;

struct dquot_operations___221;

struct quotactl_ops___221;

struct xattr_handler___131;

struct super_block___221 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___221 *s_type;
	const struct super_operations___221 *s_op;
	const struct dquot_operations___221 *dq_op;
	const struct quotactl_ops___221 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___221 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___131 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___221 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___221 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___223 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___221 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___221 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___221 *bd_inode;
	struct super_block___221 *bd_super;
	struct mutex___223 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___221 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___223 bd_fsfreeze_mutex;
};

struct cgroup___130;

struct cgroup_subsys_state___130 {
	struct cgroup___130 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___29;

typedef int kiocb_cancel_fn___29(struct kiocb___29 *, struct io_event *);

struct kiocb___29 {
	atomic_t ki_users;
	struct file___221 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___29 *ki_cancel;
	void (*ki_dtor)(struct kiocb___29 *);
	union {
		void *user;
		struct task_struct___222 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___221 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___221 *ia_file;
};

struct dquot___221 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___223 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___221 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___221 {
	int qf_fmt_id;
	const struct quota_format_ops___221 *qf_ops;
	struct module___127 *qf_owner;
	struct quota_format_type___221 *qf_next;
};

struct quota_format_ops___221 {
	int (*check_quota_file)(struct super_block___221 *, int);
	int (*read_file_info)(struct super_block___221 *, int);
	int (*write_file_info)(struct super_block___221 *, int);
	int (*free_file_info)(struct super_block___221 *, int);
	int (*read_dqblk)(struct dquot___221 *);
	int (*commit_dqblk)(struct dquot___221 *);
	int (*release_dqblk)(struct dquot___221 *);
};

struct dquot_operations___221 {
	int (*write_dquot)(struct dquot___221 *);
	struct dquot___221 * (*alloc_dquot)(struct super_block___221 *, int);
	void (*destroy_dquot)(struct dquot___221 *);
	int (*acquire_dquot)(struct dquot___221 *);
	int (*release_dquot)(struct dquot___221 *);
	int (*mark_dirty)(struct dquot___221 *);
	int (*write_info)(struct super_block___221 *, int);
	qsize_t * (*get_reserved_space)(struct inode___221 *);
};

struct quotactl_ops___221 {
	int (*quota_on)(struct super_block___221 *, int, int, struct path___221 *);
	int (*quota_on_meta)(struct super_block___221 *, int, int);
	int (*quota_off)(struct super_block___221 *, int);
	int (*quota_sync)(struct super_block___221 *, int);
	int (*get_info)(struct super_block___221 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___221 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___221 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___221 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___221 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___221 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___221 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___221 *, unsigned int);
};

struct address_space_operations___221 {
	int (*writepage)(struct page___220 *, struct writeback_control *);
	int (*readpage)(struct file___221 *, struct page___220 *);
	int (*writepages)(struct address_space___221 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___220 *);
	int (*readpages)(struct file___221 *, struct address_space___221 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___221 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___220 **, void **);
	int (*write_end)(struct file___221 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___220 *, void *);
	sector_t (*bmap)(struct address_space___221 *, sector_t);
	void (*invalidatepage)(struct page___220 *, long unsigned int);
	int (*releasepage)(struct page___220 *, gfp_t);
	void (*freepage)(struct page___220 *);
	ssize_t (*direct_IO)(int, struct kiocb___29 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___221 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___221 *, struct page___220 *, struct page___220 *, enum migrate_mode);
	int (*launder_page)(struct page___220 *);
	int (*is_partially_uptodate)(struct page___220 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___220 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___221 *, struct page___220 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___221 *, sector_t *);
	void (*swap_deactivate)(struct file___221 *);
	void (*invalidatepage_range)(struct page___220 *, unsigned int, unsigned int);
};

struct inode_operations___221 {
	struct dentry___221 * (*lookup)(struct inode___221 *, struct dentry___221 *, unsigned int);
	void * (*follow_link)(struct dentry___221 *, struct nameidata *);
	int (*permission)(struct inode___221 *, int);
	struct posix_acl * (*get_acl)(struct inode___221 *, int);
	int (*readlink)(struct dentry___221 *, char *, int);
	void (*put_link)(struct dentry___221 *, struct nameidata *, void *);
	int (*create)(struct inode___221 *, struct dentry___221 *, umode_t, bool);
	int (*link)(struct dentry___221 *, struct inode___221 *, struct dentry___221 *);
	int (*unlink)(struct inode___221 *, struct dentry___221 *);
	int (*symlink)(struct inode___221 *, struct dentry___221 *, const char *);
	int (*mkdir)(struct inode___221 *, struct dentry___221 *, umode_t);
	int (*rmdir)(struct inode___221 *, struct dentry___221 *);
	int (*mknod)(struct inode___221 *, struct dentry___221 *, umode_t, dev_t);
	int (*rename)(struct inode___221 *, struct dentry___221 *, struct inode___221 *, struct dentry___221 *);
	int (*setattr)(struct dentry___221 *, struct iattr___221 *);
	int (*getattr)(struct vfsmount *, struct dentry___221 *, struct kstat *);
	int (*setxattr)(struct dentry___221 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___221 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___221 *, char *, size_t);
	int (*removexattr)(struct dentry___221 *, const char *);
	int (*fiemap)(struct inode___221 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___221 *, struct timespec *, int);
	int (*atomic_open)(struct inode___221 *, struct dentry___221 *, struct file___221 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___119;

struct file_operations___221 {
	struct module___127 *owner;
	loff_t (*llseek)(struct file___221 *, loff_t, int);
	ssize_t (*read)(struct file___221 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___221 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___29 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___29 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___221 *, void *, filldir_t);
	unsigned int (*poll)(struct file___221 *, struct poll_table_struct___119 *);
	long int (*unlocked_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___221 *, struct vm_area_struct___229 *);
	int (*open)(struct inode___221 *, struct file___221 *);
	int (*flush)(struct file___221 *, fl_owner_t);
	int (*release)(struct inode___221 *, struct file___221 *);
	int (*fsync)(struct file___221 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___29 *, int);
	int (*fasync)(int, struct file___221 *, int);
	int (*lock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*sendpage)(struct file___221 *, struct page___220 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___221 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___221 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___221 *, long int, struct file_lock___221 **, void **);
		struct {
			int (*setlease)(struct file___221 *, long int, struct file_lock___221 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___221 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___149 *, struct file___221 *);
};

struct fasync_struct___221;

struct file_lock_operations___221;

struct lock_manager_operations___221;

struct file_lock___221 {
	struct file_lock___221 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___221 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___221 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___221 *fl_ops;
	const struct lock_manager_operations___221 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___221 {
	void (*fl_copy_lock)(struct file_lock___221 *, struct file_lock___221 *);
	void (*fl_release_private)(struct file_lock___221 *);
};

struct lock_manager_operations___221 {
	int (*lm_compare_owner)(struct file_lock___221 *, struct file_lock___221 *);
	long unsigned int (*lm_owner_key)(struct file_lock___221 *);
	void (*lm_notify)(struct file_lock___221 *);
	int (*lm_grant)(struct file_lock___221 *, struct file_lock___221 *, int);
	void (*lm_break)(struct file_lock___221 *);
	int (*lm_change)(struct file_lock___221 **, int);
};

struct fasync_struct___221 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___221 *fa_next;
	struct file___221 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___221 {
	const char *name;
	int fs_flags;
	struct dentry___221 * (*mount)(struct file_system_type___221 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___221 *);
	struct module___127 *owner;
	struct file_system_type___221 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___221 {
	struct inode___221 * (*alloc_inode)(struct super_block___221 *);
	void (*destroy_inode)(struct inode___221 *);
	void (*dirty_inode)(struct inode___221 *, int);
	int (*write_inode)(struct inode___221 *, struct writeback_control *);
	int (*drop_inode)(struct inode___221 *);
	void (*evict_inode)(struct inode___221 *);
	void (*put_super)(struct super_block___221 *);
	int (*sync_fs)(struct super_block___221 *, int);
	int (*freeze_fs)(struct super_block___221 *);
	int (*unfreeze_fs)(struct super_block___221 *);
	int (*statfs)(struct dentry___221 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___221 *, int *, char *);
	void (*umount_begin)(struct super_block___221 *);
	int (*show_options)(struct seq_file___149 *, struct dentry___221 *);
	int (*show_devname)(struct seq_file___149 *, struct dentry___221 *);
	int (*show_path)(struct seq_file___149 *, struct dentry___221 *);
	int (*show_stats)(struct seq_file___149 *, struct dentry___221 *);
	ssize_t (*quota_read)(struct super_block___221 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___221 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___221 *);
	int (*bdev_try_to_free_page)(struct super_block___221 *, struct page___220 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___221 *);
	void (*free_cached_objects)(struct super_block___221 *, int);
};

struct xattr_handler___131 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___221 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___221 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___221 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___121)(struct file___221 *, wait_queue_head_t *, struct poll_table_struct___119 *);

struct poll_table_struct___119 {
	poll_queue_proc___121 _qproc;
	long unsigned int _key;
};

struct dma_map_ops___88 {
	void * (*alloc)(struct device___205 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___205 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___205 *, struct vm_area_struct___229 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___205 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___205 *, struct page___220 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___205 *, dma_addr_t);
	int (*dma_supported)(struct device___205 *, u64);
	int (*set_dma_mask)(struct device___205 *, u64);
	int is_phys;
};

struct bus_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___205 *, char *);
	ssize_t (*store)(struct bus_type___205 *, const char *, size_t);
};

struct device_attribute___205;

struct driver_attribute___205;

struct bus_type___205 {
	const char *name;
	const char *dev_name;
	struct device___205 *dev_root;
	struct bus_attribute___205 *bus_attrs;
	struct device_attribute___205 *dev_attrs;
	struct driver_attribute___205 *drv_attrs;
	const struct attribute_group___179 **bus_groups;
	const struct attribute_group___179 **dev_groups;
	const struct attribute_group___179 **drv_groups;
	int (*match)(struct device___205 *, struct device_driver___205 *);
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	int (*probe)(struct device___205 *);
	int (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*online)(struct device___205 *);
	int (*offline)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct device___205 *, struct device_attribute___205 *, char *);
	ssize_t (*store)(struct device___205 *, struct device_attribute___205 *, const char *, size_t);
};

struct driver_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___205 *, char *);
	ssize_t (*store)(struct device_driver___205 *, const char *, size_t);
};

struct device_driver___205 {
	const char *name;
	struct bus_type___205 *bus;
	struct module___127 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___205 *);
	int (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	const struct attribute_group___179 **groups;
	const struct dev_pm_ops___205 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___205 {
	const char *name;
	const struct attribute_group___179 **groups;
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
};

struct class_attribute___205;

struct class___205 {
	const char *name;
	struct module___127 *owner;
	struct class_attribute___205 *class_attrs;
	struct device_attribute___205 *dev_attrs;
	const struct attribute_group___179 **dev_groups;
	struct bin_attribute___181 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *);
	void (*class_release)(struct class___205 *);
	void (*dev_release)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
	struct subsys_private *p;
};

struct class_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct class___205 *, struct class_attribute___205 *, char *);
	ssize_t (*store)(struct class___205 *, struct class_attribute___205 *, const char *, size_t);
	const void * (*namespace)(struct class___205 *, const struct class_attribute___205 *);
};

struct device_rh___205 {
	struct dev_pm_info_rh___205 power;
};

struct dev_pm_qos_request___34 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___205 *dev;
};

struct xol_area___220 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___220 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___205;

struct memcg_cache_params___206;

struct kmem_cache___206 {
	struct kmem_cache_cpu___205 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___206 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___197;

struct vm_operations_struct___201 {
	void (*open)(struct vm_area_struct___229 *);
	void (*close)(struct vm_area_struct___229 *);
	int (*fault)(struct vm_area_struct___229 *, struct vm_fault___197 *);
	int (*page_mkwrite)(struct vm_area_struct___229 *, struct vm_fault___197 *);
	int (*access)(struct vm_area_struct___229 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___229 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___229 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___229 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___229 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___222 {
	struct task_struct___222 *task;
	struct core_thread___222 *next;
};

struct core_state___222 {
	atomic_t nr_threads;
	struct core_thread___222 dumper;
	struct completion startup;
};

struct vm_fault___197 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___220 *page;
};

enum net_device_flags {
	IFF_UP = 1,
	IFF_BROADCAST = 2,
	IFF_DEBUG = 4,
	IFF_LOOPBACK = 8,
	IFF_POINTOPOINT = 16,
	IFF_NOTRAILERS = 32,
	IFF_RUNNING = 64,
	IFF_NOARP = 128,
	IFF_PROMISC = 256,
	IFF_ALLMULTI = 512,
	IFF_MASTER = 1024,
	IFF_SLAVE = 2048,
	IFF_MULTICAST = 4096,
	IFF_PORTSEL = 8192,
	IFF_AUTOMEDIA = 16384,
	IFF_DYNAMIC = 32768,
	IFF_LOWER_UP = 65536,
	IFF_DORMANT = 131072,
	IFF_ECHO = 262144,
};

struct signal_struct___222 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___222 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___222 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___223 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___130 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___130 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___21 {
	wait_queue_head_t wait;
	struct fasync_struct___221 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___21;

struct socket___22 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___21 *wq;
	struct file___221 *file;
	struct sock___22 *sk;
	const struct proto_ops___21 *ops;
};

struct proto_ops___21 {
	int family;
	struct module___127 *owner;
	int (*release)(struct socket___22 *);
	int (*bind)(struct socket___22 *, struct sockaddr *, int);
	int (*connect)(struct socket___22 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___22 *, struct socket___22 *);
	int (*accept)(struct socket___22 *, struct socket___22 *, int);
	int (*getname)(struct socket___22 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___221 *, struct socket___22 *, struct poll_table_struct___119 *);
	int (*ioctl)(struct socket___22 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___22 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___22 *, int);
	int (*shutdown)(struct socket___22 *, int);
	int (*setsockopt)(struct socket___22 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___22 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___22 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___22 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___29 *, struct socket___22 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___29 *, struct socket___22 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___221 *, struct socket___22 *, struct vm_area_struct___229 *);
	ssize_t (*sendpage)(struct socket___22 *, struct page___220 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___22 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___22 *, int);
		struct {
			void (*set_peek_off)(struct sock___22 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___38 {
	struct ctl_table_header___41 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___38 {
	struct mutex___223 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___38 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___41 *ctl;
};

struct netns_ipv4___38 {
	struct ctl_table_header___41 *forw_hdr;
	struct ctl_table_header___41 *frags_hdr;
	struct ctl_table_header___41 *ipv4_hdr;
	struct ctl_table_header___41 *route_hdr;
	struct ctl_table_header___41 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___22 *fibnl;
	struct sock___22 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___38 {
	struct ctl_table_header___41 *hdr;
	struct ctl_table_header___41 *route_hdr;
	struct ctl_table_header___41 *icmp_hdr;
	struct ctl_table_header___41 *frags_hdr;
	struct ctl_table_header___41 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___29;

struct neighbour___21;

struct dst_ops___39 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___39 *);
	struct dst_entry___21 * (*check)(struct dst_entry___21 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___21 *);
	unsigned int (*mtu)(const struct dst_entry___21 *);
	u32 * (*cow_metrics)(struct dst_entry___21 *, long unsigned int);
	void (*destroy)(struct dst_entry___21 *);
	void (*ifdown)(struct dst_entry___21 *, struct net_device___29 *, int);
	struct dst_entry___21 * (*negative_advice)(struct dst_entry___21 *);
	void (*link_failure)(struct sk_buff___30 *);
	void (*update_pmtu)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___30 *, u32);
	void (*redirect)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___30 *);
	int (*local_out)(struct sk_buff___30 *);
	struct neighbour___21 * (*neigh_lookup)(const struct dst_entry___21 *, struct sk_buff___30 *, const void *);
	struct kmem_cache___206 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___39 {
	struct netns_sysctl_ipv6___38 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___39 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___22 **icmp_sk;
	struct sock___22 *ndisc_sk;
	struct sock___22 *tcp_sk;
	struct sock___22 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___38 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___41 *sysctl_header;
	struct sock___22 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___21 {
	struct sock___22 *v4_ctl_sk;
	struct sock___22 *v6_ctl_sk;
};

struct netns_nf___38 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___41 *nf_log_dir_header;
};

struct nf_proto_net___38 {
	struct ctl_table_header___41 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___38 {
	struct nf_proto_net___38 pn;
	unsigned int timeout;
};

struct nf_tcp_net___38 {
	struct nf_proto_net___38 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___38 {
	struct nf_proto_net___38 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___38 {
	struct nf_proto_net___38 pn;
	unsigned int timeout;
};

struct nf_ip_net___38 {
	struct nf_generic_net___38 generic;
	struct nf_tcp_net___38 tcp;
	struct nf_udp_net___38 udp;
	struct nf_icmp_net___38 icmp;
	struct nf_icmp_net___38 icmpv6;
};

struct netns_ct___38 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___41 *sysctl_header;
	struct ctl_table_header___41 *acct_sysctl_header;
	struct ctl_table_header___41 *tstamp_sysctl_header;
	struct ctl_table_header___41 *event_sysctl_header;
	struct ctl_table_header___41 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___206 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___38 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___38 {
	struct netns_sysctl_ipv6___38 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___39 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___22 *nlsk;
	struct sock___22 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___41 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___39 xfrm4_dst_ops;
	struct dst_ops___39 xfrm6_dst_ops;
};

struct net___40 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___41 sysctls;
	struct sock___22 *rtnl;
	struct sock___22 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___29 *loopback_dev;
	struct netns_core___38 core;
	struct netns_mib mib;
	struct netns_packet___38 packet;
	struct netns_unix___38 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___38 ipv4;
	struct netns_ipv6___39 ipv6;
	struct netns_sctp___38 sctp;
	struct netns_dccp___21 dccp;
	struct netns_nf___38 nf;
	struct netns_xt xt;
	struct netns_ct___38 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___38 nf_frag;
	struct sock___22 *nfnl;
	struct sock___22 *nfnl_stash;
	struct sk_buff_head___28 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___39 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___22 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___22 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___223 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___223 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___205 {
	void **freelist;
	long unsigned int tid;
	struct page___220 *page;
	struct page___220 *partial;
};

struct memcg_cache_params___206 {
	bool is_root_cache;
	union {
		struct kmem_cache___206 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___206 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

enum {
	NETIF_F_SG_BIT = 0,
	NETIF_F_IP_CSUM_BIT = 1,
	__UNUSED_NETIF_F_1 = 2,
	NETIF_F_HW_CSUM_BIT = 3,
	NETIF_F_IPV6_CSUM_BIT = 4,
	NETIF_F_HIGHDMA_BIT = 5,
	NETIF_F_FRAGLIST_BIT = 6,
	NETIF_F_HW_VLAN_CTAG_TX_BIT = 7,
	NETIF_F_HW_VLAN_CTAG_RX_BIT = 8,
	NETIF_F_HW_VLAN_CTAG_FILTER_BIT = 9,
	NETIF_F_VLAN_CHALLENGED_BIT = 10,
	NETIF_F_GSO_BIT = 11,
	NETIF_F_LLTX_BIT = 12,
	NETIF_F_NETNS_LOCAL_BIT = 13,
	NETIF_F_GRO_BIT = 14,
	NETIF_F_LRO_BIT = 15,
	NETIF_F_GSO_SHIFT = 16,
	NETIF_F_TSO_BIT = 16,
	NETIF_F_UFO_BIT = 17,
	NETIF_F_GSO_ROBUST_BIT = 18,
	NETIF_F_TSO_ECN_BIT = 19,
	NETIF_F_TSO6_BIT = 20,
	NETIF_F_FSO_BIT = 21,
	NETIF_F_GSO_GRE_BIT = 22,
	NETIF_F_GSO_IPIP_BIT = 23,
	NETIF_F_GSO_SIT_BIT = 24,
	NETIF_F_GSO_UDP_TUNNEL_BIT = 25,
	NETIF_F_GSO_MPLS_BIT = 26,
	NETIF_F_GSO_LAST = 26,
	NETIF_F_FCOE_CRC_BIT = 27,
	NETIF_F_SCTP_CSUM_BIT = 28,
	NETIF_F_FCOE_MTU_BIT = 29,
	NETIF_F_NTUPLE_BIT = 30,
	NETIF_F_RXHASH_BIT = 31,
	NETIF_F_RXCSUM_BIT = 32,
	NETIF_F_NOCACHE_COPY_BIT = 33,
	NETIF_F_LOOPBACK_BIT = 34,
	NETIF_F_RXFCS_BIT = 35,
	NETIF_F_RXALL_BIT = 36,
	NETIF_F_HW_VLAN_STAG_TX_BIT = 37,
	NETIF_F_HW_VLAN_STAG_RX_BIT = 38,
	NETIF_F_HW_VLAN_STAG_FILTER_BIT = 39,
	NETIF_F_BUSY_POLL_BIT = 40,
	NETIF_F_GSO_GRE_CSUM_BIT = 41,
	NETIF_F_GSO_UDP_TUNNEL_CSUM_BIT = 42,
	NETIF_F_GSO_TUNNEL_REMCSUM_BIT = 43,
	NETDEV_FEATURE_COUNT = 44,
};

struct nf_bridge_info___27 {
	atomic_t use;
	unsigned int mask;
	struct net_device___29 *physindev;
	struct net_device___29 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___27(struct sk_buff___30 **);

struct net_device_ops___27;

struct ethtool_ops___27;

struct header_ops___27;

struct netdev_rx_queue___27;

struct netdev_queue___27;

struct rtnl_link_ops___21;

struct dcbnl_rtnl_ops___27;

struct net_device___29 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___27 *netdev_ops;
	const struct ethtool_ops___27 *ethtool_ops;
	const struct header_ops___27 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___24 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___27 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___27 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___27 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___27 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___27 = 0,
		NETREG_REGISTERED___27 = 1,
		NETREG_UNREGISTERING___27 = 2,
		NETREG_UNREGISTERED___27 = 3,
		NETREG_RELEASED___27 = 4,
		NETREG_DUMMY___27 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___27 = 0,
		RTNL_LINK_INITIALIZING___27 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___29 *);
	struct netpoll_info *npinfo;
	struct net___40 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___205 dev;
	const struct attribute_group___179 *sysfs_groups[4];
	const struct rtnl_link_ops___21 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___27 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___30 {
	struct sk_buff___30 *next;
	struct sk_buff___30 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___22 *sk;
	struct net_device___29 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___30 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___27 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___27 {
	int (*get_settings)(struct net_device___29 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___29 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___29 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___29 *);
	void (*get_regs)(struct net_device___29 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___29 *);
	void (*set_msglevel)(struct net_device___29 *, u32);
	int (*nway_reset)(struct net_device___29 *);
	u32 (*get_link)(struct net_device___29 *);
	int (*get_eeprom_len)(struct net_device___29 *);
	int (*get_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___29 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___29 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___29 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___29 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___29 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___29 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___29 *);
	void (*complete)(struct net_device___29 *);
	u32 (*get_priv_flags)(struct net_device___29 *);
	int (*set_priv_flags)(struct net_device___29 *, u32);
	int (*get_sset_count)(struct net_device___29 *, int);
	int (*get_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___29 *, struct ethtool_flash *);
	int (*reset)(struct net_device___29 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___29 *);
	int (*get_rxfh_indir)(struct net_device___29 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___29 *, const u32 *);
	void (*get_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___29 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___29 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___29 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___29 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___29 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___29 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___29 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___29 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___21 {
	struct callback_head callback_head;
	struct dst_entry___21 *child;
	struct net_device___29 *dev;
	struct dst_ops___39 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___21 *path;
	struct dst_entry___21 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___30 *);
	union {
		int (*output)(struct sock___22 *, struct sk_buff___30 *);
		struct {
			int (*output)(struct sk_buff___30 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___21 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___21;

struct neigh_parms___21;

struct neigh_ops___21;

struct neighbour___21 {
	struct neighbour___21 *next;
	struct neigh_table___21 *tbl;
	struct neigh_parms___21 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___28 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___21 *, struct sk_buff___30 *);
	const struct neigh_ops___21 *ops;
	struct callback_head rcu;
	struct net_device___29 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___39 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___30 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___30 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___40 *, struct dst_entry___21 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___30 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___30 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___149 {
	void * (*start)(struct seq_file___149 *, loff_t *);
	void (*stop)(struct seq_file___149 *, void *);
	void * (*next)(struct seq_file___149 *, void *, loff_t *);
	int (*show)(struct seq_file___149 *, void *);
};

struct pernet_operations___3 {
	struct list_head list;
	int (*init)(struct net___40 *);
	void (*exit)(struct net___40 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___27 {
	int (*ieee_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___29 *);
	u8 (*setstate)(struct net_device___29 *, u8);
	void (*getpermhwaddr)(struct net_device___29 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___29 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___29 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___29 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___29 *, int, u8 *);
	void (*setpfccfg)(struct net_device___29 *, int, u8);
	void (*getpfccfg)(struct net_device___29 *, int, u8 *);
	u8 (*setall)(struct net_device___29 *);
	u8 (*getcap)(struct net_device___29 *, int, u8 *);
	int (*getnumtcs)(struct net_device___29 *, int, u8 *);
	int (*setnumtcs)(struct net_device___29 *, int, u8);
	u8 (*getpfcstate)(struct net_device___29 *);
	void (*setpfcstate)(struct net_device___29 *, u8);
	void (*getbcncfg)(struct net_device___29 *, int, u32 *);
	void (*setbcncfg)(struct net_device___29 *, int, u32);
	void (*getbcnrp)(struct net_device___29 *, int, u8 *);
	void (*setbcnrp)(struct net_device___29 *, int, u8);
	u8 (*setapp)(struct net_device___29 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___29 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___29 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___29 *, int, u8);
	u8 (*getdcbx)(struct net_device___29 *);
	u8 (*setdcbx)(struct net_device___29 *, u8);
	int (*peer_getappinfo)(struct net_device___29 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___29 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___29 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___29 *, struct cee_pfc *);
};

struct cgroupfs_root___130;

struct cgroup___130 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___130 *parent;
	struct dentry___221 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___130 *subsys[11];
	struct cgroupfs_root___130 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___223 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___130 {
	struct super_block___221 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___130 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___73 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___221 *, struct file___221 *);
	ssize_t (*read)(struct cgroup___130 *, struct cftype___73 *, struct file___221 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___130 *, struct cftype___73 *);
	s64 (*read_s64)(struct cgroup___130 *, struct cftype___73 *);
	int (*read_map)(struct cgroup___130 *, struct cftype___73 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___130 *, struct cftype___73 *, struct seq_file___149 *);
	ssize_t (*write)(struct cgroup___130 *, struct cftype___73 *, struct file___221 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___130 *, struct cftype___73 *, u64);
	int (*write_s64)(struct cgroup___130 *, struct cftype___73 *, s64);
	int (*write_string)(struct cgroup___130 *, struct cftype___73 *, const char *);
	int (*trigger)(struct cgroup___130 *, unsigned int);
	int (*release)(struct inode___221 *, struct file___221 *);
	int (*register_event)(struct cgroup___130 *, struct cftype___73 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___130 *, struct cftype___73 *, struct eventfd_ctx *);
};

struct cftype_set___69 {
	struct list_head node;
	struct cftype___73 *cfts;
};

struct task_and_cgroup___69 {
	struct task_struct___222 *task;
	struct cgroup___130 *cgrp;
	struct css_set___130 *cg;
};

struct cgroup_taskset___69 {
	struct task_and_cgroup___69 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___130 *cur_cgrp;
};

struct cgroup_subsys___69 {
	struct cgroup_subsys_state___130 * (*css_alloc)(struct cgroup___130 *);
	int (*css_online)(struct cgroup___130 *);
	void (*css_offline)(struct cgroup___130 *);
	void (*css_free)(struct cgroup___130 *);
	int (*can_attach)(struct cgroup___130 *, struct cgroup_taskset___69 *);
	void (*cancel_attach)(struct cgroup___130 *, struct cgroup_taskset___69 *);
	void (*attach)(struct cgroup___130 *, struct cgroup_taskset___69 *);
	void (*fork)(struct task_struct___222 *);
	void (*exit)(struct cgroup___130 *, struct cgroup___130 *, struct task_struct___222 *);
	void (*bind)(struct cgroup___130 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___130 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___73 *base_cftypes;
	struct cftype_set___69 base_cftset;
	struct module___127 *module;
};

struct request_sock_ops___13;

struct request_sock___14 {
	struct sock_common___21 __req_common;
	struct request_sock___14 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___13 *rsk_ops;
	struct sock___22 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___28 {
	struct sk_buff___30 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___30 *, struct netlink_callback___28 *);
	int (*done)(struct netlink_callback___28 *);
	void *data;
	struct module___127 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___27 {
	int (*create)(struct sk_buff___30 *, struct net_device___29 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___30 *, unsigned char *);
	int (*rebuild)(struct sk_buff___30 *);
	int (*cache)(const struct neighbour___21 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___29 *, const unsigned char *);
};

struct napi_struct___27 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___27 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___29 *dev;
	struct sk_buff___30 *gro_list;
	struct sk_buff___30 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___27 {
	struct net_device___29 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___24 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___27 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___24 kobj;
	struct net_device___29 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___27 {
	int (*ndo_init)(struct net_device___29 *);
	void (*ndo_uninit)(struct net_device___29 *);
	int (*ndo_open)(struct net_device___29 *);
	int (*ndo_stop)(struct net_device___29 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___30 *, struct net_device___29 *);
	u16 (*ndo_select_queue)(struct net_device___29 *, struct sk_buff___30 *);
	void (*ndo_change_rx_flags)(struct net_device___29 *, int);
	void (*ndo_set_rx_mode)(struct net_device___29 *);
	int (*ndo_set_mac_address)(struct net_device___29 *, void *);
	int (*ndo_validate_addr)(struct net_device___29 *);
	int (*ndo_do_ioctl)(struct net_device___29 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___29 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___29 *, int);
	int (*ndo_neigh_setup)(struct net_device___29 *, struct neigh_parms___21 *);
	void (*ndo_tx_timeout)(struct net_device___29 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___29 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___29 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___29 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___29 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___29 *);
	int (*ndo_netpoll_setup)(struct net_device___29 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___29 *);
	int (*ndo_busy_poll)(struct napi_struct___27 *);
	int (*ndo_set_vf_mac)(struct net_device___29 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___29 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___29 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___29 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___29 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___29 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___29 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___29 *, int, struct sk_buff___30 *);
	int (*ndo_setup_tc)(struct net_device___29 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___29 *);
	int (*ndo_fcoe_disable)(struct net_device___29 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___29 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___29 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___29 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___29 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___29 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___29 *, const struct sk_buff___30 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___29 *, struct net_device___29 *);
	int (*ndo_del_slave)(struct net_device___29 *, struct net_device___29 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___21 *);
	void (*ndo_neigh_destroy)(struct neighbour___21 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___30 *, struct netlink_callback___28 *, struct net_device___29 *, int);
	int (*ndo_bridge_setlink)(struct net_device___29 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___30 *, u32, u32, struct net_device___29 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___29 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___29 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___29 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___29 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___29 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___29 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___30 *, struct net_device___29 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___29 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___29 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___29 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___21 {
	struct net___40 *net;
	struct net_device___29 *dev;
	struct neigh_parms___21 *next;
	int (*neigh_setup)(struct neighbour___21 *);
	void (*neigh_cleanup)(struct neighbour___21 *);
	struct neigh_table___21 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

enum netdev_priv_flags {
	IFF_802_1Q_VLAN = 1,
	IFF_EBRIDGE = 2,
	IFF_SLAVE_INACTIVE = 4,
	IFF_MASTER_8023AD = 8,
	IFF_MASTER_ALB = 16,
	IFF_BONDING = 32,
	IFF_SLAVE_NEEDARP = 64,
	IFF_ISATAP = 128,
	IFF_MASTER_ARPMON = 256,
	IFF_WAN_HDLC = 512,
	IFF_XMIT_DST_RELEASE = 1024,
	IFF_DONT_BRIDGE = 2048,
	IFF_DISABLE_NETPOLL = 4096,
	IFF_MACVLAN_PORT = 8192,
	IFF_BRIDGE_PORT = 16384,
	IFF_OVS_DATAPATH = 32768,
	IFF_TX_SKB_SHARING = 65536,
	IFF_UNICAST_FLT = 131072,
	IFF_TEAM_PORT = 262144,
	IFF_SUPP_NOFCS = 524288,
	IFF_LIVE_ADDR_CHANGE = 1048576,
	IFF_MACVLAN = 2097152,
	IFF_XMIT_DST_RELEASE_PERM = 4194304,
};

struct pcpu_lstats {
	u64 packets;
	u64 bytes;
	struct u64_stats_sync syncp;
};

struct rtnl_link_ops___21 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___29 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___40 *, struct net_device___29 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___29 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___29 *, struct list_head *);
	size_t (*get_size)(const struct net_device___29 *);
	int (*fill_info)(struct sk_buff___30 *, const struct net_device___29 *);
	size_t (*get_xstats_size)(const struct net_device___29 *);
	int (*fill_xstats)(struct sk_buff___30 *, const struct net_device___29 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___40 * (*get_link_net)(const struct net_device___29 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___29 *, struct net_device___29 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___29 *, const struct net_device___29 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___30 *, const struct net_device___29 *, const struct net_device___29 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___22 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___30 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___21;

struct neigh_hash_table___21;

struct neigh_table___21 {
	struct neigh_table___21 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___29 *, __u32 *);
	int (*constructor)(struct neighbour___21 *);
	int (*pconstructor)(struct pneigh_entry___21 *);
	void (*pdestructor)(struct pneigh_entry___21 *);
	void (*proxy_redo)(struct sk_buff___30 *);
	char *id;
	struct neigh_parms___21 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___28 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___21 *nht;
	struct pneigh_entry___21 **phash_buckets;
};

struct neigh_ops___21 {
	int family;
	void (*solicit)(struct neighbour___21 *, struct sk_buff___30 *);
	void (*error_report)(struct neighbour___21 *, struct sk_buff___30 *);
	int (*output)(struct neighbour___21 *, struct sk_buff___30 *);
	int (*connected_output)(struct neighbour___21 *, struct sk_buff___30 *);
};

struct pneigh_entry___21 {
	struct pneigh_entry___21 *next;
	struct net___40 *net;
	struct net_device___29 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___21 {
	struct neighbour___21 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___11;

struct proto___21 {
	void (*close)(struct sock___22 *, long int);
	int (*connect)(struct sock___22 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___22 *, int);
	struct sock___22 * (*accept)(struct sock___22 *, int, int *);
	int (*ioctl)(struct sock___22 *, int, long unsigned int);
	int (*init)(struct sock___22 *);
	void (*destroy)(struct sock___22 *);
	void (*shutdown)(struct sock___22 *, int);
	int (*setsockopt)(struct sock___22 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___22 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___22 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___22 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___22 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___29 *, struct sock___22 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___29 *, struct sock___22 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___22 *, struct page___220 *, int, size_t, int);
	int (*bind)(struct sock___22 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___22 *, struct sk_buff___30 *);
	void (*release_cb)(struct sock___22 *);
	void (*mtu_reduced)(struct sock___22 *);
	void (*hash)(struct sock___22 *);
	void (*unhash)(struct sock___22 *);
	void (*rehash)(struct sock___22 *);
	int (*get_port)(struct sock___22 *, short unsigned int);
	void (*clear_sk)(struct sock___22 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___22 *);
	void (*enter_memory_pressure)(struct sock___22 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___206 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___13 *rsk_prot;
	struct timewait_sock_ops___11 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___127 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___69 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___21 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___21 {
	void (*enter_memory_pressure)(struct sock___22 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___13 {
	int family;
	int obj_size;
	struct kmem_cache___206 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___22 *, struct request_sock___14 *);
	void (*send_ack)(struct sock___22 *, struct sk_buff___30 *, struct request_sock___14 *);
	void (*send_reset)(struct sock___22 *, struct sk_buff___30 *);
	void (*destructor)(struct request_sock___14 *);
	void (*syn_ack_timeout)(struct sock___22 *, struct request_sock___14 *);
};

struct timewait_sock_ops___11 {
	struct kmem_cache___206 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___22 *, struct sock___22 *, void *);
	void (*twsk_destructor)(struct sock___22 *);
};

struct page___221;

typedef struct page___221 *pgtable_t___221;

struct address_space___222;

struct kmem_cache___207;

struct page___221 {
	long unsigned int flags;
	struct address_space___222 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___221 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___221 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___207 *slab_cache;
		struct page___221 *first_page;
	};
	long: 64;
};

struct task_struct___223;

struct pv_cpu_ops___223 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___223 *);
	void (*end_context_switch)(struct task_struct___223 *);
};

struct mutex___224 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___223 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___216 {
	struct page___221 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___230;

struct nsproxy___115;

struct signal_struct___223;

struct css_set___131;

struct task_struct___223 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___223 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___230 *mm;
	struct mm_struct___230 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___223 *real_parent;
	struct task_struct___223 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___223 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___223 = 0,
		VTIME_USER___223 = 1,
		VTIME_SYS___223 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___115 *nsproxy;
	struct signal_struct___223 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___131 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___224 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___216 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___230 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___230 *, struct mm_struct___230 *);
	void (*dup_mmap)(struct mm_struct___230 *, struct mm_struct___230 *);
	void (*exit_mmap)(struct mm_struct___230 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___230 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___230 *);
	void (*pgd_free)(struct mm_struct___230 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___230 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___230 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___230 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___230 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___230 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___230 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___230 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___230 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___230 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___230 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___230 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___224 lock;
	void *vdso;
} mm_context_t___224;

struct xol_area___221;

struct uprobes_state___221 {
	struct xol_area___221 *xol_area;
};

struct vm_area_struct___230;

struct file___222;

struct core_state___223;

struct mm_struct___230 {
	struct vm_area_struct___230 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___230 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___230 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___224 context;
	long unsigned int flags;
	struct core_state___223 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___223 *owner;
	struct file___222 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___221 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___128;

struct module_kobject___127 {
	struct kobject___24 kobj;
	struct module___128 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___127;

struct module___128 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___127 mkobj;
	struct module_attribute___127 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___223 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct irq_data___146;

struct x86_io_apic_ops___146 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___146 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___146;

struct irq_data___146 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___146 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___206;

struct dev_pm_ops___206 {
	int (*prepare)(struct device___206 *);
	void (*complete)(struct device___206 *);
	int (*suspend)(struct device___206 *);
	int (*resume)(struct device___206 *);
	int (*freeze)(struct device___206 *);
	int (*thaw)(struct device___206 *);
	int (*poweroff)(struct device___206 *);
	int (*restore)(struct device___206 *);
	int (*suspend_late)(struct device___206 *);
	int (*resume_early)(struct device___206 *);
	int (*freeze_late)(struct device___206 *);
	int (*thaw_early)(struct device___206 *);
	int (*poweroff_late)(struct device___206 *);
	int (*restore_early)(struct device___206 *);
	int (*suspend_noirq)(struct device___206 *);
	int (*resume_noirq)(struct device___206 *);
	int (*freeze_noirq)(struct device___206 *);
	int (*thaw_noirq)(struct device___206 *);
	int (*poweroff_noirq)(struct device___206 *);
	int (*restore_noirq)(struct device___206 *);
	int (*runtime_suspend)(struct device___206 *);
	int (*runtime_resume)(struct device___206 *);
	int (*runtime_idle)(struct device___206 *);
};

struct dev_pm_qos___35;

struct dev_pm_info___35 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___35 *qos;
};

struct dma_map_ops___89;

struct dev_archdata___89 {
	struct dma_map_ops___89 *dma_ops;
	void *iommu;
};

struct device_type___206;

struct bus_type___206;

struct device_driver___206;

struct dev_pm_domain___206;

struct class___206;

struct attribute_group___180;

struct device_rh___206;

struct device___206 {
	struct device___206 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___206 *type;
	struct mutex___224 mutex;
	struct bus_type___206 *bus;
	struct device_driver___206 *driver;
	void *platform_data;
	struct dev_pm_info___35 power;
	struct dev_pm_domain___206 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___89 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___206 *class;
	const struct attribute_group___180 **groups;
	void (*release)(struct device___206 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___206 *device_rh;
};

struct dev_pm_qos_request___35;

struct dev_pm_qos___35 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___35 *latency_req;
	struct dev_pm_qos_request___35 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___35 *latency_tolerance_req;
};

struct dev_pm_info_rh___206 {
	void (*set_latency_tolerance)(struct device___206 *, s32);
};

struct dev_pm_domain___206 {
	struct dev_pm_ops___206 ops;
};

struct smp_ops___223 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___223 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___223;

struct lruvec___223 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___223 *zone;
};

struct pglist_data___223;

struct zone___223 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___223 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___223 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___223 {
	struct zone___223 *zone;
	int zone_idx;
};

struct zonelist___223 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___223 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___223 {
	struct zone___223 node_zones[4];
	struct zonelist___223 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___223 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___150;

struct irq_chip___146 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___146 *);
	void (*irq_shutdown)(struct irq_data___146 *);
	void (*irq_enable)(struct irq_data___146 *);
	void (*irq_disable)(struct irq_data___146 *);
	void (*irq_ack)(struct irq_data___146 *);
	void (*irq_mask)(struct irq_data___146 *);
	void (*irq_mask_ack)(struct irq_data___146 *);
	void (*irq_unmask)(struct irq_data___146 *);
	void (*irq_eoi)(struct irq_data___146 *);
	int (*irq_set_affinity)(struct irq_data___146 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___146 *);
	int (*irq_set_type)(struct irq_data___146 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___146 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___146 *);
	void (*irq_bus_sync_unlock)(struct irq_data___146 *);
	void (*irq_cpu_online)(struct irq_data___146 *);
	void (*irq_cpu_offline)(struct irq_data___146 *);
	void (*irq_suspend)(struct irq_data___146 *);
	void (*irq_resume)(struct irq_data___146 *);
	void (*irq_pm_shutdown)(struct irq_data___146 *);
	void (*irq_print_chip)(struct irq_data___146 *, struct seq_file___150 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___146 *, void *);
	long unsigned int flags;
};

struct seq_operations___150;

struct seq_file___150 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___224 lock;
	const struct seq_operations___150 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct inode___222;

struct file_lock___222;

struct file_operations___222 {
	struct module___128 *owner;
	loff_t (*llseek)(struct file___222 *, loff_t, int);
	ssize_t (*read)(struct file___222 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___222 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___222 *, void *, filldir_t);
	unsigned int (*poll)(struct file___222 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___222 *, struct vm_area_struct___230 *);
	int (*open)(struct inode___222 *, struct file___222 *);
	int (*flush)(struct file___222 *, fl_owner_t);
	int (*release)(struct inode___222 *, struct file___222 *);
	int (*fsync)(struct file___222 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___222 *, int);
	int (*lock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*sendpage)(struct file___222 *, struct page___221 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___222 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___222 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___222 *, long int, struct file_lock___222 **, void **);
		struct {
			int (*setlease)(struct file___222 *, long int, struct file_lock___222 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___222 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___150 *, struct file___222 *);
};

struct bin_attribute___182;

struct attribute_group___180 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___182 **bin_attrs;
};

struct bin_attribute___182 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___222 *, struct kobject___24 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___222 *, struct kobject___24 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	int (*mmap)(struct file___222 *, struct kobject___24 *, struct bin_attribute___182 *, struct vm_area_struct___230 *);
};

struct dentry___222;

struct path___222 {
	struct vfsmount *mnt;
	struct dentry___222 *dentry;
};

struct file___222 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___222 f_path;
	struct inode___222 *f_inode;
	const struct file_operations___222 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___222 *f_mapping;
	struct mutex___224 f_pos_lock;
};

struct vm_operations_struct___202;

struct vm_area_struct___230 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___230 *vm_next;
	struct vm_area_struct___230 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___230 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___202 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___222 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dma_map_ops___89 {
	void * (*alloc)(struct device___206 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___206 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___206 *, struct vm_area_struct___230 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___206 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___206 *, struct page___221 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___206 *, dma_addr_t);
	int (*dma_supported)(struct device___206 *, u64);
	int (*set_dma_mask)(struct device___206 *, u64);
	int is_phys;
};

struct bus_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___206 *, char *);
	ssize_t (*store)(struct bus_type___206 *, const char *, size_t);
};

struct device_attribute___206;

struct driver_attribute___206;

struct bus_type___206 {
	const char *name;
	const char *dev_name;
	struct device___206 *dev_root;
	struct bus_attribute___206 *bus_attrs;
	struct device_attribute___206 *dev_attrs;
	struct driver_attribute___206 *drv_attrs;
	const struct attribute_group___180 **bus_groups;
	const struct attribute_group___180 **dev_groups;
	const struct attribute_group___180 **drv_groups;
	int (*match)(struct device___206 *, struct device_driver___206 *);
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	int (*probe)(struct device___206 *);
	int (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*online)(struct device___206 *);
	int (*offline)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct device___206 *, struct device_attribute___206 *, char *);
	ssize_t (*store)(struct device___206 *, struct device_attribute___206 *, const char *, size_t);
};

struct driver_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___206 *, char *);
	ssize_t (*store)(struct device_driver___206 *, const char *, size_t);
};

struct device_driver___206 {
	const char *name;
	struct bus_type___206 *bus;
	struct module___128 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___206 *);
	int (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	const struct attribute_group___180 **groups;
	const struct dev_pm_ops___206 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___206 {
	const char *name;
	const struct attribute_group___180 **groups;
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
};

struct class_attribute___206;

struct class___206 {
	const char *name;
	struct module___128 *owner;
	struct class_attribute___206 *class_attrs;
	struct device_attribute___206 *dev_attrs;
	const struct attribute_group___180 **dev_groups;
	struct bin_attribute___182 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *);
	void (*class_release)(struct class___206 *);
	void (*dev_release)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
	struct subsys_private *p;
};

struct class_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct class___206 *, struct class_attribute___206 *, char *);
	ssize_t (*store)(struct class___206 *, struct class_attribute___206 *, const char *, size_t);
	const void * (*namespace)(struct class___206 *, const struct class_attribute___206 *);
};

struct device_rh___206 {
	struct dev_pm_info_rh___206 power;
};

struct dev_pm_qos_request___35 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___206 *dev;
};

struct xol_area___221 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___221 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___206;

struct memcg_cache_params___207;

struct kmem_cache___207 {
	struct kmem_cache_cpu___206 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___207 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___222;

struct address_space___222 {
	struct inode___222 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___224 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___222 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___198;

struct vm_operations_struct___202 {
	void (*open)(struct vm_area_struct___230 *);
	void (*close)(struct vm_area_struct___230 *);
	int (*fault)(struct vm_area_struct___230 *, struct vm_fault___198 *);
	int (*page_mkwrite)(struct vm_area_struct___230 *, struct vm_fault___198 *);
	int (*access)(struct vm_area_struct___230 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___230 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___230 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___230 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___230 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___223 {
	struct task_struct___223 *task;
	struct core_thread___223 *next;
};

struct core_state___223 {
	atomic_t nr_threads;
	struct core_thread___223 dumper;
	struct completion startup;
};

struct vm_fault___198 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___221 *page;
};

struct dentry_operations___222;

struct super_block___222;

struct dentry___222 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___222 *d_parent;
	struct qstr d_name;
	struct inode___222 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___222 *d_op;
	struct super_block___222 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___222;

struct dquot___222;

struct block_device___222;

struct inode___222 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___222 *i_op;
	struct super_block___222 *i_sb;
	struct address_space___222 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___224 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___222 *i_fop;
	struct file_lock___222 *i_flock;
	struct address_space___222 i_data;
	struct dquot___222 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___222 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___222 {
	int (*d_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_hash)(const struct dentry___222 *, struct qstr *);
	int (*d_compare)(const struct dentry___222 *, const struct dentry___222 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___222 *);
	void (*d_release)(struct dentry___222 *);
	void (*d_prune)(struct dentry___222 *);
	void (*d_iput)(struct dentry___222 *, struct inode___222 *);
	char * (*d_dname)(struct dentry___222 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___222 *);
	int (*d_manage)(struct dentry___222 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___222;

struct mem_dqinfo___222 {
	struct quota_format_type___222 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___222;

struct quota_info___222 {
	unsigned int flags;
	struct mutex___224 dqio_mutex;
	struct mutex___224 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___222 *files[2];
	struct mem_dqinfo___222 info[2];
	const struct quota_format_ops___222 *ops[2];
};

struct file_system_type___222;

struct super_operations___222;

struct dquot_operations___222;

struct quotactl_ops___222;

struct xattr_handler___132;

struct super_block___222 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___222 *s_type;
	const struct super_operations___222 *s_op;
	const struct dquot_operations___222 *dq_op;
	const struct quotactl_ops___222 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___222 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___132 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___222 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___222 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___224 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___222 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___222 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___222 *bd_inode;
	struct super_block___222 *bd_super;
	struct mutex___224 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___222 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___224 bd_fsfreeze_mutex;
};

struct cgroup___131;

struct cgroup_subsys_state___131 {
	struct cgroup___131 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___222 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___222 *ia_file;
};

struct dquot___222 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___224 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___222 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___222 {
	int qf_fmt_id;
	const struct quota_format_ops___222 *qf_ops;
	struct module___128 *qf_owner;
	struct quota_format_type___222 *qf_next;
};

struct quota_format_ops___222 {
	int (*check_quota_file)(struct super_block___222 *, int);
	int (*read_file_info)(struct super_block___222 *, int);
	int (*write_file_info)(struct super_block___222 *, int);
	int (*free_file_info)(struct super_block___222 *, int);
	int (*read_dqblk)(struct dquot___222 *);
	int (*commit_dqblk)(struct dquot___222 *);
	int (*release_dqblk)(struct dquot___222 *);
};

struct dquot_operations___222 {
	int (*write_dquot)(struct dquot___222 *);
	struct dquot___222 * (*alloc_dquot)(struct super_block___222 *, int);
	void (*destroy_dquot)(struct dquot___222 *);
	int (*acquire_dquot)(struct dquot___222 *);
	int (*release_dquot)(struct dquot___222 *);
	int (*mark_dirty)(struct dquot___222 *);
	int (*write_info)(struct super_block___222 *, int);
	qsize_t * (*get_reserved_space)(struct inode___222 *);
};

struct quotactl_ops___222 {
	int (*quota_on)(struct super_block___222 *, int, int, struct path___222 *);
	int (*quota_on_meta)(struct super_block___222 *, int, int);
	int (*quota_off)(struct super_block___222 *, int);
	int (*quota_sync)(struct super_block___222 *, int);
	int (*get_info)(struct super_block___222 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___222 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___222 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___222 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___222 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___222 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___222 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___222 *, unsigned int);
};

struct address_space_operations___222 {
	int (*writepage)(struct page___221 *, struct writeback_control *);
	int (*readpage)(struct file___222 *, struct page___221 *);
	int (*writepages)(struct address_space___222 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___221 *);
	int (*readpages)(struct file___222 *, struct address_space___222 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___222 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___221 **, void **);
	int (*write_end)(struct file___222 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___221 *, void *);
	sector_t (*bmap)(struct address_space___222 *, sector_t);
	void (*invalidatepage)(struct page___221 *, long unsigned int);
	int (*releasepage)(struct page___221 *, gfp_t);
	void (*freepage)(struct page___221 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___222 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___222 *, struct page___221 *, struct page___221 *, enum migrate_mode);
	int (*launder_page)(struct page___221 *);
	int (*is_partially_uptodate)(struct page___221 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___221 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___222 *, struct page___221 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___222 *, sector_t *);
	void (*swap_deactivate)(struct file___222 *);
	void (*invalidatepage_range)(struct page___221 *, unsigned int, unsigned int);
};

struct inode_operations___222 {
	struct dentry___222 * (*lookup)(struct inode___222 *, struct dentry___222 *, unsigned int);
	void * (*follow_link)(struct dentry___222 *, struct nameidata *);
	int (*permission)(struct inode___222 *, int);
	struct posix_acl * (*get_acl)(struct inode___222 *, int);
	int (*readlink)(struct dentry___222 *, char *, int);
	void (*put_link)(struct dentry___222 *, struct nameidata *, void *);
	int (*create)(struct inode___222 *, struct dentry___222 *, umode_t, bool);
	int (*link)(struct dentry___222 *, struct inode___222 *, struct dentry___222 *);
	int (*unlink)(struct inode___222 *, struct dentry___222 *);
	int (*symlink)(struct inode___222 *, struct dentry___222 *, const char *);
	int (*mkdir)(struct inode___222 *, struct dentry___222 *, umode_t);
	int (*rmdir)(struct inode___222 *, struct dentry___222 *);
	int (*mknod)(struct inode___222 *, struct dentry___222 *, umode_t, dev_t);
	int (*rename)(struct inode___222 *, struct dentry___222 *, struct inode___222 *, struct dentry___222 *);
	int (*setattr)(struct dentry___222 *, struct iattr___222 *);
	int (*getattr)(struct vfsmount *, struct dentry___222 *, struct kstat *);
	int (*setxattr)(struct dentry___222 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___222 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___222 *, char *, size_t);
	int (*removexattr)(struct dentry___222 *, const char *);
	int (*fiemap)(struct inode___222 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___222 *, struct timespec *, int);
	int (*atomic_open)(struct inode___222 *, struct dentry___222 *, struct file___222 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___222;

struct file_lock_operations___222;

struct lock_manager_operations___222;

struct file_lock___222 {
	struct file_lock___222 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___222 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___222 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___222 *fl_ops;
	const struct lock_manager_operations___222 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___222 {
	void (*fl_copy_lock)(struct file_lock___222 *, struct file_lock___222 *);
	void (*fl_release_private)(struct file_lock___222 *);
};

struct lock_manager_operations___222 {
	int (*lm_compare_owner)(struct file_lock___222 *, struct file_lock___222 *);
	long unsigned int (*lm_owner_key)(struct file_lock___222 *);
	void (*lm_notify)(struct file_lock___222 *);
	int (*lm_grant)(struct file_lock___222 *, struct file_lock___222 *, int);
	void (*lm_break)(struct file_lock___222 *);
	int (*lm_change)(struct file_lock___222 **, int);
};

struct fasync_struct___222 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___222 *fa_next;
	struct file___222 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___222 {
	const char *name;
	int fs_flags;
	struct dentry___222 * (*mount)(struct file_system_type___222 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___222 *);
	struct module___128 *owner;
	struct file_system_type___222 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___222 {
	struct inode___222 * (*alloc_inode)(struct super_block___222 *);
	void (*destroy_inode)(struct inode___222 *);
	void (*dirty_inode)(struct inode___222 *, int);
	int (*write_inode)(struct inode___222 *, struct writeback_control *);
	int (*drop_inode)(struct inode___222 *);
	void (*evict_inode)(struct inode___222 *);
	void (*put_super)(struct super_block___222 *);
	int (*sync_fs)(struct super_block___222 *, int);
	int (*freeze_fs)(struct super_block___222 *);
	int (*unfreeze_fs)(struct super_block___222 *);
	int (*statfs)(struct dentry___222 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___222 *, int *, char *);
	void (*umount_begin)(struct super_block___222 *);
	int (*show_options)(struct seq_file___150 *, struct dentry___222 *);
	int (*show_devname)(struct seq_file___150 *, struct dentry___222 *);
	int (*show_path)(struct seq_file___150 *, struct dentry___222 *);
	int (*show_stats)(struct seq_file___150 *, struct dentry___222 *);
	ssize_t (*quota_read)(struct super_block___222 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___222 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___222 *);
	int (*bdev_try_to_free_page)(struct super_block___222 *, struct page___221 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___222 *);
	void (*free_cached_objects)(struct super_block___222 *, int);
};

struct xattr_handler___132 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___222 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___222 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___222 *, const char *, const void *, size_t, int, int);
};

struct ctl_table_header___42;

struct ctl_node___42 {
	struct rb_node node;
	struct ctl_table_header___42 *header;
};

struct ctl_table_root___42;

struct ctl_table_set___42;

struct ctl_dir___42;

struct ctl_table_header___42 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___42 *root;
	struct ctl_table_set___42 *set;
	struct ctl_dir___42 *parent;
	struct ctl_node___42 *node;
};

struct ctl_dir___42 {
	struct ctl_table_header___42 header;
	struct rb_root root;
};

struct ctl_table_set___42 {
	int (*is_seen)(struct ctl_table_set___42 *);
	struct ctl_dir___42 dir;
};

struct ctl_table_root___42 {
	struct ctl_table_set___42 default_set;
	struct ctl_table_set___42 * (*lookup)(struct ctl_table_root___42 *, struct nsproxy___115 *);
	int (*permissions)(struct ctl_table_header___42 *, struct ctl_table *);
};

struct net___41;

struct nsproxy___115 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___41 *net_ns;
};

struct signal_struct___223 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___223 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___223 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___224 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___131 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___131 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___39 {
	struct ctl_table_header___42 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___39 {
	struct mutex___224 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___39 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___42 *ctl;
};

struct netns_ipv4___39 {
	struct ctl_table_header___42 *forw_hdr;
	struct ctl_table_header___42 *frags_hdr;
	struct ctl_table_header___42 *ipv4_hdr;
	struct ctl_table_header___42 *route_hdr;
	struct ctl_table_header___42 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___39 {
	struct ctl_table_header___42 *hdr;
	struct ctl_table_header___42 *route_hdr;
	struct ctl_table_header___42 *icmp_hdr;
	struct ctl_table_header___42 *frags_hdr;
	struct ctl_table_header___42 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___30;

struct sk_buff___31;

struct dst_ops___40 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___40 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___30 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___31 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___31 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___31 *);
	int (*local_out)(struct sk_buff___31 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___31 *, const void *);
	struct kmem_cache___207 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___40 {
	struct netns_sysctl_ipv6___39 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___40 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___39 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___42 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___39 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___42 *nf_log_dir_header;
};

struct nf_proto_net___39 {
	struct ctl_table_header___42 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___39 {
	struct nf_proto_net___39 pn;
	unsigned int timeout;
};

struct nf_tcp_net___39 {
	struct nf_proto_net___39 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___39 {
	struct nf_proto_net___39 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___39 {
	struct nf_proto_net___39 pn;
	unsigned int timeout;
};

struct nf_ip_net___39 {
	struct nf_generic_net___39 generic;
	struct nf_tcp_net___39 tcp;
	struct nf_udp_net___39 udp;
	struct nf_icmp_net___39 icmp;
	struct nf_icmp_net___39 icmpv6;
};

struct netns_ct___39 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___42 *sysctl_header;
	struct ctl_table_header___42 *acct_sysctl_header;
	struct ctl_table_header___42 *tstamp_sysctl_header;
	struct ctl_table_header___42 *event_sysctl_header;
	struct ctl_table_header___42 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___207 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___39 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___39 {
	struct netns_sysctl_ipv6___39 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___29 {
	struct sk_buff___31 *next;
	struct sk_buff___31 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___40 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___42 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___40 xfrm4_dst_ops;
	struct dst_ops___40 xfrm6_dst_ops;
};

struct net___41 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___42 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___30 *loopback_dev;
	struct netns_core___39 core;
	struct netns_mib mib;
	struct netns_packet___39 packet;
	struct netns_unix___39 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___39 ipv4;
	struct netns_ipv6___40 ipv6;
	struct netns_sctp___39 sctp;
	struct netns_dccp___21 dccp;
	struct netns_nf___39 nf;
	struct netns_xt xt;
	struct netns_ct___39 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___39 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___29 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___40 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___224 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___224 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___206 {
	void **freelist;
	long unsigned int tid;
	struct page___221 *page;
	struct page___221 *partial;
};

struct memcg_cache_params___207 {
	bool is_root_cache;
	union {
		struct kmem_cache___207 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___207 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___28 {
	atomic_t use;
	unsigned int mask;
	struct net_device___30 *physindev;
	struct net_device___30 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___28(struct sk_buff___31 **);

struct net_device_ops___28;

struct ethtool_ops___28;

struct header_ops___28;

struct netdev_rx_queue___28;

struct netdev_queue___28;

struct dcbnl_rtnl_ops___28;

struct phy_device___2;

struct net_device___30 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___28 *netdev_ops;
	const struct ethtool_ops___28 *ethtool_ops;
	const struct header_ops___28 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___24 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___28 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___28 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___28 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___28 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___28 = 0,
		NETREG_REGISTERED___28 = 1,
		NETREG_UNREGISTERING___28 = 2,
		NETREG_UNREGISTERED___28 = 3,
		NETREG_RELEASED___28 = 4,
		NETREG_DUMMY___28 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___28 = 0,
		RTNL_LINK_INITIALIZING___28 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___30 *);
	struct netpoll_info *npinfo;
	struct net___41 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___206 dev;
	const struct attribute_group___180 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___28 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___2 *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___31 {
	struct sk_buff___31 *next;
	struct sk_buff___31 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___30 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___31 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___28 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___28 {
	int (*get_settings)(struct net_device___30 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___30 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___30 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___30 *);
	void (*get_regs)(struct net_device___30 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___30 *);
	void (*set_msglevel)(struct net_device___30 *, u32);
	int (*nway_reset)(struct net_device___30 *);
	u32 (*get_link)(struct net_device___30 *);
	int (*get_eeprom_len)(struct net_device___30 *);
	int (*get_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___30 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___30 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___30 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___30 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___30 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___30 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___30 *);
	void (*complete)(struct net_device___30 *);
	u32 (*get_priv_flags)(struct net_device___30 *);
	int (*set_priv_flags)(struct net_device___30 *, u32);
	int (*get_sset_count)(struct net_device___30 *, int);
	int (*get_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___30 *, struct ethtool_flash *);
	int (*reset)(struct net_device___30 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___30 *);
	int (*get_rxfh_indir)(struct net_device___30 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___30 *, const u32 *);
	void (*get_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___30 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___30 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___30 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___30 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___30 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___30 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___30 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___30 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___40 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___31 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___31 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___41 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___31 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___31 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___150 {
	void * (*start)(struct seq_file___150 *, loff_t *);
	void (*stop)(struct seq_file___150 *, void *);
	void * (*next)(struct seq_file___150 *, void *, loff_t *);
	int (*show)(struct seq_file___150 *, void *);
};

struct mii_bus {
	const char *name;
	char id[17];
	void *priv;
	int (*read)(struct mii_bus *, int, int);
	int (*write)(struct mii_bus *, int, int, u16);
	int (*reset)(struct mii_bus *);
	struct mutex___224 mdio_lock;
	struct device___206 *parent;
	enum {
		MDIOBUS_ALLOCATED = 1,
		MDIOBUS_REGISTERED = 2,
		MDIOBUS_UNREGISTERED = 3,
		MDIOBUS_RELEASED = 4,
	} state;
	struct device___206 dev;
	struct phy_device___2 *phy_map[32];
	u32 phy_mask;
	int *irq;
};

struct dcbnl_rtnl_ops___28 {
	int (*ieee_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___30 *);
	u8 (*setstate)(struct net_device___30 *, u8);
	void (*getpermhwaddr)(struct net_device___30 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___30 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___30 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___30 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___30 *, int, u8 *);
	void (*setpfccfg)(struct net_device___30 *, int, u8);
	void (*getpfccfg)(struct net_device___30 *, int, u8 *);
	u8 (*setall)(struct net_device___30 *);
	u8 (*getcap)(struct net_device___30 *, int, u8 *);
	int (*getnumtcs)(struct net_device___30 *, int, u8 *);
	int (*setnumtcs)(struct net_device___30 *, int, u8);
	u8 (*getpfcstate)(struct net_device___30 *);
	void (*setpfcstate)(struct net_device___30 *, u8);
	void (*getbcncfg)(struct net_device___30 *, int, u32 *);
	void (*setbcncfg)(struct net_device___30 *, int, u32);
	void (*getbcnrp)(struct net_device___30 *, int, u8 *);
	void (*setbcnrp)(struct net_device___30 *, int, u8);
	u8 (*setapp)(struct net_device___30 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___30 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___30 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___30 *, int, u8);
	u8 (*getdcbx)(struct net_device___30 *);
	u8 (*setdcbx)(struct net_device___30 *, u8);
	int (*peer_getappinfo)(struct net_device___30 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___30 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___30 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___30 *, struct cee_pfc *);
};

struct cgroupfs_root___131;

struct cgroup___131 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___131 *parent;
	struct dentry___222 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___131 *subsys[11];
	struct cgroupfs_root___131 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___224 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___131 {
	struct super_block___222 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___131 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___29 {
	struct sk_buff___31 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___31 *, struct netlink_callback___29 *);
	int (*done)(struct netlink_callback___29 *);
	void *data;
	struct module___128 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___28 {
	int (*create)(struct sk_buff___31 *, struct net_device___30 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___31 *, unsigned char *);
	int (*rebuild)(struct sk_buff___31 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___30 *, const unsigned char *);
};

struct napi_struct___28 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___28 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___30 *dev;
	struct sk_buff___31 *gro_list;
	struct sk_buff___31 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___28 {
	struct net_device___30 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___24 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___28 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___24 kobj;
	struct net_device___30 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___28 {
	int (*ndo_init)(struct net_device___30 *);
	void (*ndo_uninit)(struct net_device___30 *);
	int (*ndo_open)(struct net_device___30 *);
	int (*ndo_stop)(struct net_device___30 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___31 *, struct net_device___30 *);
	u16 (*ndo_select_queue)(struct net_device___30 *, struct sk_buff___31 *);
	void (*ndo_change_rx_flags)(struct net_device___30 *, int);
	void (*ndo_set_rx_mode)(struct net_device___30 *);
	int (*ndo_set_mac_address)(struct net_device___30 *, void *);
	int (*ndo_validate_addr)(struct net_device___30 *);
	int (*ndo_do_ioctl)(struct net_device___30 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___30 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___30 *, int);
	int (*ndo_neigh_setup)(struct net_device___30 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___30 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___30 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___30 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___30 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___30 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___30 *);
	int (*ndo_netpoll_setup)(struct net_device___30 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___30 *);
	int (*ndo_busy_poll)(struct napi_struct___28 *);
	int (*ndo_set_vf_mac)(struct net_device___30 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___30 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___30 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___30 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___30 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___30 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___30 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___30 *, int, struct sk_buff___31 *);
	int (*ndo_setup_tc)(struct net_device___30 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___30 *);
	int (*ndo_fcoe_disable)(struct net_device___30 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___30 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___30 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___30 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___30 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___30 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___30 *, const struct sk_buff___31 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___30 *, struct net_device___30 *);
	int (*ndo_del_slave)(struct net_device___30 *, struct net_device___30 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___31 *, struct netlink_callback___29 *, struct net_device___30 *, int);
	int (*ndo_bridge_setlink)(struct net_device___30 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___31 *, u32, u32, struct net_device___30 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___30 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___30 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___30 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___30 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___30 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___30 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___31 *, struct net_device___30 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___30 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___30 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___30 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct phy_c45_device_ids {
	u32 devices_in_package;
	u32 device_ids[8];
};

enum phy_state {
	PHY_DOWN = 0,
	PHY_STARTING = 1,
	PHY_READY = 2,
	PHY_PENDING = 3,
	PHY_UP = 4,
	PHY_AN = 5,
	PHY_RUNNING = 6,
	PHY_NOLINK = 7,
	PHY_FORCING = 8,
	PHY_CHANGELINK = 9,
	PHY_HALTED = 10,
	PHY_RESUMING = 11,
};

typedef enum {
	PHY_INTERFACE_MODE_NA = 0,
	PHY_INTERFACE_MODE_MII = 1,
	PHY_INTERFACE_MODE_GMII = 2,
	PHY_INTERFACE_MODE_SGMII = 3,
	PHY_INTERFACE_MODE_TBI = 4,
	PHY_INTERFACE_MODE_RMII = 5,
	PHY_INTERFACE_MODE_RGMII = 6,
	PHY_INTERFACE_MODE_RGMII_ID = 7,
	PHY_INTERFACE_MODE_RGMII_RXID = 8,
	PHY_INTERFACE_MODE_RGMII_TXID = 9,
	PHY_INTERFACE_MODE_RTBI = 10,
	PHY_INTERFACE_MODE_SMII = 11,
} phy_interface_t;

struct phy_driver;

struct phy_device___2 {
	struct phy_driver *drv;
	struct mii_bus *bus;
	struct device___206 dev;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	bool is_c45;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int addr;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	int link;
	u32 interrupts;
	u32 supported;
	u32 advertising;
	int autoneg;
	int link_timeout;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	atomic_t irq_disable;
	struct mutex___224 lock;
	struct net_device___30 *attached_dev;
	void (*adjust_link)(struct net_device___30 *);
	void (*adjust_state)(struct net_device___30 *);
};

struct module_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___127 *, struct module_kobject___127 *, char *);
	ssize_t (*store)(struct module_attribute___127 *, struct module_kobject___127 *, const char *, size_t);
	void (*setup)(struct module___128 *, const char *);
	int (*test)(struct module___128 *);
	void (*free)(struct module___128 *);
};

struct mii_ioctl_data {
	__u16 phy_id;
	__u16 reg_num;
	__u16 val_in;
	__u16 val_out;
};

struct phy_driver {
	u32 phy_id;
	char *name;
	unsigned int phy_id_mask;
	u32 features;
	u32 flags;
	int (*config_init)(struct phy_device___2 *);
	int (*probe)(struct phy_device___2 *);
	int (*suspend)(struct phy_device___2 *);
	int (*resume)(struct phy_device___2 *);
	int (*config_aneg)(struct phy_device___2 *);
	int (*read_status)(struct phy_device___2 *);
	int (*ack_interrupt)(struct phy_device___2 *);
	int (*config_intr)(struct phy_device___2 *);
	int (*did_interrupt)(struct phy_device___2 *);
	void (*remove)(struct phy_device___2 *);
	int (*match_phy_device)(struct phy_device___2 *);
	int (*ts_info)(struct phy_device___2 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___2 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___2 *, struct sk_buff___31 *, int);
	void (*txtstamp)(struct phy_device___2 *, struct sk_buff___31 *, int);
	int (*set_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	struct device_driver___206 driver;
};

struct phy_setting {
	int speed;
	int duplex;
	u32 setting;
};

struct mii_bus___2 {
	const char *name;
	char id[17];
	void *priv;
	int (*read)(struct mii_bus___2 *, int, int);
	int (*write)(struct mii_bus___2 *, int, int, u16);
	int (*reset)(struct mii_bus___2 *);
	struct mutex___209 mdio_lock;
	struct device___186 *parent;
	enum {
		MDIOBUS_ALLOCATED___2 = 1,
		MDIOBUS_REGISTERED___2 = 2,
		MDIOBUS_UNREGISTERED___2 = 3,
		MDIOBUS_RELEASED___2 = 4,
	} state;
	struct device___186 dev;
	struct phy_device *phy_map[32];
	u32 phy_mask;
	int *irq;
};

struct phy_driver___2;

struct phy_device {
	struct phy_driver___2 *drv;
	struct mii_bus___2 *bus;
	struct device___186 dev;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	bool is_c45;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int addr;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	int link;
	u32 interrupts;
	u32 supported;
	u32 advertising;
	int autoneg;
	int link_timeout;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	atomic_t irq_disable;
	struct mutex___209 lock;
	struct net_device___26 *attached_dev;
	void (*adjust_link)(struct net_device___26 *);
	void (*adjust_state)(struct net_device___26 *);
};

struct phy_driver___2 {
	u32 phy_id;
	char *name;
	unsigned int phy_id_mask;
	u32 features;
	u32 flags;
	int (*config_init)(struct phy_device *);
	int (*probe)(struct phy_device *);
	int (*suspend)(struct phy_device *);
	int (*resume)(struct phy_device *);
	int (*config_aneg)(struct phy_device *);
	int (*read_status)(struct phy_device *);
	int (*ack_interrupt)(struct phy_device *);
	int (*config_intr)(struct phy_device *);
	int (*did_interrupt)(struct phy_device *);
	void (*remove)(struct phy_device *);
	int (*match_phy_device)(struct phy_device *);
	int (*ts_info)(struct phy_device *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device *, struct sk_buff___27 *, int);
	void (*txtstamp)(struct phy_device *, struct sk_buff___27 *, int);
	int (*set_wol)(struct phy_device *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device *, struct ethtool_wolinfo *);
	struct device_driver___186 driver;
};

struct phy_fixup {
	struct list_head list;
	char bus_id[20];
	u32 phy_uid;
	u32 phy_uid_mask;
	int (*run)(struct phy_device *);
};

struct page___222;

typedef struct page___222 *pgtable_t___222;

struct address_space___223;

struct kmem_cache___208;

struct page___222 {
	long unsigned int flags;
	struct address_space___223 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___222 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___222 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___208 *slab_cache;
		struct page___222 *first_page;
	};
	long: 64;
};

struct task_struct___224;

struct pv_cpu_ops___224 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___224 *);
	void (*end_context_switch)(struct task_struct___224 *);
};

struct mutex___225 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___224 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___217 {
	struct page___222 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___231;

struct nsproxy___116;

struct signal_struct___224;

struct css_set___132;

struct task_struct___224 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___224 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___231 *mm;
	struct mm_struct___231 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___224 *real_parent;
	struct task_struct___224 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___224 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___224 = 0,
		VTIME_USER___224 = 1,
		VTIME_SYS___224 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___116 *nsproxy;
	struct signal_struct___224 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___132 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___225 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___217 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___231 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___231 *, struct mm_struct___231 *);
	void (*dup_mmap)(struct mm_struct___231 *, struct mm_struct___231 *);
	void (*exit_mmap)(struct mm_struct___231 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___231 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___231 *);
	void (*pgd_free)(struct mm_struct___231 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___231 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___231 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___231 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___231 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___231 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___231 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___231 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___231 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___231 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___231 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___231 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___225 lock;
	void *vdso;
} mm_context_t___225;

struct xol_area___222;

struct uprobes_state___222 {
	struct xol_area___222 *xol_area;
};

struct vm_area_struct___231;

struct file___223;

struct core_state___224;

struct mm_struct___231 {
	struct vm_area_struct___231 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___231 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___231 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___225 context;
	long unsigned int flags;
	struct core_state___224 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___224 *owner;
	struct file___223 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___222 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___129;

struct exec_domain___57 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___129 *module;
	struct exec_domain___57 *next;
};

struct module_kobject___128 {
	struct kobject___24 kobj;
	struct module___129 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___128;

struct module___129 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___128 mkobj;
	struct module_attribute___128 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___224 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___97 {
	struct task_struct___224 *task;
	struct exec_domain___57 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___224;

struct lruvec___224 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___224 *zone;
};

struct pglist_data___224;

struct zone___224 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___224 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___224 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___224 {
	struct zone___224 *zone;
	int zone_idx;
};

struct zonelist___224 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___224 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___224 {
	struct zone___224 node_zones[4];
	struct zonelist___224 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___224 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___147;

struct x86_io_apic_ops___147 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___147 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___147;

struct irq_data___147 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___147 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___207;

struct dev_pm_ops___207 {
	int (*prepare)(struct device___207 *);
	void (*complete)(struct device___207 *);
	int (*suspend)(struct device___207 *);
	int (*resume)(struct device___207 *);
	int (*freeze)(struct device___207 *);
	int (*thaw)(struct device___207 *);
	int (*poweroff)(struct device___207 *);
	int (*restore)(struct device___207 *);
	int (*suspend_late)(struct device___207 *);
	int (*resume_early)(struct device___207 *);
	int (*freeze_late)(struct device___207 *);
	int (*thaw_early)(struct device___207 *);
	int (*poweroff_late)(struct device___207 *);
	int (*restore_early)(struct device___207 *);
	int (*suspend_noirq)(struct device___207 *);
	int (*resume_noirq)(struct device___207 *);
	int (*freeze_noirq)(struct device___207 *);
	int (*thaw_noirq)(struct device___207 *);
	int (*poweroff_noirq)(struct device___207 *);
	int (*restore_noirq)(struct device___207 *);
	int (*runtime_suspend)(struct device___207 *);
	int (*runtime_resume)(struct device___207 *);
	int (*runtime_idle)(struct device___207 *);
};

struct dev_pm_qos___36;

struct dev_pm_info___36 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___36 *qos;
};

struct dma_map_ops___90;

struct dev_archdata___90 {
	struct dma_map_ops___90 *dma_ops;
	void *iommu;
};

struct device_type___207;

struct bus_type___207;

struct device_driver___207;

struct dev_pm_domain___207;

struct device_node___14;

struct class___207;

struct attribute_group___181;

struct device_rh___207;

struct device___207 {
	struct device___207 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___207 *type;
	struct mutex___225 mutex;
	struct bus_type___207 *bus;
	struct device_driver___207 *driver;
	void *platform_data;
	struct dev_pm_info___36 power;
	struct dev_pm_domain___207 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___90 archdata;
	struct device_node___14 *of_node;
	struct acpi_dev_node___29 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___207 *class;
	const struct attribute_group___181 **groups;
	void (*release)(struct device___207 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___207 *device_rh;
};

struct dev_pm_qos_request___36;

struct dev_pm_qos___36 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___36 *latency_req;
	struct dev_pm_qos_request___36 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___36 *latency_tolerance_req;
};

struct dev_pm_info_rh___207 {
	void (*set_latency_tolerance)(struct device___207 *, s32);
};

struct dev_pm_domain___207 {
	struct dev_pm_ops___207 ops;
};

struct property___14;

struct device_node___14 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___14 *properties;
	struct property___14 *deadprops;
	struct device_node___14 *parent;
	struct device_node___14 *child;
	struct device_node___14 *sibling;
	struct device_node___14 *next;
	struct device_node___14 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject___24 kobj;
};

struct smp_ops___224 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___224 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___183;

struct attribute_group___181 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___183 **bin_attrs;
};

struct bin_attribute___183 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___223 *, struct kobject___24 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___223 *, struct kobject___24 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	int (*mmap)(struct file___223 *, struct kobject___24 *, struct bin_attribute___183 *, struct vm_area_struct___231 *);
};

struct dentry___223;

struct path___223 {
	struct vfsmount *mnt;
	struct dentry___223 *dentry;
};

struct inode___223;

struct file_operations___223;

struct file___223 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___223 f_path;
	struct inode___223 *f_inode;
	const struct file_operations___223 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___223 *f_mapping;
	struct mutex___225 f_pos_lock;
};

struct vm_operations_struct___203;

struct vm_area_struct___231 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___231 *vm_next;
	struct vm_area_struct___231 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___231 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___203 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___223 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___207 {
	void **freelist;
	long unsigned int tid;
	struct page___222 *page;
	struct page___222 *partial;
};

struct memcg_cache_params___208;

struct kmem_cache___208 {
	struct kmem_cache_cpu___207 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___208 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___208 {
	bool is_root_cache;
	union {
		struct kmem_cache___208 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___208 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct seq_file___151;

struct irq_chip___147 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___147 *);
	void (*irq_shutdown)(struct irq_data___147 *);
	void (*irq_enable)(struct irq_data___147 *);
	void (*irq_disable)(struct irq_data___147 *);
	void (*irq_ack)(struct irq_data___147 *);
	void (*irq_mask)(struct irq_data___147 *);
	void (*irq_mask_ack)(struct irq_data___147 *);
	void (*irq_unmask)(struct irq_data___147 *);
	void (*irq_eoi)(struct irq_data___147 *);
	int (*irq_set_affinity)(struct irq_data___147 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___147 *);
	int (*irq_set_type)(struct irq_data___147 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___147 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___147 *);
	void (*irq_bus_sync_unlock)(struct irq_data___147 *);
	void (*irq_cpu_online)(struct irq_data___147 *);
	void (*irq_cpu_offline)(struct irq_data___147 *);
	void (*irq_suspend)(struct irq_data___147 *);
	void (*irq_resume)(struct irq_data___147 *);
	void (*irq_pm_shutdown)(struct irq_data___147 *);
	void (*irq_print_chip)(struct irq_data___147 *, struct seq_file___151 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___147 *, void *);
	long unsigned int flags;
};

struct seq_operations___151;

struct seq_file___151 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___225 lock;
	const struct seq_operations___151 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dma_map_ops___90 {
	void * (*alloc)(struct device___207 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___207 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___207 *, struct vm_area_struct___231 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___207 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___207 *, struct page___222 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___207 *, dma_addr_t);
	int (*dma_supported)(struct device___207 *, u64);
	int (*set_dma_mask)(struct device___207 *, u64);
	int is_phys;
};

struct bus_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___207 *, char *);
	ssize_t (*store)(struct bus_type___207 *, const char *, size_t);
};

struct device_attribute___207;

struct driver_attribute___207;

struct bus_type___207 {
	const char *name;
	const char *dev_name;
	struct device___207 *dev_root;
	struct bus_attribute___207 *bus_attrs;
	struct device_attribute___207 *dev_attrs;
	struct driver_attribute___207 *drv_attrs;
	const struct attribute_group___181 **bus_groups;
	const struct attribute_group___181 **dev_groups;
	const struct attribute_group___181 **drv_groups;
	int (*match)(struct device___207 *, struct device_driver___207 *);
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	int (*probe)(struct device___207 *);
	int (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*online)(struct device___207 *);
	int (*offline)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct device___207 *, struct device_attribute___207 *, char *);
	ssize_t (*store)(struct device___207 *, struct device_attribute___207 *, const char *, size_t);
};

struct driver_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___207 *, char *);
	ssize_t (*store)(struct device_driver___207 *, const char *, size_t);
};

struct device_driver___207 {
	const char *name;
	struct bus_type___207 *bus;
	struct module___129 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___207 *);
	int (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	const struct attribute_group___181 **groups;
	const struct dev_pm_ops___207 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___207 {
	const char *name;
	const struct attribute_group___181 **groups;
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
};

struct class_attribute___207;

struct class___207 {
	const char *name;
	struct module___129 *owner;
	struct class_attribute___207 *class_attrs;
	struct device_attribute___207 *dev_attrs;
	const struct attribute_group___181 **dev_groups;
	struct bin_attribute___183 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *);
	void (*class_release)(struct class___207 *);
	void (*dev_release)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
	struct subsys_private *p;
};

struct class_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct class___207 *, struct class_attribute___207 *, char *);
	ssize_t (*store)(struct class___207 *, struct class_attribute___207 *, const char *, size_t);
	const void * (*namespace)(struct class___207 *, const struct class_attribute___207 *);
};

struct device_rh___207 {
	struct dev_pm_info_rh___207 power;
};

struct dentry_operations___223;

struct super_block___223;

struct dentry___223 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___223 *d_parent;
	struct qstr d_name;
	struct inode___223 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___223 *d_op;
	struct super_block___223 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___223;

struct address_space___223 {
	struct inode___223 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___225 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___223 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___223;

struct file_lock___223;

struct dquot___223;

struct block_device___223;

struct inode___223 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___223 *i_op;
	struct super_block___223 *i_sb;
	struct address_space___223 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___225 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___223 *i_fop;
	struct file_lock___223 *i_flock;
	struct address_space___223 i_data;
	struct dquot___223 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___223 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___223 {
	int (*d_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_hash)(const struct dentry___223 *, struct qstr *);
	int (*d_compare)(const struct dentry___223 *, const struct dentry___223 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___223 *);
	void (*d_release)(struct dentry___223 *);
	void (*d_prune)(struct dentry___223 *);
	void (*d_iput)(struct dentry___223 *, struct inode___223 *);
	char * (*d_dname)(struct dentry___223 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___223 *);
	int (*d_manage)(struct dentry___223 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___223;

struct mem_dqinfo___223 {
	struct quota_format_type___223 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___223;

struct quota_info___223 {
	unsigned int flags;
	struct mutex___225 dqio_mutex;
	struct mutex___225 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___223 *files[2];
	struct mem_dqinfo___223 info[2];
	const struct quota_format_ops___223 *ops[2];
};

struct file_system_type___223;

struct super_operations___223;

struct dquot_operations___223;

struct quotactl_ops___223;

struct xattr_handler___133;

struct super_block___223 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___223 *s_type;
	const struct super_operations___223 *s_op;
	const struct dquot_operations___223 *dq_op;
	const struct quotactl_ops___223 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___223 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___133 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___223 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___223 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___225 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___223 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___223 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___223 *bd_inode;
	struct super_block___223 *bd_super;
	struct mutex___225 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___223 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___225 bd_fsfreeze_mutex;
};

struct cgroup___132;

struct cgroup_subsys_state___132 {
	struct cgroup___132 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___223 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___223 *ia_file;
};

struct dquot___223 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___225 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___223 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___223 {
	int qf_fmt_id;
	const struct quota_format_ops___223 *qf_ops;
	struct module___129 *qf_owner;
	struct quota_format_type___223 *qf_next;
};

struct quota_format_ops___223 {
	int (*check_quota_file)(struct super_block___223 *, int);
	int (*read_file_info)(struct super_block___223 *, int);
	int (*write_file_info)(struct super_block___223 *, int);
	int (*free_file_info)(struct super_block___223 *, int);
	int (*read_dqblk)(struct dquot___223 *);
	int (*commit_dqblk)(struct dquot___223 *);
	int (*release_dqblk)(struct dquot___223 *);
};

struct dquot_operations___223 {
	int (*write_dquot)(struct dquot___223 *);
	struct dquot___223 * (*alloc_dquot)(struct super_block___223 *, int);
	void (*destroy_dquot)(struct dquot___223 *);
	int (*acquire_dquot)(struct dquot___223 *);
	int (*release_dquot)(struct dquot___223 *);
	int (*mark_dirty)(struct dquot___223 *);
	int (*write_info)(struct super_block___223 *, int);
	qsize_t * (*get_reserved_space)(struct inode___223 *);
};

struct quotactl_ops___223 {
	int (*quota_on)(struct super_block___223 *, int, int, struct path___223 *);
	int (*quota_on_meta)(struct super_block___223 *, int, int);
	int (*quota_off)(struct super_block___223 *, int);
	int (*quota_sync)(struct super_block___223 *, int);
	int (*get_info)(struct super_block___223 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___223 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___223 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___223 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___223 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___223 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___223 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___223 *, unsigned int);
};

struct address_space_operations___223 {
	int (*writepage)(struct page___222 *, struct writeback_control *);
	int (*readpage)(struct file___223 *, struct page___222 *);
	int (*writepages)(struct address_space___223 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___222 *);
	int (*readpages)(struct file___223 *, struct address_space___223 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___223 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___222 **, void **);
	int (*write_end)(struct file___223 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___222 *, void *);
	sector_t (*bmap)(struct address_space___223 *, sector_t);
	void (*invalidatepage)(struct page___222 *, long unsigned int);
	int (*releasepage)(struct page___222 *, gfp_t);
	void (*freepage)(struct page___222 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___223 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___223 *, struct page___222 *, struct page___222 *, enum migrate_mode);
	int (*launder_page)(struct page___222 *);
	int (*is_partially_uptodate)(struct page___222 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___222 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___223 *, struct page___222 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___223 *, sector_t *);
	void (*swap_deactivate)(struct file___223 *);
	void (*invalidatepage_range)(struct page___222 *, unsigned int, unsigned int);
};

struct inode_operations___223 {
	struct dentry___223 * (*lookup)(struct inode___223 *, struct dentry___223 *, unsigned int);
	void * (*follow_link)(struct dentry___223 *, struct nameidata *);
	int (*permission)(struct inode___223 *, int);
	struct posix_acl * (*get_acl)(struct inode___223 *, int);
	int (*readlink)(struct dentry___223 *, char *, int);
	void (*put_link)(struct dentry___223 *, struct nameidata *, void *);
	int (*create)(struct inode___223 *, struct dentry___223 *, umode_t, bool);
	int (*link)(struct dentry___223 *, struct inode___223 *, struct dentry___223 *);
	int (*unlink)(struct inode___223 *, struct dentry___223 *);
	int (*symlink)(struct inode___223 *, struct dentry___223 *, const char *);
	int (*mkdir)(struct inode___223 *, struct dentry___223 *, umode_t);
	int (*rmdir)(struct inode___223 *, struct dentry___223 *);
	int (*mknod)(struct inode___223 *, struct dentry___223 *, umode_t, dev_t);
	int (*rename)(struct inode___223 *, struct dentry___223 *, struct inode___223 *, struct dentry___223 *);
	int (*setattr)(struct dentry___223 *, struct iattr___223 *);
	int (*getattr)(struct vfsmount *, struct dentry___223 *, struct kstat *);
	int (*setxattr)(struct dentry___223 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___223 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___223 *, char *, size_t);
	int (*removexattr)(struct dentry___223 *, const char *);
	int (*fiemap)(struct inode___223 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___223 *, struct timespec *, int);
	int (*atomic_open)(struct inode___223 *, struct dentry___223 *, struct file___223 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___223 {
	struct module___129 *owner;
	loff_t (*llseek)(struct file___223 *, loff_t, int);
	ssize_t (*read)(struct file___223 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___223 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___223 *, void *, filldir_t);
	unsigned int (*poll)(struct file___223 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___223 *, struct vm_area_struct___231 *);
	int (*open)(struct inode___223 *, struct file___223 *);
	int (*flush)(struct file___223 *, fl_owner_t);
	int (*release)(struct inode___223 *, struct file___223 *);
	int (*fsync)(struct file___223 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___223 *, int);
	int (*lock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*sendpage)(struct file___223 *, struct page___222 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___223 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___223 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___223 *, long int, struct file_lock___223 **, void **);
		struct {
			int (*setlease)(struct file___223 *, long int, struct file_lock___223 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___223 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___151 *, struct file___223 *);
};

struct fasync_struct___223;

struct file_lock_operations___223;

struct lock_manager_operations___223;

struct file_lock___223 {
	struct file_lock___223 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___223 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___223 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___223 *fl_ops;
	const struct lock_manager_operations___223 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___223 {
	void (*fl_copy_lock)(struct file_lock___223 *, struct file_lock___223 *);
	void (*fl_release_private)(struct file_lock___223 *);
};

struct lock_manager_operations___223 {
	int (*lm_compare_owner)(struct file_lock___223 *, struct file_lock___223 *);
	long unsigned int (*lm_owner_key)(struct file_lock___223 *);
	void (*lm_notify)(struct file_lock___223 *);
	int (*lm_grant)(struct file_lock___223 *, struct file_lock___223 *, int);
	void (*lm_break)(struct file_lock___223 *);
	int (*lm_change)(struct file_lock___223 **, int);
};

struct fasync_struct___223 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___223 *fa_next;
	struct file___223 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___223 {
	const char *name;
	int fs_flags;
	struct dentry___223 * (*mount)(struct file_system_type___223 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___223 *);
	struct module___129 *owner;
	struct file_system_type___223 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___223 {
	struct inode___223 * (*alloc_inode)(struct super_block___223 *);
	void (*destroy_inode)(struct inode___223 *);
	void (*dirty_inode)(struct inode___223 *, int);
	int (*write_inode)(struct inode___223 *, struct writeback_control *);
	int (*drop_inode)(struct inode___223 *);
	void (*evict_inode)(struct inode___223 *);
	void (*put_super)(struct super_block___223 *);
	int (*sync_fs)(struct super_block___223 *, int);
	int (*freeze_fs)(struct super_block___223 *);
	int (*unfreeze_fs)(struct super_block___223 *);
	int (*statfs)(struct dentry___223 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___223 *, int *, char *);
	void (*umount_begin)(struct super_block___223 *);
	int (*show_options)(struct seq_file___151 *, struct dentry___223 *);
	int (*show_devname)(struct seq_file___151 *, struct dentry___223 *);
	int (*show_path)(struct seq_file___151 *, struct dentry___223 *);
	int (*show_stats)(struct seq_file___151 *, struct dentry___223 *);
	ssize_t (*quota_read)(struct super_block___223 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___223 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___223 *);
	int (*bdev_try_to_free_page)(struct super_block___223 *, struct page___222 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___223 *);
	void (*free_cached_objects)(struct super_block___223 *, int);
};

struct xattr_handler___133 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___223 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___223 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___223 *, const char *, const void *, size_t, int, int);
};

struct xol_area___222 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___222 *page;
	long unsigned int vaddr;
};

struct vm_fault___199;

struct vm_operations_struct___203 {
	void (*open)(struct vm_area_struct___231 *);
	void (*close)(struct vm_area_struct___231 *);
	int (*fault)(struct vm_area_struct___231 *, struct vm_fault___199 *);
	int (*page_mkwrite)(struct vm_area_struct___231 *, struct vm_fault___199 *);
	int (*access)(struct vm_area_struct___231 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___231 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___231 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___231 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___231 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___224 {
	struct task_struct___224 *task;
	struct core_thread___224 *next;
};

struct core_state___224 {
	atomic_t nr_threads;
	struct core_thread___224 dumper;
	struct completion startup;
};

struct ctl_table_header___43;

struct ctl_node___43 {
	struct rb_node node;
	struct ctl_table_header___43 *header;
};

struct ctl_table_root___43;

struct ctl_table_set___43;

struct ctl_dir___43;

struct ctl_table_header___43 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___43 *root;
	struct ctl_table_set___43 *set;
	struct ctl_dir___43 *parent;
	struct ctl_node___43 *node;
};

struct ctl_dir___43 {
	struct ctl_table_header___43 header;
	struct rb_root root;
};

struct ctl_table_set___43 {
	int (*is_seen)(struct ctl_table_set___43 *);
	struct ctl_dir___43 dir;
};

struct ctl_table_root___43 {
	struct ctl_table_set___43 default_set;
	struct ctl_table_set___43 * (*lookup)(struct ctl_table_root___43 *, struct nsproxy___116 *);
	int (*permissions)(struct ctl_table_header___43 *, struct ctl_table *);
};

struct net___42;

struct nsproxy___116 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___42 *net_ns;
};

struct signal_struct___224 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___224 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___224 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___225 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___132 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___132 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___40 {
	struct ctl_table_header___43 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___40 {
	struct mutex___225 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___40 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___43 *ctl;
};

struct netns_ipv4___40 {
	struct ctl_table_header___43 *forw_hdr;
	struct ctl_table_header___43 *frags_hdr;
	struct ctl_table_header___43 *ipv4_hdr;
	struct ctl_table_header___43 *route_hdr;
	struct ctl_table_header___43 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___40 {
	struct ctl_table_header___43 *hdr;
	struct ctl_table_header___43 *route_hdr;
	struct ctl_table_header___43 *icmp_hdr;
	struct ctl_table_header___43 *frags_hdr;
	struct ctl_table_header___43 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___31;

struct sk_buff___32;

struct dst_ops___41 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___41 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___31 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___32 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___32 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___32 *);
	int (*local_out)(struct sk_buff___32 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___32 *, const void *);
	struct kmem_cache___208 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___41 {
	struct netns_sysctl_ipv6___40 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___41 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___40 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___43 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___40 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___43 *nf_log_dir_header;
};

struct nf_proto_net___40 {
	struct ctl_table_header___43 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___40 {
	struct nf_proto_net___40 pn;
	unsigned int timeout;
};

struct nf_tcp_net___40 {
	struct nf_proto_net___40 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___40 {
	struct nf_proto_net___40 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___40 {
	struct nf_proto_net___40 pn;
	unsigned int timeout;
};

struct nf_ip_net___40 {
	struct nf_generic_net___40 generic;
	struct nf_tcp_net___40 tcp;
	struct nf_udp_net___40 udp;
	struct nf_icmp_net___40 icmp;
	struct nf_icmp_net___40 icmpv6;
};

struct netns_ct___40 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___43 *sysctl_header;
	struct ctl_table_header___43 *acct_sysctl_header;
	struct ctl_table_header___43 *tstamp_sysctl_header;
	struct ctl_table_header___43 *event_sysctl_header;
	struct ctl_table_header___43 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___208 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___40 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___40 {
	struct netns_sysctl_ipv6___40 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___30 {
	struct sk_buff___32 *next;
	struct sk_buff___32 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___41 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___43 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___41 xfrm4_dst_ops;
	struct dst_ops___41 xfrm6_dst_ops;
};

struct net___42 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___43 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___31 *loopback_dev;
	struct netns_core___40 core;
	struct netns_mib mib;
	struct netns_packet___40 packet;
	struct netns_unix___40 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___40 ipv4;
	struct netns_ipv6___41 ipv6;
	struct netns_sctp___40 sctp;
	struct netns_dccp___21 dccp;
	struct netns_nf___40 nf;
	struct netns_xt xt;
	struct netns_ct___40 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___40 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___30 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___41 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___225 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___225 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___199 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___222 *page;
};

struct nf_bridge_info___29 {
	atomic_t use;
	unsigned int mask;
	struct net_device___31 *physindev;
	struct net_device___31 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___29(struct sk_buff___32 **);

struct net_device_ops___29;

struct ethtool_ops___29;

struct header_ops___29;

struct netdev_rx_queue___29;

struct netdev_queue___29;

struct dcbnl_rtnl_ops___29;

struct phy_device___3;

struct net_device___31 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___29 *netdev_ops;
	const struct ethtool_ops___29 *ethtool_ops;
	const struct header_ops___29 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___24 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___29 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___29 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___29 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___29 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___29 = 0,
		NETREG_REGISTERED___29 = 1,
		NETREG_UNREGISTERING___29 = 2,
		NETREG_UNREGISTERED___29 = 3,
		NETREG_RELEASED___29 = 4,
		NETREG_DUMMY___29 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___29 = 0,
		RTNL_LINK_INITIALIZING___29 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___31 *);
	struct netpoll_info *npinfo;
	struct net___42 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___207 dev;
	const struct attribute_group___181 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___29 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___3 *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___32 {
	struct sk_buff___32 *next;
	struct sk_buff___32 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___31 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___32 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___29 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___29 {
	int (*get_settings)(struct net_device___31 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___31 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___31 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___31 *);
	void (*get_regs)(struct net_device___31 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___31 *);
	void (*set_msglevel)(struct net_device___31 *, u32);
	int (*nway_reset)(struct net_device___31 *);
	u32 (*get_link)(struct net_device___31 *);
	int (*get_eeprom_len)(struct net_device___31 *);
	int (*get_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___31 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___31 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___31 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___31 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___31 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___31 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___31 *);
	void (*complete)(struct net_device___31 *);
	u32 (*get_priv_flags)(struct net_device___31 *);
	int (*set_priv_flags)(struct net_device___31 *, u32);
	int (*get_sset_count)(struct net_device___31 *, int);
	int (*get_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___31 *, struct ethtool_flash *);
	int (*reset)(struct net_device___31 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___31 *);
	int (*get_rxfh_indir)(struct net_device___31 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___31 *, const u32 *);
	void (*get_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___31 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___31 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___31 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___31 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___31 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___31 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___31 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___31 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct mii_bus___3 {
	const char *name;
	char id[17];
	void *priv;
	int (*read)(struct mii_bus___3 *, int, int);
	int (*write)(struct mii_bus___3 *, int, int, u16);
	int (*reset)(struct mii_bus___3 *);
	struct mutex___225 mdio_lock;
	struct device___207 *parent;
	enum {
		MDIOBUS_ALLOCATED___3 = 1,
		MDIOBUS_REGISTERED___3 = 2,
		MDIOBUS_UNREGISTERED___3 = 3,
		MDIOBUS_RELEASED___3 = 4,
	} state;
	struct device___207 dev;
	struct phy_device___3 *phy_map[32];
	u32 phy_mask;
	int *irq;
};

struct phy_driver___3;

struct phy_device___3 {
	struct phy_driver___3 *drv;
	struct mii_bus___3 *bus;
	struct device___207 dev;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	bool is_c45;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int addr;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	int link;
	u32 interrupts;
	u32 supported;
	u32 advertising;
	int autoneg;
	int link_timeout;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	atomic_t irq_disable;
	struct mutex___225 lock;
	struct net_device___31 *attached_dev;
	void (*adjust_link)(struct net_device___31 *);
	void (*adjust_state)(struct net_device___31 *);
};

struct phy_driver___3 {
	u32 phy_id;
	char *name;
	unsigned int phy_id_mask;
	u32 features;
	u32 flags;
	int (*config_init)(struct phy_device___3 *);
	int (*probe)(struct phy_device___3 *);
	int (*suspend)(struct phy_device___3 *);
	int (*resume)(struct phy_device___3 *);
	int (*config_aneg)(struct phy_device___3 *);
	int (*read_status)(struct phy_device___3 *);
	int (*ack_interrupt)(struct phy_device___3 *);
	int (*config_intr)(struct phy_device___3 *);
	int (*did_interrupt)(struct phy_device___3 *);
	void (*remove)(struct phy_device___3 *);
	int (*match_phy_device)(struct phy_device___3 *);
	int (*ts_info)(struct phy_device___3 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___3 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___3 *, struct sk_buff___32 *, int);
	void (*txtstamp)(struct phy_device___3 *, struct sk_buff___32 *, int);
	int (*set_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	struct device_driver___207 driver;
};

struct property___14 {
	char *name;
	int length;
	void *value;
	struct property___14 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___183 attr;
};

struct dev_pm_qos_request___36 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___207 *dev;
};

struct nf_afinfo___41 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___32 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___32 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___42 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___32 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___32 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___151 {
	void * (*start)(struct seq_file___151 *, loff_t *);
	void (*stop)(struct seq_file___151 *, void *);
	void * (*next)(struct seq_file___151 *, void *, loff_t *);
	int (*show)(struct seq_file___151 *, void *);
};

struct dcbnl_rtnl_ops___29 {
	int (*ieee_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___31 *);
	u8 (*setstate)(struct net_device___31 *, u8);
	void (*getpermhwaddr)(struct net_device___31 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___31 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___31 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___31 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___31 *, int, u8 *);
	void (*setpfccfg)(struct net_device___31 *, int, u8);
	void (*getpfccfg)(struct net_device___31 *, int, u8 *);
	u8 (*setall)(struct net_device___31 *);
	u8 (*getcap)(struct net_device___31 *, int, u8 *);
	int (*getnumtcs)(struct net_device___31 *, int, u8 *);
	int (*setnumtcs)(struct net_device___31 *, int, u8);
	u8 (*getpfcstate)(struct net_device___31 *);
	void (*setpfcstate)(struct net_device___31 *, u8);
	void (*getbcncfg)(struct net_device___31 *, int, u32 *);
	void (*setbcncfg)(struct net_device___31 *, int, u32);
	void (*getbcnrp)(struct net_device___31 *, int, u8 *);
	void (*setbcnrp)(struct net_device___31 *, int, u8);
	u8 (*setapp)(struct net_device___31 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___31 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___31 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___31 *, int, u8);
	u8 (*getdcbx)(struct net_device___31 *);
	u8 (*setdcbx)(struct net_device___31 *, u8);
	int (*peer_getappinfo)(struct net_device___31 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___31 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___31 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___31 *, struct cee_pfc *);
};

struct cgroupfs_root___132;

struct cgroup___132 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___132 *parent;
	struct dentry___223 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___132 *subsys[11];
	struct cgroupfs_root___132 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___225 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___132 {
	struct super_block___223 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___132 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___30 {
	struct sk_buff___32 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___32 *, struct netlink_callback___30 *);
	int (*done)(struct netlink_callback___30 *);
	void *data;
	struct module___129 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___29 {
	int (*create)(struct sk_buff___32 *, struct net_device___31 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___32 *, unsigned char *);
	int (*rebuild)(struct sk_buff___32 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___31 *, const unsigned char *);
};

struct napi_struct___29 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___29 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___31 *dev;
	struct sk_buff___32 *gro_list;
	struct sk_buff___32 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___29 {
	struct net_device___31 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___24 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___29 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___24 kobj;
	struct net_device___31 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___29 {
	int (*ndo_init)(struct net_device___31 *);
	void (*ndo_uninit)(struct net_device___31 *);
	int (*ndo_open)(struct net_device___31 *);
	int (*ndo_stop)(struct net_device___31 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___32 *, struct net_device___31 *);
	u16 (*ndo_select_queue)(struct net_device___31 *, struct sk_buff___32 *);
	void (*ndo_change_rx_flags)(struct net_device___31 *, int);
	void (*ndo_set_rx_mode)(struct net_device___31 *);
	int (*ndo_set_mac_address)(struct net_device___31 *, void *);
	int (*ndo_validate_addr)(struct net_device___31 *);
	int (*ndo_do_ioctl)(struct net_device___31 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___31 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___31 *, int);
	int (*ndo_neigh_setup)(struct net_device___31 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___31 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___31 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___31 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___31 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___31 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___31 *);
	int (*ndo_netpoll_setup)(struct net_device___31 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___31 *);
	int (*ndo_busy_poll)(struct napi_struct___29 *);
	int (*ndo_set_vf_mac)(struct net_device___31 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___31 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___31 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___31 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___31 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___31 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___31 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___31 *, int, struct sk_buff___32 *);
	int (*ndo_setup_tc)(struct net_device___31 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___31 *);
	int (*ndo_fcoe_disable)(struct net_device___31 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___31 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___31 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___31 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___31 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___31 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___31 *, const struct sk_buff___32 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___31 *, struct net_device___31 *);
	int (*ndo_del_slave)(struct net_device___31 *, struct net_device___31 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___32 *, struct netlink_callback___30 *, struct net_device___31 *, int);
	int (*ndo_bridge_setlink)(struct net_device___31 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___32 *, u32, u32, struct net_device___31 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___31 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___31 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___31 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___31 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___31 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___31 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___32 *, struct net_device___31 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___31 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___31 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___31 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct module_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___128 *, struct module_kobject___128 *, char *);
	ssize_t (*store)(struct module_attribute___128 *, struct module_kobject___128 *, const char *, size_t);
	void (*setup)(struct module___129 *, const char *);
	int (*test)(struct module___129 *);
	void (*free)(struct module___129 *);
};

struct platform_device___9 {
	const char *name;
	int id;
	bool id_auto;
	struct device___207 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___7 {
	struct device___207 *parent;
	struct acpi_dev_node___29 acpi_node;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
};

struct fixed_phy_status {
	int link;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
};

struct fixed_mdio_bus {
	int irqs[32];
	struct mii_bus___3 *mii_bus;
	struct list_head phys;
};

struct fixed_phy {
	int id;
	u16 regs[29];
	struct phy_device___3 *phydev;
	struct fixed_phy_status status;
	int (*link_update)(struct net_device *, struct fixed_phy_status *);
	struct list_head node;
};

struct ohci {
	void *registers;
};

struct socket_state_t {
	u_int flags;
	u_int csc_mask;
	u_char Vcc;
	u_char Vpp;
	u_char io_irq;
};

typedef struct socket_state_t socket_state_t;

struct pccard_io_map {
	u_char map;
	u_char flags;
	u_short speed;
	phys_addr_t start;
	phys_addr_t stop;
};

struct pccard_mem_map {
	u_char map;
	u_char flags;
	u_short speed;
	phys_addr_t static_start;
	u_int card_start;
	struct resource *res;
};

typedef struct pccard_mem_map pccard_mem_map;

struct io_window_t {
	u_int InUse;
	u_int Config;
	struct resource *res;
};

typedef struct io_window_t io_window_t;

struct pcmcia_socket;

struct pccard_operations {
	int (*init)(struct pcmcia_socket *);
	int (*suspend)(struct pcmcia_socket *);
	int (*get_status)(struct pcmcia_socket *, u_int *);
	int (*set_socket)(struct pcmcia_socket *, socket_state_t *);
	int (*set_io_map)(struct pcmcia_socket *, struct pccard_io_map *);
	int (*set_mem_map)(struct pcmcia_socket *, struct pccard_mem_map *);
};

struct pccard_resource_ops;

struct pcmcia_callback;

struct pcmcia_socket {
	struct module___126 *owner;
	socket_state_t socket;
	u_int state;
	u_int suspended_state;
	u_short functions;
	u_short lock_count;
	pccard_mem_map cis_mem;
	void *cis_virt;
	io_window_t io[2];
	pccard_mem_map win[4];
	struct list_head cis_cache;
	size_t fake_cis_len;
	u8 *fake_cis;
	struct list_head socket_list;
	struct completion socket_released;
	unsigned int sock;
	u_int features;
	u_int irq_mask;
	u_int map_size;
	u_int io_offset;
	u_int pci_irq;
	struct pci_dev___12 *cb_dev;
	u8 resource_setup_done;
	struct pccard_operations *ops;
	struct pccard_resource_ops *resource_ops;
	void *resource_data;
	void (*zoom_video)(struct pcmcia_socket *, int);
	int (*power_hook)(struct pcmcia_socket *, int);
	void (*tune_bridge)(struct pcmcia_socket *, struct pci_bus___12 *);
	struct task_struct___221 *thread;
	struct completion thread_done;
	unsigned int thread_events;
	unsigned int sysfs_events;
	struct mutex___222 skt_mutex;
	struct mutex___222 ops_mutex;
	spinlock_t thread_lock;
	struct pcmcia_callback *callback;
	struct device___36 dev;
	void *driver_data;
	int resume_status;
};

struct pccard_resource_ops {
	int (*validate_mem)(struct pcmcia_socket *);
	int (*find_io)(struct pcmcia_socket *, unsigned int, unsigned int *, unsigned int, unsigned int, struct resource **);
	struct resource * (*find_mem)(long unsigned int, long unsigned int, long unsigned int, int, struct pcmcia_socket *);
	int (*init)(struct pcmcia_socket *);
	void (*exit)(struct pcmcia_socket *);
};

struct pcmcia_callback {
	struct module___126 *owner;
	int (*add)(struct pcmcia_socket *);
	int (*remove)(struct pcmcia_socket *);
	void (*requery)(struct pcmcia_socket *);
	int (*validate)(struct pcmcia_socket *, unsigned int *);
	int (*suspend)(struct pcmcia_socket *);
	int (*early_resume)(struct pcmcia_socket *);
	int (*resume)(struct pcmcia_socket *);
};

enum {
	PCMCIA_IOPORT_0 = 0,
	PCMCIA_IOPORT_1 = 1,
	PCMCIA_IOMEM_0 = 2,
	PCMCIA_IOMEM_1 = 3,
	PCMCIA_IOMEM_2 = 4,
	PCMCIA_IOMEM_3 = 5,
	PCMCIA_NUM_RESOURCES = 6,
};

struct pcmcia_socket___2;

struct pccard_operations___2 {
	int (*init)(struct pcmcia_socket___2 *);
	int (*suspend)(struct pcmcia_socket___2 *);
	int (*get_status)(struct pcmcia_socket___2 *, u_int *);
	int (*set_socket)(struct pcmcia_socket___2 *, socket_state_t *);
	int (*set_io_map)(struct pcmcia_socket___2 *, struct pccard_io_map *);
	int (*set_mem_map)(struct pcmcia_socket___2 *, struct pccard_mem_map *);
};

struct pccard_resource_ops___2;

struct pcmcia_callback___2;

struct pcmcia_socket___2 {
	struct module___114 *owner;
	socket_state_t socket;
	u_int state;
	u_int suspended_state;
	u_short functions;
	u_short lock_count;
	pccard_mem_map cis_mem;
	void *cis_virt;
	io_window_t io[2];
	pccard_mem_map win[4];
	struct list_head cis_cache;
	size_t fake_cis_len;
	u8 *fake_cis;
	struct list_head socket_list;
	struct completion socket_released;
	unsigned int sock;
	u_int features;
	u_int irq_mask;
	u_int map_size;
	u_int io_offset;
	u_int pci_irq;
	struct pci_dev___23 *cb_dev;
	u8 resource_setup_done;
	struct pccard_operations___2 *ops;
	struct pccard_resource_ops___2 *resource_ops;
	void *resource_data;
	void (*zoom_video)(struct pcmcia_socket___2 *, int);
	int (*power_hook)(struct pcmcia_socket___2 *, int);
	void (*tune_bridge)(struct pcmcia_socket___2 *, struct pci_bus___23 *);
	struct task_struct___220 *thread;
	struct completion thread_done;
	unsigned int thread_events;
	unsigned int sysfs_events;
	struct mutex___221 skt_mutex;
	struct mutex___221 ops_mutex;
	spinlock_t thread_lock;
	struct pcmcia_callback___2 *callback;
	struct device___159 dev;
	void *driver_data;
	int resume_status;
};

struct pccard_resource_ops___2 {
	int (*validate_mem)(struct pcmcia_socket___2 *);
	int (*find_io)(struct pcmcia_socket___2 *, unsigned int, unsigned int *, unsigned int, unsigned int, struct resource **);
	struct resource * (*find_mem)(long unsigned int, long unsigned int, long unsigned int, int, struct pcmcia_socket___2 *);
	int (*init)(struct pcmcia_socket___2 *);
	void (*exit)(struct pcmcia_socket___2 *);
};

struct pcmcia_callback___2 {
	struct module___114 *owner;
	int (*add)(struct pcmcia_socket___2 *);
	int (*remove)(struct pcmcia_socket___2 *);
	void (*requery)(struct pcmcia_socket___2 *);
	int (*validate)(struct pcmcia_socket___2 *, unsigned int *);
	int (*suspend)(struct pcmcia_socket___2 *);
	int (*early_resume)(struct pcmcia_socket___2 *);
	int (*resume)(struct pcmcia_socket___2 *);
};

struct device___208;

struct dev_pm_ops___208 {
	int (*prepare)(struct device___208 *);
	void (*complete)(struct device___208 *);
	int (*suspend)(struct device___208 *);
	int (*resume)(struct device___208 *);
	int (*freeze)(struct device___208 *);
	int (*thaw)(struct device___208 *);
	int (*poweroff)(struct device___208 *);
	int (*restore)(struct device___208 *);
	int (*suspend_late)(struct device___208 *);
	int (*resume_early)(struct device___208 *);
	int (*freeze_late)(struct device___208 *);
	int (*thaw_early)(struct device___208 *);
	int (*poweroff_late)(struct device___208 *);
	int (*restore_early)(struct device___208 *);
	int (*suspend_noirq)(struct device___208 *);
	int (*resume_noirq)(struct device___208 *);
	int (*freeze_noirq)(struct device___208 *);
	int (*thaw_noirq)(struct device___208 *);
	int (*poweroff_noirq)(struct device___208 *);
	int (*restore_noirq)(struct device___208 *);
	int (*runtime_suspend)(struct device___208 *);
	int (*runtime_resume)(struct device___208 *);
	int (*runtime_idle)(struct device___208 *);
};

struct dma_map_ops___91;

struct dev_archdata___91 {
	struct dma_map_ops___91 *dma_ops;
	void *iommu;
};

struct acpi_device___25;

struct acpi_dev_node___31 {
	union {
		struct acpi_device___25 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___208;

struct bus_type___208;

struct device_driver___208;

struct dev_pm_domain___208;

struct class___208;

struct device_rh___208;

struct device___208 {
	struct device___208 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___208 *type;
	struct mutex___225 mutex;
	struct bus_type___208 *bus;
	struct device_driver___208 *driver;
	void *platform_data;
	struct dev_pm_info___36 power;
	struct dev_pm_domain___208 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___91 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___31 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___208 *class;
	const struct attribute_group___181 **groups;
	void (*release)(struct device___208 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___208 *device_rh;
};

struct dev_pm_info_rh___208 {
	void (*set_latency_tolerance)(struct device___208 *, s32);
};

struct dev_pm_domain___208 {
	struct dev_pm_ops___208 ops;
};

struct usb_device_id {
	__u16 match_flags;
	__u16 idVendor;
	__u16 idProduct;
	__u16 bcdDevice_lo;
	__u16 bcdDevice_hi;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 bInterfaceNumber;
	kernel_ulong_t driver_info;
};

struct usb_descriptor_header {
	__u8 bLength;
	__u8 bDescriptorType;
};

struct usb_device_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__le16 idVendor;
	__le16 idProduct;
	__le16 bcdDevice;
	__u8 iManufacturer;
	__u8 iProduct;
	__u8 iSerialNumber;
	__u8 bNumConfigurations;
};

struct usb_config_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumInterfaces;
	__u8 bConfigurationValue;
	__u8 iConfiguration;
	__u8 bmAttributes;
	__u8 bMaxPower;
} __attribute__((packed));

struct usb_interface_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bInterfaceNumber;
	__u8 bAlternateSetting;
	__u8 bNumEndpoints;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 iInterface;
};

struct usb_endpoint_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bEndpointAddress;
	__u8 bmAttributes;
	__le16 wMaxPacketSize;
	__u8 bInterval;
	__u8 bRefresh;
	__u8 bSynchAddress;
} __attribute__((packed));

struct usb_ss_ep_comp_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bMaxBurst;
	__u8 bmAttributes;
	__le16 wBytesPerInterval;
};

struct usb_interface_assoc_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bFirstInterface;
	__u8 bInterfaceCount;
	__u8 bFunctionClass;
	__u8 bFunctionSubClass;
	__u8 bFunctionProtocol;
	__u8 iFunction;
};

struct usb_bos_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumDeviceCaps;
} __attribute__((packed));

struct usb_ext_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__le32 bmAttributes;
} __attribute__((packed));

struct usb_ss_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bmAttributes;
	__le16 wSpeedSupported;
	__u8 bFunctionalitySupport;
	__u8 bU1devExitLat;
	__le16 bU2DevExitLat;
};

struct usb_ss_container_id_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bReserved;
	__u8 ContainerID[16];
};

enum usb_device_speed {
	USB_SPEED_UNKNOWN = 0,
	USB_SPEED_LOW = 1,
	USB_SPEED_FULL = 2,
	USB_SPEED_HIGH = 3,
	USB_SPEED_WIRELESS = 4,
	USB_SPEED_SUPER = 5,
};

enum usb_device_state {
	USB_STATE_NOTATTACHED = 0,
	USB_STATE_ATTACHED = 1,
	USB_STATE_POWERED = 2,
	USB_STATE_RECONNECTING = 3,
	USB_STATE_UNAUTHENTICATED = 4,
	USB_STATE_DEFAULT = 5,
	USB_STATE_ADDRESS = 6,
	USB_STATE_CONFIGURED = 7,
	USB_STATE_SUSPENDED = 8,
};

enum usb3_link_state {
	USB3_LPM_U0 = 0,
	USB3_LPM_U1 = 1,
	USB3_LPM_U2 = 2,
	USB3_LPM_U3 = 3,
};

struct dma_map_ops___91 {
	void * (*alloc)(struct device___208 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___208 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___208 *, struct vm_area_struct___231 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___208 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___208 *, struct page___222 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___208 *, dma_addr_t);
	int (*dma_supported)(struct device___208 *, u64);
	int (*set_dma_mask)(struct device___208 *, u64);
	int is_phys;
};

struct bus_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___208 *, char *);
	ssize_t (*store)(struct bus_type___208 *, const char *, size_t);
};

struct device_attribute___208;

struct driver_attribute___208;

struct bus_type___208 {
	const char *name;
	const char *dev_name;
	struct device___208 *dev_root;
	struct bus_attribute___208 *bus_attrs;
	struct device_attribute___208 *dev_attrs;
	struct driver_attribute___208 *drv_attrs;
	const struct attribute_group___181 **bus_groups;
	const struct attribute_group___181 **dev_groups;
	const struct attribute_group___181 **drv_groups;
	int (*match)(struct device___208 *, struct device_driver___208 *);
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	int (*probe)(struct device___208 *);
	int (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*online)(struct device___208 *);
	int (*offline)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct device___208 *, struct device_attribute___208 *, char *);
	ssize_t (*store)(struct device___208 *, struct device_attribute___208 *, const char *, size_t);
};

struct driver_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___208 *, char *);
	ssize_t (*store)(struct device_driver___208 *, const char *, size_t);
};

struct device_driver___208 {
	const char *name;
	struct bus_type___208 *bus;
	struct module___129 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___208 *);
	int (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	const struct attribute_group___181 **groups;
	const struct dev_pm_ops___208 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___208 {
	const char *name;
	const struct attribute_group___181 **groups;
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
};

struct class_attribute___208;

struct class___208 {
	const char *name;
	struct module___129 *owner;
	struct class_attribute___208 *class_attrs;
	struct device_attribute___208 *dev_attrs;
	const struct attribute_group___181 **dev_groups;
	struct bin_attribute___183 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *);
	void (*class_release)(struct class___208 *);
	void (*dev_release)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
	struct subsys_private *p;
};

struct class_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct class___208 *, struct class_attribute___208 *, char *);
	ssize_t (*store)(struct class___208 *, struct class_attribute___208 *, const char *, size_t);
	const void * (*namespace)(struct class___208 *, const struct class_attribute___208 *);
};

struct acpi_scan_handler___25;

struct acpi_hotplug_context___25;

struct acpi_driver___25;

struct acpi_device___25 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___25 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___25 *handler;
	struct acpi_hotplug_context___25 *hp;
	struct acpi_driver___25 *driver;
	void *driver_data;
	struct device___208 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___225 physical_node_lock;
	void (*remove)(struct acpi_device___25 *);
};

struct device_rh___208 {
	struct dev_pm_info_rh___208 power;
};

struct ep_device;

struct usb_host_endpoint {
	struct usb_endpoint_descriptor desc;
	struct usb_ss_ep_comp_descriptor ss_ep_comp;
	char: 8;
	struct list_head urb_list;
	void *hcpriv;
	struct ep_device *ep_dev;
	unsigned char *extra;
	int extralen;
	int enabled;
	int streams;
	int: 32;
} __attribute__((packed));

struct usb_host_interface {
	struct usb_interface_descriptor desc;
	int extralen;
	unsigned char *extra;
	struct usb_host_endpoint *endpoint;
	char *string;
};

enum usb_interface_condition {
	USB_INTERFACE_UNBOUND = 0,
	USB_INTERFACE_BINDING = 1,
	USB_INTERFACE_BOUND = 2,
	USB_INTERFACE_UNBINDING = 3,
};

struct usb_interface {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___208 dev;
	struct device___208 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_interface_cache {
	unsigned int num_altsetting;
	struct kref ref;
	struct usb_host_interface altsetting[0];
};

struct usb_host_config {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_host_bos {
	struct usb_bos_descriptor *desc;
	struct usb_ext_cap_descriptor *ext_cap;
	struct usb_ss_cap_descriptor *ss_cap;
	struct usb_ss_container_id_descriptor *ss_id;
};

struct usb_devmap {
	long unsigned int devicemap[2];
};

struct usb_device;

struct mon_bus;

struct usb_bus {
	struct device___208 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device *root_hub;
	struct usb_bus *hs_companion;
	struct list_head bus_list;
	struct mutex___225 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct wusb_dev;

enum usb_device_removable {
	USB_DEVICE_REMOVABLE_UNKNOWN = 0,
	USB_DEVICE_REMOVABLE = 1,
	USB_DEVICE_FIXED = 2,
};

struct usb2_lpm_parameters {
	unsigned int besl;
	int timeout;
};

struct usb3_lpm_parameters {
	unsigned int mel;
	unsigned int pel;
	unsigned int sel;
	int timeout;
};

struct usb_tt;

struct usb_device {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device *parent;
	struct usb_bus *bus;
	struct usb_host_endpoint ep0;
	struct device___208 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config *config;
	struct usb_host_config *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt {
	struct usb_device *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct usbdrv_wrap {
	struct device_driver___208 driver;
	int for_devices;
};

struct usb_driver {
	const char *name;
	int (*probe)(struct usb_interface *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface *);
	int (*unlocked_ioctl)(struct usb_interface *, unsigned int, void *);
	int (*suspend)(struct usb_interface *, pm_message_t);
	int (*resume)(struct usb_interface *);
	int (*reset_resume)(struct usb_interface *);
	int (*pre_reset)(struct usb_interface *);
	int (*post_reset)(struct usb_interface *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver {
	const char *name;
	int (*probe)(struct usb_device *);
	void (*disconnect)(struct usb_device *);
	int (*suspend)(struct usb_device *, pm_message_t);
	int (*resume)(struct usb_device *, pm_message_t);
	struct usbdrv_wrap drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct usb_iso_packet_descriptor {
	unsigned int offset;
	unsigned int length;
	unsigned int actual_length;
	int status;
};

struct usb_anchor {
	struct list_head urb_list;
	wait_queue_head_t wait;
	spinlock_t lock;
	atomic_t suspend_wakeups;
	unsigned int poisoned: 1;
};

struct urb;

typedef void (*usb_complete_t)(struct urb *);

struct urb {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct giveback_urb_bh {
	bool running;
	spinlock_t lock;
	struct list_head head;
	struct tasklet_struct bh;
	struct usb_host_endpoint *completing_ep;
};

struct usb_phy;

struct dma_pool___2;

struct hc_driver;

struct usb_hcd {
	struct usb_bus self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___225 *bandwidth_mutex;
	struct usb_hcd *shared_hcd;
	struct usb_hcd *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd *);
	int flags;
	int (*reset)(struct usb_hcd *);
	int (*start)(struct usb_hcd *);
	int (*pci_suspend)(struct usb_hcd *, bool);
	int (*pci_resume)(struct usb_hcd *, bool);
	void (*stop)(struct usb_hcd *);
	void (*shutdown)(struct usb_hcd *);
	int (*get_frame_number)(struct usb_hcd *);
	int (*urb_enqueue)(struct usb_hcd *, struct urb *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd *, struct urb *, int);
	int (*map_urb_for_dma)(struct usb_hcd *, struct urb *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd *, struct urb *);
	void (*endpoint_disable)(struct usb_hcd *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd *, char *);
	int (*hub_control)(struct usb_hcd *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd *);
	int (*bus_resume)(struct usb_hcd *);
	int (*start_port_reset)(struct usb_hcd *, unsigned int);
	void (*relinquish_port)(struct usb_hcd *, int);
	int (*port_handed_over)(struct usb_hcd *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd *, struct usb_device *);
	void (*free_dev)(struct usb_hcd *, struct usb_device *);
	int (*alloc_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd *, struct usb_device *);
	void (*reset_bandwidth)(struct usb_hcd *, struct usb_device *);
	int (*address_device)(struct usb_hcd *, struct usb_device *);
	int (*enable_device)(struct usb_hcd *, struct usb_device *);
	int (*update_hub_device)(struct usb_hcd *, struct usb_device *, struct usb_tt *, gfp_t);
	int (*reset_device)(struct usb_hcd *, struct usb_device *);
	int (*update_device)(struct usb_hcd *, struct usb_device *);
	int (*set_usb2_hw_lpm)(struct usb_hcd *, struct usb_device *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd *, int);
	int (*port_power)(struct usb_hcd *, int, bool);
};

struct usb_mon_operations {
	void (*urb_submit)(struct usb_bus *, struct urb *);
	void (*urb_submit_error)(struct usb_bus *, struct urb *, int);
	void (*urb_complete)(struct usb_bus *, struct urb *, int);
};

struct acpi_hotplug_profile___25 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___25 *);
	void (*notify_online)(struct acpi_device___25 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___25 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___25 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___25 *);
	void (*bind)(struct device___208 *);
	void (*unbind)(struct device___208 *);
	struct acpi_hotplug_profile___25 hotplug;
};

struct acpi_hotplug_context___25 {
	struct acpi_device___25 *self;
	int (*notify)(struct acpi_device___25 *, u32);
	void (*uevent)(struct acpi_device___25 *, u32);
	void (*fixup)(struct acpi_device___25 *);
};

typedef int (*acpi_op_add___25)(struct acpi_device___25 *);

typedef int (*acpi_op_remove___25)(struct acpi_device___25 *);

typedef void (*acpi_op_notify___25)(struct acpi_device___25 *, u32);

struct acpi_device_ops___25 {
	acpi_op_add___25 add;
	acpi_op_remove___25 remove;
	acpi_op_notify___25 notify;
};

struct acpi_driver___25 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___25 ops;
	struct device_driver___208 drv;
	struct module___129 *owner;
};

struct find_interface_arg {
	int minor;
	struct device_driver___208 *drv;
};

struct each_dev_arg {
	void *data;
	int (*fn)(struct usb_device *, void *);
};

struct device___209;

struct dev_pm_ops___209 {
	int (*prepare)(struct device___209 *);
	void (*complete)(struct device___209 *);
	int (*suspend)(struct device___209 *);
	int (*resume)(struct device___209 *);
	int (*freeze)(struct device___209 *);
	int (*thaw)(struct device___209 *);
	int (*poweroff)(struct device___209 *);
	int (*restore)(struct device___209 *);
	int (*suspend_late)(struct device___209 *);
	int (*resume_early)(struct device___209 *);
	int (*freeze_late)(struct device___209 *);
	int (*thaw_early)(struct device___209 *);
	int (*poweroff_late)(struct device___209 *);
	int (*restore_early)(struct device___209 *);
	int (*suspend_noirq)(struct device___209 *);
	int (*resume_noirq)(struct device___209 *);
	int (*freeze_noirq)(struct device___209 *);
	int (*thaw_noirq)(struct device___209 *);
	int (*poweroff_noirq)(struct device___209 *);
	int (*restore_noirq)(struct device___209 *);
	int (*runtime_suspend)(struct device___209 *);
	int (*runtime_resume)(struct device___209 *);
	int (*runtime_idle)(struct device___209 *);
};

struct dev_pm_qos___37;

struct dev_pm_info___37 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___37 *qos;
};

struct acpi_device___26;

struct acpi_dev_node___32 {
	union {
		struct acpi_device___26 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___209;

struct bus_type___209;

struct device_driver___209;

struct dev_pm_domain___209;

struct class___209;

struct device_rh___209;

struct device___209 {
	struct device___209 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___209 *type;
	struct mutex___213 mutex;
	struct bus_type___209 *bus;
	struct device_driver___209 *driver;
	void *platform_data;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___209 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___91 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___32 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___209 *class;
	const struct attribute_group___169 **groups;
	void (*release)(struct device___209 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___209 *device_rh;
};

struct dev_pm_qos_request___37;

struct dev_pm_qos___37 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___37 *latency_req;
	struct dev_pm_qos_request___37 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___37 *latency_tolerance_req;
};

struct dev_pm_info_rh___209 {
	void (*set_latency_tolerance)(struct device___209 *, s32);
};

struct dev_pm_domain___209 {
	struct dev_pm_ops___209 ops;
};

struct usb_qualifier_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__u8 bNumConfigurations;
	__u8 bRESERVED;
};

struct usb_set_sel_req {
	__u8 u1_sel;
	__u8 u1_pel;
	__le16 u2_sel;
	__le16 u2_pel;
};

struct bus_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___209 *, char *);
	ssize_t (*store)(struct bus_type___209 *, const char *, size_t);
};

struct device_attribute___209;

struct driver_attribute___209;

struct bus_type___209 {
	const char *name;
	const char *dev_name;
	struct device___209 *dev_root;
	struct bus_attribute___209 *bus_attrs;
	struct device_attribute___209 *dev_attrs;
	struct driver_attribute___209 *drv_attrs;
	const struct attribute_group___169 **bus_groups;
	const struct attribute_group___169 **dev_groups;
	const struct attribute_group___169 **drv_groups;
	int (*match)(struct device___209 *, struct device_driver___209 *);
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	int (*probe)(struct device___209 *);
	int (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*online)(struct device___209 *);
	int (*offline)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct device___209 *, struct device_attribute___209 *, char *);
	ssize_t (*store)(struct device___209 *, struct device_attribute___209 *, const char *, size_t);
};

struct driver_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___209 *, char *);
	ssize_t (*store)(struct device_driver___209 *, const char *, size_t);
};

struct device_driver___209 {
	const char *name;
	struct bus_type___209 *bus;
	struct module___123 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___209 *);
	int (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	const struct attribute_group___169 **groups;
	const struct dev_pm_ops___209 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___209 {
	const char *name;
	const struct attribute_group___169 **groups;
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
};

struct class_attribute___209;

struct class___209 {
	const char *name;
	struct module___123 *owner;
	struct class_attribute___209 *class_attrs;
	struct device_attribute___209 *dev_attrs;
	const struct attribute_group___169 **dev_groups;
	struct bin_attribute___171 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *);
	void (*class_release)(struct class___209 *);
	void (*dev_release)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
	struct subsys_private *p;
};

struct class_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct class___209 *, struct class_attribute___209 *, char *);
	ssize_t (*store)(struct class___209 *, struct class_attribute___209 *, const char *, size_t);
	const void * (*namespace)(struct class___209 *, const struct class_attribute___209 *);
};

struct acpi_scan_handler___26;

struct acpi_hotplug_context___26;

struct acpi_driver___26;

struct acpi_device___26 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___26 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___26 *handler;
	struct acpi_hotplug_context___26 *hp;
	struct acpi_driver___26 *driver;
	void *driver_data;
	struct device___209 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___213 physical_node_lock;
	void (*remove)(struct acpi_device___26 *);
};

struct device_rh___209 {
	struct dev_pm_info_rh___209 power;
};

struct usb_interface___2 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___209 dev;
	struct device___209 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___2 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___2 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___2;

struct usb_bus___2 {
	struct device___209 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___2 *root_hub;
	struct usb_bus___2 *hs_companion;
	struct list_head bus_list;
	struct mutex___213 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___2;

struct usb_device___2 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___2 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___2 *parent;
	struct usb_bus___2 *bus;
	struct usb_host_endpoint ep0;
	struct device___209 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___2 *config;
	struct usb_host_config___2 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

enum usb_port_connect_type {
	USB_PORT_CONNECT_TYPE_UNKNOWN = 0,
	USB_PORT_CONNECT_TYPE_HOT_PLUG = 1,
	USB_PORT_CONNECT_TYPE_HARD_WIRED = 2,
	USB_PORT_NOT_USED = 3,
};

struct usb_tt___2 {
	struct usb_device___2 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___2 {
	struct device_driver___209 driver;
	int for_devices;
};

struct usb_driver___2 {
	const char *name;
	int (*probe)(struct usb_interface___2 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___2 *);
	int (*unlocked_ioctl)(struct usb_interface___2 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___2 *, pm_message_t);
	int (*resume)(struct usb_interface___2 *);
	int (*reset_resume)(struct usb_interface___2 *);
	int (*pre_reset)(struct usb_interface___2 *);
	int (*post_reset)(struct usb_interface___2 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___2 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct urb___2;

typedef void (*usb_complete_t___2)(struct urb___2 *);

struct urb___2 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___2 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___2 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usbdevfs_hub_portinfo {
	char nports;
	char port[127];
};

struct hc_driver___2;

struct usb_phy___2;

struct usb_hcd___2 {
	struct usb_bus___2 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___2 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___2 *driver;
	struct usb_phy___2 *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___213 *bandwidth_mutex;
	struct usb_hcd___2 *shared_hcd;
	struct usb_hcd___2 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___2 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___2 *);
	int flags;
	int (*reset)(struct usb_hcd___2 *);
	int (*start)(struct usb_hcd___2 *);
	int (*pci_suspend)(struct usb_hcd___2 *, bool);
	int (*pci_resume)(struct usb_hcd___2 *, bool);
	void (*stop)(struct usb_hcd___2 *);
	void (*shutdown)(struct usb_hcd___2 *);
	int (*get_frame_number)(struct usb_hcd___2 *);
	int (*urb_enqueue)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___2 *, struct urb___2 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *);
	void (*endpoint_disable)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___2 *, char *);
	int (*hub_control)(struct usb_hcd___2 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___2 *);
	int (*bus_resume)(struct usb_hcd___2 *);
	int (*start_port_reset)(struct usb_hcd___2 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___2 *, int);
	int (*port_handed_over)(struct usb_hcd___2 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*free_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*alloc_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*reset_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*address_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*enable_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_hub_device)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_tt___2 *, gfp_t);
	int (*reset_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___2 *, struct usb_device___2 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___2 *, int);
	int (*port_power)(struct usb_hcd___2 *, int, bool);
};

enum usb_phy_type {
	USB_PHY_TYPE_UNDEFINED = 0,
	USB_PHY_TYPE_USB2 = 1,
	USB_PHY_TYPE_USB3 = 2,
};

enum usb_otg_state {
	OTG_STATE_UNDEFINED = 0,
	OTG_STATE_B_IDLE = 1,
	OTG_STATE_B_SRP_INIT = 2,
	OTG_STATE_B_PERIPHERAL = 3,
	OTG_STATE_B_WAIT_ACON = 4,
	OTG_STATE_B_HOST = 5,
	OTG_STATE_A_IDLE = 6,
	OTG_STATE_A_WAIT_VRISE = 7,
	OTG_STATE_A_WAIT_BCON = 8,
	OTG_STATE_A_HOST = 9,
	OTG_STATE_A_SUSPEND = 10,
	OTG_STATE_A_PERIPHERAL = 11,
	OTG_STATE_A_WAIT_VFALL = 12,
	OTG_STATE_A_VBUS_ERR = 13,
};

enum usb_phy_events {
	USB_EVENT_NONE = 0,
	USB_EVENT_VBUS = 1,
	USB_EVENT_ID = 2,
	USB_EVENT_CHARGER = 3,
	USB_EVENT_ENUMERATED = 4,
};

struct usb_otg;

struct usb_phy_io_ops;

struct usb_phy___2 {
	struct device___209 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_otg_state state;
	enum usb_phy_events last_event;
	struct usb_otg *otg;
	struct device___209 *io_dev;
	struct usb_phy_io_ops *io_ops;
	void *io_priv;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___2 *);
	void (*shutdown)(struct usb_phy___2 *);
	int (*set_vbus)(struct usb_phy___2 *, int);
	int (*set_power)(struct usb_phy___2 *, unsigned int);
	int (*set_suspend)(struct usb_phy___2 *, int);
	int (*notify_connect)(struct usb_phy___2 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___2 *, enum usb_device_speed);
};

struct usb_port_status {
	__le16 wPortStatus;
	__le16 wPortChange;
};

struct usb_hub_status {
	__le16 wHubStatus;
	__le16 wHubChange;
};

struct usb_hub_descriptor {
	__u8 bDescLength;
	__u8 bDescriptorType;
	__u8 bNbrPorts;
	__le16 wHubCharacteristics;
	__u8 bPwrOn2PwrGood;
	__u8 bHubContrCurrent;
	union {
		struct {
			__u8 DeviceRemovable[4];
			__u8 PortPwrCtrlMask[4];
		} hs;
		struct {
			__u8 bHubHdrDecLat;
			__le16 wHubDelay;
			__le16 DeviceRemovable;
		} __attribute__((packed)) ss;
	} u;
} __attribute__((packed));

enum hub_led_mode {
	INDICATOR_AUTO = 0,
	INDICATOR_CYCLE = 1,
	INDICATOR_GREEN_BLINK = 2,
	INDICATOR_GREEN_BLINK_OFF = 3,
	INDICATOR_AMBER_BLINK = 4,
	INDICATOR_AMBER_BLINK_OFF = 5,
	INDICATOR_ALT_BLINK = 6,
	INDICATOR_ALT_BLINK_OFF = 7,
};

struct usb_tt_clear {
	struct list_head clear_list;
	unsigned int tt;
	u16 devinfo;
	struct usb_hcd___2 *hcd;
	struct usb_host_endpoint *ep;
};

struct usb_mon_operations___2 {
	void (*urb_submit)(struct usb_bus___2 *, struct urb___2 *);
	void (*urb_submit_error)(struct usb_bus___2 *, struct urb___2 *, int);
	void (*urb_complete)(struct usb_bus___2 *, struct urb___2 *, int);
};

struct usb_phy_io_ops {
	int (*read)(struct usb_phy___2 *, u32);
	int (*write)(struct usb_phy___2 *, u32, u32);
};

struct usb_gadget;

struct usb_otg {
	u8 default_a;
	struct usb_phy___2 *phy;
	struct usb_bus___2 *host;
	struct usb_gadget *gadget;
	int (*set_host)(struct usb_otg *, struct usb_bus___2 *);
	int (*set_peripheral)(struct usb_otg *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg *, bool);
	int (*start_srp)(struct usb_otg *);
	int (*start_hnp)(struct usb_otg *);
};

struct dev_pm_qos_request___37 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___209 *dev;
};

struct acpi_hotplug_profile___26 {
	struct kobject___22 kobj;
	int (*scan_dependent)(struct acpi_device___26 *);
	void (*notify_online)(struct acpi_device___26 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___26 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___26 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___26 *);
	void (*bind)(struct device___209 *);
	void (*unbind)(struct device___209 *);
	struct acpi_hotplug_profile___26 hotplug;
};

struct acpi_hotplug_context___26 {
	struct acpi_device___26 *self;
	int (*notify)(struct acpi_device___26 *, u32);
	void (*uevent)(struct acpi_device___26 *, u32);
	void (*fixup)(struct acpi_device___26 *);
};

typedef int (*acpi_op_add___26)(struct acpi_device___26 *);

typedef int (*acpi_op_remove___26)(struct acpi_device___26 *);

typedef void (*acpi_op_notify___26)(struct acpi_device___26 *, u32);

struct acpi_device_ops___26 {
	acpi_op_add___26 add;
	acpi_op_remove___26 remove;
	acpi_op_notify___26 notify;
};

struct acpi_driver___26 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___26 ops;
	struct device_driver___209 drv;
	struct module___123 *owner;
};

typedef u32 usb_port_location_t;

struct usb_port;

struct usb_hub {
	struct device___209 *intfdev;
	struct usb_device___2 *hdev;
	struct kref kref;
	struct urb___2 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex___213 status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___2 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port **ports;
};

struct dev_state;

struct usb_port {
	struct usb_device___2 *child;
	struct device___209 dev;
	struct dev_state *port_owner;
	struct usb_port *peer;
	struct dev_pm_qos_request___37 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex___213 status_lock;
	u8 portnum;
	unsigned int is_superspeed: 1;
};

enum hub_activation_type {
	HUB_INIT = 0,
	HUB_INIT2 = 1,
	HUB_INIT3 = 2,
	HUB_POST_RESET = 3,
	HUB_RESUME = 4,
	HUB_RESET_RESUME = 5,
};

enum hub_quiescing_type {
	HUB_DISCONNECT = 0,
	HUB_PRE_RESET = 1,
	HUB_SUSPEND = 2,
};

struct platform_device___10 {
	const char *name;
	int id;
	bool id_auto;
	struct device___165 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct usb_ctrlrequest {
	__u8 bRequestType;
	__u8 bRequest;
	__le16 wValue;
	__le16 wIndex;
	__le16 wLength;
};

struct usb_interface___3 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___165 dev;
	struct device___165 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___3 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___3 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___3;

struct usb_bus___3 {
	struct device___165 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___3 *root_hub;
	struct usb_bus___3 *hs_companion;
	struct list_head bus_list;
	struct mutex___213 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___3;

struct usb_device___3 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___3 *parent;
	struct usb_bus___3 *bus;
	struct usb_host_endpoint ep0;
	struct device___165 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___3 *config;
	struct usb_host_config___3 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___3 {
	struct usb_device___3 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___3;

typedef void (*usb_complete_t___3)(struct urb___3 *);

struct urb___3 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___3 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___3 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

enum usb_led_event {
	USB_LED_EVENT_HOST = 0,
	USB_LED_EVENT_GADGET = 1,
};

struct hc_driver___3;

struct usb_hcd___3 {
	struct usb_bus___3 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___3 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___3 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___213 *bandwidth_mutex;
	struct usb_hcd___3 *shared_hcd;
	struct usb_hcd___3 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___3 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___3 *);
	int flags;
	int (*reset)(struct usb_hcd___3 *);
	int (*start)(struct usb_hcd___3 *);
	int (*pci_suspend)(struct usb_hcd___3 *, bool);
	int (*pci_resume)(struct usb_hcd___3 *, bool);
	void (*stop)(struct usb_hcd___3 *);
	void (*shutdown)(struct usb_hcd___3 *);
	int (*get_frame_number)(struct usb_hcd___3 *);
	int (*urb_enqueue)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___3 *, struct urb___3 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *);
	void (*endpoint_disable)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___3 *, char *);
	int (*hub_control)(struct usb_hcd___3 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___3 *);
	int (*bus_resume)(struct usb_hcd___3 *);
	int (*start_port_reset)(struct usb_hcd___3 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___3 *, int);
	int (*port_handed_over)(struct usb_hcd___3 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*free_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*alloc_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*reset_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*address_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*enable_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_hub_device)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_tt___3 *, gfp_t);
	int (*reset_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___3 *, struct usb_device___3 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___3 *, int);
	int (*port_power)(struct usb_hcd___3 *, int, bool);
};

struct usb_mon_operations___3 {
	void (*urb_submit)(struct usb_bus___3 *, struct urb___3 *);
	void (*urb_submit_error)(struct usb_bus___3 *, struct urb___3 *, int);
	void (*urb_complete)(struct usb_bus___3 *, struct urb___3 *, int);
};

struct device___210;

struct dev_pm_ops___210 {
	int (*prepare)(struct device___210 *);
	void (*complete)(struct device___210 *);
	int (*suspend)(struct device___210 *);
	int (*resume)(struct device___210 *);
	int (*freeze)(struct device___210 *);
	int (*thaw)(struct device___210 *);
	int (*poweroff)(struct device___210 *);
	int (*restore)(struct device___210 *);
	int (*suspend_late)(struct device___210 *);
	int (*resume_early)(struct device___210 *);
	int (*freeze_late)(struct device___210 *);
	int (*thaw_early)(struct device___210 *);
	int (*poweroff_late)(struct device___210 *);
	int (*restore_early)(struct device___210 *);
	int (*suspend_noirq)(struct device___210 *);
	int (*resume_noirq)(struct device___210 *);
	int (*freeze_noirq)(struct device___210 *);
	int (*thaw_noirq)(struct device___210 *);
	int (*poweroff_noirq)(struct device___210 *);
	int (*restore_noirq)(struct device___210 *);
	int (*runtime_suspend)(struct device___210 *);
	int (*runtime_resume)(struct device___210 *);
	int (*runtime_idle)(struct device___210 *);
};

struct dma_map_ops___92;

struct dev_archdata___92 {
	struct dma_map_ops___92 *dma_ops;
	void *iommu;
};

struct acpi_device___27;

struct acpi_dev_node___33 {
	union {
		struct acpi_device___27 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___210;

struct bus_type___210;

struct device_driver___210;

struct dev_pm_domain___210;

struct class___210;

struct device_rh___210;

struct device___210 {
	struct device___210 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___210 *type;
	struct mutex___209 mutex;
	struct bus_type___210 *bus;
	struct device_driver___210 *driver;
	void *platform_data;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___210 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___33 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___210 *class;
	const struct attribute_group___165 **groups;
	void (*release)(struct device___210 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___210 *device_rh;
};

struct dev_pm_info_rh___210 {
	void (*set_latency_tolerance)(struct device___210 *, s32);
};

struct dev_pm_domain___210 {
	struct dev_pm_ops___210 ops;
};

struct dma_map_ops___92 {
	void * (*alloc)(struct device___210 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___210 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___210 *, struct vm_area_struct___215 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___210 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___210 *, struct page___206 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___210 *, dma_addr_t);
	int (*dma_supported)(struct device___210 *, u64);
	int (*set_dma_mask)(struct device___210 *, u64);
	int is_phys;
};

struct bus_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___210 *, char *);
	ssize_t (*store)(struct bus_type___210 *, const char *, size_t);
};

struct device_attribute___210;

struct driver_attribute___210;

struct bus_type___210 {
	const char *name;
	const char *dev_name;
	struct device___210 *dev_root;
	struct bus_attribute___210 *bus_attrs;
	struct device_attribute___210 *dev_attrs;
	struct driver_attribute___210 *drv_attrs;
	const struct attribute_group___165 **bus_groups;
	const struct attribute_group___165 **dev_groups;
	const struct attribute_group___165 **drv_groups;
	int (*match)(struct device___210 *, struct device_driver___210 *);
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	int (*probe)(struct device___210 *);
	int (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*online)(struct device___210 *);
	int (*offline)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct device___210 *, struct device_attribute___210 *, char *);
	ssize_t (*store)(struct device___210 *, struct device_attribute___210 *, const char *, size_t);
};

struct driver_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___210 *, char *);
	ssize_t (*store)(struct device_driver___210 *, const char *, size_t);
};

struct device_driver___210 {
	const char *name;
	struct bus_type___210 *bus;
	struct module___120 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___210 *);
	int (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	const struct attribute_group___165 **groups;
	const struct dev_pm_ops___210 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___210 {
	const char *name;
	const struct attribute_group___165 **groups;
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
};

struct class_attribute___210;

struct class___210 {
	const char *name;
	struct module___120 *owner;
	struct class_attribute___210 *class_attrs;
	struct device_attribute___210 *dev_attrs;
	const struct attribute_group___165 **dev_groups;
	struct bin_attribute___167 *dev_bin_attrs;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *);
	void (*class_release)(struct class___210 *);
	void (*dev_release)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
	struct subsys_private *p;
};

struct class_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct class___210 *, struct class_attribute___210 *, char *);
	ssize_t (*store)(struct class___210 *, struct class_attribute___210 *, const char *, size_t);
	const void * (*namespace)(struct class___210 *, const struct class_attribute___210 *);
};

struct acpi_scan_handler___27;

struct acpi_hotplug_context___27;

struct acpi_driver___27;

struct acpi_device___27 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___27 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___27 *handler;
	struct acpi_hotplug_context___27 *hp;
	struct acpi_driver___27 *driver;
	void *driver_data;
	struct device___210 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___209 physical_node_lock;
	void (*remove)(struct acpi_device___27 *);
};

struct device_rh___210 {
	struct dev_pm_info_rh___210 power;
};

struct usb_interface___4 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___210 dev;
	struct device___210 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___4 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___4 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___4;

struct usb_bus___4 {
	struct device___210 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___4 *root_hub;
	struct usb_bus___4 *hs_companion;
	struct list_head bus_list;
	struct mutex___209 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___4;

struct usb_device___4 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___4 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___4 *parent;
	struct usb_bus___4 *bus;
	struct usb_host_endpoint ep0;
	struct device___210 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___4 *config;
	struct usb_host_config___4 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___4 {
	struct usb_device___4 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___4;

typedef void (*usb_complete_t___4)(struct urb___4 *);

struct urb___4 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___4 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___4 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usb_sg_request {
	int status;
	size_t bytes;
	spinlock_t lock;
	struct usb_device___4 *dev;
	int pipe;
	int entries;
	struct urb___4 **urbs;
	int count;
	struct completion complete;
};

struct hc_driver___4;

struct usb_hcd___4 {
	struct usb_bus___4 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___4 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___4 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___209 *bandwidth_mutex;
	struct usb_hcd___4 *shared_hcd;
	struct usb_hcd___4 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___4 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___4 *);
	int flags;
	int (*reset)(struct usb_hcd___4 *);
	int (*start)(struct usb_hcd___4 *);
	int (*pci_suspend)(struct usb_hcd___4 *, bool);
	int (*pci_resume)(struct usb_hcd___4 *, bool);
	void (*stop)(struct usb_hcd___4 *);
	void (*shutdown)(struct usb_hcd___4 *);
	int (*get_frame_number)(struct usb_hcd___4 *);
	int (*urb_enqueue)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___4 *, struct urb___4 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *);
	void (*endpoint_disable)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___4 *, char *);
	int (*hub_control)(struct usb_hcd___4 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___4 *);
	int (*bus_resume)(struct usb_hcd___4 *);
	int (*start_port_reset)(struct usb_hcd___4 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___4 *, int);
	int (*port_handed_over)(struct usb_hcd___4 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*free_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*alloc_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*reset_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*address_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*enable_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_hub_device)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_tt___4 *, gfp_t);
	int (*reset_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___4 *, struct usb_device___4 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___4 *, int);
	int (*port_power)(struct usb_hcd___4 *, int, bool);
};

struct usb_mon_operations___4 {
	void (*urb_submit)(struct usb_bus___4 *, struct urb___4 *);
	void (*urb_submit_error)(struct usb_bus___4 *, struct urb___4 *, int);
	void (*urb_complete)(struct usb_bus___4 *, struct urb___4 *, int);
};

struct acpi_hotplug_profile___27 {
	struct kobject___22 kobj;
	int (*scan_dependent)(struct acpi_device___27 *);
	void (*notify_online)(struct acpi_device___27 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___27 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___27 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___27 *);
	void (*bind)(struct device___210 *);
	void (*unbind)(struct device___210 *);
	struct acpi_hotplug_profile___27 hotplug;
};

struct acpi_hotplug_context___27 {
	struct acpi_device___27 *self;
	int (*notify)(struct acpi_device___27 *, u32);
	void (*uevent)(struct acpi_device___27 *, u32);
	void (*fixup)(struct acpi_device___27 *);
};

typedef int (*acpi_op_add___27)(struct acpi_device___27 *);

typedef int (*acpi_op_remove___27)(struct acpi_device___27 *);

typedef void (*acpi_op_notify___27)(struct acpi_device___27 *, u32);

struct acpi_device_ops___27 {
	acpi_op_add___27 add;
	acpi_op_remove___27 remove;
	acpi_op_notify___27 notify;
};

struct acpi_driver___27 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___27 ops;
	struct device_driver___210 drv;
	struct module___120 *owner;
};

struct api_context {
	struct completion done;
	int status;
};

struct set_config_request {
	struct usb_device___4 *udev;
	int config;
	struct work_struct work;
	struct list_head node;
};

struct usb_dynid {
	struct list_head node;
	struct usb_device_id id;
};

struct usb_dev_cap_header {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
};

struct page___223;

typedef struct page___223 *pgtable_t___223;

struct address_space___224;

struct kmem_cache___209;

struct page___223 {
	long unsigned int flags;
	struct address_space___224 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___223 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___223 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___209 *slab_cache;
		struct page___223 *first_page;
	};
	long: 64;
};

struct task_struct___225;

struct pv_cpu_ops___225 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___225 *);
	void (*end_context_switch)(struct task_struct___225 *);
};

struct mutex___226 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___225 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___218 {
	struct page___223 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___232;

struct signal_struct___225;

struct task_struct___225 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___225 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___232 *mm;
	struct mm_struct___232 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___225 *real_parent;
	struct task_struct___225 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___225 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___225 = 0,
		VTIME_USER___225 = 1,
		VTIME_SYS___225 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___225 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___226 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___218 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___232 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___232 *, struct mm_struct___232 *);
	void (*dup_mmap)(struct mm_struct___232 *, struct mm_struct___232 *);
	void (*exit_mmap)(struct mm_struct___232 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___232 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___232 *);
	void (*pgd_free)(struct mm_struct___232 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___232 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___232 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___232 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___232 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___232 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___232 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___232 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___232 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___232 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___232 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___232 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___226 lock;
	void *vdso;
} mm_context_t___226;

struct xol_area___223;

struct uprobes_state___223 {
	struct xol_area___223 *xol_area;
};

struct vm_area_struct___232;

struct file___224;

struct core_state___225;

struct mm_struct___232 {
	struct vm_area_struct___232 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___232 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___232 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___226 context;
	long unsigned int flags;
	struct core_state___225 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___225 *owner;
	struct file___224 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___223 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___130;

struct module_kobject___129 {
	struct kobject___24 kobj;
	struct module___130 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___129;

struct module___130 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___129 mkobj;
	struct module_attribute___129 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___225 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct device___211;

struct dev_pm_ops___211 {
	int (*prepare)(struct device___211 *);
	void (*complete)(struct device___211 *);
	int (*suspend)(struct device___211 *);
	int (*resume)(struct device___211 *);
	int (*freeze)(struct device___211 *);
	int (*thaw)(struct device___211 *);
	int (*poweroff)(struct device___211 *);
	int (*restore)(struct device___211 *);
	int (*suspend_late)(struct device___211 *);
	int (*resume_early)(struct device___211 *);
	int (*freeze_late)(struct device___211 *);
	int (*thaw_early)(struct device___211 *);
	int (*poweroff_late)(struct device___211 *);
	int (*restore_early)(struct device___211 *);
	int (*suspend_noirq)(struct device___211 *);
	int (*resume_noirq)(struct device___211 *);
	int (*freeze_noirq)(struct device___211 *);
	int (*thaw_noirq)(struct device___211 *);
	int (*poweroff_noirq)(struct device___211 *);
	int (*restore_noirq)(struct device___211 *);
	int (*runtime_suspend)(struct device___211 *);
	int (*runtime_resume)(struct device___211 *);
	int (*runtime_idle)(struct device___211 *);
};

struct acpi_device___28;

struct acpi_dev_node___34 {
	union {
		struct acpi_device___28 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___211;

struct bus_type___211;

struct device_driver___211;

struct dev_pm_domain___211;

struct class___211;

struct attribute_group___182;

struct device_rh___211;

struct device___211 {
	struct device___211 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___211 *type;
	struct mutex___226 mutex;
	struct bus_type___211 *bus;
	struct device_driver___211 *driver;
	void *platform_data;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___211 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___34 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___211 *class;
	const struct attribute_group___182 **groups;
	void (*release)(struct device___211 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___211 *device_rh;
};

struct dev_pm_info_rh___211 {
	void (*set_latency_tolerance)(struct device___211 *, s32);
};

struct dev_pm_domain___211 {
	struct dev_pm_ops___211 ops;
};

struct smp_ops___225 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___225 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___225;

struct lruvec___225 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___225 *zone;
};

struct pglist_data___225;

struct zone___225 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___225 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___225 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___225 {
	struct zone___225 *zone;
	int zone_idx;
};

struct zonelist___225 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___225 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___225 {
	struct zone___225 node_zones[4];
	struct zonelist___225 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___225 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___184;

struct attribute_group___182 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___184 **bin_attrs;
};

struct bin_attribute___184 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___224 *, struct kobject___24 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___224 *, struct kobject___24 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	int (*mmap)(struct file___224 *, struct kobject___24 *, struct bin_attribute___184 *, struct vm_area_struct___232 *);
};

struct dentry___224;

struct path___224 {
	struct vfsmount *mnt;
	struct dentry___224 *dentry;
};

struct inode___224;

struct file_operations___224;

struct file___224 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___224 f_path;
	struct inode___224 *f_inode;
	const struct file_operations___224 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___224 *f_mapping;
	struct mutex___226 f_pos_lock;
};

struct vm_area_struct___232 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___232 *vm_next;
	struct vm_area_struct___232 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___232 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___224 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___211 *, char *);
	ssize_t (*store)(struct bus_type___211 *, const char *, size_t);
};

struct device_attribute___211;

struct driver_attribute___211;

struct bus_type___211 {
	const char *name;
	const char *dev_name;
	struct device___211 *dev_root;
	struct bus_attribute___211 *bus_attrs;
	struct device_attribute___211 *dev_attrs;
	struct driver_attribute___211 *drv_attrs;
	const struct attribute_group___182 **bus_groups;
	const struct attribute_group___182 **dev_groups;
	const struct attribute_group___182 **drv_groups;
	int (*match)(struct device___211 *, struct device_driver___211 *);
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	int (*probe)(struct device___211 *);
	int (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*online)(struct device___211 *);
	int (*offline)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct device___211 *, struct device_attribute___211 *, char *);
	ssize_t (*store)(struct device___211 *, struct device_attribute___211 *, const char *, size_t);
};

struct driver_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___211 *, char *);
	ssize_t (*store)(struct device_driver___211 *, const char *, size_t);
};

struct device_driver___211 {
	const char *name;
	struct bus_type___211 *bus;
	struct module___130 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___211 *);
	int (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	const struct attribute_group___182 **groups;
	const struct dev_pm_ops___211 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___211 {
	const char *name;
	const struct attribute_group___182 **groups;
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
};

struct class_attribute___211;

struct class___211 {
	const char *name;
	struct module___130 *owner;
	struct class_attribute___211 *class_attrs;
	struct device_attribute___211 *dev_attrs;
	const struct attribute_group___182 **dev_groups;
	struct bin_attribute___184 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *);
	void (*class_release)(struct class___211 *);
	void (*dev_release)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
	struct subsys_private *p;
};

struct class_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct class___211 *, struct class_attribute___211 *, char *);
	ssize_t (*store)(struct class___211 *, struct class_attribute___211 *, const char *, size_t);
	const void * (*namespace)(struct class___211 *, const struct class_attribute___211 *);
};

struct acpi_scan_handler___28;

struct acpi_hotplug_context___28;

struct acpi_driver___28;

struct acpi_device___28 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___28 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___28 *handler;
	struct acpi_hotplug_context___28 *hp;
	struct acpi_driver___28 *driver;
	void *driver_data;
	struct device___211 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___226 physical_node_lock;
	void (*remove)(struct acpi_device___28 *);
};

struct device_rh___211 {
	struct dev_pm_info_rh___211 power;
};

struct dentry_operations___224;

struct super_block___224;

struct dentry___224 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___224 *d_parent;
	struct qstr d_name;
	struct inode___224 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___224 *d_op;
	struct super_block___224 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___224;

struct address_space___224 {
	struct inode___224 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___226 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___224 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___224;

struct file_lock___224;

struct dquot___224;

struct block_device___224;

struct inode___224 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___224 *i_op;
	struct super_block___224 *i_sb;
	struct address_space___224 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___226 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___224 *i_fop;
	struct file_lock___224 *i_flock;
	struct address_space___224 i_data;
	struct dquot___224 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___224 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___224 {
	int (*d_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_hash)(const struct dentry___224 *, struct qstr *);
	int (*d_compare)(const struct dentry___224 *, const struct dentry___224 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___224 *);
	void (*d_release)(struct dentry___224 *);
	void (*d_prune)(struct dentry___224 *);
	void (*d_iput)(struct dentry___224 *, struct inode___224 *);
	char * (*d_dname)(struct dentry___224 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___224 *);
	int (*d_manage)(struct dentry___224 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___224;

struct mem_dqinfo___224 {
	struct quota_format_type___224 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___224;

struct quota_info___224 {
	unsigned int flags;
	struct mutex___226 dqio_mutex;
	struct mutex___226 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___224 *files[2];
	struct mem_dqinfo___224 info[2];
	const struct quota_format_ops___224 *ops[2];
};

struct file_system_type___224;

struct super_operations___224;

struct dquot_operations___224;

struct quotactl_ops___224;

struct super_block___224 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___224 *s_type;
	const struct super_operations___224 *s_op;
	const struct dquot_operations___224 *dq_op;
	const struct quotactl_ops___224 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___224 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___224 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___224 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___226 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___224 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___224 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___224 *bd_inode;
	struct super_block___224 *bd_super;
	struct mutex___226 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___224 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___226 bd_fsfreeze_mutex;
};

struct iattr___224 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___224 *ia_file;
};

struct dquot___224 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___226 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___224 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___224 {
	int qf_fmt_id;
	const struct quota_format_ops___224 *qf_ops;
	struct module___130 *qf_owner;
	struct quota_format_type___224 *qf_next;
};

struct quota_format_ops___224 {
	int (*check_quota_file)(struct super_block___224 *, int);
	int (*read_file_info)(struct super_block___224 *, int);
	int (*write_file_info)(struct super_block___224 *, int);
	int (*free_file_info)(struct super_block___224 *, int);
	int (*read_dqblk)(struct dquot___224 *);
	int (*commit_dqblk)(struct dquot___224 *);
	int (*release_dqblk)(struct dquot___224 *);
};

struct dquot_operations___224 {
	int (*write_dquot)(struct dquot___224 *);
	struct dquot___224 * (*alloc_dquot)(struct super_block___224 *, int);
	void (*destroy_dquot)(struct dquot___224 *);
	int (*acquire_dquot)(struct dquot___224 *);
	int (*release_dquot)(struct dquot___224 *);
	int (*mark_dirty)(struct dquot___224 *);
	int (*write_info)(struct super_block___224 *, int);
	qsize_t * (*get_reserved_space)(struct inode___224 *);
};

struct quotactl_ops___224 {
	int (*quota_on)(struct super_block___224 *, int, int, struct path___224 *);
	int (*quota_on_meta)(struct super_block___224 *, int, int);
	int (*quota_off)(struct super_block___224 *, int);
	int (*quota_sync)(struct super_block___224 *, int);
	int (*get_info)(struct super_block___224 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___224 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___224 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___224 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___224 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___224 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___224 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___224 *, unsigned int);
};

struct address_space_operations___224 {
	int (*writepage)(struct page___223 *, struct writeback_control *);
	int (*readpage)(struct file___224 *, struct page___223 *);
	int (*writepages)(struct address_space___224 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___223 *);
	int (*readpages)(struct file___224 *, struct address_space___224 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___224 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___223 **, void **);
	int (*write_end)(struct file___224 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___223 *, void *);
	sector_t (*bmap)(struct address_space___224 *, sector_t);
	void (*invalidatepage)(struct page___223 *, long unsigned int);
	int (*releasepage)(struct page___223 *, gfp_t);
	void (*freepage)(struct page___223 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___224 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___224 *, struct page___223 *, struct page___223 *, enum migrate_mode);
	int (*launder_page)(struct page___223 *);
	int (*is_partially_uptodate)(struct page___223 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___223 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___224 *, struct page___223 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___224 *, sector_t *);
	void (*swap_deactivate)(struct file___224 *);
	void (*invalidatepage_range)(struct page___223 *, unsigned int, unsigned int);
};

struct inode_operations___224 {
	struct dentry___224 * (*lookup)(struct inode___224 *, struct dentry___224 *, unsigned int);
	void * (*follow_link)(struct dentry___224 *, struct nameidata *);
	int (*permission)(struct inode___224 *, int);
	struct posix_acl * (*get_acl)(struct inode___224 *, int);
	int (*readlink)(struct dentry___224 *, char *, int);
	void (*put_link)(struct dentry___224 *, struct nameidata *, void *);
	int (*create)(struct inode___224 *, struct dentry___224 *, umode_t, bool);
	int (*link)(struct dentry___224 *, struct inode___224 *, struct dentry___224 *);
	int (*unlink)(struct inode___224 *, struct dentry___224 *);
	int (*symlink)(struct inode___224 *, struct dentry___224 *, const char *);
	int (*mkdir)(struct inode___224 *, struct dentry___224 *, umode_t);
	int (*rmdir)(struct inode___224 *, struct dentry___224 *);
	int (*mknod)(struct inode___224 *, struct dentry___224 *, umode_t, dev_t);
	int (*rename)(struct inode___224 *, struct dentry___224 *, struct inode___224 *, struct dentry___224 *);
	int (*setattr)(struct dentry___224 *, struct iattr___224 *);
	int (*getattr)(struct vfsmount *, struct dentry___224 *, struct kstat *);
	int (*setxattr)(struct dentry___224 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___224 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___224 *, char *, size_t);
	int (*removexattr)(struct dentry___224 *, const char *);
	int (*fiemap)(struct inode___224 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___224 *, struct timespec *, int);
	int (*atomic_open)(struct inode___224 *, struct dentry___224 *, struct file___224 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___224 {
	struct module___130 *owner;
	loff_t (*llseek)(struct file___224 *, loff_t, int);
	ssize_t (*read)(struct file___224 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___224 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___224 *, void *, filldir_t);
	unsigned int (*poll)(struct file___224 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___224 *, struct vm_area_struct___232 *);
	int (*open)(struct inode___224 *, struct file___224 *);
	int (*flush)(struct file___224 *, fl_owner_t);
	int (*release)(struct inode___224 *, struct file___224 *);
	int (*fsync)(struct file___224 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___224 *, int);
	int (*lock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*sendpage)(struct file___224 *, struct page___223 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___224 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___224 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___224 *, long int, struct file_lock___224 **, void **);
		struct {
			int (*setlease)(struct file___224 *, long int, struct file_lock___224 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___224 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___224 *);
};

struct fasync_struct___224;

struct file_lock_operations___224;

struct lock_manager_operations___224;

struct file_lock___224 {
	struct file_lock___224 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___224 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___224 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___224 *fl_ops;
	const struct lock_manager_operations___224 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___224 {
	void (*fl_copy_lock)(struct file_lock___224 *, struct file_lock___224 *);
	void (*fl_release_private)(struct file_lock___224 *);
};

struct lock_manager_operations___224 {
	int (*lm_compare_owner)(struct file_lock___224 *, struct file_lock___224 *);
	long unsigned int (*lm_owner_key)(struct file_lock___224 *);
	void (*lm_notify)(struct file_lock___224 *);
	int (*lm_grant)(struct file_lock___224 *, struct file_lock___224 *, int);
	void (*lm_break)(struct file_lock___224 *);
	int (*lm_change)(struct file_lock___224 **, int);
};

struct fasync_struct___224 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___224 *fa_next;
	struct file___224 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___224 {
	const char *name;
	int fs_flags;
	struct dentry___224 * (*mount)(struct file_system_type___224 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___224 *);
	struct module___130 *owner;
	struct file_system_type___224 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___224 {
	struct inode___224 * (*alloc_inode)(struct super_block___224 *);
	void (*destroy_inode)(struct inode___224 *);
	void (*dirty_inode)(struct inode___224 *, int);
	int (*write_inode)(struct inode___224 *, struct writeback_control *);
	int (*drop_inode)(struct inode___224 *);
	void (*evict_inode)(struct inode___224 *);
	void (*put_super)(struct super_block___224 *);
	int (*sync_fs)(struct super_block___224 *, int);
	int (*freeze_fs)(struct super_block___224 *);
	int (*unfreeze_fs)(struct super_block___224 *);
	int (*statfs)(struct dentry___224 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___224 *, int *, char *);
	void (*umount_begin)(struct super_block___224 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___224 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___224 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___224 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___224 *);
	ssize_t (*quota_read)(struct super_block___224 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___224 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___224 *);
	int (*bdev_try_to_free_page)(struct super_block___224 *, struct page___223 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___224 *);
	void (*free_cached_objects)(struct super_block___224 *, int);
};

struct xol_area___223 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___223 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___208;

struct memcg_cache_params___209;

struct kmem_cache___209 {
	struct kmem_cache_cpu___208 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___209 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct core_thread___225 {
	struct task_struct___225 *task;
	struct core_thread___225 *next;
};

struct core_state___225 {
	atomic_t nr_threads;
	struct core_thread___225 dumper;
	struct completion startup;
};

struct signal_struct___225 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___225 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___225 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___226 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___5 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___211 dev;
	struct device___211 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___5 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___5 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___5;

struct usb_bus___5 {
	struct device___211 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___5 *root_hub;
	struct usb_bus___5 *hs_companion;
	struct list_head bus_list;
	struct mutex___226 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___5;

struct usb_device___5 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___5 *parent;
	struct usb_bus___5 *bus;
	struct usb_host_endpoint ep0;
	struct device___211 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___5 *config;
	struct usb_host_config___5 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___5 {
	struct usb_device___5 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___5;

typedef void (*usb_complete_t___5)(struct urb___5 *);

struct urb___5 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___5 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___5 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usb_mon_operations___5 {
	void (*urb_submit)(struct usb_bus___5 *, struct urb___5 *);
	void (*urb_submit_error)(struct usb_bus___5 *, struct urb___5 *, int);
	void (*urb_complete)(struct usb_bus___5 *, struct urb___5 *, int);
};

struct module_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___129 *, struct module_kobject___129 *, char *);
	ssize_t (*store)(struct module_attribute___129 *, struct module_kobject___129 *, const char *, size_t);
	void (*setup)(struct module___130 *, const char *);
	int (*test)(struct module___130 *);
	void (*free)(struct module___130 *);
};

struct kmem_cache_cpu___208 {
	void **freelist;
	long unsigned int tid;
	struct page___223 *page;
	struct page___223 *partial;
};

struct memcg_cache_params___209 {
	bool is_root_cache;
	union {
		struct kmem_cache___209 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___209 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct acpi_hotplug_profile___28 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___28 *);
	void (*notify_online)(struct acpi_device___28 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___28 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___28 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___28 *);
	void (*bind)(struct device___211 *);
	void (*unbind)(struct device___211 *);
	struct acpi_hotplug_profile___28 hotplug;
};

struct acpi_hotplug_context___28 {
	struct acpi_device___28 *self;
	int (*notify)(struct acpi_device___28 *, u32);
	void (*uevent)(struct acpi_device___28 *, u32);
	void (*fixup)(struct acpi_device___28 *);
};

typedef int (*acpi_op_add___28)(struct acpi_device___28 *);

typedef int (*acpi_op_remove___28)(struct acpi_device___28 *);

typedef void (*acpi_op_notify___28)(struct acpi_device___28 *, u32);

struct acpi_device_ops___28 {
	acpi_op_add___28 add;
	acpi_op_remove___28 remove;
	acpi_op_notify___28 notify;
};

struct acpi_driver___28 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___28 ops;
	struct device_driver___211 drv;
	struct module___130 *owner;
};

struct usb_class_driver {
	char *name;
	char * (*devnode)(struct device___208 *, umode_t *);
	const struct file_operations___223 *fops;
	int minor_base;
};

struct usb_class {
	struct kref kref;
	struct class___208 *class;
};

struct usbdrv_wrap___3 {
	struct device_driver___211 driver;
	int for_devices;
};

struct usb_driver___3 {
	const char *name;
	int (*probe)(struct usb_interface___5 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___5 *);
	int (*unlocked_ioctl)(struct usb_interface___5 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___5 *, pm_message_t);
	int (*resume)(struct usb_interface___5 *);
	int (*reset_resume)(struct usb_interface___5 *);
	int (*pre_reset)(struct usb_interface___5 *);
	int (*post_reset)(struct usb_interface___5 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___3 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct ep_device {
	struct usb_endpoint_descriptor *desc;
	struct usb_device *udev;
	struct device___208 dev;
};

struct page___224;

typedef struct page___224 *pgtable_t___224;

struct address_space___225;

struct kmem_cache___210;

struct page___224 {
	long unsigned int flags;
	struct address_space___225 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___224 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___224 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___210 *slab_cache;
		struct page___224 *first_page;
	};
	long: 64;
};

struct task_struct___226;

struct pv_cpu_ops___226 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___226 *);
	void (*end_context_switch)(struct task_struct___226 *);
};

struct mutex___227 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___226 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___219 {
	struct page___224 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___233;

struct signal_struct___226;

struct task_struct___226 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___226 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___233 *mm;
	struct mm_struct___233 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___226 *real_parent;
	struct task_struct___226 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___226 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___226 = 0,
		VTIME_USER___226 = 1,
		VTIME_SYS___226 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___116 *nsproxy;
	struct signal_struct___226 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___227 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___219 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___233 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___233 *, struct mm_struct___233 *);
	void (*dup_mmap)(struct mm_struct___233 *, struct mm_struct___233 *);
	void (*exit_mmap)(struct mm_struct___233 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___233 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___233 *);
	void (*pgd_free)(struct mm_struct___233 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___233 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___233 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___233 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___233 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___233 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___233 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___233 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___233 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___233 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___233 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___233 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___227 lock;
	void *vdso;
} mm_context_t___227;

struct xol_area___224;

struct uprobes_state___224 {
	struct xol_area___224 *xol_area;
};

struct vm_area_struct___233;

struct file___225;

struct core_state___226;

struct mm_struct___233 {
	struct vm_area_struct___233 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___233 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___233 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___227 context;
	long unsigned int flags;
	struct core_state___226 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___226 *owner;
	struct file___225 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___224 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___131;

struct exec_domain___58 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___131 *module;
	struct exec_domain___58 *next;
};

struct module_kobject___130 {
	struct kobject___24 kobj;
	struct module___131 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___130;

struct module___131 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___130 mkobj;
	struct module_attribute___130 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___226 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___98 {
	struct task_struct___226 *task;
	struct exec_domain___58 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct inode___225;

struct dentry_operations___225;

struct super_block___225;

struct dentry___225 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___225 *d_parent;
	struct qstr d_name;
	struct inode___225 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___225 *d_op;
	struct super_block___225 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___225;

struct address_space___225 {
	struct inode___225 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___227 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___225 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___225;

struct file_operations___225;

struct file_lock___225;

struct dquot___225;

struct block_device___225;

struct cdev___59;

struct inode___225 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___225 *i_op;
	struct super_block___225 *i_sb;
	struct address_space___225 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___227 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___225 *i_fop;
	struct file_lock___225 *i_flock;
	struct address_space___225 i_data;
	struct dquot___225 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___225 *i_bdev;
		struct cdev___59 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___225;

struct dentry_operations___225 {
	int (*d_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_hash)(const struct dentry___225 *, struct qstr *);
	int (*d_compare)(const struct dentry___225 *, const struct dentry___225 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___225 *);
	void (*d_release)(struct dentry___225 *);
	void (*d_prune)(struct dentry___225 *);
	void (*d_iput)(struct dentry___225 *, struct inode___225 *);
	char * (*d_dname)(struct dentry___225 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___225 *);
	int (*d_manage)(struct dentry___225 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___225;

struct mem_dqinfo___225 {
	struct quota_format_type___225 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___225;

struct quota_info___225 {
	unsigned int flags;
	struct mutex___227 dqio_mutex;
	struct mutex___227 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___225 *files[2];
	struct mem_dqinfo___225 info[2];
	const struct quota_format_ops___225 *ops[2];
};

struct file_system_type___225;

struct super_operations___225;

struct dquot_operations___225;

struct quotactl_ops___225;

struct super_block___225 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___225 *s_type;
	const struct super_operations___225 *s_op;
	const struct dquot_operations___225 *dq_op;
	const struct quotactl_ops___225 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___225 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___225 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___225 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___227 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___225 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___225 {
	struct vfsmount *mnt;
	struct dentry___225 *dentry;
};

struct device___212;

struct dev_pm_ops___212 {
	int (*prepare)(struct device___212 *);
	void (*complete)(struct device___212 *);
	int (*suspend)(struct device___212 *);
	int (*resume)(struct device___212 *);
	int (*freeze)(struct device___212 *);
	int (*thaw)(struct device___212 *);
	int (*poweroff)(struct device___212 *);
	int (*restore)(struct device___212 *);
	int (*suspend_late)(struct device___212 *);
	int (*resume_early)(struct device___212 *);
	int (*freeze_late)(struct device___212 *);
	int (*thaw_early)(struct device___212 *);
	int (*poweroff_late)(struct device___212 *);
	int (*restore_early)(struct device___212 *);
	int (*suspend_noirq)(struct device___212 *);
	int (*resume_noirq)(struct device___212 *);
	int (*freeze_noirq)(struct device___212 *);
	int (*thaw_noirq)(struct device___212 *);
	int (*poweroff_noirq)(struct device___212 *);
	int (*restore_noirq)(struct device___212 *);
	int (*runtime_suspend)(struct device___212 *);
	int (*runtime_resume)(struct device___212 *);
	int (*runtime_idle)(struct device___212 *);
};

struct acpi_device___29;

struct acpi_dev_node___35 {
	union {
		struct acpi_device___29 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct device_type___212;

struct bus_type___212;

struct device_driver___212;

struct dev_pm_domain___212;

struct class___212;

struct attribute_group___183;

struct device_rh___212;

struct device___212 {
	struct device___212 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___212 *type;
	struct mutex___227 mutex;
	struct bus_type___212 *bus;
	struct device_driver___212 *driver;
	void *platform_data;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___212 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___35 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___212 *class;
	const struct attribute_group___183 **groups;
	void (*release)(struct device___212 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___212 *device_rh;
};

struct dev_pm_info_rh___212 {
	void (*set_latency_tolerance)(struct device___212 *, s32);
};

struct dev_pm_domain___212 {
	struct dev_pm_ops___212 ops;
};

struct smp_ops___226 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___226 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___225 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___225 *bd_inode;
	struct super_block___225 *bd_super;
	struct mutex___227 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___225 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___227 bd_fsfreeze_mutex;
};

struct iattr___225 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___225 *ia_file;
};

struct file___225 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___225 f_path;
	struct inode___225 *f_inode;
	const struct file_operations___225 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___225 *f_mapping;
	struct mutex___227 f_pos_lock;
};

struct zone___226;

struct lruvec___226 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___226 *zone;
};

struct pglist_data___226;

struct zone___226 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___226 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___226 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___226 {
	struct zone___226 *zone;
	int zone_idx;
};

struct zonelist___226 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___226 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___226 {
	struct zone___226 node_zones[4];
	struct zonelist___226 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___226 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___225 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___227 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___225 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___225 {
	int qf_fmt_id;
	const struct quota_format_ops___225 *qf_ops;
	struct module___131 *qf_owner;
	struct quota_format_type___225 *qf_next;
};

struct quota_format_ops___225 {
	int (*check_quota_file)(struct super_block___225 *, int);
	int (*read_file_info)(struct super_block___225 *, int);
	int (*write_file_info)(struct super_block___225 *, int);
	int (*free_file_info)(struct super_block___225 *, int);
	int (*read_dqblk)(struct dquot___225 *);
	int (*commit_dqblk)(struct dquot___225 *);
	int (*release_dqblk)(struct dquot___225 *);
};

struct dquot_operations___225 {
	int (*write_dquot)(struct dquot___225 *);
	struct dquot___225 * (*alloc_dquot)(struct super_block___225 *, int);
	void (*destroy_dquot)(struct dquot___225 *);
	int (*acquire_dquot)(struct dquot___225 *);
	int (*release_dquot)(struct dquot___225 *);
	int (*mark_dirty)(struct dquot___225 *);
	int (*write_info)(struct super_block___225 *, int);
	qsize_t * (*get_reserved_space)(struct inode___225 *);
};

struct quotactl_ops___225 {
	int (*quota_on)(struct super_block___225 *, int, int, struct path___225 *);
	int (*quota_on_meta)(struct super_block___225 *, int, int);
	int (*quota_off)(struct super_block___225 *, int);
	int (*quota_sync)(struct super_block___225 *, int);
	int (*get_info)(struct super_block___225 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___225 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___225 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___225 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___225 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___225 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___225 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___225 *, unsigned int);
};

struct address_space_operations___225 {
	int (*writepage)(struct page___224 *, struct writeback_control *);
	int (*readpage)(struct file___225 *, struct page___224 *);
	int (*writepages)(struct address_space___225 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___224 *);
	int (*readpages)(struct file___225 *, struct address_space___225 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___225 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___224 **, void **);
	int (*write_end)(struct file___225 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___224 *, void *);
	sector_t (*bmap)(struct address_space___225 *, sector_t);
	void (*invalidatepage)(struct page___224 *, long unsigned int);
	int (*releasepage)(struct page___224 *, gfp_t);
	void (*freepage)(struct page___224 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___225 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___225 *, struct page___224 *, struct page___224 *, enum migrate_mode);
	int (*launder_page)(struct page___224 *);
	int (*is_partially_uptodate)(struct page___224 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___224 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___225 *, struct page___224 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___225 *, sector_t *);
	void (*swap_deactivate)(struct file___225 *);
	void (*invalidatepage_range)(struct page___224 *, unsigned int, unsigned int);
};

struct cdev___59 {
	struct kobject___24 kobj;
	struct module___131 *owner;
	const struct file_operations___225 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___225 {
	struct dentry___225 * (*lookup)(struct inode___225 *, struct dentry___225 *, unsigned int);
	void * (*follow_link)(struct dentry___225 *, struct nameidata *);
	int (*permission)(struct inode___225 *, int);
	struct posix_acl * (*get_acl)(struct inode___225 *, int);
	int (*readlink)(struct dentry___225 *, char *, int);
	void (*put_link)(struct dentry___225 *, struct nameidata *, void *);
	int (*create)(struct inode___225 *, struct dentry___225 *, umode_t, bool);
	int (*link)(struct dentry___225 *, struct inode___225 *, struct dentry___225 *);
	int (*unlink)(struct inode___225 *, struct dentry___225 *);
	int (*symlink)(struct inode___225 *, struct dentry___225 *, const char *);
	int (*mkdir)(struct inode___225 *, struct dentry___225 *, umode_t);
	int (*rmdir)(struct inode___225 *, struct dentry___225 *);
	int (*mknod)(struct inode___225 *, struct dentry___225 *, umode_t, dev_t);
	int (*rename)(struct inode___225 *, struct dentry___225 *, struct inode___225 *, struct dentry___225 *);
	int (*setattr)(struct dentry___225 *, struct iattr___225 *);
	int (*getattr)(struct vfsmount *, struct dentry___225 *, struct kstat *);
	int (*setxattr)(struct dentry___225 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___225 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___225 *, char *, size_t);
	int (*removexattr)(struct dentry___225 *, const char *);
	int (*fiemap)(struct inode___225 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___225 *, struct timespec *, int);
	int (*atomic_open)(struct inode___225 *, struct dentry___225 *, struct file___225 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___120;

struct file_operations___225 {
	struct module___131 *owner;
	loff_t (*llseek)(struct file___225 *, loff_t, int);
	ssize_t (*read)(struct file___225 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___225 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___225 *, void *, filldir_t);
	unsigned int (*poll)(struct file___225 *, struct poll_table_struct___120 *);
	long int (*unlocked_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___225 *, struct vm_area_struct___233 *);
	int (*open)(struct inode___225 *, struct file___225 *);
	int (*flush)(struct file___225 *, fl_owner_t);
	int (*release)(struct inode___225 *, struct file___225 *);
	int (*fsync)(struct file___225 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___225 *, int);
	int (*lock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*sendpage)(struct file___225 *, struct page___224 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___225 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___225 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___225 *, long int, struct file_lock___225 **, void **);
		struct {
			int (*setlease)(struct file___225 *, long int, struct file_lock___225 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___225 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___225 *);
};

struct fasync_struct___225;

struct file_lock_operations___225;

struct lock_manager_operations___225;

struct file_lock___225 {
	struct file_lock___225 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___225 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___225 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___225 *fl_ops;
	const struct lock_manager_operations___225 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___225 {
	void (*fl_copy_lock)(struct file_lock___225 *, struct file_lock___225 *);
	void (*fl_release_private)(struct file_lock___225 *);
};

struct lock_manager_operations___225 {
	int (*lm_compare_owner)(struct file_lock___225 *, struct file_lock___225 *);
	long unsigned int (*lm_owner_key)(struct file_lock___225 *);
	void (*lm_notify)(struct file_lock___225 *);
	int (*lm_grant)(struct file_lock___225 *, struct file_lock___225 *, int);
	void (*lm_break)(struct file_lock___225 *);
	int (*lm_change)(struct file_lock___225 **, int);
};

struct fasync_struct___225 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___225 *fa_next;
	struct file___225 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___225 {
	const char *name;
	int fs_flags;
	struct dentry___225 * (*mount)(struct file_system_type___225 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___225 *);
	struct module___131 *owner;
	struct file_system_type___225 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___225 {
	struct inode___225 * (*alloc_inode)(struct super_block___225 *);
	void (*destroy_inode)(struct inode___225 *);
	void (*dirty_inode)(struct inode___225 *, int);
	int (*write_inode)(struct inode___225 *, struct writeback_control *);
	int (*drop_inode)(struct inode___225 *);
	void (*evict_inode)(struct inode___225 *);
	void (*put_super)(struct super_block___225 *);
	int (*sync_fs)(struct super_block___225 *, int);
	int (*freeze_fs)(struct super_block___225 *);
	int (*unfreeze_fs)(struct super_block___225 *);
	int (*statfs)(struct dentry___225 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___225 *, int *, char *);
	void (*umount_begin)(struct super_block___225 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___225 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___225 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___225 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___225 *);
	ssize_t (*quota_read)(struct super_block___225 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___225 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___225 *);
	int (*bdev_try_to_free_page)(struct super_block___225 *, struct page___224 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___225 *);
	void (*free_cached_objects)(struct super_block___225 *, int);
};

typedef void (*poll_queue_proc___122)(struct file___225 *, wait_queue_head_t *, struct poll_table_struct___120 *);

struct poll_table_struct___120 {
	poll_queue_proc___122 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___204;

struct vm_area_struct___233 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___233 *vm_next;
	struct vm_area_struct___233 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___233 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___204 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___225 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xol_area___224 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___224 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___209;

struct memcg_cache_params___210;

struct kmem_cache___210 {
	struct kmem_cache_cpu___209 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___210 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___200;

struct vm_operations_struct___204 {
	void (*open)(struct vm_area_struct___233 *);
	void (*close)(struct vm_area_struct___233 *);
	int (*fault)(struct vm_area_struct___233 *, struct vm_fault___200 *);
	int (*page_mkwrite)(struct vm_area_struct___233 *, struct vm_fault___200 *);
	int (*access)(struct vm_area_struct___233 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___233 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___233 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___233 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___233 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___226 {
	struct task_struct___226 *task;
	struct core_thread___226 *next;
};

struct core_state___226 {
	atomic_t nr_threads;
	struct core_thread___226 dumper;
	struct completion startup;
};

struct vm_fault___200 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___224 *page;
};

struct bin_attribute___185;

struct attribute_group___183 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___185 **bin_attrs;
};

struct bin_attribute___185 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___225 *, struct kobject___24 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___225 *, struct kobject___24 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	int (*mmap)(struct file___225 *, struct kobject___24 *, struct bin_attribute___185 *, struct vm_area_struct___233 *);
};

struct kmem_cache_cpu___209 {
	void **freelist;
	long unsigned int tid;
	struct page___224 *page;
	struct page___224 *partial;
};

struct memcg_cache_params___210 {
	bool is_root_cache;
	union {
		struct kmem_cache___210 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___210 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

typedef struct poll_table_struct___120 poll_table___27;

struct module_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___130 *, struct module_kobject___130 *, char *);
	ssize_t (*store)(struct module_attribute___130 *, struct module_kobject___130 *, const char *, size_t);
	void (*setup)(struct module___131 *, const char *);
	int (*test)(struct module___131 *);
	void (*free)(struct module___131 *);
};

struct bus_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___212 *, char *);
	ssize_t (*store)(struct bus_type___212 *, const char *, size_t);
};

struct device_attribute___212;

struct driver_attribute___212;

struct bus_type___212 {
	const char *name;
	const char *dev_name;
	struct device___212 *dev_root;
	struct bus_attribute___212 *bus_attrs;
	struct device_attribute___212 *dev_attrs;
	struct driver_attribute___212 *drv_attrs;
	const struct attribute_group___183 **bus_groups;
	const struct attribute_group___183 **dev_groups;
	const struct attribute_group___183 **drv_groups;
	int (*match)(struct device___212 *, struct device_driver___212 *);
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	int (*probe)(struct device___212 *);
	int (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*online)(struct device___212 *);
	int (*offline)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct device___212 *, struct device_attribute___212 *, char *);
	ssize_t (*store)(struct device___212 *, struct device_attribute___212 *, const char *, size_t);
};

struct driver_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___212 *, char *);
	ssize_t (*store)(struct device_driver___212 *, const char *, size_t);
};

struct device_driver___212 {
	const char *name;
	struct bus_type___212 *bus;
	struct module___131 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___212 *);
	int (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	const struct attribute_group___183 **groups;
	const struct dev_pm_ops___212 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___212 {
	const char *name;
	const struct attribute_group___183 **groups;
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
};

struct class_attribute___212;

struct class___212 {
	const char *name;
	struct module___131 *owner;
	struct class_attribute___212 *class_attrs;
	struct device_attribute___212 *dev_attrs;
	const struct attribute_group___183 **dev_groups;
	struct bin_attribute___185 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *);
	void (*class_release)(struct class___212 *);
	void (*dev_release)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
	struct subsys_private *p;
};

struct class_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct class___212 *, struct class_attribute___212 *, char *);
	ssize_t (*store)(struct class___212 *, struct class_attribute___212 *, const char *, size_t);
	const void * (*namespace)(struct class___212 *, const struct class_attribute___212 *);
};

struct acpi_scan_handler___29;

struct acpi_hotplug_context___29;

struct acpi_driver___29;

struct acpi_device___29 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___29 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___29 *handler;
	struct acpi_hotplug_context___29 *hp;
	struct acpi_driver___29 *driver;
	void *driver_data;
	struct device___212 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___227 physical_node_lock;
	void (*remove)(struct acpi_device___29 *);
};

struct device_rh___212 {
	struct dev_pm_info_rh___212 power;
};

struct signal_struct___226 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___226 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___226 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___227 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___6 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___212 dev;
	struct device___212 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___6 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___6 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___6;

struct usb_bus___6 {
	struct device___212 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___6 *root_hub;
	struct usb_bus___6 *hs_companion;
	struct list_head bus_list;
	struct mutex___227 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___6;

struct usb_device___6 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___6 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___6 *parent;
	struct usb_bus___6 *bus;
	struct usb_host_endpoint ep0;
	struct device___212 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___6 *config;
	struct usb_host_config___6 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___6 {
	struct usb_device___6 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___4 {
	struct device_driver___212 driver;
	int for_devices;
};

struct usb_driver___4 {
	const char *name;
	int (*probe)(struct usb_interface___6 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___6 *);
	int (*unlocked_ioctl)(struct usb_interface___6 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___6 *, pm_message_t);
	int (*resume)(struct usb_interface___6 *);
	int (*reset_resume)(struct usb_interface___6 *);
	int (*pre_reset)(struct usb_interface___6 *);
	int (*post_reset)(struct usb_interface___6 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___4 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct urb___6;

typedef void (*usb_complete_t___6)(struct urb___6 *);

struct urb___6 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___6 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___6 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usbdevfs_ctrltransfer {
	__u8 bRequestType;
	__u8 bRequest;
	__u16 wValue;
	__u16 wIndex;
	__u16 wLength;
	__u32 timeout;
	void *data;
};

struct usbdevfs_bulktransfer {
	unsigned int ep;
	unsigned int len;
	unsigned int timeout;
	void *data;
};

struct usbdevfs_setinterface {
	unsigned int interface;
	unsigned int altsetting;
};

struct usbdevfs_disconnectsignal {
	unsigned int signr;
	void *context;
};

struct usbdevfs_getdriver {
	unsigned int interface;
	char driver[256];
};

struct usbdevfs_connectinfo {
	unsigned int devnum;
	unsigned char slow;
};

struct usbdevfs_iso_packet_desc {
	unsigned int length;
	unsigned int actual_length;
	unsigned int status;
};

struct usbdevfs_urb {
	unsigned char type;
	unsigned char endpoint;
	int status;
	unsigned int flags;
	void *buffer;
	int buffer_length;
	int actual_length;
	int start_frame;
	union {
		int number_of_packets;
		unsigned int stream_id;
	};
	int error_count;
	unsigned int signr;
	void *usercontext;
	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
};

struct usbdevfs_ioctl {
	int ifno;
	int ioctl_code;
	void *data;
};

struct usbdevfs_disconnect_claim {
	unsigned int interface;
	unsigned int flags;
	char driver[256];
};

struct usbdevfs_streams {
	unsigned int num_streams;
	unsigned int num_eps;
	unsigned char eps[0];
};

struct usbdevfs_ctrltransfer32 {
	u8 bRequestType;
	u8 bRequest;
	u16 wValue;
	u16 wIndex;
	u16 wLength;
	u32 timeout;
	compat_caddr_t data;
};

struct usbdevfs_bulktransfer32 {
	compat_uint_t ep;
	compat_uint_t len;
	compat_uint_t timeout;
	compat_caddr_t data;
};

struct usbdevfs_disconnectsignal32 {
	compat_int_t signr;
	compat_caddr_t context;
};

struct usbdevfs_urb32 {
	unsigned char type;
	unsigned char endpoint;
	compat_int_t status;
	compat_uint_t flags;
	compat_caddr_t buffer;
	compat_int_t buffer_length;
	compat_int_t actual_length;
	compat_int_t start_frame;
	compat_int_t number_of_packets;
	compat_int_t error_count;
	compat_uint_t signr;
	compat_caddr_t usercontext;
	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
};

struct usbdevfs_ioctl32 {
	s32 ifno;
	s32 ioctl_code;
	compat_caddr_t data;
};

struct usb_mon_operations___6 {
	void (*urb_submit)(struct usb_bus___6 *, struct urb___6 *);
	void (*urb_submit_error)(struct usb_bus___6 *, struct urb___6 *, int);
	void (*urb_complete)(struct usb_bus___6 *, struct urb___6 *, int);
};

struct acpi_hotplug_profile___29 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___29 *);
	void (*notify_online)(struct acpi_device___29 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___29 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___29 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___29 *);
	void (*bind)(struct device___212 *);
	void (*unbind)(struct device___212 *);
	struct acpi_hotplug_profile___29 hotplug;
};

struct acpi_hotplug_context___29 {
	struct acpi_device___29 *self;
	int (*notify)(struct acpi_device___29 *, u32);
	void (*uevent)(struct acpi_device___29 *, u32);
	void (*fixup)(struct acpi_device___29 *);
};

typedef int (*acpi_op_add___29)(struct acpi_device___29 *);

typedef int (*acpi_op_remove___29)(struct acpi_device___29 *);

typedef void (*acpi_op_notify___29)(struct acpi_device___29 *, u32);

struct acpi_device_ops___29 {
	acpi_op_add___29 add;
	acpi_op_remove___29 remove;
	acpi_op_notify___29 notify;
};

struct acpi_driver___29 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___29 ops;
	struct device_driver___212 drv;
	struct module___131 *owner;
};

struct dev_state___2 {
	struct list_head list;
	struct usb_device___6 *dev;
	struct file___225 *file;
	spinlock_t lock;
	struct list_head async_pending;
	struct list_head async_completed;
	wait_queue_head_t wait;
	unsigned int discsignr;
	struct pid___91 *disc_pid;
	const struct cred___3 *cred;
	void *disccontext;
	long unsigned int ifclaimed;
	u32 secid;
	u32 disabled_bulk_eps;
};

struct async {
	struct list_head asynclist;
	struct dev_state___2 *ps;
	struct pid___91 *pid;
	const struct cred___3 *cred;
	unsigned int signr;
	unsigned int ifnum;
	void *userbuffer;
	void *userurb;
	struct urb___6 *urb;
	unsigned int mem_usage;
	int status;
	u32 secid;
	u8 bulk_addr;
	u8 bulk_status;
};

enum snoop_when {
	SUBMIT = 0,
	COMPLETE = 1,
};

struct usb_device_driver___2 {
	const char *name;
	int (*probe)(struct usb_device___5 *);
	void (*disconnect)(struct usb_device___5 *);
	int (*suspend)(struct usb_device___5 *, pm_message_t);
	int (*resume)(struct usb_device___5 *, pm_message_t);
	struct usbdrv_wrap___3 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct hc_driver___5;

struct usb_hcd___5 {
	struct usb_bus___5 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___5 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___5 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___226 *bandwidth_mutex;
	struct usb_hcd___5 *shared_hcd;
	struct usb_hcd___5 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___5 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___5 *);
	int flags;
	int (*reset)(struct usb_hcd___5 *);
	int (*start)(struct usb_hcd___5 *);
	int (*pci_suspend)(struct usb_hcd___5 *, bool);
	int (*pci_resume)(struct usb_hcd___5 *, bool);
	void (*stop)(struct usb_hcd___5 *);
	void (*shutdown)(struct usb_hcd___5 *);
	int (*get_frame_number)(struct usb_hcd___5 *);
	int (*urb_enqueue)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___5 *, struct urb___5 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *);
	void (*endpoint_disable)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___5 *, char *);
	int (*hub_control)(struct usb_hcd___5 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___5 *);
	int (*bus_resume)(struct usb_hcd___5 *);
	int (*start_port_reset)(struct usb_hcd___5 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___5 *, int);
	int (*port_handed_over)(struct usb_hcd___5 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*free_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*alloc_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*reset_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*address_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*enable_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_hub_device)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_tt___5 *, gfp_t);
	int (*reset_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___5 *, struct usb_device___5 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___5 *, int);
	int (*port_power)(struct usb_hcd___5 *, int, bool);
};

struct hc_driver___6;

struct usb_hcd___6 {
	struct usb_bus___6 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___6 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___6 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___227 *bandwidth_mutex;
	struct usb_hcd___6 *shared_hcd;
	struct usb_hcd___6 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___6 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___6 *);
	int flags;
	int (*reset)(struct usb_hcd___6 *);
	int (*start)(struct usb_hcd___6 *);
	int (*pci_suspend)(struct usb_hcd___6 *, bool);
	int (*pci_resume)(struct usb_hcd___6 *, bool);
	void (*stop)(struct usb_hcd___6 *);
	void (*shutdown)(struct usb_hcd___6 *);
	int (*get_frame_number)(struct usb_hcd___6 *);
	int (*urb_enqueue)(struct usb_hcd___6 *, struct urb___6 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___6 *, struct urb___6 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___6 *, struct urb___6 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___6 *, struct urb___6 *);
	void (*endpoint_disable)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___6 *, char *);
	int (*hub_control)(struct usb_hcd___6 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___6 *);
	int (*bus_resume)(struct usb_hcd___6 *);
	int (*start_port_reset)(struct usb_hcd___6 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___6 *, int);
	int (*port_handed_over)(struct usb_hcd___6 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___6 *, struct usb_device___6 *);
	void (*free_dev)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*alloc_streams)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___6 *, struct usb_device___6 *);
	void (*reset_bandwidth)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*address_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*enable_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*update_hub_device)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_tt___6 *, gfp_t);
	int (*reset_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*update_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___6 *, struct usb_device___6 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___6 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___6 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___6 *, int);
	int (*port_power)(struct usb_hcd___6 *, int, bool);
};

struct device_connect_event {
	atomic_t count;
	wait_queue_head_t wait;
};

struct class_info {
	int class;
	char *class_name;
};

struct device___213;

struct dev_pm_ops___213 {
	int (*prepare)(struct device___213 *);
	void (*complete)(struct device___213 *);
	int (*suspend)(struct device___213 *);
	int (*resume)(struct device___213 *);
	int (*freeze)(struct device___213 *);
	int (*thaw)(struct device___213 *);
	int (*poweroff)(struct device___213 *);
	int (*restore)(struct device___213 *);
	int (*suspend_late)(struct device___213 *);
	int (*resume_early)(struct device___213 *);
	int (*freeze_late)(struct device___213 *);
	int (*thaw_early)(struct device___213 *);
	int (*poweroff_late)(struct device___213 *);
	int (*restore_early)(struct device___213 *);
	int (*suspend_noirq)(struct device___213 *);
	int (*resume_noirq)(struct device___213 *);
	int (*freeze_noirq)(struct device___213 *);
	int (*thaw_noirq)(struct device___213 *);
	int (*poweroff_noirq)(struct device___213 *);
	int (*restore_noirq)(struct device___213 *);
	int (*runtime_suspend)(struct device___213 *);
	int (*runtime_resume)(struct device___213 *);
	int (*runtime_idle)(struct device___213 *);
};

struct dev_pm_qos___38;

struct dev_pm_info___38 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___38 *qos;
};

struct acpi_device___30;

struct acpi_dev_node___36 {
	union {
		struct acpi_device___30 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___213;

struct bus_type___213;

struct device_driver___213;

struct dev_pm_domain___213;

struct class___213;

struct device_rh___213;

struct device___213 {
	struct device___213 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___213 *type;
	struct mutex___225 mutex;
	struct bus_type___213 *bus;
	struct device_driver___213 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___213 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___213 *class;
	const struct attribute_group___181 **groups;
	void (*release)(struct device___213 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___213 *device_rh;
};

struct dev_pm_qos_request___38;

struct dev_pm_qos___38 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___38 *latency_req;
	struct dev_pm_qos_request___38 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___38 *latency_tolerance_req;
};

struct dev_pm_info_rh___213 {
	void (*set_latency_tolerance)(struct device___213 *, s32);
};

struct dev_pm_domain___213 {
	struct dev_pm_ops___213 ops;
};

struct bus_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___213 *, char *);
	ssize_t (*store)(struct bus_type___213 *, const char *, size_t);
};

struct device_attribute___213;

struct driver_attribute___213;

struct bus_type___213 {
	const char *name;
	const char *dev_name;
	struct device___213 *dev_root;
	struct bus_attribute___213 *bus_attrs;
	struct device_attribute___213 *dev_attrs;
	struct driver_attribute___213 *drv_attrs;
	const struct attribute_group___181 **bus_groups;
	const struct attribute_group___181 **dev_groups;
	const struct attribute_group___181 **drv_groups;
	int (*match)(struct device___213 *, struct device_driver___213 *);
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	int (*probe)(struct device___213 *);
	int (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*online)(struct device___213 *);
	int (*offline)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct device___213 *, struct device_attribute___213 *, char *);
	ssize_t (*store)(struct device___213 *, struct device_attribute___213 *, const char *, size_t);
};

struct driver_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___213 *, char *);
	ssize_t (*store)(struct device_driver___213 *, const char *, size_t);
};

struct device_driver___213 {
	const char *name;
	struct bus_type___213 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___213 *);
	int (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	const struct attribute_group___181 **groups;
	const struct dev_pm_ops___213 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___213 {
	const char *name;
	const struct attribute_group___181 **groups;
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
};

struct class_attribute___213;

struct class___213 {
	const char *name;
	struct module *owner;
	struct class_attribute___213 *class_attrs;
	struct device_attribute___213 *dev_attrs;
	const struct attribute_group___181 **dev_groups;
	struct bin_attribute___183 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *);
	void (*class_release)(struct class___213 *);
	void (*dev_release)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
	struct subsys_private *p;
};

struct class_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct class___213 *, struct class_attribute___213 *, char *);
	ssize_t (*store)(struct class___213 *, struct class_attribute___213 *, const char *, size_t);
	const void * (*namespace)(struct class___213 *, const struct class_attribute___213 *);
};

struct acpi_scan_handler___30;

struct acpi_hotplug_context___30;

struct acpi_driver___30;

struct acpi_device___30 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___30 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___30 *handler;
	struct acpi_hotplug_context___30 *hp;
	struct acpi_driver___30 *driver;
	void *driver_data;
	struct device___213 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___225 physical_node_lock;
	void (*remove)(struct acpi_device___30 *);
};

struct device_rh___213 {
	struct dev_pm_info_rh___213 power;
};

struct dev_pm_qos_request___38 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___213 *dev;
};

struct usb_interface___7 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___213 dev;
	struct device___213 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___7 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___7 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___7;

struct usb_bus___7 {
	struct device___213 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___7 *root_hub;
	struct usb_bus___7 *hs_companion;
	struct list_head bus_list;
	struct mutex___225 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___7;

struct usb_device___7 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___7 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___7 *parent;
	struct usb_bus___7 *bus;
	struct usb_host_endpoint ep0;
	struct device___213 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___7 *config;
	struct usb_host_config___7 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___7 {
	struct usb_device___7 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___7;

typedef void (*usb_complete_t___7)(struct urb___7 *);

struct urb___7 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___7 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___7 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___7;

struct usb_hcd___7 {
	struct usb_bus___7 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___7 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___7 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___225 *bandwidth_mutex;
	struct usb_hcd___7 *shared_hcd;
	struct usb_hcd___7 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___7 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___7 *);
	int flags;
	int (*reset)(struct usb_hcd___7 *);
	int (*start)(struct usb_hcd___7 *);
	int (*pci_suspend)(struct usb_hcd___7 *, bool);
	int (*pci_resume)(struct usb_hcd___7 *, bool);
	void (*stop)(struct usb_hcd___7 *);
	void (*shutdown)(struct usb_hcd___7 *);
	int (*get_frame_number)(struct usb_hcd___7 *);
	int (*urb_enqueue)(struct usb_hcd___7 *, struct urb___7 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___7 *, struct urb___7 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___7 *, struct urb___7 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___7 *, struct urb___7 *);
	void (*endpoint_disable)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___7 *, char *);
	int (*hub_control)(struct usb_hcd___7 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___7 *);
	int (*bus_resume)(struct usb_hcd___7 *);
	int (*start_port_reset)(struct usb_hcd___7 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___7 *, int);
	int (*port_handed_over)(struct usb_hcd___7 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___7 *, struct usb_device___7 *);
	void (*free_dev)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*alloc_streams)(struct usb_hcd___7 *, struct usb_device___7 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___7 *, struct usb_device___7 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___7 *, struct usb_device___7 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___7 *, struct usb_device___7 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___7 *, struct usb_device___7 *);
	void (*reset_bandwidth)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*address_device)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*enable_device)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*update_hub_device)(struct usb_hcd___7 *, struct usb_device___7 *, struct usb_tt___7 *, gfp_t);
	int (*reset_device)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*update_device)(struct usb_hcd___7 *, struct usb_device___7 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___7 *, struct usb_device___7 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___7 *, struct usb_device___7 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___7 *, struct usb_device___7 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___7 *, int);
	int (*port_power)(struct usb_hcd___7 *, int, bool);
};

struct usb_mon_operations___7 {
	void (*urb_submit)(struct usb_bus___7 *, struct urb___7 *);
	void (*urb_submit_error)(struct usb_bus___7 *, struct urb___7 *, int);
	void (*urb_complete)(struct usb_bus___7 *, struct urb___7 *, int);
};

struct acpi_hotplug_profile___30 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___30 *);
	void (*notify_online)(struct acpi_device___30 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___30 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___30 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___30 *);
	void (*bind)(struct device___213 *);
	void (*unbind)(struct device___213 *);
	struct acpi_hotplug_profile___30 hotplug;
};

struct acpi_hotplug_context___30 {
	struct acpi_device___30 *self;
	int (*notify)(struct acpi_device___30 *, u32);
	void (*uevent)(struct acpi_device___30 *, u32);
	void (*fixup)(struct acpi_device___30 *);
};

typedef int (*acpi_op_add___30)(struct acpi_device___30 *);

typedef int (*acpi_op_remove___30)(struct acpi_device___30 *);

typedef void (*acpi_op_notify___30)(struct acpi_device___30 *, u32);

struct acpi_device_ops___30 {
	acpi_op_add___30 add;
	acpi_op_remove___30 remove;
	acpi_op_notify___30 notify;
};

struct acpi_driver___30 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___30 ops;
	struct device_driver___213 drv;
	struct module *owner;
};

struct usb_port___2;

struct usb_hub___2 {
	struct device___213 *intfdev;
	struct usb_device___7 *hdev;
	struct kref kref;
	struct urb___7 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex___225 status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___7 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port___2 **ports;
};

struct usb_port___2 {
	struct usb_device___7 *child;
	struct device___213 dev;
	struct dev_state *port_owner;
	struct usb_port___2 *peer;
	struct dev_pm_qos_request___38 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex___225 status_lock;
	u8 portnum;
	unsigned int is_superspeed: 1;
};

struct pci_bus___26;

struct pci_slot___26;

struct pci_driver___26;

struct pci_dev___27 {
	struct list_head bus_list;
	struct pci_bus___26 *bus;
	struct pci_bus___26 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___26 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___26 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___210 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___167 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___167 *res_attr[17];
	struct bin_attribute___167 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___22 *msi_kset;
	const struct attribute_group___165 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___27 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct pci_slot___26 {
	struct pci_bus___26 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___22 kobj;
};

struct pci_ops___26;

struct pci_bus___26 {
	struct list_head node;
	struct pci_bus___26 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___27 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___26 *ops;
	struct msi_chip *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___210 *bridge;
	struct device___210 dev;
	struct bin_attribute___167 *legacy_io;
	struct bin_attribute___167 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___26;

struct pci_driver_rh___26;

struct pci_driver___26 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___27 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___27 *);
	int (*suspend)(struct pci_dev___27 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___27 *, pm_message_t);
	int (*resume_early)(struct pci_dev___27 *);
	int (*resume)(struct pci_dev___27 *);
	void (*shutdown)(struct pci_dev___27 *);
	int (*sriov_configure)(struct pci_dev___27 *, int);
	const struct pci_error_handlers___26 *err_handler;
	struct device_driver___210 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___26 *pci_driver_rh;
};

struct pci_ops___26 {
	int (*read)(struct pci_bus___26 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___26 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___26 {
	pci_ers_result_t (*error_detected)(struct pci_dev___27 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___27 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___27 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___27 *);
	void (*resume)(struct pci_dev___27 *);
};

struct pci_driver_rh___26 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___27 *, bool);
};

typedef void (*companion_fn)(struct pci_dev___27 *, struct usb_hcd___4 *, struct pci_dev___27 *, struct usb_hcd___4 *);

struct acpi_bus_type___2 {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___208 *);
	struct acpi_device___25 * (*find_companion)(struct device___208 *);
	void (*setup)(struct device___208 *);
	void (*cleanup)(struct device___208 *);
};

struct usb_port___3;

struct usb_hub___3 {
	struct device___208 *intfdev;
	struct usb_device *hdev;
	struct kref kref;
	struct urb *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex___225 status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port___3 **ports;
};

struct dev_pm_qos_request___39;

struct usb_port___3 {
	struct usb_device *child;
	struct device___208 dev;
	struct dev_state *port_owner;
	struct usb_port___3 *peer;
	struct dev_pm_qos_request___39 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex___225 status_lock;
	u8 portnum;
	unsigned int is_superspeed: 1;
};

struct mon_bus {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___223 *dent_s;
	struct dentry___223 *dent_t;
	struct dentry___223 *dent_u;
	struct device___208 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct mon_reader {
	struct list_head r_link;
	struct mon_bus *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb *);
	void (*rnf_error)(void *, struct urb *, int);
	void (*rnf_complete)(void *, struct urb *, int);
};

struct snap {
	int slen;
	char str[80];
};

struct page___225;

typedef struct page___225 *pgtable_t___225;

struct address_space___226;

struct kmem_cache___211;

struct page___225 {
	long unsigned int flags;
	struct address_space___226 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___225 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___225 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___211 *slab_cache;
		struct page___225 *first_page;
	};
	long: 64;
};

struct task_struct___227;

struct pv_cpu_ops___227 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___81 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___81 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___227 *);
	void (*end_context_switch)(struct task_struct___227 *);
};

struct mutex___228 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___227 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___220 {
	struct page___225 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___234;

struct signal_struct___227;

struct task_struct___227 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___227 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___234 *mm;
	struct mm_struct___234 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___227 *real_parent;
	struct task_struct___227 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___227 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___91 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___227 = 0,
		VTIME_USER___227 = 1,
		VTIME_SYS___227 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___81 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___227 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___228 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___220 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___234 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___234 *, struct mm_struct___234 *);
	void (*dup_mmap)(struct mm_struct___234 *, struct mm_struct___234 *);
	void (*exit_mmap)(struct mm_struct___234 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___234 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___234 *);
	void (*pgd_free)(struct mm_struct___234 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___234 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___234 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___234 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___234 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___234 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___234 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___234 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___234 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___234 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___234 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___234 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___228 lock;
	void *vdso;
} mm_context_t___228;

struct xol_area___225;

struct uprobes_state___225 {
	struct xol_area___225 *xol_area;
};

struct vm_area_struct___234;

struct file___226;

struct core_state___227;

struct mm_struct___234 {
	struct vm_area_struct___234 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___234 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___234 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___228 context;
	long unsigned int flags;
	struct core_state___227 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___227 *owner;
	struct file___226 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___225 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___99 {
	struct task_struct___227 *task;
	struct exec_domain___58 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___148;

struct x86_io_apic_ops___148 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___148 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___148;

struct irq_data___148 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___148 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___214;

struct dev_pm_ops___214 {
	int (*prepare)(struct device___214 *);
	void (*complete)(struct device___214 *);
	int (*suspend)(struct device___214 *);
	int (*resume)(struct device___214 *);
	int (*freeze)(struct device___214 *);
	int (*thaw)(struct device___214 *);
	int (*poweroff)(struct device___214 *);
	int (*restore)(struct device___214 *);
	int (*suspend_late)(struct device___214 *);
	int (*resume_early)(struct device___214 *);
	int (*freeze_late)(struct device___214 *);
	int (*thaw_early)(struct device___214 *);
	int (*poweroff_late)(struct device___214 *);
	int (*restore_early)(struct device___214 *);
	int (*suspend_noirq)(struct device___214 *);
	int (*resume_noirq)(struct device___214 *);
	int (*freeze_noirq)(struct device___214 *);
	int (*thaw_noirq)(struct device___214 *);
	int (*poweroff_noirq)(struct device___214 *);
	int (*restore_noirq)(struct device___214 *);
	int (*runtime_suspend)(struct device___214 *);
	int (*runtime_resume)(struct device___214 *);
	int (*runtime_idle)(struct device___214 *);
};

struct device_type___214;

struct bus_type___214;

struct device_driver___214;

struct dev_pm_domain___214;

struct class___214;

struct attribute_group___184;

struct device_rh___214;

struct device___214 {
	struct device___214 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___214 *type;
	struct mutex___228 mutex;
	struct bus_type___214 *bus;
	struct device_driver___214 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___214 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___214 *class;
	const struct attribute_group___184 **groups;
	void (*release)(struct device___214 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___214 *device_rh;
};

struct dev_pm_info_rh___214 {
	void (*set_latency_tolerance)(struct device___214 *, s32);
};

struct dev_pm_domain___214 {
	struct dev_pm_ops___214 ops;
};

struct smp_ops___227 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___227 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___227;

struct lruvec___227 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___227 *zone;
};

struct pglist_data___227;

struct zone___227 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___227 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___227 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___227 {
	struct zone___227 *zone;
	int zone_idx;
};

struct zonelist___227 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___227 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___227 {
	struct zone___227 node_zones[4];
	struct zonelist___227 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___227 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___152;

struct irq_chip___148 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___148 *);
	void (*irq_shutdown)(struct irq_data___148 *);
	void (*irq_enable)(struct irq_data___148 *);
	void (*irq_disable)(struct irq_data___148 *);
	void (*irq_ack)(struct irq_data___148 *);
	void (*irq_mask)(struct irq_data___148 *);
	void (*irq_mask_ack)(struct irq_data___148 *);
	void (*irq_unmask)(struct irq_data___148 *);
	void (*irq_eoi)(struct irq_data___148 *);
	int (*irq_set_affinity)(struct irq_data___148 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___148 *);
	int (*irq_set_type)(struct irq_data___148 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___148 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___148 *);
	void (*irq_bus_sync_unlock)(struct irq_data___148 *);
	void (*irq_cpu_online)(struct irq_data___148 *);
	void (*irq_cpu_offline)(struct irq_data___148 *);
	void (*irq_suspend)(struct irq_data___148 *);
	void (*irq_resume)(struct irq_data___148 *);
	void (*irq_pm_shutdown)(struct irq_data___148 *);
	void (*irq_print_chip)(struct irq_data___148 *, struct seq_file___152 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___148 *, void *);
	long unsigned int flags;
};

struct seq_operations___152;

struct seq_file___152 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___228 lock;
	const struct seq_operations___152 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___186;

struct attribute_group___184 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___186 **bin_attrs;
};

struct bin_attribute___186 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___226 *, struct kobject___24 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___226 *, struct kobject___24 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	int (*mmap)(struct file___226 *, struct kobject___24 *, struct bin_attribute___186 *, struct vm_area_struct___234 *);
};

struct dentry___226;

struct path___226 {
	struct vfsmount *mnt;
	struct dentry___226 *dentry;
};

struct inode___226;

struct file_operations___226;

struct file___226 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___226 f_path;
	struct inode___226 *f_inode;
	const struct file_operations___226 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___226 *f_mapping;
	struct mutex___228 f_pos_lock;
};

struct vm_operations_struct___205;

struct vm_area_struct___234 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___234 *vm_next;
	struct vm_area_struct___234 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___234 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___205 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___226 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___214 *, char *);
	ssize_t (*store)(struct bus_type___214 *, const char *, size_t);
};

struct device_attribute___214;

struct driver_attribute___214;

struct bus_type___214 {
	const char *name;
	const char *dev_name;
	struct device___214 *dev_root;
	struct bus_attribute___214 *bus_attrs;
	struct device_attribute___214 *dev_attrs;
	struct driver_attribute___214 *drv_attrs;
	const struct attribute_group___184 **bus_groups;
	const struct attribute_group___184 **dev_groups;
	const struct attribute_group___184 **drv_groups;
	int (*match)(struct device___214 *, struct device_driver___214 *);
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	int (*probe)(struct device___214 *);
	int (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*online)(struct device___214 *);
	int (*offline)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct device___214 *, struct device_attribute___214 *, char *);
	ssize_t (*store)(struct device___214 *, struct device_attribute___214 *, const char *, size_t);
};

struct driver_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___214 *, char *);
	ssize_t (*store)(struct device_driver___214 *, const char *, size_t);
};

struct device_driver___214 {
	const char *name;
	struct bus_type___214 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___214 *);
	int (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	const struct attribute_group___184 **groups;
	const struct dev_pm_ops___214 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___214 {
	const char *name;
	const struct attribute_group___184 **groups;
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
};

struct class_attribute___214;

struct class___214 {
	const char *name;
	struct module *owner;
	struct class_attribute___214 *class_attrs;
	struct device_attribute___214 *dev_attrs;
	const struct attribute_group___184 **dev_groups;
	struct bin_attribute___186 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *);
	void (*class_release)(struct class___214 *);
	void (*dev_release)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
	struct subsys_private *p;
};

struct class_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct class___214 *, struct class_attribute___214 *, char *);
	ssize_t (*store)(struct class___214 *, struct class_attribute___214 *, const char *, size_t);
	const void * (*namespace)(struct class___214 *, const struct class_attribute___214 *);
};

struct device_rh___214 {
	struct dev_pm_info_rh___214 power;
};

struct dentry_operations___226;

struct super_block___226;

struct dentry___226 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___226 *d_parent;
	struct qstr d_name;
	struct inode___226 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___226 *d_op;
	struct super_block___226 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___226;

struct address_space___226 {
	struct inode___226 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___228 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___226 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___226;

struct file_lock___226;

struct dquot___226;

struct block_device___226;

struct inode___226 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___226 *i_op;
	struct super_block___226 *i_sb;
	struct address_space___226 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___228 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___226 *i_fop;
	struct file_lock___226 *i_flock;
	struct address_space___226 i_data;
	struct dquot___226 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___226 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___226 {
	int (*d_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_hash)(const struct dentry___226 *, struct qstr *);
	int (*d_compare)(const struct dentry___226 *, const struct dentry___226 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___226 *);
	void (*d_release)(struct dentry___226 *);
	void (*d_prune)(struct dentry___226 *);
	void (*d_iput)(struct dentry___226 *, struct inode___226 *);
	char * (*d_dname)(struct dentry___226 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___226 *);
	int (*d_manage)(struct dentry___226 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___226;

struct mem_dqinfo___226 {
	struct quota_format_type___226 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___226;

struct quota_info___226 {
	unsigned int flags;
	struct mutex___228 dqio_mutex;
	struct mutex___228 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___226 *files[2];
	struct mem_dqinfo___226 info[2];
	const struct quota_format_ops___226 *ops[2];
};

struct file_system_type___226;

struct super_operations___226;

struct dquot_operations___226;

struct quotactl_ops___226;

struct super_block___226 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___226 *s_type;
	const struct super_operations___226 *s_op;
	const struct dquot_operations___226 *dq_op;
	const struct quotactl_ops___226 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___226 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___226 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___226 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___228 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___226 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___226 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___226 *bd_inode;
	struct super_block___226 *bd_super;
	struct mutex___228 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___226 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___228 bd_fsfreeze_mutex;
};

struct iattr___226 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___226 *ia_file;
};

struct dquot___226 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___228 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___226 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___226 {
	int qf_fmt_id;
	const struct quota_format_ops___226 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___226 *qf_next;
};

struct quota_format_ops___226 {
	int (*check_quota_file)(struct super_block___226 *, int);
	int (*read_file_info)(struct super_block___226 *, int);
	int (*write_file_info)(struct super_block___226 *, int);
	int (*free_file_info)(struct super_block___226 *, int);
	int (*read_dqblk)(struct dquot___226 *);
	int (*commit_dqblk)(struct dquot___226 *);
	int (*release_dqblk)(struct dquot___226 *);
};

struct dquot_operations___226 {
	int (*write_dquot)(struct dquot___226 *);
	struct dquot___226 * (*alloc_dquot)(struct super_block___226 *, int);
	void (*destroy_dquot)(struct dquot___226 *);
	int (*acquire_dquot)(struct dquot___226 *);
	int (*release_dquot)(struct dquot___226 *);
	int (*mark_dirty)(struct dquot___226 *);
	int (*write_info)(struct super_block___226 *, int);
	qsize_t * (*get_reserved_space)(struct inode___226 *);
};

struct quotactl_ops___226 {
	int (*quota_on)(struct super_block___226 *, int, int, struct path___226 *);
	int (*quota_on_meta)(struct super_block___226 *, int, int);
	int (*quota_off)(struct super_block___226 *, int);
	int (*quota_sync)(struct super_block___226 *, int);
	int (*get_info)(struct super_block___226 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___226 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___226 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___226 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___226 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___226 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___226 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___226 *, unsigned int);
};

struct address_space_operations___226 {
	int (*writepage)(struct page___225 *, struct writeback_control *);
	int (*readpage)(struct file___226 *, struct page___225 *);
	int (*writepages)(struct address_space___226 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___225 *);
	int (*readpages)(struct file___226 *, struct address_space___226 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___226 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___225 **, void **);
	int (*write_end)(struct file___226 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___225 *, void *);
	sector_t (*bmap)(struct address_space___226 *, sector_t);
	void (*invalidatepage)(struct page___225 *, long unsigned int);
	int (*releasepage)(struct page___225 *, gfp_t);
	void (*freepage)(struct page___225 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___226 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___226 *, struct page___225 *, struct page___225 *, enum migrate_mode);
	int (*launder_page)(struct page___225 *);
	int (*is_partially_uptodate)(struct page___225 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___225 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___226 *, struct page___225 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___226 *, sector_t *);
	void (*swap_deactivate)(struct file___226 *);
	void (*invalidatepage_range)(struct page___225 *, unsigned int, unsigned int);
};

struct inode_operations___226 {
	struct dentry___226 * (*lookup)(struct inode___226 *, struct dentry___226 *, unsigned int);
	void * (*follow_link)(struct dentry___226 *, struct nameidata *);
	int (*permission)(struct inode___226 *, int);
	struct posix_acl * (*get_acl)(struct inode___226 *, int);
	int (*readlink)(struct dentry___226 *, char *, int);
	void (*put_link)(struct dentry___226 *, struct nameidata *, void *);
	int (*create)(struct inode___226 *, struct dentry___226 *, umode_t, bool);
	int (*link)(struct dentry___226 *, struct inode___226 *, struct dentry___226 *);
	int (*unlink)(struct inode___226 *, struct dentry___226 *);
	int (*symlink)(struct inode___226 *, struct dentry___226 *, const char *);
	int (*mkdir)(struct inode___226 *, struct dentry___226 *, umode_t);
	int (*rmdir)(struct inode___226 *, struct dentry___226 *);
	int (*mknod)(struct inode___226 *, struct dentry___226 *, umode_t, dev_t);
	int (*rename)(struct inode___226 *, struct dentry___226 *, struct inode___226 *, struct dentry___226 *);
	int (*setattr)(struct dentry___226 *, struct iattr___226 *);
	int (*getattr)(struct vfsmount *, struct dentry___226 *, struct kstat *);
	int (*setxattr)(struct dentry___226 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___226 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___226 *, char *, size_t);
	int (*removexattr)(struct dentry___226 *, const char *);
	int (*fiemap)(struct inode___226 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___226 *, struct timespec *, int);
	int (*atomic_open)(struct inode___226 *, struct dentry___226 *, struct file___226 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___226 {
	struct module *owner;
	loff_t (*llseek)(struct file___226 *, loff_t, int);
	ssize_t (*read)(struct file___226 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___226 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___226 *, void *, filldir_t);
	unsigned int (*poll)(struct file___226 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___226 *, struct vm_area_struct___234 *);
	int (*open)(struct inode___226 *, struct file___226 *);
	int (*flush)(struct file___226 *, fl_owner_t);
	int (*release)(struct inode___226 *, struct file___226 *);
	int (*fsync)(struct file___226 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___226 *, int);
	int (*lock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*sendpage)(struct file___226 *, struct page___225 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___226 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___226 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___226 *, long int, struct file_lock___226 **, void **);
		struct {
			int (*setlease)(struct file___226 *, long int, struct file_lock___226 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___226 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___152 *, struct file___226 *);
};

struct fasync_struct___226;

struct file_lock_operations___226;

struct lock_manager_operations___226;

struct file_lock___226 {
	struct file_lock___226 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___91 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___226 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___226 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___226 *fl_ops;
	const struct lock_manager_operations___226 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___226 {
	void (*fl_copy_lock)(struct file_lock___226 *, struct file_lock___226 *);
	void (*fl_release_private)(struct file_lock___226 *);
};

struct lock_manager_operations___226 {
	int (*lm_compare_owner)(struct file_lock___226 *, struct file_lock___226 *);
	long unsigned int (*lm_owner_key)(struct file_lock___226 *);
	void (*lm_notify)(struct file_lock___226 *);
	int (*lm_grant)(struct file_lock___226 *, struct file_lock___226 *, int);
	void (*lm_break)(struct file_lock___226 *);
	int (*lm_change)(struct file_lock___226 **, int);
};

struct fasync_struct___226 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___226 *fa_next;
	struct file___226 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___226 {
	const char *name;
	int fs_flags;
	struct dentry___226 * (*mount)(struct file_system_type___226 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___226 *);
	struct module *owner;
	struct file_system_type___226 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___226 {
	struct inode___226 * (*alloc_inode)(struct super_block___226 *);
	void (*destroy_inode)(struct inode___226 *);
	void (*dirty_inode)(struct inode___226 *, int);
	int (*write_inode)(struct inode___226 *, struct writeback_control *);
	int (*drop_inode)(struct inode___226 *);
	void (*evict_inode)(struct inode___226 *);
	void (*put_super)(struct super_block___226 *);
	int (*sync_fs)(struct super_block___226 *, int);
	int (*freeze_fs)(struct super_block___226 *);
	int (*unfreeze_fs)(struct super_block___226 *);
	int (*statfs)(struct dentry___226 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___226 *, int *, char *);
	void (*umount_begin)(struct super_block___226 *);
	int (*show_options)(struct seq_file___152 *, struct dentry___226 *);
	int (*show_devname)(struct seq_file___152 *, struct dentry___226 *);
	int (*show_path)(struct seq_file___152 *, struct dentry___226 *);
	int (*show_stats)(struct seq_file___152 *, struct dentry___226 *);
	ssize_t (*quota_read)(struct super_block___226 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___226 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___226 *);
	int (*bdev_try_to_free_page)(struct super_block___226 *, struct page___225 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___226 *);
	void (*free_cached_objects)(struct super_block___226 *, int);
};

struct xol_area___225 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___225 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___210;

struct memcg_cache_params___211;

struct kmem_cache___211 {
	struct kmem_cache_cpu___210 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___211 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___201;

struct vm_operations_struct___205 {
	void (*open)(struct vm_area_struct___234 *);
	void (*close)(struct vm_area_struct___234 *);
	int (*fault)(struct vm_area_struct___234 *, struct vm_fault___201 *);
	int (*page_mkwrite)(struct vm_area_struct___234 *, struct vm_fault___201 *);
	int (*access)(struct vm_area_struct___234 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___234 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___234 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___234 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___234 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___227 {
	struct task_struct___227 *task;
	struct core_thread___227 *next;
};

struct core_state___227 {
	atomic_t nr_threads;
	struct core_thread___227 dumper;
	struct completion startup;
};

struct signal_struct___227 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___227 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___227 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___91 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___228 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___8 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___214 dev;
	struct device___214 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___8 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___8 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___8;

struct mon_bus___2;

struct usb_bus___8 {
	struct device___214 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___8 *root_hub;
	struct usb_bus___8 *hs_companion;
	struct list_head bus_list;
	struct mutex___228 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus___2 *mon_bus;
	int monitored;
};

struct usb_device___8 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___8 *parent;
	struct usb_bus___8 *bus;
	struct usb_host_endpoint ep0;
	struct device___214 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___8 *config;
	struct usb_host_config___8 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct mon_bus___2 {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___8 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___226 *dent_s;
	struct dentry___226 *dent_t;
	struct dentry___226 *dent_u;
	struct device___214 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct urb___8;

typedef void (*usb_complete_t___8)(struct urb___8 *);

struct urb___8 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___8 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___8 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct kmem_cache_cpu___210 {
	void **freelist;
	long unsigned int tid;
	struct page___225 *page;
	struct page___225 *partial;
};

struct memcg_cache_params___211 {
	bool is_root_cache;
	union {
		struct kmem_cache___211 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___211 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct seq_operations___152 {
	void * (*start)(struct seq_file___152 *, loff_t *);
	void (*stop)(struct seq_file___152 *, void *);
	void * (*next)(struct seq_file___152 *, void *, loff_t *);
	int (*show)(struct seq_file___152 *, void *);
};

struct vm_fault___201 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___225 *page;
};

struct mon_reader___2 {
	struct list_head r_link;
	struct mon_bus___2 *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb___8 *);
	void (*rnf_error)(void *, struct urb___8 *, int);
	void (*rnf_complete)(void *, struct urb___8 *, int);
};

struct mon_iso_desc {
	int status;
	unsigned int offset;
	unsigned int length;
};

struct mon_event_text {
	struct list_head e_link;
	int type;
	long unsigned int id;
	unsigned int tstamp;
	int busnum;
	char devnum;
	char epnum;
	char is_in;
	char xfertype;
	int length;
	int status;
	int interval;
	int start_frame;
	int error_count;
	char setup_flag;
	char data_flag;
	int numdesc;
	struct mon_iso_desc isodesc[5];
	unsigned char setup[8];
	unsigned char data[32];
};

struct mon_reader_text {
	struct kmem_cache___211 *e_slab;
	int nevents;
	struct list_head e_list;
	struct mon_reader___2 r;
	wait_queue_head_t wait;
	int printf_size;
	char *printf_buf;
	struct mutex___228 printf_lock;
	char slab_name[30];
};

struct mon_text_ptr {
	int cnt;
	int limit;
	char *pbuf;
};

struct thread_info___100 {
	struct task_struct___48 *task;
	struct exec_domain___58 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct device___215;

struct dev_pm_ops___215 {
	int (*prepare)(struct device___215 *);
	void (*complete)(struct device___215 *);
	int (*suspend)(struct device___215 *);
	int (*resume)(struct device___215 *);
	int (*freeze)(struct device___215 *);
	int (*thaw)(struct device___215 *);
	int (*poweroff)(struct device___215 *);
	int (*restore)(struct device___215 *);
	int (*suspend_late)(struct device___215 *);
	int (*resume_early)(struct device___215 *);
	int (*freeze_late)(struct device___215 *);
	int (*thaw_early)(struct device___215 *);
	int (*poweroff_late)(struct device___215 *);
	int (*restore_early)(struct device___215 *);
	int (*suspend_noirq)(struct device___215 *);
	int (*resume_noirq)(struct device___215 *);
	int (*freeze_noirq)(struct device___215 *);
	int (*thaw_noirq)(struct device___215 *);
	int (*poweroff_noirq)(struct device___215 *);
	int (*restore_noirq)(struct device___215 *);
	int (*runtime_suspend)(struct device___215 *);
	int (*runtime_resume)(struct device___215 *);
	int (*runtime_idle)(struct device___215 *);
};

struct device_type___215;

struct bus_type___215;

struct device_driver___215;

struct dev_pm_domain___215;

struct class___215;

struct attribute_group___185;

struct device_rh___215;

struct device___215 {
	struct device___215 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___215 *type;
	struct mutex___48 mutex;
	struct bus_type___215 *bus;
	struct device_driver___215 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___215 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___92 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___215 *class;
	const struct attribute_group___185 **groups;
	void (*release)(struct device___215 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___215 *device_rh;
};

struct dev_pm_info_rh___215 {
	void (*set_latency_tolerance)(struct device___215 *, s32);
};

struct dev_pm_domain___215 {
	struct dev_pm_ops___215 ops;
};

struct bin_attribute___187;

struct attribute_group___185 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___187 **bin_attrs;
};

struct bin_attribute___187 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___47 *, struct kobject *, struct bin_attribute___187 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___47 *, struct kobject *, struct bin_attribute___187 *, char *, loff_t, size_t);
	int (*mmap)(struct file___47 *, struct kobject *, struct bin_attribute___187 *, struct vm_area_struct___51 *);
};

struct bus_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___215 *, char *);
	ssize_t (*store)(struct bus_type___215 *, const char *, size_t);
};

struct device_attribute___215;

struct driver_attribute___215;

struct bus_type___215 {
	const char *name;
	const char *dev_name;
	struct device___215 *dev_root;
	struct bus_attribute___215 *bus_attrs;
	struct device_attribute___215 *dev_attrs;
	struct driver_attribute___215 *drv_attrs;
	const struct attribute_group___185 **bus_groups;
	const struct attribute_group___185 **dev_groups;
	const struct attribute_group___185 **drv_groups;
	int (*match)(struct device___215 *, struct device_driver___215 *);
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	int (*probe)(struct device___215 *);
	int (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*online)(struct device___215 *);
	int (*offline)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct device___215 *, struct device_attribute___215 *, char *);
	ssize_t (*store)(struct device___215 *, struct device_attribute___215 *, const char *, size_t);
};

struct driver_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___215 *, char *);
	ssize_t (*store)(struct device_driver___215 *, const char *, size_t);
};

struct device_driver___215 {
	const char *name;
	struct bus_type___215 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___215 *);
	int (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	const struct attribute_group___185 **groups;
	const struct dev_pm_ops___215 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___215 {
	const char *name;
	const struct attribute_group___185 **groups;
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
};

struct class_attribute___215;

struct class___215 {
	const char *name;
	struct module *owner;
	struct class_attribute___215 *class_attrs;
	struct device_attribute___215 *dev_attrs;
	const struct attribute_group___185 **dev_groups;
	struct bin_attribute___187 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *);
	void (*class_release)(struct class___215 *);
	void (*dev_release)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
	struct subsys_private *p;
};

struct class_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct class___215 *, struct class_attribute___215 *, char *);
	ssize_t (*store)(struct class___215 *, struct class_attribute___215 *, const char *, size_t);
	const void * (*namespace)(struct class___215 *, const struct class_attribute___215 *);
};

struct device_rh___215 {
	struct dev_pm_info_rh___215 power;
};

struct usb_interface___9 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___215 dev;
	struct device___215 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___9 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___9 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___9;

struct mon_bus___3;

struct usb_bus___9 {
	struct device___215 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___9 *root_hub;
	struct usb_bus___9 *hs_companion;
	struct list_head bus_list;
	struct mutex___48 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus___3 *mon_bus;
	int monitored;
};

struct usb_device___9 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___9 *parent;
	struct usb_bus___9 *bus;
	struct usb_host_endpoint ep0;
	struct device___215 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___9 *config;
	struct usb_host_config___9 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct mon_bus___3 {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___9 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___48 *dent_s;
	struct dentry___48 *dent_t;
	struct dentry___48 *dent_u;
	struct device___215 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct urb___9;

typedef void (*usb_complete_t___9)(struct urb___9 *);

struct urb___9 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___9 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___9 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

typedef struct poll_table_struct___26 poll_table___28;

struct mon_reader___3 {
	struct list_head r_link;
	struct mon_bus___3 *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb___9 *);
	void (*rnf_error)(void *, struct urb___9 *, int);
	void (*rnf_complete)(void *, struct urb___9 *, int);
};

struct iso_rec {
	int error_count;
	int numdesc;
};

struct mon_bin_hdr {
	u64 id;
	unsigned char type;
	unsigned char xfer_type;
	unsigned char epnum;
	unsigned char devnum;
	short unsigned int busnum;
	char flag_setup;
	char flag_data;
	s64 ts_sec;
	s32 ts_usec;
	int status;
	unsigned int len_urb;
	unsigned int len_cap;
	union {
		unsigned char setup[8];
		struct iso_rec iso;
	} s;
	int interval;
	int start_frame;
	unsigned int xfer_flags;
	unsigned int ndesc;
};

struct mon_bin_isodesc {
	int iso_status;
	unsigned int iso_off;
	unsigned int iso_len;
	u32 _pad;
};

struct mon_bin_stats {
	u32 queued;
	u32 dropped;
};

struct mon_bin_get {
	struct mon_bin_hdr *hdr;
	void *data;
	size_t alloc;
};

struct mon_bin_mfetch {
	u32 *offvec;
	u32 nfetch;
	u32 nflush;
};

struct mon_bin_get32 {
	u32 hdr32;
	u32 data32;
	u32 alloc32;
};

struct mon_bin_mfetch32 {
	u32 offvec32;
	u32 nfetch32;
	u32 nflush32;
};

struct mon_pgmap {
	struct page___47 *pg;
	unsigned char *ptr;
};

struct mon_reader_bin {
	spinlock_t b_lock;
	unsigned int b_size;
	unsigned int b_cnt;
	unsigned int b_in;
	unsigned int b_out;
	unsigned int b_read;
	struct mon_pgmap *b_vec;
	wait_queue_head_t b_wait;
	struct mutex___48 fetch_lock;
	int mmap_active;
	struct mon_reader___3 r;
	unsigned int cnt_lost;
};

enum amd_chipset_gen {
	NOT_AMD_CHIPSET = 0,
	AMD_CHIPSET_SB600 = 1,
	AMD_CHIPSET_SB700 = 2,
	AMD_CHIPSET_SB800 = 3,
	AMD_CHIPSET_HUDSON2 = 4,
	AMD_CHIPSET_BOLTON = 5,
	AMD_CHIPSET_YANGTZE = 6,
	AMD_CHIPSET_UNKNOWN = 7,
};

struct amd_chipset_type {
	enum amd_chipset_gen gen;
	u8 rev;
};

struct amd_chipset_info {
	struct pci_dev___22 *nb_dev;
	struct pci_dev___22 *smbus_dev;
	int nb_type;
	struct amd_chipset_type sb_type;
	int isoc_reqs;
	int probe_count;
	int probe_result;
};

struct xhci_cap_regs {
	__le32 hc_capbase;
	__le32 hcs_params1;
	__le32 hcs_params2;
	__le32 hcs_params3;
	__le32 hcc_params;
	__le32 db_off;
	__le32 run_regs_off;
};

struct xhci_op_regs {
	__le32 command;
	__le32 status;
	__le32 page_size;
	__le32 reserved1;
	__le32 reserved2;
	__le32 dev_notification;
	__le64 cmd_ring;
	__le32 reserved3[4];
	__le64 dcbaa_ptr;
	__le32 config_reg;
	__le32 reserved4[241];
	__le32 port_status_base;
	__le32 port_power_base;
	__le32 port_link_base;
	__le32 reserved5;
	__le32 reserved6[1016];
};

struct xhci_intr_reg {
	__le32 irq_pending;
	__le32 irq_control;
	__le32 erst_size;
	__le32 rsvd;
	__le64 erst_base;
	__le64 erst_dequeue;
};

struct xhci_run_regs {
	__le32 microframe_index;
	__le32 rsvd[7];
	struct xhci_intr_reg ir_set[128];
};

struct xhci_doorbell_array {
	__le32 doorbell[256];
};

struct xhci_container_ctx {
	unsigned int type;
	int size;
	u8 *bytes;
	dma_addr_t dma;
};

union xhci_trb;

struct xhci_command {
	struct xhci_container_ctx *in_ctx;
	u32 status;
	struct completion *completion;
	union xhci_trb *command_trb;
	struct list_head cmd_list;
};

struct xhci_link_trb {
	__le64 segment_ptr;
	__le32 intr_target;
	__le32 control;
};

struct xhci_transfer_event {
	__le64 buffer;
	__le32 transfer_len;
	__le32 flags;
};

struct xhci_event_cmd {
	__le64 cmd_trb;
	__le32 status;
	__le32 flags;
};

struct xhci_generic_trb {
	__le32 field[4];
};

union xhci_trb {
	struct xhci_link_trb link;
	struct xhci_transfer_event trans_event;
	struct xhci_event_cmd event_cmd;
	struct xhci_generic_trb generic;
};

struct xhci_stream_ctx {
	__le64 stream_ring;
	__le32 reserved[2];
};

struct xhci_ring;

struct xhci_stream_info {
	struct xhci_ring **stream_rings;
	unsigned int num_streams;
	struct xhci_stream_ctx *stream_ctx_array;
	unsigned int num_stream_ctxs;
	dma_addr_t ctx_array_dma;
	struct radix_tree_root trb_address_map;
	struct xhci_command *free_streams_command;
};

enum xhci_ring_type {
	TYPE_CTRL = 0,
	TYPE_ISOC = 1,
	TYPE_BULK = 2,
	TYPE_INTR = 3,
	TYPE_STREAM = 4,
	TYPE_COMMAND = 5,
	TYPE_EVENT = 6,
};

struct xhci_segment;

struct xhci_ring {
	struct xhci_segment *first_seg;
	struct xhci_segment *last_seg;
	union xhci_trb *enqueue;
	struct xhci_segment *enq_seg;
	unsigned int enq_updates;
	union xhci_trb *dequeue;
	struct xhci_segment *deq_seg;
	unsigned int deq_updates;
	struct list_head td_list;
	u32 cycle_state;
	unsigned int stream_id;
	unsigned int num_segs;
	unsigned int num_trbs_free;
	unsigned int num_trbs_free_temp;
	enum xhci_ring_type type;
	bool last_td_was_short;
	struct radix_tree_root *trb_address_map;
};

struct xhci_bw_info {
	unsigned int ep_interval;
	unsigned int mult;
	unsigned int num_packets;
	unsigned int max_packet_size;
	unsigned int max_esit_payload;
	unsigned int type;
};

struct xhci_td;

struct xhci_hcd;

struct xhci_virt_ep {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct xhci_td *stopped_td;
	unsigned int stopped_stream;
	struct timer_list stop_cmd_timer;
	int stop_cmds_pending;
	struct xhci_hcd *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
};

struct xhci_td {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___4 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	bool urb_length_set;
};

struct xhci_erst_entry;

struct xhci_erst {
	struct xhci_erst_entry *entries;
	unsigned int num_entries;
	dma_addr_t erst_dma_addr;
	unsigned int erst_size;
};

struct s3_save {
	u32 command;
	u32 dev_nt;
	u64 dcbaa_ptr;
	u32 config_reg;
	u32 irq_pending;
	u32 irq_control;
	u32 erst_size;
	u64 erst_base;
	u64 erst_dequeue;
};

struct xhci_bus_state {
	long unsigned int bus_suspended;
	long unsigned int next_statechange;
	u32 port_c_suspend;
	u32 suspended_ports;
	u32 port_remote_wakeup;
	long unsigned int resume_done[31];
	long unsigned int resuming_ports;
	long unsigned int rexit_ports;
	struct completion rexit_done[31];
};

struct xhci_device_context_array;

struct xhci_scratchpad;

struct xhci_virt_device;

struct xhci_root_port_bw_info;

struct xhci_hcd {
	struct usb_hcd___4 *main_hcd;
	struct usb_hcd___4 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	int event_ring_max;
	int addr_64;
	int page_size;
	int page_shift;
	int msix_count;
	struct msix_entry *msix_entries;
	struct clk *clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct timer_list cmd_timer;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex___209 mutex;
	struct completion addr_dev;
	int slot_id;
	struct xhci_command *lpm_command;
	struct xhci_virt_device *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	int error_bitmask;
	unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	u8 *port_array;
	__le32 **usb3_ports;
	unsigned int num_usb3_ports;
	__le32 **usb2_ports;
	unsigned int num_usb2_ports;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
};

struct xhci_segment {
	union xhci_trb *trbs;
	struct xhci_segment *next;
	dma_addr_t dma;
};

struct xhci_interval_bw {
	unsigned int num_packets;
	struct list_head endpoints;
	unsigned int overhead[3];
};

struct xhci_interval_bw_table {
	unsigned int interval0_esit_payload;
	struct xhci_interval_bw interval_bw[16];
	unsigned int bw_used;
	unsigned int ss_bw_in;
	unsigned int ss_bw_out;
};

struct xhci_tt_bw_info;

struct xhci_virt_device {
	struct usb_device___4 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_ring **ring_cache;
	int num_rings_cached;
	struct xhci_virt_ep eps[31];
	struct completion cmd_completion;
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
};

struct xhci_tt_bw_info {
	struct list_head tt_list;
	int slot_id;
	int ttport;
	struct xhci_interval_bw_table bw_table;
	int active_eps;
};

struct xhci_root_port_bw_info {
	struct list_head tts;
	unsigned int num_active_tts;
	struct xhci_interval_bw_table bw_table;
};

struct xhci_device_context_array {
	__le64 dev_context_ptrs[256];
	dma_addr_t dma;
};

struct xhci_erst_entry {
	__le64 seg_addr;
	__le32 seg_size;
	__le32 rsvd;
};

struct xhci_scratchpad {
	u64 *sp_array;
	dma_addr_t sp_dma;
	void **sp_buffers;
	dma_addr_t *sp_dma_buffers;
};

typedef void (*xhci_get_quirks_t)(struct device___210 *, struct xhci_hcd *);

struct usb_interface___10 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___157 dev;
	struct device___157 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___10 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___10 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___10;

struct usb_bus___10 {
	struct device___157 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___10 *root_hub;
	struct usb_bus___10 *hs_companion;
	struct list_head bus_list;
	struct mutex___80 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___8;

struct usb_device___10 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___8 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___10 *parent;
	struct usb_bus___10 *bus;
	struct usb_host_endpoint ep0;
	struct device___157 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___10 *config;
	struct usb_host_config___10 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___8 {
	struct usb_device___10 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___10;

typedef void (*usb_complete_t___10)(struct urb___10 *);

struct urb___10 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___10 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___10 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___8;

struct usb_phy___3;

struct usb_hcd___8 {
	struct usb_bus___10 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___10 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___8 *driver;
	struct usb_phy___3 *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___80 *bandwidth_mutex;
	struct usb_hcd___8 *shared_hcd;
	struct usb_hcd___8 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___8 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___8 *);
	int flags;
	int (*reset)(struct usb_hcd___8 *);
	int (*start)(struct usb_hcd___8 *);
	int (*pci_suspend)(struct usb_hcd___8 *, bool);
	int (*pci_resume)(struct usb_hcd___8 *, bool);
	void (*stop)(struct usb_hcd___8 *);
	void (*shutdown)(struct usb_hcd___8 *);
	int (*get_frame_number)(struct usb_hcd___8 *);
	int (*urb_enqueue)(struct usb_hcd___8 *, struct urb___10 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___8 *, struct urb___10 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___8 *, struct urb___10 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___8 *, struct urb___10 *);
	void (*endpoint_disable)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___8 *, char *);
	int (*hub_control)(struct usb_hcd___8 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___8 *);
	int (*bus_resume)(struct usb_hcd___8 *);
	int (*start_port_reset)(struct usb_hcd___8 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___8 *, int);
	int (*port_handed_over)(struct usb_hcd___8 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___8 *, struct usb_device___10 *);
	void (*free_dev)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*alloc_streams)(struct usb_hcd___8 *, struct usb_device___10 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___8 *, struct usb_device___10 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___8 *, struct usb_device___10 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___8 *, struct usb_device___10 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___8 *, struct usb_device___10 *);
	void (*reset_bandwidth)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*address_device)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*enable_device)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*update_hub_device)(struct usb_hcd___8 *, struct usb_device___10 *, struct usb_tt___8 *, gfp_t);
	int (*reset_device)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*update_device)(struct usb_hcd___8 *, struct usb_device___10 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___8 *, struct usb_device___10 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___8 *, struct usb_device___10 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___8 *, struct usb_device___10 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___8 *, int);
	int (*port_power)(struct usb_hcd___8 *, int, bool);
};

struct usb_otg___2;

struct usb_phy_io_ops___2;

struct usb_phy___3 {
	struct device___157 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_otg_state state;
	enum usb_phy_events last_event;
	struct usb_otg___2 *otg;
	struct device___157 *io_dev;
	struct usb_phy_io_ops___2 *io_ops;
	void *io_priv;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___3 *);
	void (*shutdown)(struct usb_phy___3 *);
	int (*set_vbus)(struct usb_phy___3 *, int);
	int (*set_power)(struct usb_phy___3 *, unsigned int);
	int (*set_suspend)(struct usb_phy___3 *, int);
	int (*notify_connect)(struct usb_phy___3 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___3 *, enum usb_device_speed);
};

struct usb_mon_operations___8 {
	void (*urb_submit)(struct usb_bus___10 *, struct urb___10 *);
	void (*urb_submit_error)(struct usb_bus___10 *, struct urb___10 *, int);
	void (*urb_complete)(struct usb_bus___10 *, struct urb___10 *, int);
};

struct ehci_stats {
	long unsigned int normal;
	long unsigned int error;
	long unsigned int iaa;
	long unsigned int lost_iaa;
	long unsigned int complete;
	long unsigned int unlink;
};

struct ehci_per_sched {
	struct usb_device___10 *udev;
	struct usb_host_endpoint *ep;
	struct list_head ps_list;
	u16 tt_usecs;
	u16 cs_mask;
	u16 period;
	u16 phase;
	u8 bw_phase;
	u8 phase_uf;
	u8 usecs;
	u8 c_usecs;
	u8 bw_uperiod;
	u8 bw_period;
};

enum ehci_rh_state {
	EHCI_RH_HALTED = 0,
	EHCI_RH_SUSPENDED = 1,
	EHCI_RH_RUNNING = 2,
	EHCI_RH_STOPPING = 3,
};

enum ehci_hrtimer_event {
	EHCI_HRTIMER_POLL_ASS = 0,
	EHCI_HRTIMER_POLL_PSS = 1,
	EHCI_HRTIMER_POLL_DEAD = 2,
	EHCI_HRTIMER_UNLINK_INTR = 3,
	EHCI_HRTIMER_FREE_ITDS = 4,
	EHCI_HRTIMER_START_UNLINK_INTR = 5,
	EHCI_HRTIMER_ASYNC_UNLINKS = 6,
	EHCI_HRTIMER_IAA_WATCHDOG = 7,
	EHCI_HRTIMER_DISABLE_PERIODIC = 8,
	EHCI_HRTIMER_DISABLE_ASYNC = 9,
	EHCI_HRTIMER_IO_WATCHDOG = 10,
	EHCI_HRTIMER_NUM_EVENTS = 11,
};

struct ehci_caps;

struct ehci_regs;

struct ehci_dbg_port;

struct ehci_qh;

union ehci_shadow;

struct ehci_itd;

struct ehci_sitd;

struct ehci_hcd {
	enum ehci_hrtimer_event next_hrtimer_event;
	unsigned int enabled_hrtimer_events;
	ktime_t hr_timeouts[11];
	struct hrtimer hrtimer;
	int PSS_poll_count;
	int ASS_poll_count;
	int died_poll_count;
	struct ehci_caps *caps;
	struct ehci_regs *regs;
	struct ehci_dbg_port *debug;
	__u32 hcs_params;
	spinlock_t lock;
	enum ehci_rh_state rh_state;
	bool scanning: 1;
	bool need_rescan: 1;
	bool intr_unlinking: 1;
	bool iaa_in_progress: 1;
	bool async_unlinking: 1;
	bool shutdown: 1;
	struct ehci_qh *qh_scan_next;
	struct ehci_qh *async;
	struct ehci_qh *dummy;
	struct list_head async_unlink;
	struct list_head async_idle;
	unsigned int async_unlink_cycle;
	unsigned int async_count;
	unsigned int periodic_size;
	__le32 *periodic;
	dma_addr_t periodic_dma;
	struct list_head intr_qh_list;
	unsigned int i_thresh;
	union ehci_shadow *pshadow;
	struct list_head intr_unlink_wait;
	struct list_head intr_unlink;
	unsigned int intr_unlink_wait_cycle;
	unsigned int intr_unlink_cycle;
	unsigned int now_frame;
	unsigned int last_iso_frame;
	unsigned int intr_count;
	unsigned int isoc_count;
	unsigned int periodic_count;
	unsigned int uframe_periodic_max;
	struct list_head cached_itd_list;
	struct ehci_itd *last_itd_to_free;
	struct list_head cached_sitd_list;
	struct ehci_sitd *last_sitd_to_free;
	long unsigned int reset_done[15];
	long unsigned int bus_suspended;
	long unsigned int companion_ports;
	long unsigned int owned_ports;
	long unsigned int port_c_suspend;
	long unsigned int suspended_ports;
	long unsigned int resuming_ports;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *qtd_pool;
	struct dma_pool___2 *itd_pool;
	struct dma_pool___2 *sitd_pool;
	unsigned int random_frame;
	long unsigned int next_statechange;
	ktime_t last_periodic_enable;
	u32 command;
	unsigned int no_selective_suspend: 1;
	unsigned int has_fsl_port_bug: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int big_endian_capbase: 1;
	unsigned int has_amcc_usb23: 1;
	unsigned int need_io_watchdog: 1;
	unsigned int amd_pll_fix: 1;
	unsigned int use_dummy_qh: 1;
	unsigned int has_synopsys_hc_bug: 1;
	unsigned int frame_index_bug: 1;
	unsigned int need_oc_pp_cycle: 1;
	__le32 *ohci_hcctrl_reg;
	unsigned int has_hostpc: 1;
	unsigned int has_ppcd: 1;
	u8 sbrn;
	struct ehci_stats stats;
	struct dentry___81 *debug_dir;
	u8 bandwidth[64];
	u8 tt_budget[64];
	struct list_head tt_list;
	long unsigned int priv[0];
};

struct ehci_caps {
	u32 hc_capbase;
	u32 hcs_params;
	u32 hcc_params;
	u8 portroute[8];
};

struct ehci_regs {
	u32 command;
	u32 status;
	u32 intr_enable;
	u32 frame_index;
	u32 segment;
	u32 frame_list;
	u32 async_next;
	u32 reserved1[2];
	u32 txfill_tuning;
	u32 reserved2[6];
	u32 configured_flag;
	u32 port_status[0];
	u32 reserved3[9];
	u32 usbmode;
	u32 reserved4[6];
	u32 hostpc[1];
	u32 reserved5[16];
	u32 usbmode_ex;
};

struct ehci_dbg_port {
	u32 control;
	u32 pids;
	u32 data03;
	u32 data47;
	u32 address;
};

struct ehci_fstn;

union ehci_shadow {
	struct ehci_qh *qh;
	struct ehci_itd *itd;
	struct ehci_sitd *sitd;
	struct ehci_fstn *fstn;
	__le32 *hw_next;
	void *ptr;
};

struct ehci_qh_hw;

struct ehci_qtd;

struct ehci_qh {
	struct ehci_qh_hw *hw;
	dma_addr_t qh_dma;
	union ehci_shadow qh_next;
	struct list_head qtd_list;
	struct list_head intr_node;
	struct ehci_qtd *dummy;
	struct list_head unlink_node;
	struct ehci_per_sched ps;
	unsigned int unlink_cycle;
	u8 qh_state;
	u8 xacterrs;
	u8 gap_uf;
	unsigned int is_out: 1;
	unsigned int clearing_tt: 1;
	unsigned int dequeue_during_giveback: 1;
	unsigned int exception: 1;
};

struct ehci_iso_stream;

struct ehci_itd {
	__le32 hw_next;
	__le32 hw_transaction[8];
	__le32 hw_bufp[7];
	__le32 hw_bufp_hi[7];
	dma_addr_t itd_dma;
	union ehci_shadow itd_next;
	struct urb___10 *urb;
	struct ehci_iso_stream *stream;
	struct list_head itd_list;
	unsigned int frame;
	unsigned int pg;
	unsigned int index[8];
	long: 64;
};

struct ehci_sitd {
	__le32 hw_next;
	__le32 hw_fullspeed_ep;
	__le32 hw_uframe;
	__le32 hw_results;
	__le32 hw_buf[2];
	__le32 hw_backpointer;
	__le32 hw_buf_hi[2];
	dma_addr_t sitd_dma;
	union ehci_shadow sitd_next;
	struct urb___10 *urb;
	struct ehci_iso_stream *stream;
	struct list_head sitd_list;
	unsigned int frame;
	unsigned int index;
};

struct ehci_qtd {
	__le32 hw_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	dma_addr_t qtd_dma;
	struct list_head qtd_list;
	struct urb___10 *urb;
	size_t length;
};

struct ehci_fstn {
	__le32 hw_next;
	__le32 hw_prev;
	dma_addr_t fstn_dma;
	union ehci_shadow fstn_next;
	long: 64;
};

struct ehci_qh_hw {
	__le32 hw_next;
	__le32 hw_info1;
	__le32 hw_info2;
	__le32 hw_current;
	__le32 hw_qtd_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct ehci_iso_packet {
	u64 bufp;
	__le32 transaction;
	u8 cross;
	u32 buf1;
};

struct ehci_iso_sched {
	struct list_head td_list;
	unsigned int span;
	unsigned int first_packet;
	struct ehci_iso_packet packet[0];
};

struct ehci_iso_stream {
	struct ehci_qh_hw *hw;
	u8 bEndpointAddress;
	u8 highspeed;
	struct list_head td_list;
	struct list_head free_list;
	struct ehci_per_sched ps;
	unsigned int next_uframe;
	__le32 splits;
	u16 uperiod;
	u16 maxp;
	unsigned int bandwidth;
	__le32 buf0;
	__le32 buf1;
	__le32 buf2;
	__le32 address;
};

struct ehci_tt {
	u16 bandwidth[8];
	struct list_head tt_list;
	struct list_head ps_list;
	struct usb_tt___8 *usb_tt;
	int tt_port;
};

struct ehci_driver_overrides {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___8 *);
	int (*port_power)(struct usb_hcd___8 *, int, bool);
};

struct debug_buffer {
	ssize_t (*fill_func)(struct debug_buffer *);
	struct usb_bus___10 *bus;
	struct mutex___80 mutex;
	size_t count;
	char *output_buf;
	size_t alloc_size;
};

struct usb_phy_io_ops___2 {
	int (*read)(struct usb_phy___3 *, u32);
	int (*write)(struct usb_phy___3 *, u32, u32);
};

struct usb_otg___2 {
	u8 default_a;
	struct usb_phy___3 *phy;
	struct usb_bus___10 *host;
	struct usb_gadget *gadget;
	int (*set_host)(struct usb_otg___2 *, struct usb_bus___10 *);
	int (*set_peripheral)(struct usb_otg___2 *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg___2 *, bool);
	int (*start_srp)(struct usb_otg___2 *);
	int (*start_hnp)(struct usb_otg___2 *);
};

struct ehci_per_sched___2 {
	struct usb_device___4 *udev;
	struct usb_host_endpoint *ep;
	struct list_head ps_list;
	u16 tt_usecs;
	u16 cs_mask;
	u16 period;
	u16 phase;
	u8 bw_phase;
	u8 phase_uf;
	u8 usecs;
	u8 c_usecs;
	u8 bw_uperiod;
	u8 bw_period;
};

struct ehci_qh___2;

union ehci_shadow___2;

struct ehci_itd___2;

struct ehci_sitd___2;

struct ehci_hcd___2 {
	enum ehci_hrtimer_event next_hrtimer_event;
	unsigned int enabled_hrtimer_events;
	ktime_t hr_timeouts[11];
	struct hrtimer hrtimer;
	int PSS_poll_count;
	int ASS_poll_count;
	int died_poll_count;
	struct ehci_caps *caps;
	struct ehci_regs *regs;
	struct ehci_dbg_port *debug;
	__u32 hcs_params;
	spinlock_t lock;
	enum ehci_rh_state rh_state;
	bool scanning: 1;
	bool need_rescan: 1;
	bool intr_unlinking: 1;
	bool iaa_in_progress: 1;
	bool async_unlinking: 1;
	bool shutdown: 1;
	struct ehci_qh___2 *qh_scan_next;
	struct ehci_qh___2 *async;
	struct ehci_qh___2 *dummy;
	struct list_head async_unlink;
	struct list_head async_idle;
	unsigned int async_unlink_cycle;
	unsigned int async_count;
	unsigned int periodic_size;
	__le32 *periodic;
	dma_addr_t periodic_dma;
	struct list_head intr_qh_list;
	unsigned int i_thresh;
	union ehci_shadow___2 *pshadow;
	struct list_head intr_unlink_wait;
	struct list_head intr_unlink;
	unsigned int intr_unlink_wait_cycle;
	unsigned int intr_unlink_cycle;
	unsigned int now_frame;
	unsigned int last_iso_frame;
	unsigned int intr_count;
	unsigned int isoc_count;
	unsigned int periodic_count;
	unsigned int uframe_periodic_max;
	struct list_head cached_itd_list;
	struct ehci_itd___2 *last_itd_to_free;
	struct list_head cached_sitd_list;
	struct ehci_sitd___2 *last_sitd_to_free;
	long unsigned int reset_done[15];
	long unsigned int bus_suspended;
	long unsigned int companion_ports;
	long unsigned int owned_ports;
	long unsigned int port_c_suspend;
	long unsigned int suspended_ports;
	long unsigned int resuming_ports;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *qtd_pool;
	struct dma_pool___2 *itd_pool;
	struct dma_pool___2 *sitd_pool;
	unsigned int random_frame;
	long unsigned int next_statechange;
	ktime_t last_periodic_enable;
	u32 command;
	unsigned int no_selective_suspend: 1;
	unsigned int has_fsl_port_bug: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int big_endian_capbase: 1;
	unsigned int has_amcc_usb23: 1;
	unsigned int need_io_watchdog: 1;
	unsigned int amd_pll_fix: 1;
	unsigned int use_dummy_qh: 1;
	unsigned int has_synopsys_hc_bug: 1;
	unsigned int frame_index_bug: 1;
	unsigned int need_oc_pp_cycle: 1;
	__le32 *ohci_hcctrl_reg;
	unsigned int has_hostpc: 1;
	unsigned int has_ppcd: 1;
	u8 sbrn;
	struct ehci_stats stats;
	struct dentry___207 *debug_dir;
	u8 bandwidth[64];
	u8 tt_budget[64];
	struct list_head tt_list;
	long unsigned int priv[0];
};

struct ehci_fstn___2;

union ehci_shadow___2 {
	struct ehci_qh___2 *qh;
	struct ehci_itd___2 *itd;
	struct ehci_sitd___2 *sitd;
	struct ehci_fstn___2 *fstn;
	__le32 *hw_next;
	void *ptr;
};

struct ehci_qtd___2;

struct ehci_qh___2 {
	struct ehci_qh_hw *hw;
	dma_addr_t qh_dma;
	union ehci_shadow___2 qh_next;
	struct list_head qtd_list;
	struct list_head intr_node;
	struct ehci_qtd___2 *dummy;
	struct list_head unlink_node;
	struct ehci_per_sched___2 ps;
	unsigned int unlink_cycle;
	u8 qh_state;
	u8 xacterrs;
	u8 gap_uf;
	unsigned int is_out: 1;
	unsigned int clearing_tt: 1;
	unsigned int dequeue_during_giveback: 1;
	unsigned int exception: 1;
};

struct ehci_iso_stream___2;

struct ehci_itd___2 {
	__le32 hw_next;
	__le32 hw_transaction[8];
	__le32 hw_bufp[7];
	__le32 hw_bufp_hi[7];
	dma_addr_t itd_dma;
	union ehci_shadow___2 itd_next;
	struct urb___4 *urb;
	struct ehci_iso_stream___2 *stream;
	struct list_head itd_list;
	unsigned int frame;
	unsigned int pg;
	unsigned int index[8];
	long: 64;
};

struct ehci_sitd___2 {
	__le32 hw_next;
	__le32 hw_fullspeed_ep;
	__le32 hw_uframe;
	__le32 hw_results;
	__le32 hw_buf[2];
	__le32 hw_backpointer;
	__le32 hw_buf_hi[2];
	dma_addr_t sitd_dma;
	union ehci_shadow___2 sitd_next;
	struct urb___4 *urb;
	struct ehci_iso_stream___2 *stream;
	struct list_head sitd_list;
	unsigned int frame;
	unsigned int index;
};

struct ehci_qtd___2 {
	__le32 hw_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	dma_addr_t qtd_dma;
	struct list_head qtd_list;
	struct urb___4 *urb;
	size_t length;
};

struct ehci_fstn___2 {
	__le32 hw_next;
	__le32 hw_prev;
	dma_addr_t fstn_dma;
	union ehci_shadow___2 fstn_next;
	long: 64;
};

struct ehci_iso_stream___2 {
	struct ehci_qh_hw *hw;
	u8 bEndpointAddress;
	u8 highspeed;
	struct list_head td_list;
	struct list_head free_list;
	struct ehci_per_sched___2 ps;
	unsigned int next_uframe;
	__le32 splits;
	u16 uperiod;
	u16 maxp;
	unsigned int bandwidth;
	__le32 buf0;
	__le32 buf1;
	__le32 buf2;
	__le32 address;
};

struct ehci_driver_overrides___2 {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___4 *);
	int (*port_power)(struct usb_hcd___4 *, int, bool);
};

typedef __u32 __hc32;

typedef __u16 __hc16;

struct td;

struct ed {
	__hc32 hwINFO;
	__hc32 hwTailP;
	__hc32 hwHeadP;
	__hc32 hwNextED;
	dma_addr_t dma;
	struct td *dummy;
	struct ed *ed_next;
	struct ed *ed_prev;
	struct list_head td_list;
	struct list_head in_use_list;
	u8 state;
	u8 type;
	u8 branch;
	u16 interval;
	u16 load;
	u16 last_iso;
	u16 tick;
	unsigned int takeback_wdh_cnt;
	struct td *pending_td;
	long: 64;
};

struct td {
	__hc32 hwINFO;
	__hc32 hwCBP;
	__hc32 hwNextTD;
	__hc32 hwBE;
	__hc16 hwPSW[2];
	__u8 index;
	struct ed *ed;
	struct td *td_hash;
	struct td *next_dl_td;
	struct urb___10 *urb;
	dma_addr_t td_dma;
	dma_addr_t data_dma;
	struct list_head td_list;
	long: 64;
};

struct ohci_hcca {
	__hc32 int_table[32];
	__hc32 frame_no;
	__hc32 done_head;
	u8 reserved_for_hc[116];
	u8 what[4];
};

struct ohci_roothub_regs {
	__hc32 a;
	__hc32 b;
	__hc32 status;
	__hc32 portstatus[15];
};

struct ohci_regs {
	__hc32 revision;
	__hc32 control;
	__hc32 cmdstatus;
	__hc32 intrstatus;
	__hc32 intrenable;
	__hc32 intrdisable;
	__hc32 hcca;
	__hc32 ed_periodcurrent;
	__hc32 ed_controlhead;
	__hc32 ed_controlcurrent;
	__hc32 ed_bulkhead;
	__hc32 ed_bulkcurrent;
	__hc32 donehead;
	__hc32 fminterval;
	__hc32 fmremaining;
	__hc32 fmnumber;
	__hc32 periodicstart;
	__hc32 lsthresh;
	struct ohci_roothub_regs roothub;
	long: 64;
	long: 64;
};

struct urb_priv {
	struct ed *ed;
	u16 length;
	u16 td_cnt;
	struct list_head pending;
	struct td *td[0];
};

typedef struct urb_priv urb_priv_t;

enum ohci_rh_state {
	OHCI_RH_HALTED = 0,
	OHCI_RH_SUSPENDED = 1,
	OHCI_RH_RUNNING = 2,
};

struct ohci_hcd {
	spinlock_t lock;
	struct ohci_regs *regs;
	struct ohci_hcca *hcca;
	dma_addr_t hcca_dma;
	struct ed *ed_rm_list;
	struct ed *ed_bulktail;
	struct ed *ed_controltail;
	struct ed *periodic[32];
	void (*start_hnp)(struct ohci_hcd *);
	struct dma_pool___2 *td_cache;
	struct dma_pool___2 *ed_cache;
	struct td *td_hash[64];
	struct td *dl_start;
	struct td *dl_end;
	struct list_head pending;
	struct list_head eds_in_use;
	enum ohci_rh_state rh_state;
	int num_ports;
	int load[32];
	u32 hc_control;
	long unsigned int next_statechange;
	u32 fminterval;
	unsigned int autostop: 1;
	unsigned int working: 1;
	unsigned int restart_work: 1;
	long unsigned int flags;
	unsigned int prev_frame_no;
	unsigned int wdh_cnt;
	unsigned int prev_wdh_cnt;
	u32 prev_donehead;
	struct timer_list io_watchdog;
	struct work_struct nec_work;
	struct dentry___81 *debug_dir;
	struct dentry___81 *debug_async;
	struct dentry___81 *debug_periodic;
	struct dentry___81 *debug_registers;
	long unsigned int priv[0];
};

struct ohci_driver_overrides {
	const char *product_desc;
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___8 *);
};

struct debug_buffer___2 {
	ssize_t (*fill_func)(struct debug_buffer___2 *);
	struct ohci_hcd *ohci;
	struct mutex___80 mutex;
	size_t count;
	char *page;
};

struct td___2;

struct ed___2 {
	__hc32 hwINFO;
	__hc32 hwTailP;
	__hc32 hwHeadP;
	__hc32 hwNextED;
	dma_addr_t dma;
	struct td___2 *dummy;
	struct ed___2 *ed_next;
	struct ed___2 *ed_prev;
	struct list_head td_list;
	struct list_head in_use_list;
	u8 state;
	u8 type;
	u8 branch;
	u16 interval;
	u16 load;
	u16 last_iso;
	u16 tick;
	unsigned int takeback_wdh_cnt;
	struct td___2 *pending_td;
	long: 64;
};

struct td___2 {
	__hc32 hwINFO;
	__hc32 hwCBP;
	__hc32 hwNextTD;
	__hc32 hwBE;
	__hc16 hwPSW[2];
	__u8 index;
	struct ed___2 *ed;
	struct td___2 *td_hash;
	struct td___2 *next_dl_td;
	struct urb___4 *urb;
	dma_addr_t td_dma;
	dma_addr_t data_dma;
	struct list_head td_list;
	long: 64;
};

struct ohci_hcd___2 {
	spinlock_t lock;
	struct ohci_regs *regs;
	struct ohci_hcca *hcca;
	dma_addr_t hcca_dma;
	struct ed___2 *ed_rm_list;
	struct ed___2 *ed_bulktail;
	struct ed___2 *ed_controltail;
	struct ed___2 *periodic[32];
	void (*start_hnp)(struct ohci_hcd___2 *);
	struct dma_pool___2 *td_cache;
	struct dma_pool___2 *ed_cache;
	struct td___2 *td_hash[64];
	struct td___2 *dl_start;
	struct td___2 *dl_end;
	struct list_head pending;
	struct list_head eds_in_use;
	enum ohci_rh_state rh_state;
	int num_ports;
	int load[32];
	u32 hc_control;
	long unsigned int next_statechange;
	u32 fminterval;
	unsigned int autostop: 1;
	unsigned int working: 1;
	unsigned int restart_work: 1;
	long unsigned int flags;
	unsigned int prev_frame_no;
	unsigned int wdh_cnt;
	unsigned int prev_wdh_cnt;
	u32 prev_donehead;
	struct timer_list io_watchdog;
	struct work_struct nec_work;
	struct dentry___207 *debug_dir;
	struct dentry___207 *debug_async;
	struct dentry___207 *debug_periodic;
	struct dentry___207 *debug_registers;
	long unsigned int priv[0];
};

struct ohci_driver_overrides___2 {
	const char *product_desc;
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___4 *);
};

struct uhci_td;

struct uhci_qh {
	__le32 link;
	__le32 element;
	dma_addr_t dma_handle;
	struct list_head node;
	struct usb_host_endpoint *hep;
	struct usb_device___4 *udev;
	struct list_head queue;
	struct uhci_td *dummy_td;
	struct uhci_td *post_td;
	struct usb_iso_packet_descriptor *iso_packet_desc;
	long unsigned int advance_jiffies;
	unsigned int unlink_frame;
	unsigned int period;
	short int phase;
	short int load;
	unsigned int iso_frame;
	int state;
	int type;
	int skel;
	unsigned int initial_toggle: 1;
	unsigned int needs_fixup: 1;
	unsigned int is_stopped: 1;
	unsigned int wait_expired: 1;
	unsigned int bandwidth_reserved: 1;
};

struct uhci_td {
	__le32 link;
	__le32 status;
	__le32 token;
	__le32 buffer;
	dma_addr_t dma_handle;
	struct list_head list;
	int frame;
	struct list_head fl_list;
};

enum uhci_rh_state {
	UHCI_RH_RESET = 0,
	UHCI_RH_SUSPENDED = 1,
	UHCI_RH_AUTO_STOPPED = 2,
	UHCI_RH_RESUMING = 3,
	UHCI_RH_SUSPENDING = 4,
	UHCI_RH_RUNNING = 5,
	UHCI_RH_RUNNING_NODEVS = 6,
};

struct uhci_hcd {
	struct dentry___207 *dentry;
	long unsigned int io_addr;
	void *regs;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *td_pool;
	struct uhci_td *term_td;
	struct uhci_qh *skelqh[11];
	struct uhci_qh *next_qh;
	spinlock_t lock;
	dma_addr_t frame_dma_handle;
	__le32 *frame;
	void **frame_cpu;
	enum uhci_rh_state rh_state;
	long unsigned int auto_stop_time;
	unsigned int frame_number;
	unsigned int is_stopped;
	unsigned int last_iso_frame;
	unsigned int cur_iso_frame;
	unsigned int scan_in_progress: 1;
	unsigned int need_rescan: 1;
	unsigned int dead: 1;
	unsigned int RD_enable: 1;
	unsigned int is_initialized: 1;
	unsigned int fsbr_is_on: 1;
	unsigned int fsbr_is_wanted: 1;
	unsigned int fsbr_expiring: 1;
	struct timer_list fsbr_timer;
	unsigned int oc_low: 1;
	unsigned int wait_for_hp: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	long unsigned int port_c_suspend;
	long unsigned int resuming_ports;
	long unsigned int ports_timeout;
	struct list_head idle_qh_list;
	int rh_numports;
	wait_queue_head_t waitqh;
	int num_waiting;
	int total_load;
	short int load[32];
	void (*reset_hc)(struct uhci_hcd *);
	int (*check_and_reset_hc)(struct uhci_hcd *);
	void (*configure_hc)(struct uhci_hcd *);
	int (*resume_detect_interrupts_are_broken)(struct uhci_hcd *);
	int (*global_suspend_mode_is_broken)(struct uhci_hcd *);
};

struct urb_priv___2 {
	struct list_head node;
	struct urb___4 *urb;
	struct uhci_qh *qh;
	struct list_head td_list;
	unsigned int fsbr: 1;
};

struct uhci_debug {
	int size;
	char *data;
};

struct usbdrv_wrap___5 {
	struct device_driver___210 driver;
	int for_devices;
};

struct usb_driver___5 {
	const char *name;
	int (*probe)(struct usb_interface___4 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___4 *);
	int (*unlocked_ioctl)(struct usb_interface___4 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___4 *, pm_message_t);
	int (*resume)(struct usb_interface___4 *);
	int (*reset_resume)(struct usb_interface___4 *);
	int (*pre_reset)(struct usb_interface___4 *);
	int (*post_reset)(struct usb_interface___4 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___5 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct xhci_slot_ctx {
	__le32 dev_info;
	__le32 dev_info2;
	__le32 tt_info;
	__le32 dev_state;
	__le32 reserved[4];
};

struct xhci_ep_ctx {
	__le32 ep_info;
	__le32 ep_info2;
	__le64 deq;
	__le32 tx_info;
	__le32 reserved[3];
};

struct xhci_input_control_ctx {
	__le32 drop_flags;
	__le32 add_flags;
	__le32 rsvd2[6];
};

enum xhci_overhead_type {
	LS_OVERHEAD_TYPE = 0,
	FS_OVERHEAD_TYPE = 1,
	HS_OVERHEAD_TYPE = 2,
};

enum xhci_setup_dev {
	SETUP_CONTEXT_ONLY = 0,
	SETUP_CONTEXT_ADDRESS = 1,
};

struct xhci_dequeue_state {
	struct xhci_segment *new_deq_seg;
	union xhci_trb *new_deq_ptr;
	int new_cycle_state;
};

struct urb_priv___3 {
	int length;
	int td_cnt;
	struct xhci_td *td[0];
};

struct device___216;

struct dev_pm_ops___216 {
	int (*prepare)(struct device___216 *);
	void (*complete)(struct device___216 *);
	int (*suspend)(struct device___216 *);
	int (*resume)(struct device___216 *);
	int (*freeze)(struct device___216 *);
	int (*thaw)(struct device___216 *);
	int (*poweroff)(struct device___216 *);
	int (*restore)(struct device___216 *);
	int (*suspend_late)(struct device___216 *);
	int (*resume_early)(struct device___216 *);
	int (*freeze_late)(struct device___216 *);
	int (*thaw_early)(struct device___216 *);
	int (*poweroff_late)(struct device___216 *);
	int (*restore_early)(struct device___216 *);
	int (*suspend_noirq)(struct device___216 *);
	int (*resume_noirq)(struct device___216 *);
	int (*freeze_noirq)(struct device___216 *);
	int (*thaw_noirq)(struct device___216 *);
	int (*poweroff_noirq)(struct device___216 *);
	int (*restore_noirq)(struct device___216 *);
	int (*runtime_suspend)(struct device___216 *);
	int (*runtime_resume)(struct device___216 *);
	int (*runtime_idle)(struct device___216 *);
};

struct dma_map_ops___93;

struct dev_archdata___93 {
	struct dma_map_ops___93 *dma_ops;
	void *iommu;
};

struct device_type___216;

struct bus_type___216;

struct device_driver___216;

struct dev_pm_domain___216;

struct class___216;

struct device_rh___216;

struct device___216 {
	struct device___216 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___216 *type;
	struct mutex___228 mutex;
	struct bus_type___216 *bus;
	struct device_driver___216 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___216 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___216 *class;
	const struct attribute_group___184 **groups;
	void (*release)(struct device___216 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___216 *device_rh;
};

struct dev_pm_info_rh___216 {
	void (*set_latency_tolerance)(struct device___216 *, s32);
};

struct dev_pm_domain___216 {
	struct dev_pm_ops___216 ops;
};

struct dma_map_ops___93 {
	void * (*alloc)(struct device___216 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___216 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___216 *, struct vm_area_struct___234 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___216 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___216 *, struct page___225 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___216 *, dma_addr_t);
	int (*dma_supported)(struct device___216 *, u64);
	int (*set_dma_mask)(struct device___216 *, u64);
	int is_phys;
};

struct bus_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___216 *, char *);
	ssize_t (*store)(struct bus_type___216 *, const char *, size_t);
};

struct device_attribute___216;

struct driver_attribute___216;

struct bus_type___216 {
	const char *name;
	const char *dev_name;
	struct device___216 *dev_root;
	struct bus_attribute___216 *bus_attrs;
	struct device_attribute___216 *dev_attrs;
	struct driver_attribute___216 *drv_attrs;
	const struct attribute_group___184 **bus_groups;
	const struct attribute_group___184 **dev_groups;
	const struct attribute_group___184 **drv_groups;
	int (*match)(struct device___216 *, struct device_driver___216 *);
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	int (*probe)(struct device___216 *);
	int (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*online)(struct device___216 *);
	int (*offline)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct device___216 *, struct device_attribute___216 *, char *);
	ssize_t (*store)(struct device___216 *, struct device_attribute___216 *, const char *, size_t);
};

struct driver_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___216 *, char *);
	ssize_t (*store)(struct device_driver___216 *, const char *, size_t);
};

struct device_driver___216 {
	const char *name;
	struct bus_type___216 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___216 *);
	int (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	const struct attribute_group___184 **groups;
	const struct dev_pm_ops___216 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___216 {
	const char *name;
	const struct attribute_group___184 **groups;
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
};

struct class_attribute___216;

struct class___216 {
	const char *name;
	struct module *owner;
	struct class_attribute___216 *class_attrs;
	struct device_attribute___216 *dev_attrs;
	const struct attribute_group___184 **dev_groups;
	struct bin_attribute___186 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *);
	void (*class_release)(struct class___216 *);
	void (*dev_release)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
	struct subsys_private *p;
};

struct class_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct class___216 *, struct class_attribute___216 *, char *);
	ssize_t (*store)(struct class___216 *, struct class_attribute___216 *, const char *, size_t);
	const void * (*namespace)(struct class___216 *, const struct class_attribute___216 *);
};

struct device_rh___216 {
	struct dev_pm_info_rh___216 power;
};

struct usb_interface___11 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___216 dev;
	struct device___216 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___11 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___11 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___11;

struct usb_bus___11 {
	struct device___216 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___11 *root_hub;
	struct usb_bus___11 *hs_companion;
	struct list_head bus_list;
	struct mutex___228 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___9;

struct usb_device___11 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___9 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___11 *parent;
	struct usb_bus___11 *bus;
	struct usb_host_endpoint ep0;
	struct device___216 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___11 *config;
	struct usb_host_config___11 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___9 {
	struct usb_device___11 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___11;

typedef void (*usb_complete_t___11)(struct urb___11 *);

struct urb___11 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___11 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___11 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___9;

struct usb_hcd___9 {
	struct usb_bus___11 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___11 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___9 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___228 *bandwidth_mutex;
	struct usb_hcd___9 *shared_hcd;
	struct usb_hcd___9 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___9 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___9 *);
	int flags;
	int (*reset)(struct usb_hcd___9 *);
	int (*start)(struct usb_hcd___9 *);
	int (*pci_suspend)(struct usb_hcd___9 *, bool);
	int (*pci_resume)(struct usb_hcd___9 *, bool);
	void (*stop)(struct usb_hcd___9 *);
	void (*shutdown)(struct usb_hcd___9 *);
	int (*get_frame_number)(struct usb_hcd___9 *);
	int (*urb_enqueue)(struct usb_hcd___9 *, struct urb___11 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___9 *, struct urb___11 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___9 *, struct urb___11 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___9 *, struct urb___11 *);
	void (*endpoint_disable)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___9 *, char *);
	int (*hub_control)(struct usb_hcd___9 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___9 *);
	int (*bus_resume)(struct usb_hcd___9 *);
	int (*start_port_reset)(struct usb_hcd___9 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___9 *, int);
	int (*port_handed_over)(struct usb_hcd___9 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___9 *, struct usb_device___11 *);
	void (*free_dev)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*alloc_streams)(struct usb_hcd___9 *, struct usb_device___11 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___9 *, struct usb_device___11 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___9 *, struct usb_device___11 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___9 *, struct usb_device___11 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___9 *, struct usb_device___11 *);
	void (*reset_bandwidth)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*address_device)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*enable_device)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*update_hub_device)(struct usb_hcd___9 *, struct usb_device___11 *, struct usb_tt___9 *, gfp_t);
	int (*reset_device)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*update_device)(struct usb_hcd___9 *, struct usb_device___11 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___9 *, struct usb_device___11 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___9 *, struct usb_device___11 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___9 *, struct usb_device___11 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___9 *, int);
	int (*port_power)(struct usb_hcd___9 *, int, bool);
};

struct usb_mon_operations___9 {
	void (*urb_submit)(struct usb_bus___11 *, struct urb___11 *);
	void (*urb_submit_error)(struct usb_bus___11 *, struct urb___11 *, int);
	void (*urb_complete)(struct usb_bus___11 *, struct urb___11 *, int);
};

struct xhci_td___2;

struct xhci_hcd___2;

struct xhci_virt_ep___2 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct xhci_td___2 *stopped_td;
	unsigned int stopped_stream;
	struct timer_list stop_cmd_timer;
	int stop_cmds_pending;
	struct xhci_hcd___2 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
};

struct xhci_td___2 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___11 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	bool urb_length_set;
};

struct xhci_virt_device___2;

struct xhci_hcd___2 {
	struct usb_hcd___9 *main_hcd;
	struct usb_hcd___9 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	int event_ring_max;
	int addr_64;
	int page_size;
	int page_shift;
	int msix_count;
	struct msix_entry *msix_entries;
	struct clk *clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct timer_list cmd_timer;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex___228 mutex;
	struct completion addr_dev;
	int slot_id;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___2 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	int error_bitmask;
	unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	u8 *port_array;
	__le32 **usb3_ports;
	unsigned int num_usb3_ports;
	__le32 **usb2_ports;
	unsigned int num_usb2_ports;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
};

struct xhci_virt_device___2 {
	struct usb_device___11 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_ring **ring_cache;
	int num_rings_cached;
	struct xhci_virt_ep___2 eps[31];
	struct completion cmd_completion;
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
};

struct urb_priv___4 {
	int length;
	int td_cnt;
	struct xhci_td___2 *td[0];
};

struct usb_interface___12 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___194 dev;
	struct device___194 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___12 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___12 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___12;

struct usb_bus___12 {
	struct device___194 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___12 *root_hub;
	struct usb_bus___12 *hs_companion;
	struct list_head bus_list;
	struct mutex___212 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___10;

struct usb_device___12 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___10 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___12 *parent;
	struct usb_bus___12 *bus;
	struct usb_host_endpoint ep0;
	struct device___194 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___12 *config;
	struct usb_host_config___12 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___10 {
	struct usb_device___12 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___12;

typedef void (*usb_complete_t___12)(struct urb___12 *);

struct urb___12 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___12 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___12 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___10;

struct usb_hcd___10 {
	struct usb_bus___12 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___12 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___10 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___212 *bandwidth_mutex;
	struct usb_hcd___10 *shared_hcd;
	struct usb_hcd___10 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___10 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___10 *);
	int flags;
	int (*reset)(struct usb_hcd___10 *);
	int (*start)(struct usb_hcd___10 *);
	int (*pci_suspend)(struct usb_hcd___10 *, bool);
	int (*pci_resume)(struct usb_hcd___10 *, bool);
	void (*stop)(struct usb_hcd___10 *);
	void (*shutdown)(struct usb_hcd___10 *);
	int (*get_frame_number)(struct usb_hcd___10 *);
	int (*urb_enqueue)(struct usb_hcd___10 *, struct urb___12 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___10 *, struct urb___12 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___10 *, struct urb___12 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___10 *, struct urb___12 *);
	void (*endpoint_disable)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___10 *, char *);
	int (*hub_control)(struct usb_hcd___10 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___10 *);
	int (*bus_resume)(struct usb_hcd___10 *);
	int (*start_port_reset)(struct usb_hcd___10 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___10 *, int);
	int (*port_handed_over)(struct usb_hcd___10 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___10 *, struct usb_device___12 *);
	void (*free_dev)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*alloc_streams)(struct usb_hcd___10 *, struct usb_device___12 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___10 *, struct usb_device___12 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___10 *, struct usb_device___12 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___10 *, struct usb_device___12 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___10 *, struct usb_device___12 *);
	void (*reset_bandwidth)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*address_device)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*enable_device)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*update_hub_device)(struct usb_hcd___10 *, struct usb_device___12 *, struct usb_tt___10 *, gfp_t);
	int (*reset_device)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*update_device)(struct usb_hcd___10 *, struct usb_device___12 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___10 *, struct usb_device___12 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___10 *, struct usb_device___12 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___10 *, struct usb_device___12 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___10 *, int);
	int (*port_power)(struct usb_hcd___10 *, int, bool);
};

struct usb_mon_operations___10 {
	void (*urb_submit)(struct usb_bus___12 *, struct urb___12 *);
	void (*urb_submit_error)(struct usb_bus___12 *, struct urb___12 *, int);
	void (*urb_complete)(struct usb_bus___12 *, struct urb___12 *, int);
};

struct xhci_td___3;

struct xhci_hcd___3;

struct xhci_virt_ep___3 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct xhci_td___3 *stopped_td;
	unsigned int stopped_stream;
	struct timer_list stop_cmd_timer;
	int stop_cmds_pending;
	struct xhci_hcd___3 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
};

struct xhci_td___3 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___12 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	bool urb_length_set;
};

struct xhci_virt_device___3;

struct xhci_hcd___3 {
	struct usb_hcd___10 *main_hcd;
	struct usb_hcd___10 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	int event_ring_max;
	int addr_64;
	int page_size;
	int page_shift;
	int msix_count;
	struct msix_entry *msix_entries;
	struct clk *clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct timer_list cmd_timer;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex___212 mutex;
	struct completion addr_dev;
	int slot_id;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___3 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	int error_bitmask;
	unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	u8 *port_array;
	__le32 **usb3_ports;
	unsigned int num_usb3_ports;
	__le32 **usb2_ports;
	unsigned int num_usb2_ports;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
};

struct xhci_virt_device___3 {
	struct usb_device___12 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_ring **ring_cache;
	int num_rings_cached;
	struct xhci_virt_ep___3 eps[31];
	struct completion cmd_completion;
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
};

struct urb_priv___5 {
	int length;
	int td_cnt;
	struct xhci_td___3 *td[0];
};

struct xhci_td___4;

struct xhci_hcd___4;

struct xhci_virt_ep___4 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct xhci_td___4 *stopped_td;
	unsigned int stopped_stream;
	struct timer_list stop_cmd_timer;
	int stop_cmds_pending;
	struct xhci_hcd___4 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
};

struct xhci_td___4 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___7 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	bool urb_length_set;
};

struct xhci_virt_device___4;

struct xhci_hcd___4 {
	struct usb_hcd___7 *main_hcd;
	struct usb_hcd___7 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	int event_ring_max;
	int addr_64;
	int page_size;
	int page_shift;
	int msix_count;
	struct msix_entry *msix_entries;
	struct clk *clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct timer_list cmd_timer;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex___225 mutex;
	struct completion addr_dev;
	int slot_id;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___4 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	int error_bitmask;
	unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	u8 *port_array;
	__le32 **usb3_ports;
	unsigned int num_usb3_ports;
	__le32 **usb2_ports;
	unsigned int num_usb2_ports;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
};

struct xhci_virt_device___4 {
	struct usb_device___7 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_ring **ring_cache;
	int num_rings_cached;
	struct xhci_virt_ep___4 eps[31];
	struct completion cmd_completion;
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
};

struct page___226;

typedef struct page___226 *pgtable_t___226;

struct address_space___227;

struct kmem_cache___212;

struct page___226 {
	long unsigned int flags;
	struct address_space___227 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___226 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___226 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___212 *slab_cache;
		struct page___226 *first_page;
	};
	long: 64;
};

struct thread_struct___82;

struct task_struct___228;

struct pv_cpu_ops___228 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___228 *);
	void (*end_context_switch)(struct task_struct___228 *);
};

struct perf_event___82;

struct thread_struct___82 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___82 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___92;

struct pid_link___92 {
	struct hlist_node node;
	struct pid___92 *pid;
};

struct mutex___229 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___228 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___221 {
	struct page___226 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___235;

struct nsproxy___117;

struct signal_struct___228;

struct css_set___133;

struct perf_event_context___82;

struct task_struct___228 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___228 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___235 *mm;
	struct mm_struct___235 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___228 *real_parent;
	struct task_struct___228 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___228 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___228 = 0,
		VTIME_USER___228 = 1,
		VTIME_SYS___228 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___117 *nsproxy;
	struct signal_struct___228 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___133 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___82 *perf_event_ctxp[2];
	struct mutex___229 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___221 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___235 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___235 *, struct mm_struct___235 *);
	void (*dup_mmap)(struct mm_struct___235 *, struct mm_struct___235 *);
	void (*exit_mmap)(struct mm_struct___235 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___235 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___235 *);
	void (*pgd_free)(struct mm_struct___235 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___235 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___235 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___235 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___235 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___235 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___235 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___235 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___235 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___235 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___235 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___235 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___229 lock;
	void *vdso;
} mm_context_t___229;

struct xol_area___226;

struct uprobes_state___226 {
	struct xol_area___226 *xol_area;
};

struct vm_area_struct___235;

struct file___227;

struct core_state___228;

struct mm_struct___235 {
	struct vm_area_struct___235 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___235 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___235 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___229 context;
	long unsigned int flags;
	struct core_state___228 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___228 *owner;
	struct file___227 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___226 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___82 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___228 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___228 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___228 *target;
};

typedef void (*perf_overflow_handler_t___82)(struct perf_event___82 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___82;

typedef void (*ftrace_func_t___82)(long unsigned int, long unsigned int, struct ftrace_ops___82 *, struct pt_regs *);

struct ftrace_ops___82 {
	ftrace_func_t___82 func;
	struct ftrace_ops___82 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___229 regex_lock;
};

struct pmu___82;

struct fasync_struct___227;

struct pid_namespace___92;

struct ftrace_event_call___71;

struct perf_cgroup___82;

struct perf_event___82 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___82 *group_leader;
	struct pmu___82 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___82 hw;
	struct perf_event_context___82 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___229 child_mutex;
	struct list_head child_list;
	struct perf_event___82 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___228 *owner;
	struct mutex___229 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___227 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___82 *);
	struct callback_head callback_head;
	struct pid_namespace___92 *ns;
	u64 id;
	perf_overflow_handler_t___82 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___71 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___82 ftrace_ops;
	struct perf_cgroup___82 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___101 {
	struct task_struct___228 *task;
	struct exec_domain___58 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct irq_data___149;

struct x86_io_apic_ops___149 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___149 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___149;

struct irq_data___149 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___149 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___217;

struct dev_pm_ops___217 {
	int (*prepare)(struct device___217 *);
	void (*complete)(struct device___217 *);
	int (*suspend)(struct device___217 *);
	int (*resume)(struct device___217 *);
	int (*freeze)(struct device___217 *);
	int (*thaw)(struct device___217 *);
	int (*poweroff)(struct device___217 *);
	int (*restore)(struct device___217 *);
	int (*suspend_late)(struct device___217 *);
	int (*resume_early)(struct device___217 *);
	int (*freeze_late)(struct device___217 *);
	int (*thaw_early)(struct device___217 *);
	int (*poweroff_late)(struct device___217 *);
	int (*restore_early)(struct device___217 *);
	int (*suspend_noirq)(struct device___217 *);
	int (*resume_noirq)(struct device___217 *);
	int (*freeze_noirq)(struct device___217 *);
	int (*thaw_noirq)(struct device___217 *);
	int (*poweroff_noirq)(struct device___217 *);
	int (*restore_noirq)(struct device___217 *);
	int (*runtime_suspend)(struct device___217 *);
	int (*runtime_resume)(struct device___217 *);
	int (*runtime_idle)(struct device___217 *);
};

struct device_type___217;

struct bus_type___217;

struct device_driver___217;

struct dev_pm_domain___217;

struct class___217;

struct attribute_group___186;

struct device_rh___217;

struct device___217 {
	struct device___217 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___217 *type;
	struct mutex___229 mutex;
	struct bus_type___217 *bus;
	struct device_driver___217 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___217 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___217 *class;
	const struct attribute_group___186 **groups;
	void (*release)(struct device___217 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___217 *device_rh;
};

struct dev_pm_info_rh___217 {
	void (*set_latency_tolerance)(struct device___217 *, s32);
};

struct dev_pm_domain___217 {
	struct dev_pm_ops___217 ops;
};

struct smp_ops___228 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___228 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___228;

struct lruvec___228 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___228 *zone;
};

struct pglist_data___228;

struct zone___228 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___228 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___228 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___228 {
	struct zone___228 *zone;
	int zone_idx;
};

struct zonelist___228 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___228 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___228 {
	struct zone___228 node_zones[4];
	struct zonelist___228 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___228 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___153;

struct irq_chip___149 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___149 *);
	void (*irq_shutdown)(struct irq_data___149 *);
	void (*irq_enable)(struct irq_data___149 *);
	void (*irq_disable)(struct irq_data___149 *);
	void (*irq_ack)(struct irq_data___149 *);
	void (*irq_mask)(struct irq_data___149 *);
	void (*irq_mask_ack)(struct irq_data___149 *);
	void (*irq_unmask)(struct irq_data___149 *);
	void (*irq_eoi)(struct irq_data___149 *);
	int (*irq_set_affinity)(struct irq_data___149 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___149 *);
	int (*irq_set_type)(struct irq_data___149 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___149 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___149 *);
	void (*irq_bus_sync_unlock)(struct irq_data___149 *);
	void (*irq_cpu_online)(struct irq_data___149 *);
	void (*irq_cpu_offline)(struct irq_data___149 *);
	void (*irq_suspend)(struct irq_data___149 *);
	void (*irq_resume)(struct irq_data___149 *);
	void (*irq_pm_shutdown)(struct irq_data___149 *);
	void (*irq_print_chip)(struct irq_data___149 *, struct seq_file___153 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___149 *, void *);
	long unsigned int flags;
};

struct seq_operations___153;

struct seq_file___153 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___229 lock;
	const struct seq_operations___153 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___188;

struct attribute_group___186 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___188 **bin_attrs;
};

struct bin_attribute___188 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___227 *, struct kobject___24 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___227 *, struct kobject___24 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	int (*mmap)(struct file___227 *, struct kobject___24 *, struct bin_attribute___188 *, struct vm_area_struct___235 *);
};

struct dentry___227;

struct path___227 {
	struct vfsmount *mnt;
	struct dentry___227 *dentry;
};

struct fown_struct___92 {
	rwlock_t lock;
	struct pid___92 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___227;

struct file_operations___227;

struct file___227 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___227 f_path;
	struct inode___227 *f_inode;
	const struct file_operations___227 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___227 *f_mapping;
	struct mutex___229 f_pos_lock;
};

struct vm_operations_struct___206;

struct vm_area_struct___235 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___235 *vm_next;
	struct vm_area_struct___235 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___235 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___206 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___227 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___217 *, char *);
	ssize_t (*store)(struct bus_type___217 *, const char *, size_t);
};

struct device_attribute___217;

struct driver_attribute___217;

struct bus_type___217 {
	const char *name;
	const char *dev_name;
	struct device___217 *dev_root;
	struct bus_attribute___217 *bus_attrs;
	struct device_attribute___217 *dev_attrs;
	struct driver_attribute___217 *drv_attrs;
	const struct attribute_group___186 **bus_groups;
	const struct attribute_group___186 **dev_groups;
	const struct attribute_group___186 **drv_groups;
	int (*match)(struct device___217 *, struct device_driver___217 *);
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	int (*probe)(struct device___217 *);
	int (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*online)(struct device___217 *);
	int (*offline)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct device___217 *, struct device_attribute___217 *, char *);
	ssize_t (*store)(struct device___217 *, struct device_attribute___217 *, const char *, size_t);
};

struct driver_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___217 *, char *);
	ssize_t (*store)(struct device_driver___217 *, const char *, size_t);
};

struct device_driver___217 {
	const char *name;
	struct bus_type___217 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___217 *);
	int (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	const struct attribute_group___186 **groups;
	const struct dev_pm_ops___217 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___217 {
	const char *name;
	const struct attribute_group___186 **groups;
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
};

struct class_attribute___217;

struct class___217 {
	const char *name;
	struct module *owner;
	struct class_attribute___217 *class_attrs;
	struct device_attribute___217 *dev_attrs;
	const struct attribute_group___186 **dev_groups;
	struct bin_attribute___188 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *);
	void (*class_release)(struct class___217 *);
	void (*dev_release)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
	struct subsys_private *p;
};

struct class_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct class___217 *, struct class_attribute___217 *, char *);
	ssize_t (*store)(struct class___217 *, struct class_attribute___217 *, const char *, size_t);
	const void * (*namespace)(struct class___217 *, const struct class_attribute___217 *);
};

struct device_rh___217 {
	struct dev_pm_info_rh___217 power;
};

struct dentry_operations___227;

struct super_block___227;

struct dentry___227 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___227 *d_parent;
	struct qstr d_name;
	struct inode___227 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___227 *d_op;
	struct super_block___227 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___227;

struct address_space___227 {
	struct inode___227 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___229 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___227 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___227;

struct file_lock___227;

struct dquot___227;

struct block_device___227;

struct inode___227 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___227 *i_op;
	struct super_block___227 *i_sb;
	struct address_space___227 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___229 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___227 *i_fop;
	struct file_lock___227 *i_flock;
	struct address_space___227 i_data;
	struct dquot___227 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___227 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___227 {
	int (*d_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_hash)(const struct dentry___227 *, struct qstr *);
	int (*d_compare)(const struct dentry___227 *, const struct dentry___227 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___227 *);
	void (*d_release)(struct dentry___227 *);
	void (*d_prune)(struct dentry___227 *);
	void (*d_iput)(struct dentry___227 *, struct inode___227 *);
	char * (*d_dname)(struct dentry___227 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___227 *);
	int (*d_manage)(struct dentry___227 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___227;

struct mem_dqinfo___227 {
	struct quota_format_type___227 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___227;

struct quota_info___227 {
	unsigned int flags;
	struct mutex___229 dqio_mutex;
	struct mutex___229 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___227 *files[2];
	struct mem_dqinfo___227 info[2];
	const struct quota_format_ops___227 *ops[2];
};

struct file_system_type___227;

struct super_operations___227;

struct dquot_operations___227;

struct quotactl_ops___227;

struct xattr_handler___134;

struct super_block___227 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___227 *s_type;
	const struct super_operations___227 *s_op;
	const struct dquot_operations___227 *dq_op;
	const struct quotactl_ops___227 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___227 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___134 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___227 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___227 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___229 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___227 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___92 {
	int nr;
	struct pid_namespace___92 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___92 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___228 *child_reaper;
	struct kmem_cache___212 *pid_cachep;
	unsigned int level;
	struct pid_namespace___92 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___227 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___92 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___92 numbers[1];
};

struct block_device___227 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___227 *bd_inode;
	struct super_block___227 *bd_super;
	struct mutex___229 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___227 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___229 bd_fsfreeze_mutex;
};

struct cgroup___133;

struct cgroup_subsys_state___133 {
	struct cgroup___133 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___227 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___227 *ia_file;
};

struct dquot___227 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___229 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___227 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___227 {
	int qf_fmt_id;
	const struct quota_format_ops___227 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___227 *qf_next;
};

struct quota_format_ops___227 {
	int (*check_quota_file)(struct super_block___227 *, int);
	int (*read_file_info)(struct super_block___227 *, int);
	int (*write_file_info)(struct super_block___227 *, int);
	int (*free_file_info)(struct super_block___227 *, int);
	int (*read_dqblk)(struct dquot___227 *);
	int (*commit_dqblk)(struct dquot___227 *);
	int (*release_dqblk)(struct dquot___227 *);
};

struct dquot_operations___227 {
	int (*write_dquot)(struct dquot___227 *);
	struct dquot___227 * (*alloc_dquot)(struct super_block___227 *, int);
	void (*destroy_dquot)(struct dquot___227 *);
	int (*acquire_dquot)(struct dquot___227 *);
	int (*release_dquot)(struct dquot___227 *);
	int (*mark_dirty)(struct dquot___227 *);
	int (*write_info)(struct super_block___227 *, int);
	qsize_t * (*get_reserved_space)(struct inode___227 *);
};

struct quotactl_ops___227 {
	int (*quota_on)(struct super_block___227 *, int, int, struct path___227 *);
	int (*quota_on_meta)(struct super_block___227 *, int, int);
	int (*quota_off)(struct super_block___227 *, int);
	int (*quota_sync)(struct super_block___227 *, int);
	int (*get_info)(struct super_block___227 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___227 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___227 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___227 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___227 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___227 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___227 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___227 *, unsigned int);
};

struct address_space_operations___227 {
	int (*writepage)(struct page___226 *, struct writeback_control *);
	int (*readpage)(struct file___227 *, struct page___226 *);
	int (*writepages)(struct address_space___227 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___226 *);
	int (*readpages)(struct file___227 *, struct address_space___227 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___227 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___226 **, void **);
	int (*write_end)(struct file___227 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___226 *, void *);
	sector_t (*bmap)(struct address_space___227 *, sector_t);
	void (*invalidatepage)(struct page___226 *, long unsigned int);
	int (*releasepage)(struct page___226 *, gfp_t);
	void (*freepage)(struct page___226 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___227 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___227 *, struct page___226 *, struct page___226 *, enum migrate_mode);
	int (*launder_page)(struct page___226 *);
	int (*is_partially_uptodate)(struct page___226 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___226 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___227 *, struct page___226 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___227 *, sector_t *);
	void (*swap_deactivate)(struct file___227 *);
	void (*invalidatepage_range)(struct page___226 *, unsigned int, unsigned int);
};

struct inode_operations___227 {
	struct dentry___227 * (*lookup)(struct inode___227 *, struct dentry___227 *, unsigned int);
	void * (*follow_link)(struct dentry___227 *, struct nameidata *);
	int (*permission)(struct inode___227 *, int);
	struct posix_acl * (*get_acl)(struct inode___227 *, int);
	int (*readlink)(struct dentry___227 *, char *, int);
	void (*put_link)(struct dentry___227 *, struct nameidata *, void *);
	int (*create)(struct inode___227 *, struct dentry___227 *, umode_t, bool);
	int (*link)(struct dentry___227 *, struct inode___227 *, struct dentry___227 *);
	int (*unlink)(struct inode___227 *, struct dentry___227 *);
	int (*symlink)(struct inode___227 *, struct dentry___227 *, const char *);
	int (*mkdir)(struct inode___227 *, struct dentry___227 *, umode_t);
	int (*rmdir)(struct inode___227 *, struct dentry___227 *);
	int (*mknod)(struct inode___227 *, struct dentry___227 *, umode_t, dev_t);
	int (*rename)(struct inode___227 *, struct dentry___227 *, struct inode___227 *, struct dentry___227 *);
	int (*setattr)(struct dentry___227 *, struct iattr___227 *);
	int (*getattr)(struct vfsmount *, struct dentry___227 *, struct kstat *);
	int (*setxattr)(struct dentry___227 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___227 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___227 *, char *, size_t);
	int (*removexattr)(struct dentry___227 *, const char *);
	int (*fiemap)(struct inode___227 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___227 *, struct timespec *, int);
	int (*atomic_open)(struct inode___227 *, struct dentry___227 *, struct file___227 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___121;

struct file_operations___227 {
	struct module *owner;
	loff_t (*llseek)(struct file___227 *, loff_t, int);
	ssize_t (*read)(struct file___227 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___227 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___227 *, void *, filldir_t);
	unsigned int (*poll)(struct file___227 *, struct poll_table_struct___121 *);
	long int (*unlocked_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___227 *, struct vm_area_struct___235 *);
	int (*open)(struct inode___227 *, struct file___227 *);
	int (*flush)(struct file___227 *, fl_owner_t);
	int (*release)(struct inode___227 *, struct file___227 *);
	int (*fsync)(struct file___227 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___227 *, int);
	int (*lock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*sendpage)(struct file___227 *, struct page___226 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___227 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___227 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___227 *, long int, struct file_lock___227 **, void **);
		struct {
			int (*setlease)(struct file___227 *, long int, struct file_lock___227 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___227 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___153 *, struct file___227 *);
};

struct file_lock_operations___227;

struct lock_manager_operations___227;

struct file_lock___227 {
	struct file_lock___227 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___227 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___227 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___227 *fl_ops;
	const struct lock_manager_operations___227 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___227 {
	void (*fl_copy_lock)(struct file_lock___227 *, struct file_lock___227 *);
	void (*fl_release_private)(struct file_lock___227 *);
};

struct lock_manager_operations___227 {
	int (*lm_compare_owner)(struct file_lock___227 *, struct file_lock___227 *);
	long unsigned int (*lm_owner_key)(struct file_lock___227 *);
	void (*lm_notify)(struct file_lock___227 *);
	int (*lm_grant)(struct file_lock___227 *, struct file_lock___227 *, int);
	void (*lm_break)(struct file_lock___227 *);
	int (*lm_change)(struct file_lock___227 **, int);
};

struct fasync_struct___227 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___227 *fa_next;
	struct file___227 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___227 {
	const char *name;
	int fs_flags;
	struct dentry___227 * (*mount)(struct file_system_type___227 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___227 *);
	struct module *owner;
	struct file_system_type___227 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___227 {
	struct inode___227 * (*alloc_inode)(struct super_block___227 *);
	void (*destroy_inode)(struct inode___227 *);
	void (*dirty_inode)(struct inode___227 *, int);
	int (*write_inode)(struct inode___227 *, struct writeback_control *);
	int (*drop_inode)(struct inode___227 *);
	void (*evict_inode)(struct inode___227 *);
	void (*put_super)(struct super_block___227 *);
	int (*sync_fs)(struct super_block___227 *, int);
	int (*freeze_fs)(struct super_block___227 *);
	int (*unfreeze_fs)(struct super_block___227 *);
	int (*statfs)(struct dentry___227 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___227 *, int *, char *);
	void (*umount_begin)(struct super_block___227 *);
	int (*show_options)(struct seq_file___153 *, struct dentry___227 *);
	int (*show_devname)(struct seq_file___153 *, struct dentry___227 *);
	int (*show_path)(struct seq_file___153 *, struct dentry___227 *);
	int (*show_stats)(struct seq_file___153 *, struct dentry___227 *);
	ssize_t (*quota_read)(struct super_block___227 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___227 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___227 *);
	int (*bdev_try_to_free_page)(struct super_block___227 *, struct page___226 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___227 *);
	void (*free_cached_objects)(struct super_block___227 *, int);
};

struct xattr_handler___134 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___227 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___227 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___227 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___123)(struct file___227 *, wait_queue_head_t *, struct poll_table_struct___121 *);

struct poll_table_struct___121 {
	poll_queue_proc___123 _qproc;
	long unsigned int _key;
};

struct xol_area___226 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___226 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___211;

struct memcg_cache_params___212;

struct kmem_cache___212 {
	struct kmem_cache_cpu___211 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___212 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___202;

struct vm_operations_struct___206 {
	void (*open)(struct vm_area_struct___235 *);
	void (*close)(struct vm_area_struct___235 *);
	int (*fault)(struct vm_area_struct___235 *, struct vm_fault___202 *);
	int (*page_mkwrite)(struct vm_area_struct___235 *, struct vm_fault___202 *);
	int (*access)(struct vm_area_struct___235 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___235 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___235 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___235 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___235 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___228 {
	struct task_struct___228 *task;
	struct core_thread___228 *next;
};

struct core_state___228 {
	atomic_t nr_threads;
	struct core_thread___228 dumper;
	struct completion startup;
};

struct nsproxy___117 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___92 *pid_ns;
	struct net *net_ns;
};

struct signal_struct___228 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___228 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___228 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___229 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___133 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___133 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___82 {
	struct pmu___82 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___229 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___228 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___82 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct usb_interface___13 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___217 dev;
	struct device___217 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___13 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___13 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___13;

struct usb_bus___13 {
	struct device___217 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___13 *root_hub;
	struct usb_bus___13 *hs_companion;
	struct list_head bus_list;
	struct mutex___229 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___11;

struct usb_device___13 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___11 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___13 *parent;
	struct usb_bus___13 *bus;
	struct usb_host_endpoint ep0;
	struct device___217 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___13 *config;
	struct usb_host_config___13 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_tt___11 {
	struct usb_device___13 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___13;

typedef void (*usb_complete_t___13)(struct urb___13 *);

struct urb___13 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___13 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___13 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___11;

struct usb_hcd___11 {
	struct usb_bus___13 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___13 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___11 *driver;
	struct usb_phy *phy;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int authorized_default: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex___229 *bandwidth_mutex;
	struct usb_hcd___11 *shared_hcd;
	struct usb_hcd___11 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___11 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___11 *);
	int flags;
	int (*reset)(struct usb_hcd___11 *);
	int (*start)(struct usb_hcd___11 *);
	int (*pci_suspend)(struct usb_hcd___11 *, bool);
	int (*pci_resume)(struct usb_hcd___11 *, bool);
	void (*stop)(struct usb_hcd___11 *);
	void (*shutdown)(struct usb_hcd___11 *);
	int (*get_frame_number)(struct usb_hcd___11 *);
	int (*urb_enqueue)(struct usb_hcd___11 *, struct urb___13 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___11 *, struct urb___13 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___11 *, struct urb___13 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___11 *, struct urb___13 *);
	void (*endpoint_disable)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___11 *, char *);
	int (*hub_control)(struct usb_hcd___11 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___11 *);
	int (*bus_resume)(struct usb_hcd___11 *);
	int (*start_port_reset)(struct usb_hcd___11 *, unsigned int);
	void (*relinquish_port)(struct usb_hcd___11 *, int);
	int (*port_handed_over)(struct usb_hcd___11 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___11 *, struct usb_device___13 *);
	void (*free_dev)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*alloc_streams)(struct usb_hcd___11 *, struct usb_device___13 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___11 *, struct usb_device___13 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___11 *, struct usb_device___13 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___11 *, struct usb_device___13 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___11 *, struct usb_device___13 *);
	void (*reset_bandwidth)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*address_device)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*enable_device)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*update_hub_device)(struct usb_hcd___11 *, struct usb_device___13 *, struct usb_tt___11 *, gfp_t);
	int (*reset_device)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*update_device)(struct usb_hcd___11 *, struct usb_device___13 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___11 *, struct usb_device___13 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___11 *, struct usb_device___13 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___11 *, struct usb_device___13 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___11 *, int);
	int (*port_power)(struct usb_hcd___11 *, int, bool);
};

struct usb_mon_operations___11 {
	void (*urb_submit)(struct usb_bus___13 *, struct urb___13 *);
	void (*urb_submit_error)(struct usb_bus___13 *, struct urb___13 *, int);
	void (*urb_complete)(struct usb_bus___13 *, struct urb___13 *, int);
};

struct xhci_td___5;

struct xhci_hcd___5;

struct xhci_virt_ep___5 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct xhci_td___5 *stopped_td;
	unsigned int stopped_stream;
	struct timer_list stop_cmd_timer;
	int stop_cmds_pending;
	struct xhci_hcd___5 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
};

struct xhci_td___5 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___13 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	bool urb_length_set;
};

struct xhci_virt_device___5;

struct xhci_hcd___5 {
	struct usb_hcd___11 *main_hcd;
	struct usb_hcd___11 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	int event_ring_max;
	int addr_64;
	int page_size;
	int page_shift;
	int msix_count;
	struct msix_entry *msix_entries;
	struct clk *clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct timer_list cmd_timer;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex___229 mutex;
	struct completion addr_dev;
	int slot_id;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___5 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	int error_bitmask;
	unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	u8 *port_array;
	__le32 **usb3_ports;
	unsigned int num_usb3_ports;
	__le32 **usb2_ports;
	unsigned int num_usb2_ports;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
};

struct xhci_virt_device___5 {
	struct usb_device___13 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_ring **ring_cache;
	int num_rings_cached;
	struct xhci_virt_ep___5 eps[31];
	struct completion cmd_completion;
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
};

struct vm_fault___202 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___226 *page;
};

struct seq_operations___153 {
	void * (*start)(struct seq_file___153 *, loff_t *);
	void (*stop)(struct seq_file___153 *, void *);
	void * (*next)(struct seq_file___153 *, void *, loff_t *);
	int (*show)(struct seq_file___153 *, void *);
};

struct kmem_cache_cpu___211 {
	void **freelist;
	long unsigned int tid;
	struct page___226 *page;
	struct page___226 *partial;
};

struct memcg_cache_params___212 {
	bool is_root_cache;
	union {
		struct kmem_cache___212 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___212 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___133;

struct cgroup___133 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___133 *parent;
	struct dentry___227 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___133 *subsys[11];
	struct cgroupfs_root___133 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___229 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___133 {
	struct super_block___227 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___133 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___82;

struct pmu___82 {
	struct list_head entry;
	struct device___217 *dev;
	const struct attribute_group___186 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___82 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___82 *);
	void (*pmu_disable)(struct pmu___82 *);
	int (*event_init)(struct perf_event___82 *);
	int (*add)(struct perf_event___82 *, int);
	void (*del)(struct perf_event___82 *, int);
	void (*start)(struct perf_event___82 *, int);
	void (*stop)(struct perf_event___82 *, int);
	void (*read)(struct perf_event___82 *);
	void (*start_txn)(struct pmu___82 *);
	int (*commit_txn)(struct pmu___82 *);
	void (*cancel_txn)(struct pmu___82 *);
	int (*event_idx)(struct perf_event___82 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___82 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___82 *);
};

struct perf_cpu_context___82 {
	struct perf_event_context___82 ctx;
	struct perf_event_context___82 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___82 *unique_pmu;
	struct perf_cgroup___82 *cgrp;
};

struct trace_event_functions___71;

struct trace_event___71 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___71 *funcs;
};

struct ftrace_event_class___71;

struct ftrace_event_call___71 {
	struct list_head list;
	struct ftrace_event_class___71 *class;
	char *name;
	struct trace_event___71 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___82 {
	struct cgroup_subsys_state___133 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___71 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___229 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___71)(struct trace_iterator___71 *, int, struct trace_event___71 *);

struct trace_event_functions___71 {
	trace_print_func___71 trace;
	trace_print_func___71 raw;
	trace_print_func___71 hex;
	trace_print_func___71 binary;
};

struct ftrace_event_class___71 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___71 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___71 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___71 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___71 *);
};

struct ftrace_event_file___25 {
	struct list_head list;
	struct ftrace_event_call___71 *event_call;
	struct dentry___227 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_xhci_log_msg {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct ftrace_raw_xhci_log_ctx {
	struct trace_entry ent;
	int ctx_64;
	unsigned int ctx_type;
	dma_addr_t ctx_dma;
	u8 *ctx_va;
	unsigned int ctx_ep_num;
	int slot_id;
	u32 __data_loc_ctx_data;
	char __data[0];
};

struct ftrace_raw_xhci_log_event {
	struct trace_entry ent;
	void *va;
	u64 dma;
	u32 status;
	u32 flags;
	u32 __data_loc_trb;
	char __data[0];
};

struct ftrace_data_offsets_xhci_log_msg {
	u32 msg;
};

struct ftrace_data_offsets_xhci_log_ctx {
	u32 ctx_data;
};

struct ftrace_data_offsets_xhci_log_event {
	u32 trb;
};

struct page___227;

typedef struct page___227 *pgtable_t___227;

struct address_space___228;

struct kmem_cache___213;

struct page___227 {
	long unsigned int flags;
	struct address_space___228 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___227 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___227 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___213 *slab_cache;
		struct page___227 *first_page;
	};
	long: 64;
};

struct task_struct___229;

struct pv_cpu_ops___229 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___229 *);
	void (*end_context_switch)(struct task_struct___229 *);
};

struct mutex___230 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___229 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___222 {
	struct page___227 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___236;

struct signal_struct___229;

struct task_struct___229 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___229 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___236 *mm;
	struct mm_struct___236 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___229 *real_parent;
	struct task_struct___229 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___229 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___229 = 0,
		VTIME_USER___229 = 1,
		VTIME_SYS___229 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___229 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___230 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___222 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___236 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___236 *, struct mm_struct___236 *);
	void (*dup_mmap)(struct mm_struct___236 *, struct mm_struct___236 *);
	void (*exit_mmap)(struct mm_struct___236 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___236 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___236 *);
	void (*pgd_free)(struct mm_struct___236 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___236 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___236 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___236 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___236 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___236 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___236 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___236 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___236 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___236 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___236 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___236 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___230 lock;
	void *vdso;
} mm_context_t___230;

struct xol_area___227;

struct uprobes_state___227 {
	struct xol_area___227 *xol_area;
};

struct vm_area_struct___236;

struct file___228;

struct core_state___229;

struct mm_struct___236 {
	struct vm_area_struct___236 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___236 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___236 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___230 context;
	long unsigned int flags;
	struct core_state___229 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___229 *owner;
	struct file___228 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___227 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___132;

struct module_kobject___131 {
	struct kobject___24 kobj;
	struct module___132 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___131;

struct module___132 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___131 mkobj;
	struct module_attribute___131 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___229 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___229;

struct lruvec___229 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___229 *zone;
};

struct pglist_data___229;

struct zone___229 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___229 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___229 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___229 {
	struct zone___229 *zone;
	int zone_idx;
};

struct zonelist___229 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___229 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___229 {
	struct zone___229 node_zones[4];
	struct zonelist___229 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___229 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___150;

struct x86_io_apic_ops___150 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___150 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___150;

struct irq_data___150 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___150 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___218;

struct dev_pm_ops___218 {
	int (*prepare)(struct device___218 *);
	void (*complete)(struct device___218 *);
	int (*suspend)(struct device___218 *);
	int (*resume)(struct device___218 *);
	int (*freeze)(struct device___218 *);
	int (*thaw)(struct device___218 *);
	int (*poweroff)(struct device___218 *);
	int (*restore)(struct device___218 *);
	int (*suspend_late)(struct device___218 *);
	int (*resume_early)(struct device___218 *);
	int (*freeze_late)(struct device___218 *);
	int (*thaw_early)(struct device___218 *);
	int (*poweroff_late)(struct device___218 *);
	int (*restore_early)(struct device___218 *);
	int (*suspend_noirq)(struct device___218 *);
	int (*resume_noirq)(struct device___218 *);
	int (*freeze_noirq)(struct device___218 *);
	int (*thaw_noirq)(struct device___218 *);
	int (*poweroff_noirq)(struct device___218 *);
	int (*restore_noirq)(struct device___218 *);
	int (*runtime_suspend)(struct device___218 *);
	int (*runtime_resume)(struct device___218 *);
	int (*runtime_idle)(struct device___218 *);
};

struct device_type___218;

struct bus_type___218;

struct device_driver___218;

struct dev_pm_domain___218;

struct class___218;

struct attribute_group___187;

struct device_rh___218;

struct device___218 {
	struct device___218 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___218 *type;
	struct mutex___230 mutex;
	struct bus_type___218 *bus;
	struct device_driver___218 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___218 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___25 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___218 *class;
	const struct attribute_group___187 **groups;
	void (*release)(struct device___218 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___218 *device_rh;
};

struct dev_pm_info_rh___218 {
	void (*set_latency_tolerance)(struct device___218 *, s32);
};

struct dev_pm_domain___218 {
	struct dev_pm_ops___218 ops;
};

struct smp_ops___229 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___229 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___189;

struct attribute_group___187 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___189 **bin_attrs;
};

struct bin_attribute___189 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___228 *, struct kobject___24 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___228 *, struct kobject___24 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	int (*mmap)(struct file___228 *, struct kobject___24 *, struct bin_attribute___189 *, struct vm_area_struct___236 *);
};

struct dentry___228;

struct path___228 {
	struct vfsmount *mnt;
	struct dentry___228 *dentry;
};

struct inode___228;

struct file_operations___228;

struct file___228 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___228 f_path;
	struct inode___228 *f_inode;
	const struct file_operations___228 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___228 *f_mapping;
	struct mutex___230 f_pos_lock;
};

struct vm_operations_struct___207;

struct vm_area_struct___236 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___236 *vm_next;
	struct vm_area_struct___236 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___236 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___207 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___228 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___212 {
	void **freelist;
	long unsigned int tid;
	struct page___227 *page;
	struct page___227 *partial;
};

struct memcg_cache_params___213;

struct kmem_cache___213 {
	struct kmem_cache_cpu___212 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___213 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___213 {
	bool is_root_cache;
	union {
		struct kmem_cache___213 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___213 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___228;

struct super_block___228;

struct dentry___228 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___228 *d_parent;
	struct qstr d_name;
	struct inode___228 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___228 *d_op;
	struct super_block___228 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___228;

struct address_space___228 {
	struct inode___228 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___230 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___228 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___228;

struct file_lock___228;

struct dquot___228;

struct block_device___228;

struct cdev___60;

struct inode___228 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___228 *i_op;
	struct super_block___228 *i_sb;
	struct address_space___228 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___230 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___228 *i_fop;
	struct file_lock___228 *i_flock;
	struct address_space___228 i_data;
	struct dquot___228 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___228 *i_bdev;
		struct cdev___60 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___228 {
	int (*d_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_hash)(const struct dentry___228 *, struct qstr *);
	int (*d_compare)(const struct dentry___228 *, const struct dentry___228 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___228 *);
	void (*d_release)(struct dentry___228 *);
	void (*d_prune)(struct dentry___228 *);
	void (*d_iput)(struct dentry___228 *, struct inode___228 *);
	char * (*d_dname)(struct dentry___228 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___228 *);
	int (*d_manage)(struct dentry___228 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___228;

struct mem_dqinfo___228 {
	struct quota_format_type___228 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___228;

struct quota_info___228 {
	unsigned int flags;
	struct mutex___230 dqio_mutex;
	struct mutex___230 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___228 *files[2];
	struct mem_dqinfo___228 info[2];
	const struct quota_format_ops___228 *ops[2];
};

struct file_system_type___228;

struct super_operations___228;

struct dquot_operations___228;

struct quotactl_ops___228;

struct super_block___228 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___228 *s_type;
	const struct super_operations___228 *s_op;
	const struct dquot_operations___228 *dq_op;
	const struct quotactl_ops___228 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___228 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___228 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___228 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___230 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___228 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___228 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___228 *bd_inode;
	struct super_block___228 *bd_super;
	struct mutex___230 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___228 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___230 bd_fsfreeze_mutex;
};

struct iattr___228 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___228 *ia_file;
};

struct dquot___228 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___230 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___228 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___228 {
	int qf_fmt_id;
	const struct quota_format_ops___228 *qf_ops;
	struct module___132 *qf_owner;
	struct quota_format_type___228 *qf_next;
};

struct quota_format_ops___228 {
	int (*check_quota_file)(struct super_block___228 *, int);
	int (*read_file_info)(struct super_block___228 *, int);
	int (*write_file_info)(struct super_block___228 *, int);
	int (*free_file_info)(struct super_block___228 *, int);
	int (*read_dqblk)(struct dquot___228 *);
	int (*commit_dqblk)(struct dquot___228 *);
	int (*release_dqblk)(struct dquot___228 *);
};

struct dquot_operations___228 {
	int (*write_dquot)(struct dquot___228 *);
	struct dquot___228 * (*alloc_dquot)(struct super_block___228 *, int);
	void (*destroy_dquot)(struct dquot___228 *);
	int (*acquire_dquot)(struct dquot___228 *);
	int (*release_dquot)(struct dquot___228 *);
	int (*mark_dirty)(struct dquot___228 *);
	int (*write_info)(struct super_block___228 *, int);
	qsize_t * (*get_reserved_space)(struct inode___228 *);
};

struct quotactl_ops___228 {
	int (*quota_on)(struct super_block___228 *, int, int, struct path___228 *);
	int (*quota_on_meta)(struct super_block___228 *, int, int);
	int (*quota_off)(struct super_block___228 *, int);
	int (*quota_sync)(struct super_block___228 *, int);
	int (*get_info)(struct super_block___228 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___228 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___228 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___228 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___228 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___228 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___228 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___228 *, unsigned int);
};

struct address_space_operations___228 {
	int (*writepage)(struct page___227 *, struct writeback_control *);
	int (*readpage)(struct file___228 *, struct page___227 *);
	int (*writepages)(struct address_space___228 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___227 *);
	int (*readpages)(struct file___228 *, struct address_space___228 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___228 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___227 **, void **);
	int (*write_end)(struct file___228 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___227 *, void *);
	sector_t (*bmap)(struct address_space___228 *, sector_t);
	void (*invalidatepage)(struct page___227 *, long unsigned int);
	int (*releasepage)(struct page___227 *, gfp_t);
	void (*freepage)(struct page___227 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___228 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___228 *, struct page___227 *, struct page___227 *, enum migrate_mode);
	int (*launder_page)(struct page___227 *);
	int (*is_partially_uptodate)(struct page___227 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___227 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___228 *, struct page___227 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___228 *, sector_t *);
	void (*swap_deactivate)(struct file___228 *);
	void (*invalidatepage_range)(struct page___227 *, unsigned int, unsigned int);
};

struct cdev___60 {
	struct kobject___24 kobj;
	struct module___132 *owner;
	const struct file_operations___228 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___228 {
	struct dentry___228 * (*lookup)(struct inode___228 *, struct dentry___228 *, unsigned int);
	void * (*follow_link)(struct dentry___228 *, struct nameidata *);
	int (*permission)(struct inode___228 *, int);
	struct posix_acl * (*get_acl)(struct inode___228 *, int);
	int (*readlink)(struct dentry___228 *, char *, int);
	void (*put_link)(struct dentry___228 *, struct nameidata *, void *);
	int (*create)(struct inode___228 *, struct dentry___228 *, umode_t, bool);
	int (*link)(struct dentry___228 *, struct inode___228 *, struct dentry___228 *);
	int (*unlink)(struct inode___228 *, struct dentry___228 *);
	int (*symlink)(struct inode___228 *, struct dentry___228 *, const char *);
	int (*mkdir)(struct inode___228 *, struct dentry___228 *, umode_t);
	int (*rmdir)(struct inode___228 *, struct dentry___228 *);
	int (*mknod)(struct inode___228 *, struct dentry___228 *, umode_t, dev_t);
	int (*rename)(struct inode___228 *, struct dentry___228 *, struct inode___228 *, struct dentry___228 *);
	int (*setattr)(struct dentry___228 *, struct iattr___228 *);
	int (*getattr)(struct vfsmount *, struct dentry___228 *, struct kstat *);
	int (*setxattr)(struct dentry___228 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___228 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___228 *, char *, size_t);
	int (*removexattr)(struct dentry___228 *, const char *);
	int (*fiemap)(struct inode___228 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___228 *, struct timespec *, int);
	int (*atomic_open)(struct inode___228 *, struct dentry___228 *, struct file___228 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___154;

struct file_operations___228 {
	struct module___132 *owner;
	loff_t (*llseek)(struct file___228 *, loff_t, int);
	ssize_t (*read)(struct file___228 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___228 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___228 *, void *, filldir_t);
	unsigned int (*poll)(struct file___228 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___228 *, struct vm_area_struct___236 *);
	int (*open)(struct inode___228 *, struct file___228 *);
	int (*flush)(struct file___228 *, fl_owner_t);
	int (*release)(struct inode___228 *, struct file___228 *);
	int (*fsync)(struct file___228 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___228 *, int);
	int (*lock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*sendpage)(struct file___228 *, struct page___227 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___228 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___228 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___228 *, long int, struct file_lock___228 **, void **);
		struct {
			int (*setlease)(struct file___228 *, long int, struct file_lock___228 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___228 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___154 *, struct file___228 *);
};

struct fasync_struct___228;

struct file_lock_operations___228;

struct lock_manager_operations___228;

struct file_lock___228 {
	struct file_lock___228 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___228 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___228 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___228 *fl_ops;
	const struct lock_manager_operations___228 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___228 {
	void (*fl_copy_lock)(struct file_lock___228 *, struct file_lock___228 *);
	void (*fl_release_private)(struct file_lock___228 *);
};

struct lock_manager_operations___228 {
	int (*lm_compare_owner)(struct file_lock___228 *, struct file_lock___228 *);
	long unsigned int (*lm_owner_key)(struct file_lock___228 *);
	void (*lm_notify)(struct file_lock___228 *);
	int (*lm_grant)(struct file_lock___228 *, struct file_lock___228 *, int);
	void (*lm_break)(struct file_lock___228 *);
	int (*lm_change)(struct file_lock___228 **, int);
};

struct fasync_struct___228 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___228 *fa_next;
	struct file___228 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___228 {
	const char *name;
	int fs_flags;
	struct dentry___228 * (*mount)(struct file_system_type___228 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___228 *);
	struct module___132 *owner;
	struct file_system_type___228 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___228 {
	struct inode___228 * (*alloc_inode)(struct super_block___228 *);
	void (*destroy_inode)(struct inode___228 *);
	void (*dirty_inode)(struct inode___228 *, int);
	int (*write_inode)(struct inode___228 *, struct writeback_control *);
	int (*drop_inode)(struct inode___228 *);
	void (*evict_inode)(struct inode___228 *);
	void (*put_super)(struct super_block___228 *);
	int (*sync_fs)(struct super_block___228 *, int);
	int (*freeze_fs)(struct super_block___228 *);
	int (*unfreeze_fs)(struct super_block___228 *);
	int (*statfs)(struct dentry___228 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___228 *, int *, char *);
	void (*umount_begin)(struct super_block___228 *);
	int (*show_options)(struct seq_file___154 *, struct dentry___228 *);
	int (*show_devname)(struct seq_file___154 *, struct dentry___228 *);
	int (*show_path)(struct seq_file___154 *, struct dentry___228 *);
	int (*show_stats)(struct seq_file___154 *, struct dentry___228 *);
	ssize_t (*quota_read)(struct super_block___228 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___228 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___228 *);
	int (*bdev_try_to_free_page)(struct super_block___228 *, struct page___227 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___228 *);
	void (*free_cached_objects)(struct super_block___228 *, int);
};

struct seq_operations___154;

struct seq_file___154 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___230 lock;
	const struct seq_operations___154 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct tty_struct___29;

struct tty_driver___29;

struct tty_operations___29 {
	struct tty_struct___29 * (*lookup)(struct tty_driver___29 *, struct inode___228 *, int);
	int (*install)(struct tty_driver___29 *, struct tty_struct___29 *);
	void (*remove)(struct tty_driver___29 *, struct tty_struct___29 *);
	int (*open)(struct tty_struct___29 *, struct file___228 *);
	void (*close)(struct tty_struct___29 *, struct file___228 *);
	void (*shutdown)(struct tty_struct___29 *);
	void (*cleanup)(struct tty_struct___29 *);
	int (*write)(struct tty_struct___29 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___29 *, unsigned char);
	void (*flush_chars)(struct tty_struct___29 *);
	int (*write_room)(struct tty_struct___29 *);
	int (*chars_in_buffer)(struct tty_struct___29 *);
	int (*ioctl)(struct tty_struct___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___29 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___29 *, struct ktermios *);
	void (*throttle)(struct tty_struct___29 *);
	void (*unthrottle)(struct tty_struct___29 *);
	void (*stop)(struct tty_struct___29 *);
	void (*start)(struct tty_struct___29 *);
	void (*hangup)(struct tty_struct___29 *);
	int (*break_ctl)(struct tty_struct___29 *, int);
	void (*flush_buffer)(struct tty_struct___29 *);
	void (*set_ldisc)(struct tty_struct___29 *);
	void (*wait_until_sent)(struct tty_struct___29 *, int);
	void (*send_xchar)(struct tty_struct___29 *, char);
	int (*tiocmget)(struct tty_struct___29 *);
	int (*tiocmset)(struct tty_struct___29 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___29 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___29 *, struct termiox *);
	int (*get_icount)(struct tty_struct___29 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___29 *, int, char *);
	int (*poll_get_char)(struct tty_driver___29 *, int);
	void (*poll_put_char)(struct tty_driver___29 *, int, char);
	const struct file_operations___228 *proc_fops;
};

struct tty_ldisc___29;

struct tty_port___29;

struct tty_struct___29 {
	int magic;
	struct kref kref;
	struct device___218 *dev;
	struct tty_driver___29 *driver;
	const struct tty_operations___29 *ops;
	int index;
	struct mutex___230 ldisc_mutex;
	struct tty_ldisc___29 *ldisc;
	struct mutex___230 atomic_write_lock;
	struct mutex___230 legacy_mutex;
	struct mutex___230 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___92 *pgrp;
	struct pid___92 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___29 *link;
	struct fasync_struct___228 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___29 *port;
	struct ld_semaphore ldisc_sem;
};

struct tty_driver___29 {
	int magic;
	struct kref kref;
	struct cdev___60 *cdevs;
	struct module___132 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___29 *other;
	struct tty_struct___29 **ttys;
	struct tty_port___29 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___29 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___29;

struct tty_port___29 {
	struct tty_bufhead buf;
	struct tty_struct___29 *tty;
	struct tty_struct___29 *itty;
	const struct tty_port_operations___29 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___230 mutex;
	struct mutex___230 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___29 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___29 *);
	void (*close)(struct tty_struct___29 *);
	void (*flush_buffer)(struct tty_struct___29 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___29 *);
	ssize_t (*read)(struct tty_struct___29 *, struct file___228 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___29 *, struct file___228 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___29 *, struct file___228 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___29 *, struct file___228 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___29 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___29 *, struct file___228 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___29 *);
	void (*receive_buf)(struct tty_struct___29 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___29 *);
	void (*dcd_change)(struct tty_struct___29 *, unsigned int);
	struct module___132 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___29 *, int);
};

struct tty_ldisc___29 {
	struct tty_ldisc_ops___29 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___29 *tty;
};

struct tty_port_operations___29 {
	int (*carrier_raised)(struct tty_port___29 *);
	void (*dtr_rts)(struct tty_port___29 *, int);
	void (*shutdown)(struct tty_port___29 *);
	void (*drop)(struct tty_port___29 *);
	int (*activate)(struct tty_port___29 *, struct tty_struct___29 *);
	void (*destruct)(struct tty_port___29 *);
};

struct module_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___131 *, struct module_kobject___131 *, char *);
	ssize_t (*store)(struct module_attribute___131 *, struct module_kobject___131 *, const char *, size_t);
	void (*setup)(struct module___132 *, const char *);
	int (*test)(struct module___132 *);
	void (*free)(struct module___132 *);
};

struct seq_operations___154 {
	void * (*start)(struct seq_file___154 *, loff_t *);
	void (*stop)(struct seq_file___154 *, void *);
	void * (*next)(struct seq_file___154 *, void *, loff_t *);
	int (*show)(struct seq_file___154 *, void *);
};

struct async_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 tx;
	__u32 rx;
	__u32 frame;
	__u32 parity;
	__u32 overrun;
	__u32 brk;
	__u32 buf_overrun;
};

struct irq_chip___150 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___150 *);
	void (*irq_shutdown)(struct irq_data___150 *);
	void (*irq_enable)(struct irq_data___150 *);
	void (*irq_disable)(struct irq_data___150 *);
	void (*irq_ack)(struct irq_data___150 *);
	void (*irq_mask)(struct irq_data___150 *);
	void (*irq_mask_ack)(struct irq_data___150 *);
	void (*irq_unmask)(struct irq_data___150 *);
	void (*irq_eoi)(struct irq_data___150 *);
	int (*irq_set_affinity)(struct irq_data___150 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___150 *);
	int (*irq_set_type)(struct irq_data___150 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___150 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___150 *);
	void (*irq_bus_sync_unlock)(struct irq_data___150 *);
	void (*irq_cpu_online)(struct irq_data___150 *);
	void (*irq_cpu_offline)(struct irq_data___150 *);
	void (*irq_suspend)(struct irq_data___150 *);
	void (*irq_resume)(struct irq_data___150 *);
	void (*irq_pm_shutdown)(struct irq_data___150 *);
	void (*irq_print_chip)(struct irq_data___150 *, struct seq_file___154 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___150 *, void *);
	long unsigned int flags;
};

struct bus_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___218 *, char *);
	ssize_t (*store)(struct bus_type___218 *, const char *, size_t);
};

struct device_attribute___218;

struct driver_attribute___218;

struct bus_type___218 {
	const char *name;
	const char *dev_name;
	struct device___218 *dev_root;
	struct bus_attribute___218 *bus_attrs;
	struct device_attribute___218 *dev_attrs;
	struct driver_attribute___218 *drv_attrs;
	const struct attribute_group___187 **bus_groups;
	const struct attribute_group___187 **dev_groups;
	const struct attribute_group___187 **drv_groups;
	int (*match)(struct device___218 *, struct device_driver___218 *);
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	int (*probe)(struct device___218 *);
	int (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*online)(struct device___218 *);
	int (*offline)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct device___218 *, struct device_attribute___218 *, char *);
	ssize_t (*store)(struct device___218 *, struct device_attribute___218 *, const char *, size_t);
};

struct driver_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___218 *, char *);
	ssize_t (*store)(struct device_driver___218 *, const char *, size_t);
};

struct device_driver___218 {
	const char *name;
	struct bus_type___218 *bus;
	struct module___132 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___218 *);
	int (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	const struct attribute_group___187 **groups;
	const struct dev_pm_ops___218 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___218 {
	const char *name;
	const struct attribute_group___187 **groups;
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
};

struct class_attribute___218;

struct class___218 {
	const char *name;
	struct module___132 *owner;
	struct class_attribute___218 *class_attrs;
	struct device_attribute___218 *dev_attrs;
	const struct attribute_group___187 **dev_groups;
	struct bin_attribute___189 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *);
	void (*class_release)(struct class___218 *);
	void (*dev_release)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
	struct subsys_private *p;
};

struct class_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct class___218 *, struct class_attribute___218 *, char *);
	ssize_t (*store)(struct class___218 *, struct class_attribute___218 *, const char *, size_t);
	const void * (*namespace)(struct class___218 *, const struct class_attribute___218 *);
};

struct device_rh___218 {
	struct dev_pm_info_rh___218 power;
};

struct xol_area___227 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___227 *page;
	long unsigned int vaddr;
};

struct vm_fault___203;

struct vm_operations_struct___207 {
	void (*open)(struct vm_area_struct___236 *);
	void (*close)(struct vm_area_struct___236 *);
	int (*fault)(struct vm_area_struct___236 *, struct vm_fault___203 *);
	int (*page_mkwrite)(struct vm_area_struct___236 *, struct vm_fault___203 *);
	int (*access)(struct vm_area_struct___236 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___236 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___236 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___236 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___236 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___229 {
	struct task_struct___229 *task;
	struct core_thread___229 *next;
};

struct core_state___229 {
	atomic_t nr_threads;
	struct core_thread___229 dumper;
	struct completion startup;
};

struct signal_struct___229 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___229 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___229 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct___29 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___230 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___14 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___218 dev;
	struct device___218 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___14 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___14 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___14;

struct usb_bus___14 {
	struct device___218 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___14 *root_hub;
	struct usb_bus___14 *hs_companion;
	struct list_head bus_list;
	struct mutex___230 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_device___14 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___14 *parent;
	struct usb_bus___14 *bus;
	struct usb_host_endpoint ep0;
	struct device___218 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___14 *config;
	struct usb_host_config___14 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usbdrv_wrap___6 {
	struct device_driver___218 driver;
	int for_devices;
};

struct usb_driver___6 {
	const char *name;
	int (*probe)(struct usb_interface___14 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___14 *);
	int (*unlocked_ioctl)(struct usb_interface___14 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___14 *, pm_message_t);
	int (*resume)(struct usb_interface___14 *);
	int (*reset_resume)(struct usb_interface___14 *);
	int (*pre_reset)(struct usb_interface___14 *);
	int (*post_reset)(struct usb_interface___14 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___6 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct urb___14;

typedef void (*usb_complete_t___14)(struct urb___14 *);

struct urb___14 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___14 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___14 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct vm_fault___203 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___227 *page;
};

struct kfifo {
	union {
		struct __kfifo kfifo;
		unsigned char *type;
		char (*rectype)[0];
		void *ptr;
		const void *ptr_const;
	};
	unsigned char buf[0];
};

struct usb_serial;

struct usb_serial_port {
	struct usb_serial *serial;
	struct tty_port___29 port;
	spinlock_t lock;
	u32 minor;
	u8 port_number;
	unsigned char *interrupt_in_buffer;
	struct urb___14 *interrupt_in_urb;
	__u8 interrupt_in_endpointAddress;
	unsigned char *interrupt_out_buffer;
	int interrupt_out_size;
	struct urb___14 *interrupt_out_urb;
	__u8 interrupt_out_endpointAddress;
	unsigned char *bulk_in_buffer;
	int bulk_in_size;
	struct urb___14 *read_urb;
	__u8 bulk_in_endpointAddress;
	unsigned char *bulk_in_buffers[2];
	struct urb___14 *read_urbs[2];
	long unsigned int read_urbs_free;
	unsigned char *bulk_out_buffer;
	int bulk_out_size;
	struct urb___14 *write_urb;
	struct kfifo write_fifo;
	unsigned char *bulk_out_buffers[2];
	struct urb___14 *write_urbs[2];
	long unsigned int write_urbs_free;
	__u8 bulk_out_endpointAddress;
	struct async_icount icount;
	int tx_bytes;
	long unsigned int flags;
	wait_queue_head_t write_wait;
	struct work_struct work;
	char throttled;
	char throttle_req;
	long unsigned int sysrq;
	struct device___218 dev;
};

struct usb_serial_driver;

struct usb_serial {
	struct usb_device___14 *dev;
	struct usb_serial_driver *type;
	struct usb_interface___14 *interface;
	unsigned char disconnected: 1;
	unsigned char suspending: 1;
	unsigned char attached: 1;
	unsigned char minors_reserved: 1;
	unsigned char num_ports;
	unsigned char num_port_pointers;
	char num_interrupt_in;
	char num_interrupt_out;
	char num_bulk_in;
	char num_bulk_out;
	struct usb_serial_port *port[8];
	struct kref kref;
	struct mutex___230 disc_mutex;
	void *private;
};

struct usb_serial_driver {
	const char *description;
	const struct usb_device_id *id_table;
	char num_ports;
	struct list_head driver_list;
	struct device_driver___218 driver;
	struct usb_driver___6 *usb_driver;
	struct usb_dynids dynids;
	size_t bulk_in_size;
	size_t bulk_out_size;
	int (*probe)(struct usb_serial *, const struct usb_device_id *);
	int (*attach)(struct usb_serial *);
	int (*calc_num_ports)(struct usb_serial *);
	void (*disconnect)(struct usb_serial *);
	void (*release)(struct usb_serial *);
	int (*port_probe)(struct usb_serial_port *);
	int (*port_remove)(struct usb_serial_port *);
	int (*suspend)(struct usb_serial *, pm_message_t);
	int (*resume)(struct usb_serial *);
	int (*reset_resume)(struct usb_serial *);
	int (*open)(struct tty_struct___29 *, struct usb_serial_port *);
	void (*close)(struct usb_serial_port *);
	int (*write)(struct tty_struct___29 *, struct usb_serial_port *, const unsigned char *, int);
	int (*write_room)(struct tty_struct___29 *);
	int (*ioctl)(struct tty_struct___29 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___29 *, struct usb_serial_port *, struct ktermios *);
	void (*break_ctl)(struct tty_struct___29 *, int);
	int (*chars_in_buffer)(struct tty_struct___29 *);
	void (*wait_until_sent)(struct tty_struct___29 *, long int);
	bool (*tx_empty)(struct usb_serial_port *);
	void (*throttle)(struct tty_struct___29 *);
	void (*unthrottle)(struct tty_struct___29 *);
	int (*tiocmget)(struct tty_struct___29 *);
	int (*tiocmset)(struct tty_struct___29 *, unsigned int, unsigned int);
	int (*tiocmiwait)(struct tty_struct___29 *, long unsigned int);
	int (*get_icount)(struct tty_struct___29 *, struct serial_icounter_struct *);
	void (*dtr_rts)(struct usb_serial_port *, int);
	int (*carrier_raised)(struct usb_serial_port *);
	void (*init_termios)(struct tty_struct___29 *);
	void (*read_int_callback)(struct urb___14 *);
	void (*write_int_callback)(struct urb___14 *);
	void (*read_bulk_callback)(struct urb___14 *);
	void (*write_bulk_callback)(struct urb___14 *);
	void (*process_read_urb)(struct urb___14 *);
	int (*prepare_write_buffer)(struct usb_serial_port *, void *, size_t);
};

struct exec_domain___59 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___132 *module;
	struct exec_domain___59 *next;
};

struct thread_info___102 {
	struct task_struct___229 *task;
	struct exec_domain___59 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct console___11 {
	char name[16];
	void (*write)(struct console___11 *, const char *, unsigned int);
	int (*read)(struct console___11 *, char *, unsigned int);
	struct tty_driver___29 * (*device)(struct console___11 *, int *);
	void (*unblank)();
	int (*setup)(struct console___11 *, char *);
	int (*early_setup)();
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___11 *next;
};

struct usbcons_info {
	int magic;
	int break_flag;
	struct usb_serial_port *port;
};

struct usb_debug_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDebugInEndpoint;
	__u8 bDebugOutEndpoint;
};

struct ehci_dev {
	u32 bus;
	u32 slot;
	u32 func;
};

typedef void (*set_debug_port_t)(int);

struct usb_hcd___12;

struct serio_device_id {
	__u8 type;
	__u8 extra;
	__u8 id;
	__u8 proto;
};

struct serio_driver;

struct serio {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio *, unsigned char);
	int (*open)(struct serio *);
	void (*close)(struct serio *);
	int (*start)(struct serio *);
	void (*stop)(struct serio *);
	struct serio *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver *drv;
	struct mutex___221 drv_mutex;
	struct device___188 dev;
	struct list_head node;
};

struct serio_driver {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio *);
	irqreturn_t (*interrupt)(struct serio *, unsigned char, unsigned int);
	int (*connect)(struct serio *, struct serio_driver *);
	int (*reconnect)(struct serio *);
	void (*disconnect)(struct serio *);
	void (*cleanup)(struct serio *);
	struct device_driver___188 driver;
};

enum serio_event_type {
	SERIO_RESCAN_PORT = 0,
	SERIO_RECONNECT_PORT = 1,
	SERIO_RECONNECT_SUBTREE = 2,
	SERIO_REGISTER_PORT = 3,
	SERIO_ATTACH_DRIVER = 4,
};

struct serio_event {
	enum serio_event_type type;
	void *object;
	struct module___114 *owner;
	struct list_head node;
};

struct i8042_port {
	struct serio *serio;
	int irq;
	bool exists;
	signed char mux;
};

struct page___228;

typedef struct page___228 *pgtable_t___228;

struct address_space___229;

struct kmem_cache___214;

struct page___228 {
	long unsigned int flags;
	struct address_space___229 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___228 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___228 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___214 *slab_cache;
		struct page___228 *first_page;
	};
	long: 64;
};

struct task_struct___230;

struct pv_cpu_ops___230 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___230 *);
	void (*end_context_switch)(struct task_struct___230 *);
};

struct mutex___231 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___230 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___223 {
	struct page___228 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___237;

struct signal_struct___230;

struct task_struct___230 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___230 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___237 *mm;
	struct mm_struct___237 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___230 *real_parent;
	struct task_struct___230 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___230 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___230 = 0,
		VTIME_USER___230 = 1,
		VTIME_SYS___230 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___230 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___231 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___223 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___237 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___237 *, struct mm_struct___237 *);
	void (*dup_mmap)(struct mm_struct___237 *, struct mm_struct___237 *);
	void (*exit_mmap)(struct mm_struct___237 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___237 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___237 *);
	void (*pgd_free)(struct mm_struct___237 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___237 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___237 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___237 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___237 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___237 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___237 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___237 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___237 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___237 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___237 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___237 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___231 lock;
	void *vdso;
} mm_context_t___231;

struct xol_area___228;

struct uprobes_state___228 {
	struct xol_area___228 *xol_area;
};

struct vm_area_struct___237;

struct file___229;

struct core_state___230;

struct mm_struct___237 {
	struct vm_area_struct___237 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___237 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___237 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___231 context;
	long unsigned int flags;
	struct core_state___230 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___230 *owner;
	struct file___229 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___228 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___133;

struct exec_domain___60 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___133 *module;
	struct exec_domain___60 *next;
};

struct module_kobject___132 {
	struct kobject___24 kobj;
	struct module___133 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___132;

struct module___133 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___132 mkobj;
	struct module_attribute___132 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___230 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___103 {
	struct task_struct___230 *task;
	struct exec_domain___60 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___228 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___228 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___213;

struct memcg_cache_params___214;

struct kmem_cache___214 {
	struct kmem_cache_cpu___213 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___214 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___229;

struct address_space_operations___229;

struct address_space___229 {
	struct inode___229 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___231 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___229 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___229;

struct path___229 {
	struct vfsmount *mnt;
	struct dentry___229 *dentry;
};

struct file_operations___229;

struct file___229 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___229 f_path;
	struct inode___229 *f_inode;
	const struct file_operations___229 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___229 *f_mapping;
	struct mutex___231 f_pos_lock;
};

struct vm_area_struct___237 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___237 *vm_next;
	struct vm_area_struct___237 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___237 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___229 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___230 {
	struct task_struct___230 *task;
	struct core_thread___230 *next;
};

struct core_state___230 {
	atomic_t nr_threads;
	struct core_thread___230 dumper;
	struct completion startup;
};

struct device___219;

struct dev_pm_ops___219 {
	int (*prepare)(struct device___219 *);
	void (*complete)(struct device___219 *);
	int (*suspend)(struct device___219 *);
	int (*resume)(struct device___219 *);
	int (*freeze)(struct device___219 *);
	int (*thaw)(struct device___219 *);
	int (*poweroff)(struct device___219 *);
	int (*restore)(struct device___219 *);
	int (*suspend_late)(struct device___219 *);
	int (*resume_early)(struct device___219 *);
	int (*freeze_late)(struct device___219 *);
	int (*thaw_early)(struct device___219 *);
	int (*poweroff_late)(struct device___219 *);
	int (*restore_early)(struct device___219 *);
	int (*suspend_noirq)(struct device___219 *);
	int (*resume_noirq)(struct device___219 *);
	int (*freeze_noirq)(struct device___219 *);
	int (*thaw_noirq)(struct device___219 *);
	int (*poweroff_noirq)(struct device___219 *);
	int (*restore_noirq)(struct device___219 *);
	int (*runtime_suspend)(struct device___219 *);
	int (*runtime_resume)(struct device___219 *);
	int (*runtime_idle)(struct device___219 *);
};

struct device_type___219;

struct bus_type___219;

struct device_driver___219;

struct dev_pm_domain___219;

struct class___219;

struct attribute_group___188;

struct device_rh___219;

struct device___219 {
	struct device___219 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___219 *type;
	struct mutex___231 mutex;
	struct bus_type___219 *bus;
	struct device_driver___219 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___219 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___32 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___219 *class;
	const struct attribute_group___188 **groups;
	void (*release)(struct device___219 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___219 *device_rh;
};

struct dev_pm_info_rh___219 {
	void (*set_latency_tolerance)(struct device___219 *, s32);
};

struct dev_pm_domain___219 {
	struct dev_pm_ops___219 ops;
};

struct smp_ops___230 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___230 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___230;

struct lruvec___230 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___230 *zone;
};

struct pglist_data___230;

struct zone___230 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___230 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___230 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___230 {
	struct zone___230 *zone;
	int zone_idx;
};

struct zonelist___230 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___230 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___230 {
	struct zone___230 node_zones[4];
	struct zonelist___230 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___230 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tty_struct___30;

struct signal_struct___230 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___230 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___230 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct___30 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___231 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___30;

struct tty_operations___30;

struct tty_ldisc___30;

struct fasync_struct___229;

struct tty_port___30;

struct tty_struct___30 {
	int magic;
	struct kref kref;
	struct device___219 *dev;
	struct tty_driver___30 *driver;
	const struct tty_operations___30 *ops;
	int index;
	struct mutex___231 ldisc_mutex;
	struct tty_ldisc___30 *ldisc;
	struct mutex___231 atomic_write_lock;
	struct mutex___231 legacy_mutex;
	struct mutex___231 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___92 *pgrp;
	struct pid___92 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___30 *link;
	struct fasync_struct___229 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___30 *port;
	struct ld_semaphore ldisc_sem;
};

struct bin_attribute___190;

struct attribute_group___188 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___190 **bin_attrs;
};

struct bin_attribute___190 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___229 *, struct kobject___24 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___229 *, struct kobject___24 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	int (*mmap)(struct file___229 *, struct kobject___24 *, struct bin_attribute___190 *, struct vm_area_struct___237 *);
};

struct kmem_cache_cpu___213 {
	void **freelist;
	long unsigned int tid;
	struct page___228 *page;
	struct page___228 *partial;
};

struct memcg_cache_params___214 {
	bool is_root_cache;
	union {
		struct kmem_cache___214 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___214 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct module_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___132 *, struct module_kobject___132 *, char *);
	ssize_t (*store)(struct module_attribute___132 *, struct module_kobject___132 *, const char *, size_t);
	void (*setup)(struct module___133 *, const char *);
	int (*test)(struct module___133 *);
	void (*free)(struct module___133 *);
};

struct bus_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___219 *, char *);
	ssize_t (*store)(struct bus_type___219 *, const char *, size_t);
};

struct device_attribute___219;

struct driver_attribute___219;

struct bus_type___219 {
	const char *name;
	const char *dev_name;
	struct device___219 *dev_root;
	struct bus_attribute___219 *bus_attrs;
	struct device_attribute___219 *dev_attrs;
	struct driver_attribute___219 *drv_attrs;
	const struct attribute_group___188 **bus_groups;
	const struct attribute_group___188 **dev_groups;
	const struct attribute_group___188 **drv_groups;
	int (*match)(struct device___219 *, struct device_driver___219 *);
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	int (*probe)(struct device___219 *);
	int (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*online)(struct device___219 *);
	int (*offline)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct device___219 *, struct device_attribute___219 *, char *);
	ssize_t (*store)(struct device___219 *, struct device_attribute___219 *, const char *, size_t);
};

struct driver_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___219 *, char *);
	ssize_t (*store)(struct device_driver___219 *, const char *, size_t);
};

struct device_driver___219 {
	const char *name;
	struct bus_type___219 *bus;
	struct module___133 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___219 *);
	int (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	const struct attribute_group___188 **groups;
	const struct dev_pm_ops___219 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___219 {
	const char *name;
	const struct attribute_group___188 **groups;
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
};

struct class_attribute___219;

struct class___219 {
	const char *name;
	struct module___133 *owner;
	struct class_attribute___219 *class_attrs;
	struct device_attribute___219 *dev_attrs;
	const struct attribute_group___188 **dev_groups;
	struct bin_attribute___190 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *);
	void (*class_release)(struct class___219 *);
	void (*dev_release)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
	struct subsys_private *p;
};

struct class_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct class___219 *, struct class_attribute___219 *, char *);
	ssize_t (*store)(struct class___219 *, struct class_attribute___219 *, const char *, size_t);
	const void * (*namespace)(struct class___219 *, const struct class_attribute___219 *);
};

struct device_rh___219 {
	struct dev_pm_info_rh___219 power;
};

struct serio_driver___2;

struct serio___2 {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio___2 *, unsigned char);
	int (*open)(struct serio___2 *);
	void (*close)(struct serio___2 *);
	int (*start)(struct serio___2 *);
	void (*stop)(struct serio___2 *);
	struct serio___2 *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver___2 *drv;
	struct mutex___231 drv_mutex;
	struct device___219 dev;
	struct list_head node;
};

struct serio_driver___2 {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio___2 *);
	irqreturn_t (*interrupt)(struct serio___2 *, unsigned char, unsigned int);
	int (*connect)(struct serio___2 *, struct serio_driver___2 *);
	int (*reconnect)(struct serio___2 *);
	void (*disconnect)(struct serio___2 *);
	void (*cleanup)(struct serio___2 *);
	struct device_driver___219 driver;
};

struct dentry_operations___229;

struct super_block___229;

struct dentry___229 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___229 *d_parent;
	struct qstr d_name;
	struct inode___229 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___229 *d_op;
	struct super_block___229 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___229;

struct file_lock___229;

struct dquot___229;

struct block_device___229;

struct cdev___61;

struct inode___229 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___229 *i_op;
	struct super_block___229 *i_sb;
	struct address_space___229 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___231 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___229 *i_fop;
	struct file_lock___229 *i_flock;
	struct address_space___229 i_data;
	struct dquot___229 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___229 *i_bdev;
		struct cdev___61 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___229 {
	int (*d_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_hash)(const struct dentry___229 *, struct qstr *);
	int (*d_compare)(const struct dentry___229 *, const struct dentry___229 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___229 *);
	void (*d_release)(struct dentry___229 *);
	void (*d_prune)(struct dentry___229 *);
	void (*d_iput)(struct dentry___229 *, struct inode___229 *);
	char * (*d_dname)(struct dentry___229 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___229 *);
	int (*d_manage)(struct dentry___229 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___229;

struct mem_dqinfo___229 {
	struct quota_format_type___229 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___229;

struct quota_info___229 {
	unsigned int flags;
	struct mutex___231 dqio_mutex;
	struct mutex___231 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___229 *files[2];
	struct mem_dqinfo___229 info[2];
	const struct quota_format_ops___229 *ops[2];
};

struct file_system_type___229;

struct super_operations___229;

struct dquot_operations___229;

struct quotactl_ops___229;

struct super_block___229 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___229 *s_type;
	const struct super_operations___229 *s_op;
	const struct dquot_operations___229 *dq_op;
	const struct quotactl_ops___229 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___229 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___229 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___229 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___231 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___229 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___229 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___229 *bd_inode;
	struct super_block___229 *bd_super;
	struct mutex___231 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___229 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___231 bd_fsfreeze_mutex;
};

struct iattr___229 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___229 *ia_file;
};

struct dquot___229 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___231 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___229 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___229 {
	int qf_fmt_id;
	const struct quota_format_ops___229 *qf_ops;
	struct module___133 *qf_owner;
	struct quota_format_type___229 *qf_next;
};

struct quota_format_ops___229 {
	int (*check_quota_file)(struct super_block___229 *, int);
	int (*read_file_info)(struct super_block___229 *, int);
	int (*write_file_info)(struct super_block___229 *, int);
	int (*free_file_info)(struct super_block___229 *, int);
	int (*read_dqblk)(struct dquot___229 *);
	int (*commit_dqblk)(struct dquot___229 *);
	int (*release_dqblk)(struct dquot___229 *);
};

struct dquot_operations___229 {
	int (*write_dquot)(struct dquot___229 *);
	struct dquot___229 * (*alloc_dquot)(struct super_block___229 *, int);
	void (*destroy_dquot)(struct dquot___229 *);
	int (*acquire_dquot)(struct dquot___229 *);
	int (*release_dquot)(struct dquot___229 *);
	int (*mark_dirty)(struct dquot___229 *);
	int (*write_info)(struct super_block___229 *, int);
	qsize_t * (*get_reserved_space)(struct inode___229 *);
};

struct quotactl_ops___229 {
	int (*quota_on)(struct super_block___229 *, int, int, struct path___229 *);
	int (*quota_on_meta)(struct super_block___229 *, int, int);
	int (*quota_off)(struct super_block___229 *, int);
	int (*quota_sync)(struct super_block___229 *, int);
	int (*get_info)(struct super_block___229 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___229 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___229 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___229 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___229 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___229 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___229 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___229 *, unsigned int);
};

struct address_space_operations___229 {
	int (*writepage)(struct page___228 *, struct writeback_control *);
	int (*readpage)(struct file___229 *, struct page___228 *);
	int (*writepages)(struct address_space___229 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___228 *);
	int (*readpages)(struct file___229 *, struct address_space___229 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___229 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___228 **, void **);
	int (*write_end)(struct file___229 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___228 *, void *);
	sector_t (*bmap)(struct address_space___229 *, sector_t);
	void (*invalidatepage)(struct page___228 *, long unsigned int);
	int (*releasepage)(struct page___228 *, gfp_t);
	void (*freepage)(struct page___228 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___229 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___229 *, struct page___228 *, struct page___228 *, enum migrate_mode);
	int (*launder_page)(struct page___228 *);
	int (*is_partially_uptodate)(struct page___228 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___228 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___229 *, struct page___228 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___229 *, sector_t *);
	void (*swap_deactivate)(struct file___229 *);
	void (*invalidatepage_range)(struct page___228 *, unsigned int, unsigned int);
};

struct cdev___61 {
	struct kobject___24 kobj;
	struct module___133 *owner;
	const struct file_operations___229 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___229 {
	struct dentry___229 * (*lookup)(struct inode___229 *, struct dentry___229 *, unsigned int);
	void * (*follow_link)(struct dentry___229 *, struct nameidata *);
	int (*permission)(struct inode___229 *, int);
	struct posix_acl * (*get_acl)(struct inode___229 *, int);
	int (*readlink)(struct dentry___229 *, char *, int);
	void (*put_link)(struct dentry___229 *, struct nameidata *, void *);
	int (*create)(struct inode___229 *, struct dentry___229 *, umode_t, bool);
	int (*link)(struct dentry___229 *, struct inode___229 *, struct dentry___229 *);
	int (*unlink)(struct inode___229 *, struct dentry___229 *);
	int (*symlink)(struct inode___229 *, struct dentry___229 *, const char *);
	int (*mkdir)(struct inode___229 *, struct dentry___229 *, umode_t);
	int (*rmdir)(struct inode___229 *, struct dentry___229 *);
	int (*mknod)(struct inode___229 *, struct dentry___229 *, umode_t, dev_t);
	int (*rename)(struct inode___229 *, struct dentry___229 *, struct inode___229 *, struct dentry___229 *);
	int (*setattr)(struct dentry___229 *, struct iattr___229 *);
	int (*getattr)(struct vfsmount *, struct dentry___229 *, struct kstat *);
	int (*setxattr)(struct dentry___229 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___229 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___229 *, char *, size_t);
	int (*removexattr)(struct dentry___229 *, const char *);
	int (*fiemap)(struct inode___229 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___229 *, struct timespec *, int);
	int (*atomic_open)(struct inode___229 *, struct dentry___229 *, struct file___229 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___229 {
	struct module___133 *owner;
	loff_t (*llseek)(struct file___229 *, loff_t, int);
	ssize_t (*read)(struct file___229 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___229 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___229 *, void *, filldir_t);
	unsigned int (*poll)(struct file___229 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___229 *, struct vm_area_struct___237 *);
	int (*open)(struct inode___229 *, struct file___229 *);
	int (*flush)(struct file___229 *, fl_owner_t);
	int (*release)(struct inode___229 *, struct file___229 *);
	int (*fsync)(struct file___229 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___229 *, int);
	int (*lock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*sendpage)(struct file___229 *, struct page___228 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___229 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___229 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___229 *, long int, struct file_lock___229 **, void **);
		struct {
			int (*setlease)(struct file___229 *, long int, struct file_lock___229 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___229 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___5 *, struct file___229 *);
};

struct file_lock_operations___229;

struct lock_manager_operations___229;

struct file_lock___229 {
	struct file_lock___229 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___229 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___229 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___229 *fl_ops;
	const struct lock_manager_operations___229 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___229 {
	void (*fl_copy_lock)(struct file_lock___229 *, struct file_lock___229 *);
	void (*fl_release_private)(struct file_lock___229 *);
};

struct lock_manager_operations___229 {
	int (*lm_compare_owner)(struct file_lock___229 *, struct file_lock___229 *);
	long unsigned int (*lm_owner_key)(struct file_lock___229 *);
	void (*lm_notify)(struct file_lock___229 *);
	int (*lm_grant)(struct file_lock___229 *, struct file_lock___229 *, int);
	void (*lm_break)(struct file_lock___229 *);
	int (*lm_change)(struct file_lock___229 **, int);
};

struct fasync_struct___229 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___229 *fa_next;
	struct file___229 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___229 {
	const char *name;
	int fs_flags;
	struct dentry___229 * (*mount)(struct file_system_type___229 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___229 *);
	struct module___133 *owner;
	struct file_system_type___229 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___229 {
	struct inode___229 * (*alloc_inode)(struct super_block___229 *);
	void (*destroy_inode)(struct inode___229 *);
	void (*dirty_inode)(struct inode___229 *, int);
	int (*write_inode)(struct inode___229 *, struct writeback_control *);
	int (*drop_inode)(struct inode___229 *);
	void (*evict_inode)(struct inode___229 *);
	void (*put_super)(struct super_block___229 *);
	int (*sync_fs)(struct super_block___229 *, int);
	int (*freeze_fs)(struct super_block___229 *);
	int (*unfreeze_fs)(struct super_block___229 *);
	int (*statfs)(struct dentry___229 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___229 *, int *, char *);
	void (*umount_begin)(struct super_block___229 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___229 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___229 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___229 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___229 *);
	ssize_t (*quota_read)(struct super_block___229 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___229 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___229 *);
	int (*bdev_try_to_free_page)(struct super_block___229 *, struct page___228 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___229 *);
	void (*free_cached_objects)(struct super_block___229 *, int);
};

struct tty_operations___30 {
	struct tty_struct___30 * (*lookup)(struct tty_driver___30 *, struct inode___229 *, int);
	int (*install)(struct tty_driver___30 *, struct tty_struct___30 *);
	void (*remove)(struct tty_driver___30 *, struct tty_struct___30 *);
	int (*open)(struct tty_struct___30 *, struct file___229 *);
	void (*close)(struct tty_struct___30 *, struct file___229 *);
	void (*shutdown)(struct tty_struct___30 *);
	void (*cleanup)(struct tty_struct___30 *);
	int (*write)(struct tty_struct___30 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___30 *, unsigned char);
	void (*flush_chars)(struct tty_struct___30 *);
	int (*write_room)(struct tty_struct___30 *);
	int (*chars_in_buffer)(struct tty_struct___30 *);
	int (*ioctl)(struct tty_struct___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___30 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___30 *, struct ktermios *);
	void (*throttle)(struct tty_struct___30 *);
	void (*unthrottle)(struct tty_struct___30 *);
	void (*stop)(struct tty_struct___30 *);
	void (*start)(struct tty_struct___30 *);
	void (*hangup)(struct tty_struct___30 *);
	int (*break_ctl)(struct tty_struct___30 *, int);
	void (*flush_buffer)(struct tty_struct___30 *);
	void (*set_ldisc)(struct tty_struct___30 *);
	void (*wait_until_sent)(struct tty_struct___30 *, int);
	void (*send_xchar)(struct tty_struct___30 *, char);
	int (*tiocmget)(struct tty_struct___30 *);
	int (*tiocmset)(struct tty_struct___30 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___30 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___30 *, struct termiox *);
	int (*get_icount)(struct tty_struct___30 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___30 *, int, char *);
	int (*poll_get_char)(struct tty_driver___30 *, int);
	void (*poll_put_char)(struct tty_driver___30 *, int, char);
	const struct file_operations___229 *proc_fops;
};

struct tty_driver___30 {
	int magic;
	struct kref kref;
	struct cdev___61 *cdevs;
	struct module___133 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___30 *other;
	struct tty_struct___30 **ttys;
	struct tty_port___30 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___30 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___30;

struct tty_port___30 {
	struct tty_bufhead buf;
	struct tty_struct___30 *tty;
	struct tty_struct___30 *itty;
	const struct tty_port_operations___30 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___231 mutex;
	struct mutex___231 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___30 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___30 *);
	void (*close)(struct tty_struct___30 *);
	void (*flush_buffer)(struct tty_struct___30 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___30 *);
	ssize_t (*read)(struct tty_struct___30 *, struct file___229 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___30 *, struct file___229 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___30 *, struct file___229 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___30 *, struct file___229 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___30 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___30 *, struct file___229 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___30 *);
	void (*receive_buf)(struct tty_struct___30 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___30 *);
	void (*dcd_change)(struct tty_struct___30 *, unsigned int);
	struct module___133 *owner;
	int refcount;
	void (*fasync)(struct tty_struct___30 *, int);
};

struct tty_ldisc___30 {
	struct tty_ldisc_ops___30 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___30 *tty;
};

struct tty_port_operations___30 {
	int (*carrier_raised)(struct tty_port___30 *);
	void (*dtr_rts)(struct tty_port___30 *, int);
	void (*shutdown)(struct tty_port___30 *);
	void (*drop)(struct tty_port___30 *);
	int (*activate)(struct tty_port___30 *, struct tty_struct___30 *);
	void (*destruct)(struct tty_port___30 *);
};

struct serport {
	struct tty_struct___30 *tty;
	wait_queue_head_t wait;
	struct serio___2 *serio;
	struct serio_device_id id;
	spinlock_t lock;
	long unsigned int flags;
};

struct serio_driver___3;

struct serio___3 {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio___3 *, unsigned char);
	int (*open)(struct serio___3 *);
	void (*close)(struct serio___3 *);
	int (*start)(struct serio___3 *);
	void (*stop)(struct serio___3 *);
	struct serio___3 *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver___3 *drv;
	struct mutex___213 drv_mutex;
	struct device___209 dev;
	struct list_head node;
};

struct serio_driver___3 {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio___3 *);
	irqreturn_t (*interrupt)(struct serio___3 *, unsigned char, unsigned int);
	int (*connect)(struct serio___3 *, struct serio_driver___3 *);
	int (*reconnect)(struct serio___3 *);
	void (*disconnect)(struct serio___3 *);
	void (*cleanup)(struct serio___3 *);
	struct device_driver___209 driver;
};

struct ps2dev {
	struct serio___3 *serio;
	struct mutex___213 cmd_mutex;
	wait_queue_head_t wait;
	long unsigned int flags;
	unsigned char cmdbuf[8];
	unsigned char cmdcnt;
	unsigned char nak;
};

struct page___229;

typedef struct page___229 *pgtable_t___229;

struct address_space___230;

struct kmem_cache___215;

struct page___229 {
	long unsigned int flags;
	struct address_space___230 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___229 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___229 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___215 *slab_cache;
		struct page___229 *first_page;
	};
	long: 64;
};

struct task_struct___231;

struct pv_cpu_ops___231 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___231 *);
	void (*end_context_switch)(struct task_struct___231 *);
};

struct mutex___232 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___231 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___224 {
	struct page___229 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___238;

struct signal_struct___231;

struct task_struct___231 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___231 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___238 *mm;
	struct mm_struct___238 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___231 *real_parent;
	struct task_struct___231 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___231 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___231 = 0,
		VTIME_USER___231 = 1,
		VTIME_SYS___231 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___231 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___232 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___224 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___238 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___238 *, struct mm_struct___238 *);
	void (*dup_mmap)(struct mm_struct___238 *, struct mm_struct___238 *);
	void (*exit_mmap)(struct mm_struct___238 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___238 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___238 *);
	void (*pgd_free)(struct mm_struct___238 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___238 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___238 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___238 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___238 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___238 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___238 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___238 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___238 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___238 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___238 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___238 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___232 lock;
	void *vdso;
} mm_context_t___232;

struct xol_area___229;

struct uprobes_state___229 {
	struct xol_area___229 *xol_area;
};

struct vm_area_struct___238;

struct file___230;

struct core_state___231;

struct mm_struct___238 {
	struct vm_area_struct___238 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___238 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___238 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___232 context;
	long unsigned int flags;
	struct core_state___231 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___231 *owner;
	struct file___230 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___229 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___134;

struct exec_domain___61 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___134 *module;
	struct exec_domain___61 *next;
};

struct module_kobject___133 {
	struct kobject___24 kobj;
	struct module___134 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___133;

struct module___134 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___133 mkobj;
	struct module_attribute___133 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___231 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___104 {
	struct task_struct___231 *task;
	struct exec_domain___61 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___191;

struct attribute_group___189 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___191 **bin_attrs;
};

struct bin_attribute___191 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___230 *, struct kobject___24 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___230 *, struct kobject___24 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	int (*mmap)(struct file___230 *, struct kobject___24 *, struct bin_attribute___191 *, struct vm_area_struct___238 *);
};

struct dentry___230;

struct path___230 {
	struct vfsmount *mnt;
	struct dentry___230 *dentry;
};

struct inode___230;

struct file_operations___230;

struct file___230 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___230 f_path;
	struct inode___230 *f_inode;
	const struct file_operations___230 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___230 *f_mapping;
	struct mutex___232 f_pos_lock;
};

struct vm_area_struct___238 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___238 *vm_next;
	struct vm_area_struct___238 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___238 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___230 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___220;

struct dev_pm_ops___220 {
	int (*prepare)(struct device___220 *);
	void (*complete)(struct device___220 *);
	int (*suspend)(struct device___220 *);
	int (*resume)(struct device___220 *);
	int (*freeze)(struct device___220 *);
	int (*thaw)(struct device___220 *);
	int (*poweroff)(struct device___220 *);
	int (*restore)(struct device___220 *);
	int (*suspend_late)(struct device___220 *);
	int (*resume_early)(struct device___220 *);
	int (*freeze_late)(struct device___220 *);
	int (*thaw_early)(struct device___220 *);
	int (*poweroff_late)(struct device___220 *);
	int (*restore_early)(struct device___220 *);
	int (*suspend_noirq)(struct device___220 *);
	int (*resume_noirq)(struct device___220 *);
	int (*freeze_noirq)(struct device___220 *);
	int (*thaw_noirq)(struct device___220 *);
	int (*poweroff_noirq)(struct device___220 *);
	int (*restore_noirq)(struct device___220 *);
	int (*runtime_suspend)(struct device___220 *);
	int (*runtime_resume)(struct device___220 *);
	int (*runtime_idle)(struct device___220 *);
};

struct device_type___220;

struct bus_type___220;

struct device_driver___220;

struct dev_pm_domain___220;

struct class___220;

struct device_rh___220;

struct device___220 {
	struct device___220 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___220 *type;
	struct mutex___232 mutex;
	struct bus_type___220 *bus;
	struct device_driver___220 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___220 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___220 *class;
	const struct attribute_group___189 **groups;
	void (*release)(struct device___220 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___220 *device_rh;
};

struct dev_pm_info_rh___220 {
	void (*set_latency_tolerance)(struct device___220 *, s32);
};

struct dev_pm_domain___220 {
	struct dev_pm_ops___220 ops;
};

struct zone___231;

struct lruvec___231 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___231 *zone;
};

struct pglist_data___231;

struct zone___231 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___231 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___231 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___231 {
	struct zone___231 *zone;
	int zone_idx;
};

struct zonelist___231 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___231 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___231 {
	struct zone___231 node_zones[4];
	struct zonelist___231 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___231 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct smp_ops___231 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___231 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bus_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___220 *, char *);
	ssize_t (*store)(struct bus_type___220 *, const char *, size_t);
};

struct device_attribute___220;

struct driver_attribute___220;

struct bus_type___220 {
	const char *name;
	const char *dev_name;
	struct device___220 *dev_root;
	struct bus_attribute___220 *bus_attrs;
	struct device_attribute___220 *dev_attrs;
	struct driver_attribute___220 *drv_attrs;
	const struct attribute_group___189 **bus_groups;
	const struct attribute_group___189 **dev_groups;
	const struct attribute_group___189 **drv_groups;
	int (*match)(struct device___220 *, struct device_driver___220 *);
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	int (*probe)(struct device___220 *);
	int (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*online)(struct device___220 *);
	int (*offline)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct device___220 *, struct device_attribute___220 *, char *);
	ssize_t (*store)(struct device___220 *, struct device_attribute___220 *, const char *, size_t);
};

struct driver_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___220 *, char *);
	ssize_t (*store)(struct device_driver___220 *, const char *, size_t);
};

struct device_driver___220 {
	const char *name;
	struct bus_type___220 *bus;
	struct module___134 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___220 *);
	int (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	const struct attribute_group___189 **groups;
	const struct dev_pm_ops___220 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___220 {
	const char *name;
	const struct attribute_group___189 **groups;
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
};

struct class_attribute___220;

struct class___220 {
	const char *name;
	struct module___134 *owner;
	struct class_attribute___220 *class_attrs;
	struct device_attribute___220 *dev_attrs;
	const struct attribute_group___189 **dev_groups;
	struct bin_attribute___191 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *);
	void (*class_release)(struct class___220 *);
	void (*dev_release)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
	struct subsys_private *p;
};

struct class_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct class___220 *, struct class_attribute___220 *, char *);
	ssize_t (*store)(struct class___220 *, struct class_attribute___220 *, const char *, size_t);
	const void * (*namespace)(struct class___220 *, const struct class_attribute___220 *);
};

typedef void (*dr_release_t___9)(struct device___220 *, void *);

typedef int (*dr_match_t___9)(struct device___220 *, void *, void *);

struct device_rh___220 {
	struct dev_pm_info_rh___220 power;
};

struct dentry_operations___230;

struct super_block___230;

struct dentry___230 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___230 *d_parent;
	struct qstr d_name;
	struct inode___230 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___230 *d_op;
	struct super_block___230 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___230;

struct address_space___230 {
	struct inode___230 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___232 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___230 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___230;

struct file_lock___230;

struct dquot___230;

struct block_device___230;

struct inode___230 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___230 *i_op;
	struct super_block___230 *i_sb;
	struct address_space___230 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___232 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___230 *i_fop;
	struct file_lock___230 *i_flock;
	struct address_space___230 i_data;
	struct dquot___230 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___230 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___230 {
	int (*d_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_hash)(const struct dentry___230 *, struct qstr *);
	int (*d_compare)(const struct dentry___230 *, const struct dentry___230 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___230 *);
	void (*d_release)(struct dentry___230 *);
	void (*d_prune)(struct dentry___230 *);
	void (*d_iput)(struct dentry___230 *, struct inode___230 *);
	char * (*d_dname)(struct dentry___230 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___230 *);
	int (*d_manage)(struct dentry___230 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___230;

struct mem_dqinfo___230 {
	struct quota_format_type___230 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___230;

struct quota_info___230 {
	unsigned int flags;
	struct mutex___232 dqio_mutex;
	struct mutex___232 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___230 *files[2];
	struct mem_dqinfo___230 info[2];
	const struct quota_format_ops___230 *ops[2];
};

struct file_system_type___230;

struct super_operations___230;

struct dquot_operations___230;

struct quotactl_ops___230;

struct super_block___230 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___230 *s_type;
	const struct super_operations___230 *s_op;
	const struct dquot_operations___230 *dq_op;
	const struct quotactl_ops___230 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___230 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___230 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___230 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___232 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___230 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___230 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___230 *bd_inode;
	struct super_block___230 *bd_super;
	struct mutex___232 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___230 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___232 bd_fsfreeze_mutex;
};

struct iattr___230 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___230 *ia_file;
};

struct dquot___230 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___232 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___230 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___230 {
	int qf_fmt_id;
	const struct quota_format_ops___230 *qf_ops;
	struct module___134 *qf_owner;
	struct quota_format_type___230 *qf_next;
};

struct quota_format_ops___230 {
	int (*check_quota_file)(struct super_block___230 *, int);
	int (*read_file_info)(struct super_block___230 *, int);
	int (*write_file_info)(struct super_block___230 *, int);
	int (*free_file_info)(struct super_block___230 *, int);
	int (*read_dqblk)(struct dquot___230 *);
	int (*commit_dqblk)(struct dquot___230 *);
	int (*release_dqblk)(struct dquot___230 *);
};

struct dquot_operations___230 {
	int (*write_dquot)(struct dquot___230 *);
	struct dquot___230 * (*alloc_dquot)(struct super_block___230 *, int);
	void (*destroy_dquot)(struct dquot___230 *);
	int (*acquire_dquot)(struct dquot___230 *);
	int (*release_dquot)(struct dquot___230 *);
	int (*mark_dirty)(struct dquot___230 *);
	int (*write_info)(struct super_block___230 *, int);
	qsize_t * (*get_reserved_space)(struct inode___230 *);
};

struct quotactl_ops___230 {
	int (*quota_on)(struct super_block___230 *, int, int, struct path___230 *);
	int (*quota_on_meta)(struct super_block___230 *, int, int);
	int (*quota_off)(struct super_block___230 *, int);
	int (*quota_sync)(struct super_block___230 *, int);
	int (*get_info)(struct super_block___230 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___230 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___230 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___230 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___230 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___230 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___230 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___230 *, unsigned int);
};

struct address_space_operations___230 {
	int (*writepage)(struct page___229 *, struct writeback_control *);
	int (*readpage)(struct file___230 *, struct page___229 *);
	int (*writepages)(struct address_space___230 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___229 *);
	int (*readpages)(struct file___230 *, struct address_space___230 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___230 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___229 **, void **);
	int (*write_end)(struct file___230 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___229 *, void *);
	sector_t (*bmap)(struct address_space___230 *, sector_t);
	void (*invalidatepage)(struct page___229 *, long unsigned int);
	int (*releasepage)(struct page___229 *, gfp_t);
	void (*freepage)(struct page___229 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___230 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___230 *, struct page___229 *, struct page___229 *, enum migrate_mode);
	int (*launder_page)(struct page___229 *);
	int (*is_partially_uptodate)(struct page___229 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___229 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___230 *, struct page___229 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___230 *, sector_t *);
	void (*swap_deactivate)(struct file___230 *);
	void (*invalidatepage_range)(struct page___229 *, unsigned int, unsigned int);
};

struct inode_operations___230 {
	struct dentry___230 * (*lookup)(struct inode___230 *, struct dentry___230 *, unsigned int);
	void * (*follow_link)(struct dentry___230 *, struct nameidata *);
	int (*permission)(struct inode___230 *, int);
	struct posix_acl * (*get_acl)(struct inode___230 *, int);
	int (*readlink)(struct dentry___230 *, char *, int);
	void (*put_link)(struct dentry___230 *, struct nameidata *, void *);
	int (*create)(struct inode___230 *, struct dentry___230 *, umode_t, bool);
	int (*link)(struct dentry___230 *, struct inode___230 *, struct dentry___230 *);
	int (*unlink)(struct inode___230 *, struct dentry___230 *);
	int (*symlink)(struct inode___230 *, struct dentry___230 *, const char *);
	int (*mkdir)(struct inode___230 *, struct dentry___230 *, umode_t);
	int (*rmdir)(struct inode___230 *, struct dentry___230 *);
	int (*mknod)(struct inode___230 *, struct dentry___230 *, umode_t, dev_t);
	int (*rename)(struct inode___230 *, struct dentry___230 *, struct inode___230 *, struct dentry___230 *);
	int (*setattr)(struct dentry___230 *, struct iattr___230 *);
	int (*getattr)(struct vfsmount *, struct dentry___230 *, struct kstat *);
	int (*setxattr)(struct dentry___230 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___230 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___230 *, char *, size_t);
	int (*removexattr)(struct dentry___230 *, const char *);
	int (*fiemap)(struct inode___230 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___230 *, struct timespec *, int);
	int (*atomic_open)(struct inode___230 *, struct dentry___230 *, struct file___230 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___122;

struct seq_file___155;

struct file_operations___230 {
	struct module___134 *owner;
	loff_t (*llseek)(struct file___230 *, loff_t, int);
	ssize_t (*read)(struct file___230 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___230 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___230 *, void *, filldir_t);
	unsigned int (*poll)(struct file___230 *, struct poll_table_struct___122 *);
	long int (*unlocked_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___230 *, struct vm_area_struct___238 *);
	int (*open)(struct inode___230 *, struct file___230 *);
	int (*flush)(struct file___230 *, fl_owner_t);
	int (*release)(struct inode___230 *, struct file___230 *);
	int (*fsync)(struct file___230 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___230 *, int);
	int (*lock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*sendpage)(struct file___230 *, struct page___229 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___230 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___230 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___230 *, long int, struct file_lock___230 **, void **);
		struct {
			int (*setlease)(struct file___230 *, long int, struct file_lock___230 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___230 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___155 *, struct file___230 *);
};

struct fasync_struct___230;

struct file_lock_operations___230;

struct lock_manager_operations___230;

struct file_lock___230 {
	struct file_lock___230 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___230 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___230 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___230 *fl_ops;
	const struct lock_manager_operations___230 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___230 {
	void (*fl_copy_lock)(struct file_lock___230 *, struct file_lock___230 *);
	void (*fl_release_private)(struct file_lock___230 *);
};

struct lock_manager_operations___230 {
	int (*lm_compare_owner)(struct file_lock___230 *, struct file_lock___230 *);
	long unsigned int (*lm_owner_key)(struct file_lock___230 *);
	void (*lm_notify)(struct file_lock___230 *);
	int (*lm_grant)(struct file_lock___230 *, struct file_lock___230 *, int);
	void (*lm_break)(struct file_lock___230 *);
	int (*lm_change)(struct file_lock___230 **, int);
};

struct fasync_struct___230 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___230 *fa_next;
	struct file___230 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___230 {
	const char *name;
	int fs_flags;
	struct dentry___230 * (*mount)(struct file_system_type___230 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___230 *);
	struct module___134 *owner;
	struct file_system_type___230 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___230 {
	struct inode___230 * (*alloc_inode)(struct super_block___230 *);
	void (*destroy_inode)(struct inode___230 *);
	void (*dirty_inode)(struct inode___230 *, int);
	int (*write_inode)(struct inode___230 *, struct writeback_control *);
	int (*drop_inode)(struct inode___230 *);
	void (*evict_inode)(struct inode___230 *);
	void (*put_super)(struct super_block___230 *);
	int (*sync_fs)(struct super_block___230 *, int);
	int (*freeze_fs)(struct super_block___230 *);
	int (*unfreeze_fs)(struct super_block___230 *);
	int (*statfs)(struct dentry___230 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___230 *, int *, char *);
	void (*umount_begin)(struct super_block___230 *);
	int (*show_options)(struct seq_file___155 *, struct dentry___230 *);
	int (*show_devname)(struct seq_file___155 *, struct dentry___230 *);
	int (*show_path)(struct seq_file___155 *, struct dentry___230 *);
	int (*show_stats)(struct seq_file___155 *, struct dentry___230 *);
	ssize_t (*quota_read)(struct super_block___230 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___230 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___230 *);
	int (*bdev_try_to_free_page)(struct super_block___230 *, struct page___229 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___230 *);
	void (*free_cached_objects)(struct super_block___230 *, int);
};

typedef void (*poll_queue_proc___124)(struct file___230 *, wait_queue_head_t *, struct poll_table_struct___122 *);

struct poll_table_struct___122 {
	poll_queue_proc___124 _qproc;
	long unsigned int _key;
};

struct seq_operations___155;

struct seq_file___155 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___232 lock;
	const struct seq_operations___155 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ff_device___4;

struct input_handle___4;

struct input_dev___4 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___4 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___4 *, struct input_keymap_entry *);
	struct ff_device___4 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___4 *);
	void (*close)(struct input_dev___4 *);
	int (*flush)(struct input_dev___4 *, struct file___230 *);
	int (*event)(struct input_dev___4 *, unsigned int, unsigned int, int);
	struct input_handle___4 *grab;
	spinlock_t event_lock;
	struct mutex___232 mutex;
	unsigned int users;
	bool going_away;
	struct device___220 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___4 {
	int (*upload)(struct input_dev___4 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___4 *, int);
	int (*playback)(struct input_dev___4 *, int, int);
	void (*set_gain)(struct input_dev___4 *, u16);
	void (*set_autocenter)(struct input_dev___4 *, u16);
	void (*destroy)(struct ff_device___4 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___232 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___230 *effect_owners[0];
};

struct input_mt_slot {
	int abs[14];
	unsigned int frame;
	unsigned int key;
};

struct input_mt {
	int trkid;
	int num_slots;
	int slot;
	unsigned int flags;
	unsigned int frame;
	int *red;
	struct input_mt_slot slots[0];
};

struct input_handler___4;

struct input_handle___4 {
	void *private;
	int open;
	const char *name;
	struct input_dev___4 *dev;
	struct input_handler___4 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___4 {
	void *private;
	void (*event)(struct input_handle___4 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___4 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___4 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___4 *, struct input_dev___4 *);
	int (*connect)(struct input_handler___4 *, struct input_dev___4 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___4 *);
	void (*start)(struct input_handle___4 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct module_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___133 *, struct module_kobject___133 *, char *);
	ssize_t (*store)(struct module_attribute___133 *, struct module_kobject___133 *, const char *, size_t);
	void (*setup)(struct module___134 *, const char *);
	int (*test)(struct module___134 *);
	void (*free)(struct module___134 *);
};

struct kmem_cache_cpu___214 {
	void **freelist;
	long unsigned int tid;
	struct page___229 *page;
	struct page___229 *partial;
};

struct memcg_cache_params___215;

struct kmem_cache___215 {
	struct kmem_cache_cpu___214 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___215 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___215 {
	bool is_root_cache;
	union {
		struct kmem_cache___215 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___215 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___229 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___229 *page;
	long unsigned int vaddr;
};

struct core_thread___231 {
	struct task_struct___231 *task;
	struct core_thread___231 *next;
};

struct core_state___231 {
	atomic_t nr_threads;
	struct core_thread___231 dumper;
	struct completion startup;
};

struct signal_struct___231 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___231 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___231 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___232 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___155 {
	void * (*start)(struct seq_file___155 *, loff_t *);
	void (*stop)(struct seq_file___155 *, void *);
	void * (*next)(struct seq_file___155 *, void *, loff_t *);
	int (*show)(struct seq_file___155 *, void *);
};

typedef struct poll_table_struct___122 poll_table___29;

union input_seq_state {
	struct {
		short unsigned int pos;
		bool mutex_acquired;
	};
	void *p;
};

struct input_devres {
	struct input_dev___4 *input;
};

struct input_event {
	struct timeval time;
	__u16 type;
	__u16 code;
	__s32 value;
};

struct input_event_compat {
	struct compat_timeval time;
	__u16 type;
	__u16 code;
	__s32 value;
};

struct ff_periodic_effect_compat {
	__u16 waveform;
	__u16 period;
	__s16 magnitude;
	__s16 offset;
	__u16 phase;
	struct ff_envelope envelope;
	__u32 custom_len;
	compat_uptr_t custom_data;
};

struct ff_effect_compat {
	__u16 type;
	__s16 id;
	__u16 direction;
	struct ff_trigger trigger;
	struct ff_replay replay;
	union {
		struct ff_constant_effect constant;
		struct ff_ramp_effect ramp;
		struct ff_periodic_effect_compat periodic;
		struct ff_condition_effect condition[2];
		struct ff_rumble_effect rumble;
	} u;
};

struct input_mt_pos {
	s16 x;
	s16 y;
};

typedef struct poll_table_struct___111 poll_table___30;

struct ff_device___5;

struct input_handle___5;

struct input_dev___5 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___5 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___5 *, struct input_keymap_entry *);
	struct ff_device___5 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___5 *);
	void (*close)(struct input_dev___5 *);
	int (*flush)(struct input_dev___5 *, struct file___195 *);
	int (*event)(struct input_dev___5 *, unsigned int, unsigned int, int);
	struct input_handle___5 *grab;
	spinlock_t event_lock;
	struct mutex___198 mutex;
	unsigned int users;
	bool going_away;
	struct device___171 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___5 {
	int (*upload)(struct input_dev___5 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___5 *, int);
	int (*playback)(struct input_dev___5 *, int, int);
	void (*set_gain)(struct input_dev___5 *, u16);
	void (*set_autocenter)(struct input_dev___5 *, u16);
	void (*destroy)(struct ff_device___5 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___198 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___195 *effect_owners[0];
};

struct input_handler___5;

struct input_handle___5 {
	void *private;
	int open;
	const char *name;
	struct input_dev___5 *dev;
	struct input_handler___5 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___5 {
	void *private;
	void (*event)(struct input_handle___5 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___5 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___5 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___5 *, struct input_dev___5 *);
	int (*connect)(struct input_handler___5 *, struct input_dev___5 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___5 *);
	void (*start)(struct input_handle___5 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct mousedev_hw_data {
	int dx;
	int dy;
	int dz;
	int x;
	int y;
	int abs_event;
	long unsigned int buttons;
};

struct mousedev {
	int open;
	struct input_handle___5 handle;
	wait_queue_head_t wait;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex___198 mutex;
	struct device___171 dev;
	struct cdev___49 cdev;
	bool exist;
	bool is_mixdev;
	struct list_head mixdev_node;
	bool opened_by_mixdev;
	struct mousedev_hw_data packet;
	unsigned int pkt_count;
	int old_x[4];
	int old_y[4];
	int frac_dx;
	int frac_dy;
	long unsigned int touch;
};

enum mousedev_emul {
	MOUSEDEV_EMUL_PS2 = 0,
	MOUSEDEV_EMUL_IMPS = 1,
	MOUSEDEV_EMUL_EXPS = 2,
};

struct mousedev_motion {
	int dx;
	int dy;
	int dz;
	long unsigned int buttons;
};

struct mousedev_client {
	struct fasync_struct___195 *fasync;
	struct mousedev *mousedev;
	struct list_head node;
	struct mousedev_motion packets[16];
	unsigned int head;
	unsigned int tail;
	spinlock_t packet_lock;
	int pos_x;
	int pos_y;
	signed char ps2[6];
	unsigned char ready;
	unsigned char buffer;
	unsigned char bufsiz;
	unsigned char imexseq;
	unsigned char impsseq;
	enum mousedev_emul mode;
	long unsigned int last_buttons;
};

typedef struct poll_table_struct poll_table___31;

struct ff_device___6;

struct input_handle___6;

struct input_dev___6 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___6 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___6 *, struct input_keymap_entry *);
	struct ff_device___6 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___6 *);
	void (*close)(struct input_dev___6 *);
	int (*flush)(struct input_dev___6 *, struct file___2 *);
	int (*event)(struct input_dev___6 *, unsigned int, unsigned int, int);
	struct input_handle___6 *grab;
	spinlock_t event_lock;
	struct mutex___3 mutex;
	unsigned int users;
	bool going_away;
	struct device___158 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___6 {
	int (*upload)(struct input_dev___6 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___6 *, int);
	int (*playback)(struct input_dev___6 *, int, int);
	void (*set_gain)(struct input_dev___6 *, u16);
	void (*set_autocenter)(struct input_dev___6 *, u16);
	void (*destroy)(struct ff_device___6 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___3 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___2 *effect_owners[0];
};

struct input_handler___6;

struct input_handle___6 {
	void *private;
	int open;
	const char *name;
	struct input_dev___6 *dev;
	struct input_handler___6 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___6 {
	void *private;
	void (*event)(struct input_handle___6 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___6 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___6 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___6 *, struct input_dev___6 *);
	int (*connect)(struct input_handler___6 *, struct input_dev___6 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___6 *);
	void (*start)(struct input_handle___6 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct evdev_client;

struct evdev {
	int open;
	struct input_handle___6 handle;
	wait_queue_head_t wait;
	struct evdev_client *grab;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex___3 mutex;
	struct device___158 dev;
	struct cdev cdev;
	bool exist;
};

struct evdev_client {
	unsigned int head;
	unsigned int tail;
	unsigned int packet_head;
	spinlock_t buffer_lock;
	struct fasync_struct *fasync;
	struct evdev *evdev;
	struct list_head node;
	int clkid;
	unsigned int bufsize;
	struct input_event buffer[0];
};

struct serio_driver___4;

struct serio___4 {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio___4 *, unsigned char);
	int (*open)(struct serio___4 *);
	void (*close)(struct serio___4 *);
	int (*start)(struct serio___4 *);
	void (*stop)(struct serio___4 *);
	struct serio___4 *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver___4 *drv;
	struct mutex___232 drv_mutex;
	struct device___220 dev;
	struct list_head node;
};

struct serio_driver___4 {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio___4 *);
	irqreturn_t (*interrupt)(struct serio___4 *, unsigned char, unsigned int);
	int (*connect)(struct serio___4 *, struct serio_driver___4 *);
	int (*reconnect)(struct serio___4 *);
	void (*disconnect)(struct serio___4 *);
	void (*cleanup)(struct serio___4 *);
	struct device_driver___220 driver;
};

struct ps2dev___2 {
	struct serio___4 *serio;
	struct mutex___232 cmd_mutex;
	wait_queue_head_t wait;
	long unsigned int flags;
	unsigned char cmdbuf[8];
	unsigned char cmdcnt;
	unsigned char nak;
};

struct atkbd {
	struct ps2dev___2 ps2dev;
	struct input_dev___4 *dev;
	char name[64];
	char phys[32];
	short unsigned int id;
	short unsigned int keycode[512];
	long unsigned int force_release_mask[8];
	unsigned char set;
	bool translated;
	bool extra;
	bool write;
	bool softrepeat;
	bool softraw;
	bool scroll;
	bool enabled;
	unsigned char emul;
	bool resend;
	bool release;
	long unsigned int xl_bit;
	unsigned int last;
	long unsigned int time;
	long unsigned int err_count;
	struct delayed_work event_work;
	long unsigned int event_jiffies;
	long unsigned int event_mask;
	struct mutex___232 mutex;
};

enum psmouse_state {
	PSMOUSE_IGNORE = 0,
	PSMOUSE_INITIALIZING = 1,
	PSMOUSE_RESYNCING = 2,
	PSMOUSE_CMD_MODE = 3,
	PSMOUSE_ACTIVATED = 4,
};

typedef enum {
	PSMOUSE_BAD_DATA = 0,
	PSMOUSE_GOOD_DATA = 1,
	PSMOUSE_FULL_PACKET = 2,
} psmouse_ret_t;

struct psmouse {
	void *private;
	struct input_dev___4 *dev;
	struct ps2dev___2 ps2dev;
	struct delayed_work resync_work;
	char *vendor;
	char *name;
	unsigned char packet[8];
	unsigned char badbyte;
	unsigned char pktcnt;
	unsigned char pktsize;
	unsigned char type;
	bool ignore_parity;
	bool acks_disable_command;
	unsigned int model;
	long unsigned int last;
	long unsigned int out_of_sync_cnt;
	long unsigned int num_resyncs;
	enum psmouse_state state;
	char devname[64];
	char phys[32];
	unsigned int rate;
	unsigned int resolution;
	unsigned int resetafter;
	unsigned int resync_time;
	bool smartscroll;
	psmouse_ret_t (*protocol_handler)(struct psmouse *);
	void (*set_rate)(struct psmouse *, unsigned int);
	void (*set_resolution)(struct psmouse *, unsigned int);
	int (*reconnect)(struct psmouse *);
	void (*disconnect)(struct psmouse *);
	void (*cleanup)(struct psmouse *);
	int (*poll)(struct psmouse *);
	void (*pt_activate)(struct psmouse *);
	void (*pt_deactivate)(struct psmouse *);
};

enum psmouse_type {
	PSMOUSE_NONE = 0,
	PSMOUSE_PS2 = 1,
	PSMOUSE_PS2PP = 2,
	PSMOUSE_THINKPS = 3,
	PSMOUSE_GENPS = 4,
	PSMOUSE_IMPS = 5,
	PSMOUSE_IMEX = 6,
	PSMOUSE_SYNAPTICS = 7,
	PSMOUSE_ALPS = 8,
	PSMOUSE_LIFEBOOK = 9,
	PSMOUSE_TRACKPOINT = 10,
	PSMOUSE_TOUCHKIT_PS2 = 11,
	PSMOUSE_CORTRON = 12,
	PSMOUSE_HGPK = 13,
	PSMOUSE_ELANTECH = 14,
	PSMOUSE_FSP = 15,
	PSMOUSE_SYNAPTICS_RELATIVE = 16,
	PSMOUSE_CYPRESS = 17,
	PSMOUSE_AUTO = 18,
};

struct psmouse_attribute {
	struct device_attribute___220 dattr;
	void *data;
	ssize_t (*show)(struct psmouse *, void *, char *);
	ssize_t (*set)(struct psmouse *, void *, const char *, size_t);
	bool protect;
};

struct psmouse_protocol {
	enum psmouse_type type;
	bool maxproto;
	bool ignore_parity;
	const char *name;
	const char *alias;
	int (*detect)(struct psmouse *, bool);
	int (*init)(struct psmouse *);
};

struct synaptics_mt_state {
	int count;
	int sgm;
	int agm;
};

struct synaptics_hw_state {
	int x;
	int y;
	int z;
	int w;
	unsigned int left: 1;
	unsigned int right: 1;
	unsigned int middle: 1;
	unsigned int up: 1;
	unsigned int down: 1;
	unsigned char ext_buttons;
	signed char scroll;
	struct synaptics_mt_state mt_state;
};

struct synaptics_data {
	long unsigned int model_id;
	long unsigned int firmware_id;
	long unsigned int board_id;
	long unsigned int capabilities;
	long unsigned int ext_cap;
	long unsigned int ext_cap_0c;
	long unsigned int ext_cap_10;
	long unsigned int identity;
	unsigned int x_res;
	unsigned int y_res;
	unsigned int x_max;
	unsigned int y_max;
	unsigned int x_min;
	unsigned int y_min;
	unsigned char pkt_type;
	unsigned char mode;
	int scroll;
	bool absolute_mode;
	bool disable_gesture;
	struct serio___4 *pt_port;
	unsigned char pt_buttons;
	struct synaptics_mt_state mt_state;
	bool mt_state_lost;
	struct synaptics_hw_state agm;
	bool agm_pending;
};

struct min_max_quirk {
	const char * const *pnp_ids;
	struct {
		long unsigned int min;
		long unsigned int max;
	} board_id;
	int x_min;
	int x_max;
	int y_min;
	int y_max;
};

enum V7_PACKET_ID {
	V7_PACKET_ID_IDLE = 0,
	V7_PACKET_ID_TWO = 1,
	V7_PACKET_ID_MULTI = 2,
	V7_PACKET_ID_NEW = 3,
	V7_PACKET_ID_UNKNOWN = 4,
};

struct alps_model_info {
	unsigned char signature[3];
	unsigned char command_mode_resp;
	unsigned char proto_version;
	unsigned char byte0;
	unsigned char mask0;
	int flags;
};

struct alps_nibble_commands {
	int command;
	unsigned char data;
};

struct alps_bitmap_point {
	int start_bit;
	int num_bits;
};

struct alps_fields {
	unsigned int x_map;
	unsigned int y_map;
	unsigned int fingers;
	int pressure;
	struct input_mt_pos st;
	struct input_mt_pos mt[2];
	unsigned int first_mp: 1;
	unsigned int is_mp: 1;
	unsigned int left: 1;
	unsigned int right: 1;
	unsigned int middle: 1;
	unsigned int ts_left: 1;
	unsigned int ts_right: 1;
	unsigned int ts_middle: 1;
};

struct alps_data {
	struct input_dev___4 *dev2;
	char phys[32];
	const struct alps_nibble_commands *nibble_commands;
	int addr_command;
	unsigned char proto_version;
	unsigned char byte0;
	unsigned char mask0;
	unsigned char fw_ver[3];
	int flags;
	int x_max;
	int y_max;
	int x_bits;
	int y_bits;
	unsigned int x_res;
	unsigned int y_res;
	int (*hw_init)(struct psmouse *);
	void (*process_packet)(struct psmouse *);
	int (*decode_fields)(struct alps_fields *, unsigned char *, struct psmouse *);
	void (*set_abs_params)(struct alps_data *, struct input_dev___4 *);
	int prev_fin;
	int multi_packet;
	unsigned char multi_data[6];
	struct alps_fields f;
	u8 quirks;
	struct timer_list timer;
};

struct finger_pos {
	unsigned int x;
	unsigned int y;
};

struct elantech_data {
	struct input_dev___4 *tp_dev;
	char tp_phys[32];
	unsigned char reg_07;
	unsigned char reg_10;
	unsigned char reg_11;
	unsigned char reg_20;
	unsigned char reg_21;
	unsigned char reg_22;
	unsigned char reg_23;
	unsigned char reg_24;
	unsigned char reg_25;
	unsigned char reg_26;
	unsigned char debug;
	unsigned char capabilities[3];
	bool paritycheck;
	bool jumpy_cursor;
	bool reports_pressure;
	bool crc_enabled;
	bool set_hw_resolution;
	unsigned char hw_version;
	unsigned int fw_version;
	unsigned int single_finger_reports;
	unsigned int y_max;
	unsigned int width;
	struct finger_pos mt[5];
	unsigned char parity[256];
	int (*send_cmd)(struct psmouse *, unsigned char, unsigned char *);
	void (*original_set_rate)(struct psmouse *, unsigned int);
};

struct elantech_attr_data {
	size_t field_offset;
	unsigned char reg;
};

struct ps2pp_info {
	u8 model;
	u8 kind;
	u16 features;
};

struct lifebook_data {
	struct input_dev___4 *dev2;
	char phys[32];
};

struct fsp_data {
	unsigned char ver;
	unsigned char rev;
	unsigned int buttons;
	unsigned int flags;
	bool vscroll;
	bool hscroll;
	unsigned char last_reg;
	unsigned char last_val;
	unsigned int last_mt_fgr;
};

struct trackpoint_data {
	unsigned char sensitivity;
	unsigned char speed;
	unsigned char inertia;
	unsigned char reach;
	unsigned char draghys;
	unsigned char mindrag;
	unsigned char thresh;
	unsigned char upthresh;
	unsigned char ztime;
	unsigned char jenks;
	unsigned char press_to_select;
	unsigned char skipback;
	unsigned char ext_dev;
};

struct trackpoint_attr_data {
	size_t field_offset;
	unsigned char command;
	unsigned char mask;
	unsigned char inverted;
	unsigned char power_on_default;
};

struct cytp_contact {
	int x;
	int y;
	int z;
};

struct cytp_report_data {
	int contact_cnt;
	struct cytp_contact contacts[2];
	unsigned int left: 1;
	unsigned int right: 1;
	unsigned int middle: 1;
	unsigned int tap: 1;
};

struct cytp_data {
	int fw_version;
	int pkt_size;
	int mode;
	int tp_min_pressure;
	int tp_max_pressure;
	int tp_width;
	int tp_high;
	int tp_max_abs_x;
	int tp_max_abs_y;
	int tp_res_x;
	int tp_res_y;
	int tp_metrics_supported;
};

typedef void (*dr_release_t___10)(struct device___143 *, void *);

typedef int (*dr_match_t___10)(struct device___143 *, void *, void *);

struct rtc_class_ops___2 {
	int (*open)(struct device___143 *);
	void (*release)(struct device___143 *);
	int (*ioctl)(struct device___143 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___143 *, struct rtc_time *);
	int (*set_time)(struct device___143 *, struct rtc_time *);
	int (*read_alarm)(struct device___143 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___143 *, struct rtc_wkalrm *);
	int (*proc)(struct device___143 *, struct seq_file___154 *);
	int (*set_mmss)(struct device___143 *, long unsigned int);
	int (*read_callback)(struct device___143 *, int);
	int (*alarm_irq_enable)(struct device___143 *, unsigned int);
};

struct rtc_device___2 {
	struct device___143 dev;
	struct module___134 *owner;
	int id;
	char name[20];
	const struct rtc_class_ops___2 *ops;
	struct mutex___232 ops_lock;
	struct cdev___42 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___178 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
};

struct rtc;

struct page___230;

typedef struct page___230 *pgtable_t___230;

struct address_space___231;

struct page___230 {
	long unsigned int flags;
	struct address_space___231 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___230 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___230 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___230 *first_page;
	};
	long: 64;
};

struct task_struct___232;

struct pv_cpu_ops___232 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___232 *);
	void (*end_context_switch)(struct task_struct___232 *);
};

struct mutex___233 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___232 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___225 {
	struct page___230 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___239;

struct signal_struct___232;

struct task_struct___232 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___232 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___239 *mm;
	struct mm_struct___239 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___232 *real_parent;
	struct task_struct___232 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___232 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___232 = 0,
		VTIME_USER___232 = 1,
		VTIME_SYS___232 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___232 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___233 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___225 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___239 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___239 *, struct mm_struct___239 *);
	void (*dup_mmap)(struct mm_struct___239 *, struct mm_struct___239 *);
	void (*exit_mmap)(struct mm_struct___239 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___239 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___239 *);
	void (*pgd_free)(struct mm_struct___239 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___239 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___239 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___239 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___239 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___239 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___239 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___239 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___239 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___239 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___239 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___239 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___233 lock;
	void *vdso;
} mm_context_t___233;

struct xol_area___230;

struct uprobes_state___230 {
	struct xol_area___230 *xol_area;
};

struct vm_area_struct___239;

struct file___231;

struct core_state___232;

struct mm_struct___239 {
	struct vm_area_struct___239 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___239 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___239 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___233 context;
	long unsigned int flags;
	struct core_state___232 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___232 *owner;
	struct file___231 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___230 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___135;

struct module_kobject___134 {
	struct kobject___24 kobj;
	struct module___135 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___134;

struct module___135 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___134 mkobj;
	struct module_attribute___134 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___232 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct irq_data___151;

struct x86_io_apic_ops___151 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___151 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___151;

struct irq_data___151 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___151 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___221;

struct dev_pm_ops___221 {
	int (*prepare)(struct device___221 *);
	void (*complete)(struct device___221 *);
	int (*suspend)(struct device___221 *);
	int (*resume)(struct device___221 *);
	int (*freeze)(struct device___221 *);
	int (*thaw)(struct device___221 *);
	int (*poweroff)(struct device___221 *);
	int (*restore)(struct device___221 *);
	int (*suspend_late)(struct device___221 *);
	int (*resume_early)(struct device___221 *);
	int (*freeze_late)(struct device___221 *);
	int (*thaw_early)(struct device___221 *);
	int (*poweroff_late)(struct device___221 *);
	int (*restore_early)(struct device___221 *);
	int (*suspend_noirq)(struct device___221 *);
	int (*resume_noirq)(struct device___221 *);
	int (*freeze_noirq)(struct device___221 *);
	int (*thaw_noirq)(struct device___221 *);
	int (*poweroff_noirq)(struct device___221 *);
	int (*restore_noirq)(struct device___221 *);
	int (*runtime_suspend)(struct device___221 *);
	int (*runtime_resume)(struct device___221 *);
	int (*runtime_idle)(struct device___221 *);
};

struct device_type___221;

struct bus_type___221;

struct device_driver___221;

struct dev_pm_domain___221;

struct class___221;

struct attribute_group___190;

struct device_rh___221;

struct device___221 {
	struct device___221 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___221 *type;
	struct mutex___233 mutex;
	struct bus_type___221 *bus;
	struct device_driver___221 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___221 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___221 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___221 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___221 *device_rh;
};

struct dev_pm_info_rh___221 {
	void (*set_latency_tolerance)(struct device___221 *, s32);
};

struct dev_pm_domain___221 {
	struct dev_pm_ops___221 ops;
};

struct smp_ops___232 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___232 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___232;

struct lruvec___232 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___232 *zone;
};

struct pglist_data___232;

struct zone___232 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___232 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___232 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___232 {
	struct zone___232 *zone;
	int zone_idx;
};

struct zonelist___232 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___232 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___232 {
	struct zone___232 node_zones[4];
	struct zonelist___232 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___232 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___156;

struct irq_chip___151 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___151 *);
	void (*irq_shutdown)(struct irq_data___151 *);
	void (*irq_enable)(struct irq_data___151 *);
	void (*irq_disable)(struct irq_data___151 *);
	void (*irq_ack)(struct irq_data___151 *);
	void (*irq_mask)(struct irq_data___151 *);
	void (*irq_mask_ack)(struct irq_data___151 *);
	void (*irq_unmask)(struct irq_data___151 *);
	void (*irq_eoi)(struct irq_data___151 *);
	int (*irq_set_affinity)(struct irq_data___151 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___151 *);
	int (*irq_set_type)(struct irq_data___151 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___151 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___151 *);
	void (*irq_bus_sync_unlock)(struct irq_data___151 *);
	void (*irq_cpu_online)(struct irq_data___151 *);
	void (*irq_cpu_offline)(struct irq_data___151 *);
	void (*irq_suspend)(struct irq_data___151 *);
	void (*irq_resume)(struct irq_data___151 *);
	void (*irq_pm_shutdown)(struct irq_data___151 *);
	void (*irq_print_chip)(struct irq_data___151 *, struct seq_file___156 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___151 *, void *);
	long unsigned int flags;
};

struct seq_operations___156;

struct seq_file___156 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___233 lock;
	const struct seq_operations___156 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bin_attribute___192;

struct attribute_group___190 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___192 **bin_attrs;
};

struct bin_attribute___192 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___231 *, struct kobject___24 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___231 *, struct kobject___24 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	int (*mmap)(struct file___231 *, struct kobject___24 *, struct bin_attribute___192 *, struct vm_area_struct___239 *);
};

struct dentry___231;

struct path___231 {
	struct vfsmount *mnt;
	struct dentry___231 *dentry;
};

struct inode___231;

struct file_operations___231;

struct file___231 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___231 f_path;
	struct inode___231 *f_inode;
	const struct file_operations___231 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___231 *f_mapping;
	struct mutex___233 f_pos_lock;
};

struct vm_area_struct___239 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___239 *vm_next;
	struct vm_area_struct___239 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___239 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___231 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bus_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___221 *, char *);
	ssize_t (*store)(struct bus_type___221 *, const char *, size_t);
};

struct device_attribute___221;

struct driver_attribute___221;

struct bus_type___221 {
	const char *name;
	const char *dev_name;
	struct device___221 *dev_root;
	struct bus_attribute___221 *bus_attrs;
	struct device_attribute___221 *dev_attrs;
	struct driver_attribute___221 *drv_attrs;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___221 *, struct device_driver___221 *);
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	int (*probe)(struct device___221 *);
	int (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*online)(struct device___221 *);
	int (*offline)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct device___221 *, struct device_attribute___221 *, char *);
	ssize_t (*store)(struct device___221 *, struct device_attribute___221 *, const char *, size_t);
};

struct driver_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___221 *, char *);
	ssize_t (*store)(struct device_driver___221 *, const char *, size_t);
};

struct device_driver___221 {
	const char *name;
	struct bus_type___221 *bus;
	struct module___135 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___221 *);
	int (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	const struct attribute_group___190 **groups;
	const struct dev_pm_ops___221 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___221 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
};

struct class_attribute___221;

struct class___221 {
	const char *name;
	struct module___135 *owner;
	struct class_attribute___221 *class_attrs;
	struct device_attribute___221 *dev_attrs;
	const struct attribute_group___190 **dev_groups;
	struct bin_attribute___192 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *);
	void (*class_release)(struct class___221 *);
	void (*dev_release)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
	struct subsys_private *p;
};

struct class_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct class___221 *, struct class_attribute___221 *, char *);
	ssize_t (*store)(struct class___221 *, struct class_attribute___221 *, const char *, size_t);
	const void * (*namespace)(struct class___221 *, const struct class_attribute___221 *);
};

struct device_rh___221 {
	struct dev_pm_info_rh___221 power;
};

struct seq_operations___156 {
	void * (*start)(struct seq_file___156 *, loff_t *);
	void (*stop)(struct seq_file___156 *, void *);
	void * (*next)(struct seq_file___156 *, void *, loff_t *);
	int (*show)(struct seq_file___156 *, void *);
};

struct cdev___62 {
	struct kobject___24 kobj;
	struct module___135 *owner;
	const struct file_operations___231 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___123;

struct file_lock___231;

struct file_operations___231 {
	struct module___135 *owner;
	loff_t (*llseek)(struct file___231 *, loff_t, int);
	ssize_t (*read)(struct file___231 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___231 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___231 *, void *, filldir_t);
	unsigned int (*poll)(struct file___231 *, struct poll_table_struct___123 *);
	long int (*unlocked_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___231 *, struct vm_area_struct___239 *);
	int (*open)(struct inode___231 *, struct file___231 *);
	int (*flush)(struct file___231 *, fl_owner_t);
	int (*release)(struct inode___231 *, struct file___231 *);
	int (*fsync)(struct file___231 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___231 *, int);
	int (*lock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*sendpage)(struct file___231 *, struct page___230 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___231 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___231 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___231 *, long int, struct file_lock___231 **, void **);
		struct {
			int (*setlease)(struct file___231 *, long int, struct file_lock___231 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___231 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___156 *, struct file___231 *);
};

struct dentry_operations___231;

struct super_block___231;

struct dentry___231 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___231 *d_parent;
	struct qstr d_name;
	struct inode___231 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___231 *d_op;
	struct super_block___231 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___231;

struct address_space___231 {
	struct inode___231 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___233 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___231 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___231;

struct dquot___231;

struct block_device___231;

struct inode___231 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___231 *i_op;
	struct super_block___231 *i_sb;
	struct address_space___231 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___233 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___231 *i_fop;
	struct file_lock___231 *i_flock;
	struct address_space___231 i_data;
	struct dquot___231 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___231 *i_bdev;
		struct cdev___62 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___231 {
	int (*d_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_hash)(const struct dentry___231 *, struct qstr *);
	int (*d_compare)(const struct dentry___231 *, const struct dentry___231 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___231 *);
	void (*d_release)(struct dentry___231 *);
	void (*d_prune)(struct dentry___231 *);
	void (*d_iput)(struct dentry___231 *, struct inode___231 *);
	char * (*d_dname)(struct dentry___231 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___231 *);
	int (*d_manage)(struct dentry___231 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___231;

struct mem_dqinfo___231 {
	struct quota_format_type___231 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___231;

struct quota_info___231 {
	unsigned int flags;
	struct mutex___233 dqio_mutex;
	struct mutex___233 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___231 *files[2];
	struct mem_dqinfo___231 info[2];
	const struct quota_format_ops___231 *ops[2];
};

struct file_system_type___231;

struct super_operations___231;

struct dquot_operations___231;

struct quotactl_ops___231;

struct super_block___231 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___231 *s_type;
	const struct super_operations___231 *s_op;
	const struct dquot_operations___231 *dq_op;
	const struct quotactl_ops___231 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___231 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___231 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___231 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___233 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___231 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___231 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___231 *bd_inode;
	struct super_block___231 *bd_super;
	struct mutex___233 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___231 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___233 bd_fsfreeze_mutex;
};

struct iattr___231 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___231 *ia_file;
};

struct dquot___231 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___233 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___231 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___231 {
	int qf_fmt_id;
	const struct quota_format_ops___231 *qf_ops;
	struct module___135 *qf_owner;
	struct quota_format_type___231 *qf_next;
};

struct quota_format_ops___231 {
	int (*check_quota_file)(struct super_block___231 *, int);
	int (*read_file_info)(struct super_block___231 *, int);
	int (*write_file_info)(struct super_block___231 *, int);
	int (*free_file_info)(struct super_block___231 *, int);
	int (*read_dqblk)(struct dquot___231 *);
	int (*commit_dqblk)(struct dquot___231 *);
	int (*release_dqblk)(struct dquot___231 *);
};

struct dquot_operations___231 {
	int (*write_dquot)(struct dquot___231 *);
	struct dquot___231 * (*alloc_dquot)(struct super_block___231 *, int);
	void (*destroy_dquot)(struct dquot___231 *);
	int (*acquire_dquot)(struct dquot___231 *);
	int (*release_dquot)(struct dquot___231 *);
	int (*mark_dirty)(struct dquot___231 *);
	int (*write_info)(struct super_block___231 *, int);
	qsize_t * (*get_reserved_space)(struct inode___231 *);
};

struct quotactl_ops___231 {
	int (*quota_on)(struct super_block___231 *, int, int, struct path___231 *);
	int (*quota_on_meta)(struct super_block___231 *, int, int);
	int (*quota_off)(struct super_block___231 *, int);
	int (*quota_sync)(struct super_block___231 *, int);
	int (*get_info)(struct super_block___231 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___231 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___231 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___231 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___231 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___231 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___231 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___231 *, unsigned int);
};

struct address_space_operations___231 {
	int (*writepage)(struct page___230 *, struct writeback_control *);
	int (*readpage)(struct file___231 *, struct page___230 *);
	int (*writepages)(struct address_space___231 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___230 *);
	int (*readpages)(struct file___231 *, struct address_space___231 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___231 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___230 **, void **);
	int (*write_end)(struct file___231 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___230 *, void *);
	sector_t (*bmap)(struct address_space___231 *, sector_t);
	void (*invalidatepage)(struct page___230 *, long unsigned int);
	int (*releasepage)(struct page___230 *, gfp_t);
	void (*freepage)(struct page___230 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___231 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___231 *, struct page___230 *, struct page___230 *, enum migrate_mode);
	int (*launder_page)(struct page___230 *);
	int (*is_partially_uptodate)(struct page___230 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___230 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___231 *, struct page___230 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___231 *, sector_t *);
	void (*swap_deactivate)(struct file___231 *);
	void (*invalidatepage_range)(struct page___230 *, unsigned int, unsigned int);
};

struct inode_operations___231 {
	struct dentry___231 * (*lookup)(struct inode___231 *, struct dentry___231 *, unsigned int);
	void * (*follow_link)(struct dentry___231 *, struct nameidata *);
	int (*permission)(struct inode___231 *, int);
	struct posix_acl * (*get_acl)(struct inode___231 *, int);
	int (*readlink)(struct dentry___231 *, char *, int);
	void (*put_link)(struct dentry___231 *, struct nameidata *, void *);
	int (*create)(struct inode___231 *, struct dentry___231 *, umode_t, bool);
	int (*link)(struct dentry___231 *, struct inode___231 *, struct dentry___231 *);
	int (*unlink)(struct inode___231 *, struct dentry___231 *);
	int (*symlink)(struct inode___231 *, struct dentry___231 *, const char *);
	int (*mkdir)(struct inode___231 *, struct dentry___231 *, umode_t);
	int (*rmdir)(struct inode___231 *, struct dentry___231 *);
	int (*mknod)(struct inode___231 *, struct dentry___231 *, umode_t, dev_t);
	int (*rename)(struct inode___231 *, struct dentry___231 *, struct inode___231 *, struct dentry___231 *);
	int (*setattr)(struct dentry___231 *, struct iattr___231 *);
	int (*getattr)(struct vfsmount *, struct dentry___231 *, struct kstat *);
	int (*setxattr)(struct dentry___231 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___231 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___231 *, char *, size_t);
	int (*removexattr)(struct dentry___231 *, const char *);
	int (*fiemap)(struct inode___231 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___231 *, struct timespec *, int);
	int (*atomic_open)(struct inode___231 *, struct dentry___231 *, struct file___231 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___231;

struct file_lock_operations___231;

struct lock_manager_operations___231;

struct file_lock___231 {
	struct file_lock___231 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___231 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___231 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___231 *fl_ops;
	const struct lock_manager_operations___231 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___231 {
	void (*fl_copy_lock)(struct file_lock___231 *, struct file_lock___231 *);
	void (*fl_release_private)(struct file_lock___231 *);
};

struct lock_manager_operations___231 {
	int (*lm_compare_owner)(struct file_lock___231 *, struct file_lock___231 *);
	long unsigned int (*lm_owner_key)(struct file_lock___231 *);
	void (*lm_notify)(struct file_lock___231 *);
	int (*lm_grant)(struct file_lock___231 *, struct file_lock___231 *, int);
	void (*lm_break)(struct file_lock___231 *);
	int (*lm_change)(struct file_lock___231 **, int);
};

struct fasync_struct___231 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___231 *fa_next;
	struct file___231 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___231 {
	const char *name;
	int fs_flags;
	struct dentry___231 * (*mount)(struct file_system_type___231 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___231 *);
	struct module___135 *owner;
	struct file_system_type___231 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___231 {
	struct inode___231 * (*alloc_inode)(struct super_block___231 *);
	void (*destroy_inode)(struct inode___231 *);
	void (*dirty_inode)(struct inode___231 *, int);
	int (*write_inode)(struct inode___231 *, struct writeback_control *);
	int (*drop_inode)(struct inode___231 *);
	void (*evict_inode)(struct inode___231 *);
	void (*put_super)(struct super_block___231 *);
	int (*sync_fs)(struct super_block___231 *, int);
	int (*freeze_fs)(struct super_block___231 *);
	int (*unfreeze_fs)(struct super_block___231 *);
	int (*statfs)(struct dentry___231 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___231 *, int *, char *);
	void (*umount_begin)(struct super_block___231 *);
	int (*show_options)(struct seq_file___156 *, struct dentry___231 *);
	int (*show_devname)(struct seq_file___156 *, struct dentry___231 *);
	int (*show_path)(struct seq_file___156 *, struct dentry___231 *);
	int (*show_stats)(struct seq_file___156 *, struct dentry___231 *);
	ssize_t (*quota_read)(struct super_block___231 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___231 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___231 *);
	int (*bdev_try_to_free_page)(struct super_block___231 *, struct page___230 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___231 *);
	void (*free_cached_objects)(struct super_block___231 *, int);
};

typedef void (*poll_queue_proc___125)(struct file___231 *, wait_queue_head_t *, struct poll_table_struct___123 *);

struct poll_table_struct___123 {
	poll_queue_proc___125 _qproc;
	long unsigned int _key;
};

struct rtc_class_ops___3 {
	int (*open)(struct device___221 *);
	void (*release)(struct device___221 *);
	int (*ioctl)(struct device___221 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___221 *, struct rtc_time *);
	int (*set_time)(struct device___221 *, struct rtc_time *);
	int (*read_alarm)(struct device___221 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___221 *, struct rtc_wkalrm *);
	int (*proc)(struct device___221 *, struct seq_file___156 *);
	int (*set_mmss)(struct device___221 *, long unsigned int);
	int (*read_callback)(struct device___221 *, int);
	int (*alarm_irq_enable)(struct device___221 *, unsigned int);
};

struct rtc_device___3 {
	struct device___221 dev;
	struct module___135 *owner;
	int id;
	char name[20];
	const struct rtc_class_ops___3 *ops;
	struct mutex___233 ops_lock;
	struct cdev___62 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___231 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
};

struct xol_area___230 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___230 *page;
	long unsigned int vaddr;
};

struct core_thread___232 {
	struct task_struct___232 *task;
	struct core_thread___232 *next;
};

struct core_state___232 {
	atomic_t nr_threads;
	struct core_thread___232 dumper;
	struct completion startup;
};

struct signal_struct___232 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___232 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___232 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___233 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___134 *, struct module_kobject___134 *, char *);
	ssize_t (*store)(struct module_attribute___134 *, struct module_kobject___134 *, const char *, size_t);
	void (*setup)(struct module___135 *, const char *);
	int (*test)(struct module___135 *);
	void (*free)(struct module___135 *);
};

enum {
	none = 0,
	day = 1,
	month = 2,
	year = 3,
};

struct page___231;

typedef struct page___231 *pgtable_t___231;

struct address_space___232;

struct page___231 {
	long unsigned int flags;
	struct address_space___232 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___231 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___231 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache *slab_cache;
		struct page___231 *first_page;
	};
	long: 64;
};

struct task_struct___233;

struct pv_cpu_ops___233 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___233 *);
	void (*end_context_switch)(struct task_struct___233 *);
};

struct mutex___234 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___233 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___226 {
	struct page___231 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___240;

struct signal_struct___233;

struct task_struct___233 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___233 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___240 *mm;
	struct mm_struct___240 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___233 *real_parent;
	struct task_struct___233 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___233 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___233 = 0,
		VTIME_USER___233 = 1,
		VTIME_SYS___233 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___233 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___234 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___226 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___240 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___240 *, struct mm_struct___240 *);
	void (*dup_mmap)(struct mm_struct___240 *, struct mm_struct___240 *);
	void (*exit_mmap)(struct mm_struct___240 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___240 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___240 *);
	void (*pgd_free)(struct mm_struct___240 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___240 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___240 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___240 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___240 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___240 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___240 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___240 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___240 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___240 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___240 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___240 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___234 lock;
	void *vdso;
} mm_context_t___234;

struct xol_area___231;

struct uprobes_state___231 {
	struct xol_area___231 *xol_area;
};

struct vm_area_struct___240;

struct file___232;

struct core_state___233;

struct mm_struct___240 {
	struct vm_area_struct___240 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___240 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___240 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___234 context;
	long unsigned int flags;
	struct core_state___233 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___233 *owner;
	struct file___232 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___231 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___136;

struct exec_domain___62 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___136 *module;
	struct exec_domain___62 *next;
};

struct module_kobject___135 {
	struct kobject___24 kobj;
	struct module___136 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___135;

struct module___136 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___135 mkobj;
	struct module_attribute___135 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___233 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___105 {
	struct task_struct___233 *task;
	struct exec_domain___62 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___233;

struct lruvec___233 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___233 *zone;
};

struct pglist_data___233;

struct zone___233 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___233 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___233 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___233 {
	struct zone___233 *zone;
	int zone_idx;
};

struct zonelist___233 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___233 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___233 {
	struct zone___233 node_zones[4];
	struct zonelist___233 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___233 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___152;

struct x86_io_apic_ops___152 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___152 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___152;

struct irq_data___152 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___152 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___222;

struct dev_pm_ops___222 {
	int (*prepare)(struct device___222 *);
	void (*complete)(struct device___222 *);
	int (*suspend)(struct device___222 *);
	int (*resume)(struct device___222 *);
	int (*freeze)(struct device___222 *);
	int (*thaw)(struct device___222 *);
	int (*poweroff)(struct device___222 *);
	int (*restore)(struct device___222 *);
	int (*suspend_late)(struct device___222 *);
	int (*resume_early)(struct device___222 *);
	int (*freeze_late)(struct device___222 *);
	int (*thaw_early)(struct device___222 *);
	int (*poweroff_late)(struct device___222 *);
	int (*restore_early)(struct device___222 *);
	int (*suspend_noirq)(struct device___222 *);
	int (*resume_noirq)(struct device___222 *);
	int (*freeze_noirq)(struct device___222 *);
	int (*thaw_noirq)(struct device___222 *);
	int (*poweroff_noirq)(struct device___222 *);
	int (*restore_noirq)(struct device___222 *);
	int (*runtime_suspend)(struct device___222 *);
	int (*runtime_resume)(struct device___222 *);
	int (*runtime_idle)(struct device___222 *);
};

struct device_type___222;

struct bus_type___222;

struct device_driver___222;

struct dev_pm_domain___222;

struct class___222;

struct attribute_group___191;

struct device_rh___222;

struct device___222 {
	struct device___222 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___222 *type;
	struct mutex___234 mutex;
	struct bus_type___222 *bus;
	struct device_driver___222 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___222 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___36 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___222 *class;
	const struct attribute_group___191 **groups;
	void (*release)(struct device___222 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___222 *device_rh;
};

struct dev_pm_info_rh___222 {
	void (*set_latency_tolerance)(struct device___222 *, s32);
};

struct dev_pm_domain___222 {
	struct dev_pm_ops___222 ops;
};

struct smp_ops___233 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___233 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___193;

struct attribute_group___191 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___193 **bin_attrs;
};

struct bin_attribute___193 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___232 *, struct kobject___24 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___232 *, struct kobject___24 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	int (*mmap)(struct file___232 *, struct kobject___24 *, struct bin_attribute___193 *, struct vm_area_struct___240 *);
};

struct dentry___232;

struct path___232 {
	struct vfsmount *mnt;
	struct dentry___232 *dentry;
};

struct inode___232;

struct file_operations___232;

struct file___232 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___232 f_path;
	struct inode___232 *f_inode;
	const struct file_operations___232 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___232 *f_mapping;
	struct mutex___234 f_pos_lock;
};

struct vm_area_struct___240 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___240 *vm_next;
	struct vm_area_struct___240 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___240 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___232 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___135 *, struct module_kobject___135 *, char *);
	ssize_t (*store)(struct module_attribute___135 *, struct module_kobject___135 *, const char *, size_t);
	void (*setup)(struct module___136 *, const char *);
	int (*test)(struct module___136 *);
	void (*free)(struct module___136 *);
};

struct seq_file___157;

struct irq_chip___152 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___152 *);
	void (*irq_shutdown)(struct irq_data___152 *);
	void (*irq_enable)(struct irq_data___152 *);
	void (*irq_disable)(struct irq_data___152 *);
	void (*irq_ack)(struct irq_data___152 *);
	void (*irq_mask)(struct irq_data___152 *);
	void (*irq_mask_ack)(struct irq_data___152 *);
	void (*irq_unmask)(struct irq_data___152 *);
	void (*irq_eoi)(struct irq_data___152 *);
	int (*irq_set_affinity)(struct irq_data___152 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___152 *);
	int (*irq_set_type)(struct irq_data___152 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___152 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___152 *);
	void (*irq_bus_sync_unlock)(struct irq_data___152 *);
	void (*irq_cpu_online)(struct irq_data___152 *);
	void (*irq_cpu_offline)(struct irq_data___152 *);
	void (*irq_suspend)(struct irq_data___152 *);
	void (*irq_resume)(struct irq_data___152 *);
	void (*irq_pm_shutdown)(struct irq_data___152 *);
	void (*irq_print_chip)(struct irq_data___152 *, struct seq_file___157 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___152 *, void *);
	long unsigned int flags;
};

struct seq_operations___157;

struct seq_file___157 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___234 lock;
	const struct seq_operations___157 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bus_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___222 *, char *);
	ssize_t (*store)(struct bus_type___222 *, const char *, size_t);
};

struct device_attribute___222;

struct driver_attribute___222;

struct bus_type___222 {
	const char *name;
	const char *dev_name;
	struct device___222 *dev_root;
	struct bus_attribute___222 *bus_attrs;
	struct device_attribute___222 *dev_attrs;
	struct driver_attribute___222 *drv_attrs;
	const struct attribute_group___191 **bus_groups;
	const struct attribute_group___191 **dev_groups;
	const struct attribute_group___191 **drv_groups;
	int (*match)(struct device___222 *, struct device_driver___222 *);
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	int (*probe)(struct device___222 *);
	int (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*online)(struct device___222 *);
	int (*offline)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct device___222 *, struct device_attribute___222 *, char *);
	ssize_t (*store)(struct device___222 *, struct device_attribute___222 *, const char *, size_t);
};

struct driver_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___222 *, char *);
	ssize_t (*store)(struct device_driver___222 *, const char *, size_t);
};

struct device_driver___222 {
	const char *name;
	struct bus_type___222 *bus;
	struct module___136 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___222 *);
	int (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	const struct attribute_group___191 **groups;
	const struct dev_pm_ops___222 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___222 {
	const char *name;
	const struct attribute_group___191 **groups;
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
};

struct class_attribute___222;

struct class___222 {
	const char *name;
	struct module___136 *owner;
	struct class_attribute___222 *class_attrs;
	struct device_attribute___222 *dev_attrs;
	const struct attribute_group___191 **dev_groups;
	struct bin_attribute___193 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *);
	void (*class_release)(struct class___222 *);
	void (*dev_release)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
	struct subsys_private *p;
};

struct class_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct class___222 *, struct class_attribute___222 *, char *);
	ssize_t (*store)(struct class___222 *, struct class_attribute___222 *, const char *, size_t);
	const void * (*namespace)(struct class___222 *, const struct class_attribute___222 *);
};

struct device_rh___222 {
	struct dev_pm_info_rh___222 power;
};

struct seq_operations___157 {
	void * (*start)(struct seq_file___157 *, loff_t *);
	void (*stop)(struct seq_file___157 *, void *);
	void * (*next)(struct seq_file___157 *, void *, loff_t *);
	int (*show)(struct seq_file___157 *, void *);
};

struct cdev___63 {
	struct kobject___24 kobj;
	struct module___136 *owner;
	const struct file_operations___232 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___124;

struct file_lock___232;

struct file_operations___232 {
	struct module___136 *owner;
	loff_t (*llseek)(struct file___232 *, loff_t, int);
	ssize_t (*read)(struct file___232 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___232 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___232 *, void *, filldir_t);
	unsigned int (*poll)(struct file___232 *, struct poll_table_struct___124 *);
	long int (*unlocked_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___232 *, struct vm_area_struct___240 *);
	int (*open)(struct inode___232 *, struct file___232 *);
	int (*flush)(struct file___232 *, fl_owner_t);
	int (*release)(struct inode___232 *, struct file___232 *);
	int (*fsync)(struct file___232 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___232 *, int);
	int (*lock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*sendpage)(struct file___232 *, struct page___231 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___232 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___232 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___232 *, long int, struct file_lock___232 **, void **);
		struct {
			int (*setlease)(struct file___232 *, long int, struct file_lock___232 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___232 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___157 *, struct file___232 *);
};

struct dentry_operations___232;

struct super_block___232;

struct dentry___232 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___232 *d_parent;
	struct qstr d_name;
	struct inode___232 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___232 *d_op;
	struct super_block___232 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___232;

struct address_space___232 {
	struct inode___232 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___234 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___232 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___232;

struct dquot___232;

struct block_device___232;

struct inode___232 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___232 *i_op;
	struct super_block___232 *i_sb;
	struct address_space___232 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___234 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___232 *i_fop;
	struct file_lock___232 *i_flock;
	struct address_space___232 i_data;
	struct dquot___232 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___232 *i_bdev;
		struct cdev___63 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___232 {
	int (*d_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_hash)(const struct dentry___232 *, struct qstr *);
	int (*d_compare)(const struct dentry___232 *, const struct dentry___232 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___232 *);
	void (*d_release)(struct dentry___232 *);
	void (*d_prune)(struct dentry___232 *);
	void (*d_iput)(struct dentry___232 *, struct inode___232 *);
	char * (*d_dname)(struct dentry___232 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___232 *);
	int (*d_manage)(struct dentry___232 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___232;

struct mem_dqinfo___232 {
	struct quota_format_type___232 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___232;

struct quota_info___232 {
	unsigned int flags;
	struct mutex___234 dqio_mutex;
	struct mutex___234 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___232 *files[2];
	struct mem_dqinfo___232 info[2];
	const struct quota_format_ops___232 *ops[2];
};

struct file_system_type___232;

struct super_operations___232;

struct dquot_operations___232;

struct quotactl_ops___232;

struct super_block___232 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___232 *s_type;
	const struct super_operations___232 *s_op;
	const struct dquot_operations___232 *dq_op;
	const struct quotactl_ops___232 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___232 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___232 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___232 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___234 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___232 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___232 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___232 *bd_inode;
	struct super_block___232 *bd_super;
	struct mutex___234 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___232 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___234 bd_fsfreeze_mutex;
};

struct iattr___232 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___232 *ia_file;
};

struct dquot___232 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___234 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___232 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___232 {
	int qf_fmt_id;
	const struct quota_format_ops___232 *qf_ops;
	struct module___136 *qf_owner;
	struct quota_format_type___232 *qf_next;
};

struct quota_format_ops___232 {
	int (*check_quota_file)(struct super_block___232 *, int);
	int (*read_file_info)(struct super_block___232 *, int);
	int (*write_file_info)(struct super_block___232 *, int);
	int (*free_file_info)(struct super_block___232 *, int);
	int (*read_dqblk)(struct dquot___232 *);
	int (*commit_dqblk)(struct dquot___232 *);
	int (*release_dqblk)(struct dquot___232 *);
};

struct dquot_operations___232 {
	int (*write_dquot)(struct dquot___232 *);
	struct dquot___232 * (*alloc_dquot)(struct super_block___232 *, int);
	void (*destroy_dquot)(struct dquot___232 *);
	int (*acquire_dquot)(struct dquot___232 *);
	int (*release_dquot)(struct dquot___232 *);
	int (*mark_dirty)(struct dquot___232 *);
	int (*write_info)(struct super_block___232 *, int);
	qsize_t * (*get_reserved_space)(struct inode___232 *);
};

struct quotactl_ops___232 {
	int (*quota_on)(struct super_block___232 *, int, int, struct path___232 *);
	int (*quota_on_meta)(struct super_block___232 *, int, int);
	int (*quota_off)(struct super_block___232 *, int);
	int (*quota_sync)(struct super_block___232 *, int);
	int (*get_info)(struct super_block___232 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___232 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___232 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___232 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___232 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___232 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___232 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___232 *, unsigned int);
};

struct address_space_operations___232 {
	int (*writepage)(struct page___231 *, struct writeback_control *);
	int (*readpage)(struct file___232 *, struct page___231 *);
	int (*writepages)(struct address_space___232 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___231 *);
	int (*readpages)(struct file___232 *, struct address_space___232 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___232 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___231 **, void **);
	int (*write_end)(struct file___232 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___231 *, void *);
	sector_t (*bmap)(struct address_space___232 *, sector_t);
	void (*invalidatepage)(struct page___231 *, long unsigned int);
	int (*releasepage)(struct page___231 *, gfp_t);
	void (*freepage)(struct page___231 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___232 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___232 *, struct page___231 *, struct page___231 *, enum migrate_mode);
	int (*launder_page)(struct page___231 *);
	int (*is_partially_uptodate)(struct page___231 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___231 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___232 *, struct page___231 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___232 *, sector_t *);
	void (*swap_deactivate)(struct file___232 *);
	void (*invalidatepage_range)(struct page___231 *, unsigned int, unsigned int);
};

struct inode_operations___232 {
	struct dentry___232 * (*lookup)(struct inode___232 *, struct dentry___232 *, unsigned int);
	void * (*follow_link)(struct dentry___232 *, struct nameidata *);
	int (*permission)(struct inode___232 *, int);
	struct posix_acl * (*get_acl)(struct inode___232 *, int);
	int (*readlink)(struct dentry___232 *, char *, int);
	void (*put_link)(struct dentry___232 *, struct nameidata *, void *);
	int (*create)(struct inode___232 *, struct dentry___232 *, umode_t, bool);
	int (*link)(struct dentry___232 *, struct inode___232 *, struct dentry___232 *);
	int (*unlink)(struct inode___232 *, struct dentry___232 *);
	int (*symlink)(struct inode___232 *, struct dentry___232 *, const char *);
	int (*mkdir)(struct inode___232 *, struct dentry___232 *, umode_t);
	int (*rmdir)(struct inode___232 *, struct dentry___232 *);
	int (*mknod)(struct inode___232 *, struct dentry___232 *, umode_t, dev_t);
	int (*rename)(struct inode___232 *, struct dentry___232 *, struct inode___232 *, struct dentry___232 *);
	int (*setattr)(struct dentry___232 *, struct iattr___232 *);
	int (*getattr)(struct vfsmount *, struct dentry___232 *, struct kstat *);
	int (*setxattr)(struct dentry___232 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___232 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___232 *, char *, size_t);
	int (*removexattr)(struct dentry___232 *, const char *);
	int (*fiemap)(struct inode___232 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___232 *, struct timespec *, int);
	int (*atomic_open)(struct inode___232 *, struct dentry___232 *, struct file___232 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___232;

struct file_lock_operations___232;

struct lock_manager_operations___232;

struct file_lock___232 {
	struct file_lock___232 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___232 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___232 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___232 *fl_ops;
	const struct lock_manager_operations___232 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___232 {
	void (*fl_copy_lock)(struct file_lock___232 *, struct file_lock___232 *);
	void (*fl_release_private)(struct file_lock___232 *);
};

struct lock_manager_operations___232 {
	int (*lm_compare_owner)(struct file_lock___232 *, struct file_lock___232 *);
	long unsigned int (*lm_owner_key)(struct file_lock___232 *);
	void (*lm_notify)(struct file_lock___232 *);
	int (*lm_grant)(struct file_lock___232 *, struct file_lock___232 *, int);
	void (*lm_break)(struct file_lock___232 *);
	int (*lm_change)(struct file_lock___232 **, int);
};

struct fasync_struct___232 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___232 *fa_next;
	struct file___232 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___232 {
	const char *name;
	int fs_flags;
	struct dentry___232 * (*mount)(struct file_system_type___232 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___232 *);
	struct module___136 *owner;
	struct file_system_type___232 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___232 {
	struct inode___232 * (*alloc_inode)(struct super_block___232 *);
	void (*destroy_inode)(struct inode___232 *);
	void (*dirty_inode)(struct inode___232 *, int);
	int (*write_inode)(struct inode___232 *, struct writeback_control *);
	int (*drop_inode)(struct inode___232 *);
	void (*evict_inode)(struct inode___232 *);
	void (*put_super)(struct super_block___232 *);
	int (*sync_fs)(struct super_block___232 *, int);
	int (*freeze_fs)(struct super_block___232 *);
	int (*unfreeze_fs)(struct super_block___232 *);
	int (*statfs)(struct dentry___232 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___232 *, int *, char *);
	void (*umount_begin)(struct super_block___232 *);
	int (*show_options)(struct seq_file___157 *, struct dentry___232 *);
	int (*show_devname)(struct seq_file___157 *, struct dentry___232 *);
	int (*show_path)(struct seq_file___157 *, struct dentry___232 *);
	int (*show_stats)(struct seq_file___157 *, struct dentry___232 *);
	ssize_t (*quota_read)(struct super_block___232 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___232 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___232 *);
	int (*bdev_try_to_free_page)(struct super_block___232 *, struct page___231 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___232 *);
	void (*free_cached_objects)(struct super_block___232 *, int);
};

typedef void (*poll_queue_proc___126)(struct file___232 *, wait_queue_head_t *, struct poll_table_struct___124 *);

struct poll_table_struct___124 {
	poll_queue_proc___126 _qproc;
	long unsigned int _key;
};

typedef struct poll_table_struct___124 poll_table___32;

struct rtc_class_ops___4 {
	int (*open)(struct device___222 *);
	void (*release)(struct device___222 *);
	int (*ioctl)(struct device___222 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___222 *, struct rtc_time *);
	int (*set_time)(struct device___222 *, struct rtc_time *);
	int (*read_alarm)(struct device___222 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___222 *, struct rtc_wkalrm *);
	int (*proc)(struct device___222 *, struct seq_file___157 *);
	int (*set_mmss)(struct device___222 *, long unsigned int);
	int (*read_callback)(struct device___222 *, int);
	int (*alarm_irq_enable)(struct device___222 *, unsigned int);
};

struct rtc_device___4 {
	struct device___222 dev;
	struct module___136 *owner;
	int id;
	char name[20];
	const struct rtc_class_ops___4 *ops;
	struct mutex___234 ops_lock;
	struct cdev___63 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___232 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
};

struct xol_area___231 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___231 *page;
	long unsigned int vaddr;
};

struct core_thread___233 {
	struct task_struct___233 *task;
	struct core_thread___233 *next;
};

struct core_state___233 {
	atomic_t nr_threads;
	struct core_thread___233 dumper;
	struct completion startup;
};

struct signal_struct___233 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___233 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___233 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___234 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct page___232;

typedef struct page___232 *pgtable_t___232;

struct address_space___233;

struct kmem_cache___216;

struct page___232 {
	long unsigned int flags;
	struct address_space___233 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___232 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___232 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___216 *slab_cache;
		struct page___232 *first_page;
	};
	long: 64;
};

struct task_struct___234;

struct pv_cpu_ops___234 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___234 *);
	void (*end_context_switch)(struct task_struct___234 *);
};

struct mutex___235 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___234 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___227 {
	struct page___232 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___241;

struct signal_struct___234;

struct task_struct___234 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___234 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___241 *mm;
	struct mm_struct___241 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___234 *real_parent;
	struct task_struct___234 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___234 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___234 = 0,
		VTIME_USER___234 = 1,
		VTIME_SYS___234 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___234 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___235 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___227 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___241 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___241 *, struct mm_struct___241 *);
	void (*dup_mmap)(struct mm_struct___241 *, struct mm_struct___241 *);
	void (*exit_mmap)(struct mm_struct___241 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___241 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___241 *);
	void (*pgd_free)(struct mm_struct___241 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___241 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___241 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___241 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___241 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___241 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___241 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___241 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___241 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___241 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___241 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___241 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___235 lock;
	void *vdso;
} mm_context_t___235;

struct xol_area___232;

struct uprobes_state___232 {
	struct xol_area___232 *xol_area;
};

struct vm_area_struct___241;

struct file___233;

struct core_state___234;

struct mm_struct___241 {
	struct vm_area_struct___241 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___241 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___241 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___235 context;
	long unsigned int flags;
	struct core_state___234 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___234 *owner;
	struct file___233 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___232 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___137;

struct module_kobject___136 {
	struct kobject kobj;
	struct module___137 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___136;

struct module___137 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___136 mkobj;
	struct module_attribute___136 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___234 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___234;

struct lruvec___234 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___234 *zone;
};

struct pglist_data___234;

struct zone___234 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___234 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___234 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___234 {
	struct zone___234 *zone;
	int zone_idx;
};

struct zonelist___234 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___234 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___234 {
	struct zone___234 node_zones[4];
	struct zonelist___234 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___234 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___153;

struct x86_io_apic_ops___153 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___153 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___153;

struct irq_data___153 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___153 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___5 *msi_desc;
	cpumask_var_t affinity;
};

struct device___223;

struct dev_pm_ops___223 {
	int (*prepare)(struct device___223 *);
	void (*complete)(struct device___223 *);
	int (*suspend)(struct device___223 *);
	int (*resume)(struct device___223 *);
	int (*freeze)(struct device___223 *);
	int (*thaw)(struct device___223 *);
	int (*poweroff)(struct device___223 *);
	int (*restore)(struct device___223 *);
	int (*suspend_late)(struct device___223 *);
	int (*resume_early)(struct device___223 *);
	int (*freeze_late)(struct device___223 *);
	int (*thaw_early)(struct device___223 *);
	int (*poweroff_late)(struct device___223 *);
	int (*restore_early)(struct device___223 *);
	int (*suspend_noirq)(struct device___223 *);
	int (*resume_noirq)(struct device___223 *);
	int (*freeze_noirq)(struct device___223 *);
	int (*thaw_noirq)(struct device___223 *);
	int (*poweroff_noirq)(struct device___223 *);
	int (*restore_noirq)(struct device___223 *);
	int (*runtime_suspend)(struct device___223 *);
	int (*runtime_resume)(struct device___223 *);
	int (*runtime_idle)(struct device___223 *);
};

struct acpi_device___31;

struct acpi_dev_node___37 {
	union {
		struct acpi_device___31 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___223;

struct bus_type___223;

struct device_driver___223;

struct dev_pm_domain___223;

struct device_node___15;

struct class___223;

struct attribute_group___192;

struct device_rh___223;

struct device___223 {
	struct device___223 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___223 *type;
	struct mutex___235 mutex;
	struct bus_type___223 *bus;
	struct device_driver___223 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___223 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___93 archdata;
	struct device_node___15 *of_node;
	struct acpi_dev_node___37 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___223 *class;
	const struct attribute_group___192 **groups;
	void (*release)(struct device___223 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___223 *device_rh;
};

struct dev_pm_info_rh___223 {
	void (*set_latency_tolerance)(struct device___223 *, s32);
};

struct dev_pm_domain___223 {
	struct dev_pm_ops___223 ops;
};

struct property___15;

struct device_node___15 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct property___15 *properties;
	struct property___15 *deadprops;
	struct device_node___15 *parent;
	struct device_node___15 *child;
	struct device_node___15 *sibling;
	struct device_node___15 *next;
	struct device_node___15 *allnext;
	struct proc_dir_entry *pde;
	struct kref kref;
	long unsigned int _flags;
	void *data;
	struct kobject kobj;
};

struct smp_ops___234 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___234 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___194;

struct attribute_group___192 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___194 **bin_attrs;
};

struct bin_attribute___194 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___233 *, struct kobject *, struct bin_attribute___194 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___233 *, struct kobject *, struct bin_attribute___194 *, char *, loff_t, size_t);
	int (*mmap)(struct file___233 *, struct kobject *, struct bin_attribute___194 *, struct vm_area_struct___241 *);
};

struct dentry___233;

struct path___233 {
	struct vfsmount *mnt;
	struct dentry___233 *dentry;
};

struct inode___233;

struct file_operations___233;

struct file___233 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___233 f_path;
	struct inode___233 *f_inode;
	const struct file_operations___233 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___233 *f_mapping;
	struct mutex___235 f_pos_lock;
};

struct vm_area_struct___241 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___241 *vm_next;
	struct vm_area_struct___241 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___241 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file___233 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___136 *, struct module_kobject___136 *, char *);
	ssize_t (*store)(struct module_attribute___136 *, struct module_kobject___136 *, const char *, size_t);
	void (*setup)(struct module___137 *, const char *);
	int (*test)(struct module___137 *);
	void (*free)(struct module___137 *);
};

struct seq_file___158;

struct irq_chip___153 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___153 *);
	void (*irq_shutdown)(struct irq_data___153 *);
	void (*irq_enable)(struct irq_data___153 *);
	void (*irq_disable)(struct irq_data___153 *);
	void (*irq_ack)(struct irq_data___153 *);
	void (*irq_mask)(struct irq_data___153 *);
	void (*irq_mask_ack)(struct irq_data___153 *);
	void (*irq_unmask)(struct irq_data___153 *);
	void (*irq_eoi)(struct irq_data___153 *);
	int (*irq_set_affinity)(struct irq_data___153 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___153 *);
	int (*irq_set_type)(struct irq_data___153 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___153 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___153 *);
	void (*irq_bus_sync_unlock)(struct irq_data___153 *);
	void (*irq_cpu_online)(struct irq_data___153 *);
	void (*irq_cpu_offline)(struct irq_data___153 *);
	void (*irq_suspend)(struct irq_data___153 *);
	void (*irq_resume)(struct irq_data___153 *);
	void (*irq_pm_shutdown)(struct irq_data___153 *);
	void (*irq_print_chip)(struct irq_data___153 *, struct seq_file___158 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___153 *, void *);
	long unsigned int flags;
};

struct seq_operations___158;

struct seq_file___158 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___235 lock;
	const struct seq_operations___158 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct bus_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___223 *, char *);
	ssize_t (*store)(struct bus_type___223 *, const char *, size_t);
};

struct device_attribute___223;

struct driver_attribute___223;

struct bus_type___223 {
	const char *name;
	const char *dev_name;
	struct device___223 *dev_root;
	struct bus_attribute___223 *bus_attrs;
	struct device_attribute___223 *dev_attrs;
	struct driver_attribute___223 *drv_attrs;
	const struct attribute_group___192 **bus_groups;
	const struct attribute_group___192 **dev_groups;
	const struct attribute_group___192 **drv_groups;
	int (*match)(struct device___223 *, struct device_driver___223 *);
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	int (*probe)(struct device___223 *);
	int (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*online)(struct device___223 *);
	int (*offline)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct device___223 *, struct device_attribute___223 *, char *);
	ssize_t (*store)(struct device___223 *, struct device_attribute___223 *, const char *, size_t);
};

struct driver_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___223 *, char *);
	ssize_t (*store)(struct device_driver___223 *, const char *, size_t);
};

struct device_driver___223 {
	const char *name;
	struct bus_type___223 *bus;
	struct module___137 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___223 *);
	int (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	const struct attribute_group___192 **groups;
	const struct dev_pm_ops___223 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___223 {
	const char *name;
	const struct attribute_group___192 **groups;
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
};

struct class_attribute___223;

struct class___223 {
	const char *name;
	struct module___137 *owner;
	struct class_attribute___223 *class_attrs;
	struct device_attribute___223 *dev_attrs;
	const struct attribute_group___192 **dev_groups;
	struct bin_attribute___194 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *);
	void (*class_release)(struct class___223 *);
	void (*dev_release)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
	struct subsys_private *p;
};

struct class_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct class___223 *, struct class_attribute___223 *, char *);
	ssize_t (*store)(struct class___223 *, struct class_attribute___223 *, const char *, size_t);
	const void * (*namespace)(struct class___223 *, const struct class_attribute___223 *);
};

struct acpi_scan_handler___31;

struct acpi_hotplug_context___31;

struct acpi_driver___31;

struct acpi_device___31 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___31 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___31 *handler;
	struct acpi_hotplug_context___31 *hp;
	struct acpi_driver___31 *driver;
	void *driver_data;
	struct device___223 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___235 physical_node_lock;
	void (*remove)(struct acpi_device___31 *);
};

struct device_rh___223 {
	struct dev_pm_info_rh___223 power;
};

struct platform_device___11 {
	const char *name;
	int id;
	bool id_auto;
	struct device___223 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___7 {
	int (*probe)(struct platform_device___11 *);
	int (*remove)(struct platform_device___11 *);
	void (*shutdown)(struct platform_device___11 *);
	int (*suspend)(struct platform_device___11 *, pm_message_t);
	int (*resume)(struct platform_device___11 *);
	struct device_driver___223 driver;
	const struct platform_device_id *id_table;
};

struct property___15 {
	char *name;
	int length;
	void *value;
	struct property___15 *next;
	long unsigned int _flags;
	unsigned int unique_id;
	struct bin_attribute___194 attr;
};

struct seq_operations___158 {
	void * (*start)(struct seq_file___158 *, loff_t *);
	void (*stop)(struct seq_file___158 *, void *);
	void * (*next)(struct seq_file___158 *, void *, loff_t *);
	int (*show)(struct seq_file___158 *, void *);
};

struct cdev___64 {
	struct kobject kobj;
	struct module___137 *owner;
	const struct file_operations___233 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct poll_table_struct___125;

struct file_lock___233;

struct file_operations___233 {
	struct module___137 *owner;
	loff_t (*llseek)(struct file___233 *, loff_t, int);
	ssize_t (*read)(struct file___233 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___233 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___233 *, void *, filldir_t);
	unsigned int (*poll)(struct file___233 *, struct poll_table_struct___125 *);
	long int (*unlocked_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___233 *, struct vm_area_struct___241 *);
	int (*open)(struct inode___233 *, struct file___233 *);
	int (*flush)(struct file___233 *, fl_owner_t);
	int (*release)(struct inode___233 *, struct file___233 *);
	int (*fsync)(struct file___233 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___233 *, int);
	int (*lock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*sendpage)(struct file___233 *, struct page___232 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___233 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___233 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___233 *, long int, struct file_lock___233 **, void **);
		struct {
			int (*setlease)(struct file___233 *, long int, struct file_lock___233 **);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long int (*fallocate)(struct file___233 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___158 *, struct file___233 *);
};

struct dentry_operations___233;

struct super_block___233;

struct dentry___233 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___233 *d_parent;
	struct qstr d_name;
	struct inode___233 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___233 *d_op;
	struct super_block___233 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___233;

struct address_space___233 {
	struct inode___233 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___235 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___233 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___233;

struct dquot___233;

struct block_device___233;

struct inode___233 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___233 *i_op;
	struct super_block___233 *i_sb;
	struct address_space___233 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___235 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___233 *i_fop;
	struct file_lock___233 *i_flock;
	struct address_space___233 i_data;
	struct dquot___233 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___233 *i_bdev;
		struct cdev___64 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___233 {
	int (*d_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_hash)(const struct dentry___233 *, struct qstr *);
	int (*d_compare)(const struct dentry___233 *, const struct dentry___233 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___233 *);
	void (*d_release)(struct dentry___233 *);
	void (*d_prune)(struct dentry___233 *);
	void (*d_iput)(struct dentry___233 *, struct inode___233 *);
	char * (*d_dname)(struct dentry___233 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___233 *);
	int (*d_manage)(struct dentry___233 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___233;

struct mem_dqinfo___233 {
	struct quota_format_type___233 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___233;

struct quota_info___233 {
	unsigned int flags;
	struct mutex___235 dqio_mutex;
	struct mutex___235 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___233 *files[2];
	struct mem_dqinfo___233 info[2];
	const struct quota_format_ops___233 *ops[2];
};

struct file_system_type___233;

struct super_operations___233;

struct dquot_operations___233;

struct quotactl_ops___233;

struct super_block___233 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___233 *s_type;
	const struct super_operations___233 *s_op;
	const struct dquot_operations___233 *dq_op;
	const struct quotactl_ops___233 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___233 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___233 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___233 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___235 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___233 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___233 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___233 *bd_inode;
	struct super_block___233 *bd_super;
	struct mutex___235 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___233 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___235 bd_fsfreeze_mutex;
};

struct iattr___233 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___233 *ia_file;
};

struct dquot___233 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___235 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___233 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___233 {
	int qf_fmt_id;
	const struct quota_format_ops___233 *qf_ops;
	struct module___137 *qf_owner;
	struct quota_format_type___233 *qf_next;
};

struct quota_format_ops___233 {
	int (*check_quota_file)(struct super_block___233 *, int);
	int (*read_file_info)(struct super_block___233 *, int);
	int (*write_file_info)(struct super_block___233 *, int);
	int (*free_file_info)(struct super_block___233 *, int);
	int (*read_dqblk)(struct dquot___233 *);
	int (*commit_dqblk)(struct dquot___233 *);
	int (*release_dqblk)(struct dquot___233 *);
};

struct dquot_operations___233 {
	int (*write_dquot)(struct dquot___233 *);
	struct dquot___233 * (*alloc_dquot)(struct super_block___233 *, int);
	void (*destroy_dquot)(struct dquot___233 *);
	int (*acquire_dquot)(struct dquot___233 *);
	int (*release_dquot)(struct dquot___233 *);
	int (*mark_dirty)(struct dquot___233 *);
	int (*write_info)(struct super_block___233 *, int);
	qsize_t * (*get_reserved_space)(struct inode___233 *);
};

struct quotactl_ops___233 {
	int (*quota_on)(struct super_block___233 *, int, int, struct path___233 *);
	int (*quota_on_meta)(struct super_block___233 *, int, int);
	int (*quota_off)(struct super_block___233 *, int);
	int (*quota_sync)(struct super_block___233 *, int);
	int (*get_info)(struct super_block___233 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___233 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___233 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___233 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___233 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___233 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___233 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___233 *, unsigned int);
};

struct address_space_operations___233 {
	int (*writepage)(struct page___232 *, struct writeback_control *);
	int (*readpage)(struct file___233 *, struct page___232 *);
	int (*writepages)(struct address_space___233 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___232 *);
	int (*readpages)(struct file___233 *, struct address_space___233 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___233 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___232 **, void **);
	int (*write_end)(struct file___233 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___232 *, void *);
	sector_t (*bmap)(struct address_space___233 *, sector_t);
	void (*invalidatepage)(struct page___232 *, long unsigned int);
	int (*releasepage)(struct page___232 *, gfp_t);
	void (*freepage)(struct page___232 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___233 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___233 *, struct page___232 *, struct page___232 *, enum migrate_mode);
	int (*launder_page)(struct page___232 *);
	int (*is_partially_uptodate)(struct page___232 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___232 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___233 *, struct page___232 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___233 *, sector_t *);
	void (*swap_deactivate)(struct file___233 *);
	void (*invalidatepage_range)(struct page___232 *, unsigned int, unsigned int);
};

struct inode_operations___233 {
	struct dentry___233 * (*lookup)(struct inode___233 *, struct dentry___233 *, unsigned int);
	void * (*follow_link)(struct dentry___233 *, struct nameidata *);
	int (*permission)(struct inode___233 *, int);
	struct posix_acl * (*get_acl)(struct inode___233 *, int);
	int (*readlink)(struct dentry___233 *, char *, int);
	void (*put_link)(struct dentry___233 *, struct nameidata *, void *);
	int (*create)(struct inode___233 *, struct dentry___233 *, umode_t, bool);
	int (*link)(struct dentry___233 *, struct inode___233 *, struct dentry___233 *);
	int (*unlink)(struct inode___233 *, struct dentry___233 *);
	int (*symlink)(struct inode___233 *, struct dentry___233 *, const char *);
	int (*mkdir)(struct inode___233 *, struct dentry___233 *, umode_t);
	int (*rmdir)(struct inode___233 *, struct dentry___233 *);
	int (*mknod)(struct inode___233 *, struct dentry___233 *, umode_t, dev_t);
	int (*rename)(struct inode___233 *, struct dentry___233 *, struct inode___233 *, struct dentry___233 *);
	int (*setattr)(struct dentry___233 *, struct iattr___233 *);
	int (*getattr)(struct vfsmount *, struct dentry___233 *, struct kstat *);
	int (*setxattr)(struct dentry___233 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___233 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___233 *, char *, size_t);
	int (*removexattr)(struct dentry___233 *, const char *);
	int (*fiemap)(struct inode___233 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___233 *, struct timespec *, int);
	int (*atomic_open)(struct inode___233 *, struct dentry___233 *, struct file___233 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___233;

struct file_lock_operations___233;

struct lock_manager_operations___233;

struct file_lock___233 {
	struct file_lock___233 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___233 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___233 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___233 *fl_ops;
	const struct lock_manager_operations___233 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___233 {
	void (*fl_copy_lock)(struct file_lock___233 *, struct file_lock___233 *);
	void (*fl_release_private)(struct file_lock___233 *);
};

struct lock_manager_operations___233 {
	int (*lm_compare_owner)(struct file_lock___233 *, struct file_lock___233 *);
	long unsigned int (*lm_owner_key)(struct file_lock___233 *);
	void (*lm_notify)(struct file_lock___233 *);
	int (*lm_grant)(struct file_lock___233 *, struct file_lock___233 *, int);
	void (*lm_break)(struct file_lock___233 *);
	int (*lm_change)(struct file_lock___233 **, int);
};

struct fasync_struct___233 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___233 *fa_next;
	struct file___233 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___233 {
	const char *name;
	int fs_flags;
	struct dentry___233 * (*mount)(struct file_system_type___233 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___233 *);
	struct module___137 *owner;
	struct file_system_type___233 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___233 {
	struct inode___233 * (*alloc_inode)(struct super_block___233 *);
	void (*destroy_inode)(struct inode___233 *);
	void (*dirty_inode)(struct inode___233 *, int);
	int (*write_inode)(struct inode___233 *, struct writeback_control *);
	int (*drop_inode)(struct inode___233 *);
	void (*evict_inode)(struct inode___233 *);
	void (*put_super)(struct super_block___233 *);
	int (*sync_fs)(struct super_block___233 *, int);
	int (*freeze_fs)(struct super_block___233 *);
	int (*unfreeze_fs)(struct super_block___233 *);
	int (*statfs)(struct dentry___233 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___233 *, int *, char *);
	void (*umount_begin)(struct super_block___233 *);
	int (*show_options)(struct seq_file___158 *, struct dentry___233 *);
	int (*show_devname)(struct seq_file___158 *, struct dentry___233 *);
	int (*show_path)(struct seq_file___158 *, struct dentry___233 *);
	int (*show_stats)(struct seq_file___158 *, struct dentry___233 *);
	ssize_t (*quota_read)(struct super_block___233 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___233 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___233 *);
	int (*bdev_try_to_free_page)(struct super_block___233 *, struct page___232 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___233 *);
	void (*free_cached_objects)(struct super_block___233 *, int);
};

typedef void (*poll_queue_proc___127)(struct file___233 *, wait_queue_head_t *, struct poll_table_struct___125 *);

struct poll_table_struct___125 {
	poll_queue_proc___127 _qproc;
	long unsigned int _key;
};

struct rtc_class_ops___5 {
	int (*open)(struct device___223 *);
	void (*release)(struct device___223 *);
	int (*ioctl)(struct device___223 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___223 *, struct rtc_time *);
	int (*set_time)(struct device___223 *, struct rtc_time *);
	int (*read_alarm)(struct device___223 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___223 *, struct rtc_wkalrm *);
	int (*proc)(struct device___223 *, struct seq_file___158 *);
	int (*set_mmss)(struct device___223 *, long unsigned int);
	int (*read_callback)(struct device___223 *, int);
	int (*alarm_irq_enable)(struct device___223 *, unsigned int);
};

struct rtc_device___5 {
	struct device___223 dev;
	struct module___137 *owner;
	int id;
	char name[20];
	const struct rtc_class_ops___5 *ops;
	struct mutex___235 ops_lock;
	struct cdev___64 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___233 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
};

struct cmos_rtc_board_info {
	void (*wake_on)(struct device___223 *);
	void (*wake_off)(struct device___223 *);
	u8 rtc_day_alarm;
	u8 rtc_mon_alarm;
	u8 rtc_century;
};

struct cmos_rtc {
	struct rtc_device___5 *rtc;
	struct device___223 *dev;
	int irq;
	struct resource *iomem;
	void (*wake_on)(struct device___223 *);
	void (*wake_off)(struct device___223 *);
	u8 enabled_wake;
	u8 suspend_ctrl;
	u8 day_alrm;
	u8 mon_alrm;
	u8 century;
};

struct xol_area___232 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___232 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___215;

struct memcg_cache_params___216;

struct kmem_cache___216 {
	struct kmem_cache_cpu___215 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject kobj;
	struct memcg_cache_params___216 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct core_thread___234 {
	struct task_struct___234 *task;
	struct core_thread___234 *next;
};

struct core_state___234 {
	atomic_t nr_threads;
	struct core_thread___234 dumper;
	struct completion startup;
};

struct signal_struct___234 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___234 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___234 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___235 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_cpu___215 {
	void **freelist;
	long unsigned int tid;
	struct page___232 *page;
	struct page___232 *partial;
};

struct memcg_cache_params___216 {
	bool is_root_cache;
	union {
		struct kmem_cache___216 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___216 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct acpi_hotplug_profile___31 {
	struct kobject kobj;
	int (*scan_dependent)(struct acpi_device___31 *);
	void (*notify_online)(struct acpi_device___31 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___31 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___31 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___31 *);
	void (*bind)(struct device___223 *);
	void (*unbind)(struct device___223 *);
	struct acpi_hotplug_profile___31 hotplug;
};

struct acpi_hotplug_context___31 {
	struct acpi_device___31 *self;
	int (*notify)(struct acpi_device___31 *, u32);
	void (*uevent)(struct acpi_device___31 *, u32);
	void (*fixup)(struct acpi_device___31 *);
};

typedef int (*acpi_op_add___31)(struct acpi_device___31 *);

typedef int (*acpi_op_remove___31)(struct acpi_device___31 *);

typedef void (*acpi_op_notify___31)(struct acpi_device___31 *, u32);

struct acpi_device_ops___31 {
	acpi_op_add___31 add;
	acpi_op_remove___31 remove;
	acpi_op_notify___31 notify;
};

struct acpi_driver___31 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___31 ops;
	struct device_driver___223 drv;
	struct module___137 *owner;
};

struct pnp_protocol___6;

struct pnp_card___6 {
	struct device___223 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___6 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___6;

struct pnp_protocol___6 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___6 *);
	int (*set)(struct pnp_dev___6 *);
	int (*disable)(struct pnp_dev___6 *);
	bool (*can_wakeup)(struct pnp_dev___6 *);
	int (*suspend)(struct pnp_dev___6 *, pm_message_t);
	int (*resume)(struct pnp_dev___6 *);
	unsigned char number;
	struct device___223 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___6;

struct pnp_card_link___6 {
	struct pnp_card___6 *card;
	struct pnp_card_driver___6 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___6 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___6 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___6 *);
	void (*shutdown)(struct pnp_dev___6 *);
	int (*suspend)(struct pnp_dev___6 *, pm_message_t);
	int (*resume)(struct pnp_dev___6 *);
	struct device_driver___223 driver;
};

struct pnp_card_driver___6 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___6 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___6 *);
	int (*suspend)(struct pnp_card_link___6 *, pm_message_t);
	int (*resume)(struct pnp_card_link___6 *);
	struct pnp_driver___6 link;
};

struct pnp_dev___6 {
	struct device___223 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___6 *protocol;
	struct pnp_card___6 *card;
	struct pnp_driver___6 *driver;
	struct pnp_card_link___6 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct i2c_board_info {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	void *platform_data;
	struct dev_archdata___71 *archdata;
	struct device_node___10 *of_node;
	struct acpi_dev_node___26 acpi_node;
	int irq;
};

struct i2c_devinfo {
	struct list_head list;
	int busnum;
	struct i2c_board_info board_info;
};

struct powercap_control_type;

struct powercap_control_type_ops {
	int (*set_enable)(struct powercap_control_type *, bool);
	int (*get_enable)(struct powercap_control_type *, bool *);
	int (*release)(struct powercap_control_type *);
};

struct powercap_control_type {
	struct device___223 dev;
	struct idr idr;
	int nr_zones;
	const struct powercap_control_type_ops *ops;
	struct mutex___235 lock;
	bool allocated;
	struct list_head node;
};

struct powercap_zone;

struct powercap_zone_ops {
	int (*get_max_energy_range_uj)(struct powercap_zone *, u64 *);
	int (*get_energy_uj)(struct powercap_zone *, u64 *);
	int (*reset_energy_uj)(struct powercap_zone *);
	int (*get_max_power_range_uw)(struct powercap_zone *, u64 *);
	int (*get_power_uw)(struct powercap_zone *, u64 *);
	int (*set_enable)(struct powercap_zone *, bool);
	int (*get_enable)(struct powercap_zone *, bool *);
	int (*release)(struct powercap_zone *);
};

struct powercap_zone_constraint;

struct powercap_zone {
	int id;
	char *name;
	void *control_type_inst;
	const struct powercap_zone_ops *ops;
	struct device___223 dev;
	int const_id_cnt;
	struct idr idr;
	struct idr *parent_idr;
	void *private_data;
	struct attribute **zone_dev_attrs;
	int zone_attr_count;
	struct attribute_group___192 dev_zone_attr_group;
	const struct attribute_group___192 *dev_attr_groups[2];
	bool allocated;
	struct powercap_zone_constraint *constraints;
};

struct powercap_zone_constraint_ops;

struct powercap_zone_constraint {
	int id;
	struct powercap_zone *power_zone;
	struct powercap_zone_constraint_ops *ops;
};

struct powercap_zone_constraint_ops {
	int (*set_power_limit_uw)(struct powercap_zone *, int, u64);
	int (*get_power_limit_uw)(struct powercap_zone *, int, u64 *);
	int (*set_time_window_us)(struct powercap_zone *, int, u64);
	int (*get_time_window_us)(struct powercap_zone *, int, u64 *);
	int (*get_max_power_uw)(struct powercap_zone *, int, u64 *);
	int (*get_min_power_uw)(struct powercap_zone *, int, u64 *);
	int (*get_max_time_window_us)(struct powercap_zone *, int, u64 *);
	int (*get_min_time_window_us)(struct powercap_zone *, int, u64 *);
	const char * (*get_name)(struct powercap_zone *, int);
};

struct powercap_constraint_attr {
	struct device_attribute___223 power_limit_attr;
	struct device_attribute___223 time_window_attr;
	struct device_attribute___223 max_power_attr;
	struct device_attribute___223 min_power_attr;
	struct device_attribute___223 max_time_window_attr;
	struct device_attribute___223 min_time_window_attr;
	struct device_attribute___223 name_attr;
};

typedef void (*dr_release_t___11)(struct device___210 *, void *);

typedef int (*dr_match_t___11)(struct device___210 *, void *, void *);

struct hwmon_device {
	const char *name;
	struct device___210 dev;
};

struct page___233;

typedef struct page___233 *pgtable_t___233;

struct address_space___234;

struct kmem_cache___217;

struct page___233 {
	long unsigned int flags;
	struct address_space___234 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___233 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___233 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___217 *slab_cache;
		struct page___233 *first_page;
	};
	long: 64;
};

struct task_struct___235;

struct pv_cpu_ops___235 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___235 *);
	void (*end_context_switch)(struct task_struct___235 *);
};

struct mutex___236 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___235 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___228 {
	struct page___233 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___242;

struct nsproxy___118;

struct signal_struct___235;

struct task_struct___235 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___235 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___242 *mm;
	struct mm_struct___242 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___235 *real_parent;
	struct task_struct___235 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___235 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___235 = 0,
		VTIME_USER___235 = 1,
		VTIME_SYS___235 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___118 *nsproxy;
	struct signal_struct___235 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___236 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___228 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___242 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___242 *, struct mm_struct___242 *);
	void (*dup_mmap)(struct mm_struct___242 *, struct mm_struct___242 *);
	void (*exit_mmap)(struct mm_struct___242 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___242 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___242 *);
	void (*pgd_free)(struct mm_struct___242 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___242 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___242 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___242 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___242 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___242 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___242 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___242 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___242 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___242 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___242 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___242 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___236 lock;
	void *vdso;
} mm_context_t___236;

struct xol_area___233;

struct uprobes_state___233 {
	struct xol_area___233 *xol_area;
};

struct vm_area_struct___242;

struct file___234;

struct core_state___235;

struct mm_struct___242 {
	struct vm_area_struct___242 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___242 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___242 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___236 context;
	long unsigned int flags;
	struct core_state___235 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___235 *owner;
	struct file___234 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___233 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___138;

struct module_kobject___137 {
	struct kobject___24 kobj;
	struct module___138 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___137;

struct module___138 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___137 mkobj;
	struct module_attribute___137 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___235 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___235;

struct lruvec___235 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___235 *zone;
};

struct pglist_data___235;

struct zone___235 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___235 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___235 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___235 {
	struct zone___235 *zone;
	int zone_idx;
};

struct zonelist___235 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___235 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___235 {
	struct zone___235 node_zones[4];
	struct zonelist___235 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___235 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___154;

struct x86_io_apic_ops___154 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___154 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___154;

struct irq_data___154 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___154 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___224;

struct dev_pm_ops___224 {
	int (*prepare)(struct device___224 *);
	void (*complete)(struct device___224 *);
	int (*suspend)(struct device___224 *);
	int (*resume)(struct device___224 *);
	int (*freeze)(struct device___224 *);
	int (*thaw)(struct device___224 *);
	int (*poweroff)(struct device___224 *);
	int (*restore)(struct device___224 *);
	int (*suspend_late)(struct device___224 *);
	int (*resume_early)(struct device___224 *);
	int (*freeze_late)(struct device___224 *);
	int (*thaw_early)(struct device___224 *);
	int (*poweroff_late)(struct device___224 *);
	int (*restore_early)(struct device___224 *);
	int (*suspend_noirq)(struct device___224 *);
	int (*resume_noirq)(struct device___224 *);
	int (*freeze_noirq)(struct device___224 *);
	int (*thaw_noirq)(struct device___224 *);
	int (*poweroff_noirq)(struct device___224 *);
	int (*restore_noirq)(struct device___224 *);
	int (*runtime_suspend)(struct device___224 *);
	int (*runtime_resume)(struct device___224 *);
	int (*runtime_idle)(struct device___224 *);
};

struct dma_map_ops___94;

struct dev_archdata___94 {
	struct dma_map_ops___94 *dma_ops;
	void *iommu;
};

struct device_type___224;

struct bus_type___224;

struct device_driver___224;

struct dev_pm_domain___224;

struct class___224;

struct attribute_group___193;

struct device_rh___224;

struct device___224 {
	struct device___224 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___224 *type;
	struct mutex___236 mutex;
	struct bus_type___224 *bus;
	struct device_driver___224 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___224 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___94 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___37 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___224 *class;
	const struct attribute_group___193 **groups;
	void (*release)(struct device___224 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___224 *device_rh;
};

struct dev_pm_info_rh___224 {
	void (*set_latency_tolerance)(struct device___224 *, s32);
};

struct dev_pm_domain___224 {
	struct dev_pm_ops___224 ops;
};

struct smp_ops___235 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___235 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___44;

struct ctl_node___44 {
	struct rb_node node;
	struct ctl_table_header___44 *header;
};

struct ctl_table_root___44;

struct ctl_table_set___44;

struct ctl_dir___44;

struct ctl_table_header___44 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___44 *root;
	struct ctl_table_set___44 *set;
	struct ctl_dir___44 *parent;
	struct ctl_node___44 *node;
};

struct ctl_dir___44 {
	struct ctl_table_header___44 header;
	struct rb_root root;
};

struct ctl_table_set___44 {
	int (*is_seen)(struct ctl_table_set___44 *);
	struct ctl_dir___44 dir;
};

struct ctl_table_root___44 {
	struct ctl_table_set___44 default_set;
	struct ctl_table_set___44 * (*lookup)(struct ctl_table_root___44 *, struct nsproxy___118 *);
	int (*permissions)(struct ctl_table_header___44 *, struct ctl_table *);
};

struct net___43;

struct nsproxy___118 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___43 *net_ns;
};

struct bin_attribute___195;

struct attribute_group___193 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___195 **bin_attrs;
};

struct bin_attribute___195 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___234 *, struct kobject___24 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___234 *, struct kobject___24 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	int (*mmap)(struct file___234 *, struct kobject___24 *, struct bin_attribute___195 *, struct vm_area_struct___242 *);
};

struct dentry___234;

struct path___234 {
	struct vfsmount *mnt;
	struct dentry___234 *dentry;
};

struct inode___234;

struct file_operations___234;

struct file___234 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___234 f_path;
	struct inode___234 *f_inode;
	const struct file_operations___234 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___234 *f_mapping;
	struct mutex___236 f_pos_lock;
};

struct vm_operations_struct___208;

struct vm_area_struct___242 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___242 *vm_next;
	struct vm_area_struct___242 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___242 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___208 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___234 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___137 *, struct module_kobject___137 *, char *);
	ssize_t (*store)(struct module_attribute___137 *, struct module_kobject___137 *, const char *, size_t);
	void (*setup)(struct module___138 *, const char *);
	int (*test)(struct module___138 *);
	void (*free)(struct module___138 *);
};

struct dma_map_ops___94 {
	void * (*alloc)(struct device___224 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___224 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___224 *, struct vm_area_struct___242 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___224 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___224 *, struct page___233 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___224 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___224 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___224 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___224 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___224 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___224 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___224 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___224 *, dma_addr_t);
	int (*dma_supported)(struct device___224 *, u64);
	int (*set_dma_mask)(struct device___224 *, u64);
	int is_phys;
};

struct bus_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___224 *, char *);
	ssize_t (*store)(struct bus_type___224 *, const char *, size_t);
};

struct device_attribute___224;

struct driver_attribute___224;

struct bus_type___224 {
	const char *name;
	const char *dev_name;
	struct device___224 *dev_root;
	struct bus_attribute___224 *bus_attrs;
	struct device_attribute___224 *dev_attrs;
	struct driver_attribute___224 *drv_attrs;
	const struct attribute_group___193 **bus_groups;
	const struct attribute_group___193 **dev_groups;
	const struct attribute_group___193 **drv_groups;
	int (*match)(struct device___224 *, struct device_driver___224 *);
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	int (*probe)(struct device___224 *);
	int (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*online)(struct device___224 *);
	int (*offline)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct device___224 *, struct device_attribute___224 *, char *);
	ssize_t (*store)(struct device___224 *, struct device_attribute___224 *, const char *, size_t);
};

struct driver_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___224 *, char *);
	ssize_t (*store)(struct device_driver___224 *, const char *, size_t);
};

struct device_driver___224 {
	const char *name;
	struct bus_type___224 *bus;
	struct module___138 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___224 *);
	int (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	const struct attribute_group___193 **groups;
	const struct dev_pm_ops___224 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___224 {
	const char *name;
	const struct attribute_group___193 **groups;
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
};

struct class_attribute___224;

struct class___224 {
	const char *name;
	struct module___138 *owner;
	struct class_attribute___224 *class_attrs;
	struct device_attribute___224 *dev_attrs;
	const struct attribute_group___193 **dev_groups;
	struct bin_attribute___195 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *);
	void (*class_release)(struct class___224 *);
	void (*dev_release)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
	struct subsys_private *p;
};

struct class_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct class___224 *, struct class_attribute___224 *, char *);
	ssize_t (*store)(struct class___224 *, struct class_attribute___224 *, const char *, size_t);
	const void * (*namespace)(struct class___224 *, const struct class_attribute___224 *);
};

struct device_rh___224 {
	struct dev_pm_info_rh___224 power;
};

struct kmem_cache_cpu___216 {
	void **freelist;
	long unsigned int tid;
	struct page___233 *page;
	struct page___233 *partial;
};

struct memcg_cache_params___217;

struct kmem_cache___217 {
	struct kmem_cache_cpu___216 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___217 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___217 {
	bool is_root_cache;
	union {
		struct kmem_cache___217 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___217 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

enum events {
	THERMAL_AUX0 = 0,
	THERMAL_AUX1 = 1,
	THERMAL_CRITICAL = 2,
	THERMAL_DEV_FAULT = 3,
};

enum {
	THERMAL_GENL_ATTR_UNSPEC = 0,
	THERMAL_GENL_ATTR_EVENT = 1,
	__THERMAL_GENL_ATTR_MAX = 2,
};

enum {
	THERMAL_GENL_CMD_UNSPEC = 0,
	THERMAL_GENL_CMD_EVENT = 1,
	__THERMAL_GENL_CMD_MAX = 2,
};

struct thermal_zone_device___2;

struct thermal_cooling_device___3;

struct thermal_zone_device_ops___2 {
	int (*bind)(struct thermal_zone_device___2 *, struct thermal_cooling_device___3 *);
	int (*unbind)(struct thermal_zone_device___2 *, struct thermal_cooling_device___3 *);
	int (*get_temp)(struct thermal_zone_device___2 *, long unsigned int *);
	int (*get_mode)(struct thermal_zone_device___2 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___2 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___2 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___2 *, int, long unsigned int *);
	int (*set_trip_temp)(struct thermal_zone_device___2 *, int, long unsigned int);
	int (*get_trip_hyst)(struct thermal_zone_device___2 *, int, long unsigned int *);
	int (*set_trip_hyst)(struct thermal_zone_device___2 *, int, long unsigned int);
	int (*get_crit_temp)(struct thermal_zone_device___2 *, long unsigned int *);
	int (*set_emul_temp)(struct thermal_zone_device___2 *, long unsigned int);
	int (*get_trend)(struct thermal_zone_device___2 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___2 *, int, enum thermal_trip_type);
};

struct thermal_attr___2;

struct thermal_zone_params___2;

struct thermal_governor___2;

struct thermal_zone_device___2 {
	int id;
	char type[20];
	struct device___224 device;
	struct thermal_attr___2 *trip_temp_attrs;
	struct thermal_attr___2 *trip_type_attrs;
	struct thermal_attr___2 *trip_hyst_attrs;
	void *devdata;
	int trips;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	unsigned int forced_passive;
	const struct thermal_zone_device_ops___2 *ops;
	const struct thermal_zone_params___2 *tzp;
	struct thermal_governor___2 *governor;
	struct list_head thermal_instances;
	struct idr idr;
	struct mutex___236 lock;
	struct list_head node;
	struct delayed_work poll_queue;
};

struct thermal_cooling_device_ops___3;

struct thermal_cooling_device___3 {
	int id;
	char type[20];
	struct device___224 device;
	void *devdata;
	const struct thermal_cooling_device_ops___3 *ops;
	bool updated;
	struct mutex___236 lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___3 {
	int (*get_max_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___3 *, long unsigned int);
};

struct thermal_attr___2 {
	struct device_attribute___224 attr;
	char name[20];
};

struct thermal_bind_params___2;

struct thermal_zone_params___2 {
	char governor_name[20];
	int num_tbps;
	struct thermal_bind_params___2 *tbp;
};

struct thermal_governor___2 {
	char name[20];
	int (*throttle)(struct thermal_zone_device___2 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___2 {
	struct thermal_cooling_device___3 *cdev;
	int weight;
	int trip_mask;
	int (*match)(struct thermal_zone_device___2 *, struct thermal_cooling_device___3 *);
};

struct thermal_genl_event {
	u32 orig;
	enum events event;
};

struct xol_area___233 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___233 *page;
	long unsigned int vaddr;
};

struct address_space_operations___234;

struct address_space___234 {
	struct inode___234 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___236 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___234 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___204;

struct vm_operations_struct___208 {
	void (*open)(struct vm_area_struct___242 *);
	void (*close)(struct vm_area_struct___242 *);
	int (*fault)(struct vm_area_struct___242 *, struct vm_fault___204 *);
	int (*page_mkwrite)(struct vm_area_struct___242 *, struct vm_fault___204 *);
	int (*access)(struct vm_area_struct___242 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___242 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___242 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___242 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___242 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___235 {
	struct task_struct___235 *task;
	struct core_thread___235 *next;
};

struct core_state___235 {
	atomic_t nr_threads;
	struct core_thread___235 dumper;
	struct completion startup;
};

struct fasync_struct___234 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___234 *fa_next;
	struct file___234 *fa_file;
	struct callback_head fa_rcu;
};

struct netns_core___41 {
	struct ctl_table_header___44 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___41 {
	struct mutex___236 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___41 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___44 *ctl;
};

struct netns_ipv4___41 {
	struct ctl_table_header___44 *forw_hdr;
	struct ctl_table_header___44 *frags_hdr;
	struct ctl_table_header___44 *ipv4_hdr;
	struct ctl_table_header___44 *route_hdr;
	struct ctl_table_header___44 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___41 {
	struct ctl_table_header___44 *hdr;
	struct ctl_table_header___44 *route_hdr;
	struct ctl_table_header___44 *icmp_hdr;
	struct ctl_table_header___44 *frags_hdr;
	struct ctl_table_header___44 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_ops___42 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___42 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *);
	int (*local_out)(struct sk_buff___26 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___26 *, const void *);
	struct kmem_cache___217 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___42 {
	struct netns_sysctl_ipv6___41 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___42 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___41 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___44 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___41 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___44 *nf_log_dir_header;
};

struct nf_proto_net___41 {
	struct ctl_table_header___44 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___41 {
	struct nf_proto_net___41 pn;
	unsigned int timeout;
};

struct nf_tcp_net___41 {
	struct nf_proto_net___41 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___41 {
	struct nf_proto_net___41 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___41 {
	struct nf_proto_net___41 pn;
	unsigned int timeout;
};

struct nf_ip_net___41 {
	struct nf_generic_net___41 generic;
	struct nf_tcp_net___41 tcp;
	struct nf_udp_net___41 udp;
	struct nf_icmp_net___41 icmp;
	struct nf_icmp_net___41 icmpv6;
};

struct netns_ct___41 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___44 *sysctl_header;
	struct ctl_table_header___44 *acct_sysctl_header;
	struct ctl_table_header___44 *tstamp_sysctl_header;
	struct ctl_table_header___44 *event_sysctl_header;
	struct ctl_table_header___44 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___217 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___41 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___41 {
	struct netns_sysctl_ipv6___41 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___42 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___44 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___42 xfrm4_dst_ops;
	struct dst_ops___42 xfrm6_dst_ops;
};

struct net___43 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___44 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___41 core;
	struct netns_mib mib;
	struct netns_packet___41 packet;
	struct netns_unix___41 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___41 ipv4;
	struct netns_ipv6___42 ipv6;
	struct netns_sctp___41 sctp;
	struct netns_dccp___21 dccp;
	struct netns_nf___41 nf;
	struct netns_xt xt;
	struct netns_ct___41 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___41 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___24 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___42 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___236 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___236 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___204 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___233 *page;
};

struct signal_struct___235 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___235 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___235 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___236 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___234;

struct super_block___234;

struct file_lock___234;

struct dquot___234;

struct block_device___234;

struct inode___234 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___234 *i_op;
	struct super_block___234 *i_sb;
	struct address_space___234 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___236 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___234 *i_fop;
	struct file_lock___234 *i_flock;
	struct address_space___234 i_data;
	struct dquot___234 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___234 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___234;

struct mem_dqinfo___234 {
	struct quota_format_type___234 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___234;

struct quota_info___234 {
	unsigned int flags;
	struct mutex___236 dqio_mutex;
	struct mutex___236 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___234 *files[2];
	struct mem_dqinfo___234 info[2];
	const struct quota_format_ops___234 *ops[2];
};

struct file_system_type___234;

struct super_operations___234;

struct dquot_operations___234;

struct quotactl_ops___234;

struct dentry_operations___234;

struct super_block___234 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___234 *s_type;
	const struct super_operations___234 *s_op;
	const struct dquot_operations___234 *dq_op;
	const struct quotactl_ops___234 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___234 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___234 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___234 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___236 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___234 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___234 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___234 *d_parent;
	struct qstr d_name;
	struct inode___234 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___234 *d_op;
	struct super_block___234 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct seq_operations___159;

struct seq_file___159 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___236 lock;
	const struct seq_operations___159 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct iattr___234 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___234 *ia_file;
};

struct netlink_callback___31 {
	struct sk_buff___26 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___26 *, struct netlink_callback___31 *);
	int (*done)(struct netlink_callback___31 *);
	void *data;
	struct module___138 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct dentry_operations___234 {
	int (*d_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_hash)(const struct dentry___234 *, struct qstr *);
	int (*d_compare)(const struct dentry___234 *, const struct dentry___234 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___234 *);
	void (*d_release)(struct dentry___234 *);
	void (*d_prune)(struct dentry___234 *);
	void (*d_iput)(struct dentry___234 *, struct inode___234 *);
	char * (*d_dname)(struct dentry___234 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___234 *);
	int (*d_manage)(struct dentry___234 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___234 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___234 *bd_inode;
	struct super_block___234 *bd_super;
	struct mutex___236 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___234 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___236 bd_fsfreeze_mutex;
};

struct dquot___234 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___236 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___234 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___234 {
	int qf_fmt_id;
	const struct quota_format_ops___234 *qf_ops;
	struct module___138 *qf_owner;
	struct quota_format_type___234 *qf_next;
};

struct quota_format_ops___234 {
	int (*check_quota_file)(struct super_block___234 *, int);
	int (*read_file_info)(struct super_block___234 *, int);
	int (*write_file_info)(struct super_block___234 *, int);
	int (*free_file_info)(struct super_block___234 *, int);
	int (*read_dqblk)(struct dquot___234 *);
	int (*commit_dqblk)(struct dquot___234 *);
	int (*release_dqblk)(struct dquot___234 *);
};

struct dquot_operations___234 {
	int (*write_dquot)(struct dquot___234 *);
	struct dquot___234 * (*alloc_dquot)(struct super_block___234 *, int);
	void (*destroy_dquot)(struct dquot___234 *);
	int (*acquire_dquot)(struct dquot___234 *);
	int (*release_dquot)(struct dquot___234 *);
	int (*mark_dirty)(struct dquot___234 *);
	int (*write_info)(struct super_block___234 *, int);
	qsize_t * (*get_reserved_space)(struct inode___234 *);
};

struct quotactl_ops___234 {
	int (*quota_on)(struct super_block___234 *, int, int, struct path___234 *);
	int (*quota_on_meta)(struct super_block___234 *, int, int);
	int (*quota_off)(struct super_block___234 *, int);
	int (*quota_sync)(struct super_block___234 *, int);
	int (*get_info)(struct super_block___234 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___234 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___234 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___234 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___234 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___234 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___234 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___234 *, unsigned int);
};

struct address_space_operations___234 {
	int (*writepage)(struct page___233 *, struct writeback_control *);
	int (*readpage)(struct file___234 *, struct page___233 *);
	int (*writepages)(struct address_space___234 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___233 *);
	int (*readpages)(struct file___234 *, struct address_space___234 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___234 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___233 **, void **);
	int (*write_end)(struct file___234 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___233 *, void *);
	sector_t (*bmap)(struct address_space___234 *, sector_t);
	void (*invalidatepage)(struct page___233 *, long unsigned int);
	int (*releasepage)(struct page___233 *, gfp_t);
	void (*freepage)(struct page___233 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___234 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___234 *, struct page___233 *, struct page___233 *, enum migrate_mode);
	int (*launder_page)(struct page___233 *);
	int (*is_partially_uptodate)(struct page___233 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___233 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___234 *, struct page___233 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___234 *, sector_t *);
	void (*swap_deactivate)(struct file___234 *);
	void (*invalidatepage_range)(struct page___233 *, unsigned int, unsigned int);
};

struct inode_operations___234 {
	struct dentry___234 * (*lookup)(struct inode___234 *, struct dentry___234 *, unsigned int);
	void * (*follow_link)(struct dentry___234 *, struct nameidata *);
	int (*permission)(struct inode___234 *, int);
	struct posix_acl * (*get_acl)(struct inode___234 *, int);
	int (*readlink)(struct dentry___234 *, char *, int);
	void (*put_link)(struct dentry___234 *, struct nameidata *, void *);
	int (*create)(struct inode___234 *, struct dentry___234 *, umode_t, bool);
	int (*link)(struct dentry___234 *, struct inode___234 *, struct dentry___234 *);
	int (*unlink)(struct inode___234 *, struct dentry___234 *);
	int (*symlink)(struct inode___234 *, struct dentry___234 *, const char *);
	int (*mkdir)(struct inode___234 *, struct dentry___234 *, umode_t);
	int (*rmdir)(struct inode___234 *, struct dentry___234 *);
	int (*mknod)(struct inode___234 *, struct dentry___234 *, umode_t, dev_t);
	int (*rename)(struct inode___234 *, struct dentry___234 *, struct inode___234 *, struct dentry___234 *);
	int (*setattr)(struct dentry___234 *, struct iattr___234 *);
	int (*getattr)(struct vfsmount *, struct dentry___234 *, struct kstat *);
	int (*setxattr)(struct dentry___234 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___234 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___234 *, char *, size_t);
	int (*removexattr)(struct dentry___234 *, const char *);
	int (*fiemap)(struct inode___234 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___234 *, struct timespec *, int);
	int (*atomic_open)(struct inode___234 *, struct dentry___234 *, struct file___234 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___234 {
	struct module___138 *owner;
	loff_t (*llseek)(struct file___234 *, loff_t, int);
	ssize_t (*read)(struct file___234 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___234 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___234 *, void *, filldir_t);
	unsigned int (*poll)(struct file___234 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___234 *, struct vm_area_struct___242 *);
	int (*open)(struct inode___234 *, struct file___234 *);
	int (*flush)(struct file___234 *, fl_owner_t);
	int (*release)(struct inode___234 *, struct file___234 *);
	int (*fsync)(struct file___234 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___234 *, int);
	int (*lock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*sendpage)(struct file___234 *, struct page___233 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___234 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___234 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___234 *, long int, struct file_lock___234 **, void **);
		struct {
			int (*setlease)(struct file___234 *, long int, struct file_lock___234 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___234 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___159 *, struct file___234 *);
};

struct file_lock_operations___234;

struct lock_manager_operations___234;

struct file_lock___234 {
	struct file_lock___234 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___234 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___234 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___234 *fl_ops;
	const struct lock_manager_operations___234 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___234 {
	void (*fl_copy_lock)(struct file_lock___234 *, struct file_lock___234 *);
	void (*fl_release_private)(struct file_lock___234 *);
};

struct lock_manager_operations___234 {
	int (*lm_compare_owner)(struct file_lock___234 *, struct file_lock___234 *);
	long unsigned int (*lm_owner_key)(struct file_lock___234 *);
	void (*lm_notify)(struct file_lock___234 *);
	int (*lm_grant)(struct file_lock___234 *, struct file_lock___234 *, int);
	void (*lm_break)(struct file_lock___234 *);
	int (*lm_change)(struct file_lock___234 **, int);
};

struct file_system_type___234 {
	const char *name;
	int fs_flags;
	struct dentry___234 * (*mount)(struct file_system_type___234 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___234 *);
	struct module___138 *owner;
	struct file_system_type___234 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___234 {
	struct inode___234 * (*alloc_inode)(struct super_block___234 *);
	void (*destroy_inode)(struct inode___234 *);
	void (*dirty_inode)(struct inode___234 *, int);
	int (*write_inode)(struct inode___234 *, struct writeback_control *);
	int (*drop_inode)(struct inode___234 *);
	void (*evict_inode)(struct inode___234 *);
	void (*put_super)(struct super_block___234 *);
	int (*sync_fs)(struct super_block___234 *, int);
	int (*freeze_fs)(struct super_block___234 *);
	int (*unfreeze_fs)(struct super_block___234 *);
	int (*statfs)(struct dentry___234 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___234 *, int *, char *);
	void (*umount_begin)(struct super_block___234 *);
	int (*show_options)(struct seq_file___159 *, struct dentry___234 *);
	int (*show_devname)(struct seq_file___159 *, struct dentry___234 *);
	int (*show_path)(struct seq_file___159 *, struct dentry___234 *);
	int (*show_stats)(struct seq_file___159 *, struct dentry___234 *);
	ssize_t (*quota_read)(struct super_block___234 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___234 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___234 *);
	int (*bdev_try_to_free_page)(struct super_block___234 *, struct page___233 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___234 *);
	void (*free_cached_objects)(struct super_block___234 *, int);
};

struct nf_afinfo___42 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___26 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___26 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___43 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___26 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___26 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___154 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___154 *);
	void (*irq_shutdown)(struct irq_data___154 *);
	void (*irq_enable)(struct irq_data___154 *);
	void (*irq_disable)(struct irq_data___154 *);
	void (*irq_ack)(struct irq_data___154 *);
	void (*irq_mask)(struct irq_data___154 *);
	void (*irq_mask_ack)(struct irq_data___154 *);
	void (*irq_unmask)(struct irq_data___154 *);
	void (*irq_eoi)(struct irq_data___154 *);
	int (*irq_set_affinity)(struct irq_data___154 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___154 *);
	int (*irq_set_type)(struct irq_data___154 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___154 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___154 *);
	void (*irq_bus_sync_unlock)(struct irq_data___154 *);
	void (*irq_cpu_online)(struct irq_data___154 *);
	void (*irq_cpu_offline)(struct irq_data___154 *);
	void (*irq_suspend)(struct irq_data___154 *);
	void (*irq_resume)(struct irq_data___154 *);
	void (*irq_pm_shutdown)(struct irq_data___154 *);
	void (*irq_print_chip)(struct irq_data___154 *, struct seq_file___159 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___154 *, void *);
	long unsigned int flags;
};

struct seq_operations___159 {
	void * (*start)(struct seq_file___159 *, loff_t *);
	void (*stop)(struct seq_file___159 *, void *);
	void * (*next)(struct seq_file___159 *, void *, loff_t *);
	int (*show)(struct seq_file___159 *, void *);
};

struct genl_ops___4;

struct genl_info___4;

struct genl_family___4 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___4 *, struct sk_buff___26 *, struct genl_info___4 *);
	void (*post_doit)(const struct genl_ops___4 *, struct sk_buff___26 *, struct genl_info___4 *);
	struct nlattr **attrbuf;
	const struct genl_ops___4 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module___138 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___4 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___26 *, struct genl_info___4 *);
	int (*dumpit)(struct sk_buff___26 *, struct netlink_callback___31 *);
	int (*done)(struct netlink_callback___31 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___4 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___43 *_net;
	void *user_ptr[2];
	struct sock *dst_sk;
};

struct thermal_instance {
	int id;
	char name[20];
	struct thermal_zone_device___2 *tz;
	struct thermal_cooling_device___3 *cdev;
	int trip;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___224 attr;
	struct list_head tz_node;
	struct list_head cdev_node;
};

struct thermal_hwmon_device {
	char type[20];
	struct device___224 *device;
	int count;
	struct list_head tz_list;
	struct list_head node;
};

struct thermal_hwmon_attr {
	struct device_attribute___224 attr;
	char name[16];
};

struct thermal_hwmon_temp {
	struct list_head hwmon_node;
	struct thermal_zone_device___2 *tz;
	struct thermal_hwmon_attr temp_input;
	struct thermal_hwmon_attr temp_crit;
};

struct watchdog_info {
	__u32 options;
	__u32 firmware_version;
	__u8 identity[32];
};

struct watchdog_device;

struct watchdog_ops {
	struct module___138 *owner;
	int (*start)(struct watchdog_device *);
	int (*stop)(struct watchdog_device *);
	int (*ping)(struct watchdog_device *);
	unsigned int (*status)(struct watchdog_device *);
	int (*set_timeout)(struct watchdog_device *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device *);
	void (*ref)(struct watchdog_device *);
	void (*unref)(struct watchdog_device *);
	long int (*ioctl)(struct watchdog_device *, unsigned int, long unsigned int);
};

struct watchdog_device {
	int id;
	struct cdev___64 cdev;
	struct device___224 *dev;
	struct device___224 *parent;
	const struct watchdog_info *info;
	const struct watchdog_ops *ops;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	void *driver_data;
	struct mutex___236 lock;
	long unsigned int status;
};

struct watchdog_device___2;

struct watchdog_ops___2 {
	struct module___138 *owner;
	int (*start)(struct watchdog_device___2 *);
	int (*stop)(struct watchdog_device___2 *);
	int (*ping)(struct watchdog_device___2 *);
	unsigned int (*status)(struct watchdog_device___2 *);
	int (*set_timeout)(struct watchdog_device___2 *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device___2 *);
	void (*ref)(struct watchdog_device___2 *);
	void (*unref)(struct watchdog_device___2 *);
	long int (*ioctl)(struct watchdog_device___2 *, unsigned int, long unsigned int);
};

struct watchdog_device___2 {
	int id;
	struct cdev___60 cdev;
	struct device___218 *dev;
	struct device___218 *parent;
	const struct watchdog_info *info;
	const struct watchdog_ops___2 *ops;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	void *driver_data;
	struct mutex___236 lock;
	long unsigned int status;
};

struct page___234;

typedef struct page___234 *pgtable_t___234;

struct address_space___235;

struct kmem_cache___218;

struct page___234 {
	long unsigned int flags;
	struct address_space___235 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___234 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___234 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___218 *slab_cache;
		struct page___234 *first_page;
	};
	long: 64;
};

struct task_struct___236;

struct pv_cpu_ops___236 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___236 *);
	void (*end_context_switch)(struct task_struct___236 *);
};

struct mutex___237 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___236 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___229 {
	struct page___234 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___243;

struct signal_struct___236;

struct bio_list___50;

struct backing_dev_info___61;

struct io_context___50;

struct task_struct___236 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___236 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___243 *mm;
	struct mm_struct___243 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___236 *real_parent;
	struct task_struct___236 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___236 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___236 = 0,
		VTIME_USER___236 = 1,
		VTIME_SYS___236 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___236 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___50 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___61 *backing_dev_info;
	struct io_context___50 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___237 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___229 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___243 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___243 *, struct mm_struct___243 *);
	void (*dup_mmap)(struct mm_struct___243 *, struct mm_struct___243 *);
	void (*exit_mmap)(struct mm_struct___243 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___243 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___243 *);
	void (*pgd_free)(struct mm_struct___243 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___243 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___243 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___243 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___243 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___243 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___243 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___243 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___243 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___243 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___243 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___243 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___237 lock;
	void *vdso;
} mm_context_t___237;

struct xol_area___234;

struct uprobes_state___234 {
	struct xol_area___234 *xol_area;
};

struct vm_area_struct___243;

struct file___235;

struct core_state___236;

struct mm_struct___243 {
	struct vm_area_struct___243 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___243 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___243 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___237 context;
	long unsigned int flags;
	struct core_state___236 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___236 *owner;
	struct file___235 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___234 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___139;

struct exec_domain___63 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___139 *module;
	struct exec_domain___63 *next;
};

struct module_kobject___138 {
	struct kobject___24 kobj;
	struct module___139 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___138;

struct module___139 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___138 mkobj;
	struct module_attribute___138 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___236 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___106 {
	struct task_struct___236 *task;
	struct exec_domain___63 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___234 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___234 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___217;

struct memcg_cache_params___218;

struct kmem_cache___218 {
	struct kmem_cache_cpu___217 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___218 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___235;

struct address_space_operations___235;

struct address_space___235 {
	struct inode___235 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___237 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___235 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___61 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___235;

struct path___235 {
	struct vfsmount *mnt;
	struct dentry___235 *dentry;
};

struct file_operations___235;

struct file___235 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___235 f_path;
	struct inode___235 *f_inode;
	const struct file_operations___235 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___235 *f_mapping;
	struct mutex___237 f_pos_lock;
};

struct vm_operations_struct___209;

struct vm_area_struct___243 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___243 *vm_next;
	struct vm_area_struct___243 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___243 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___209 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___235 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___205;

struct vm_operations_struct___209 {
	void (*open)(struct vm_area_struct___243 *);
	void (*close)(struct vm_area_struct___243 *);
	int (*fault)(struct vm_area_struct___243 *, struct vm_fault___205 *);
	int (*page_mkwrite)(struct vm_area_struct___243 *, struct vm_fault___205 *);
	int (*access)(struct vm_area_struct___243 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___243 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___243 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___243 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___243 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___236 {
	struct task_struct___236 *task;
	struct core_thread___236 *next;
};

struct core_state___236 {
	atomic_t nr_threads;
	struct core_thread___236 dumper;
	struct completion startup;
};

struct irq_data___155;

struct x86_io_apic_ops___155 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___155 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___155;

struct irq_data___155 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___155 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___225;

struct dev_pm_ops___225 {
	int (*prepare)(struct device___225 *);
	void (*complete)(struct device___225 *);
	int (*suspend)(struct device___225 *);
	int (*resume)(struct device___225 *);
	int (*freeze)(struct device___225 *);
	int (*thaw)(struct device___225 *);
	int (*poweroff)(struct device___225 *);
	int (*restore)(struct device___225 *);
	int (*suspend_late)(struct device___225 *);
	int (*resume_early)(struct device___225 *);
	int (*freeze_late)(struct device___225 *);
	int (*thaw_early)(struct device___225 *);
	int (*poweroff_late)(struct device___225 *);
	int (*restore_early)(struct device___225 *);
	int (*suspend_noirq)(struct device___225 *);
	int (*resume_noirq)(struct device___225 *);
	int (*freeze_noirq)(struct device___225 *);
	int (*thaw_noirq)(struct device___225 *);
	int (*poweroff_noirq)(struct device___225 *);
	int (*restore_noirq)(struct device___225 *);
	int (*runtime_suspend)(struct device___225 *);
	int (*runtime_resume)(struct device___225 *);
	int (*runtime_idle)(struct device___225 *);
};

struct device_type___225;

struct bus_type___225;

struct device_driver___225;

struct dev_pm_domain___225;

struct class___225;

struct attribute_group___194;

struct device_rh___225;

struct device___225 {
	struct device___225 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___225 *type;
	struct mutex___237 mutex;
	struct bus_type___225 *bus;
	struct device_driver___225 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___225 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___94 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___32 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___225 *class;
	const struct attribute_group___194 **groups;
	void (*release)(struct device___225 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___225 *device_rh;
};

struct dev_pm_info_rh___225 {
	void (*set_latency_tolerance)(struct device___225 *, s32);
};

struct dev_pm_domain___225 {
	struct dev_pm_ops___225 ops;
};

struct smp_ops___236 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___236 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___236;

struct lruvec___236 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___236 *zone;
};

struct pglist_data___236;

struct zone___236 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___236 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___236 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___236 {
	struct zone___236 *zone;
	int zone_idx;
};

struct zonelist___236 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___236 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___236 {
	struct zone___236 node_zones[4];
	struct zonelist___236 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___236 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___236 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___236 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___236 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___237 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___51;

struct bio_list___50 {
	struct bio___51 *head;
	struct bio___51 *tail;
};

struct bdi_writeback___61 {
	struct backing_dev_info___61 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___61 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___61 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___225 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___235 *debug_dir;
	struct dentry___235 *debug_stats;
};

struct io_cq___50;

struct io_context___50 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___50 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bin_attribute___196;

struct attribute_group___194 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___196 **bin_attrs;
};

struct bin_attribute___196 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___235 *, struct kobject___24 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___235 *, struct kobject___24 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	int (*mmap)(struct file___235 *, struct kobject___24 *, struct bin_attribute___196 *, struct vm_area_struct___243 *);
};

struct kmem_cache_cpu___217 {
	void **freelist;
	long unsigned int tid;
	struct page___234 *page;
	struct page___234 *partial;
};

struct memcg_cache_params___218 {
	bool is_root_cache;
	union {
		struct kmem_cache___218 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___218 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___225 *, char *);
	ssize_t (*store)(struct bus_type___225 *, const char *, size_t);
};

struct device_attribute___225;

struct driver_attribute___225;

struct bus_type___225 {
	const char *name;
	const char *dev_name;
	struct device___225 *dev_root;
	struct bus_attribute___225 *bus_attrs;
	struct device_attribute___225 *dev_attrs;
	struct driver_attribute___225 *drv_attrs;
	const struct attribute_group___194 **bus_groups;
	const struct attribute_group___194 **dev_groups;
	const struct attribute_group___194 **drv_groups;
	int (*match)(struct device___225 *, struct device_driver___225 *);
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	int (*probe)(struct device___225 *);
	int (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*online)(struct device___225 *);
	int (*offline)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct device___225 *, struct device_attribute___225 *, char *);
	ssize_t (*store)(struct device___225 *, struct device_attribute___225 *, const char *, size_t);
};

struct driver_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___225 *, char *);
	ssize_t (*store)(struct device_driver___225 *, const char *, size_t);
};

struct device_driver___225 {
	const char *name;
	struct bus_type___225 *bus;
	struct module___139 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___225 *);
	int (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	const struct attribute_group___194 **groups;
	const struct dev_pm_ops___225 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___225 {
	const char *name;
	const struct attribute_group___194 **groups;
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
};

struct class_attribute___225;

struct class___225 {
	const char *name;
	struct module___139 *owner;
	struct class_attribute___225 *class_attrs;
	struct device_attribute___225 *dev_attrs;
	const struct attribute_group___194 **dev_groups;
	struct bin_attribute___196 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *);
	void (*class_release)(struct class___225 *);
	void (*dev_release)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
	struct subsys_private *p;
};

struct class_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct class___225 *, struct class_attribute___225 *, char *);
	ssize_t (*store)(struct class___225 *, struct class_attribute___225 *, const char *, size_t);
	const void * (*namespace)(struct class___225 *, const struct class_attribute___225 *);
};

struct device_rh___225 {
	struct dev_pm_info_rh___225 power;
};

struct dentry_operations___235;

struct super_block___235;

struct dentry___235 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___235 *d_parent;
	struct qstr d_name;
	struct inode___235 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___235 *d_op;
	struct super_block___235 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___235;

struct file_lock___235;

struct dquot___235;

struct block_device___235;

struct inode___235 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___235 *i_op;
	struct super_block___235 *i_sb;
	struct address_space___235 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___237 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___235 *i_fop;
	struct file_lock___235 *i_flock;
	struct address_space___235 i_data;
	struct dquot___235 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___235 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___235 {
	int (*d_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_hash)(const struct dentry___235 *, struct qstr *);
	int (*d_compare)(const struct dentry___235 *, const struct dentry___235 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___235 *);
	void (*d_release)(struct dentry___235 *);
	void (*d_prune)(struct dentry___235 *);
	void (*d_iput)(struct dentry___235 *, struct inode___235 *);
	char * (*d_dname)(struct dentry___235 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___235 *);
	int (*d_manage)(struct dentry___235 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___235;

struct mem_dqinfo___235 {
	struct quota_format_type___235 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___235;

struct quota_info___235 {
	unsigned int flags;
	struct mutex___237 dqio_mutex;
	struct mutex___237 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___235 *files[2];
	struct mem_dqinfo___235 info[2];
	const struct quota_format_ops___235 *ops[2];
};

struct file_system_type___235;

struct super_operations___235;

struct dquot_operations___235;

struct quotactl_ops___235;

struct super_block___235 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___235 *s_type;
	const struct super_operations___235 *s_op;
	const struct dquot_operations___235 *dq_op;
	const struct quotactl_ops___235 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___235 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___235 *s_bdev;
	struct backing_dev_info___61 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___235 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___237 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___235 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___51(struct bio___51 *, int);

struct bio_vec___51 {
	struct page___234 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___51;

struct bio_set___51;

struct bio___51 {
	sector_t bi_sector;
	struct bio___51 *bi_next;
	struct block_device___235 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___51 *bi_end_io;
	void *bi_private;
	struct io_context___50 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___51 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___51 *bi_io_vec;
	struct bio_set___51 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___51 bi_inline_vecs[0];
};

struct hd_struct___54;

struct gendisk___54;

struct request_queue___50;

struct block_device___235 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___235 *bd_inode;
	struct super_block___235 *bd_super;
	struct mutex___237 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___235 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___54 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___54 *bd_disk;
	struct request_queue___50 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___237 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___51 {
	struct bio___51 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___51 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___51 *bip_vec;
	struct bio_vec___51 bip_inline_vecs[0];
};

struct bio_set___51 {
	struct kmem_cache___218 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___50 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___235 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___235 *ia_file;
};

struct dquot___235 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___237 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___235 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___235 {
	int qf_fmt_id;
	const struct quota_format_ops___235 *qf_ops;
	struct module___139 *qf_owner;
	struct quota_format_type___235 *qf_next;
};

struct quota_format_ops___235 {
	int (*check_quota_file)(struct super_block___235 *, int);
	int (*read_file_info)(struct super_block___235 *, int);
	int (*write_file_info)(struct super_block___235 *, int);
	int (*free_file_info)(struct super_block___235 *, int);
	int (*read_dqblk)(struct dquot___235 *);
	int (*commit_dqblk)(struct dquot___235 *);
	int (*release_dqblk)(struct dquot___235 *);
};

struct dquot_operations___235 {
	int (*write_dquot)(struct dquot___235 *);
	struct dquot___235 * (*alloc_dquot)(struct super_block___235 *, int);
	void (*destroy_dquot)(struct dquot___235 *);
	int (*acquire_dquot)(struct dquot___235 *);
	int (*release_dquot)(struct dquot___235 *);
	int (*mark_dirty)(struct dquot___235 *);
	int (*write_info)(struct super_block___235 *, int);
	qsize_t * (*get_reserved_space)(struct inode___235 *);
};

struct quotactl_ops___235 {
	int (*quota_on)(struct super_block___235 *, int, int, struct path___235 *);
	int (*quota_on_meta)(struct super_block___235 *, int, int);
	int (*quota_off)(struct super_block___235 *, int);
	int (*quota_sync)(struct super_block___235 *, int);
	int (*get_info)(struct super_block___235 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___235 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___235 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___235 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___235 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___235 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___235 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___235 *, unsigned int);
};

struct address_space_operations___235 {
	int (*writepage)(struct page___234 *, struct writeback_control *);
	int (*readpage)(struct file___235 *, struct page___234 *);
	int (*writepages)(struct address_space___235 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___234 *);
	int (*readpages)(struct file___235 *, struct address_space___235 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___235 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___234 **, void **);
	int (*write_end)(struct file___235 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___234 *, void *);
	sector_t (*bmap)(struct address_space___235 *, sector_t);
	void (*invalidatepage)(struct page___234 *, long unsigned int);
	int (*releasepage)(struct page___234 *, gfp_t);
	void (*freepage)(struct page___234 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___235 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___235 *, struct page___234 *, struct page___234 *, enum migrate_mode);
	int (*launder_page)(struct page___234 *);
	int (*is_partially_uptodate)(struct page___234 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___234 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___235 *, struct page___234 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___235 *, sector_t *);
	void (*swap_deactivate)(struct file___235 *);
	void (*invalidatepage_range)(struct page___234 *, unsigned int, unsigned int);
};

struct hd_struct___54 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___225 __dev;
	struct kobject___24 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___54;

struct block_device_operations___50;

struct gendisk___54 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___54 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___54 *part_tbl;
	struct hd_struct___54 part0;
	const struct block_device_operations___50 *fops;
	struct request_queue___50 *queue;
	void *private_data;
	int flags;
	struct device___225 *driverfs_dev;
	struct kobject___24 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___50 {
	struct request_queue___50 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___50(struct request_queue___50 *);

typedef void make_request_fn___50(struct request_queue___50 *, struct bio___51 *);

struct request___50;

typedef int prep_rq_fn___50(struct request_queue___50 *, struct request___50 *);

struct bvec_merge_data___50;

typedef int merge_bvec_fn___51(struct request_queue___50 *, struct bvec_merge_data___50 *, struct bio_vec___51 *);

typedef void softirq_done_fn___50(struct request___50 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___50(struct request___50 *);

typedef int dma_drain_needed_fn___50(struct request___50 *);

typedef int lld_busy_fn___50(struct request_queue___50 *);

struct bsg_class_device___50 {
	struct device___225 *class_dev;
	struct device___225 *parent;
	int minor;
	struct request_queue___50 *queue;
	struct kref ref;
	void (*release)(struct device___225 *);
};

typedef void unprep_rq_fn___50(struct request_queue___50 *, struct request___50 *);

struct elevator_queue___50;

struct blk_queue_tag___50;

struct request_queue___50 {
	struct list_head queue_head;
	struct request___50 *last_merge;
	struct elevator_queue___50 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___50 root_rl;
	request_fn_proc___50 *request_fn;
	make_request_fn___50 *make_request_fn;
	prep_rq_fn___50 *prep_rq_fn;
	merge_bvec_fn___51 *merge_bvec_fn;
	softirq_done_fn___50 *softirq_done_fn;
	rq_timed_out_fn___50 *rq_timed_out_fn;
	dma_drain_needed_fn___50 *dma_drain_needed;
	lld_busy_fn___50 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___50 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___61 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___24 kobj;
	struct kobject___24 mq_kobj;
	struct device___225 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___50 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___50 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___237 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___50 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___50 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___51 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___235 {
	struct dentry___235 * (*lookup)(struct inode___235 *, struct dentry___235 *, unsigned int);
	void * (*follow_link)(struct dentry___235 *, struct nameidata *);
	int (*permission)(struct inode___235 *, int);
	struct posix_acl * (*get_acl)(struct inode___235 *, int);
	int (*readlink)(struct dentry___235 *, char *, int);
	void (*put_link)(struct dentry___235 *, struct nameidata *, void *);
	int (*create)(struct inode___235 *, struct dentry___235 *, umode_t, bool);
	int (*link)(struct dentry___235 *, struct inode___235 *, struct dentry___235 *);
	int (*unlink)(struct inode___235 *, struct dentry___235 *);
	int (*symlink)(struct inode___235 *, struct dentry___235 *, const char *);
	int (*mkdir)(struct inode___235 *, struct dentry___235 *, umode_t);
	int (*rmdir)(struct inode___235 *, struct dentry___235 *);
	int (*mknod)(struct inode___235 *, struct dentry___235 *, umode_t, dev_t);
	int (*rename)(struct inode___235 *, struct dentry___235 *, struct inode___235 *, struct dentry___235 *);
	int (*setattr)(struct dentry___235 *, struct iattr___235 *);
	int (*getattr)(struct vfsmount *, struct dentry___235 *, struct kstat *);
	int (*setxattr)(struct dentry___235 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___235 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___235 *, char *, size_t);
	int (*removexattr)(struct dentry___235 *, const char *);
	int (*fiemap)(struct inode___235 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___235 *, struct timespec *, int);
	int (*atomic_open)(struct inode___235 *, struct dentry___235 *, struct file___235 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___126;

struct seq_file___160;

struct file_operations___235 {
	struct module___139 *owner;
	loff_t (*llseek)(struct file___235 *, loff_t, int);
	ssize_t (*read)(struct file___235 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___235 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___235 *, void *, filldir_t);
	unsigned int (*poll)(struct file___235 *, struct poll_table_struct___126 *);
	long int (*unlocked_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___235 *, struct vm_area_struct___243 *);
	int (*open)(struct inode___235 *, struct file___235 *);
	int (*flush)(struct file___235 *, fl_owner_t);
	int (*release)(struct inode___235 *, struct file___235 *);
	int (*fsync)(struct file___235 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___235 *, int);
	int (*lock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*sendpage)(struct file___235 *, struct page___234 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___235 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___235 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___235 *, long int, struct file_lock___235 **, void **);
		struct {
			int (*setlease)(struct file___235 *, long int, struct file_lock___235 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___235 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___160 *, struct file___235 *);
};

struct fasync_struct___235;

struct file_lock_operations___235;

struct lock_manager_operations___235;

struct file_lock___235 {
	struct file_lock___235 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___235 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___235 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___235 *fl_ops;
	const struct lock_manager_operations___235 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___235 {
	void (*fl_copy_lock)(struct file_lock___235 *, struct file_lock___235 *);
	void (*fl_release_private)(struct file_lock___235 *);
};

struct lock_manager_operations___235 {
	int (*lm_compare_owner)(struct file_lock___235 *, struct file_lock___235 *);
	long unsigned int (*lm_owner_key)(struct file_lock___235 *);
	void (*lm_notify)(struct file_lock___235 *);
	int (*lm_grant)(struct file_lock___235 *, struct file_lock___235 *, int);
	void (*lm_break)(struct file_lock___235 *);
	int (*lm_change)(struct file_lock___235 **, int);
};

struct fasync_struct___235 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___235 *fa_next;
	struct file___235 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___235 {
	const char *name;
	int fs_flags;
	struct dentry___235 * (*mount)(struct file_system_type___235 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___235 *);
	struct module___139 *owner;
	struct file_system_type___235 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___235 {
	struct inode___235 * (*alloc_inode)(struct super_block___235 *);
	void (*destroy_inode)(struct inode___235 *);
	void (*dirty_inode)(struct inode___235 *, int);
	int (*write_inode)(struct inode___235 *, struct writeback_control *);
	int (*drop_inode)(struct inode___235 *);
	void (*evict_inode)(struct inode___235 *);
	void (*put_super)(struct super_block___235 *);
	int (*sync_fs)(struct super_block___235 *, int);
	int (*freeze_fs)(struct super_block___235 *);
	int (*unfreeze_fs)(struct super_block___235 *);
	int (*statfs)(struct dentry___235 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___235 *, int *, char *);
	void (*umount_begin)(struct super_block___235 *);
	int (*show_options)(struct seq_file___160 *, struct dentry___235 *);
	int (*show_devname)(struct seq_file___160 *, struct dentry___235 *);
	int (*show_path)(struct seq_file___160 *, struct dentry___235 *);
	int (*show_stats)(struct seq_file___160 *, struct dentry___235 *);
	ssize_t (*quota_read)(struct super_block___235 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___235 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___235 *);
	int (*bdev_try_to_free_page)(struct super_block___235 *, struct page___234 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___235 *);
	void (*free_cached_objects)(struct super_block___235 *, int);
};

typedef void (*poll_queue_proc___128)(struct file___235 *, wait_queue_head_t *, struct poll_table_struct___126 *);

struct poll_table_struct___126 {
	poll_queue_proc___128 _qproc;
	long unsigned int _key;
};

struct seq_operations___160;

struct seq_file___160 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___237 lock;
	const struct seq_operations___160 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___54 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___54 *last_lookup;
	struct hd_struct___54 *part[0];
};

struct block_device_operations___50 {
	int (*open)(struct block_device___235 *, fmode_t);
	void (*release)(struct gendisk___54 *, fmode_t);
	int (*ioctl)(struct block_device___235 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___235 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___235 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___54 *, unsigned int);
	int (*media_changed)(struct gendisk___54 *);
	void (*unlock_native_capacity)(struct gendisk___54 *);
	int (*revalidate_disk)(struct gendisk___54 *);
	int (*getgeo)(struct block_device___235 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___235 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___139 *owner;
};

struct vm_fault___205 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___234 *page;
};

struct irq_chip___155 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___155 *);
	void (*irq_shutdown)(struct irq_data___155 *);
	void (*irq_enable)(struct irq_data___155 *);
	void (*irq_disable)(struct irq_data___155 *);
	void (*irq_ack)(struct irq_data___155 *);
	void (*irq_mask)(struct irq_data___155 *);
	void (*irq_mask_ack)(struct irq_data___155 *);
	void (*irq_unmask)(struct irq_data___155 *);
	void (*irq_eoi)(struct irq_data___155 *);
	int (*irq_set_affinity)(struct irq_data___155 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___155 *);
	int (*irq_set_type)(struct irq_data___155 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___155 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___155 *);
	void (*irq_bus_sync_unlock)(struct irq_data___155 *);
	void (*irq_cpu_online)(struct irq_data___155 *);
	void (*irq_cpu_offline)(struct irq_data___155 *);
	void (*irq_suspend)(struct irq_data___155 *);
	void (*irq_resume)(struct irq_data___155 *);
	void (*irq_pm_shutdown)(struct irq_data___155 *);
	void (*irq_print_chip)(struct irq_data___155 *, struct seq_file___160 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___155 *, void *);
	long unsigned int flags;
};

struct io_cq___50 {
	struct request_queue___50 *q;
	struct io_context___50 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___218 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___50(struct request___50 *, int);

struct request___50 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___50 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___51 *bio;
	struct bio___51 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___50 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___50 *saved_end_io;
		} flush;
	};
	struct gendisk___54 *rq_disk;
	struct hd_struct___54 *part;
	long unsigned int start_time;
	struct request_list___50 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___50 *end_io;
	void *end_io_data;
	struct request___50 *next_rq;
};

typedef int elevator_merge_fn___50(struct request_queue___50 *, struct request___50 **, struct bio___51 *);

typedef void elevator_merge_req_fn___50(struct request_queue___50 *, struct request___50 *, struct request___50 *);

typedef void elevator_merged_fn___50(struct request_queue___50 *, struct request___50 *, int);

typedef int elevator_allow_merge_fn___50(struct request_queue___50 *, struct request___50 *, struct bio___51 *);

typedef void elevator_bio_merged_fn___50(struct request_queue___50 *, struct request___50 *, struct bio___51 *);

typedef int elevator_dispatch_fn___50(struct request_queue___50 *, int);

typedef void elevator_add_req_fn___50(struct request_queue___50 *, struct request___50 *);

typedef struct request___50 *elevator_request_list_fn___50(struct request_queue___50 *, struct request___50 *);

typedef void elevator_completed_req_fn___50(struct request_queue___50 *, struct request___50 *);

typedef int elevator_may_queue_fn___50(struct request_queue___50 *, int);

typedef void elevator_init_icq_fn___50(struct io_cq___50 *);

typedef void elevator_exit_icq_fn___50(struct io_cq___50 *);

typedef int elevator_set_req_fn___50(struct request_queue___50 *, struct request___50 *, struct bio___51 *, gfp_t);

typedef void elevator_put_req_fn___50(struct request___50 *);

typedef void elevator_activate_req_fn___50(struct request_queue___50 *, struct request___50 *);

typedef void elevator_deactivate_req_fn___50(struct request_queue___50 *, struct request___50 *);

struct elevator_type___50;

typedef int elevator_init_fn___51(struct request_queue___50 *, struct elevator_type___50 *);

typedef void elevator_exit_fn___50(struct elevator_queue___50 *);

struct elevator_ops___50 {
	elevator_merge_fn___50 *elevator_merge_fn;
	elevator_merged_fn___50 *elevator_merged_fn;
	elevator_merge_req_fn___50 *elevator_merge_req_fn;
	elevator_allow_merge_fn___50 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___50 *elevator_bio_merged_fn;
	elevator_dispatch_fn___50 *elevator_dispatch_fn;
	elevator_add_req_fn___50 *elevator_add_req_fn;
	elevator_activate_req_fn___50 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___50 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___50 *elevator_completed_req_fn;
	elevator_request_list_fn___50 *elevator_former_req_fn;
	elevator_request_list_fn___50 *elevator_latter_req_fn;
	elevator_init_icq_fn___50 *elevator_init_icq_fn;
	elevator_exit_icq_fn___50 *elevator_exit_icq_fn;
	elevator_set_req_fn___50 *elevator_set_req_fn;
	elevator_put_req_fn___50 *elevator_put_req_fn;
	elevator_may_queue_fn___50 *elevator_may_queue_fn;
	elevator_init_fn___51 *elevator_init_fn;
	elevator_exit_fn___50 *elevator_exit_fn;
};

struct elv_fs_entry___50;

struct elevator_type___50 {
	struct kmem_cache___218 *icq_cache;
	struct elevator_ops___50 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___50 *elevator_attrs;
	char elevator_name[16];
	struct module___139 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___50 {
	struct elevator_type___50 *type;
	void *elevator_data;
	struct kobject___24 kobj;
	struct mutex___237 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___50 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___50 *, char *);
	ssize_t (*store)(struct elevator_queue___50 *, const char *, size_t);
};

struct bvec_merge_data___50 {
	struct block_device___235 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___50 {
	struct request___50 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___160 {
	void * (*start)(struct seq_file___160 *, loff_t *);
	void (*stop)(struct seq_file___160 *, void *);
	void * (*next)(struct seq_file___160 *, void *, loff_t *);
	int (*show)(struct seq_file___160 *, void *);
};

typedef struct poll_table_struct___126 poll_table___33;

struct module_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___138 *, struct module_kobject___138 *, char *);
	ssize_t (*store)(struct module_attribute___138 *, struct module_kobject___138 *, const char *, size_t);
	void (*setup)(struct module___139 *, const char *);
	int (*test)(struct module___139 *);
	void (*free)(struct module___139 *);
};

struct mdp_device_descriptor_s {
	__u32 number;
	__u32 major;
	__u32 minor;
	__u32 raid_disk;
	__u32 state;
	__u32 reserved[27];
};

typedef struct mdp_device_descriptor_s mdp_disk_t;

struct mdp_superblock_s {
	__u32 md_magic;
	__u32 major_version;
	__u32 minor_version;
	__u32 patch_version;
	__u32 gvalid_words;
	__u32 set_uuid0;
	__u32 ctime;
	__u32 level;
	__u32 size;
	__u32 nr_disks;
	__u32 raid_disks;
	__u32 md_minor;
	__u32 not_persistent;
	__u32 set_uuid1;
	__u32 set_uuid2;
	__u32 set_uuid3;
	__u32 gstate_creserved[16];
	__u32 utime;
	__u32 state;
	__u32 active_disks;
	__u32 working_disks;
	__u32 failed_disks;
	__u32 spare_disks;
	__u32 sb_csum;
	__u32 events_lo;
	__u32 events_hi;
	__u32 cp_events_lo;
	__u32 cp_events_hi;
	__u32 recovery_cp;
	__u64 reshape_position;
	__u32 new_level;
	__u32 delta_disks;
	__u32 new_layout;
	__u32 new_chunk;
	__u32 gstate_sreserved[14];
	__u32 layout;
	__u32 chunk_size;
	__u32 root_pv;
	__u32 root_block;
	__u32 pstate_reserved[60];
	mdp_disk_t disks[27];
	__u32 reserved[0];
	mdp_disk_t this_disk;
};

typedef struct mdp_superblock_s mdp_super_t;

struct mdp_superblock_1 {
	__le32 magic;
	__le32 major_version;
	__le32 feature_map;
	__le32 pad0;
	__u8 set_uuid[16];
	char set_name[32];
	__le64 ctime;
	__le32 level;
	__le32 layout;
	__le64 size;
	__le32 chunksize;
	__le32 raid_disks;
	__le32 bitmap_offset;
	__le32 new_level;
	__le64 reshape_position;
	__le32 delta_disks;
	__le32 new_layout;
	__le32 new_chunk;
	__le32 new_offset;
	__le64 data_offset;
	__le64 data_size;
	__le64 super_offset;
	__le64 recovery_offset;
	__le32 dev_number;
	__le32 cnt_corrected_read;
	__u8 device_uuid[16];
	__u8 devflags;
	__u8 bblog_shift;
	__le16 bblog_size;
	__le32 bblog_offset;
	__le64 utime;
	__le64 events;
	__le64 resync_offset;
	__le32 sb_csum;
	__le32 max_dev;
	__u8 pad3[32];
	__le16 dev_roles[0];
};

struct mdu_version_s {
	int major;
	int minor;
	int patchlevel;
};

typedef struct mdu_version_s mdu_version_t;

struct mdu_bitmap_file_s {
	char pathname[4096];
};

typedef struct mdu_bitmap_file_s mdu_bitmap_file_t;

struct badblocks {
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

struct mddev;

struct md_rdev {
	struct list_head same_set;
	sector_t sectors;
	struct mddev *mddev;
	int last_events;
	struct block_device___235 *meta_bdev;
	struct block_device___235 *bdev;
	struct page___234 *sb_page;
	struct page___234 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___24 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	sector_t recovery_offset;
	atomic_t nr_pending;
	atomic_t read_errors;
	struct timespec last_read_error;
	atomic_t corrected_errors;
	struct work_struct del_work;
	struct sysfs_dirent *sysfs_state;
	struct badblocks badblocks;
};

struct md_personality;

struct md_thread;

struct bitmap;

struct mddev {
	void *private;
	struct md_personality *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	int ready;
	struct gendisk___54 *gendisk;
	struct kobject___24 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time_t ctime;
	time_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread *thread;
	struct md_thread *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex___237 open_mutex;
	struct mutex___237 reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	int merge_check_needed;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct sysfs_dirent *sysfs_state;
	struct sysfs_dirent *sysfs_action;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	atomic_t writes_pending;
	struct request_queue___50 *queue;
	struct bitmap *bitmap;
	struct {
		struct file___235 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex___237 mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	struct attribute_group___194 *to_remove;
	struct bio_set___51 *bio_set;
	struct bio___51 *flush_bio;
	atomic_t flush_pending;
	struct work_struct flush_work;
	struct work_struct event_work;
	void (*sync_super)(struct mddev *, struct md_rdev *);
};

enum flag_bits {
	Faulty = 0,
	In_sync = 1,
	Bitmap_sync = 2,
	Unmerged = 3,
	WriteMostly = 4,
	AutoDetected = 5,
	Blocked = 6,
	WriteErrorSeen = 7,
	FaultRecorded = 8,
	BlockedBadBlocks = 9,
	WantReplacement = 10,
	Replacement = 11,
};

struct md_personality {
	char *name;
	int level;
	struct list_head list;
	struct module___139 *owner;
	void (*make_request)(struct mddev *, struct bio___51 *);
	int (*run)(struct mddev *);
	void (*free)(struct mddev *, void *);
	void (*status)(struct seq_file___160 *, struct mddev *);
	void (*error_handler)(struct mddev *, struct md_rdev *);
	int (*hot_add_disk)(struct mddev *, struct md_rdev *);
	int (*hot_remove_disk)(struct mddev *, struct md_rdev *);
	int (*spare_active)(struct mddev *);
	sector_t (*sync_request)(struct mddev *, sector_t, int *);
	int (*resize)(struct mddev *, sector_t);
	sector_t (*size)(struct mddev *, sector_t, int);
	int (*check_reshape)(struct mddev *);
	int (*start_reshape)(struct mddev *);
	void (*finish_reshape)(struct mddev *);
	void (*quiesce)(struct mddev *, int);
	void * (*takeover)(struct mddev *);
	int (*congested)(struct mddev *, int);
	int (*mergeable_bvec)(struct mddev *, struct bvec_merge_data___50 *, struct bio_vec___51 *);
};

struct md_thread {
	void (*run)(struct md_thread *);
	struct mddev *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___236 *tsk;
	long unsigned int timeout;
	void *private;
};

struct bitmap_page;

struct bitmap_counts {
	spinlock_t lock;
	struct bitmap_page *bp;
	long unsigned int pages;
	long unsigned int missing_pages;
	long unsigned int chunkshift;
	long unsigned int chunks;
};

struct bitmap_storage {
	struct file___235 *file;
	struct page___234 *sb_page;
	struct page___234 **filemap;
	long unsigned int *filemap_attr;
	long unsigned int file_pages;
	long unsigned int bytes;
};

struct bitmap {
	struct bitmap_counts counts;
	struct mddev *mddev;
	__u64 events_cleared;
	int need_sync;
	struct bitmap_storage storage;
	long unsigned int flags;
	int allclean;
	atomic_t behind_writes;
	long unsigned int behind_writes_used;
	long unsigned int daemon_lastrun;
	long unsigned int last_end_sync;
	atomic_t pending_writes;
	wait_queue_head_t write_wait;
	wait_queue_head_t overflow_wait;
	wait_queue_head_t behind_wait;
	struct sysfs_dirent *sysfs_can_clear;
};

struct md_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct mddev *, char *);
	ssize_t (*store)(struct mddev *, const char *, size_t);
};

struct bitmap_page {
	char *map;
	unsigned int hijacked: 1;
	unsigned int pending: 1;
	unsigned int count: 30;
};

struct super_type {
	char *name;
	struct module___139 *owner;
	int (*load_super)(struct md_rdev *, struct md_rdev *, int);
	int (*validate_super)(struct mddev *, struct md_rdev *);
	void (*sync_super)(struct mddev *, struct md_rdev *);
	long long unsigned int (*rdev_size_change)(struct md_rdev *, sector_t);
	int (*allow_new_offset)(struct md_rdev *, long long unsigned int);
};

struct rdev_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct md_rdev *, char *);
	ssize_t (*store)(struct md_rdev *, const char *, size_t);
};

enum array_state {
	clear = 0,
	inactive = 1,
	suspended = 2,
	readonly = 3,
	read_auto = 4,
	clean = 5,
	active = 6,
	write_pending = 7,
	active_idle = 8,
	bad_word = 9,
};

struct detected_devices_node {
	struct list_head list;
	dev_t dev;
};

struct page___235;

typedef struct page___235 *pgtable_t___235;

struct address_space___236;

struct kmem_cache___219;

struct page___235 {
	long unsigned int flags;
	struct address_space___236 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___235 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___235 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___219 *slab_cache;
		struct page___235 *first_page;
	};
	long: 64;
};

struct task_struct___237;

struct pv_cpu_ops___237 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___237 *);
	void (*end_context_switch)(struct task_struct___237 *);
};

struct mutex___238 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___237 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___230 {
	struct page___235 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___244;

struct signal_struct___237;

struct bio_list___51;

struct backing_dev_info___62;

struct io_context___51;

struct task_struct___237 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___237 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___244 *mm;
	struct mm_struct___244 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___237 *real_parent;
	struct task_struct___237 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___237 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___237 = 0,
		VTIME_USER___237 = 1,
		VTIME_SYS___237 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___237 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___51 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___62 *backing_dev_info;
	struct io_context___51 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___238 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___230 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___244 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___244 *, struct mm_struct___244 *);
	void (*dup_mmap)(struct mm_struct___244 *, struct mm_struct___244 *);
	void (*exit_mmap)(struct mm_struct___244 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___244 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___244 *);
	void (*pgd_free)(struct mm_struct___244 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___244 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___244 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___244 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___244 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___244 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___244 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___244 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___244 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___244 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___244 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___244 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___238 lock;
	void *vdso;
} mm_context_t___238;

struct xol_area___235;

struct uprobes_state___235 {
	struct xol_area___235 *xol_area;
};

struct vm_area_struct___244;

struct file___236;

struct core_state___237;

struct mm_struct___244 {
	struct vm_area_struct___244 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___244 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___244 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___238 context;
	long unsigned int flags;
	struct core_state___237 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___237 *owner;
	struct file___236 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___235 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___140;

struct exec_domain___64 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___140 *module;
	struct exec_domain___64 *next;
};

struct module_kobject___139 {
	struct kobject___24 kobj;
	struct module___140 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___139;

struct module___140 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___139 mkobj;
	struct module_attribute___139 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___237 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___107 {
	struct task_struct___237 *task;
	struct exec_domain___64 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___235 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___235 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___218;

struct memcg_cache_params___219;

struct kmem_cache___219 {
	struct kmem_cache_cpu___218 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___219 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___236;

struct address_space_operations___236;

struct address_space___236 {
	struct inode___236 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___238 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___236 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___62 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___44;

struct dentry___236;

struct path___236 {
	struct vfsmount___44 *mnt;
	struct dentry___236 *dentry;
};

struct file_operations___236;

struct file___236 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___236 f_path;
	struct inode___236 *f_inode;
	const struct file_operations___236 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___236 *f_mapping;
	struct mutex___238 f_pos_lock;
};

struct vm_operations_struct___210;

struct vm_area_struct___244 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___244 *vm_next;
	struct vm_area_struct___244 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___244 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___210 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___236 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___206;

struct vm_operations_struct___210 {
	void (*open)(struct vm_area_struct___244 *);
	void (*close)(struct vm_area_struct___244 *);
	int (*fault)(struct vm_area_struct___244 *, struct vm_fault___206 *);
	int (*page_mkwrite)(struct vm_area_struct___244 *, struct vm_fault___206 *);
	int (*access)(struct vm_area_struct___244 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___244 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___244 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___244 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___244 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___237 {
	struct task_struct___237 *task;
	struct core_thread___237 *next;
};

struct core_state___237 {
	atomic_t nr_threads;
	struct core_thread___237 dumper;
	struct completion startup;
};

struct irq_data___156;

struct x86_io_apic_ops___156 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___156 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___156;

struct irq_data___156 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___156 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___226;

struct dev_pm_ops___226 {
	int (*prepare)(struct device___226 *);
	void (*complete)(struct device___226 *);
	int (*suspend)(struct device___226 *);
	int (*resume)(struct device___226 *);
	int (*freeze)(struct device___226 *);
	int (*thaw)(struct device___226 *);
	int (*poweroff)(struct device___226 *);
	int (*restore)(struct device___226 *);
	int (*suspend_late)(struct device___226 *);
	int (*resume_early)(struct device___226 *);
	int (*freeze_late)(struct device___226 *);
	int (*thaw_early)(struct device___226 *);
	int (*poweroff_late)(struct device___226 *);
	int (*restore_early)(struct device___226 *);
	int (*suspend_noirq)(struct device___226 *);
	int (*resume_noirq)(struct device___226 *);
	int (*freeze_noirq)(struct device___226 *);
	int (*thaw_noirq)(struct device___226 *);
	int (*poweroff_noirq)(struct device___226 *);
	int (*restore_noirq)(struct device___226 *);
	int (*runtime_suspend)(struct device___226 *);
	int (*runtime_resume)(struct device___226 *);
	int (*runtime_idle)(struct device___226 *);
};

struct device_type___226;

struct bus_type___226;

struct device_driver___226;

struct dev_pm_domain___226;

struct class___226;

struct attribute_group___195;

struct device_rh___226;

struct device___226 {
	struct device___226 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___226 *type;
	struct mutex___238 mutex;
	struct bus_type___226 *bus;
	struct device_driver___226 *driver;
	void *platform_data;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___226 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___94 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___32 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___226 *class;
	const struct attribute_group___195 **groups;
	void (*release)(struct device___226 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___226 *device_rh;
};

struct dev_pm_info_rh___226 {
	void (*set_latency_tolerance)(struct device___226 *, s32);
};

struct dev_pm_domain___226 {
	struct dev_pm_ops___226 ops;
};

struct smp_ops___237 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___237 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___237;

struct lruvec___237 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___237 *zone;
};

struct pglist_data___237;

struct zone___237 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___237 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___237 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___237 {
	struct zone___237 *zone;
	int zone_idx;
};

struct zonelist___237 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___237 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___237 {
	struct zone___237 node_zones[4];
	struct zonelist___237 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___237 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___237 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___237 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___237 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___238 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___52;

struct bio_list___51 {
	struct bio___52 *head;
	struct bio___52 *tail;
};

struct bdi_writeback___62 {
	struct backing_dev_info___62 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___62 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___62 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___226 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___236 *debug_dir;
	struct dentry___236 *debug_stats;
};

struct io_cq___51;

struct io_context___51 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___51 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bin_attribute___197;

struct attribute_group___195 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___197 **bin_attrs;
};

struct bin_attribute___197 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___236 *, struct kobject___24 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___236 *, struct kobject___24 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	int (*mmap)(struct file___236 *, struct kobject___24 *, struct bin_attribute___197 *, struct vm_area_struct___244 *);
};

struct kmem_cache_cpu___218 {
	void **freelist;
	long unsigned int tid;
	struct page___235 *page;
	struct page___235 *partial;
};

struct memcg_cache_params___219 {
	bool is_root_cache;
	union {
		struct kmem_cache___219 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___219 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct bus_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___226 *, char *);
	ssize_t (*store)(struct bus_type___226 *, const char *, size_t);
};

struct device_attribute___226;

struct driver_attribute___226;

struct bus_type___226 {
	const char *name;
	const char *dev_name;
	struct device___226 *dev_root;
	struct bus_attribute___226 *bus_attrs;
	struct device_attribute___226 *dev_attrs;
	struct driver_attribute___226 *drv_attrs;
	const struct attribute_group___195 **bus_groups;
	const struct attribute_group___195 **dev_groups;
	const struct attribute_group___195 **drv_groups;
	int (*match)(struct device___226 *, struct device_driver___226 *);
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	int (*probe)(struct device___226 *);
	int (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*online)(struct device___226 *);
	int (*offline)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct device___226 *, struct device_attribute___226 *, char *);
	ssize_t (*store)(struct device___226 *, struct device_attribute___226 *, const char *, size_t);
};

struct driver_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___226 *, char *);
	ssize_t (*store)(struct device_driver___226 *, const char *, size_t);
};

struct device_driver___226 {
	const char *name;
	struct bus_type___226 *bus;
	struct module___140 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___226 *);
	int (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	const struct attribute_group___195 **groups;
	const struct dev_pm_ops___226 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___226 {
	const char *name;
	const struct attribute_group___195 **groups;
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
};

struct class_attribute___226;

struct class___226 {
	const char *name;
	struct module___140 *owner;
	struct class_attribute___226 *class_attrs;
	struct device_attribute___226 *dev_attrs;
	const struct attribute_group___195 **dev_groups;
	struct bin_attribute___197 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *);
	void (*class_release)(struct class___226 *);
	void (*dev_release)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
	struct subsys_private *p;
};

struct class_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct class___226 *, struct class_attribute___226 *, char *);
	ssize_t (*store)(struct class___226 *, struct class_attribute___226 *, const char *, size_t);
	const void * (*namespace)(struct class___226 *, const struct class_attribute___226 *);
};

struct device_rh___226 {
	struct dev_pm_info_rh___226 power;
};

struct dentry_operations___236;

struct super_block___236;

struct dentry___236 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___236 *d_parent;
	struct qstr d_name;
	struct inode___236 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___236 *d_op;
	struct super_block___236 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___236;

struct file_lock___236;

struct dquot___236;

struct block_device___236;

struct inode___236 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___236 *i_op;
	struct super_block___236 *i_sb;
	struct address_space___236 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___238 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___236 *i_fop;
	struct file_lock___236 *i_flock;
	struct address_space___236 i_data;
	struct dquot___236 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___236 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___236 {
	int (*d_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_hash)(const struct dentry___236 *, struct qstr *);
	int (*d_compare)(const struct dentry___236 *, const struct dentry___236 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___236 *);
	void (*d_release)(struct dentry___236 *);
	void (*d_prune)(struct dentry___236 *);
	void (*d_iput)(struct dentry___236 *, struct inode___236 *);
	char * (*d_dname)(struct dentry___236 *, char *, int);
	struct vfsmount___44 * (*d_automount)(struct path___236 *);
	int (*d_manage)(struct dentry___236 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___236;

struct mem_dqinfo___236 {
	struct quota_format_type___236 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___236;

struct quota_info___236 {
	unsigned int flags;
	struct mutex___238 dqio_mutex;
	struct mutex___238 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___236 *files[2];
	struct mem_dqinfo___236 info[2];
	const struct quota_format_ops___236 *ops[2];
};

struct file_system_type___236;

struct super_operations___236;

struct dquot_operations___236;

struct quotactl_ops___236;

struct super_block___236 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___236 *s_type;
	const struct super_operations___236 *s_op;
	const struct dquot_operations___236 *dq_op;
	const struct quotactl_ops___236 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___236 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___236 *s_bdev;
	struct backing_dev_info___62 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___236 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___238 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___236 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___44 {
	struct dentry___236 *mnt_root;
	struct super_block___236 *mnt_sb;
	int mnt_flags;
};

typedef void bio_end_io_t___52(struct bio___52 *, int);

struct bio_vec___52 {
	struct page___235 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___52;

struct bio_set___52;

struct bio___52 {
	sector_t bi_sector;
	struct bio___52 *bi_next;
	struct block_device___236 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___52 *bi_end_io;
	void *bi_private;
	struct io_context___51 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___52 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___52 *bi_io_vec;
	struct bio_set___52 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___52 bi_inline_vecs[0];
};

struct hd_struct___55;

struct gendisk___55;

struct request_queue___51;

struct block_device___236 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___236 *bd_inode;
	struct super_block___236 *bd_super;
	struct mutex___238 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___236 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___55 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___55 *bd_disk;
	struct request_queue___51 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___238 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___52 {
	struct bio___52 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___52 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___52 *bip_vec;
	struct bio_vec___52 bip_inline_vecs[0];
};

struct bio_set___52 {
	struct kmem_cache___219 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___51 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct buffer_head___7;

typedef void bh_end_io_t___6(struct buffer_head___7 *, int);

struct buffer_head___7 {
	long unsigned int b_state;
	struct buffer_head___7 *b_this_page;
	struct page___235 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___236 *b_bdev;
	bh_end_io_t___6 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___236 *b_assoc_map;
	atomic_t b_count;
};

struct iattr___236 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___236 *ia_file;
};

struct dquot___236 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___238 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___236 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___236 {
	int qf_fmt_id;
	const struct quota_format_ops___236 *qf_ops;
	struct module___140 *qf_owner;
	struct quota_format_type___236 *qf_next;
};

struct quota_format_ops___236 {
	int (*check_quota_file)(struct super_block___236 *, int);
	int (*read_file_info)(struct super_block___236 *, int);
	int (*write_file_info)(struct super_block___236 *, int);
	int (*free_file_info)(struct super_block___236 *, int);
	int (*read_dqblk)(struct dquot___236 *);
	int (*commit_dqblk)(struct dquot___236 *);
	int (*release_dqblk)(struct dquot___236 *);
};

struct dquot_operations___236 {
	int (*write_dquot)(struct dquot___236 *);
	struct dquot___236 * (*alloc_dquot)(struct super_block___236 *, int);
	void (*destroy_dquot)(struct dquot___236 *);
	int (*acquire_dquot)(struct dquot___236 *);
	int (*release_dquot)(struct dquot___236 *);
	int (*mark_dirty)(struct dquot___236 *);
	int (*write_info)(struct super_block___236 *, int);
	qsize_t * (*get_reserved_space)(struct inode___236 *);
};

struct quotactl_ops___236 {
	int (*quota_on)(struct super_block___236 *, int, int, struct path___236 *);
	int (*quota_on_meta)(struct super_block___236 *, int, int);
	int (*quota_off)(struct super_block___236 *, int);
	int (*quota_sync)(struct super_block___236 *, int);
	int (*get_info)(struct super_block___236 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___236 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___236 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___236 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___236 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___236 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___236 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___236 *, unsigned int);
};

struct address_space_operations___236 {
	int (*writepage)(struct page___235 *, struct writeback_control *);
	int (*readpage)(struct file___236 *, struct page___235 *);
	int (*writepages)(struct address_space___236 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___235 *);
	int (*readpages)(struct file___236 *, struct address_space___236 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___236 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___235 **, void **);
	int (*write_end)(struct file___236 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___235 *, void *);
	sector_t (*bmap)(struct address_space___236 *, sector_t);
	void (*invalidatepage)(struct page___235 *, long unsigned int);
	int (*releasepage)(struct page___235 *, gfp_t);
	void (*freepage)(struct page___235 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___236 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___236 *, struct page___235 *, struct page___235 *, enum migrate_mode);
	int (*launder_page)(struct page___235 *);
	int (*is_partially_uptodate)(struct page___235 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___235 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___236 *, struct page___235 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___236 *, sector_t *);
	void (*swap_deactivate)(struct file___236 *);
	void (*invalidatepage_range)(struct page___235 *, unsigned int, unsigned int);
};

struct hd_struct___55 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___226 __dev;
	struct kobject___24 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___55;

struct block_device_operations___51;

struct gendisk___55 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___55 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___55 *part_tbl;
	struct hd_struct___55 part0;
	const struct block_device_operations___51 *fops;
	struct request_queue___51 *queue;
	void *private_data;
	int flags;
	struct device___226 *driverfs_dev;
	struct kobject___24 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___51 {
	struct request_queue___51 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___51(struct request_queue___51 *);

typedef void make_request_fn___51(struct request_queue___51 *, struct bio___52 *);

struct request___51;

typedef int prep_rq_fn___51(struct request_queue___51 *, struct request___51 *);

struct bvec_merge_data___51;

typedef int merge_bvec_fn___52(struct request_queue___51 *, struct bvec_merge_data___51 *, struct bio_vec___52 *);

typedef void softirq_done_fn___51(struct request___51 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___51(struct request___51 *);

typedef int dma_drain_needed_fn___51(struct request___51 *);

typedef int lld_busy_fn___51(struct request_queue___51 *);

struct bsg_class_device___51 {
	struct device___226 *class_dev;
	struct device___226 *parent;
	int minor;
	struct request_queue___51 *queue;
	struct kref ref;
	void (*release)(struct device___226 *);
};

typedef void unprep_rq_fn___51(struct request_queue___51 *, struct request___51 *);

struct elevator_queue___51;

struct blk_queue_tag___51;

struct request_queue___51 {
	struct list_head queue_head;
	struct request___51 *last_merge;
	struct elevator_queue___51 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___51 root_rl;
	request_fn_proc___51 *request_fn;
	make_request_fn___51 *make_request_fn;
	prep_rq_fn___51 *prep_rq_fn;
	merge_bvec_fn___52 *merge_bvec_fn;
	softirq_done_fn___51 *softirq_done_fn;
	rq_timed_out_fn___51 *rq_timed_out_fn;
	dma_drain_needed_fn___51 *dma_drain_needed;
	lld_busy_fn___51 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___51 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___62 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___24 kobj;
	struct kobject___24 mq_kobj;
	struct device___226 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___51 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___51 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___238 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___51 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___51 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___52 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct inode_operations___236 {
	struct dentry___236 * (*lookup)(struct inode___236 *, struct dentry___236 *, unsigned int);
	void * (*follow_link)(struct dentry___236 *, struct nameidata *);
	int (*permission)(struct inode___236 *, int);
	struct posix_acl * (*get_acl)(struct inode___236 *, int);
	int (*readlink)(struct dentry___236 *, char *, int);
	void (*put_link)(struct dentry___236 *, struct nameidata *, void *);
	int (*create)(struct inode___236 *, struct dentry___236 *, umode_t, bool);
	int (*link)(struct dentry___236 *, struct inode___236 *, struct dentry___236 *);
	int (*unlink)(struct inode___236 *, struct dentry___236 *);
	int (*symlink)(struct inode___236 *, struct dentry___236 *, const char *);
	int (*mkdir)(struct inode___236 *, struct dentry___236 *, umode_t);
	int (*rmdir)(struct inode___236 *, struct dentry___236 *);
	int (*mknod)(struct inode___236 *, struct dentry___236 *, umode_t, dev_t);
	int (*rename)(struct inode___236 *, struct dentry___236 *, struct inode___236 *, struct dentry___236 *);
	int (*setattr)(struct dentry___236 *, struct iattr___236 *);
	int (*getattr)(struct vfsmount___44 *, struct dentry___236 *, struct kstat *);
	int (*setxattr)(struct dentry___236 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___236 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___236 *, char *, size_t);
	int (*removexattr)(struct dentry___236 *, const char *);
	int (*fiemap)(struct inode___236 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___236 *, struct timespec *, int);
	int (*atomic_open)(struct inode___236 *, struct dentry___236 *, struct file___236 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___161;

struct file_operations___236 {
	struct module___140 *owner;
	loff_t (*llseek)(struct file___236 *, loff_t, int);
	ssize_t (*read)(struct file___236 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___236 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___236 *, void *, filldir_t);
	unsigned int (*poll)(struct file___236 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___236 *, struct vm_area_struct___244 *);
	int (*open)(struct inode___236 *, struct file___236 *);
	int (*flush)(struct file___236 *, fl_owner_t);
	int (*release)(struct inode___236 *, struct file___236 *);
	int (*fsync)(struct file___236 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___236 *, int);
	int (*lock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*sendpage)(struct file___236 *, struct page___235 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___236 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___236 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___236 *, long int, struct file_lock___236 **, void **);
		struct {
			int (*setlease)(struct file___236 *, long int, struct file_lock___236 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___236 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___161 *, struct file___236 *);
};

struct fasync_struct___236;

struct file_lock_operations___236;

struct lock_manager_operations___236;

struct file_lock___236 {
	struct file_lock___236 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___236 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___236 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___236 *fl_ops;
	const struct lock_manager_operations___236 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___236 {
	void (*fl_copy_lock)(struct file_lock___236 *, struct file_lock___236 *);
	void (*fl_release_private)(struct file_lock___236 *);
};

struct lock_manager_operations___236 {
	int (*lm_compare_owner)(struct file_lock___236 *, struct file_lock___236 *);
	long unsigned int (*lm_owner_key)(struct file_lock___236 *);
	void (*lm_notify)(struct file_lock___236 *);
	int (*lm_grant)(struct file_lock___236 *, struct file_lock___236 *, int);
	void (*lm_break)(struct file_lock___236 *);
	int (*lm_change)(struct file_lock___236 **, int);
};

struct fasync_struct___236 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___236 *fa_next;
	struct file___236 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___236 {
	const char *name;
	int fs_flags;
	struct dentry___236 * (*mount)(struct file_system_type___236 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___236 *);
	struct module___140 *owner;
	struct file_system_type___236 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___236 {
	struct inode___236 * (*alloc_inode)(struct super_block___236 *);
	void (*destroy_inode)(struct inode___236 *);
	void (*dirty_inode)(struct inode___236 *, int);
	int (*write_inode)(struct inode___236 *, struct writeback_control *);
	int (*drop_inode)(struct inode___236 *);
	void (*evict_inode)(struct inode___236 *);
	void (*put_super)(struct super_block___236 *);
	int (*sync_fs)(struct super_block___236 *, int);
	int (*freeze_fs)(struct super_block___236 *);
	int (*unfreeze_fs)(struct super_block___236 *);
	int (*statfs)(struct dentry___236 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___236 *, int *, char *);
	void (*umount_begin)(struct super_block___236 *);
	int (*show_options)(struct seq_file___161 *, struct dentry___236 *);
	int (*show_devname)(struct seq_file___161 *, struct dentry___236 *);
	int (*show_path)(struct seq_file___161 *, struct dentry___236 *);
	int (*show_stats)(struct seq_file___161 *, struct dentry___236 *);
	ssize_t (*quota_read)(struct super_block___236 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___236 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___236 *);
	int (*bdev_try_to_free_page)(struct super_block___236 *, struct page___235 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___236 *);
	void (*free_cached_objects)(struct super_block___236 *, int);
};

struct seq_operations___161;

struct seq_file___161 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___238 lock;
	const struct seq_operations___161 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___55 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___55 *last_lookup;
	struct hd_struct___55 *part[0];
};

struct block_device_operations___51 {
	int (*open)(struct block_device___236 *, fmode_t);
	void (*release)(struct gendisk___55 *, fmode_t);
	int (*ioctl)(struct block_device___236 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___236 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___236 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___55 *, unsigned int);
	int (*media_changed)(struct gendisk___55 *);
	void (*unlock_native_capacity)(struct gendisk___55 *);
	int (*revalidate_disk)(struct gendisk___55 *);
	int (*getgeo)(struct block_device___236 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___236 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___140 *owner;
};

struct vm_fault___206 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___235 *page;
};

struct irq_chip___156 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___156 *);
	void (*irq_shutdown)(struct irq_data___156 *);
	void (*irq_enable)(struct irq_data___156 *);
	void (*irq_disable)(struct irq_data___156 *);
	void (*irq_ack)(struct irq_data___156 *);
	void (*irq_mask)(struct irq_data___156 *);
	void (*irq_mask_ack)(struct irq_data___156 *);
	void (*irq_unmask)(struct irq_data___156 *);
	void (*irq_eoi)(struct irq_data___156 *);
	int (*irq_set_affinity)(struct irq_data___156 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___156 *);
	int (*irq_set_type)(struct irq_data___156 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___156 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___156 *);
	void (*irq_bus_sync_unlock)(struct irq_data___156 *);
	void (*irq_cpu_online)(struct irq_data___156 *);
	void (*irq_cpu_offline)(struct irq_data___156 *);
	void (*irq_suspend)(struct irq_data___156 *);
	void (*irq_resume)(struct irq_data___156 *);
	void (*irq_pm_shutdown)(struct irq_data___156 *);
	void (*irq_print_chip)(struct irq_data___156 *, struct seq_file___161 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___156 *, void *);
	long unsigned int flags;
};

struct io_cq___51 {
	struct request_queue___51 *q;
	struct io_context___51 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___219 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___51(struct request___51 *, int);

struct request___51 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___51 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___52 *bio;
	struct bio___52 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___51 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___51 *saved_end_io;
		} flush;
	};
	struct gendisk___55 *rq_disk;
	struct hd_struct___55 *part;
	long unsigned int start_time;
	struct request_list___51 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___51 *end_io;
	void *end_io_data;
	struct request___51 *next_rq;
};

typedef int elevator_merge_fn___51(struct request_queue___51 *, struct request___51 **, struct bio___52 *);

typedef void elevator_merge_req_fn___51(struct request_queue___51 *, struct request___51 *, struct request___51 *);

typedef void elevator_merged_fn___51(struct request_queue___51 *, struct request___51 *, int);

typedef int elevator_allow_merge_fn___51(struct request_queue___51 *, struct request___51 *, struct bio___52 *);

typedef void elevator_bio_merged_fn___51(struct request_queue___51 *, struct request___51 *, struct bio___52 *);

typedef int elevator_dispatch_fn___51(struct request_queue___51 *, int);

typedef void elevator_add_req_fn___51(struct request_queue___51 *, struct request___51 *);

typedef struct request___51 *elevator_request_list_fn___51(struct request_queue___51 *, struct request___51 *);

typedef void elevator_completed_req_fn___51(struct request_queue___51 *, struct request___51 *);

typedef int elevator_may_queue_fn___51(struct request_queue___51 *, int);

typedef void elevator_init_icq_fn___51(struct io_cq___51 *);

typedef void elevator_exit_icq_fn___51(struct io_cq___51 *);

typedef int elevator_set_req_fn___51(struct request_queue___51 *, struct request___51 *, struct bio___52 *, gfp_t);

typedef void elevator_put_req_fn___51(struct request___51 *);

typedef void elevator_activate_req_fn___51(struct request_queue___51 *, struct request___51 *);

typedef void elevator_deactivate_req_fn___51(struct request_queue___51 *, struct request___51 *);

struct elevator_type___51;

typedef int elevator_init_fn___52(struct request_queue___51 *, struct elevator_type___51 *);

typedef void elevator_exit_fn___51(struct elevator_queue___51 *);

struct elevator_ops___51 {
	elevator_merge_fn___51 *elevator_merge_fn;
	elevator_merged_fn___51 *elevator_merged_fn;
	elevator_merge_req_fn___51 *elevator_merge_req_fn;
	elevator_allow_merge_fn___51 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___51 *elevator_bio_merged_fn;
	elevator_dispatch_fn___51 *elevator_dispatch_fn;
	elevator_add_req_fn___51 *elevator_add_req_fn;
	elevator_activate_req_fn___51 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___51 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___51 *elevator_completed_req_fn;
	elevator_request_list_fn___51 *elevator_former_req_fn;
	elevator_request_list_fn___51 *elevator_latter_req_fn;
	elevator_init_icq_fn___51 *elevator_init_icq_fn;
	elevator_exit_icq_fn___51 *elevator_exit_icq_fn;
	elevator_set_req_fn___51 *elevator_set_req_fn;
	elevator_put_req_fn___51 *elevator_put_req_fn;
	elevator_may_queue_fn___51 *elevator_may_queue_fn;
	elevator_init_fn___52 *elevator_init_fn;
	elevator_exit_fn___51 *elevator_exit_fn;
};

struct elv_fs_entry___51;

struct elevator_type___51 {
	struct kmem_cache___219 *icq_cache;
	struct elevator_ops___51 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___51 *elevator_attrs;
	char elevator_name[16];
	struct module___140 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___51 {
	struct elevator_type___51 *type;
	void *elevator_data;
	struct kobject___24 kobj;
	struct mutex___238 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___51 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___51 *, char *);
	ssize_t (*store)(struct elevator_queue___51 *, const char *, size_t);
};

struct bvec_merge_data___51 {
	struct block_device___236 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___51 {
	struct request___51 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct module_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___139 *, struct module_kobject___139 *, char *);
	ssize_t (*store)(struct module_attribute___139 *, struct module_kobject___139 *, const char *, size_t);
	void (*setup)(struct module___140 *, const char *);
	int (*test)(struct module___140 *);
	void (*free)(struct module___140 *);
};

struct seq_operations___161 {
	void * (*start)(struct seq_file___161 *, loff_t *);
	void (*stop)(struct seq_file___161 *, void *);
	void * (*next)(struct seq_file___161 *, void *, loff_t *);
	int (*show)(struct seq_file___161 *, void *);
};

struct mddev___2;

struct md_rdev___2 {
	struct list_head same_set;
	sector_t sectors;
	struct mddev___2 *mddev;
	int last_events;
	struct block_device___236 *meta_bdev;
	struct block_device___236 *bdev;
	struct page___235 *sb_page;
	struct page___235 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___24 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	sector_t recovery_offset;
	atomic_t nr_pending;
	atomic_t read_errors;
	struct timespec last_read_error;
	atomic_t corrected_errors;
	struct work_struct del_work;
	struct sysfs_dirent *sysfs_state;
	struct badblocks badblocks;
};

struct md_personality___2;

struct md_thread___2;

struct bitmap___2;

struct mddev___2 {
	void *private;
	struct md_personality___2 *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	int ready;
	struct gendisk___55 *gendisk;
	struct kobject___24 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time_t ctime;
	time_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread___2 *thread;
	struct md_thread___2 *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex___238 open_mutex;
	struct mutex___238 reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	int merge_check_needed;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct sysfs_dirent *sysfs_state;
	struct sysfs_dirent *sysfs_action;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	atomic_t writes_pending;
	struct request_queue___51 *queue;
	struct bitmap___2 *bitmap;
	struct {
		struct file___236 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex___238 mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	struct attribute_group___195 *to_remove;
	struct bio_set___52 *bio_set;
	struct bio___52 *flush_bio;
	atomic_t flush_pending;
	struct work_struct flush_work;
	struct work_struct event_work;
	void (*sync_super)(struct mddev___2 *, struct md_rdev___2 *);
};

struct md_personality___2 {
	char *name;
	int level;
	struct list_head list;
	struct module___140 *owner;
	void (*make_request)(struct mddev___2 *, struct bio___52 *);
	int (*run)(struct mddev___2 *);
	void (*free)(struct mddev___2 *, void *);
	void (*status)(struct seq_file___161 *, struct mddev___2 *);
	void (*error_handler)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_add_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_remove_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*spare_active)(struct mddev___2 *);
	sector_t (*sync_request)(struct mddev___2 *, sector_t, int *);
	int (*resize)(struct mddev___2 *, sector_t);
	sector_t (*size)(struct mddev___2 *, sector_t, int);
	int (*check_reshape)(struct mddev___2 *);
	int (*start_reshape)(struct mddev___2 *);
	void (*finish_reshape)(struct mddev___2 *);
	void (*quiesce)(struct mddev___2 *, int);
	void * (*takeover)(struct mddev___2 *);
	int (*congested)(struct mddev___2 *, int);
	int (*mergeable_bvec)(struct mddev___2 *, struct bvec_merge_data___51 *, struct bio_vec___52 *);
};

struct md_thread___2 {
	void (*run)(struct md_thread___2 *);
	struct mddev___2 *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___237 *tsk;
	long unsigned int timeout;
	void *private;
};

struct bitmap_storage___2 {
	struct file___236 *file;
	struct page___235 *sb_page;
	struct page___235 **filemap;
	long unsigned int *filemap_attr;
	long unsigned int file_pages;
	long unsigned int bytes;
};

struct bitmap___2 {
	struct bitmap_counts counts;
	struct mddev___2 *mddev;
	__u64 events_cleared;
	int need_sync;
	struct bitmap_storage___2 storage;
	long unsigned int flags;
	int allclean;
	atomic_t behind_writes;
	long unsigned int behind_writes_used;
	long unsigned int daemon_lastrun;
	long unsigned int last_end_sync;
	atomic_t pending_writes;
	wait_queue_head_t write_wait;
	wait_queue_head_t overflow_wait;
	wait_queue_head_t behind_wait;
	struct sysfs_dirent *sysfs_can_clear;
};

struct md_sysfs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct mddev___2 *, char *);
	ssize_t (*store)(struct mddev___2 *, const char *, size_t);
};

typedef __u16 bitmap_counter_t;

enum bitmap_state {
	BITMAP_STALE = 1,
	BITMAP_WRITE_ERROR = 2,
	BITMAP_HOSTENDIAN = 15,
};

struct bitmap_super_s {
	__le32 magic;
	__le32 version;
	__u8 uuid[16];
	__le64 events;
	__le64 events_cleared;
	__le64 sync_size;
	__le32 state;
	__le32 chunksize;
	__le32 daemon_sleep;
	__le32 write_behind;
	__le32 sectors_reserved;
	__u8 pad[188];
};

typedef struct bitmap_super_s bitmap_super_t;

enum bitmap_page_attr {
	BITMAP_PAGE_DIRTY = 0,
	BITMAP_PAGE_PENDING = 1,
	BITMAP_PAGE_NEEDWRITE = 2,
};

struct dm_kobject_holder {
	struct kobject___22 kobj;
	struct completion completion;
};

enum {
	EDAC_REPORTING_ENABLED = 0,
	EDAC_REPORTING_DISABLED = 1,
	EDAC_REPORTING_FORCE = 2,
};

struct device___227;

struct dev_pm_ops___227 {
	int (*prepare)(struct device___227 *);
	void (*complete)(struct device___227 *);
	int (*suspend)(struct device___227 *);
	int (*resume)(struct device___227 *);
	int (*freeze)(struct device___227 *);
	int (*thaw)(struct device___227 *);
	int (*poweroff)(struct device___227 *);
	int (*restore)(struct device___227 *);
	int (*suspend_late)(struct device___227 *);
	int (*resume_early)(struct device___227 *);
	int (*freeze_late)(struct device___227 *);
	int (*thaw_early)(struct device___227 *);
	int (*poweroff_late)(struct device___227 *);
	int (*restore_early)(struct device___227 *);
	int (*suspend_noirq)(struct device___227 *);
	int (*resume_noirq)(struct device___227 *);
	int (*freeze_noirq)(struct device___227 *);
	int (*thaw_noirq)(struct device___227 *);
	int (*poweroff_noirq)(struct device___227 *);
	int (*restore_noirq)(struct device___227 *);
	int (*runtime_suspend)(struct device___227 *);
	int (*runtime_resume)(struct device___227 *);
	int (*runtime_idle)(struct device___227 *);
};

struct dev_pm_qos___39;

struct dev_pm_info___39 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___39 *qos;
};

struct device_type___227;

struct bus_type___227;

struct device_driver___227;

struct dev_pm_domain___227;

struct class___227;

struct device_rh___227;

struct device___227 {
	struct device___227 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___227 *type;
	struct mutex___91 mutex;
	struct bus_type___227 *bus;
	struct device_driver___227 *driver;
	void *platform_data;
	struct dev_pm_info___39 power;
	struct dev_pm_domain___227 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___94 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___37 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___227 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___227 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___227 *device_rh;
};

struct dev_pm_qos_request___40;

struct dev_pm_qos___39 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___40 *latency_req;
	struct dev_pm_qos_request___40 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___40 *latency_tolerance_req;
};

struct dev_pm_info_rh___227 {
	void (*set_latency_tolerance)(struct device___227 *, s32);
};

struct dev_pm_domain___227 {
	struct dev_pm_ops___227 ops;
};

struct srcu_notifier_head___2 {
	struct mutex___91 mutex;
	struct srcu_struct srcu;
	struct notifier_block *head;
};

struct bus_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___227 *, char *);
	ssize_t (*store)(struct bus_type___227 *, const char *, size_t);
};

struct device_attribute___227;

struct driver_attribute___227;

struct bus_type___227 {
	const char *name;
	const char *dev_name;
	struct device___227 *dev_root;
	struct bus_attribute___227 *bus_attrs;
	struct device_attribute___227 *dev_attrs;
	struct driver_attribute___227 *drv_attrs;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___227 *, struct device_driver___227 *);
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	int (*probe)(struct device___227 *);
	int (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*online)(struct device___227 *);
	int (*offline)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct device___227 *, struct device_attribute___227 *, char *);
	ssize_t (*store)(struct device___227 *, struct device_attribute___227 *, const char *, size_t);
};

struct driver_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___227 *, char *);
	ssize_t (*store)(struct device_driver___227 *, const char *, size_t);
};

struct device_driver___227 {
	const char *name;
	struct bus_type___227 *bus;
	struct module___47 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___227 *);
	int (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___227 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___227 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
};

struct subsys_interface___3 {
	const char *name;
	struct bus_type___227 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___227 *, struct subsys_interface___3 *);
	int (*remove_dev)(struct device___227 *, struct subsys_interface___3 *);
};

struct class_attribute___227;

struct class___227 {
	const char *name;
	struct module___47 *owner;
	struct class_attribute___227 *class_attrs;
	struct device_attribute___227 *dev_attrs;
	const struct attribute_group___62 **dev_groups;
	struct bin_attribute___62 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *);
	void (*class_release)(struct class___227 *);
	void (*dev_release)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
	struct subsys_private *p;
};

struct class_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct class___227 *, struct class_attribute___227 *, char *);
	ssize_t (*store)(struct class___227 *, struct class_attribute___227 *, const char *, size_t);
	const void * (*namespace)(struct class___227 *, const struct class_attribute___227 *);
};

struct device_rh___227 {
	struct dev_pm_info_rh___227 power;
};

struct cpufreq_governor___2;

struct cpufreq_real_policy___2 {
	unsigned int min;
	unsigned int max;
	unsigned int policy;
	struct cpufreq_governor___2 *governor;
};

struct cpufreq_policy___2;

struct cpufreq_governor___2 {
	char name[16];
	int initialized;
	int (*governor)(struct cpufreq_policy___2 *, unsigned int);
	ssize_t (*show_setspeed)(struct cpufreq_policy___2 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___2 *, unsigned int);
	unsigned int max_transition_latency;
	struct list_head governor_list;
	struct module___47 *owner;
};

struct cpufreq_policy___2 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	unsigned int last_cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	struct cpufreq_governor___2 *governor;
	void *governor_data;
	bool governor_enabled;
	struct work_struct update;
	struct cpufreq_real_policy___2 user_policy;
	struct cpufreq_frequency_table *freq_table;
	struct list_head policy_list;
	struct kobject kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___90 *transition_task;
};

struct freq_attr;

struct cpufreq_driver {
	struct module___47 *owner;
	char name[16];
	u8 flags;
	int (*init)(struct cpufreq_policy___2 *);
	int (*verify)(struct cpufreq_policy___2 *);
	int (*setpolicy)(struct cpufreq_policy___2 *);
	int (*target)(struct cpufreq_policy___2 *, unsigned int, unsigned int);
	int (*target_index)(struct cpufreq_policy___2 *, unsigned int);
	unsigned int (*get_intermediate)(struct cpufreq_policy___2 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___2 *, unsigned int);
	unsigned int (*get)(unsigned int);
	int (*bios_limit)(int, unsigned int *);
	int (*exit)(struct cpufreq_policy___2 *);
	void (*stop_cpu)(struct cpufreq_policy___2 *);
	int (*suspend)(struct cpufreq_policy___2 *);
	int (*resume)(struct cpufreq_policy___2 *);
	struct freq_attr **attr;
	bool boost_supported;
	bool boost_enabled;
	int (*set_boost)(int);
};

struct freq_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___2 *, char *);
	ssize_t (*store)(struct cpufreq_policy___2 *, const char *, size_t);
};

struct global_attr {
	struct attribute attr;
	ssize_t (*show)(struct kobject *, struct attribute *, char *);
	ssize_t (*store)(struct kobject *, struct attribute *, const char *, size_t);
};

struct dev_pm_qos_request___40 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___227 *dev;
};

enum {
	OD_NORMAL_SAMPLE = 0,
	OD_SUB_SAMPLE = 1,
};

struct cpu_dbs_common_info {
	int cpu;
	u64 prev_cpu_idle;
	u64 prev_cpu_wall;
	u64 prev_cpu_nice;
	unsigned int prev_load;
	struct cpufreq_policy___2 *cur_policy;
	struct delayed_work work;
	struct mutex___221 timer_mutex;
	ktime_t time_stamp;
};

struct od_cpu_dbs_info_s {
	struct cpu_dbs_common_info cdbs;
	struct cpufreq_frequency_table *freq_table;
	unsigned int freq_lo;
	unsigned int freq_lo_jiffies;
	unsigned int freq_hi_jiffies;
	unsigned int rate_mult;
	unsigned int sample_type: 1;
};

struct od_dbs_tuners {
	unsigned int ignore_nice_load;
	unsigned int sampling_rate;
	unsigned int sampling_down_factor;
	unsigned int up_threshold;
	unsigned int powersave_bias;
	unsigned int io_is_busy;
};

struct dbs_data;

struct common_dbs_data {
	int governor;
	struct attribute_group___177 *attr_group_gov_sys;
	struct attribute_group___177 *attr_group_gov_pol;
	struct dbs_data *gdbs_data;
	struct cpu_dbs_common_info * (*get_cpu_cdbs)(int);
	void * (*get_cpu_dbs_info_s)(int);
	void (*gov_dbs_timer)(struct work_struct *);
	void (*gov_check_cpu)(int, unsigned int);
	int (*init)(struct dbs_data *);
	void (*exit)(struct dbs_data *);
	void *gov_ops;
};

struct dbs_data {
	struct common_dbs_data *cdata;
	unsigned int min_sampling_rate;
	int usage_count;
	void *tuners;
	struct mutex___221 mutex;
};

struct od_ops {
	void (*powersave_bias_init_cpu)(int);
	unsigned int (*powersave_bias_target)(struct cpufreq_policy___2 *, unsigned int, unsigned int);
	void (*freq_increase)(struct cpufreq_policy___2 *, unsigned int);
};

struct cpufreq_governor___3;

struct cpufreq_real_policy___3 {
	unsigned int min;
	unsigned int max;
	unsigned int policy;
	struct cpufreq_governor___3 *governor;
};

struct cpufreq_policy___3;

struct cpufreq_governor___3 {
	char name[16];
	int initialized;
	int (*governor)(struct cpufreq_policy___3 *, unsigned int);
	ssize_t (*show_setspeed)(struct cpufreq_policy___3 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___3 *, unsigned int);
	unsigned int max_transition_latency;
	struct list_head governor_list;
	struct module___123 *owner;
};

struct cpufreq_policy___3 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	unsigned int last_cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	struct cpufreq_governor___3 *governor;
	void *governor_data;
	bool governor_enabled;
	struct work_struct update;
	struct cpufreq_real_policy___3 user_policy;
	struct cpufreq_frequency_table *freq_table;
	struct list_head policy_list;
	struct kobject___24 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___212 *transition_task;
};

struct freq_attr___2 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___3 *, char *);
	ssize_t (*store)(struct cpufreq_policy___3 *, const char *, size_t);
};

struct cpu_dbs_common_info___2 {
	int cpu;
	u64 prev_cpu_idle;
	u64 prev_cpu_wall;
	u64 prev_cpu_nice;
	unsigned int prev_load;
	struct cpufreq_policy___3 *cur_policy;
	struct delayed_work work;
	struct mutex___213 timer_mutex;
	ktime_t time_stamp;
};

struct cs_cpu_dbs_info_s {
	struct cpu_dbs_common_info___2 cdbs;
	unsigned int down_skip;
	unsigned int requested_freq;
	unsigned int enable: 1;
};

struct cs_dbs_tuners {
	unsigned int ignore_nice_load;
	unsigned int sampling_rate;
	unsigned int sampling_down_factor;
	unsigned int up_threshold;
	unsigned int down_threshold;
	unsigned int freq_step;
};

struct dbs_data___2;

struct common_dbs_data___2 {
	int governor;
	struct attribute_group___169 *attr_group_gov_sys;
	struct attribute_group___169 *attr_group_gov_pol;
	struct dbs_data___2 *gdbs_data;
	struct cpu_dbs_common_info___2 * (*get_cpu_cdbs)(int);
	void * (*get_cpu_dbs_info_s)(int);
	void (*gov_dbs_timer)(struct work_struct *);
	void (*gov_check_cpu)(int, unsigned int);
	int (*init)(struct dbs_data___2 *);
	void (*exit)(struct dbs_data___2 *);
	void *gov_ops;
};

struct dbs_data___2 {
	struct common_dbs_data___2 *cdata;
	unsigned int min_sampling_rate;
	int usage_count;
	void *tuners;
	struct mutex___213 mutex;
};

struct cs_ops {
	struct notifier_block *notifier_block;
};

struct cpufreq_governor___4;

struct cpufreq_real_policy___4 {
	unsigned int min;
	unsigned int max;
	unsigned int policy;
	struct cpufreq_governor___4 *governor;
};

struct cpufreq_policy___4;

struct cpufreq_governor___4 {
	char name[16];
	int initialized;
	int (*governor)(struct cpufreq_policy___4 *, unsigned int);
	ssize_t (*show_setspeed)(struct cpufreq_policy___4 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___4 *, unsigned int);
	unsigned int max_transition_latency;
	struct list_head governor_list;
	struct module___41 *owner;
};

struct cpufreq_policy___4 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	unsigned int last_cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	struct cpufreq_governor___4 *governor;
	void *governor_data;
	bool governor_enabled;
	struct work_struct update;
	struct cpufreq_real_policy___4 user_policy;
	struct cpufreq_frequency_table *freq_table;
	struct list_head policy_list;
	struct kobject___24 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___72 *transition_task;
};

struct cpu_dbs_common_info___3 {
	int cpu;
	u64 prev_cpu_idle;
	u64 prev_cpu_wall;
	u64 prev_cpu_nice;
	unsigned int prev_load;
	struct cpufreq_policy___4 *cur_policy;
	struct delayed_work work;
	struct mutex___73 timer_mutex;
	ktime_t time_stamp;
};

struct od_cpu_dbs_info_s___2 {
	struct cpu_dbs_common_info___3 cdbs;
	struct cpufreq_frequency_table *freq_table;
	unsigned int freq_lo;
	unsigned int freq_lo_jiffies;
	unsigned int freq_hi_jiffies;
	unsigned int rate_mult;
	unsigned int sample_type: 1;
};

struct cs_cpu_dbs_info_s___2 {
	struct cpu_dbs_common_info___3 cdbs;
	unsigned int down_skip;
	unsigned int requested_freq;
	unsigned int enable: 1;
};

struct dbs_data___3;

struct common_dbs_data___3 {
	int governor;
	struct attribute_group___155 *attr_group_gov_sys;
	struct attribute_group___155 *attr_group_gov_pol;
	struct dbs_data___3 *gdbs_data;
	struct cpu_dbs_common_info___3 * (*get_cpu_cdbs)(int);
	void * (*get_cpu_dbs_info_s)(int);
	void (*gov_dbs_timer)(struct work_struct *);
	void (*gov_check_cpu)(int, unsigned int);
	int (*init)(struct dbs_data___3 *);
	void (*exit)(struct dbs_data___3 *);
	void *gov_ops;
};

struct dbs_data___3 {
	struct common_dbs_data___3 *cdata;
	unsigned int min_sampling_rate;
	int usage_count;
	void *tuners;
	struct mutex___73 mutex;
};

struct od_ops___2 {
	void (*powersave_bias_init_cpu)(int);
	unsigned int (*powersave_bias_target)(struct cpufreq_policy___4 *, unsigned int, unsigned int);
	void (*freq_increase)(struct cpufreq_policy___4 *, unsigned int);
};

struct device___228;

struct dev_pm_ops___228 {
	int (*prepare)(struct device___228 *);
	void (*complete)(struct device___228 *);
	int (*suspend)(struct device___228 *);
	int (*resume)(struct device___228 *);
	int (*freeze)(struct device___228 *);
	int (*thaw)(struct device___228 *);
	int (*poweroff)(struct device___228 *);
	int (*restore)(struct device___228 *);
	int (*suspend_late)(struct device___228 *);
	int (*resume_early)(struct device___228 *);
	int (*freeze_late)(struct device___228 *);
	int (*thaw_early)(struct device___228 *);
	int (*poweroff_late)(struct device___228 *);
	int (*restore_early)(struct device___228 *);
	int (*suspend_noirq)(struct device___228 *);
	int (*resume_noirq)(struct device___228 *);
	int (*freeze_noirq)(struct device___228 *);
	int (*thaw_noirq)(struct device___228 *);
	int (*poweroff_noirq)(struct device___228 *);
	int (*restore_noirq)(struct device___228 *);
	int (*runtime_suspend)(struct device___228 *);
	int (*runtime_resume)(struct device___228 *);
	int (*runtime_idle)(struct device___228 *);
};

struct dev_pm_qos___40;

struct dev_pm_info___40 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___40 *qos;
};

struct acpi_device___32;

struct acpi_dev_node___38 {
	union {
		struct acpi_device___32 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___228;

struct bus_type___228;

struct device_driver___228;

struct dev_pm_domain___228;

struct class___228;

struct device_rh___228;

struct device___228 {
	struct device___228 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___228 *type;
	struct mutex___63 mutex;
	struct bus_type___228 *bus;
	struct device_driver___228 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___228 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___94 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___38 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___228 *class;
	const struct attribute_group___46 **groups;
	void (*release)(struct device___228 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___228 *device_rh;
};

struct dev_pm_qos_request___41;

struct dev_pm_qos___40 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___41 *latency_req;
	struct dev_pm_qos_request___41 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___41 *latency_tolerance_req;
};

struct dev_pm_info_rh___228 {
	void (*set_latency_tolerance)(struct device___228 *, s32);
};

struct dev_pm_domain___228 {
	struct dev_pm_ops___228 ops;
};

struct bus_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___228 *, char *);
	ssize_t (*store)(struct bus_type___228 *, const char *, size_t);
};

struct device_attribute___228;

struct driver_attribute___228;

struct bus_type___228 {
	const char *name;
	const char *dev_name;
	struct device___228 *dev_root;
	struct bus_attribute___228 *bus_attrs;
	struct device_attribute___228 *dev_attrs;
	struct driver_attribute___228 *drv_attrs;
	const struct attribute_group___46 **bus_groups;
	const struct attribute_group___46 **dev_groups;
	const struct attribute_group___46 **drv_groups;
	int (*match)(struct device___228 *, struct device_driver___228 *);
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	int (*probe)(struct device___228 *);
	int (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*online)(struct device___228 *);
	int (*offline)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct device___228 *, struct device_attribute___228 *, char *);
	ssize_t (*store)(struct device___228 *, struct device_attribute___228 *, const char *, size_t);
};

struct driver_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___228 *, char *);
	ssize_t (*store)(struct device_driver___228 *, const char *, size_t);
};

struct device_driver___228 {
	const char *name;
	struct bus_type___228 *bus;
	struct module___39 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___228 *);
	int (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	const struct attribute_group___46 **groups;
	const struct dev_pm_ops___228 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___228 {
	const char *name;
	const struct attribute_group___46 **groups;
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
};

struct class_attribute___228;

struct class___228 {
	const char *name;
	struct module___39 *owner;
	struct class_attribute___228 *class_attrs;
	struct device_attribute___228 *dev_attrs;
	const struct attribute_group___46 **dev_groups;
	struct bin_attribute___46 *dev_bin_attrs;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *);
	void (*class_release)(struct class___228 *);
	void (*dev_release)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
	struct subsys_private *p;
};

struct class_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct class___228 *, struct class_attribute___228 *, char *);
	ssize_t (*store)(struct class___228 *, struct class_attribute___228 *, const char *, size_t);
	const void * (*namespace)(struct class___228 *, const struct class_attribute___228 *);
};

struct acpi_scan_handler___32;

struct acpi_hotplug_context___32;

struct acpi_driver___32;

struct acpi_device___32 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___32 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___32 *handler;
	struct acpi_hotplug_context___32 *hp;
	struct acpi_driver___32 *driver;
	void *driver_data;
	struct device___228 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___63 physical_node_lock;
	void (*remove)(struct acpi_device___32 *);
};

struct device_rh___228 {
	struct dev_pm_info_rh___228 power;
};

struct cpufreq_governor___5;

struct cpufreq_real_policy___5 {
	unsigned int min;
	unsigned int max;
	unsigned int policy;
	struct cpufreq_governor___5 *governor;
};

struct cpufreq_policy___5;

struct cpufreq_governor___5 {
	char name[16];
	int initialized;
	int (*governor)(struct cpufreq_policy___5 *, unsigned int);
	ssize_t (*show_setspeed)(struct cpufreq_policy___5 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___5 *, unsigned int);
	unsigned int max_transition_latency;
	struct list_head governor_list;
	struct module___39 *owner;
};

struct cpufreq_policy___5 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	unsigned int last_cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	struct cpufreq_governor___5 *governor;
	void *governor_data;
	bool governor_enabled;
	struct work_struct update;
	struct cpufreq_real_policy___5 user_policy;
	struct cpufreq_frequency_table *freq_table;
	struct list_head policy_list;
	struct kobject___3 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___63 *transition_task;
};

struct freq_attr___3;

struct cpufreq_driver___2 {
	struct module___39 *owner;
	char name[16];
	u8 flags;
	int (*init)(struct cpufreq_policy___5 *);
	int (*verify)(struct cpufreq_policy___5 *);
	int (*setpolicy)(struct cpufreq_policy___5 *);
	int (*target)(struct cpufreq_policy___5 *, unsigned int, unsigned int);
	int (*target_index)(struct cpufreq_policy___5 *, unsigned int);
	unsigned int (*get_intermediate)(struct cpufreq_policy___5 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___5 *, unsigned int);
	unsigned int (*get)(unsigned int);
	int (*bios_limit)(int, unsigned int *);
	int (*exit)(struct cpufreq_policy___5 *);
	void (*stop_cpu)(struct cpufreq_policy___5 *);
	int (*suspend)(struct cpufreq_policy___5 *);
	int (*resume)(struct cpufreq_policy___5 *);
	struct freq_attr___3 **attr;
	bool boost_supported;
	bool boost_enabled;
	int (*set_boost)(int);
};

struct freq_attr___3 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___5 *, char *);
	ssize_t (*store)(struct cpufreq_policy___5 *, const char *, size_t);
};

struct acpi_hotplug_profile___32 {
	struct kobject___3 kobj;
	int (*scan_dependent)(struct acpi_device___32 *);
	void (*notify_online)(struct acpi_device___32 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___32 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___32 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___32 *);
	void (*bind)(struct device___228 *);
	void (*unbind)(struct device___228 *);
	struct acpi_hotplug_profile___32 hotplug;
};

struct acpi_hotplug_context___32 {
	struct acpi_device___32 *self;
	int (*notify)(struct acpi_device___32 *, u32);
	void (*uevent)(struct acpi_device___32 *, u32);
	void (*fixup)(struct acpi_device___32 *);
};

typedef int (*acpi_op_add___32)(struct acpi_device___32 *);

typedef int (*acpi_op_remove___32)(struct acpi_device___32 *);

typedef void (*acpi_op_notify___32)(struct acpi_device___32 *, u32);

struct acpi_device_ops___32 {
	acpi_op_add___32 add;
	acpi_op_remove___32 remove;
	acpi_op_notify___32 notify;
};

struct acpi_driver___32 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___32 ops;
	struct device_driver___228 drv;
	struct module___39 *owner;
};

struct dev_pm_qos_request___41 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___228 *dev;
};

struct sample {
	int32_t core_pct_busy;
	u64 aperf;
	u64 mperf;
	int freq;
	ktime_t time;
};

struct pstate_data {
	int current_pstate;
	int min_pstate;
	int max_pstate;
	int scaling;
	int turbo_pstate;
};

struct vid_data {
	int min;
	int max;
	int turbo;
	int32_t ratio;
};

struct _pid {
	int setpoint;
	int32_t integral;
	int32_t p_gain;
	int32_t i_gain;
	int32_t d_gain;
	int deadband;
	int32_t last_err;
};

struct cpudata {
	int cpu;
	unsigned int policy;
	struct timer_list timer;
	struct pstate_data pstate;
	struct vid_data vid;
	struct _pid pid;
	ktime_t last_sample_time;
	u64 prev_aperf;
	u64 prev_mperf;
	struct sample sample;
	int32_t max_perf;
	int32_t min_perf;
	int max_policy_pct;
	int min_policy_pct;
	int max_perf_pct;
	int min_perf_pct;
};

struct pstate_adjust_policy {
	int sample_rate_ms;
	int deadband;
	int setpoint;
	int p_gain_pct;
	int d_gain_pct;
	int i_gain_pct;
};

struct pstate_funcs {
	int (*get_max)();
	int (*get_min)();
	int (*get_turbo)();
	int (*get_scaling)();
	void (*set)(struct cpudata *, int);
	void (*get_vid)(struct cpudata *);
};

struct cpu_defaults {
	struct pstate_adjust_policy pid_policy;
	struct pstate_funcs funcs;
};

struct perf_limits {
	int no_turbo;
	int turbo_disabled;
	int max_sysfs_pct;
	int min_sysfs_pct;
};

struct pid_param {
	char *name;
	void *value;
};

struct thermal_cooling_device_ops___4;

struct thermal_cooling_device___4 {
	int id;
	char type[20];
	struct device___228 device;
	void *devdata;
	const struct thermal_cooling_device_ops___4 *ops;
	bool updated;
	struct mutex___63 lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___4 {
	int (*get_max_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___4 *, long unsigned int);
};

struct acpi_processor___3;

struct acpi_processor_throttling___3 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___3 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___3 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___3 {
	acpi_handle handle;
	u32 acpi_id;
	u32 phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___3 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___4 *cdev;
	struct device___228 *dev;
};

enum {
	PSS = 0,
	PPC = 1,
};

struct hw_vendor_info {
	u16 valid;
	char oem_id[6];
	char oem_table_id[8];
	int oem_pwr_table;
};

struct cpuidle_driver___3;

struct cpuidle_state___3 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___3 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
};

struct cpuidle_driver___3 {
	const char *name;
	struct module___140 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___3 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct cpuidle_governor {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver___3 *, struct cpuidle_device *);
	void (*disable)(struct cpuidle_driver___3 *, struct cpuidle_device *);
	int (*select)(struct cpuidle_driver___3 *, struct cpuidle_device *);
	void (*reflect)(struct cpuidle_device *, int);
	struct module___140 *owner;
};

struct cpuidle_state_kobj {
	struct cpuidle_state___3 *state;
	struct cpuidle_state_usage *state_usage;
	struct completion kobj_unregister;
	struct kobject___24 kobj;
};

struct cpuidle_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_device *, char *);
	ssize_t (*store)(struct cpuidle_device *, const char *, size_t);
};

struct cpuidle_state_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_state___3 *, struct cpuidle_state_usage *, char *);
	ssize_t (*store)(struct cpuidle_state___3 *, struct cpuidle_state_usage *, const char *, size_t);
};

struct cpuidle_governor___2 {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver *, struct cpuidle_device *);
	void (*disable)(struct cpuidle_driver *, struct cpuidle_device *);
	int (*select)(struct cpuidle_driver *, struct cpuidle_device *);
	void (*reflect)(struct cpuidle_device *, int);
	struct module___107 *owner;
};

struct menu_device {
	int last_state_idx;
	int needs_update;
	unsigned int expected_us;
	u64 predicted_us;
	unsigned int exit_us;
	unsigned int bucket;
	u64 correction_factor[12];
	u32 intervals[8];
	int interval_ptr;
};

struct sdhci_pci_data {
	struct pci_dev___2 *pdev;
	int slotno;
	int rst_n_gpio;
	int cd_gpio;
	int (*setup)(struct sdhci_pci_data *);
	void (*cleanup)(struct sdhci_pci_data *);
};

struct led_trigger___3;

struct led_classdev___3 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___3 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___3 *);
	int (*blink_set)(struct led_classdev___3 *, long unsigned int *, long unsigned int *);
	struct device___188 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___3 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___3 {
	const char *name;
	void (*activate)(struct led_classdev___3 *);
	void (*deactivate)(struct led_classdev___3 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct mmc_data;

struct mmc_request;

struct mmc_command {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	unsigned int error;
	unsigned int cmd_timeout_ms;
	struct mmc_data *data;
	struct mmc_request *mrq;
};

struct mmc_data {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command *stop;
	struct mmc_request *mrq;
	unsigned int sg_len;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_host;

struct mmc_request {
	struct mmc_command *sbc;
	struct mmc_command *cmd;
	struct mmc_data *data;
	struct mmc_command *stop;
	struct completion completion;
	void (*done)(struct mmc_request *);
	struct mmc_host *host;
};

typedef unsigned int mmc_pm_flag_t;

struct mmc_ios {
	unsigned int clock;
	short unsigned int vdd;
	unsigned char bus_mode;
	unsigned char chip_select;
	unsigned char power_mode;
	unsigned char bus_width;
	unsigned char timing;
	unsigned char signal_voltage;
	unsigned char drv_type;
};

struct mmc_card;

struct mmc_slot {
	int cd_irq;
	struct mutex___221 lock;
	void *handler_priv;
};

struct mmc_bus_ops;

struct regulator;

struct mmc_supply {
	struct regulator *vmmc;
	struct regulator *vqmmc;
};

struct mmc_context_info {
	bool is_done_rcv;
	bool is_new_req;
	bool is_waiting_last_req;
	wait_queue_head_t wait;
	spinlock_t lock;
};

struct mmc_host_ops;

struct mmc_async_req;

struct mmc_host {
	struct device___188 *parent;
	struct device___188 class_dev;
	int index;
	const struct mmc_host_ops *ops;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct notifier_block pm_notify;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_discard_to;
	spinlock_t lock;
	struct mmc_ios ios;
	u32 ocr;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int bus_dead: 1;
	int rescan_disable;
	int rescan_entered;
	struct mmc_card *card;
	wait_queue_head_t wq;
	struct task_struct___220 *claimer;
	int claim_cnt;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops *bus_ops;
	unsigned int bus_refs;
	unsigned int sdio_irqs;
	struct task_struct___220 *sdio_irq_thread;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___3 *led;
	struct mmc_supply supply;
	struct dentry___141 *debugfs_root;
	struct mmc_async_req *areq;
	struct mmc_context_info context_info;
	unsigned int actual_clock;
	unsigned int slotno;
	long: 64;
	long unsigned int private[0];
};

struct mmc_host_ops {
	int (*enable)(struct mmc_host *);
	int (*disable)(struct mmc_host *);
	void (*post_req)(struct mmc_host *, struct mmc_request *, int);
	void (*pre_req)(struct mmc_host *, struct mmc_request *, bool);
	void (*request)(struct mmc_host *, struct mmc_request *);
	void (*set_ios)(struct mmc_host *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host *);
	int (*get_cd)(struct mmc_host *);
	void (*enable_sdio_irq)(struct mmc_host *, int);
	void (*init_card)(struct mmc_host *, struct mmc_card *);
	int (*start_signal_voltage_switch)(struct mmc_host *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host *);
	int (*execute_tuning)(struct mmc_host *, u32);
	int (*select_drive_strength)(unsigned int, int, int);
	void (*hw_reset)(struct mmc_host *);
	void (*card_event)(struct mmc_host *);
};

struct mmc_async_req {
	struct mmc_request *mrq;
	int (*err_check)(struct mmc_card *, struct mmc_async_req *);
};

struct sdhci_ops;

struct sdhci_host {
	const char *hw_name;
	unsigned int quirks;
	unsigned int quirks2;
	int irq;
	void *ioaddr;
	const struct sdhci_ops *ops;
	struct regulator *vmmc;
	struct regulator *vqmmc;
	struct mmc_host *mmc;
	u64 dma_mask;
	struct led_classdev___3 led;
	char led_name[32];
	spinlock_t lock;
	int flags;
	unsigned int version;
	unsigned int max_clk;
	unsigned int timeout_clk;
	unsigned int clk_mul;
	unsigned int clock;
	u8 pwr;
	bool runtime_suspended;
	struct mmc_request *mrq;
	struct mmc_command *cmd;
	struct mmc_data *data;
	unsigned int data_early: 1;
	struct sg_mapping_iter sg_miter;
	unsigned int blocks;
	int sg_count;
	u8 *adma_desc;
	u8 *align_buffer;
	dma_addr_t adma_addr;
	dma_addr_t align_addr;
	struct tasklet_struct card_tasklet;
	struct tasklet_struct finish_tasklet;
	struct timer_list timer;
	u32 caps;
	u32 caps1;
	unsigned int ocr_avail_sdio;
	unsigned int ocr_avail_sd;
	unsigned int ocr_avail_mmc;
	wait_queue_head_t buf_ready_int;
	unsigned int tuning_done;
	unsigned int tuning_count;
	unsigned int tuning_mode;
	struct timer_list tuning_timer;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct sdhci_ops {
	void (*set_clock)(struct sdhci_host *, unsigned int);
	int (*enable_dma)(struct sdhci_host *);
	unsigned int (*get_max_clock)(struct sdhci_host *);
	unsigned int (*get_min_clock)(struct sdhci_host *);
	unsigned int (*get_timeout_clock)(struct sdhci_host *);
	int (*platform_bus_width)(struct sdhci_host *, int);
	void (*platform_send_init_74_clocks)(struct sdhci_host *, u8);
	unsigned int (*get_ro)(struct sdhci_host *);
	void (*platform_reset_enter)(struct sdhci_host *, u8);
	void (*platform_reset_exit)(struct sdhci_host *, u8);
	int (*set_uhs_signaling)(struct sdhci_host *, unsigned int);
	void (*hw_reset)(struct sdhci_host *);
	void (*platform_suspend)(struct sdhci_host *);
	void (*platform_resume)(struct sdhci_host *);
	void (*adma_workaround)(struct sdhci_host *, u32);
	void (*platform_init)(struct sdhci_host *);
};

struct sdhci_pci_chip;

struct sdhci_pci_slot;

struct sdhci_pci_fixes {
	unsigned int quirks;
	unsigned int quirks2;
	bool allow_runtime_pm;
	int (*probe)(struct sdhci_pci_chip *);
	int (*probe_slot)(struct sdhci_pci_slot *);
	void (*remove_slot)(struct sdhci_pci_slot *, int);
	int (*suspend)(struct sdhci_pci_chip *);
	int (*resume)(struct sdhci_pci_chip *);
};

struct sdhci_pci_chip {
	struct pci_dev___23 *pdev;
	unsigned int quirks;
	unsigned int quirks2;
	bool allow_runtime_pm;
	const struct sdhci_pci_fixes *fixes;
	int num_slots;
	struct sdhci_pci_slot *slots[8];
};

struct sdhci_pci_data___2;

struct sdhci_pci_slot {
	struct sdhci_pci_chip *chip;
	struct sdhci_host *host;
	struct sdhci_pci_data___2 *data;
	int pci_bar;
	int rst_n_gpio;
	int cd_gpio;
	int cd_irq;
	void (*hw_reset)(struct sdhci_host *);
};

struct dmi_memdev_info {
	const char *device;
	const char *bank;
	u16 handle;
};

struct dmi_sysfs_entry {
	struct dmi_header dh;
	struct kobject___24 kobj;
	int instance;
	int position;
	struct list_head list;
	struct kobject___24 *child;
};

struct dmi_sysfs_attribute {
	struct attribute attr;
	ssize_t (*show)(struct dmi_sysfs_entry *, char *);
};

struct dmi_sysfs_mapped_attribute {
	struct attribute attr;
	ssize_t (*show)(struct dmi_sysfs_entry *, const struct dmi_header *, char *);
};

typedef ssize_t (*dmi_callback)(struct dmi_sysfs_entry *, const struct dmi_header *, void *);

struct find_dmi_data {
	struct dmi_sysfs_entry *entry;
	dmi_callback callback;
	void *private;
	int instance_countdown;
	ssize_t ret;
};

struct dmi_read_state {
	char *buf;
	loff_t pos;
	size_t count;
};

struct dmi_entry_attr_show_data {
	struct attribute *attr;
	char *buf;
};

struct dmi_system_event_log {
	struct dmi_header header;
	u16 area_length;
	u16 header_start_offset;
	u16 data_start_offset;
	u8 access_method;
	u8 status;
	u32 change_token;
	union {
		struct {
			u16 index_addr;
			u16 data_addr;
		} io;
		u32 phys_addr32;
		u16 gpnv_handle;
		u32 access_method_address;
	};
	u8 header_format;
	u8 type_descriptors_supported_count;
	u8 per_log_type_descriptor_length;
	u8 supported_log_type_descriptos[0];
} __attribute__((packed));

typedef u8 (*sel_io_reader)(const struct dmi_system_event_log *, loff_t);

struct dmi_device_attribute {
	struct device_attribute___227 dev_attr;
	int field;
};

struct mafield {
	const char *prefix;
	int field;
};

struct page___236;

typedef struct page___236 *pgtable_t___236;

struct address_space___237;

struct kmem_cache___220;

struct page___236 {
	long unsigned int flags;
	struct address_space___237 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___236 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___236 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___220 *slab_cache;
		struct page___236 *first_page;
	};
	long: 64;
};

struct task_struct___238;

struct pv_cpu_ops___238 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___82 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___82 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___238 *);
	void (*end_context_switch)(struct task_struct___238 *);
};

struct mutex___239 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___238 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___231 {
	struct page___236 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___245;

struct signal_struct___238;

struct bio_list___52;

struct backing_dev_info___63;

struct io_context___52;

struct task_struct___238 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___238 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___245 *mm;
	struct mm_struct___245 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___238 *real_parent;
	struct task_struct___238 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___238 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___92 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___238 = 0,
		VTIME_USER___238 = 1,
		VTIME_SYS___238 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___82 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___238 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___52 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___63 *backing_dev_info;
	struct io_context___52 *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___239 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___231 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___245 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___245 *, struct mm_struct___245 *);
	void (*dup_mmap)(struct mm_struct___245 *, struct mm_struct___245 *);
	void (*exit_mmap)(struct mm_struct___245 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___245 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___245 *);
	void (*pgd_free)(struct mm_struct___245 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___245 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___245 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___245 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___245 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___245 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___245 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___245 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___245 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___245 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___245 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___245 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___239 lock;
	void *vdso;
} mm_context_t___239;

struct xol_area___236;

struct uprobes_state___236 {
	struct xol_area___236 *xol_area;
};

struct vm_area_struct___245;

struct file___237;

struct core_state___238;

struct mm_struct___245 {
	struct vm_area_struct___245 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___245 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___245 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___239 context;
	long unsigned int flags;
	struct core_state___238 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___238 *owner;
	struct file___237 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___236 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___141;

struct module_kobject___140 {
	struct kobject___24 kobj;
	struct module___141 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___140;

struct module___141 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___140 mkobj;
	struct module_attribute___140 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___238 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___238;

struct lruvec___238 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___238 *zone;
};

struct pglist_data___238;

struct zone___238 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___238 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___238 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___238 {
	struct zone___238 *zone;
	int zone_idx;
};

struct zonelist___238 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___238 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___238 {
	struct zone___238 node_zones[4];
	struct zonelist___238 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___238 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___157;

struct x86_io_apic_ops___157 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___157 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___157;

struct irq_data___157 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___157 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___229;

struct dev_pm_ops___229 {
	int (*prepare)(struct device___229 *);
	void (*complete)(struct device___229 *);
	int (*suspend)(struct device___229 *);
	int (*resume)(struct device___229 *);
	int (*freeze)(struct device___229 *);
	int (*thaw)(struct device___229 *);
	int (*poweroff)(struct device___229 *);
	int (*restore)(struct device___229 *);
	int (*suspend_late)(struct device___229 *);
	int (*resume_early)(struct device___229 *);
	int (*freeze_late)(struct device___229 *);
	int (*thaw_early)(struct device___229 *);
	int (*poweroff_late)(struct device___229 *);
	int (*restore_early)(struct device___229 *);
	int (*suspend_noirq)(struct device___229 *);
	int (*resume_noirq)(struct device___229 *);
	int (*freeze_noirq)(struct device___229 *);
	int (*thaw_noirq)(struct device___229 *);
	int (*poweroff_noirq)(struct device___229 *);
	int (*restore_noirq)(struct device___229 *);
	int (*runtime_suspend)(struct device___229 *);
	int (*runtime_resume)(struct device___229 *);
	int (*runtime_idle)(struct device___229 *);
};

struct dma_map_ops___95;

struct dev_archdata___95 {
	struct dma_map_ops___95 *dma_ops;
	void *iommu;
};

struct acpi_device___33;

struct acpi_dev_node___39 {
	union {
		struct acpi_device___33 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

struct device_type___229;

struct bus_type___229;

struct device_driver___229;

struct dev_pm_domain___229;

struct class___229;

struct attribute_group___196;

struct device_rh___229;

struct device___229 {
	struct device___229 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___229 *type;
	struct mutex___239 mutex;
	struct bus_type___229 *bus;
	struct device_driver___229 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___229 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___95 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___229 *class;
	const struct attribute_group___196 **groups;
	void (*release)(struct device___229 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___229 *device_rh;
};

struct dev_pm_info_rh___229 {
	void (*set_latency_tolerance)(struct device___229 *, s32);
};

struct dev_pm_domain___229 {
	struct dev_pm_ops___229 ops;
};

struct smp_ops___238 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___238 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___236 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___236 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___219;

struct memcg_cache_params___220;

struct kmem_cache___220 {
	struct kmem_cache_cpu___219 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___220 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___237;

struct address_space_operations___237;

struct address_space___237 {
	struct inode___237 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___239 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___237 *a_ops;
	long unsigned int flags;
	struct backing_dev_info___63 *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___237;

struct path___237 {
	struct vfsmount *mnt;
	struct dentry___237 *dentry;
};

struct file_operations___237;

struct file___237 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___237 f_path;
	struct inode___237 *f_inode;
	const struct file_operations___237 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___237 *f_mapping;
	struct mutex___239 f_pos_lock;
};

struct vm_operations_struct___211;

struct vm_area_struct___245 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___245 *vm_next;
	struct vm_area_struct___245 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___245 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___211 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___237 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___207;

struct vm_operations_struct___211 {
	void (*open)(struct vm_area_struct___245 *);
	void (*close)(struct vm_area_struct___245 *);
	int (*fault)(struct vm_area_struct___245 *, struct vm_fault___207 *);
	int (*page_mkwrite)(struct vm_area_struct___245 *, struct vm_fault___207 *);
	int (*access)(struct vm_area_struct___245 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___245 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___245 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___245 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___245 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___238 {
	struct task_struct___238 *task;
	struct core_thread___238 *next;
};

struct core_state___238 {
	atomic_t nr_threads;
	struct core_thread___238 dumper;
	struct completion startup;
};

struct signal_struct___238 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___238 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___238 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___92 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___239 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___53;

struct bio_list___52 {
	struct bio___53 *head;
	struct bio___53 *tail;
};

struct bdi_writeback___63 {
	struct backing_dev_info___63 *bdi;
	unsigned int nr;
	long unsigned int last_old_flush;
	struct delayed_work dwork;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
};

struct backing_dev_info___63 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int state;
	unsigned int capabilities;
	congested_fn *congested_fn;
	void *congested_data;
	char *name;
	struct percpu_counter bdi_stat[4];
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	struct bdi_writeback___63 wb;
	spinlock_t wb_lock;
	struct list_head work_list;
	struct device___229 *dev;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___237 *debug_dir;
	struct dentry___237 *debug_stats;
};

struct io_cq___52;

struct io_context___52 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct radix_tree_root icq_tree;
	struct io_cq___52 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct bin_attribute___198;

struct attribute_group___196 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___198 **bin_attrs;
};

struct bin_attribute___198 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___237 *, struct kobject___24 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___237 *, struct kobject___24 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	int (*mmap)(struct file___237 *, struct kobject___24 *, struct bin_attribute___198 *, struct vm_area_struct___245 *);
};

struct kmem_cache_cpu___219 {
	void **freelist;
	long unsigned int tid;
	struct page___236 *page;
	struct page___236 *partial;
};

struct memcg_cache_params___220 {
	bool is_root_cache;
	union {
		struct kmem_cache___220 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___220 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___95 {
	void * (*alloc)(struct device___229 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___229 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___229 *, struct vm_area_struct___245 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___229 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___229 *, struct page___236 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___229 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___229 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___229 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___229 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___229 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___229 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___229 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___229 *, dma_addr_t);
	int (*dma_supported)(struct device___229 *, u64);
	int (*set_dma_mask)(struct device___229 *, u64);
	int is_phys;
};

struct bus_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___229 *, char *);
	ssize_t (*store)(struct bus_type___229 *, const char *, size_t);
};

struct device_attribute___229;

struct driver_attribute___229;

struct bus_type___229 {
	const char *name;
	const char *dev_name;
	struct device___229 *dev_root;
	struct bus_attribute___229 *bus_attrs;
	struct device_attribute___229 *dev_attrs;
	struct driver_attribute___229 *drv_attrs;
	const struct attribute_group___196 **bus_groups;
	const struct attribute_group___196 **dev_groups;
	const struct attribute_group___196 **drv_groups;
	int (*match)(struct device___229 *, struct device_driver___229 *);
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	int (*probe)(struct device___229 *);
	int (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*online)(struct device___229 *);
	int (*offline)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct device___229 *, struct device_attribute___229 *, char *);
	ssize_t (*store)(struct device___229 *, struct device_attribute___229 *, const char *, size_t);
};

struct driver_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___229 *, char *);
	ssize_t (*store)(struct device_driver___229 *, const char *, size_t);
};

struct device_driver___229 {
	const char *name;
	struct bus_type___229 *bus;
	struct module___141 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___229 *);
	int (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	const struct attribute_group___196 **groups;
	const struct dev_pm_ops___229 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___229 {
	const char *name;
	const struct attribute_group___196 **groups;
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
};

struct class_attribute___229;

struct class___229 {
	const char *name;
	struct module___141 *owner;
	struct class_attribute___229 *class_attrs;
	struct device_attribute___229 *dev_attrs;
	const struct attribute_group___196 **dev_groups;
	struct bin_attribute___198 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *);
	void (*class_release)(struct class___229 *);
	void (*dev_release)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
	struct subsys_private *p;
};

struct class_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct class___229 *, struct class_attribute___229 *, char *);
	ssize_t (*store)(struct class___229 *, struct class_attribute___229 *, const char *, size_t);
	const void * (*namespace)(struct class___229 *, const struct class_attribute___229 *);
};

struct acpi_scan_handler___33;

struct acpi_hotplug_context___33;

struct acpi_driver___33;

struct acpi_device___33 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___33 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___33 *handler;
	struct acpi_hotplug_context___33 *hp;
	struct acpi_driver___33 *driver;
	void *driver_data;
	struct device___229 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___239 physical_node_lock;
	void (*remove)(struct acpi_device___33 *);
};

struct device_rh___229 {
	struct dev_pm_info_rh___229 power;
};

struct dentry_operations___237;

struct super_block___237;

struct dentry___237 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___237 *d_parent;
	struct qstr d_name;
	struct inode___237 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___237 *d_op;
	struct super_block___237 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___237;

struct file_lock___237;

struct dquot___237;

struct block_device___237;

struct cdev___65;

struct inode___237 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___237 *i_op;
	struct super_block___237 *i_sb;
	struct address_space___237 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___239 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___237 *i_fop;
	struct file_lock___237 *i_flock;
	struct address_space___237 i_data;
	struct dquot___237 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___237 *i_bdev;
		struct cdev___65 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___237 {
	int (*d_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_hash)(const struct dentry___237 *, struct qstr *);
	int (*d_compare)(const struct dentry___237 *, const struct dentry___237 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___237 *);
	void (*d_release)(struct dentry___237 *);
	void (*d_prune)(struct dentry___237 *);
	void (*d_iput)(struct dentry___237 *, struct inode___237 *);
	char * (*d_dname)(struct dentry___237 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___237 *);
	int (*d_manage)(struct dentry___237 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___237;

struct mem_dqinfo___237 {
	struct quota_format_type___237 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___237;

struct quota_info___237 {
	unsigned int flags;
	struct mutex___239 dqio_mutex;
	struct mutex___239 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___237 *files[2];
	struct mem_dqinfo___237 info[2];
	const struct quota_format_ops___237 *ops[2];
};

struct file_system_type___237;

struct super_operations___237;

struct dquot_operations___237;

struct quotactl_ops___237;

struct super_block___237 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___237 *s_type;
	const struct super_operations___237 *s_op;
	const struct dquot_operations___237 *dq_op;
	const struct quotactl_ops___237 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___237 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___237 *s_bdev;
	struct backing_dev_info___63 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___237 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___239 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___237 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___53(struct bio___53 *, int);

struct bio_vec___53 {
	struct page___236 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___53;

struct bio_set___53;

struct bio___53 {
	sector_t bi_sector;
	struct bio___53 *bi_next;
	struct block_device___237 *bi_bdev;
	long unsigned int bi_flags;
	long unsigned int bi_rw;
	short unsigned int bi_vcnt;
	short unsigned int bi_idx;
	unsigned int bi_phys_segments;
	unsigned int bi_size;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	bio_end_io_t___53 *bi_end_io;
	void *bi_private;
	struct io_context___52 *bi_ioc;
	struct cgroup_subsys_state___69 *bi_css;
	struct bio_integrity_payload___53 *bi_integrity;
	unsigned int bi_max_vecs;
	atomic_t bi_cnt;
	struct bio_vec___53 *bi_io_vec;
	struct bio_set___53 *bi_pool;
	union {
		struct bio_aux *bio_aux;
		struct {
			void *rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct bio_vec___53 bi_inline_vecs[0];
};

struct hd_struct___56;

struct gendisk___56;

struct request_queue___52;

struct block_device___237 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___237 *bd_inode;
	struct super_block___237 *bd_super;
	struct mutex___239 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___237 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct___56 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___56 *bd_disk;
	struct request_queue___52 *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___239 bd_fsfreeze_mutex;
};

struct bio_integrity_payload___53 {
	struct bio___53 *bip_bio;
	sector_t bip_sector;
	void *bip_buf;
	bio_end_io_t___53 *bip_end_io;
	unsigned int bip_size;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_idx;
	unsigned int bip_owns_buf: 1;
	struct work_struct bip_work;
	struct bio_vec___53 *bip_vec;
	struct bio_vec___53 bip_inline_vecs[0];
};

struct bio_set___53 {
	struct kmem_cache___220 *bio_slab;
	unsigned int front_pad;
	mempool_t *bio_pool;
	mempool_t *bvec_pool;
	mempool_t *bio_integrity_pool;
	mempool_t *bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___52 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
};

struct iattr___237 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___237 *ia_file;
};

struct dquot___237 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___239 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___237 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___237 {
	int qf_fmt_id;
	const struct quota_format_ops___237 *qf_ops;
	struct module___141 *qf_owner;
	struct quota_format_type___237 *qf_next;
};

struct quota_format_ops___237 {
	int (*check_quota_file)(struct super_block___237 *, int);
	int (*read_file_info)(struct super_block___237 *, int);
	int (*write_file_info)(struct super_block___237 *, int);
	int (*free_file_info)(struct super_block___237 *, int);
	int (*read_dqblk)(struct dquot___237 *);
	int (*commit_dqblk)(struct dquot___237 *);
	int (*release_dqblk)(struct dquot___237 *);
};

struct dquot_operations___237 {
	int (*write_dquot)(struct dquot___237 *);
	struct dquot___237 * (*alloc_dquot)(struct super_block___237 *, int);
	void (*destroy_dquot)(struct dquot___237 *);
	int (*acquire_dquot)(struct dquot___237 *);
	int (*release_dquot)(struct dquot___237 *);
	int (*mark_dirty)(struct dquot___237 *);
	int (*write_info)(struct super_block___237 *, int);
	qsize_t * (*get_reserved_space)(struct inode___237 *);
};

struct quotactl_ops___237 {
	int (*quota_on)(struct super_block___237 *, int, int, struct path___237 *);
	int (*quota_on_meta)(struct super_block___237 *, int, int);
	int (*quota_off)(struct super_block___237 *, int);
	int (*quota_sync)(struct super_block___237 *, int);
	int (*get_info)(struct super_block___237 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___237 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___237 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___237 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___237 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___237 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___237 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___237 *, unsigned int);
};

struct address_space_operations___237 {
	int (*writepage)(struct page___236 *, struct writeback_control *);
	int (*readpage)(struct file___237 *, struct page___236 *);
	int (*writepages)(struct address_space___237 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___236 *);
	int (*readpages)(struct file___237 *, struct address_space___237 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___237 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___236 **, void **);
	int (*write_end)(struct file___237 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___236 *, void *);
	sector_t (*bmap)(struct address_space___237 *, sector_t);
	void (*invalidatepage)(struct page___236 *, long unsigned int);
	int (*releasepage)(struct page___236 *, gfp_t);
	void (*freepage)(struct page___236 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___237 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___237 *, struct page___236 *, struct page___236 *, enum migrate_mode);
	int (*launder_page)(struct page___236 *);
	int (*is_partially_uptodate)(struct page___236 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___236 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___237 *, struct page___236 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___237 *, sector_t *);
	void (*swap_deactivate)(struct file___237 *);
	void (*invalidatepage_range)(struct page___236 *, unsigned int, unsigned int);
};

struct hd_struct___56 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___229 __dev;
	struct kobject___24 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	atomic_t in_flight[2];
	struct disk_stats *dkstats;
	atomic_t ref;
	struct callback_head callback_head;
};

struct disk_part_tbl___56;

struct block_device_operations___52;

struct gendisk___56 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___56 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___56 *part_tbl;
	struct hd_struct___56 part0;
	const struct block_device_operations___52 *fops;
	struct request_queue___52 *queue;
	void *private_data;
	int flags;
	struct device___229 *driverfs_dev;
	struct kobject___24 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct blk_integrity___4 *integrity;
	int node_id;
};

struct request_list___52 {
	struct request_queue___52 *q;
	struct blkcg_gq *blkg;
	int count[2];
	int starved[2];
	mempool_t *rq_pool;
	wait_queue_head_t wait[2];
	unsigned int flags;
};

typedef void request_fn_proc___52(struct request_queue___52 *);

typedef void make_request_fn___52(struct request_queue___52 *, struct bio___53 *);

struct request___52;

typedef int prep_rq_fn___52(struct request_queue___52 *, struct request___52 *);

struct bvec_merge_data___52;

typedef int merge_bvec_fn___53(struct request_queue___52 *, struct bvec_merge_data___52 *, struct bio_vec___53 *);

typedef void softirq_done_fn___52(struct request___52 *);

typedef enum blk_eh_timer_return rq_timed_out_fn___52(struct request___52 *);

typedef int dma_drain_needed_fn___52(struct request___52 *);

typedef int lld_busy_fn___52(struct request_queue___52 *);

struct bsg_class_device___52 {
	struct device___229 *class_dev;
	struct device___229 *parent;
	int minor;
	struct request_queue___52 *queue;
	struct kref ref;
	void (*release)(struct device___229 *);
};

typedef void unprep_rq_fn___52(struct request_queue___52 *, struct request___52 *);

struct elevator_queue___52;

struct blk_queue_tag___52;

struct request_queue___52 {
	struct list_head queue_head;
	struct request___52 *last_merge;
	struct elevator_queue___52 *elevator;
	int nr_rqs[2];
	int nr_rqs_elvpriv;
	struct request_list___52 root_rl;
	request_fn_proc___52 *request_fn;
	make_request_fn___52 *make_request_fn;
	prep_rq_fn___52 *prep_rq_fn;
	merge_bvec_fn___53 *merge_bvec_fn;
	softirq_done_fn___52 *softirq_done_fn;
	rq_timed_out_fn___52 *rq_timed_out_fn;
	dma_drain_needed_fn___52 *dma_drain_needed;
	lld_busy_fn___52 *lld_busy_fn;
	struct blk_mq_ops *mq_ops;
	unsigned int *mq_map;
	union {
		struct blk_mq_ctx___12 *queue_ctx;
		struct {
			struct blk_mq_ctx___12 *queue_ctx;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	unsigned int nr_queues;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	sector_t end_sector;
	struct request___52 *boundary_rq;
	struct delayed_work delay_work;
	struct backing_dev_info___63 backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	int id;
	gfp_t bounce_gfp;
	spinlock_t __queue_lock;
	spinlock_t *queue_lock;
	struct kobject___24 kobj;
	struct kobject___24 mq_kobj;
	struct device___229 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int nr_congestion_on;
	unsigned int nr_congestion_off;
	unsigned int nr_batching;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_queue_tag___52 *queue_tags;
	struct list_head tag_busy_list;
	unsigned int nr_sorted;
	unsigned int in_flight[2];
	unsigned int request_fn_active;
	unsigned int rq_timeout;
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head timeout_list;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits___3 limits;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	unsigned int flush_flags;
	unsigned int flush_not_queueable: 1;
	unsigned int rh_reserved_flush_queue_delayed: 1;
	unsigned int rh_reserved_flush_pending_idx: 1;
	unsigned int rh_reserved_flush_running_idx: 1;
	long unsigned int rh_reserved_flush_pending_since;
	struct list_head rh_reserved_flush_queue[2];
	struct list_head rh_reserved_flush_data_in_flight;
	struct request___52 *rh_reserved_flush_rq;
	spinlock_t rh_reserved_mq_flush_lock;
	struct mutex___239 sysfs_lock;
	int bypass_depth;
	bsg_job_fn *bsg_job_fn;
	int bsg_job_size;
	struct bsg_class_device___52 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_counter rh_reserved_mq_usage_counter;
	struct list_head all_q_node;
	unprep_rq_fn___52 *unprep_rq_fn;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___53 *bio_split;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct work_struct requeue_work;
	int mq_freeze_depth;
	struct blk_flush_queue *fq;
	struct percpu_ref mq_usage_counter;
	bool mq_sysfs_init_done;
};

struct cdev___65 {
	struct kobject___24 kobj;
	struct module___141 *owner;
	const struct file_operations___237 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___237 {
	struct dentry___237 * (*lookup)(struct inode___237 *, struct dentry___237 *, unsigned int);
	void * (*follow_link)(struct dentry___237 *, struct nameidata *);
	int (*permission)(struct inode___237 *, int);
	struct posix_acl * (*get_acl)(struct inode___237 *, int);
	int (*readlink)(struct dentry___237 *, char *, int);
	void (*put_link)(struct dentry___237 *, struct nameidata *, void *);
	int (*create)(struct inode___237 *, struct dentry___237 *, umode_t, bool);
	int (*link)(struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*unlink)(struct inode___237 *, struct dentry___237 *);
	int (*symlink)(struct inode___237 *, struct dentry___237 *, const char *);
	int (*mkdir)(struct inode___237 *, struct dentry___237 *, umode_t);
	int (*rmdir)(struct inode___237 *, struct dentry___237 *);
	int (*mknod)(struct inode___237 *, struct dentry___237 *, umode_t, dev_t);
	int (*rename)(struct inode___237 *, struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*setattr)(struct dentry___237 *, struct iattr___237 *);
	int (*getattr)(struct vfsmount *, struct dentry___237 *, struct kstat *);
	int (*setxattr)(struct dentry___237 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___237 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___237 *, char *, size_t);
	int (*removexattr)(struct dentry___237 *, const char *);
	int (*fiemap)(struct inode___237 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___237 *, struct timespec *, int);
	int (*atomic_open)(struct inode___237 *, struct dentry___237 *, struct file___237 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___127;

struct seq_file___162;

struct file_operations___237 {
	struct module___141 *owner;
	loff_t (*llseek)(struct file___237 *, loff_t, int);
	ssize_t (*read)(struct file___237 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___237 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___237 *, void *, filldir_t);
	unsigned int (*poll)(struct file___237 *, struct poll_table_struct___127 *);
	long int (*unlocked_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___237 *, struct vm_area_struct___245 *);
	int (*open)(struct inode___237 *, struct file___237 *);
	int (*flush)(struct file___237 *, fl_owner_t);
	int (*release)(struct inode___237 *, struct file___237 *);
	int (*fsync)(struct file___237 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___237 *, int);
	int (*lock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*sendpage)(struct file___237 *, struct page___236 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___237 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___237 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___237 *, long int, struct file_lock___237 **, void **);
		struct {
			int (*setlease)(struct file___237 *, long int, struct file_lock___237 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___237 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___162 *, struct file___237 *);
};

struct fasync_struct___237;

struct file_lock_operations___237;

struct lock_manager_operations___237;

struct file_lock___237 {
	struct file_lock___237 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___92 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___237 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___237 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___237 *fl_ops;
	const struct lock_manager_operations___237 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___237 {
	void (*fl_copy_lock)(struct file_lock___237 *, struct file_lock___237 *);
	void (*fl_release_private)(struct file_lock___237 *);
};

struct lock_manager_operations___237 {
	int (*lm_compare_owner)(struct file_lock___237 *, struct file_lock___237 *);
	long unsigned int (*lm_owner_key)(struct file_lock___237 *);
	void (*lm_notify)(struct file_lock___237 *);
	int (*lm_grant)(struct file_lock___237 *, struct file_lock___237 *, int);
	void (*lm_break)(struct file_lock___237 *);
	int (*lm_change)(struct file_lock___237 **, int);
};

struct fasync_struct___237 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___237 *fa_next;
	struct file___237 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___237 {
	const char *name;
	int fs_flags;
	struct dentry___237 * (*mount)(struct file_system_type___237 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___237 *);
	struct module___141 *owner;
	struct file_system_type___237 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___237 {
	struct inode___237 * (*alloc_inode)(struct super_block___237 *);
	void (*destroy_inode)(struct inode___237 *);
	void (*dirty_inode)(struct inode___237 *, int);
	int (*write_inode)(struct inode___237 *, struct writeback_control *);
	int (*drop_inode)(struct inode___237 *);
	void (*evict_inode)(struct inode___237 *);
	void (*put_super)(struct super_block___237 *);
	int (*sync_fs)(struct super_block___237 *, int);
	int (*freeze_fs)(struct super_block___237 *);
	int (*unfreeze_fs)(struct super_block___237 *);
	int (*statfs)(struct dentry___237 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___237 *, int *, char *);
	void (*umount_begin)(struct super_block___237 *);
	int (*show_options)(struct seq_file___162 *, struct dentry___237 *);
	int (*show_devname)(struct seq_file___162 *, struct dentry___237 *);
	int (*show_path)(struct seq_file___162 *, struct dentry___237 *);
	int (*show_stats)(struct seq_file___162 *, struct dentry___237 *);
	ssize_t (*quota_read)(struct super_block___237 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___237 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___237 *);
	int (*bdev_try_to_free_page)(struct super_block___237 *, struct page___236 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___237 *);
	void (*free_cached_objects)(struct super_block___237 *, int);
};

typedef void (*poll_queue_proc___129)(struct file___237 *, wait_queue_head_t *, struct poll_table_struct___127 *);

struct poll_table_struct___127 {
	poll_queue_proc___129 _qproc;
	long unsigned int _key;
};

struct seq_operations___162;

struct seq_file___162 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___239 lock;
	const struct seq_operations___162 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct disk_part_tbl___56 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___56 *last_lookup;
	struct hd_struct___56 *part[0];
};

struct block_device_operations___52 {
	int (*open)(struct block_device___237 *, fmode_t);
	void (*release)(struct gendisk___56 *, fmode_t);
	int (*ioctl)(struct block_device___237 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___237 *, fmode_t, unsigned int, long unsigned int);
	int (*direct_access)(struct block_device___237 *, sector_t, void **, long unsigned int *);
	unsigned int (*check_events)(struct gendisk___56 *, unsigned int);
	int (*media_changed)(struct gendisk___56 *);
	void (*unlock_native_capacity)(struct gendisk___56 *);
	int (*revalidate_disk)(struct gendisk___56 *);
	int (*getgeo)(struct block_device___237 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___237 *, long unsigned int);
	void *rh_reserved_ptrs1;
	void *rh_reserved_ptrs2;
	void *rh_reserved_ptrs3;
	void *rh_reserved_ptrs4;
	void *rh_reserved_ptrs5;
	struct module___141 *owner;
};

struct vm_fault___207 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___236 *page;
};

struct irq_chip___157 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___157 *);
	void (*irq_shutdown)(struct irq_data___157 *);
	void (*irq_enable)(struct irq_data___157 *);
	void (*irq_disable)(struct irq_data___157 *);
	void (*irq_ack)(struct irq_data___157 *);
	void (*irq_mask)(struct irq_data___157 *);
	void (*irq_mask_ack)(struct irq_data___157 *);
	void (*irq_unmask)(struct irq_data___157 *);
	void (*irq_eoi)(struct irq_data___157 *);
	int (*irq_set_affinity)(struct irq_data___157 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___157 *);
	int (*irq_set_type)(struct irq_data___157 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___157 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___157 *);
	void (*irq_bus_sync_unlock)(struct irq_data___157 *);
	void (*irq_cpu_online)(struct irq_data___157 *);
	void (*irq_cpu_offline)(struct irq_data___157 *);
	void (*irq_suspend)(struct irq_data___157 *);
	void (*irq_resume)(struct irq_data___157 *);
	void (*irq_pm_shutdown)(struct irq_data___157 *);
	void (*irq_print_chip)(struct irq_data___157 *, struct seq_file___162 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___157 *, void *);
	long unsigned int flags;
};

struct io_cq___52 {
	struct request_queue___52 *q;
	struct io_context___52 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___220 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef void rq_end_io_fn___52(struct request___52 *, int);

struct request___52 {
	struct list_head queuelist;
	union {
		struct call_single_data___2 csd;
		union {
			long unsigned int fifo_time;
			struct {
				struct work_struct mq_flush_work;
			} __UNIQUE_ID_rh_kabi_hide10;
			union {			};
		};
	};
	struct request_queue___52 *q;
	struct blk_mq_ctx *mq_ctx;
	u64 cmd_flags;
	enum rq_cmd_type_bits cmd_type;
	long unsigned int atomic_flags;
	int cpu;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___53 *bio;
	struct bio___53 *biotail;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		void *completion_data;
	};
	union {
		struct {
			struct io_cq___52 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___52 *saved_end_io;
		} flush;
	};
	struct gendisk___56 *rq_disk;
	struct hd_struct___56 *part;
	long unsigned int start_time;
	struct request_list___52 *rl;
	long long unsigned int start_time_ns;
	long long unsigned int io_start_time_ns;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int ioprio;
	void *special;
	char *buffer;
	int tag;
	int errors;
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	unsigned int extra_len;
	unsigned int sense_len;
	unsigned int resid_len;
	void *sense;
	long unsigned int deadline;
	struct list_head timeout_list;
	unsigned int timeout;
	int retries;
	rq_end_io_fn___52 *end_io;
	void *end_io_data;
	struct request___52 *next_rq;
};

typedef int elevator_merge_fn___52(struct request_queue___52 *, struct request___52 **, struct bio___53 *);

typedef void elevator_merge_req_fn___52(struct request_queue___52 *, struct request___52 *, struct request___52 *);

typedef void elevator_merged_fn___52(struct request_queue___52 *, struct request___52 *, int);

typedef int elevator_allow_merge_fn___52(struct request_queue___52 *, struct request___52 *, struct bio___53 *);

typedef void elevator_bio_merged_fn___52(struct request_queue___52 *, struct request___52 *, struct bio___53 *);

typedef int elevator_dispatch_fn___52(struct request_queue___52 *, int);

typedef void elevator_add_req_fn___52(struct request_queue___52 *, struct request___52 *);

typedef struct request___52 *elevator_request_list_fn___52(struct request_queue___52 *, struct request___52 *);

typedef void elevator_completed_req_fn___52(struct request_queue___52 *, struct request___52 *);

typedef int elevator_may_queue_fn___52(struct request_queue___52 *, int);

typedef void elevator_init_icq_fn___52(struct io_cq___52 *);

typedef void elevator_exit_icq_fn___52(struct io_cq___52 *);

typedef int elevator_set_req_fn___52(struct request_queue___52 *, struct request___52 *, struct bio___53 *, gfp_t);

typedef void elevator_put_req_fn___52(struct request___52 *);

typedef void elevator_activate_req_fn___52(struct request_queue___52 *, struct request___52 *);

typedef void elevator_deactivate_req_fn___52(struct request_queue___52 *, struct request___52 *);

struct elevator_type___52;

typedef int elevator_init_fn___53(struct request_queue___52 *, struct elevator_type___52 *);

typedef void elevator_exit_fn___52(struct elevator_queue___52 *);

struct elevator_ops___52 {
	elevator_merge_fn___52 *elevator_merge_fn;
	elevator_merged_fn___52 *elevator_merged_fn;
	elevator_merge_req_fn___52 *elevator_merge_req_fn;
	elevator_allow_merge_fn___52 *elevator_allow_merge_fn;
	elevator_bio_merged_fn___52 *elevator_bio_merged_fn;
	elevator_dispatch_fn___52 *elevator_dispatch_fn;
	elevator_add_req_fn___52 *elevator_add_req_fn;
	elevator_activate_req_fn___52 *elevator_activate_req_fn;
	elevator_deactivate_req_fn___52 *elevator_deactivate_req_fn;
	elevator_completed_req_fn___52 *elevator_completed_req_fn;
	elevator_request_list_fn___52 *elevator_former_req_fn;
	elevator_request_list_fn___52 *elevator_latter_req_fn;
	elevator_init_icq_fn___52 *elevator_init_icq_fn;
	elevator_exit_icq_fn___52 *elevator_exit_icq_fn;
	elevator_set_req_fn___52 *elevator_set_req_fn;
	elevator_put_req_fn___52 *elevator_put_req_fn;
	elevator_may_queue_fn___52 *elevator_may_queue_fn;
	elevator_init_fn___53 *elevator_init_fn;
	elevator_exit_fn___52 *elevator_exit_fn;
};

struct elv_fs_entry___52;

struct elevator_type___52 {
	struct kmem_cache___220 *icq_cache;
	struct elevator_ops___52 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___52 *elevator_attrs;
	char elevator_name[16];
	struct module___141 *elevator_owner;
	char icq_cache_name[21];
	struct list_head list;
};

struct elevator_queue___52 {
	struct elevator_type___52 *type;
	void *elevator_data;
	struct kobject___24 kobj;
	struct mutex___239 sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___52 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___52 *, char *);
	ssize_t (*store)(struct elevator_queue___52 *, const char *, size_t);
};

struct bvec_merge_data___52 {
	struct block_device___237 *bi_bdev;
	sector_t bi_sector;
	unsigned int bi_size;
	long unsigned int bi_rw;
};

struct blk_queue_tag___52 {
	struct request___52 **tag_index;
	long unsigned int *tag_map;
	int busy;
	int max_depth;
	int real_max_depth;
	atomic_t refcnt;
};

struct seq_operations___162 {
	void * (*start)(struct seq_file___162 *, loff_t *);
	void (*stop)(struct seq_file___162 *, void *);
	void * (*next)(struct seq_file___162 *, void *, loff_t *);
	int (*show)(struct seq_file___162 *, void *);
};

struct module_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___140 *, struct module_kobject___140 *, char *);
	ssize_t (*store)(struct module_attribute___140 *, struct module_kobject___140 *, const char *, size_t);
	void (*setup)(struct module___141 *, const char *);
	int (*test)(struct module___141 *);
	void (*free)(struct module___141 *);
};

struct acpi_table_ibft {
	struct acpi_table_header header;
	u8 reserved[12];
};

struct acpi_hotplug_profile___33 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___33 *);
	void (*notify_online)(struct acpi_device___33 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___33 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___33 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___33 *);
	void (*bind)(struct device___229 *);
	void (*unbind)(struct device___229 *);
	struct acpi_hotplug_profile___33 hotplug;
};

struct acpi_hotplug_context___33 {
	struct acpi_device___33 *self;
	int (*notify)(struct acpi_device___33 *, u32);
	void (*uevent)(struct acpi_device___33 *, u32);
	void (*fixup)(struct acpi_device___33 *);
};

typedef int (*acpi_op_add___33)(struct acpi_device___33 *);

typedef int (*acpi_op_remove___33)(struct acpi_device___33 *);

typedef void (*acpi_op_notify___33)(struct acpi_device___33 *, u32);

struct acpi_device_ops___33 {
	acpi_op_add___33 add;
	acpi_op_remove___33 remove;
	acpi_op_notify___33 notify;
};

struct acpi_driver___33 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___33 ops;
	struct device_driver___229 drv;
	struct module___141 *owner;
};

struct firmware_map_entry {
	u64 start;
	u64 end;
	const char *type;
	struct list_head list;
	struct kobject___24 kobj;
};

struct memmap_attribute {
	struct attribute attr;
	ssize_t (*show)(struct firmware_map_entry *, char *);
};

typedef efi_status_t efi_query_variable_store_t(u32, long unsigned int);

typedef struct {
	efi_guid_t guid;
	u32 table;
} efi_config_table_32_t;

struct efivar_operations {
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_query_variable_store_t *query_variable_store;
};

struct efivars {
	spinlock_t lock;
	struct kset___24 *kset;
	struct kobject___24 *kobject;
	const struct efivar_operations *ops;
};

struct efi_generic_dev_path {
	u8 type;
	u8 sub_type;
	u16 length;
};

struct variable_validate {
	char *name;
	bool (*validate)(struct efi_variable *, int, u8 *, long unsigned int);
};

struct efivar_attribute {
	struct attribute attr;
	ssize_t (*show)(struct efivar_entry *, char *);
	ssize_t (*store)(struct efivar_entry *, const char *, size_t);
};

struct pstore_read_data {
	u64 *id;
	enum pstore_type_id *type;
	int *count;
	struct timespec *timespec;
	char **buf;
};

struct pstore_erase_data {
	u64 id;
	enum pstore_type_id type;
	int count;
	struct timespec time;
	efi_char16_t *name;
};

struct efi_runtime_map_entry {
	efi_memory_desc_t md;
	struct kobject___24 kobj;
};

struct map_attribute {
	struct attribute attr;
	ssize_t (*show)(struct efi_runtime_map_entry *, char *);
};

struct device___230;

struct dev_pm_ops___230 {
	int (*prepare)(struct device___230 *);
	void (*complete)(struct device___230 *);
	int (*suspend)(struct device___230 *);
	int (*resume)(struct device___230 *);
	int (*freeze)(struct device___230 *);
	int (*thaw)(struct device___230 *);
	int (*poweroff)(struct device___230 *);
	int (*restore)(struct device___230 *);
	int (*suspend_late)(struct device___230 *);
	int (*resume_early)(struct device___230 *);
	int (*freeze_late)(struct device___230 *);
	int (*thaw_early)(struct device___230 *);
	int (*poweroff_late)(struct device___230 *);
	int (*restore_early)(struct device___230 *);
	int (*suspend_noirq)(struct device___230 *);
	int (*resume_noirq)(struct device___230 *);
	int (*freeze_noirq)(struct device___230 *);
	int (*thaw_noirq)(struct device___230 *);
	int (*poweroff_noirq)(struct device___230 *);
	int (*restore_noirq)(struct device___230 *);
	int (*runtime_suspend)(struct device___230 *);
	int (*runtime_resume)(struct device___230 *);
	int (*runtime_idle)(struct device___230 *);
};

struct dma_map_ops___96;

struct dev_archdata___96 {
	struct dma_map_ops___96 *dma_ops;
	void *iommu;
};

struct acpi_device___34;

struct acpi_dev_node___40 {
	union {
		struct acpi_device___34 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___230;

struct bus_type___230;

struct device_driver___230;

struct dev_pm_domain___230;

struct class___230;

struct device_rh___230;

struct device___230 {
	struct device___230 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___230 *type;
	struct mutex___230 mutex;
	struct bus_type___230 *bus;
	struct device_driver___230 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___230 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___96 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___40 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___230 *class;
	const struct attribute_group___187 **groups;
	void (*release)(struct device___230 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___230 *device_rh;
};

struct dev_pm_info_rh___230 {
	void (*set_latency_tolerance)(struct device___230 *, s32);
};

struct dev_pm_domain___230 {
	struct dev_pm_ops___230 ops;
};

struct cper_sec_proc_generic {
	__u64 validation_bits;
	__u8 proc_type;
	__u8 proc_isa;
	__u8 proc_error_type;
	__u8 operation;
	__u8 flags;
	__u8 level;
	__u16 reserved;
	__u64 cpu_version;
	char cpu_brand[128];
	__u64 proc_id;
	__u64 target_addr;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 ip;
};

struct cper_mem_err_compact {
	__u64 validation_bits;
	__u16 node;
	__u16 card;
	__u16 module;
	__u16 bank;
	__u16 device;
	__u16 row;
	__u16 column;
	__u16 bit_pos;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 target_id;
	__u16 rank;
	__u16 mem_array_handle;
	__u16 mem_dev_handle;
} __attribute__((packed));

struct dma_map_ops___96 {
	void * (*alloc)(struct device___230 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___230 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___230 *, struct vm_area_struct___236 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___230 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___230 *, struct page___227 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___230 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___230 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___230 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___230 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___230 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___230 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___230 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___230 *, dma_addr_t);
	int (*dma_supported)(struct device___230 *, u64);
	int (*set_dma_mask)(struct device___230 *, u64);
	int is_phys;
};

struct bus_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___230 *, char *);
	ssize_t (*store)(struct bus_type___230 *, const char *, size_t);
};

struct device_attribute___230;

struct driver_attribute___230;

struct bus_type___230 {
	const char *name;
	const char *dev_name;
	struct device___230 *dev_root;
	struct bus_attribute___230 *bus_attrs;
	struct device_attribute___230 *dev_attrs;
	struct driver_attribute___230 *drv_attrs;
	const struct attribute_group___187 **bus_groups;
	const struct attribute_group___187 **dev_groups;
	const struct attribute_group___187 **drv_groups;
	int (*match)(struct device___230 *, struct device_driver___230 *);
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	int (*probe)(struct device___230 *);
	int (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*online)(struct device___230 *);
	int (*offline)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct device___230 *, struct device_attribute___230 *, char *);
	ssize_t (*store)(struct device___230 *, struct device_attribute___230 *, const char *, size_t);
};

struct driver_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___230 *, char *);
	ssize_t (*store)(struct device_driver___230 *, const char *, size_t);
};

struct device_driver___230 {
	const char *name;
	struct bus_type___230 *bus;
	struct module___132 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___230 *);
	int (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	const struct attribute_group___187 **groups;
	const struct dev_pm_ops___230 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___230 {
	const char *name;
	const struct attribute_group___187 **groups;
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
};

struct class_attribute___230;

struct class___230 {
	const char *name;
	struct module___132 *owner;
	struct class_attribute___230 *class_attrs;
	struct device_attribute___230 *dev_attrs;
	const struct attribute_group___187 **dev_groups;
	struct bin_attribute___189 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *);
	void (*class_release)(struct class___230 *);
	void (*dev_release)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
	struct subsys_private *p;
};

struct class_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct class___230 *, struct class_attribute___230 *, char *);
	ssize_t (*store)(struct class___230 *, struct class_attribute___230 *, const char *, size_t);
	const void * (*namespace)(struct class___230 *, const struct class_attribute___230 *);
};

struct acpi_scan_handler___34;

struct acpi_hotplug_context___34;

struct acpi_driver___34;

struct acpi_device___34 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___34 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___34 *handler;
	struct acpi_hotplug_context___34 *hp;
	struct acpi_driver___34 *driver;
	void *driver_data;
	struct device___230 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___230 physical_node_lock;
	void (*remove)(struct acpi_device___34 *);
};

struct device_rh___230 {
	struct dev_pm_info_rh___230 power;
};

struct acpi_hotplug_profile___34 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___34 *);
	void (*notify_online)(struct acpi_device___34 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___34 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___34 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___34 *);
	void (*bind)(struct device___230 *);
	void (*unbind)(struct device___230 *);
	struct acpi_hotplug_profile___34 hotplug;
};

struct acpi_hotplug_context___34 {
	struct acpi_device___34 *self;
	int (*notify)(struct acpi_device___34 *, u32);
	void (*uevent)(struct acpi_device___34 *, u32);
	void (*fixup)(struct acpi_device___34 *);
};

typedef int (*acpi_op_add___34)(struct acpi_device___34 *);

typedef int (*acpi_op_remove___34)(struct acpi_device___34 *);

typedef void (*acpi_op_notify___34)(struct acpi_device___34 *, u32);

struct acpi_device_ops___34 {
	acpi_op_add___34 add;
	acpi_op_remove___34 remove;
	acpi_op_notify___34 notify;
};

struct acpi_driver___34 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___34 ops;
	struct device_driver___230 drv;
	struct module___132 *owner;
};

typedef struct poll_table_struct___49 poll_table___34;

struct hid_device_id {
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	kernel_ulong_t driver_data;
};

struct ff_device___7;

struct input_handle___7;

struct input_dev___7 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___7 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___7 *, struct input_keymap_entry *);
	struct ff_device___7 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___7 *);
	void (*close)(struct input_dev___7 *);
	int (*flush)(struct input_dev___7 *, struct file___81 *);
	int (*event)(struct input_dev___7 *, unsigned int, unsigned int, int);
	struct input_handle___7 *grab;
	spinlock_t event_lock;
	struct mutex___81 mutex;
	unsigned int users;
	bool going_away;
	struct device___158 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___7 {
	int (*upload)(struct input_dev___7 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___7 *, int);
	int (*playback)(struct input_dev___7 *, int, int);
	void (*set_gain)(struct input_dev___7 *, u16);
	void (*set_autocenter)(struct input_dev___7 *, u16);
	void (*destroy)(struct ff_device___7 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___81 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___81 *effect_owners[0];
};

struct input_handler___7;

struct input_handle___7 {
	void *private;
	int open;
	const char *name;
	struct input_dev___7 *dev;
	struct input_handler___7 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___7 {
	void *private;
	void (*event)(struct input_handle___7 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___7 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___7 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___7 *, struct input_dev___7 *);
	int (*connect)(struct input_handler___7 *, struct input_dev___7 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___7 *);
	void (*start)(struct input_handle___7 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___4;

struct led_classdev___4 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___4 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___4 *);
	int (*blink_set)(struct led_classdev___4 *, long unsigned int *, long unsigned int *);
	struct device___158 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___4 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___4 {
	const char *name;
	void (*activate)(struct led_classdev___4 *);
	void (*deactivate)(struct led_classdev___4 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___3 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply___3 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___3 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___3 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___3 *);
	void (*set_charged)(struct power_supply___3 *);
	int use_for_apm;
	struct device___158 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger___4 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___4 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___4 *full_trig;
	char *full_trig_name;
	struct led_trigger___4 *online_trig;
	char *online_trig_name;
	struct led_trigger___4 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_collection {
	unsigned int type;
	unsigned int usage;
	unsigned int level;
};

struct hid_usage {
	unsigned int hid;
	unsigned int collection_index;
	unsigned int usage_index;
	__u16 code;
	__u8 type;
	__s8 hat_min;
	__s8 hat_max;
	__s8 hat_dir;
};

struct hid_report;

struct hid_input;

struct hid_field {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report *report;
	unsigned int index;
	struct hid_input *hidinput;
	__u16 dpad;
};

struct hid_device;

struct hid_report {
	struct list_head list;
	unsigned int id;
	unsigned int type;
	struct hid_field *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device *device;
};

struct hid_input {
	struct list_head list;
	struct hid_report *report;
	struct input_dev___7 *input;
};

enum hid_type {
	HID_TYPE_OTHER = 0,
	HID_TYPE_USBMOUSE = 1,
	HID_TYPE_USBNONE = 2,
};

struct hid_report_enum {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report *report_id_hash[256];
};

struct hid_driver;

struct hid_ll_driver;

struct hid_device {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum report_enum[3];
	struct semaphore driver_lock;
	struct semaphore driver_input_lock;
	struct device___158 dev;
	struct hid_driver *driver;
	struct hid_ll_driver *ll_driver;
	struct power_supply___3 battery;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	int minor;
	int open;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device *);
	int (*hiddev_connect)(struct hid_device *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device *);
	void (*hiddev_hid_event)(struct hid_device *, struct hid_field *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device *, struct hid_report *);
	int (*hid_get_raw_report)(struct hid_device *, unsigned char, __u8 *, size_t, unsigned char);
	int (*hid_output_raw_report)(struct hid_device *, __u8 *, size_t, unsigned char);
	short unsigned int debug;
	struct dentry___82 *debug_dir;
	struct dentry___82 *debug_rdesc;
	struct dentry___82 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_report_id;

struct hid_usage_id;

struct hid_driver {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	int (*probe)(struct hid_device *, const struct hid_device_id *);
	void (*remove)(struct hid_device *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device *, struct hid_report *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device *, struct hid_field *, struct hid_usage *, __s32);
	void (*report)(struct hid_device *, struct hid_report *);
	__u8 * (*report_fixup)(struct hid_device *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device *, struct hid_input *, struct hid_field *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device *, struct hid_input *, struct hid_field *, struct hid_usage *, long unsigned int **, int *);
	void (*input_configured)(struct hid_device *, struct hid_input *);
	void (*feature_mapping)(struct hid_device *, struct hid_field *, struct hid_usage *);
	int (*suspend)(struct hid_device *, pm_message_t);
	int (*resume)(struct hid_device *);
	int (*reset_resume)(struct hid_device *);
	struct device_driver___158 driver;
};

struct hid_ll_driver {
	int (*start)(struct hid_device *);
	void (*stop)(struct hid_device *);
	int (*open)(struct hid_device *);
	void (*close)(struct hid_device *);
	int (*power)(struct hid_device *, int);
	int (*hidinput_input_event)(struct input_dev___7 *, unsigned int, unsigned int, int);
	int (*parse)(struct hid_device *);
	void (*request)(struct hid_device *, struct hid_report *, int);
	int (*wait)(struct hid_device *);
	int (*idle)(struct hid_device *, int, int, int);
};

struct hid_report_id {
	__u32 report_type;
};

struct hid_usage_id {
	__u32 usage_hid;
	__u32 usage_type;
	__u32 usage_code;
};

struct hid_debug_list {
	char *hid_debug_buf;
	int head;
	int tail;
	struct fasync_struct___81 *fasync;
	struct hid_device *hdev;
	struct list_head node;
	struct mutex___81 read_mutex;
};

struct hid_usage_entry {
	unsigned int page;
	unsigned int usage;
	const char *description;
};

struct ff_device___8;

struct input_handle___8;

struct input_dev___8 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___8 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___8 *, struct input_keymap_entry *);
	struct ff_device___8 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___8 *);
	void (*close)(struct input_dev___8 *);
	int (*flush)(struct input_dev___8 *, struct file___210 *);
	int (*event)(struct input_dev___8 *, unsigned int, unsigned int, int);
	struct input_handle___8 *grab;
	spinlock_t event_lock;
	struct mutex___212 mutex;
	unsigned int users;
	bool going_away;
	struct device___194 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___8 {
	int (*upload)(struct input_dev___8 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___8 *, int);
	int (*playback)(struct input_dev___8 *, int, int);
	void (*set_gain)(struct input_dev___8 *, u16);
	void (*set_autocenter)(struct input_dev___8 *, u16);
	void (*destroy)(struct ff_device___8 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___212 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___210 *effect_owners[0];
};

struct input_handler___8;

struct input_handle___8 {
	void *private;
	int open;
	const char *name;
	struct input_dev___8 *dev;
	struct input_handler___8 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___8 {
	void *private;
	void (*event)(struct input_handle___8 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___8 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___8 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___8 *, struct input_dev___8 *);
	int (*connect)(struct input_handler___8 *, struct input_dev___8 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___8 *);
	void (*start)(struct input_handle___8 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___5;

struct led_classdev___5 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___5 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___5 *);
	int (*blink_set)(struct led_classdev___5 *, long unsigned int *, long unsigned int *);
	struct device___194 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___5 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___5 {
	const char *name;
	void (*activate)(struct led_classdev___5 *);
	void (*deactivate)(struct led_classdev___5 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___4 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply___4 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___4 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___4 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___4 *);
	void (*set_charged)(struct power_supply___4 *);
	int use_for_apm;
	struct device___194 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger___5 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___5 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___5 *full_trig;
	char *full_trig_name;
	struct led_trigger___5 *online_trig;
	char *online_trig_name;
	struct led_trigger___5 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_item {
	unsigned int format;
	__u8 size;
	__u8 type;
	__u8 tag;
	union {
		__u8 u8;
		__s8 s8;
		__u16 u16;
		__s16 s16;
		__u32 u32;
		__s32 s32;
		__u8 *longdata;
	} data;
};

struct hid_global {
	unsigned int usage_page;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	unsigned int report_id;
	unsigned int report_size;
	unsigned int report_count;
};

struct hid_local {
	unsigned int usage[12288];
	unsigned int collection_index[12288];
	unsigned int usage_index;
	unsigned int usage_minimum;
	unsigned int delimiter_depth;
	unsigned int delimiter_branch;
};

struct hid_report___2;

struct hid_input___2;

struct hid_field___2 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___2 *report;
	unsigned int index;
	struct hid_input___2 *hidinput;
	__u16 dpad;
};

struct hid_device___2;

struct hid_report___2 {
	struct list_head list;
	unsigned int id;
	unsigned int type;
	struct hid_field___2 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___2 *device;
};

struct hid_input___2 {
	struct list_head list;
	struct hid_report___2 *report;
	struct input_dev___8 *input;
};

struct hid_report_enum___2 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___2 *report_id_hash[256];
};

struct hid_driver___2;

struct hid_ll_driver___2;

struct hid_device___2 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___2 report_enum[3];
	struct semaphore driver_lock;
	struct semaphore driver_input_lock;
	struct device___194 dev;
	struct hid_driver___2 *driver;
	struct hid_ll_driver___2 *ll_driver;
	struct power_supply___4 battery;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	int minor;
	int open;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___2 *);
	int (*hiddev_connect)(struct hid_device___2 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___2 *);
	void (*hiddev_hid_event)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___2 *, struct hid_report___2 *);
	int (*hid_get_raw_report)(struct hid_device___2 *, unsigned char, __u8 *, size_t, unsigned char);
	int (*hid_output_raw_report)(struct hid_device___2 *, __u8 *, size_t, unsigned char);
	short unsigned int debug;
	struct dentry___210 *debug_dir;
	struct dentry___210 *debug_rdesc;
	struct dentry___210 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___2 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	int (*probe)(struct hid_device___2 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___2 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___2 *, struct hid_report___2 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___2 *, struct hid_report___2 *);
	__u8 * (*report_fixup)(struct hid_device___2 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___2 *, struct hid_input___2 *, struct hid_field___2 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___2 *, struct hid_input___2 *, struct hid_field___2 *, struct hid_usage *, long unsigned int **, int *);
	void (*input_configured)(struct hid_device___2 *, struct hid_input___2 *);
	void (*feature_mapping)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *);
	int (*suspend)(struct hid_device___2 *, pm_message_t);
	int (*resume)(struct hid_device___2 *);
	int (*reset_resume)(struct hid_device___2 *);
	struct device_driver___194 driver;
};

struct hid_ll_driver___2 {
	int (*start)(struct hid_device___2 *);
	void (*stop)(struct hid_device___2 *);
	int (*open)(struct hid_device___2 *);
	void (*close)(struct hid_device___2 *);
	int (*power)(struct hid_device___2 *, int);
	int (*hidinput_input_event)(struct input_dev___8 *, unsigned int, unsigned int, int);
	int (*parse)(struct hid_device___2 *);
	void (*request)(struct hid_device___2 *, struct hid_report___2 *, int);
	int (*wait)(struct hid_device___2 *);
	int (*idle)(struct hid_device___2 *, int, int, int);
};

struct hid_parser {
	struct hid_global global;
	struct hid_global global_stack[4];
	unsigned int global_stack_ptr;
	struct hid_local local;
	unsigned int collection_stack[4];
	unsigned int collection_stack_ptr;
	struct hid_device___2 *device;
};

struct hidraw {
	unsigned int minor;
	int exist;
	int open;
	wait_queue_head_t wait;
	struct hid_device___2 *hid;
	struct device___194 *dev;
	struct list_head list;
};

struct hid_dynid {
	struct list_head list;
	struct hid_device_id id;
};

struct led_trigger___6;

struct led_classdev___6 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___6 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___6 *);
	int (*blink_set)(struct led_classdev___6 *, long unsigned int *, long unsigned int *);
	struct device___223 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___6 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___6 {
	const char *name;
	void (*activate)(struct led_classdev___6 *);
	void (*deactivate)(struct led_classdev___6 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

enum {
	POWER_SUPPLY_SCOPE_UNKNOWN = 0,
	POWER_SUPPLY_SCOPE_SYSTEM = 1,
	POWER_SUPPLY_SCOPE_DEVICE = 2,
};

struct power_supply___5 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply___5 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___5 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___5 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___5 *);
	void (*set_charged)(struct power_supply___5 *);
	int use_for_apm;
	struct device___223 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger___6 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___6 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___6 *full_trig;
	char *full_trig_name;
	struct led_trigger___6 *online_trig;
	char *online_trig_name;
	struct led_trigger___6 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___3;

struct hid_input___3;

struct hid_field___3 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___3 *report;
	unsigned int index;
	struct hid_input___3 *hidinput;
	__u16 dpad;
};

struct hid_device___3;

struct hid_report___3 {
	struct list_head list;
	unsigned int id;
	unsigned int type;
	struct hid_field___3 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___3 *device;
};

struct hid_input___3 {
	struct list_head list;
	struct hid_report___3 *report;
	struct input_dev___4 *input;
};

struct hid_report_enum___3 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___3 *report_id_hash[256];
};

struct hid_driver___3;

struct hid_ll_driver___3;

struct hid_device___3 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___3 report_enum[3];
	struct semaphore driver_lock;
	struct semaphore driver_input_lock;
	struct device___223 dev;
	struct hid_driver___3 *driver;
	struct hid_ll_driver___3 *ll_driver;
	struct power_supply___5 battery;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	int minor;
	int open;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___3 *);
	int (*hiddev_connect)(struct hid_device___3 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___3 *);
	void (*hiddev_hid_event)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___3 *, struct hid_report___3 *);
	int (*hid_get_raw_report)(struct hid_device___3 *, unsigned char, __u8 *, size_t, unsigned char);
	int (*hid_output_raw_report)(struct hid_device___3 *, __u8 *, size_t, unsigned char);
	short unsigned int debug;
	struct dentry___233 *debug_dir;
	struct dentry___233 *debug_rdesc;
	struct dentry___233 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___3 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	int (*probe)(struct hid_device___3 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___3 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___3 *, struct hid_report___3 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___3 *, struct hid_report___3 *);
	__u8 * (*report_fixup)(struct hid_device___3 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___3 *, struct hid_input___3 *, struct hid_field___3 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___3 *, struct hid_input___3 *, struct hid_field___3 *, struct hid_usage *, long unsigned int **, int *);
	void (*input_configured)(struct hid_device___3 *, struct hid_input___3 *);
	void (*feature_mapping)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *);
	int (*suspend)(struct hid_device___3 *, pm_message_t);
	int (*resume)(struct hid_device___3 *);
	int (*reset_resume)(struct hid_device___3 *);
	struct device_driver___223 driver;
};

struct hid_ll_driver___3 {
	int (*start)(struct hid_device___3 *);
	void (*stop)(struct hid_device___3 *);
	int (*open)(struct hid_device___3 *);
	void (*close)(struct hid_device___3 *);
	int (*power)(struct hid_device___3 *, int);
	int (*hidinput_input_event)(struct input_dev___4 *, unsigned int, unsigned int, int);
	int (*parse)(struct hid_device___3 *);
	void (*request)(struct hid_device___3 *, struct hid_report___3 *, int);
	int (*wait)(struct hid_device___3 *);
	int (*idle)(struct hid_device___3 *, int, int, int);
};

typedef bool (*hid_usage_cmp_t)(struct hid_usage *, unsigned int, unsigned int);

struct exec_domain___65 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___17 *module;
	struct exec_domain___65 *next;
};

struct thread_info___108 {
	struct task_struct___30 *task;
	struct exec_domain___65 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct device___231;

struct dev_pm_ops___231 {
	int (*prepare)(struct device___231 *);
	void (*complete)(struct device___231 *);
	int (*suspend)(struct device___231 *);
	int (*resume)(struct device___231 *);
	int (*freeze)(struct device___231 *);
	int (*thaw)(struct device___231 *);
	int (*poweroff)(struct device___231 *);
	int (*restore)(struct device___231 *);
	int (*suspend_late)(struct device___231 *);
	int (*resume_early)(struct device___231 *);
	int (*freeze_late)(struct device___231 *);
	int (*thaw_early)(struct device___231 *);
	int (*poweroff_late)(struct device___231 *);
	int (*restore_early)(struct device___231 *);
	int (*suspend_noirq)(struct device___231 *);
	int (*resume_noirq)(struct device___231 *);
	int (*freeze_noirq)(struct device___231 *);
	int (*thaw_noirq)(struct device___231 *);
	int (*poweroff_noirq)(struct device___231 *);
	int (*restore_noirq)(struct device___231 *);
	int (*runtime_suspend)(struct device___231 *);
	int (*runtime_resume)(struct device___231 *);
	int (*runtime_idle)(struct device___231 *);
};

struct device_type___231;

struct bus_type___231;

struct device_driver___231;

struct dev_pm_domain___231;

struct class___231;

struct attribute_group___197;

struct device_rh___231;

struct device___231 {
	struct device___231 *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type___231 *type;
	struct mutex___30 mutex;
	struct bus_type___231 *bus;
	struct device_driver___231 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___231 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___96 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___40 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___231 *class;
	const struct attribute_group___197 **groups;
	void (*release)(struct device___231 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___231 *device_rh;
};

struct dev_pm_info_rh___231 {
	void (*set_latency_tolerance)(struct device___231 *, s32);
};

struct dev_pm_domain___231 {
	struct dev_pm_ops___231 ops;
};

struct bin_attribute___199;

struct attribute_group___197 {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___199 **bin_attrs;
};

struct bin_attribute___199 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___29 *, struct kobject *, struct bin_attribute___199 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject *, struct bin_attribute___199 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject *, struct bin_attribute___199 *, struct vm_area_struct___32 *);
};

typedef struct poll_table_struct___15 poll_table___35;

struct bus_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___231 *, char *);
	ssize_t (*store)(struct bus_type___231 *, const char *, size_t);
};

struct device_attribute___231;

struct driver_attribute___231;

struct bus_type___231 {
	const char *name;
	const char *dev_name;
	struct device___231 *dev_root;
	struct bus_attribute___231 *bus_attrs;
	struct device_attribute___231 *dev_attrs;
	struct driver_attribute___231 *drv_attrs;
	const struct attribute_group___197 **bus_groups;
	const struct attribute_group___197 **dev_groups;
	const struct attribute_group___197 **drv_groups;
	int (*match)(struct device___231 *, struct device_driver___231 *);
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	int (*probe)(struct device___231 *);
	int (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*online)(struct device___231 *);
	int (*offline)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct device___231 *, struct device_attribute___231 *, char *);
	ssize_t (*store)(struct device___231 *, struct device_attribute___231 *, const char *, size_t);
};

struct driver_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___231 *, char *);
	ssize_t (*store)(struct device_driver___231 *, const char *, size_t);
};

struct device_driver___231 {
	const char *name;
	struct bus_type___231 *bus;
	struct module___17 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___231 *);
	int (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	const struct attribute_group___197 **groups;
	const struct dev_pm_ops___231 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___231 {
	const char *name;
	const struct attribute_group___197 **groups;
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
};

struct class_attribute___231;

struct class___231 {
	const char *name;
	struct module___17 *owner;
	struct class_attribute___231 *class_attrs;
	struct device_attribute___231 *dev_attrs;
	const struct attribute_group___197 **dev_groups;
	struct bin_attribute___199 *dev_bin_attrs;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *);
	void (*class_release)(struct class___231 *);
	void (*dev_release)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
	struct subsys_private *p;
};

struct class_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct class___231 *, struct class_attribute___231 *, char *);
	ssize_t (*store)(struct class___231 *, struct class_attribute___231 *, const char *, size_t);
	const void * (*namespace)(struct class___231 *, const struct class_attribute___231 *);
};

struct device_rh___231 {
	struct dev_pm_info_rh___231 power;
};

struct ff_device___9;

struct input_handle___9;

struct input_dev___9 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___9 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___9 *, struct input_keymap_entry *);
	struct ff_device___9 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___9 *);
	void (*close)(struct input_dev___9 *);
	int (*flush)(struct input_dev___9 *, struct file___29 *);
	int (*event)(struct input_dev___9 *, unsigned int, unsigned int, int);
	struct input_handle___9 *grab;
	spinlock_t event_lock;
	struct mutex___30 mutex;
	unsigned int users;
	bool going_away;
	struct device___231 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___9 {
	int (*upload)(struct input_dev___9 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___9 *, int);
	int (*playback)(struct input_dev___9 *, int, int);
	void (*set_gain)(struct input_dev___9 *, u16);
	void (*set_autocenter)(struct input_dev___9 *, u16);
	void (*destroy)(struct ff_device___9 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex___30 mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___29 *effect_owners[0];
};

struct input_handler___9;

struct input_handle___9 {
	void *private;
	int open;
	const char *name;
	struct input_dev___9 *dev;
	struct input_handler___9 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___9 {
	void *private;
	void (*event)(struct input_handle___9 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___9 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___9 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___9 *, struct input_dev___9 *);
	int (*connect)(struct input_handler___9 *, struct input_dev___9 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___9 *);
	void (*start)(struct input_handle___9 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___7;

struct led_classdev___7 {
	const char *name;
	int brightness;
	int max_brightness;
	int flags;
	void (*brightness_set)(struct led_classdev___7 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___7 *);
	int (*blink_set)(struct led_classdev___7 *, long unsigned int *, long unsigned int *);
	struct device___231 *dev;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___7 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
};

struct led_trigger___7 {
	const char *name;
	void (*activate)(struct led_classdev___7 *);
	void (*deactivate)(struct led_classdev___7 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___6 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_property *properties;
	size_t num_properties;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	int (*get_property)(struct power_supply___6 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___6 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___6 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___6 *);
	void (*set_charged)(struct power_supply___6 *);
	int use_for_apm;
	struct device___231 *dev;
	struct work_struct changed_work;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device *tcd;
	struct led_trigger___7 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___7 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___7 *full_trig;
	char *full_trig_name;
	struct led_trigger___7 *online_trig;
	char *online_trig_name;
	struct led_trigger___7 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___4;

struct hid_input___4;

struct hid_field___4 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___4 *report;
	unsigned int index;
	struct hid_input___4 *hidinput;
	__u16 dpad;
};

struct hid_device___4;

struct hid_report___4 {
	struct list_head list;
	unsigned int id;
	unsigned int type;
	struct hid_field___4 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___4 *device;
};

struct hid_input___4 {
	struct list_head list;
	struct hid_report___4 *report;
	struct input_dev___9 *input;
};

struct hid_report_enum___4 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___4 *report_id_hash[256];
};

struct hid_driver___4;

struct hid_ll_driver___4;

struct hid_device___4 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___4 report_enum[3];
	struct semaphore driver_lock;
	struct semaphore driver_input_lock;
	struct device___231 dev;
	struct hid_driver___4 *driver;
	struct hid_ll_driver___4 *ll_driver;
	struct power_supply___6 battery;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	int minor;
	int open;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___4 *);
	int (*hiddev_connect)(struct hid_device___4 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___4 *);
	void (*hiddev_hid_event)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___4 *, struct hid_report___4 *);
	int (*hid_get_raw_report)(struct hid_device___4 *, unsigned char, __u8 *, size_t, unsigned char);
	int (*hid_output_raw_report)(struct hid_device___4 *, __u8 *, size_t, unsigned char);
	short unsigned int debug;
	struct dentry___30 *debug_dir;
	struct dentry___30 *debug_rdesc;
	struct dentry___30 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___4 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	int (*probe)(struct hid_device___4 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___4 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___4 *, struct hid_report___4 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___4 *, struct hid_report___4 *);
	__u8 * (*report_fixup)(struct hid_device___4 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___4 *, struct hid_input___4 *, struct hid_field___4 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___4 *, struct hid_input___4 *, struct hid_field___4 *, struct hid_usage *, long unsigned int **, int *);
	void (*input_configured)(struct hid_device___4 *, struct hid_input___4 *);
	void (*feature_mapping)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *);
	int (*suspend)(struct hid_device___4 *, pm_message_t);
	int (*resume)(struct hid_device___4 *);
	int (*reset_resume)(struct hid_device___4 *);
	struct device_driver___231 driver;
};

struct hid_ll_driver___4 {
	int (*start)(struct hid_device___4 *);
	void (*stop)(struct hid_device___4 *);
	int (*open)(struct hid_device___4 *);
	void (*close)(struct hid_device___4 *);
	int (*power)(struct hid_device___4 *, int);
	int (*hidinput_input_event)(struct input_dev___9 *, unsigned int, unsigned int, int);
	int (*parse)(struct hid_device___4 *);
	void (*request)(struct hid_device___4 *, struct hid_report___4 *, int);
	int (*wait)(struct hid_device___4 *);
	int (*idle)(struct hid_device___4 *, int, int, int);
};

struct hidraw_devinfo {
	__u32 bustype;
	__s16 vendor;
	__s16 product;
};

struct hidraw___2 {
	unsigned int minor;
	int exist;
	int open;
	wait_queue_head_t wait;
	struct hid_device___4 *hid;
	struct device___231 *dev;
	struct list_head list;
};

struct hidraw_report {
	__u8 *value;
	int len;
};

struct hidraw_list {
	struct hidraw_report buffer[64];
	int head;
	int tail;
	struct fasync_struct___29 *fasync;
	struct hidraw___2 *hidraw;
	struct list_head node;
	struct mutex___30 read_mutex;
};

struct a4tech_sc {
	long unsigned int quirks;
	unsigned int hw_wheel;
	__s32 delayed_value;
};

struct apple_sc {
	long unsigned int quirks;
	unsigned int fn_on;
	long unsigned int pressed_fn[12];
	long unsigned int pressed_numlock[12];
};

struct apple_key_translation {
	u16 from;
	u16 to;
	u8 flags;
};

struct lg_drv_data {
	long unsigned int quirks;
	void *device_props;
};

struct magicmouse_sc {
	struct input_dev___4 *input;
	long unsigned int quirks;
	int ntouches;
	int scroll_accel;
	long unsigned int scroll_jiffies;
	struct {
		short int x;
		short int y;
		short int scroll_x;
		short int scroll_y;
		u8 size;
	} touches[16];
	int tracking_ids[16];
};

struct ntrig_data {
	__u16 x;
	__u16 y;
	__u16 w;
	__u16 h;
	__u16 id;
	bool tipswitch;
	bool confidence;
	bool first_contact_touch;
	bool reading_mt;
	__u8 mt_footer[4];
	__u8 mt_foot_count;
	__s8 act_state;
	__s8 deactivate_slack;
	__s8 activate_slack;
	__u16 min_width;
	__u16 min_height;
	__u16 activation_width;
	__u16 activation_height;
	__u16 sensor_logical_width;
	__u16 sensor_logical_height;
	__u16 sensor_physical_width;
	__u16 sensor_physical_height;
};

struct usbdrv_wrap___7 {
	struct device_driver___194 driver;
	int for_devices;
};

struct usb_driver___7 {
	const char *name;
	int (*probe)(struct usb_interface___12 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___12 *);
	int (*unlocked_ioctl)(struct usb_interface___12 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___12 *, pm_message_t);
	int (*resume)(struct usb_interface___12 *);
	int (*reset_resume)(struct usb_interface___12 *);
	int (*pre_reset)(struct usb_interface___12 *);
	int (*post_reset)(struct usb_interface___12 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___7 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct hid_control_fifo {
	unsigned char dir;
	struct hid_report___2 *report;
	char *raw_report;
};

struct hid_output_fifo {
	struct hid_report___2 *report;
	char *raw_report;
};

struct hid_class_descriptor {
	__u8 bDescriptorType;
	__le16 wDescriptorLength;
} __attribute__((packed));

struct hid_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdHID;
	__u8 bCountryCode;
	__u8 bNumDescriptors;
	struct hid_class_descriptor desc[1];
} __attribute__((packed));

struct usbhid_device {
	struct hid_device___2 *hid;
	struct usb_interface___12 *intf;
	int ifnum;
	unsigned int bufsize;
	struct urb___12 *urbin;
	char *inbuf;
	dma_addr_t inbuf_dma;
	struct urb___12 *urbctrl;
	struct usb_ctrlrequest *cr;
	struct hid_control_fifo ctrl[256];
	unsigned char ctrlhead;
	unsigned char ctrltail;
	char *ctrlbuf;
	dma_addr_t ctrlbuf_dma;
	long unsigned int last_ctrl;
	struct urb___12 *urbout;
	struct hid_output_fifo out[256];
	unsigned char outhead;
	unsigned char outtail;
	char *outbuf;
	dma_addr_t outbuf_dma;
	long unsigned int last_out;
	spinlock_t lock;
	long unsigned int iofl;
	struct timer_list io_retry;
	long unsigned int stop_retry;
	unsigned int retry_delay;
	struct work_struct reset_work;
	wait_queue_head_t wait;
	int ledcount;
	struct work_struct led_work;
};

struct hid_blacklist {
	__u16 idVendor;
	__u16 idProduct;
	__u32 quirks;
};

struct quirks_list_struct {
	struct hid_blacklist hid_bl_item;
	struct list_head node;
};

typedef struct poll_table_struct___119 poll_table___36;

struct usb_interface___15 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	struct device___231 dev;
	struct device___231 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___15 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___15 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___15;

struct usb_bus___15 {
	struct device___231 *controller;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct usb_devmap devmap;
	struct usb_device___15 *root_hub;
	struct usb_bus___15 *hs_companion;
	struct list_head bus_list;
	struct mutex___223 usb_address0_mutex;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_device___15 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___15 *parent;
	struct usb_bus___15 *bus;
	struct usb_host_endpoint ep0;
	struct device___231 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___15 *config;
	struct usb_host_config___15 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
};

struct usb_class_driver___2 {
	char *name;
	char * (*devnode)(struct device___231 *, umode_t *);
	const struct file_operations___221 *fops;
	int minor_base;
};

struct urb___15;

typedef void (*usb_complete_t___15)(struct urb___15 *);

struct urb___15 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___15 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___15 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hid_control_fifo___2 {
	unsigned char dir;
	struct hid_report___4 *report;
	char *raw_report;
};

struct hid_output_fifo___2 {
	struct hid_report___4 *report;
	char *raw_report;
};

struct hiddev_event {
	unsigned int hid;
	int value;
};

struct hiddev_devinfo {
	__u32 bustype;
	__u32 busnum;
	__u32 devnum;
	__u32 ifnum;
	__s16 vendor;
	__s16 product;
	__s16 version;
	__u32 num_applications;
};

struct hiddev_collection_info {
	__u32 index;
	__u32 type;
	__u32 usage;
	__u32 level;
};

struct hiddev_report_info {
	__u32 report_type;
	__u32 report_id;
	__u32 num_fields;
};

struct hiddev_field_info {
	__u32 report_type;
	__u32 report_id;
	__u32 field_index;
	__u32 maxusage;
	__u32 flags;
	__u32 physical;
	__u32 logical;
	__u32 application;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__u32 unit_exponent;
	__u32 unit;
};

struct hiddev_usage_ref {
	__u32 report_type;
	__u32 report_id;
	__u32 field_index;
	__u32 usage_index;
	__u32 usage_code;
	__s32 value;
};

struct hiddev_usage_ref_multi {
	struct hiddev_usage_ref uref;
	__u32 num_values;
	__s32 values[1024];
};

struct usbhid_device___2 {
	struct hid_device___4 *hid;
	struct usb_interface___15 *intf;
	int ifnum;
	unsigned int bufsize;
	struct urb___15 *urbin;
	char *inbuf;
	dma_addr_t inbuf_dma;
	struct urb___15 *urbctrl;
	struct usb_ctrlrequest *cr;
	struct hid_control_fifo___2 ctrl[256];
	unsigned char ctrlhead;
	unsigned char ctrltail;
	char *ctrlbuf;
	dma_addr_t ctrlbuf_dma;
	long unsigned int last_ctrl;
	struct urb___15 *urbout;
	struct hid_output_fifo___2 out[256];
	unsigned char outhead;
	unsigned char outtail;
	char *outbuf;
	dma_addr_t outbuf_dma;
	long unsigned int last_out;
	spinlock_t lock;
	long unsigned int iofl;
	struct timer_list io_retry;
	long unsigned int stop_retry;
	unsigned int retry_delay;
	struct work_struct reset_work;
	wait_queue_head_t wait;
	int ledcount;
	struct work_struct led_work;
};

struct hiddev {
	int exist;
	int open;
	struct mutex___223 existancelock;
	wait_queue_head_t wait;
	struct hid_device___4 *hid;
	struct list_head list;
	spinlock_t list_lock;
};

struct hiddev_list {
	struct hiddev_usage_ref buffer[2048];
	int head;
	int tail;
	unsigned int flags;
	struct fasync_struct___221 *fasync;
	struct hiddev *hiddev;
	struct list_head node;
	struct mutex___223 thread_lock;
};

struct pidff_usage {
	struct hid_field___3 *field;
	s32 *value;
};

struct pidff_device {
	struct hid_device___3 *hid;
	struct hid_report___3 *reports[13];
	struct pidff_usage set_effect[7];
	struct pidff_usage set_envelope[5];
	struct pidff_usage set_condition[8];
	struct pidff_usage set_periodic[5];
	struct pidff_usage set_constant[2];
	struct pidff_usage set_ramp[3];
	struct pidff_usage device_gain[1];
	struct pidff_usage block_load[2];
	struct pidff_usage pool[3];
	struct pidff_usage effect_operation[2];
	struct pidff_usage block_free[1];
	struct hid_field___3 *create_new_effect_type;
	struct hid_field___3 *set_effect_type;
	struct hid_field___3 *effect_direction;
	struct hid_field___3 *device_control;
	struct hid_field___3 *block_load_status;
	struct hid_field___3 *effect_operation_status;
	int control_id[2];
	int type_id[11];
	int status_id[2];
	int operation_id[2];
	int pid_id[64];
};

enum iommu_attr {
	DOMAIN_ATTR_GEOMETRY = 0,
	DOMAIN_ATTR_PAGING = 1,
	DOMAIN_ATTR_WINDOWS = 2,
	DOMAIN_ATTR_MAX = 3,
};

struct iommu_domain;

struct iommu_ops {
	int (*domain_init)(struct iommu_domain *);
	void (*domain_destroy)(struct iommu_domain *);
	int (*attach_dev)(struct iommu_domain *, struct device___224 *);
	void (*detach_dev)(struct iommu_domain *, struct device___224 *);
	int (*map)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain *, long unsigned int, size_t);
	phys_addr_t (*iova_to_phys)(struct iommu_domain *, dma_addr_t);
	int (*domain_has_cap)(struct iommu_domain *, long unsigned int);
	int (*add_device)(struct device___224 *);
	void (*remove_device)(struct device___224 *);
	int (*device_group)(struct device___224 *, unsigned int *);
	int (*domain_get_attr)(struct iommu_domain *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain *, enum iommu_attr, void *);
	int (*domain_window_enable)(struct iommu_domain *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain *, u32);
	int (*domain_set_windows)(struct iommu_domain *, u32);
	u32 (*domain_get_windows)(struct iommu_domain *);
	long unsigned int pgsize_bitmap;
};

struct iommu_group {
	struct kobject___24 kobj;
	struct kobject___24 *devices_kobj;
	struct list_head devices;
	struct mutex___236 mutex;
	struct blocking_notifier_head notifier;
	void *iommu_data;
	void (*iommu_data_release)(void *);
	char *name;
	int id;
};

typedef int (*iommu_fault_handler_t)(struct iommu_domain *, struct device___224 *, long unsigned int, int, void *);

struct iommu_domain_geometry {
	dma_addr_t aperture_start;
	dma_addr_t aperture_end;
	bool force_aperture;
};

struct iommu_domain {
	struct iommu_ops *ops;
	void *priv;
	iommu_fault_handler_t handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
};

struct iommu_device {
	struct list_head list;
	struct device___224 *dev;
	char *name;
};

struct iommu_group_attribute {
	struct attribute attr;
	ssize_t (*show)(struct iommu_group *, char *);
	ssize_t (*store)(struct iommu_group *, const char *, size_t);
};

struct group_for_pci_data {
	struct pci_dev___27 *pdev;
	struct iommu_group *group;
};

struct page___237;

typedef struct page___237 *pgtable_t___237;

struct address_space___238;

struct kmem_cache___221;

struct page___237 {
	long unsigned int flags;
	struct address_space___238 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___237 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___237 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___221 *slab_cache;
		struct page___237 *first_page;
	};
	long: 64;
};

struct thread_struct___83;

struct task_struct___239;

struct pv_cpu_ops___239 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___83 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___83 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___239 *);
	void (*end_context_switch)(struct task_struct___239 *);
};

struct perf_event___83;

struct thread_struct___83 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___83 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___93;

struct pid_link___93 {
	struct hlist_node node;
	struct pid___93 *pid;
};

struct mutex___240 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___239 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___232 {
	struct page___237 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___246;

struct nsproxy___119;

struct signal_struct___239;

struct css_set___134;

struct perf_event_context___83;

struct task_struct___239 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___239 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___246 *mm;
	struct mm_struct___246 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___239 *real_parent;
	struct task_struct___239 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___239 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___93 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___239 = 0,
		VTIME_USER___239 = 1,
		VTIME_SYS___239 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___83 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___119 *nsproxy;
	struct signal_struct___239 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___134 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___83 *perf_event_ctxp[2];
	struct mutex___240 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___232 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___246 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___246 *, struct mm_struct___246 *);
	void (*dup_mmap)(struct mm_struct___246 *, struct mm_struct___246 *);
	void (*exit_mmap)(struct mm_struct___246 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___246 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___246 *);
	void (*pgd_free)(struct mm_struct___246 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___246 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___246 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___246 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___246 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___246 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___246 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___246 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___246 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___246 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___246 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___246 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___240 lock;
	void *vdso;
} mm_context_t___240;

struct xol_area___237;

struct uprobes_state___237 {
	struct xol_area___237 *xol_area;
};

struct vm_area_struct___246;

struct file___238;

struct core_state___239;

struct mm_struct___246 {
	struct vm_area_struct___246 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___246 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___246 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___240 context;
	long unsigned int flags;
	struct core_state___239 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___239 *owner;
	struct file___238 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___237 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___83 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___239 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___239 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___239 *target;
};

typedef void (*perf_overflow_handler_t___83)(struct perf_event___83 *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops___83;

typedef void (*ftrace_func_t___83)(long unsigned int, long unsigned int, struct ftrace_ops___83 *, struct pt_regs *);

struct ftrace_ops___83 {
	ftrace_func_t___83 func;
	struct ftrace_ops___83 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___240 regex_lock;
};

struct pmu___83;

struct fasync_struct___238;

struct pid_namespace___93;

struct ftrace_event_call___72;

struct perf_cgroup___83;

struct perf_event___83 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___83 *group_leader;
	struct pmu___83 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___83 hw;
	struct perf_event_context___83 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___240 child_mutex;
	struct list_head child_list;
	struct perf_event___83 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___239 *owner;
	struct mutex___240 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___238 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___83 *);
	struct callback_head callback_head;
	struct pid_namespace___93 *ns;
	u64 id;
	perf_overflow_handler_t___83 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___72 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___83 ftrace_ops;
	struct perf_cgroup___83 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___109 {
	struct task_struct___239 *task;
	struct exec_domain___65 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct bin_attribute___200;

struct attribute_group___198 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___200 **bin_attrs;
};

struct bin_attribute___200 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___238 *, struct kobject___24 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___238 *, struct kobject___24 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	int (*mmap)(struct file___238 *, struct kobject___24 *, struct bin_attribute___200 *, struct vm_area_struct___246 *);
};

struct dentry___238;

struct path___238 {
	struct vfsmount *mnt;
	struct dentry___238 *dentry;
};

struct fown_struct___93 {
	rwlock_t lock;
	struct pid___93 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___238;

struct file_operations___238;

struct file___238 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___238 f_path;
	struct inode___238 *f_inode;
	const struct file_operations___238 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___93 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___238 *f_mapping;
	struct mutex___240 f_pos_lock;
};

struct vm_operations_struct___212;

struct vm_area_struct___246 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___246 *vm_next;
	struct vm_area_struct___246 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___246 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___212 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___238 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___232;

struct dev_pm_ops___232 {
	int (*prepare)(struct device___232 *);
	void (*complete)(struct device___232 *);
	int (*suspend)(struct device___232 *);
	int (*resume)(struct device___232 *);
	int (*freeze)(struct device___232 *);
	int (*thaw)(struct device___232 *);
	int (*poweroff)(struct device___232 *);
	int (*restore)(struct device___232 *);
	int (*suspend_late)(struct device___232 *);
	int (*resume_early)(struct device___232 *);
	int (*freeze_late)(struct device___232 *);
	int (*thaw_early)(struct device___232 *);
	int (*poweroff_late)(struct device___232 *);
	int (*restore_early)(struct device___232 *);
	int (*suspend_noirq)(struct device___232 *);
	int (*resume_noirq)(struct device___232 *);
	int (*freeze_noirq)(struct device___232 *);
	int (*thaw_noirq)(struct device___232 *);
	int (*poweroff_noirq)(struct device___232 *);
	int (*restore_noirq)(struct device___232 *);
	int (*runtime_suspend)(struct device___232 *);
	int (*runtime_resume)(struct device___232 *);
	int (*runtime_idle)(struct device___232 *);
};

struct dma_map_ops___97;

struct dev_archdata___97 {
	struct dma_map_ops___97 *dma_ops;
	void *iommu;
};

struct device_type___232;

struct bus_type___232;

struct device_driver___232;

struct dev_pm_domain___232;

struct class___232;

struct device_rh___232;

struct device___232 {
	struct device___232 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___232 *type;
	struct mutex___240 mutex;
	struct bus_type___232 *bus;
	struct device_driver___232 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___232 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___97 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___37 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___232 *class;
	const struct attribute_group___198 **groups;
	void (*release)(struct device___232 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___232 *device_rh;
};

struct dev_pm_info_rh___232 {
	void (*set_latency_tolerance)(struct device___232 *, s32);
};

struct dev_pm_domain___232 {
	struct dev_pm_ops___232 ops;
};

struct zone___239;

struct lruvec___239 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___239 *zone;
};

struct pglist_data___239;

struct zone___239 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___239 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___239 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___239 {
	struct zone___239 *zone;
	int zone_idx;
};

struct zonelist___239 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___239 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___239 {
	struct zone___239 node_zones[4];
	struct zonelist___239 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___239 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___158;

struct x86_io_apic_ops___158 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___158 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___158;

struct irq_data___158 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___158 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___239 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___239 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___97 {
	void * (*alloc)(struct device___232 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___232 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___232 *, struct vm_area_struct___246 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___232 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___232 *, struct page___237 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___232 *, dma_addr_t);
	int (*dma_supported)(struct device___232 *, u64);
	int (*set_dma_mask)(struct device___232 *, u64);
	int is_phys;
};

struct bus_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___232 *, char *);
	ssize_t (*store)(struct bus_type___232 *, const char *, size_t);
};

struct device_attribute___232;

struct driver_attribute___232;

struct bus_type___232 {
	const char *name;
	const char *dev_name;
	struct device___232 *dev_root;
	struct bus_attribute___232 *bus_attrs;
	struct device_attribute___232 *dev_attrs;
	struct driver_attribute___232 *drv_attrs;
	const struct attribute_group___198 **bus_groups;
	const struct attribute_group___198 **dev_groups;
	const struct attribute_group___198 **drv_groups;
	int (*match)(struct device___232 *, struct device_driver___232 *);
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	int (*probe)(struct device___232 *);
	int (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*online)(struct device___232 *);
	int (*offline)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct device___232 *, struct device_attribute___232 *, char *);
	ssize_t (*store)(struct device___232 *, struct device_attribute___232 *, const char *, size_t);
};

struct driver_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___232 *, char *);
	ssize_t (*store)(struct device_driver___232 *, const char *, size_t);
};

struct device_driver___232 {
	const char *name;
	struct bus_type___232 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___232 *);
	int (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	const struct attribute_group___198 **groups;
	const struct dev_pm_ops___232 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___232 {
	const char *name;
	const struct attribute_group___198 **groups;
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
};

struct class_attribute___232;

struct class___232 {
	const char *name;
	struct module *owner;
	struct class_attribute___232 *class_attrs;
	struct device_attribute___232 *dev_attrs;
	const struct attribute_group___198 **dev_groups;
	struct bin_attribute___200 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *);
	void (*class_release)(struct class___232 *);
	void (*dev_release)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
	struct subsys_private *p;
};

struct class_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct class___232 *, struct class_attribute___232 *, char *);
	ssize_t (*store)(struct class___232 *, struct class_attribute___232 *, const char *, size_t);
	const void * (*namespace)(struct class___232 *, const struct class_attribute___232 *);
};

struct device_rh___232 {
	struct dev_pm_info_rh___232 power;
};

struct xol_area___237 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___237 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___220;

struct memcg_cache_params___221;

struct kmem_cache___221 {
	struct kmem_cache_cpu___220 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___24 kobj;
	struct memcg_cache_params___221 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___238;

struct address_space___238 {
	struct inode___238 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___240 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___238 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___208;

struct vm_operations_struct___212 {
	void (*open)(struct vm_area_struct___246 *);
	void (*close)(struct vm_area_struct___246 *);
	int (*fault)(struct vm_area_struct___246 *, struct vm_fault___208 *);
	int (*page_mkwrite)(struct vm_area_struct___246 *, struct vm_fault___208 *);
	int (*access)(struct vm_area_struct___246 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___246 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___246 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___246 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___246 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___239 {
	struct task_struct___239 *task;
	struct core_thread___239 *next;
};

struct core_state___239 {
	atomic_t nr_threads;
	struct core_thread___239 dumper;
	struct completion startup;
};

struct vm_fault___208 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___237 *page;
};

struct kmem_cache_cpu___220 {
	void **freelist;
	long unsigned int tid;
	struct page___237 *page;
	struct page___237 *partial;
};

struct memcg_cache_params___221 {
	bool is_root_cache;
	union {
		struct kmem_cache___221 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___221 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct seq_operations___163;

struct seq_file___163 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___240 lock;
	const struct seq_operations___163 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___163 {
	void * (*start)(struct seq_file___163 *, loff_t *);
	void (*stop)(struct seq_file___163 *, void *);
	void * (*next)(struct seq_file___163 *, void *, loff_t *);
	int (*show)(struct seq_file___163 *, void *);
};

struct dentry_operations___238;

struct super_block___238;

struct dentry___238 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___238 *d_parent;
	struct qstr d_name;
	struct inode___238 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___238 *d_op;
	struct super_block___238 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___238;

struct file_lock___238;

struct dquot___238;

struct block_device___238;

struct inode___238 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___238 *i_op;
	struct super_block___238 *i_sb;
	struct address_space___238 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___240 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___238 *i_fop;
	struct file_lock___238 *i_flock;
	struct address_space___238 i_data;
	struct dquot___238 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___238 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___238 {
	int (*d_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_hash)(const struct dentry___238 *, struct qstr *);
	int (*d_compare)(const struct dentry___238 *, const struct dentry___238 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___238 *);
	void (*d_release)(struct dentry___238 *);
	void (*d_prune)(struct dentry___238 *);
	void (*d_iput)(struct dentry___238 *, struct inode___238 *);
	char * (*d_dname)(struct dentry___238 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___238 *);
	int (*d_manage)(struct dentry___238 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___238;

struct mem_dqinfo___238 {
	struct quota_format_type___238 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___238;

struct quota_info___238 {
	unsigned int flags;
	struct mutex___240 dqio_mutex;
	struct mutex___240 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___238 *files[2];
	struct mem_dqinfo___238 info[2];
	const struct quota_format_ops___238 *ops[2];
};

struct file_system_type___238;

struct super_operations___238;

struct dquot_operations___238;

struct quotactl_ops___238;

struct xattr_handler___135;

struct super_block___238 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___238 *s_type;
	const struct super_operations___238 *s_op;
	const struct dquot_operations___238 *dq_op;
	const struct quotactl_ops___238 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___238 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___135 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___238 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___238 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___240 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___238 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___93 {
	int nr;
	struct pid_namespace___93 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___93 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___239 *child_reaper;
	struct kmem_cache___221 *pid_cachep;
	unsigned int level;
	struct pid_namespace___93 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___238 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___93 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___93 numbers[1];
};

struct block_device___238 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___238 *bd_inode;
	struct super_block___238 *bd_super;
	struct mutex___240 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___238 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___240 bd_fsfreeze_mutex;
};

struct cgroup___134;

struct cgroup_subsys_state___134 {
	struct cgroup___134 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___238 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___238 *ia_file;
};

struct dquot___238 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___240 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___238 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___238 {
	int qf_fmt_id;
	const struct quota_format_ops___238 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___238 *qf_next;
};

struct quota_format_ops___238 {
	int (*check_quota_file)(struct super_block___238 *, int);
	int (*read_file_info)(struct super_block___238 *, int);
	int (*write_file_info)(struct super_block___238 *, int);
	int (*free_file_info)(struct super_block___238 *, int);
	int (*read_dqblk)(struct dquot___238 *);
	int (*commit_dqblk)(struct dquot___238 *);
	int (*release_dqblk)(struct dquot___238 *);
};

struct dquot_operations___238 {
	int (*write_dquot)(struct dquot___238 *);
	struct dquot___238 * (*alloc_dquot)(struct super_block___238 *, int);
	void (*destroy_dquot)(struct dquot___238 *);
	int (*acquire_dquot)(struct dquot___238 *);
	int (*release_dquot)(struct dquot___238 *);
	int (*mark_dirty)(struct dquot___238 *);
	int (*write_info)(struct super_block___238 *, int);
	qsize_t * (*get_reserved_space)(struct inode___238 *);
};

struct quotactl_ops___238 {
	int (*quota_on)(struct super_block___238 *, int, int, struct path___238 *);
	int (*quota_on_meta)(struct super_block___238 *, int, int);
	int (*quota_off)(struct super_block___238 *, int);
	int (*quota_sync)(struct super_block___238 *, int);
	int (*get_info)(struct super_block___238 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___238 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___238 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___238 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___238 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___238 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___238 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___238 *, unsigned int);
};

struct address_space_operations___238 {
	int (*writepage)(struct page___237 *, struct writeback_control *);
	int (*readpage)(struct file___238 *, struct page___237 *);
	int (*writepages)(struct address_space___238 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___237 *);
	int (*readpages)(struct file___238 *, struct address_space___238 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___238 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___237 **, void **);
	int (*write_end)(struct file___238 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___237 *, void *);
	sector_t (*bmap)(struct address_space___238 *, sector_t);
	void (*invalidatepage)(struct page___237 *, long unsigned int);
	int (*releasepage)(struct page___237 *, gfp_t);
	void (*freepage)(struct page___237 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___238 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___238 *, struct page___237 *, struct page___237 *, enum migrate_mode);
	int (*launder_page)(struct page___237 *);
	int (*is_partially_uptodate)(struct page___237 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___237 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___238 *, struct page___237 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___238 *, sector_t *);
	void (*swap_deactivate)(struct file___238 *);
	void (*invalidatepage_range)(struct page___237 *, unsigned int, unsigned int);
};

struct inode_operations___238 {
	struct dentry___238 * (*lookup)(struct inode___238 *, struct dentry___238 *, unsigned int);
	void * (*follow_link)(struct dentry___238 *, struct nameidata *);
	int (*permission)(struct inode___238 *, int);
	struct posix_acl * (*get_acl)(struct inode___238 *, int);
	int (*readlink)(struct dentry___238 *, char *, int);
	void (*put_link)(struct dentry___238 *, struct nameidata *, void *);
	int (*create)(struct inode___238 *, struct dentry___238 *, umode_t, bool);
	int (*link)(struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*unlink)(struct inode___238 *, struct dentry___238 *);
	int (*symlink)(struct inode___238 *, struct dentry___238 *, const char *);
	int (*mkdir)(struct inode___238 *, struct dentry___238 *, umode_t);
	int (*rmdir)(struct inode___238 *, struct dentry___238 *);
	int (*mknod)(struct inode___238 *, struct dentry___238 *, umode_t, dev_t);
	int (*rename)(struct inode___238 *, struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*setattr)(struct dentry___238 *, struct iattr___238 *);
	int (*getattr)(struct vfsmount *, struct dentry___238 *, struct kstat *);
	int (*setxattr)(struct dentry___238 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___238 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___238 *, char *, size_t);
	int (*removexattr)(struct dentry___238 *, const char *);
	int (*fiemap)(struct inode___238 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___238 *, struct timespec *, int);
	int (*atomic_open)(struct inode___238 *, struct dentry___238 *, struct file___238 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___128;

struct file_operations___238 {
	struct module *owner;
	loff_t (*llseek)(struct file___238 *, loff_t, int);
	ssize_t (*read)(struct file___238 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___238 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___238 *, void *, filldir_t);
	unsigned int (*poll)(struct file___238 *, struct poll_table_struct___128 *);
	long int (*unlocked_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___238 *, struct vm_area_struct___246 *);
	int (*open)(struct inode___238 *, struct file___238 *);
	int (*flush)(struct file___238 *, fl_owner_t);
	int (*release)(struct inode___238 *, struct file___238 *);
	int (*fsync)(struct file___238 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___238 *, int);
	int (*lock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*sendpage)(struct file___238 *, struct page___237 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___238 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___238 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___238 *, long int, struct file_lock___238 **, void **);
		struct {
			int (*setlease)(struct file___238 *, long int, struct file_lock___238 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___238 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___163 *, struct file___238 *);
};

struct file_lock_operations___238;

struct lock_manager_operations___238;

struct file_lock___238 {
	struct file_lock___238 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___93 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___238 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___238 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___238 *fl_ops;
	const struct lock_manager_operations___238 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___238 {
	void (*fl_copy_lock)(struct file_lock___238 *, struct file_lock___238 *);
	void (*fl_release_private)(struct file_lock___238 *);
};

struct lock_manager_operations___238 {
	int (*lm_compare_owner)(struct file_lock___238 *, struct file_lock___238 *);
	long unsigned int (*lm_owner_key)(struct file_lock___238 *);
	void (*lm_notify)(struct file_lock___238 *);
	int (*lm_grant)(struct file_lock___238 *, struct file_lock___238 *, int);
	void (*lm_break)(struct file_lock___238 *);
	int (*lm_change)(struct file_lock___238 **, int);
};

struct fasync_struct___238 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___238 *fa_next;
	struct file___238 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___238 {
	const char *name;
	int fs_flags;
	struct dentry___238 * (*mount)(struct file_system_type___238 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___238 *);
	struct module *owner;
	struct file_system_type___238 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___238 {
	struct inode___238 * (*alloc_inode)(struct super_block___238 *);
	void (*destroy_inode)(struct inode___238 *);
	void (*dirty_inode)(struct inode___238 *, int);
	int (*write_inode)(struct inode___238 *, struct writeback_control *);
	int (*drop_inode)(struct inode___238 *);
	void (*evict_inode)(struct inode___238 *);
	void (*put_super)(struct super_block___238 *);
	int (*sync_fs)(struct super_block___238 *, int);
	int (*freeze_fs)(struct super_block___238 *);
	int (*unfreeze_fs)(struct super_block___238 *);
	int (*statfs)(struct dentry___238 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___238 *, int *, char *);
	void (*umount_begin)(struct super_block___238 *);
	int (*show_options)(struct seq_file___163 *, struct dentry___238 *);
	int (*show_devname)(struct seq_file___163 *, struct dentry___238 *);
	int (*show_path)(struct seq_file___163 *, struct dentry___238 *);
	int (*show_stats)(struct seq_file___163 *, struct dentry___238 *);
	ssize_t (*quota_read)(struct super_block___238 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___238 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___238 *);
	int (*bdev_try_to_free_page)(struct super_block___238 *, struct page___237 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___238 *);
	void (*free_cached_objects)(struct super_block___238 *, int);
};

struct xattr_handler___135 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___238 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___238 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___238 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___130)(struct file___238 *, wait_queue_head_t *, struct poll_table_struct___128 *);

struct poll_table_struct___128 {
	poll_queue_proc___130 _qproc;
	long unsigned int _key;
};

struct nsproxy___119 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___93 *pid_ns;
	struct net *net_ns;
};

struct irq_chip___158 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___158 *);
	void (*irq_shutdown)(struct irq_data___158 *);
	void (*irq_enable)(struct irq_data___158 *);
	void (*irq_disable)(struct irq_data___158 *);
	void (*irq_ack)(struct irq_data___158 *);
	void (*irq_mask)(struct irq_data___158 *);
	void (*irq_mask_ack)(struct irq_data___158 *);
	void (*irq_unmask)(struct irq_data___158 *);
	void (*irq_eoi)(struct irq_data___158 *);
	int (*irq_set_affinity)(struct irq_data___158 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___158 *);
	int (*irq_set_type)(struct irq_data___158 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___158 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___158 *);
	void (*irq_bus_sync_unlock)(struct irq_data___158 *);
	void (*irq_cpu_online)(struct irq_data___158 *);
	void (*irq_cpu_offline)(struct irq_data___158 *);
	void (*irq_suspend)(struct irq_data___158 *);
	void (*irq_resume)(struct irq_data___158 *);
	void (*irq_pm_shutdown)(struct irq_data___158 *);
	void (*irq_print_chip)(struct irq_data___158 *, struct seq_file___163 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___158 *, void *);
	long unsigned int flags;
};

struct signal_struct___239 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___239 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___239 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___93 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___93 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___240 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___134 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___134 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___83 {
	struct pmu___83 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___240 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___239 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___83 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct cgroupfs_root___134;

struct cgroup___134 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___134 *parent;
	struct dentry___238 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___134 *subsys[11];
	struct cgroupfs_root___134 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___240 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___134 {
	struct super_block___238 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___134 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct perf_cpu_context___83;

struct pmu___83 {
	struct list_head entry;
	struct device___232 *dev;
	const struct attribute_group___198 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___83 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___83 *);
	void (*pmu_disable)(struct pmu___83 *);
	int (*event_init)(struct perf_event___83 *);
	int (*add)(struct perf_event___83 *, int);
	void (*del)(struct perf_event___83 *, int);
	void (*start)(struct perf_event___83 *, int);
	void (*stop)(struct perf_event___83 *, int);
	void (*read)(struct perf_event___83 *);
	void (*start_txn)(struct pmu___83 *);
	int (*commit_txn)(struct pmu___83 *);
	void (*cancel_txn)(struct pmu___83 *);
	int (*event_idx)(struct perf_event___83 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___83 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___83 *);
};

struct perf_cpu_context___83 {
	struct perf_event_context___83 ctx;
	struct perf_event_context___83 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___83 *unique_pmu;
	struct perf_cgroup___83 *cgrp;
};

struct trace_event_functions___72;

struct trace_event___72 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___72 *funcs;
};

struct ftrace_event_class___72;

struct ftrace_event_call___72 {
	struct list_head list;
	struct ftrace_event_class___72 *class;
	char *name;
	struct trace_event___72 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___83 {
	struct cgroup_subsys_state___134 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___72 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___240 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___72)(struct trace_iterator___72 *, int, struct trace_event___72 *);

struct trace_event_functions___72 {
	trace_print_func___72 trace;
	trace_print_func___72 raw;
	trace_print_func___72 hex;
	trace_print_func___72 binary;
};

struct ftrace_event_class___72 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___72 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___72 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___72 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___72 *);
};

struct ftrace_event_file___26 {
	struct list_head list;
	struct ftrace_event_call___72 *event_call;
	struct dentry___238 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_iommu_group_event {
	struct trace_entry ent;
	int gid;
	u32 __data_loc_device;
	char __data[0];
};

struct ftrace_raw_iommu_device_event {
	struct trace_entry ent;
	u32 __data_loc_device;
	char __data[0];
};

struct ftrace_raw_iommu_map_unmap {
	struct trace_entry ent;
	u64 iova;
	u64 paddr;
	int size;
	char __data[0];
};

struct ftrace_raw_iommu_error {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	u64 iova;
	int flags;
	char __data[0];
};

struct ftrace_data_offsets_iommu_group_event {
	u32 device;
};

struct ftrace_data_offsets_iommu_device_event {
	u32 device;
};

struct ftrace_data_offsets_iommu_map_unmap {};

struct ftrace_data_offsets_iommu_error {
	u32 device;
	u32 driver;
};

typedef int (*iommu_fault_handler_t___2)(struct iommu_domain *, struct device___232 *, long unsigned int, int, void *);

struct device___233;

struct dev_pm_ops___233 {
	int (*prepare)(struct device___233 *);
	void (*complete)(struct device___233 *);
	int (*suspend)(struct device___233 *);
	int (*resume)(struct device___233 *);
	int (*freeze)(struct device___233 *);
	int (*thaw)(struct device___233 *);
	int (*poweroff)(struct device___233 *);
	int (*restore)(struct device___233 *);
	int (*suspend_late)(struct device___233 *);
	int (*resume_early)(struct device___233 *);
	int (*freeze_late)(struct device___233 *);
	int (*thaw_early)(struct device___233 *);
	int (*poweroff_late)(struct device___233 *);
	int (*restore_early)(struct device___233 *);
	int (*suspend_noirq)(struct device___233 *);
	int (*resume_noirq)(struct device___233 *);
	int (*freeze_noirq)(struct device___233 *);
	int (*thaw_noirq)(struct device___233 *);
	int (*poweroff_noirq)(struct device___233 *);
	int (*restore_noirq)(struct device___233 *);
	int (*runtime_suspend)(struct device___233 *);
	int (*runtime_resume)(struct device___233 *);
	int (*runtime_idle)(struct device___233 *);
};

struct dma_map_ops___98;

struct dev_archdata___98 {
	struct dma_map_ops___98 *dma_ops;
	void *iommu;
};

struct device_type___233;

struct bus_type___233;

struct device_driver___233;

struct dev_pm_domain___233;

struct class___233;

struct device_rh___233;

struct device___233 {
	struct device___233 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___233 *type;
	struct mutex___240 mutex;
	struct bus_type___233 *bus;
	struct device_driver___233 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___233 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___98 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___37 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___233 *class;
	const struct attribute_group___198 **groups;
	void (*release)(struct device___233 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___233 *device_rh;
};

struct dev_pm_info_rh___233 {
	void (*set_latency_tolerance)(struct device___233 *, s32);
};

struct dev_pm_domain___233 {
	struct dev_pm_ops___233 ops;
};

struct pci_bus___27;

struct pci_slot___27;

struct pci_driver___27;

struct pci_dev___28 {
	struct list_head bus_list;
	struct pci_bus___27 *bus;
	struct pci_bus___27 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___27 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___27 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___233 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___200 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___200 *res_attr[17];
	struct bin_attribute___200 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___24 *msi_kset;
	const struct attribute_group___198 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___28 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___6 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___28 *dev;
	struct msi_msg msg;
	struct kobject___24 kobj;
};

struct irq_data___159;

struct x86_io_apic_ops___159 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___159 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___159;

struct irq_data___159 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___159 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___6 *msi_desc;
	cpumask_var_t affinity;
};

struct dma_map_ops___98 {
	void * (*alloc)(struct device___233 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___233 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___233 *, struct vm_area_struct___246 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___233 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___233 *, struct page___237 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___233 *, dma_addr_t);
	int (*dma_supported)(struct device___233 *, u64);
	int (*set_dma_mask)(struct device___233 *, u64);
	int is_phys;
};

struct bus_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___233 *, char *);
	ssize_t (*store)(struct bus_type___233 *, const char *, size_t);
};

struct device_attribute___233;

struct driver_attribute___233;

struct iommu_ops___2;

struct bus_type___233 {
	const char *name;
	const char *dev_name;
	struct device___233 *dev_root;
	struct bus_attribute___233 *bus_attrs;
	struct device_attribute___233 *dev_attrs;
	struct driver_attribute___233 *drv_attrs;
	const struct attribute_group___198 **bus_groups;
	const struct attribute_group___198 **dev_groups;
	const struct attribute_group___198 **drv_groups;
	int (*match)(struct device___233 *, struct device_driver___233 *);
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	int (*probe)(struct device___233 *);
	int (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*online)(struct device___233 *);
	int (*offline)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
	struct iommu_ops___2 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct device___233 *, struct device_attribute___233 *, char *);
	ssize_t (*store)(struct device___233 *, struct device_attribute___233 *, const char *, size_t);
};

struct driver_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___233 *, char *);
	ssize_t (*store)(struct device_driver___233 *, const char *, size_t);
};

struct device_driver___233 {
	const char *name;
	struct bus_type___233 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___233 *);
	int (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	const struct attribute_group___198 **groups;
	const struct dev_pm_ops___233 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___2;

struct iommu_ops___2 {
	int (*domain_init)(struct iommu_domain___2 *);
	void (*domain_destroy)(struct iommu_domain___2 *);
	int (*attach_dev)(struct iommu_domain___2 *, struct device___233 *);
	void (*detach_dev)(struct iommu_domain___2 *, struct device___233 *);
	int (*map)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___2 *, long unsigned int, size_t);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___2 *, dma_addr_t);
	int (*domain_has_cap)(struct iommu_domain___2 *, long unsigned int);
	int (*add_device)(struct device___233 *);
	void (*remove_device)(struct device___233 *);
	int (*device_group)(struct device___233 *, unsigned int *);
	int (*domain_get_attr)(struct iommu_domain___2 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___2 *, enum iommu_attr, void *);
	int (*domain_window_enable)(struct iommu_domain___2 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___2 *, u32);
	int (*domain_set_windows)(struct iommu_domain___2 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___2 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___233 {
	const char *name;
	const struct attribute_group___198 **groups;
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
};

struct class_attribute___233;

struct class___233 {
	const char *name;
	struct module *owner;
	struct class_attribute___233 *class_attrs;
	struct device_attribute___233 *dev_attrs;
	const struct attribute_group___198 **dev_groups;
	struct bin_attribute___200 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *);
	void (*class_release)(struct class___233 *);
	void (*dev_release)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
	struct subsys_private *p;
};

struct class_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct class___233 *, struct class_attribute___233 *, char *);
	ssize_t (*store)(struct class___233 *, struct class_attribute___233 *, const char *, size_t);
	const void * (*namespace)(struct class___233 *, const struct class_attribute___233 *);
};

struct device_rh___233 {
	struct dev_pm_info_rh___233 power;
};

struct pci_slot___27 {
	struct pci_bus___27 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___24 kobj;
};

struct pci_ops___27;

struct msi_chip___6;

struct pci_bus___27 {
	struct list_head node;
	struct pci_bus___27 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___28 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___27 *ops;
	struct msi_chip___6 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___233 *bridge;
	struct device___233 dev;
	struct bin_attribute___200 *legacy_io;
	struct bin_attribute___200 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___27;

struct pci_driver_rh___27;

struct pci_driver___27 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___28 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___28 *);
	int (*suspend)(struct pci_dev___28 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___28 *, pm_message_t);
	int (*resume_early)(struct pci_dev___28 *);
	int (*resume)(struct pci_dev___28 *);
	void (*shutdown)(struct pci_dev___28 *);
	int (*sriov_configure)(struct pci_dev___28 *, int);
	const struct pci_error_handlers___27 *err_handler;
	struct device_driver___233 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___27 *pci_driver_rh;
};

struct pci_ops___27 {
	int (*read)(struct pci_bus___27 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___27 *, unsigned int, int, int, u32);
};

struct msi_chip___6 {
	struct module *owner;
	struct device___233 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___6 *, struct pci_dev___28 *, struct msi_desc___6 *);
	void (*teardown_irq)(struct msi_chip___6 *, unsigned int);
	int (*check_device)(struct msi_chip___6 *, struct pci_dev___28 *, int, int);
};

struct pci_error_handlers___27 {
	pci_ers_result_t (*error_detected)(struct pci_dev___28 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___28 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___28 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___28 *);
	void (*resume)(struct pci_dev___28 *);
};

struct pci_driver_rh___27 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___28 *, bool);
};

typedef int (*iommu_fault_handler_t___3)(struct iommu_domain___2 *, struct device___233 *, long unsigned int, int, void *);

struct iommu_domain___2 {
	struct iommu_ops___2 *ops;
	void *priv;
	iommu_fault_handler_t___3 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
};

struct amd_iommu_device_info {
	int max_pasids;
	u32 flags;
};

struct irq_chip___159 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___159 *);
	void (*irq_shutdown)(struct irq_data___159 *);
	void (*irq_enable)(struct irq_data___159 *);
	void (*irq_disable)(struct irq_data___159 *);
	void (*irq_ack)(struct irq_data___159 *);
	void (*irq_mask)(struct irq_data___159 *);
	void (*irq_mask_ack)(struct irq_data___159 *);
	void (*irq_unmask)(struct irq_data___159 *);
	void (*irq_eoi)(struct irq_data___159 *);
	int (*irq_set_affinity)(struct irq_data___159 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___159 *);
	int (*irq_set_type)(struct irq_data___159 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___159 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___159 *);
	void (*irq_bus_sync_unlock)(struct irq_data___159 *);
	void (*irq_cpu_online)(struct irq_data___159 *);
	void (*irq_cpu_offline)(struct irq_data___159 *);
	void (*irq_suspend)(struct irq_data___159 *);
	void (*irq_resume)(struct irq_data___159 *);
	void (*irq_pm_shutdown)(struct irq_data___159 *);
	void (*irq_print_chip)(struct irq_data___159 *, struct seq_file___163 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___159 *, void *);
	long unsigned int flags;
};

struct irq_remap_table {
	spinlock_t lock;
	unsigned int min_index;
	u32 *table;
};

struct amd_iommu_fault {
	u64 address;
	u32 pasid;
	u16 device_id;
	u16 tag;
	u16 flags;
};

struct protection_domain {
	struct list_head list;
	struct list_head dev_list;
	spinlock_t lock;
	struct mutex___240 api_lock;
	u16 id;
	int mode;
	u64 *pt_root;
	int glx;
	u64 *gcr3_tbl;
	long unsigned int flags;
	bool updated;
	unsigned int dev_cnt;
	unsigned int dev_iommu[32];
	void *priv;
	struct iommu_domain___2 *iommu_domain;
};

struct iommu_dev_data {
	struct list_head list;
	struct list_head dev_data_list;
	struct iommu_dev_data *alias_data;
	struct protection_domain *domain;
	atomic_t bind;
	u16 devid;
	bool iommu_v2;
	bool passthrough;
	struct {
		bool enabled;
		int qdep;
	} ats;
	bool pri_tlp;
	u32 errata;
};

struct aperture_range {
	long unsigned int *bitmap;
	u64 *pte_pages[64];
	long unsigned int offset;
};

struct dma_ops_domain {
	struct list_head list;
	struct protection_domain domain;
	long unsigned int aperture_size;
	long unsigned int next_address;
	struct aperture_range *aperture[32];
	bool need_flush;
	u16 target_dev;
};

struct amd_iommu {
	struct list_head list;
	int index;
	spinlock_t lock;
	struct pci_dev___28 *dev;
	struct pci_dev___28 *root_pdev;
	u64 mmio_phys;
	u8 *mmio_base;
	u32 cap;
	u8 acpi_flags;
	u64 features;
	bool is_iommu_v2;
	u16 devid;
	u16 cap_ptr;
	u16 pci_seg;
	u16 first_device;
	u16 last_device;
	u64 exclusion_start;
	u64 exclusion_length;
	u8 *cmd_buf;
	u32 cmd_buf_size;
	u32 evt_buf_size;
	u8 *evt_buf;
	u8 *ppr_log;
	bool int_enabled;
	bool need_sync;
	struct dma_ops_domain *default_dom;
	struct device___233 *iommu_dev;
	u32 stored_addr_lo;
	u32 stored_addr_hi;
	u32 stored_l1[108];
	u32 stored_l2[131];
};

struct devid_map {
	struct list_head list;
	u8 id;
	u16 devid;
	bool cmd_line;
};

struct dev_table_entry {
	u64 data[4];
};

struct unity_map_entry {
	struct list_head list;
	u16 devid_start;
	u16 devid_end;
	u64 address_start;
	u64 address_end;
	int prot;
};

struct __iommu_counter {
	char *name;
	struct dentry___238 *dent;
	u64 value;
};

struct irq_remap_ops {
	int capability;
	int (*supported)();
	int (*prepare)();
	int (*enable)();
	void (*disable)();
	int (*reenable)(int);
	int (*enable_faulting)();
	int (*setup_ioapic_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	int (*set_affinity)(struct irq_data___159 *, const struct cpumask *, bool);
	int (*free_irq)(int);
	void (*compose_msi_msg)(struct pci_dev___28 *, unsigned int, unsigned int, struct msi_msg *, u8);
	int (*msi_alloc_irq)(struct pci_dev___28 *, int, int);
	int (*msi_setup_irq)(struct pci_dev___28 *, unsigned int, int, int);
	int (*setup_hpet_msi)(unsigned int, unsigned int);
	int (*irq_set_vcpu_affinity)(struct irq_data___159 *, void *);
};

struct iommu_cmd {
	u32 data[4];
};

union irte {
	u32 val;
	struct {
		u32 valid: 1;
		u32 no_fault: 1;
		u32 int_type: 3;
		u32 rq_eoi: 1;
		u32 dm: 1;
		u32 rsvd_1: 1;
		u32 destination: 8;
		u32 vector: 8;
		u32 rsvd_2: 8;
	} fields;
};

struct device___234;

struct dev_pm_ops___234 {
	int (*prepare)(struct device___234 *);
	void (*complete)(struct device___234 *);
	int (*suspend)(struct device___234 *);
	int (*resume)(struct device___234 *);
	int (*freeze)(struct device___234 *);
	int (*thaw)(struct device___234 *);
	int (*poweroff)(struct device___234 *);
	int (*restore)(struct device___234 *);
	int (*suspend_late)(struct device___234 *);
	int (*resume_early)(struct device___234 *);
	int (*freeze_late)(struct device___234 *);
	int (*thaw_early)(struct device___234 *);
	int (*poweroff_late)(struct device___234 *);
	int (*restore_early)(struct device___234 *);
	int (*suspend_noirq)(struct device___234 *);
	int (*resume_noirq)(struct device___234 *);
	int (*freeze_noirq)(struct device___234 *);
	int (*thaw_noirq)(struct device___234 *);
	int (*poweroff_noirq)(struct device___234 *);
	int (*restore_noirq)(struct device___234 *);
	int (*runtime_suspend)(struct device___234 *);
	int (*runtime_resume)(struct device___234 *);
	int (*runtime_idle)(struct device___234 *);
};

struct dma_map_ops___99;

struct dev_archdata___99 {
	struct dma_map_ops___99 *dma_ops;
	void *iommu;
};

struct acpi_device___35;

struct acpi_dev_node___41 {
	union {
		struct acpi_device___35 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___234;

struct bus_type___234;

struct device_driver___234;

struct dev_pm_domain___234;

struct class___234;

struct device_rh___234;

struct device___234 {
	struct device___234 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___234 *type;
	struct mutex___221 mutex;
	struct bus_type___234 *bus;
	struct device_driver___234 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___234 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___99 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___41 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___234 *class;
	const struct attribute_group___177 **groups;
	void (*release)(struct device___234 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___234 *device_rh;
};

struct dev_pm_info_rh___234 {
	void (*set_latency_tolerance)(struct device___234 *, s32);
};

struct dev_pm_domain___234 {
	struct dev_pm_ops___234 ops;
};

struct pci_bus___28;

struct pci_slot___28;

struct pci_driver___28;

struct pci_dev___29 {
	struct list_head bus_list;
	struct pci_bus___28 *bus;
	struct pci_bus___28 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___28 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___28 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___234 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___179 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___179 *res_attr[17];
	struct bin_attribute___179 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___23 *msi_kset;
	const struct attribute_group___177 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___29 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___7 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___29 *dev;
	struct msi_msg msg;
	struct kobject___23 kobj;
};

struct irq_data___160;

struct x86_io_apic_ops___160 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___160 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___160;

struct irq_data___160 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___160 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___7 *msi_desc;
	cpumask_var_t affinity;
};

struct dma_map_ops___99 {
	void * (*alloc)(struct device___234 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___234 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___234 *, struct vm_area_struct___227 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___234 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___234 *, struct page___218 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___234 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___234 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___234 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___234 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___234 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___234 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___234 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___234 *, dma_addr_t);
	int (*dma_supported)(struct device___234 *, u64);
	int (*set_dma_mask)(struct device___234 *, u64);
	int is_phys;
};

struct bus_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___234 *, char *);
	ssize_t (*store)(struct bus_type___234 *, const char *, size_t);
};

struct device_attribute___234;

struct driver_attribute___234;

struct iommu_ops___3;

struct bus_type___234 {
	const char *name;
	const char *dev_name;
	struct device___234 *dev_root;
	struct bus_attribute___234 *bus_attrs;
	struct device_attribute___234 *dev_attrs;
	struct driver_attribute___234 *drv_attrs;
	const struct attribute_group___177 **bus_groups;
	const struct attribute_group___177 **dev_groups;
	const struct attribute_group___177 **drv_groups;
	int (*match)(struct device___234 *, struct device_driver___234 *);
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	int (*probe)(struct device___234 *);
	int (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*online)(struct device___234 *);
	int (*offline)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
	struct iommu_ops___3 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct device___234 *, struct device_attribute___234 *, char *);
	ssize_t (*store)(struct device___234 *, struct device_attribute___234 *, const char *, size_t);
};

struct driver_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___234 *, char *);
	ssize_t (*store)(struct device_driver___234 *, const char *, size_t);
};

struct device_driver___234 {
	const char *name;
	struct bus_type___234 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___234 *);
	int (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	const struct attribute_group___177 **groups;
	const struct dev_pm_ops___234 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___3;

struct iommu_ops___3 {
	int (*domain_init)(struct iommu_domain___3 *);
	void (*domain_destroy)(struct iommu_domain___3 *);
	int (*attach_dev)(struct iommu_domain___3 *, struct device___234 *);
	void (*detach_dev)(struct iommu_domain___3 *, struct device___234 *);
	int (*map)(struct iommu_domain___3 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___3 *, long unsigned int, size_t);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___3 *, dma_addr_t);
	int (*domain_has_cap)(struct iommu_domain___3 *, long unsigned int);
	int (*add_device)(struct device___234 *);
	void (*remove_device)(struct device___234 *);
	int (*device_group)(struct device___234 *, unsigned int *);
	int (*domain_get_attr)(struct iommu_domain___3 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___3 *, enum iommu_attr, void *);
	int (*domain_window_enable)(struct iommu_domain___3 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___3 *, u32);
	int (*domain_set_windows)(struct iommu_domain___3 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___3 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___234 {
	const char *name;
	const struct attribute_group___177 **groups;
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
};

struct class_attribute___234;

struct class___234 {
	const char *name;
	struct module *owner;
	struct class_attribute___234 *class_attrs;
	struct device_attribute___234 *dev_attrs;
	const struct attribute_group___177 **dev_groups;
	struct bin_attribute___179 *dev_bin_attrs;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *);
	void (*class_release)(struct class___234 *);
	void (*dev_release)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
	struct subsys_private *p;
};

struct class_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct class___234 *, struct class_attribute___234 *, char *);
	ssize_t (*store)(struct class___234 *, struct class_attribute___234 *, const char *, size_t);
	const void * (*namespace)(struct class___234 *, const struct class_attribute___234 *);
};

struct acpi_scan_handler___35;

struct acpi_hotplug_context___35;

struct acpi_driver___35;

struct acpi_device___35 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___35 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___35 *handler;
	struct acpi_hotplug_context___35 *hp;
	struct acpi_driver___35 *driver;
	void *driver_data;
	struct device___234 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___221 physical_node_lock;
	void (*remove)(struct acpi_device___35 *);
};

struct device_rh___234 {
	struct dev_pm_info_rh___234 power;
};

struct pci_slot___28 {
	struct pci_bus___28 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___23 kobj;
};

struct pci_ops___28;

struct msi_chip___7;

struct pci_bus___28 {
	struct list_head node;
	struct pci_bus___28 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___29 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___28 *ops;
	struct msi_chip___7 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___234 *bridge;
	struct device___234 dev;
	struct bin_attribute___179 *legacy_io;
	struct bin_attribute___179 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___28;

struct pci_driver_rh___28;

struct pci_driver___28 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___29 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___29 *);
	int (*suspend)(struct pci_dev___29 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___29 *, pm_message_t);
	int (*resume_early)(struct pci_dev___29 *);
	int (*resume)(struct pci_dev___29 *);
	void (*shutdown)(struct pci_dev___29 *);
	int (*sriov_configure)(struct pci_dev___29 *, int);
	const struct pci_error_handlers___28 *err_handler;
	struct device_driver___234 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___28 *pci_driver_rh;
};

struct pci_ops___28 {
	int (*read)(struct pci_bus___28 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___28 *, unsigned int, int, int, u32);
};

struct msi_chip___7 {
	struct module *owner;
	struct device___234 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___7 *, struct pci_dev___29 *, struct msi_desc___7 *);
	void (*teardown_irq)(struct msi_chip___7 *, unsigned int);
	int (*check_device)(struct msi_chip___7 *, struct pci_dev___29 *, int, int);
};

struct pci_error_handlers___28 {
	pci_ers_result_t (*error_detected)(struct pci_dev___29 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___29 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___29 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___29 *);
	void (*resume)(struct pci_dev___29 *);
};

struct pci_driver_rh___28 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___29 *, bool);
};

struct acpi_hotplug_profile___35 {
	struct kobject___23 kobj;
	int (*scan_dependent)(struct acpi_device___35 *);
	void (*notify_online)(struct acpi_device___35 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___35 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___35 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___35 *);
	void (*bind)(struct device___234 *);
	void (*unbind)(struct device___234 *);
	struct acpi_hotplug_profile___35 hotplug;
};

struct acpi_hotplug_context___35 {
	struct acpi_device___35 *self;
	int (*notify)(struct acpi_device___35 *, u32);
	void (*uevent)(struct acpi_device___35 *, u32);
	void (*fixup)(struct acpi_device___35 *);
};

typedef int (*acpi_op_add___35)(struct acpi_device___35 *);

typedef int (*acpi_op_remove___35)(struct acpi_device___35 *);

typedef void (*acpi_op_notify___35)(struct acpi_device___35 *, u32);

struct acpi_device_ops___35 {
	acpi_op_add___35 add;
	acpi_op_remove___35 remove;
	acpi_op_notify___35 notify;
};

struct acpi_driver___35 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___35 ops;
	struct device_driver___234 drv;
	struct module *owner;
};

struct irq_chip___160 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___160 *);
	void (*irq_shutdown)(struct irq_data___160 *);
	void (*irq_enable)(struct irq_data___160 *);
	void (*irq_disable)(struct irq_data___160 *);
	void (*irq_ack)(struct irq_data___160 *);
	void (*irq_mask)(struct irq_data___160 *);
	void (*irq_mask_ack)(struct irq_data___160 *);
	void (*irq_unmask)(struct irq_data___160 *);
	void (*irq_eoi)(struct irq_data___160 *);
	int (*irq_set_affinity)(struct irq_data___160 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___160 *);
	int (*irq_set_type)(struct irq_data___160 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___160 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___160 *);
	void (*irq_bus_sync_unlock)(struct irq_data___160 *);
	void (*irq_cpu_online)(struct irq_data___160 *);
	void (*irq_cpu_offline)(struct irq_data___160 *);
	void (*irq_suspend)(struct irq_data___160 *);
	void (*irq_resume)(struct irq_data___160 *);
	void (*irq_pm_shutdown)(struct irq_data___160 *);
	void (*irq_print_chip)(struct irq_data___160 *, struct seq_file___5 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___160 *, void *);
	long unsigned int flags;
};

typedef int (*iommu_fault_handler_t___4)(struct iommu_domain___3 *, struct device___234 *, long unsigned int, int, void *);

struct iommu_domain___3 {
	struct iommu_ops___3 *ops;
	void *priv;
	iommu_fault_handler_t___4 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
};

struct protection_domain___2 {
	struct list_head list;
	struct list_head dev_list;
	spinlock_t lock;
	struct mutex___221 api_lock;
	u16 id;
	int mode;
	u64 *pt_root;
	int glx;
	u64 *gcr3_tbl;
	long unsigned int flags;
	bool updated;
	unsigned int dev_cnt;
	unsigned int dev_iommu[32];
	void *priv;
	struct iommu_domain___3 *iommu_domain;
};

struct dma_ops_domain___2 {
	struct list_head list;
	struct protection_domain___2 domain;
	long unsigned int aperture_size;
	long unsigned int next_address;
	struct aperture_range *aperture[32];
	bool need_flush;
	u16 target_dev;
};

struct amd_iommu___2 {
	struct list_head list;
	int index;
	spinlock_t lock;
	struct pci_dev___29 *dev;
	struct pci_dev___29 *root_pdev;
	u64 mmio_phys;
	u8 *mmio_base;
	u32 cap;
	u8 acpi_flags;
	u64 features;
	bool is_iommu_v2;
	u16 devid;
	u16 cap_ptr;
	u16 pci_seg;
	u16 first_device;
	u16 last_device;
	u64 exclusion_start;
	u64 exclusion_length;
	u8 *cmd_buf;
	u32 cmd_buf_size;
	u32 evt_buf_size;
	u8 *evt_buf;
	u8 *ppr_log;
	bool int_enabled;
	bool need_sync;
	struct dma_ops_domain___2 *default_dom;
	struct device___234 *iommu_dev;
	u32 stored_addr_lo;
	u32 stored_addr_hi;
	u32 stored_l1[108];
	u32 stored_l2[131];
};

struct ivhd_header {
	u8 type;
	u8 flags;
	u16 length;
	u16 devid;
	u16 cap_ptr;
	u64 mmio_phys;
	u16 pci_seg;
	u16 info;
	u32 reserved;
};

struct ivhd_entry {
	u8 type;
	u16 devid;
	u8 flags;
	u32 ext;
} __attribute__((packed));

struct ivmd_header {
	u8 type;
	u8 flags;
	u16 length;
	u16 devid;
	u16 aux;
	u64 resv;
	u64 range_start;
	u64 range_length;
};

enum iommu_init_state {
	IOMMU_START_STATE = 0,
	IOMMU_IVRS_DETECTED = 1,
	IOMMU_ACPI_FINISHED = 2,
	IOMMU_ENABLED = 3,
	IOMMU_PCI_INIT = 4,
	IOMMU_INTERRUPTS_EN = 5,
	IOMMU_DMA_OPS = 6,
	IOMMU_INITIALIZED = 7,
	IOMMU_NOT_FOUND = 8,
	IOMMU_INIT_ERROR = 9,
};

struct pci_sysdata___4 {
	int domain;
	int node;
	struct acpi_device___35 *companion;
	void *iommu;
};

struct acpi_table_dmar {
	struct acpi_table_header header;
	u8 width;
	u8 flags;
	u8 reserved[10];
};

struct acpi_dmar_header {
	u16 type;
	u16 length;
};

enum acpi_dmar_type {
	ACPI_DMAR_TYPE_HARDWARE_UNIT = 0,
	ACPI_DMAR_TYPE_RESERVED_MEMORY = 1,
	ACPI_DMAR_TYPE_ATSR = 2,
	ACPI_DMAR_HARDWARE_AFFINITY = 3,
	ACPI_DMAR_TYPE_ANDD = 4,
	ACPI_DMAR_TYPE_RESERVED = 5,
};

struct acpi_dmar_device_scope {
	u8 entry_type;
	u8 length;
	u16 reserved;
	u8 enumeration_id;
	u8 bus;
};

enum acpi_dmar_scope_type {
	ACPI_DMAR_SCOPE_TYPE_NOT_USED = 0,
	ACPI_DMAR_SCOPE_TYPE_ENDPOINT = 1,
	ACPI_DMAR_SCOPE_TYPE_BRIDGE = 2,
	ACPI_DMAR_SCOPE_TYPE_IOAPIC = 3,
	ACPI_DMAR_SCOPE_TYPE_HPET = 4,
	ACPI_DMAR_SCOPE_TYPE_ACPI = 5,
	ACPI_DMAR_SCOPE_TYPE_RESERVED = 6,
};

struct acpi_dmar_pci_path {
	u8 device;
	u8 function;
};

struct acpi_dmar_hardware_unit {
	struct acpi_dmar_header header;
	u8 flags;
	u8 reserved;
	u16 segment;
	u64 address;
};

struct acpi_dmar_reserved_memory {
	struct acpi_dmar_header header;
	u16 reserved;
	u16 segment;
	u64 base_address;
	u64 end_address;
};

struct acpi_dmar_atsr {
	struct acpi_dmar_header header;
	u8 flags;
	u8 reserved;
	u16 segment;
};

struct acpi_dmar_rhsa {
	struct acpi_dmar_header header;
	u32 reserved;
	u64 base_address;
	u32 proximity_domain;
} __attribute__((packed));

struct acpi_dmar_andd {
	struct acpi_dmar_header header;
	u8 reserved[3];
	u8 device_number;
	u8 object_name[0];
};

struct dmar_dev_scope {
	struct device___234 *dev;
	u8 bus;
	u8 devfn;
};

struct intel_iommu___2;

struct dmar_drhd_unit {
	struct list_head list;
	struct acpi_dmar_header *hdr;
	u64 reg_base_addr;
	struct dmar_dev_scope *devices;
	int devices_cnt;
	u16 segment;
	u8 ignored: 1;
	u8 include_all: 1;
	struct intel_iommu___2 *iommu;
};

struct dmar_domain;

struct root_entry;

struct iommu_flush {
	void (*flush_context)(struct intel_iommu___2 *, u16, u16, u8, u64);
	void (*flush_iotlb)(struct intel_iommu___2 *, u16, u64, unsigned int, u64);
};

struct q_inval;

struct ir_table;

struct intel_iommu___2 {
	void *reg;
	u64 reg_phys;
	u64 reg_size;
	u64 cap;
	u64 ecap;
	u32 gcmd;
	raw_spinlock_t register_lock;
	int seq_id;
	int agaw;
	int msagaw;
	unsigned int irq;
	u16 segment;
	unsigned char name[13];
	long unsigned int *domain_ids;
	struct dmar_domain **domains;
	spinlock_t lock;
	struct root_entry *root_entry;
	struct iommu_flush flush;
	struct q_inval *qi;
	u32 *iommu_state;
	struct ir_table *ir_table;
	struct device___234 *iommu_dev;
	int node;
};

struct dmar_pci_path {
	u8 bus;
	u8 device;
	u8 function;
};

struct dmar_pci_notify_info {
	struct pci_dev___29 *dev;
	long unsigned int event;
	int bus;
	u16 seg;
	u16 level;
	struct dmar_pci_path path[0];
};

struct irte___2 {
	union {
		struct {
			__u64 present: 1;
			__u64 fpd: 1;
			__u64 __res0: 6;
			__u64 avail: 4;
			__u64 __res1: 3;
			__u64 pst: 1;
			__u64 vector: 8;
			__u64 __res2: 40;
		};
		struct {
			__u64 r_present: 1;
			__u64 r_fpd: 1;
			__u64 dst_mode: 1;
			__u64 redir_hint: 1;
			__u64 trigger_mode: 1;
			__u64 dlvry_mode: 3;
			__u64 r_avail: 4;
			__u64 r_res0: 4;
			__u64 r_vector: 8;
			__u64 r_res1: 8;
			__u64 dest_id: 32;
		};
		struct {
			__u64 p_present: 1;
			__u64 p_fpd: 1;
			__u64 p_res0: 6;
			__u64 p_avail: 4;
			__u64 p_res1: 2;
			__u64 p_urgent: 1;
			__u64 p_pst: 1;
			__u64 p_vector: 8;
			__u64 p_res2: 14;
			__u64 pda_l: 26;
		};
		__u64 low;
	};
	union {
		struct {
			__u64 sid: 16;
			__u64 sq: 2;
			__u64 svt: 2;
			__u64 __res3: 44;
		};
		struct {
			__u64 p_sid: 16;
			__u64 p_sq: 2;
			__u64 p_svt: 2;
			__u64 p_res3: 12;
			__u64 pda_h: 32;
		};
		__u64 high;
	};
};

enum {
	QI_FREE = 0,
	QI_IN_USE = 1,
	QI_DONE = 2,
	QI_ABORT = 3,
};

struct qi_desc {
	u64 low;
	u64 high;
};

struct q_inval {
	raw_spinlock_t q_lock;
	struct qi_desc *desc;
	int *desc_status;
	int free_head;
	int free_tail;
	int free_cnt;
};

struct ir_table {
	struct irte___2 *base;
	long unsigned int *bitmap;
};

enum faulttype {
	DMA_REMAP = 0,
	INTR_REMAP = 1,
	UNKNOWN = 2,
};

struct iova {
	struct rb_node node;
	long unsigned int pfn_hi;
	long unsigned int pfn_lo;
};

struct iova_domain {
	spinlock_t iova_rbtree_lock;
	struct rb_root rbroot;
	struct rb_node *cached32_node;
	long unsigned int dma_32bit_pfn;
};

struct dma_map_ops___100;

struct dev_archdata___100 {
	struct dma_map_ops___100 *dma_ops;
	void *iommu;
};

struct acpi_device___36;

struct acpi_dev_node___42 {
	union {
		struct acpi_device___36 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

struct device_type___235;

struct bus_type___235;

struct device_driver___235;

struct dev_pm_domain___235;

struct class___235;

struct device_rh___235;

struct device___235 {
	struct device___235 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___235 *type;
	struct mutex___230 mutex;
	struct bus_type___235 *bus;
	struct device_driver___235 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___235 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___100 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___42 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___235 *class;
	const struct attribute_group___187 **groups;
	void (*release)(struct device___235 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___235 *device_rh;
};

struct pci_bus___29;

struct pci_slot___29;

struct pci_driver___29;

struct pci_dev___30 {
	struct list_head bus_list;
	struct pci_bus___29 *bus;
	struct pci_bus___29 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___29 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___29 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___235 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___189 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___189 *res_attr[17];
	struct bin_attribute___189 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___24 *msi_kset;
	const struct attribute_group___187 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___30 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___8 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___30 *dev;
	struct msi_msg msg;
	struct kobject___24 kobj;
};

struct irq_data___161;

struct x86_io_apic_ops___161 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___161 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___161;

struct irq_data___161 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___161 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___8 *msi_desc;
	cpumask_var_t affinity;
};

struct dev_pm_ops___235 {
	int (*prepare)(struct device___235 *);
	void (*complete)(struct device___235 *);
	int (*suspend)(struct device___235 *);
	int (*resume)(struct device___235 *);
	int (*freeze)(struct device___235 *);
	int (*thaw)(struct device___235 *);
	int (*poweroff)(struct device___235 *);
	int (*restore)(struct device___235 *);
	int (*suspend_late)(struct device___235 *);
	int (*resume_early)(struct device___235 *);
	int (*freeze_late)(struct device___235 *);
	int (*thaw_early)(struct device___235 *);
	int (*poweroff_late)(struct device___235 *);
	int (*restore_early)(struct device___235 *);
	int (*suspend_noirq)(struct device___235 *);
	int (*resume_noirq)(struct device___235 *);
	int (*freeze_noirq)(struct device___235 *);
	int (*thaw_noirq)(struct device___235 *);
	int (*poweroff_noirq)(struct device___235 *);
	int (*restore_noirq)(struct device___235 *);
	int (*runtime_suspend)(struct device___235 *);
	int (*runtime_resume)(struct device___235 *);
	int (*runtime_idle)(struct device___235 *);
};

struct dev_pm_info_rh___235 {
	void (*set_latency_tolerance)(struct device___235 *, s32);
};

struct dev_pm_domain___235 {
	struct dev_pm_ops___235 ops;
};

struct irq_chip___161 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___161 *);
	void (*irq_shutdown)(struct irq_data___161 *);
	void (*irq_enable)(struct irq_data___161 *);
	void (*irq_disable)(struct irq_data___161 *);
	void (*irq_ack)(struct irq_data___161 *);
	void (*irq_mask)(struct irq_data___161 *);
	void (*irq_mask_ack)(struct irq_data___161 *);
	void (*irq_unmask)(struct irq_data___161 *);
	void (*irq_eoi)(struct irq_data___161 *);
	int (*irq_set_affinity)(struct irq_data___161 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___161 *);
	int (*irq_set_type)(struct irq_data___161 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___161 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___161 *);
	void (*irq_bus_sync_unlock)(struct irq_data___161 *);
	void (*irq_cpu_online)(struct irq_data___161 *);
	void (*irq_cpu_offline)(struct irq_data___161 *);
	void (*irq_suspend)(struct irq_data___161 *);
	void (*irq_resume)(struct irq_data___161 *);
	void (*irq_pm_shutdown)(struct irq_data___161 *);
	void (*irq_print_chip)(struct irq_data___161 *, struct seq_file___154 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___161 *, void *);
	long unsigned int flags;
};

struct intel_iommu___3;

struct iommu_flush___2 {
	void (*flush_context)(struct intel_iommu___3 *, u16, u16, u8, u64);
	void (*flush_iotlb)(struct intel_iommu___3 *, u16, u64, unsigned int, u64);
};

struct dmar_domain___2;

struct root_entry___2;

struct intel_iommu___3 {
	void *reg;
	u64 reg_phys;
	u64 reg_size;
	u64 cap;
	u64 ecap;
	u32 gcmd;
	raw_spinlock_t register_lock;
	int seq_id;
	int agaw;
	int msagaw;
	unsigned int irq;
	u16 segment;
	unsigned char name[13];
	long unsigned int *domain_ids;
	struct dmar_domain___2 **domains;
	spinlock_t lock;
	struct root_entry___2 *root_entry;
	struct iommu_flush___2 flush;
	struct q_inval *qi;
	u32 *iommu_state;
	struct ir_table *ir_table;
	struct device___235 *iommu_dev;
	int node;
};

struct dma_map_ops___100 {
	void * (*alloc)(struct device___235 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___235 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___235 *, struct vm_area_struct___236 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___235 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___235 *, struct page___227 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___235 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___235 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___235 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___235 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___235 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___235 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___235 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___235 *, dma_addr_t);
	int (*dma_supported)(struct device___235 *, u64);
	int (*set_dma_mask)(struct device___235 *, u64);
	int is_phys;
};

struct bus_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___235 *, char *);
	ssize_t (*store)(struct bus_type___235 *, const char *, size_t);
};

struct device_attribute___235;

struct driver_attribute___235;

struct iommu_ops___4;

struct bus_type___235 {
	const char *name;
	const char *dev_name;
	struct device___235 *dev_root;
	struct bus_attribute___235 *bus_attrs;
	struct device_attribute___235 *dev_attrs;
	struct driver_attribute___235 *drv_attrs;
	const struct attribute_group___187 **bus_groups;
	const struct attribute_group___187 **dev_groups;
	const struct attribute_group___187 **drv_groups;
	int (*match)(struct device___235 *, struct device_driver___235 *);
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	int (*probe)(struct device___235 *);
	int (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*online)(struct device___235 *);
	int (*offline)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
	struct iommu_ops___4 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct device___235 *, struct device_attribute___235 *, char *);
	ssize_t (*store)(struct device___235 *, struct device_attribute___235 *, const char *, size_t);
};

struct driver_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___235 *, char *);
	ssize_t (*store)(struct device_driver___235 *, const char *, size_t);
};

struct device_driver___235 {
	const char *name;
	struct bus_type___235 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___235 *);
	int (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	const struct attribute_group___187 **groups;
	const struct dev_pm_ops___235 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___4;

struct iommu_ops___4 {
	int (*domain_init)(struct iommu_domain___4 *);
	void (*domain_destroy)(struct iommu_domain___4 *);
	int (*attach_dev)(struct iommu_domain___4 *, struct device___235 *);
	void (*detach_dev)(struct iommu_domain___4 *, struct device___235 *);
	int (*map)(struct iommu_domain___4 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___4 *, long unsigned int, size_t);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___4 *, dma_addr_t);
	int (*domain_has_cap)(struct iommu_domain___4 *, long unsigned int);
	int (*add_device)(struct device___235 *);
	void (*remove_device)(struct device___235 *);
	int (*device_group)(struct device___235 *, unsigned int *);
	int (*domain_get_attr)(struct iommu_domain___4 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___4 *, enum iommu_attr, void *);
	int (*domain_window_enable)(struct iommu_domain___4 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___4 *, u32);
	int (*domain_set_windows)(struct iommu_domain___4 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___4 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___235 {
	const char *name;
	const struct attribute_group___187 **groups;
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
};

struct class_attribute___235;

struct class___235 {
	const char *name;
	struct module *owner;
	struct class_attribute___235 *class_attrs;
	struct device_attribute___235 *dev_attrs;
	const struct attribute_group___187 **dev_groups;
	struct bin_attribute___189 *dev_bin_attrs;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *);
	void (*class_release)(struct class___235 *);
	void (*dev_release)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
	struct subsys_private *p;
};

struct class_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct class___235 *, struct class_attribute___235 *, char *);
	ssize_t (*store)(struct class___235 *, struct class_attribute___235 *, const char *, size_t);
	const void * (*namespace)(struct class___235 *, const struct class_attribute___235 *);
};

struct acpi_scan_handler___36;

struct acpi_hotplug_context___36;

struct acpi_driver___36;

struct acpi_device___36 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___36 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___36 *handler;
	struct acpi_hotplug_context___36 *hp;
	struct acpi_driver___36 *driver;
	void *driver_data;
	struct device___235 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___230 physical_node_lock;
	void (*remove)(struct acpi_device___36 *);
};

struct device_rh___235 {
	struct dev_pm_info_rh___235 power;
};

struct pci_slot___29 {
	struct pci_bus___29 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___24 kobj;
};

struct pci_ops___29;

struct msi_chip___8;

struct pci_bus___29 {
	struct list_head node;
	struct pci_bus___29 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___30 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___29 *ops;
	struct msi_chip___8 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___235 *bridge;
	struct device___235 dev;
	struct bin_attribute___189 *legacy_io;
	struct bin_attribute___189 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct pci_error_handlers___29;

struct pci_driver_rh___29;

struct pci_driver___29 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___30 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___30 *);
	int (*suspend)(struct pci_dev___30 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___30 *, pm_message_t);
	int (*resume_early)(struct pci_dev___30 *);
	int (*resume)(struct pci_dev___30 *);
	void (*shutdown)(struct pci_dev___30 *);
	int (*sriov_configure)(struct pci_dev___30 *, int);
	const struct pci_error_handlers___29 *err_handler;
	struct device_driver___235 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___29 *pci_driver_rh;
};

struct pci_ops___29 {
	int (*read)(struct pci_bus___29 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___29 *, unsigned int, int, int, u32);
};

struct msi_chip___8 {
	struct module *owner;
	struct device___235 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___8 *, struct pci_dev___30 *, struct msi_desc___8 *);
	void (*teardown_irq)(struct msi_chip___8 *, unsigned int);
	int (*check_device)(struct msi_chip___8 *, struct pci_dev___30 *, int, int);
};

struct pci_error_handlers___29 {
	pci_ers_result_t (*error_detected)(struct pci_dev___30 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___30 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___30 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___30 *);
	void (*resume)(struct pci_dev___30 *);
};

struct pci_driver_rh___29 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___30 *, bool);
};

struct pci_sysdata___5 {
	int domain;
	int node;
	struct acpi_device___36 *companion;
	void *iommu;
};

struct pci_fixup___2 {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___30 *);
};

struct acpi_hotplug_profile___36 {
	struct kobject___24 kobj;
	int (*scan_dependent)(struct acpi_device___36 *);
	void (*notify_online)(struct acpi_device___36 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___36 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___36 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___36 *);
	void (*bind)(struct device___235 *);
	void (*unbind)(struct device___235 *);
	struct acpi_hotplug_profile___36 hotplug;
};

struct acpi_hotplug_context___36 {
	struct acpi_device___36 *self;
	int (*notify)(struct acpi_device___36 *, u32);
	void (*uevent)(struct acpi_device___36 *, u32);
	void (*fixup)(struct acpi_device___36 *);
};

typedef int (*acpi_op_add___36)(struct acpi_device___36 *);

typedef int (*acpi_op_remove___36)(struct acpi_device___36 *);

typedef void (*acpi_op_notify___36)(struct acpi_device___36 *, u32);

struct acpi_device_ops___36 {
	acpi_op_add___36 add;
	acpi_op_remove___36 remove;
	acpi_op_notify___36 notify;
};

struct acpi_driver___36 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___36 ops;
	struct device_driver___235 drv;
	struct module *owner;
};

struct acpi_device_physical_node___3 {
	unsigned int node_id;
	struct list_head node;
	struct device___235 *dev;
	bool put_online: 1;
};

struct dmar_dev_scope___2 {
	struct device___235 *dev;
	u8 bus;
	u8 devfn;
};

struct dmar_drhd_unit___2 {
	struct list_head list;
	struct acpi_dmar_header *hdr;
	u64 reg_base_addr;
	struct dmar_dev_scope___2 *devices;
	int devices_cnt;
	u16 segment;
	u8 ignored: 1;
	u8 include_all: 1;
	struct intel_iommu___3 *iommu;
};

struct dmar_pci_notify_info___2 {
	struct pci_dev___30 *dev;
	long unsigned int event;
	int bus;
	u16 seg;
	u16 level;
	struct dmar_pci_path path[0];
};

typedef int (*iommu_fault_handler_t___5)(struct iommu_domain___4 *, struct device___235 *, long unsigned int, int, void *);

struct iommu_domain___4 {
	struct iommu_ops___4 *ops;
	void *priv;
	iommu_fault_handler_t___5 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
};

enum {
	SR_DMAR_FECTL_REG = 0,
	SR_DMAR_FEDATA_REG = 1,
	SR_DMAR_FEADDR_REG = 2,
	SR_DMAR_FEUADDR_REG = 3,
	MAX_SR_DMAR_REGS = 4,
};

struct dma_pte;

struct dmar_domain___2 {
	int id;
	int nid;
	long unsigned int iommu_bmp[2];
	struct list_head devices;
	struct iova_domain iovad;
	struct dma_pte *pgd;
	int gaw;
	int agaw;
	int flags;
	int iommu_coherency;
	int iommu_snooping;
	int iommu_count;
	int iommu_superpage;
	spinlock_t iommu_lock;
	u64 max_addr;
};

struct root_entry___2 {
	u64 val;
	u64 rsvd1;
};

struct context_entry {
	u64 lo;
	u64 hi;
};

struct dma_pte {
	u64 val;
};

struct device_domain_info {
	struct list_head link;
	struct list_head global;
	u8 bus;
	u8 devfn;
	struct device___235 *dev;
	struct intel_iommu___3 *iommu;
	struct dmar_domain___2 *domain;
};

struct dmar_rmrr_unit {
	struct list_head list;
	struct acpi_dmar_header *hdr;
	u64 base_address;
	u64 end_address;
	struct dmar_dev_scope___2 *devices;
	int devices_cnt;
};

struct dmar_atsr_unit {
	struct list_head list;
	struct acpi_dmar_header *hdr;
	struct dmar_dev_scope___2 *devices;
	int devices_cnt;
	u8 include_all: 1;
};

struct deferred_flush_tables {
	int next;
	struct iova *iova[250];
	struct dmar_domain___2 *domain[250];
	struct page___227 *freelist[250];
};

struct domain_context_mapping_data {
	struct dmar_domain___2 *domain;
	struct intel_iommu___3 *iommu;
	int translation;
};

struct dma_map_ops___101;

struct dev_archdata___101 {
	struct dma_map_ops___101 *dma_ops;
	void *iommu;
};

struct acpi_device___37;

struct acpi_dev_node___43 {
	union {
		struct acpi_device___37 *companion;
		struct {
			void *handle;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
};

struct device_type___236;

struct bus_type___236;

struct device_driver___236;

struct dev_pm_domain___236;

struct class___236;

struct device_rh___236;

struct device___236 {
	struct device___236 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___236 *type;
	struct mutex___194 mutex;
	struct bus_type___236 *bus;
	struct device_driver___236 *driver;
	void *platform_data;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___236 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___101 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___236 *class;
	const struct attribute_group___149 **groups;
	void (*release)(struct device___236 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___236 *device_rh;
};

struct pci_bus___30;

struct pci_slot___30;

struct pci_driver___30;

struct pci_dev___31 {
	struct list_head bus_list;
	struct pci_bus___30 *bus;
	struct pci_bus___30 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___30 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	struct pci_driver___30 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_interrupt: 1;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	pci_channel_state_t error_state;
	struct device___236 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_added: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int irq_managed: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___151 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___151 *res_attr[17];
	struct bin_attribute___151 *res_attr_wc[17];
	struct list_head msi_list;
	struct kset___20 *msi_kset;
	const struct attribute_group___149 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___31 *physfn;
	};
	struct pci_ats *ats;
	phys_addr_t rom;
	size_t romlen;
	struct pci_dev_rh *pci_dev_rh;
};

struct msi_desc___9 {
	struct {
		__u8 is_msix: 1;
		__u8 multiple: 3;
		__u8 maskbit: 1;
		__u8 is_64: 1;
		__u8 pos;
		__u16 entry_nr;
		unsigned int default_irq;
	} msi_attrib;
	u32 masked;
	unsigned int irq;
	unsigned int nvec_used;
	__u8 multi_cap: 3;
	struct list_head list;
	union {
		void *mask_base;
		u8 mask_pos;
	};
	struct pci_dev___31 *dev;
	struct msi_msg msg;
	struct kobject___20 kobj;
};

struct irq_data___162;

struct x86_io_apic_ops___162 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___162 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___162;

struct irq_data___162 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___162 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc___9 *msi_desc;
	cpumask_var_t affinity;
};

struct dev_pm_ops___236 {
	int (*prepare)(struct device___236 *);
	void (*complete)(struct device___236 *);
	int (*suspend)(struct device___236 *);
	int (*resume)(struct device___236 *);
	int (*freeze)(struct device___236 *);
	int (*thaw)(struct device___236 *);
	int (*poweroff)(struct device___236 *);
	int (*restore)(struct device___236 *);
	int (*suspend_late)(struct device___236 *);
	int (*resume_early)(struct device___236 *);
	int (*freeze_late)(struct device___236 *);
	int (*thaw_early)(struct device___236 *);
	int (*poweroff_late)(struct device___236 *);
	int (*restore_early)(struct device___236 *);
	int (*suspend_noirq)(struct device___236 *);
	int (*resume_noirq)(struct device___236 *);
	int (*freeze_noirq)(struct device___236 *);
	int (*thaw_noirq)(struct device___236 *);
	int (*poweroff_noirq)(struct device___236 *);
	int (*restore_noirq)(struct device___236 *);
	int (*runtime_suspend)(struct device___236 *);
	int (*runtime_resume)(struct device___236 *);
	int (*runtime_idle)(struct device___236 *);
};

struct dev_pm_info_rh___236 {
	void (*set_latency_tolerance)(struct device___236 *, s32);
};

struct dev_pm_domain___236 {
	struct dev_pm_ops___236 ops;
};

struct irq_chip___162 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___162 *);
	void (*irq_shutdown)(struct irq_data___162 *);
	void (*irq_enable)(struct irq_data___162 *);
	void (*irq_disable)(struct irq_data___162 *);
	void (*irq_ack)(struct irq_data___162 *);
	void (*irq_mask)(struct irq_data___162 *);
	void (*irq_mask_ack)(struct irq_data___162 *);
	void (*irq_unmask)(struct irq_data___162 *);
	void (*irq_eoi)(struct irq_data___162 *);
	int (*irq_set_affinity)(struct irq_data___162 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___162 *);
	int (*irq_set_type)(struct irq_data___162 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___162 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___162 *);
	void (*irq_bus_sync_unlock)(struct irq_data___162 *);
	void (*irq_cpu_online)(struct irq_data___162 *);
	void (*irq_cpu_offline)(struct irq_data___162 *);
	void (*irq_suspend)(struct irq_data___162 *);
	void (*irq_resume)(struct irq_data___162 *);
	void (*irq_pm_shutdown)(struct irq_data___162 *);
	void (*irq_print_chip)(struct irq_data___162 *, struct seq_file___5 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___162 *, void *);
	long unsigned int flags;
};

struct iommu_flush___3 {
	void (*flush_context)(struct intel_iommu *, u16, u16, u8, u64);
	void (*flush_iotlb)(struct intel_iommu *, u16, u64, unsigned int, u64);
};

struct intel_iommu {
	void *reg;
	u64 reg_phys;
	u64 reg_size;
	u64 cap;
	u64 ecap;
	u32 gcmd;
	raw_spinlock_t register_lock;
	int seq_id;
	int agaw;
	int msagaw;
	unsigned int irq;
	u16 segment;
	unsigned char name[13];
	long unsigned int *domain_ids;
	struct dmar_domain **domains;
	spinlock_t lock;
	struct root_entry *root_entry;
	struct iommu_flush___3 flush;
	struct q_inval *qi;
	u32 *iommu_state;
	struct ir_table *ir_table;
	struct device___236 *iommu_dev;
	int node;
};

struct dma_map_ops___101 {
	void * (*alloc)(struct device___236 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___236 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___236 *, struct vm_area_struct___199 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___236 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___236 *, struct page___190 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___236 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___236 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___236 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___236 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___236 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___236 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___236 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___236 *, dma_addr_t);
	int (*dma_supported)(struct device___236 *, u64);
	int (*set_dma_mask)(struct device___236 *, u64);
	int is_phys;
};

struct bus_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___236 *, char *);
	ssize_t (*store)(struct bus_type___236 *, const char *, size_t);
};

struct device_attribute___236;

struct driver_attribute___236;

struct bus_type___236 {
	const char *name;
	const char *dev_name;
	struct device___236 *dev_root;
	struct bus_attribute___236 *bus_attrs;
	struct device_attribute___236 *dev_attrs;
	struct driver_attribute___236 *drv_attrs;
	const struct attribute_group___149 **bus_groups;
	const struct attribute_group___149 **dev_groups;
	const struct attribute_group___149 **drv_groups;
	int (*match)(struct device___236 *, struct device_driver___236 *);
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	int (*probe)(struct device___236 *);
	int (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*online)(struct device___236 *);
	int (*offline)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct device___236 *, struct device_attribute___236 *, char *);
	ssize_t (*store)(struct device___236 *, struct device_attribute___236 *, const char *, size_t);
};

struct driver_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___236 *, char *);
	ssize_t (*store)(struct device_driver___236 *, const char *, size_t);
};

struct device_driver___236 {
	const char *name;
	struct bus_type___236 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___236 *);
	int (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	const struct attribute_group___149 **groups;
	const struct dev_pm_ops___236 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___236 {
	const char *name;
	const struct attribute_group___149 **groups;
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
};

struct class_attribute___236;

struct class___236 {
	const char *name;
	struct module *owner;
	struct class_attribute___236 *class_attrs;
	struct device_attribute___236 *dev_attrs;
	const struct attribute_group___149 **dev_groups;
	struct bin_attribute___151 *dev_bin_attrs;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *);
	void (*class_release)(struct class___236 *);
	void (*dev_release)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
	struct subsys_private *p;
};

struct class_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct class___236 *, struct class_attribute___236 *, char *);
	ssize_t (*store)(struct class___236 *, struct class_attribute___236 *, const char *, size_t);
	const void * (*namespace)(struct class___236 *, const struct class_attribute___236 *);
};

struct acpi_scan_handler___37;

struct acpi_hotplug_context___37;

struct acpi_driver___37;

struct acpi_device___37 {
	int device_type;
	acpi_handle handle;
	struct acpi_device___37 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_scan_handler___37 *handler;
	struct acpi_hotplug_context___37 *hp;
	struct acpi_driver___37 *driver;
	void *driver_data;
	struct device___236 dev;
	unsigned int physical_node_count;
	struct list_head physical_node_list;
	struct mutex___194 physical_node_lock;
	void (*remove)(struct acpi_device___37 *);
};

struct device_rh___236 {
	struct dev_pm_info_rh___236 power;
};

struct acpi_hotplug_profile___37 {
	struct kobject___20 kobj;
	int (*scan_dependent)(struct acpi_device___37 *);
	void (*notify_online)(struct acpi_device___37 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_scan_handler___37 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	int (*attach)(struct acpi_device___37 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___37 *);
	void (*bind)(struct device___236 *);
	void (*unbind)(struct device___236 *);
	struct acpi_hotplug_profile___37 hotplug;
};

struct acpi_hotplug_context___37 {
	struct acpi_device___37 *self;
	int (*notify)(struct acpi_device___37 *, u32);
	void (*uevent)(struct acpi_device___37 *, u32);
	void (*fixup)(struct acpi_device___37 *);
};

typedef int (*acpi_op_add___37)(struct acpi_device___37 *);

typedef int (*acpi_op_remove___37)(struct acpi_device___37 *);

typedef void (*acpi_op_notify___37)(struct acpi_device___37 *, u32);

struct acpi_device_ops___37 {
	acpi_op_add___37 add;
	acpi_op_remove___37 remove;
	acpi_op_notify___37 notify;
};

struct acpi_driver___37 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___37 ops;
	struct device_driver___236 drv;
	struct module *owner;
};

struct pci_ops___30;

struct msi_chip___9;

struct pci_bus___30 {
	struct list_head node;
	struct pci_bus___30 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___31 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___30 *ops;
	struct msi_chip___9 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___236 *bridge;
	struct device___236 dev;
	struct bin_attribute___151 *legacy_io;
	struct bin_attribute___151 *legacy_mem;
	unsigned int is_added: 1;
	struct pci_bus_rh *pci_bus_rh;
};

struct msi_chip___9 {
	struct module *owner;
	struct device___236 *dev;
	struct device_node *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_chip___9 *, struct pci_dev___31 *, struct msi_desc___9 *);
	void (*teardown_irq)(struct msi_chip___9 *, unsigned int);
	int (*check_device)(struct msi_chip___9 *, struct pci_dev___31 *, int, int);
};

struct dmar_dev_scope___3 {
	struct device___236 *dev;
	u8 bus;
	u8 devfn;
};

struct dmar_drhd_unit___3 {
	struct list_head list;
	struct acpi_dmar_header *hdr;
	u64 reg_base_addr;
	struct dmar_dev_scope___3 *devices;
	int devices_cnt;
	u16 segment;
	u8 ignored: 1;
	u8 include_all: 1;
	struct intel_iommu *iommu;
};

struct pci_slot___30 {
	struct pci_bus___30 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___20 kobj;
};

struct pci_error_handlers___30;

struct pci_driver_rh___30;

struct pci_driver___30 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___31 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___31 *);
	int (*suspend)(struct pci_dev___31 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___31 *, pm_message_t);
	int (*resume_early)(struct pci_dev___31 *);
	int (*resume)(struct pci_dev___31 *);
	void (*shutdown)(struct pci_dev___31 *);
	int (*sriov_configure)(struct pci_dev___31 *, int);
	const struct pci_error_handlers___30 *err_handler;
	struct device_driver___236 driver;
	struct pci_dynids dynids;
	struct pci_driver_rh___30 *pci_driver_rh;
};

struct pci_ops___30 {
	int (*read)(struct pci_bus___30 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___30 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___30 {
	pci_ers_result_t (*error_detected)(struct pci_dev___31 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___31 *);
	pci_ers_result_t (*link_reset)(struct pci_dev___31 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___31 *);
	void (*resume)(struct pci_dev___31 *);
};

struct pci_driver_rh___30 {
	unsigned int size;
	void (*reset_notify)(struct pci_dev___31 *, bool);
};

enum irq_remap_cap {
	IRQ_POSTING_CAP = 0,
};

struct vcpu_data {
	u64 pi_desc_addr;
	u32 vector;
};

struct irq_remap_ops___2 {
	int capability;
	int (*supported)();
	int (*prepare)();
	int (*enable)();
	void (*disable)();
	int (*reenable)(int);
	int (*enable_faulting)();
	int (*setup_ioapic_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	int (*set_affinity)(struct irq_data___162 *, const struct cpumask *, bool);
	int (*free_irq)(int);
	void (*compose_msi_msg)(struct pci_dev___31 *, unsigned int, unsigned int, struct msi_msg *, u8);
	int (*msi_alloc_irq)(struct pci_dev___31 *, int, int);
	int (*msi_setup_irq)(struct pci_dev___31 *, unsigned int, int, int);
	int (*setup_hpet_msi)(unsigned int, unsigned int);
	int (*irq_set_vcpu_affinity)(struct irq_data___162 *, void *);
};

struct ioapic_scope {
	struct intel_iommu *iommu;
	unsigned int id;
	unsigned int bus;
	unsigned int devfn;
};

struct hpet_scope {
	struct intel_iommu *iommu;
	u8 id;
	unsigned int bus;
	unsigned int devfn;
};

struct set_msi_sid_data {
	struct pci_dev___31 *pdev;
	u16 alias;
};

struct thread_info___110 {
	struct task_struct___77 *task;
	struct exec_domain___65 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

enum hw_event_mc_err_type {
	HW_EVENT_ERR_CORRECTED = 0,
	HW_EVENT_ERR_UNCORRECTED = 1,
	HW_EVENT_ERR_FATAL = 2,
	HW_EVENT_ERR_INFO = 3,
};

struct ftrace_event_file___27 {
	struct list_head list;
	struct ftrace_event_call___28 *event_call;
	struct dentry___79 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_extlog_mem_event {
	struct trace_entry ent;
	u32 err_seq;
	u8 etype;
	u8 sev;
	u64 pa;
	u8 pa_mask_lsb;
	uuid_le fru_id;
	u32 __data_loc_fru_text;
	struct cper_mem_err_compact data;
	char __data[0];
};

struct ftrace_raw_mc_event {
	struct trace_entry ent;
	unsigned int error_type;
	u32 __data_loc_msg;
	u32 __data_loc_label;
	u16 error_count;
	u8 mc_index;
	s8 top_layer;
	s8 middle_layer;
	s8 lower_layer;
	long int address;
	u8 grain_bits;
	long int syndrome;
	u32 __data_loc_driver_detail;
	char __data[0];
};

struct ftrace_raw_aer_event {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u32 status;
	u8 severity;
	char __data[0];
};

struct ftrace_data_offsets_extlog_mem_event {
	u32 fru_text;
};

struct ftrace_data_offsets_mc_event {
	u32 msg;
	u32 label;
	u32 driver_detail;
};

struct ftrace_data_offsets_aer_event {
	u32 dev_name;
};

struct pcibios_fwaddrmap {
	struct list_head list;
	struct pci_dev___29 *dev;
	resource_size_t fw_addr[17];
};

struct pci_check_idx_range {
	int start;
	int end;
};

struct pci_raw_ops {
	int (*read)(unsigned int, unsigned int, unsigned int, int, int, u32 *);
	int (*write)(unsigned int, unsigned int, unsigned int, int, int, u32);
};

struct pci_mmcfg_region {
	struct list_head list;
	struct resource res;
	u64 address;
	char *virt;
	u16 segment;
	u8 start_bus;
	u8 end_bus;
	char name[30];
};

struct acpi_table_mcfg {
	struct acpi_table_header header;
	u8 reserved[8];
};

struct acpi_mcfg_allocation {
	u64 address;
	u16 pci_segment;
	u8 start_bus_number;
	u8 end_bus_number;
	u32 reserved;
};

struct pci_mmcfg_hostbridge_probe {
	u32 bus;
	u32 devfn;
	u32 vendor;
	u32 device;
	const char * (*probe)();
};

typedef int (*check_reserved_t)(u64, u64, unsigned int);

struct x86_msi_ops___3 {
	int (*setup_msi_irqs)(struct pci_dev___8 *, int, int);
	void (*compose_msi_msg)(struct pci_dev___8 *, unsigned int, unsigned int, struct msi_msg *, u8);
	void (*teardown_msi_irq)(unsigned int);
	void (*teardown_msi_irqs)(struct pci_dev___8 *);
	void (*restore_msi_irqs)(struct pci_dev___8 *);
	int (*setup_hpet_msi)(unsigned int, unsigned int);
	u32 (*msi_mask_irq)(struct msi_desc___3 *, u32, u32);
	u32 (*msix_mask_irq)(struct msi_desc___3 *, u32);
};

struct xen_pci_frontend_ops___3 {
	int (*enable_msi)(struct pci_dev___8 *, int *);
	void (*disable_msi)(struct pci_dev___8 *);
	int (*enable_msix)(struct pci_dev___8 *, int *, int);
	void (*disable_msix)(struct pci_dev___8 *);
};

struct pci_host_bridge___2 {
	struct device___234 dev;
	struct pci_bus___28 *bus;
	struct list_head windows;
	void (*release_fn)(struct pci_host_bridge___2 *);
	void *release_data;
};

struct pci_root_info {
	struct acpi_device___35 *bridge;
	char name[16];
	unsigned int res_num;
	struct resource *res;
	resource_size_t *res_offset;
	struct pci_sysdata___4 sd;
	bool mcfg_added;
	u16 segment;
	u8 start_bus;
	u8 end_bus;
};

struct irq_info___3 {
	u8 bus;
	u8 devfn;
	struct {
		u8 link;
		u16 bitmap;
	} __attribute__((packed)) irq[4];
	u8 slot;
	u8 rfu;
};

struct irq_routing_table {
	u32 signature;
	u16 version;
	u16 size;
	u8 rtr_bus;
	u8 rtr_devfn;
	u16 exclusive_irqs;
	u16 rtr_vendor;
	u16 rtr_device;
	u32 miniport_data;
	u8 rfu[11];
	u8 checksum;
	struct irq_info___3 slots[0];
};

struct irq_router {
	char *name;
	u16 vendor;
	u16 device;
	int (*get)(struct pci_dev___29 *, struct pci_dev___29 *, int);
	int (*set)(struct pci_dev___29 *, struct pci_dev___29 *, int, int);
};

struct irq_router_handler {
	u16 vendor;
	int (*probe)(struct irq_router *, struct pci_dev___29 *, u16);
};

struct pci_sysdata___6 {
	int domain;
	int node;
	struct acpi_device___3 *companion;
	void *iommu;
};

struct pci_setup_rom {
	struct setup_data data;
	uint16_t vendor;
	uint16_t devid;
	uint64_t pcilen;
	long unsigned int segment;
	long unsigned int bus;
	long unsigned int device;
	long unsigned int function;
	uint8_t romdata[0];
};

enum pci_bf_sort_state {
	pci_bf_sort_default = 0,
	pci_force_nobf = 1,
	pci_force_bf = 2,
	pci_dmi_bf = 3,
};

struct pci_root_res {
	struct list_head list;
	struct resource res;
};

struct pci_root_info___2 {
	struct list_head list;
	char name[12];
	struct list_head resources;
	struct resource busn;
	int node;
	int link;
};

struct amd_hostbridge {
	u32 bus;
	u32 slot;
	u32 device;
};

struct saved_context {
	struct pt_regs regs;
	u16 ds;
	u16 es;
	u16 fs;
	u16 gs;
	u16 ss;
	long unsigned int gs_base;
	long unsigned int gs_kernel_base;
	long unsigned int fs_base;
	long unsigned int cr0;
	long unsigned int cr2;
	long unsigned int cr3;
	long unsigned int cr4;
	long unsigned int cr8;
	u64 misc_enable;
	bool misc_enable_saved;
	long unsigned int efer;
	u16 gdt_pad;
	struct desc_ptr gdt_desc;
	u16 idt_pad;
	u16 idt_limit;
	long unsigned int idt_base;
	u16 ldt;
	u16 tss;
	long unsigned int tr;
	long unsigned int safety;
	long unsigned int return_address;
} __attribute__((packed));

struct restore_data_record {
	long unsigned int jump_address;
	long unsigned int cr3;
	long unsigned int magic;
};

struct page___238;

typedef struct page___238 *pgtable_t___238;

struct address_space___239;

struct kmem_cache___222;

struct page___238 {
	long unsigned int flags;
	struct address_space___239 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___238 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___238 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___222 *slab_cache;
		struct page___238 *first_page;
	};
	long: 64;
};

struct thread_struct___84;

struct task_struct___240;

struct pv_cpu_ops___240 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___240 *);
	void (*end_context_switch)(struct task_struct___240 *);
};

struct perf_event___84;

struct thread_struct___84 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___84 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___94;

struct pid_link___94 {
	struct hlist_node node;
	struct pid___94 *pid;
};

struct mutex___241 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___240 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___233 {
	struct page___238 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___247;

struct nsproxy___120;

struct signal_struct___240;

struct css_set___135;

struct perf_event_context___84;

struct task_struct___240 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___240 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___247 *mm;
	struct mm_struct___247 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___240 *real_parent;
	struct task_struct___240 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___240 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___240 = 0,
		VTIME_USER___240 = 1,
		VTIME_SYS___240 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___120 *nsproxy;
	struct signal_struct___240 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___135 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___84 *perf_event_ctxp[2];
	struct mutex___241 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___233 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___247 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___247 *, struct mm_struct___247 *);
	void (*dup_mmap)(struct mm_struct___247 *, struct mm_struct___247 *);
	void (*exit_mmap)(struct mm_struct___247 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___247 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___247 *);
	void (*pgd_free)(struct mm_struct___247 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___247 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___247 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___247 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___247 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___247 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___247 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___247 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___247 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___247 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___247 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___247 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___241 lock;
	void *vdso;
} mm_context_t___241;

struct xol_area___238;

struct uprobes_state___238 {
	struct xol_area___238 *xol_area;
};

struct vm_area_struct___247;

struct file___239;

struct core_state___240;

struct mm_struct___247 {
	struct vm_area_struct___247 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___247 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___247 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___241 context;
	long unsigned int flags;
	struct core_state___240 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___240 *owner;
	struct file___239 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___238 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___142;

struct exec_domain___66 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___142 *module;
	struct exec_domain___66 *next;
};

struct kset___25;

struct kobj_type___25;

struct kobject___25 {
	const char *name;
	struct list_head entry;
	struct kobject___25 *parent;
	struct kset___25 *kset;
	struct kobj_type___25 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___141 {
	struct kobject___25 kobj;
	struct module___142 *mod;
	struct kobject___25 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___141;

struct ftrace_event_call___73;

struct module___142 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___141 mkobj;
	struct module_attribute___141 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___25 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___73 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___240 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct hw_perf_event___84 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___240 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___240 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___240 *target;
};

struct perf_sample_data___8;

typedef void (*perf_overflow_handler_t___84)(struct perf_event___84 *, struct perf_sample_data___8 *, struct pt_regs *);

struct ftrace_ops___84;

typedef void (*ftrace_func_t___84)(long unsigned int, long unsigned int, struct ftrace_ops___84 *, struct pt_regs *);

struct ftrace_ops___84 {
	ftrace_func_t___84 func;
	struct ftrace_ops___84 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___241 regex_lock;
};

struct pmu___84;

struct fasync_struct___239;

struct pid_namespace___94;

struct perf_cgroup___84;

struct perf_event___84 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___84 *group_leader;
	struct pmu___84 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___84 hw;
	struct perf_event_context___84 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___241 child_mutex;
	struct list_head child_list;
	struct perf_event___84 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___240 *owner;
	struct mutex___241 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___239 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___84 *);
	struct callback_head callback_head;
	struct pid_namespace___94 *ns;
	u64 id;
	perf_overflow_handler_t___84 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___73 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___84 ftrace_ops;
	struct perf_cgroup___84 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___111 {
	struct task_struct___240 *task;
	struct exec_domain___66 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___240;

struct lruvec___240 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___240 *zone;
};

struct pglist_data___240;

struct zone___240 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___240 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___240 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___240 {
	struct zone___240 *zone;
	int zone_idx;
};

struct zonelist___240 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___240 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___240 {
	struct zone___240 node_zones[4];
	struct zonelist___240 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___240 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___163;

struct x86_io_apic_ops___163 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___163 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___163;

struct irq_data___163 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___163 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___237;

struct dev_pm_ops___237 {
	int (*prepare)(struct device___237 *);
	void (*complete)(struct device___237 *);
	int (*suspend)(struct device___237 *);
	int (*resume)(struct device___237 *);
	int (*freeze)(struct device___237 *);
	int (*thaw)(struct device___237 *);
	int (*poweroff)(struct device___237 *);
	int (*restore)(struct device___237 *);
	int (*suspend_late)(struct device___237 *);
	int (*resume_early)(struct device___237 *);
	int (*freeze_late)(struct device___237 *);
	int (*thaw_early)(struct device___237 *);
	int (*poweroff_late)(struct device___237 *);
	int (*restore_early)(struct device___237 *);
	int (*suspend_noirq)(struct device___237 *);
	int (*resume_noirq)(struct device___237 *);
	int (*freeze_noirq)(struct device___237 *);
	int (*thaw_noirq)(struct device___237 *);
	int (*poweroff_noirq)(struct device___237 *);
	int (*restore_noirq)(struct device___237 *);
	int (*runtime_suspend)(struct device___237 *);
	int (*runtime_resume)(struct device___237 *);
	int (*runtime_idle)(struct device___237 *);
};

struct dev_pm_qos___41;

struct dev_pm_info___41 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___41 *qos;
};

struct dma_map_ops___102;

struct dev_archdata___102 {
	struct dma_map_ops___102 *dma_ops;
	void *iommu;
};

struct device_type___237;

struct bus_type___237;

struct device_driver___237;

struct dev_pm_domain___237;

struct class___237;

struct attribute_group___199;

struct device_rh___237;

struct device___237 {
	struct device___237 *parent;
	struct device_private *p;
	struct kobject___25 kobj;
	const char *init_name;
	const struct device_type___237 *type;
	struct mutex___241 mutex;
	struct bus_type___237 *bus;
	struct device_driver___237 *driver;
	void *platform_data;
	struct dev_pm_info___41 power;
	struct dev_pm_domain___237 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___102 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___237 *class;
	const struct attribute_group___199 **groups;
	void (*release)(struct device___237 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___237 *device_rh;
};

struct dev_pm_qos_request___42;

struct dev_pm_qos___41 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___42 *latency_req;
	struct dev_pm_qos_request___42 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___42 *latency_tolerance_req;
};

struct dev_pm_info_rh___237 {
	void (*set_latency_tolerance)(struct device___237 *, s32);
};

struct dev_pm_domain___237 {
	struct dev_pm_ops___237 ops;
};

struct smp_ops___240 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___240 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___238 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___238 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___221;

struct memcg_cache_params___222;

struct kmem_cache___222 {
	struct kmem_cache_cpu___221 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___25 kobj;
	struct memcg_cache_params___222 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___239;

struct address_space_operations___239;

struct address_space___239 {
	struct inode___239 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___241 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___239 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___45;

struct dentry___239;

struct path___239 {
	struct vfsmount___45 *mnt;
	struct dentry___239 *dentry;
};

struct fown_struct___94 {
	rwlock_t lock;
	struct pid___94 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___239;

struct file___239 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___239 f_path;
	struct inode___239 *f_inode;
	const struct file_operations___239 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___239 *f_mapping;
	struct mutex___241 f_pos_lock;
};

struct vm_operations_struct___213;

struct vm_area_struct___247 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___247 *vm_next;
	struct vm_area_struct___247 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___247 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___213 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___239 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___209;

struct vm_operations_struct___213 {
	void (*open)(struct vm_area_struct___247 *);
	void (*close)(struct vm_area_struct___247 *);
	int (*fault)(struct vm_area_struct___247 *, struct vm_fault___209 *);
	int (*page_mkwrite)(struct vm_area_struct___247 *, struct vm_fault___209 *);
	int (*access)(struct vm_area_struct___247 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___247 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___247 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___247 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___247 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___240 {
	struct task_struct___240 *task;
	struct core_thread___240 *next;
};

struct core_state___240 {
	atomic_t nr_threads;
	struct core_thread___240 dumper;
	struct completion startup;
};

struct vm_fault___209 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___238 *page;
};

struct mmsghdr {
	struct msghdr msg_hdr;
	unsigned int msg_len;
};

enum sock_shutdown_cmd {
	SHUT_RD = 0,
	SHUT_WR = 1,
	SHUT_RDWR = 2,
};

struct socket_wq___22 {
	wait_queue_head_t wait;
	struct fasync_struct___239 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___239 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___239 *fa_next;
	struct file___239 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___23;

struct proto_ops___22;

struct socket___23 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___22 *wq;
	struct file___239 *file;
	struct sock___23 *sk;
	const struct proto_ops___22 *ops;
};

struct proto___22;

struct net___44;

struct sock_common___22 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___22 *skc_prot;
	struct net___44 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___33;

struct sk_buff_head___31 {
	struct sk_buff___33 *next;
	struct sk_buff___33 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___23;

struct dst_entry___22;

struct cg_proto___22;

struct sock___23 {
	struct sock_common___22 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___31 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___33 *head;
		struct sk_buff___33 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___23 *sk_filter;
	struct socket_wq___22 *sk_wq;
	struct sk_buff_head___31 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___22 *sk_rx_dst;
	struct dst_entry___22 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___31 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___31 sk_error_queue;
	struct proto___22 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___23 *sk_socket;
	void *sk_user_data;
	struct page_frag___233 sk_frag;
	struct sk_buff___33 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___22 *sk_cgrp;
	void (*sk_state_change)(struct sock___23 *);
	void (*sk_data_ready)(struct sock___23 *, int);
	void (*sk_write_space)(struct sock___23 *);
	void (*sk_error_report)(struct sock___23 *);
	int (*sk_backlog_rcv)(struct sock___23 *, struct sk_buff___33 *);
	void (*sk_destruct)(struct sock___23 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___129;

struct kiocb___30;

struct proto_ops___22 {
	int family;
	struct module___142 *owner;
	int (*release)(struct socket___23 *);
	int (*bind)(struct socket___23 *, struct sockaddr *, int);
	int (*connect)(struct socket___23 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___23 *, struct socket___23 *);
	int (*accept)(struct socket___23 *, struct socket___23 *, int);
	int (*getname)(struct socket___23 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___239 *, struct socket___23 *, struct poll_table_struct___129 *);
	int (*ioctl)(struct socket___23 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___23 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___23 *, int);
	int (*shutdown)(struct socket___23 *, int);
	int (*setsockopt)(struct socket___23 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___23 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___23 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___23 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___30 *, struct socket___23 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___30 *, struct socket___23 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___239 *, struct socket___23 *, struct vm_area_struct___247 *);
	ssize_t (*sendpage)(struct socket___23 *, struct page___238 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___23 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___23 *, int);
		struct {
			void (*set_peek_off)(struct sock___23 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___131)(struct file___239 *, wait_queue_head_t *, struct poll_table_struct___129 *);

struct poll_table_struct___129 {
	poll_queue_proc___131 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___30(struct kiocb___30 *, struct io_event *);

struct kiocb___30 {
	atomic_t ki_users;
	struct file___239 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___30 *ki_cancel;
	void (*ki_dtor)(struct kiocb___30 *);
	union {
		void *user;
		struct task_struct___240 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct net_proto_family___2 {
	int family;
	int (*create)(struct net___44 *, struct socket___23 *, int, int);
	struct module___142 *owner;
};

struct ctl_table_root___45;

struct ctl_table_set___45;

struct ctl_dir___45;

struct ctl_node___45;

struct ctl_table_header___45 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___45 *root;
	struct ctl_table_set___45 *set;
	struct ctl_dir___45 *parent;
	struct ctl_node___45 *node;
};

struct ctl_dir___45 {
	struct ctl_table_header___45 header;
	struct rb_root root;
};

struct ctl_table_set___45 {
	int (*is_seen)(struct ctl_table_set___45 *);
	struct ctl_dir___45 dir;
};

struct netns_core___42 {
	struct ctl_table_header___45 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___42 {
	struct mutex___241 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___42 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___45 *ctl;
};

struct netns_ipv4___42 {
	struct ctl_table_header___45 *forw_hdr;
	struct ctl_table_header___45 *frags_hdr;
	struct ctl_table_header___45 *ipv4_hdr;
	struct ctl_table_header___45 *route_hdr;
	struct ctl_table_header___45 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___23 *fibnl;
	struct sock___23 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___42 {
	struct ctl_table_header___45 *hdr;
	struct ctl_table_header___45 *route_hdr;
	struct ctl_table_header___45 *icmp_hdr;
	struct ctl_table_header___45 *frags_hdr;
	struct ctl_table_header___45 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___32;

struct neighbour___22;

struct dst_ops___43 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___43 *);
	struct dst_entry___22 * (*check)(struct dst_entry___22 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___22 *);
	unsigned int (*mtu)(const struct dst_entry___22 *);
	u32 * (*cow_metrics)(struct dst_entry___22 *, long unsigned int);
	void (*destroy)(struct dst_entry___22 *);
	void (*ifdown)(struct dst_entry___22 *, struct net_device___32 *, int);
	struct dst_entry___22 * (*negative_advice)(struct dst_entry___22 *);
	void (*link_failure)(struct sk_buff___33 *);
	void (*update_pmtu)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___33 *, u32);
	void (*redirect)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___33 *);
	int (*local_out)(struct sk_buff___33 *);
	struct neighbour___22 * (*neigh_lookup)(const struct dst_entry___22 *, struct sk_buff___33 *, const void *);
	struct kmem_cache___222 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___43 {
	struct netns_sysctl_ipv6___42 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___43 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___23 **icmp_sk;
	struct sock___23 *ndisc_sk;
	struct sock___23 *tcp_sk;
	struct sock___23 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___42 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___45 *sysctl_header;
	struct sock___23 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___22 {
	struct sock___23 *v4_ctl_sk;
	struct sock___23 *v6_ctl_sk;
};

struct netns_nf___42 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___45 *nf_log_dir_header;
};

struct nf_proto_net___42 {
	struct ctl_table_header___45 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___42 {
	struct nf_proto_net___42 pn;
	unsigned int timeout;
};

struct nf_tcp_net___42 {
	struct nf_proto_net___42 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___42 {
	struct nf_proto_net___42 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___42 {
	struct nf_proto_net___42 pn;
	unsigned int timeout;
};

struct nf_ip_net___42 {
	struct nf_generic_net___42 generic;
	struct nf_tcp_net___42 tcp;
	struct nf_udp_net___42 udp;
	struct nf_icmp_net___42 icmp;
	struct nf_icmp_net___42 icmpv6;
};

struct netns_ct___42 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___45 *sysctl_header;
	struct ctl_table_header___45 *acct_sysctl_header;
	struct ctl_table_header___45 *tstamp_sysctl_header;
	struct ctl_table_header___45 *event_sysctl_header;
	struct ctl_table_header___45 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___222 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___42 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___42 {
	struct netns_sysctl_ipv6___42 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___43 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___23 *nlsk;
	struct sock___23 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___45 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___43 xfrm4_dst_ops;
	struct dst_ops___43 xfrm6_dst_ops;
};

struct net___44 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___45 sysctls;
	struct sock___23 *rtnl;
	struct sock___23 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___32 *loopback_dev;
	struct netns_core___42 core;
	struct netns_mib mib;
	struct netns_packet___42 packet;
	struct netns_unix___42 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___42 ipv4;
	struct netns_ipv6___43 ipv6;
	struct netns_sctp___42 sctp;
	struct netns_dccp___22 dccp;
	struct netns_nf___42 nf;
	struct netns_xt xt;
	struct netns_ct___42 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___42 nf_frag;
	struct sock___23 *nfnl;
	struct sock___23 *nfnl_stash;
	struct sk_buff_head___31 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___43 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___23 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___23 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___241 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___241 flow_flush_sem;
	long: 64;
	long: 64;
};

struct seq_file___164;

struct irq_chip___163 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___163 *);
	void (*irq_shutdown)(struct irq_data___163 *);
	void (*irq_enable)(struct irq_data___163 *);
	void (*irq_disable)(struct irq_data___163 *);
	void (*irq_ack)(struct irq_data___163 *);
	void (*irq_mask)(struct irq_data___163 *);
	void (*irq_mask_ack)(struct irq_data___163 *);
	void (*irq_unmask)(struct irq_data___163 *);
	void (*irq_eoi)(struct irq_data___163 *);
	int (*irq_set_affinity)(struct irq_data___163 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___163 *);
	int (*irq_set_type)(struct irq_data___163 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___163 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___163 *);
	void (*irq_bus_sync_unlock)(struct irq_data___163 *);
	void (*irq_cpu_online)(struct irq_data___163 *);
	void (*irq_cpu_offline)(struct irq_data___163 *);
	void (*irq_suspend)(struct irq_data___163 *);
	void (*irq_resume)(struct irq_data___163 *);
	void (*irq_pm_shutdown)(struct irq_data___163 *);
	void (*irq_print_chip)(struct irq_data___163 *, struct seq_file___164 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___163 *, void *);
	long unsigned int flags;
};

struct seq_operations___164;

struct seq_file___164 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___241 lock;
	const struct seq_operations___164 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___239;

struct file_operations___239 {
	struct module___142 *owner;
	loff_t (*llseek)(struct file___239 *, loff_t, int);
	ssize_t (*read)(struct file___239 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___239 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___30 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___30 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___239 *, void *, filldir_t);
	unsigned int (*poll)(struct file___239 *, struct poll_table_struct___129 *);
	long int (*unlocked_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___239 *, struct vm_area_struct___247 *);
	int (*open)(struct inode___239 *, struct file___239 *);
	int (*flush)(struct file___239 *, fl_owner_t);
	int (*release)(struct inode___239 *, struct file___239 *);
	int (*fsync)(struct file___239 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___30 *, int);
	int (*fasync)(int, struct file___239 *, int);
	int (*lock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*sendpage)(struct file___239 *, struct page___238 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___239 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___239 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___239 *, long int, struct file_lock___239 **, void **);
		struct {
			int (*setlease)(struct file___239 *, long int, struct file_lock___239 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___239 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___164 *, struct file___239 *);
};

struct kobj_ns_type_operations___22 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___23 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___201;

struct attribute_group___199 {
	const char *name;
	umode_t (*is_visible)(struct kobject___25 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___201 **bin_attrs;
};

struct bin_attribute___201 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___239 *, struct kobject___25 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___239 *, struct kobject___25 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	int (*mmap)(struct file___239 *, struct kobject___25 *, struct bin_attribute___201 *, struct vm_area_struct___247 *);
};

struct sysfs_ops___25 {
	ssize_t (*show)(struct kobject___25 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___25 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___25 *, const struct attribute *);
};

struct kset_uevent_ops___25;

struct kset___25 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___25 kobj;
	const struct kset_uevent_ops___25 *uevent_ops;
};

struct kobj_type___25 {
	void (*release)(struct kobject___25 *);
	const struct sysfs_ops___25 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___22 * (*child_ns_type)(struct kobject___25 *);
	const void * (*namespace)(struct kobject___25 *);
};

struct kset_uevent_ops___25 {
	int (* const filter)(struct kset___25 *, struct kobject___25 *);
	const char * (* const name)(struct kset___25 *, struct kobject___25 *);
	int (* const uevent)(struct kset___25 *, struct kobject___25 *, struct kobj_uevent_env *);
};

struct dma_map_ops___102 {
	void * (*alloc)(struct device___237 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___237 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___237 *, struct vm_area_struct___247 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___237 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___237 *, struct page___238 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___237 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___237 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___237 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___237 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___237 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___237 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___237 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___237 *, dma_addr_t);
	int (*dma_supported)(struct device___237 *, u64);
	int (*set_dma_mask)(struct device___237 *, u64);
	int is_phys;
};

struct bus_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___237 *, char *);
	ssize_t (*store)(struct bus_type___237 *, const char *, size_t);
};

struct device_attribute___237;

struct driver_attribute___237;

struct bus_type___237 {
	const char *name;
	const char *dev_name;
	struct device___237 *dev_root;
	struct bus_attribute___237 *bus_attrs;
	struct device_attribute___237 *dev_attrs;
	struct driver_attribute___237 *drv_attrs;
	const struct attribute_group___199 **bus_groups;
	const struct attribute_group___199 **dev_groups;
	const struct attribute_group___199 **drv_groups;
	int (*match)(struct device___237 *, struct device_driver___237 *);
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	int (*probe)(struct device___237 *);
	int (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*online)(struct device___237 *);
	int (*offline)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct device___237 *, struct device_attribute___237 *, char *);
	ssize_t (*store)(struct device___237 *, struct device_attribute___237 *, const char *, size_t);
};

struct driver_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___237 *, char *);
	ssize_t (*store)(struct device_driver___237 *, const char *, size_t);
};

struct device_driver___237 {
	const char *name;
	struct bus_type___237 *bus;
	struct module___142 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___237 *);
	int (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	const struct attribute_group___199 **groups;
	const struct dev_pm_ops___237 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___237 {
	const char *name;
	const struct attribute_group___199 **groups;
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
};

struct class_attribute___237;

struct class___237 {
	const char *name;
	struct module___142 *owner;
	struct class_attribute___237 *class_attrs;
	struct device_attribute___237 *dev_attrs;
	const struct attribute_group___199 **dev_groups;
	struct bin_attribute___201 *dev_bin_attrs;
	struct kobject___25 *dev_kobj;
	int (*dev_uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *);
	void (*class_release)(struct class___237 *);
	void (*dev_release)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	const struct kobj_ns_type_operations___22 *ns_type;
	const void * (*namespace)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
	struct subsys_private *p;
};

struct class_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct class___237 *, struct class_attribute___237 *, char *);
	ssize_t (*store)(struct class___237 *, struct class_attribute___237 *, const char *, size_t);
	const void * (*namespace)(struct class___237 *, const struct class_attribute___237 *);
};

struct device_rh___237 {
	struct dev_pm_info_rh___237 power;
};

struct dev_pm_qos_request___42 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___237 *dev;
};

struct ifconf {
	int ifc_len;
	union {
		char *ifcu_buf;
		struct ifreq *ifcu_req;
	} ifc_ifcu;
};

struct dentry_operations___239;

struct super_block___239;

struct dentry___239 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___239 *d_parent;
	struct qstr d_name;
	struct inode___239 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___239 *d_op;
	struct super_block___239 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___239;

struct dquot___239;

struct block_device___239;

struct inode___239 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___239 *i_op;
	struct super_block___239 *i_sb;
	struct address_space___239 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___241 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___239 *i_fop;
	struct file_lock___239 *i_flock;
	struct address_space___239 i_data;
	struct dquot___239 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___239 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___239 {
	int (*d_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_hash)(const struct dentry___239 *, struct qstr *);
	int (*d_compare)(const struct dentry___239 *, const struct dentry___239 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___239 *);
	void (*d_release)(struct dentry___239 *);
	void (*d_prune)(struct dentry___239 *);
	void (*d_iput)(struct dentry___239 *, struct inode___239 *);
	char * (*d_dname)(struct dentry___239 *, char *, int);
	struct vfsmount___45 * (*d_automount)(struct path___239 *);
	int (*d_manage)(struct dentry___239 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___239;

struct mem_dqinfo___239 {
	struct quota_format_type___239 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___239;

struct quota_info___239 {
	unsigned int flags;
	struct mutex___241 dqio_mutex;
	struct mutex___241 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___239 *files[2];
	struct mem_dqinfo___239 info[2];
	const struct quota_format_ops___239 *ops[2];
};

struct file_system_type___239;

struct super_operations___239;

struct dquot_operations___239;

struct quotactl_ops___239;

struct xattr_handler___136;

struct super_block___239 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___239 *s_type;
	const struct super_operations___239 *s_op;
	const struct dquot_operations___239 *dq_op;
	const struct quotactl_ops___239 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___239 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___136 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___239 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___239 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___241 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___239 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___45 {
	struct dentry___239 *mnt_root;
	struct super_block___239 *mnt_sb;
	int mnt_flags;
};

struct upid___94 {
	int nr;
	struct pid_namespace___94 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___94 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___240 *child_reaper;
	struct kmem_cache___222 *pid_cachep;
	unsigned int level;
	struct pid_namespace___94 *parent;
	struct vfsmount___45 *proc_mnt;
	struct dentry___239 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___94 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___94 numbers[1];
};

struct block_device___239 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___239 *bd_inode;
	struct super_block___239 *bd_super;
	struct mutex___241 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___239 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___241 bd_fsfreeze_mutex;
};

struct cgroup___135;

struct cgroup_subsys_state___135 {
	struct cgroup___135 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___239 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___239 *ia_file;
};

struct dquot___239 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___241 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___239 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___239 {
	int qf_fmt_id;
	const struct quota_format_ops___239 *qf_ops;
	struct module___142 *qf_owner;
	struct quota_format_type___239 *qf_next;
};

struct quota_format_ops___239 {
	int (*check_quota_file)(struct super_block___239 *, int);
	int (*read_file_info)(struct super_block___239 *, int);
	int (*write_file_info)(struct super_block___239 *, int);
	int (*free_file_info)(struct super_block___239 *, int);
	int (*read_dqblk)(struct dquot___239 *);
	int (*commit_dqblk)(struct dquot___239 *);
	int (*release_dqblk)(struct dquot___239 *);
};

struct dquot_operations___239 {
	int (*write_dquot)(struct dquot___239 *);
	struct dquot___239 * (*alloc_dquot)(struct super_block___239 *, int);
	void (*destroy_dquot)(struct dquot___239 *);
	int (*acquire_dquot)(struct dquot___239 *);
	int (*release_dquot)(struct dquot___239 *);
	int (*mark_dirty)(struct dquot___239 *);
	int (*write_info)(struct super_block___239 *, int);
	qsize_t * (*get_reserved_space)(struct inode___239 *);
};

struct quotactl_ops___239 {
	int (*quota_on)(struct super_block___239 *, int, int, struct path___239 *);
	int (*quota_on_meta)(struct super_block___239 *, int, int);
	int (*quota_off)(struct super_block___239 *, int);
	int (*quota_sync)(struct super_block___239 *, int);
	int (*get_info)(struct super_block___239 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___239 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___239 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___239 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___239 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___239 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___239 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___239 *, unsigned int);
};

struct address_space_operations___239 {
	int (*writepage)(struct page___238 *, struct writeback_control *);
	int (*readpage)(struct file___239 *, struct page___238 *);
	int (*writepages)(struct address_space___239 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___238 *);
	int (*readpages)(struct file___239 *, struct address_space___239 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___239 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___238 **, void **);
	int (*write_end)(struct file___239 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___238 *, void *);
	sector_t (*bmap)(struct address_space___239 *, sector_t);
	void (*invalidatepage)(struct page___238 *, long unsigned int);
	int (*releasepage)(struct page___238 *, gfp_t);
	void (*freepage)(struct page___238 *);
	ssize_t (*direct_IO)(int, struct kiocb___30 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___239 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___239 *, struct page___238 *, struct page___238 *, enum migrate_mode);
	int (*launder_page)(struct page___238 *);
	int (*is_partially_uptodate)(struct page___238 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___238 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___239 *, struct page___238 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___239 *, sector_t *);
	void (*swap_deactivate)(struct file___239 *);
	void (*invalidatepage_range)(struct page___238 *, unsigned int, unsigned int);
};

struct inode_operations___239 {
	struct dentry___239 * (*lookup)(struct inode___239 *, struct dentry___239 *, unsigned int);
	void * (*follow_link)(struct dentry___239 *, struct nameidata *);
	int (*permission)(struct inode___239 *, int);
	struct posix_acl * (*get_acl)(struct inode___239 *, int);
	int (*readlink)(struct dentry___239 *, char *, int);
	void (*put_link)(struct dentry___239 *, struct nameidata *, void *);
	int (*create)(struct inode___239 *, struct dentry___239 *, umode_t, bool);
	int (*link)(struct dentry___239 *, struct inode___239 *, struct dentry___239 *);
	int (*unlink)(struct inode___239 *, struct dentry___239 *);
	int (*symlink)(struct inode___239 *, struct dentry___239 *, const char *);
	int (*mkdir)(struct inode___239 *, struct dentry___239 *, umode_t);
	int (*rmdir)(struct inode___239 *, struct dentry___239 *);
	int (*mknod)(struct inode___239 *, struct dentry___239 *, umode_t, dev_t);
	int (*rename)(struct inode___239 *, struct dentry___239 *, struct inode___239 *, struct dentry___239 *);
	int (*setattr)(struct dentry___239 *, struct iattr___239 *);
	int (*getattr)(struct vfsmount___45 *, struct dentry___239 *, struct kstat *);
	int (*setxattr)(struct dentry___239 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___239 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___239 *, char *, size_t);
	int (*removexattr)(struct dentry___239 *, const char *);
	int (*fiemap)(struct inode___239 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___239 *, struct timespec *, int);
	int (*atomic_open)(struct inode___239 *, struct dentry___239 *, struct file___239 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___239;

struct lock_manager_operations___239;

struct file_lock___239 {
	struct file_lock___239 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___239 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___239 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___239 *fl_ops;
	const struct lock_manager_operations___239 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___239 {
	void (*fl_copy_lock)(struct file_lock___239 *, struct file_lock___239 *);
	void (*fl_release_private)(struct file_lock___239 *);
};

struct lock_manager_operations___239 {
	int (*lm_compare_owner)(struct file_lock___239 *, struct file_lock___239 *);
	long unsigned int (*lm_owner_key)(struct file_lock___239 *);
	void (*lm_notify)(struct file_lock___239 *);
	int (*lm_grant)(struct file_lock___239 *, struct file_lock___239 *, int);
	void (*lm_break)(struct file_lock___239 *);
	int (*lm_change)(struct file_lock___239 **, int);
};

struct file_system_type___239 {
	const char *name;
	int fs_flags;
	struct dentry___239 * (*mount)(struct file_system_type___239 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___239 *);
	struct module___142 *owner;
	struct file_system_type___239 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___239 {
	struct inode___239 * (*alloc_inode)(struct super_block___239 *);
	void (*destroy_inode)(struct inode___239 *);
	void (*dirty_inode)(struct inode___239 *, int);
	int (*write_inode)(struct inode___239 *, struct writeback_control *);
	int (*drop_inode)(struct inode___239 *);
	void (*evict_inode)(struct inode___239 *);
	void (*put_super)(struct super_block___239 *);
	int (*sync_fs)(struct super_block___239 *, int);
	int (*freeze_fs)(struct super_block___239 *);
	int (*unfreeze_fs)(struct super_block___239 *);
	int (*statfs)(struct dentry___239 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___239 *, int *, char *);
	void (*umount_begin)(struct super_block___239 *);
	int (*show_options)(struct seq_file___164 *, struct dentry___239 *);
	int (*show_devname)(struct seq_file___164 *, struct dentry___239 *);
	int (*show_path)(struct seq_file___164 *, struct dentry___239 *);
	int (*show_stats)(struct seq_file___164 *, struct dentry___239 *);
	ssize_t (*quota_read)(struct super_block___239 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___239 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___239 *);
	int (*bdev_try_to_free_page)(struct super_block___239 *, struct page___238 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___239 *);
	void (*free_cached_objects)(struct super_block___239 *, int);
};

struct xattr_handler___136 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___239 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___239 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___239 *, const char *, const void *, size_t, int, int);
};

struct ctl_node___45 {
	struct rb_node node;
	struct ctl_table_header___45 *header;
};

struct ctl_table_root___45 {
	struct ctl_table_set___45 default_set;
	struct ctl_table_set___45 * (*lookup)(struct ctl_table_root___45 *, struct nsproxy___120 *);
	int (*permissions)(struct ctl_table_header___45 *, struct ctl_table *);
};

struct nsproxy___120 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___94 *pid_ns;
	struct net___44 *net_ns;
};

struct signal_struct___240 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___240 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___240 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___241 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___135 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___135 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___84 {
	struct pmu___84 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___241 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___240 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___84 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct compat_ifmap {
	compat_ulong_t mem_start;
	compat_ulong_t mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct compat_if_settings {
	unsigned int type;
	unsigned int size;
	compat_uptr_t ifs_ifsu;
};

struct compat_ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		compat_int_t ifru_ivalue;
		compat_int_t ifru_mtu;
		struct compat_ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		compat_caddr_t ifru_data;
		struct compat_if_settings ifru_settings;
	} ifr_ifru;
};

struct compat_ifconf {
	compat_int_t ifc_len;
	compat_caddr_t ifcbuf;
};

struct kmem_cache_cpu___221 {
	void **freelist;
	long unsigned int tid;
	struct page___238 *page;
	struct page___238 *partial;
};

struct memcg_cache_params___222 {
	bool is_root_cache;
	union {
		struct kmem_cache___222 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___222 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___30 {
	atomic_t use;
	unsigned int mask;
	struct net_device___32 *physindev;
	struct net_device___32 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___30(struct sk_buff___33 **);

struct iw_handler_def___2;

struct net_device_ops___30;

struct ethtool_ops___30;

struct header_ops___30;

struct inet6_dev___11;

struct netdev_rx_queue___30;

struct netdev_queue___30;

struct rtnl_link_ops___22;

struct dcbnl_rtnl_ops___30;

struct net_device___32 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def___2 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___30 *netdev_ops;
	const struct ethtool_ops___30 *ethtool_ops;
	const struct header_ops___30 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___25 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___11 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___30 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___30 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___30 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___30 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___30 = 0,
		NETREG_REGISTERED___30 = 1,
		NETREG_UNREGISTERING___30 = 2,
		NETREG_UNREGISTERED___30 = 3,
		NETREG_RELEASED___30 = 4,
		NETREG_DUMMY___30 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___30 = 0,
		RTNL_LINK_INITIALIZING___30 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___32 *);
	struct netpoll_info *npinfo;
	struct net___44 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___237 dev;
	const struct attribute_group___199 *sysfs_groups[4];
	const struct rtnl_link_ops___22 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___30 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___33 {
	struct sk_buff___33 *next;
	struct sk_buff___33 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___23 *sk;
	struct net_device___32 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___33 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___30 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct {
	struct {
		struct page___238 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct skb_frag_t;

struct skb_shared_hwtstamps {
	ktime_t hwtstamp;
	ktime_t syststamp;
};

enum {
	SKBTX_HW_TSTAMP = 1,
	SKBTX_SW_TSTAMP = 2,
	SKBTX_IN_PROGRESS = 4,
	SKBTX_DEV_ZEROCOPY = 8,
	SKBTX_WIFI_STATUS = 16,
	SKBTX_SHARED_FRAG = 32,
};

struct skb_shared_info {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___33 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t frags[17];
};

struct compat_ethtool_rx_flow_spec {
	u32 flow_type;
	union ethtool_flow_union h_u;
	struct ethtool_flow_ext h_ext;
	union ethtool_flow_union m_u;
	struct ethtool_flow_ext m_ext;
	compat_u64 ring_cookie;
	u32 location;
} __attribute__((packed));

struct compat_ethtool_rxnfc {
	u32 cmd;
	u32 flow_type;
	compat_u64 data;
	struct compat_ethtool_rx_flow_spec fs;
	u32 rule_cnt;
	u32 rule_locs[0];
} __attribute__((packed));

struct ethtool_ops___30 {
	int (*get_settings)(struct net_device___32 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___32 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___32 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___32 *);
	void (*get_regs)(struct net_device___32 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___32 *);
	void (*set_msglevel)(struct net_device___32 *, u32);
	int (*nway_reset)(struct net_device___32 *);
	u32 (*get_link)(struct net_device___32 *);
	int (*get_eeprom_len)(struct net_device___32 *);
	int (*get_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___32 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___32 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___32 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___32 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___32 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___32 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___32 *);
	void (*complete)(struct net_device___32 *);
	u32 (*get_priv_flags)(struct net_device___32 *);
	int (*set_priv_flags)(struct net_device___32 *, u32);
	int (*get_sset_count)(struct net_device___32 *, int);
	int (*get_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___32 *, struct ethtool_flash *);
	int (*reset)(struct net_device___32 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___32 *);
	int (*get_rxfh_indir)(struct net_device___32 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___32 *, const u32 *);
	void (*get_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___32 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___32 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___32 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___32 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___32 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___32 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___32 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___32 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	LINUX_MIB_NUM = 0,
	LINUX_MIB_SYNCOOKIESSENT = 1,
	LINUX_MIB_SYNCOOKIESRECV = 2,
	LINUX_MIB_SYNCOOKIESFAILED = 3,
	LINUX_MIB_EMBRYONICRSTS = 4,
	LINUX_MIB_PRUNECALLED = 5,
	LINUX_MIB_RCVPRUNED = 6,
	LINUX_MIB_OFOPRUNED = 7,
	LINUX_MIB_OUTOFWINDOWICMPS = 8,
	LINUX_MIB_LOCKDROPPEDICMPS = 9,
	LINUX_MIB_ARPFILTER = 10,
	LINUX_MIB_TIMEWAITED = 11,
	LINUX_MIB_TIMEWAITRECYCLED = 12,
	LINUX_MIB_TIMEWAITKILLED = 13,
	LINUX_MIB_PAWSPASSIVEREJECTED = 14,
	LINUX_MIB_PAWSACTIVEREJECTED = 15,
	LINUX_MIB_PAWSESTABREJECTED = 16,
	LINUX_MIB_DELAYEDACKS = 17,
	LINUX_MIB_DELAYEDACKLOCKED = 18,
	LINUX_MIB_DELAYEDACKLOST = 19,
	LINUX_MIB_LISTENOVERFLOWS = 20,
	LINUX_MIB_LISTENDROPS = 21,
	LINUX_MIB_TCPPREQUEUED = 22,
	LINUX_MIB_TCPDIRECTCOPYFROMBACKLOG = 23,
	LINUX_MIB_TCPDIRECTCOPYFROMPREQUEUE = 24,
	LINUX_MIB_TCPPREQUEUEDROPPED = 25,
	LINUX_MIB_TCPHPHITS = 26,
	LINUX_MIB_TCPHPHITSTOUSER = 27,
	LINUX_MIB_TCPPUREACKS = 28,
	LINUX_MIB_TCPHPACKS = 29,
	LINUX_MIB_TCPRENORECOVERY = 30,
	LINUX_MIB_TCPSACKRECOVERY = 31,
	LINUX_MIB_TCPSACKRENEGING = 32,
	LINUX_MIB_TCPFACKREORDER = 33,
	LINUX_MIB_TCPSACKREORDER = 34,
	LINUX_MIB_TCPRENOREORDER = 35,
	LINUX_MIB_TCPTSREORDER = 36,
	LINUX_MIB_TCPFULLUNDO = 37,
	LINUX_MIB_TCPPARTIALUNDO = 38,
	LINUX_MIB_TCPDSACKUNDO = 39,
	LINUX_MIB_TCPLOSSUNDO = 40,
	LINUX_MIB_TCPLOSTRETRANSMIT = 41,
	LINUX_MIB_TCPRENOFAILURES = 42,
	LINUX_MIB_TCPSACKFAILURES = 43,
	LINUX_MIB_TCPLOSSFAILURES = 44,
	LINUX_MIB_TCPFASTRETRANS = 45,
	LINUX_MIB_TCPFORWARDRETRANS = 46,
	LINUX_MIB_TCPSLOWSTARTRETRANS = 47,
	LINUX_MIB_TCPTIMEOUTS = 48,
	LINUX_MIB_TCPLOSSPROBES = 49,
	LINUX_MIB_TCPLOSSPROBERECOVERY = 50,
	LINUX_MIB_TCPRENORECOVERYFAIL = 51,
	LINUX_MIB_TCPSACKRECOVERYFAIL = 52,
	LINUX_MIB_TCPSCHEDULERFAILED = 53,
	LINUX_MIB_TCPRCVCOLLAPSED = 54,
	LINUX_MIB_TCPDSACKOLDSENT = 55,
	LINUX_MIB_TCPDSACKOFOSENT = 56,
	LINUX_MIB_TCPDSACKRECV = 57,
	LINUX_MIB_TCPDSACKOFORECV = 58,
	LINUX_MIB_TCPABORTONDATA = 59,
	LINUX_MIB_TCPABORTONCLOSE = 60,
	LINUX_MIB_TCPABORTONMEMORY = 61,
	LINUX_MIB_TCPABORTONTIMEOUT = 62,
	LINUX_MIB_TCPABORTONLINGER = 63,
	LINUX_MIB_TCPABORTFAILED = 64,
	LINUX_MIB_TCPMEMORYPRESSURES = 65,
	LINUX_MIB_TCPSACKDISCARD = 66,
	LINUX_MIB_TCPDSACKIGNOREDOLD = 67,
	LINUX_MIB_TCPDSACKIGNOREDNOUNDO = 68,
	LINUX_MIB_TCPSPURIOUSRTOS = 69,
	LINUX_MIB_TCPMD5NOTFOUND = 70,
	LINUX_MIB_TCPMD5UNEXPECTED = 71,
	LINUX_MIB_SACKSHIFTED = 72,
	LINUX_MIB_SACKMERGED = 73,
	LINUX_MIB_SACKSHIFTFALLBACK = 74,
	LINUX_MIB_TCPBACKLOGDROP = 75,
	LINUX_MIB_TCPMINTTLDROP = 76,
	LINUX_MIB_TCPDEFERACCEPTDROP = 77,
	LINUX_MIB_IPRPFILTER = 78,
	LINUX_MIB_TCPTIMEWAITOVERFLOW = 79,
	LINUX_MIB_TCPREQQFULLDOCOOKIES = 80,
	LINUX_MIB_TCPREQQFULLDROP = 81,
	LINUX_MIB_TCPRETRANSFAIL = 82,
	LINUX_MIB_TCPRCVCOALESCE = 83,
	LINUX_MIB_TCPOFOQUEUE = 84,
	LINUX_MIB_TCPOFODROP = 85,
	LINUX_MIB_TCPOFOMERGE = 86,
	LINUX_MIB_TCPCHALLENGEACK = 87,
	LINUX_MIB_TCPSYNCHALLENGE = 88,
	LINUX_MIB_TCPFASTOPENACTIVE = 89,
	LINUX_MIB_TCPFASTOPENACTIVEFAIL = 90,
	LINUX_MIB_TCPFASTOPENPASSIVE = 91,
	LINUX_MIB_TCPFASTOPENPASSIVEFAIL = 92,
	LINUX_MIB_TCPFASTOPENLISTENOVERFLOW = 93,
	LINUX_MIB_TCPFASTOPENCOOKIEREQD = 94,
	LINUX_MIB_TCPSPURIOUS_RTX_HOSTQUEUES = 95,
	LINUX_MIB_BUSYPOLLRXPACKETS = 96,
	LINUX_MIB_TCPAUTOCORKING = 97,
	LINUX_MIB_TCPFROMZEROWINDOWADV = 98,
	LINUX_MIB_TCPTOZEROWINDOWADV = 99,
	LINUX_MIB_TCPWANTZEROWINDOWADV = 100,
	LINUX_MIB_TCPSYNRETRANS = 101,
	LINUX_MIB_TCPORIGDATASENT = 102,
	LINUX_MIB_TCPHYSTARTTRAINDETECT = 103,
	LINUX_MIB_TCPHYSTARTTRAINCWND = 104,
	LINUX_MIB_TCPHYSTARTDELAYDETECT = 105,
	LINUX_MIB_TCPHYSTARTDELAYCWND = 106,
	LINUX_MIB_TCPACKSKIPPEDSYNRECV = 107,
	LINUX_MIB_TCPACKSKIPPEDPAWS = 108,
	LINUX_MIB_TCPACKSKIPPEDSEQ = 109,
	LINUX_MIB_TCPACKSKIPPEDFINWAIT2 = 110,
	LINUX_MIB_TCPACKSKIPPEDTIMEWAIT = 111,
	LINUX_MIB_TCPACKSKIPPEDCHALLENGE = 112,
	__LINUX_MIB_MAX = 113,
};

struct rtable___6;

struct dst_entry___22 {
	struct callback_head callback_head;
	struct dst_entry___22 *child;
	struct net_device___32 *dev;
	struct dst_ops___43 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___22 *path;
	struct dst_entry___22 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___33 *);
	union {
		int (*output)(struct sock___23 *, struct sk_buff___33 *);
		struct {
			int (*output)(struct sk_buff___33 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___22 *next;
		struct rtable___6 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___22;

struct neigh_parms___22;

struct neigh_ops___22;

struct neighbour___22 {
	struct neighbour___22 *next;
	struct neigh_table___22 *tbl;
	struct neigh_parms___22 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___31 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___22 *, struct sk_buff___33 *);
	const struct neigh_ops___22 *ops;
	struct callback_head rcu;
	struct net_device___32 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___43 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___33 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___33 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___44 *, struct dst_entry___22 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___33 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___33 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___164 {
	void * (*start)(struct seq_file___164 *, loff_t *);
	void (*stop)(struct seq_file___164 *, void *);
	void * (*next)(struct seq_file___164 *, void *, loff_t *);
	int (*show)(struct seq_file___164 *, void *);
};

struct dcbnl_rtnl_ops___30 {
	int (*ieee_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___32 *);
	u8 (*setstate)(struct net_device___32 *, u8);
	void (*getpermhwaddr)(struct net_device___32 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___32 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___32 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___32 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___32 *, int, u8 *);
	void (*setpfccfg)(struct net_device___32 *, int, u8);
	void (*getpfccfg)(struct net_device___32 *, int, u8 *);
	u8 (*setall)(struct net_device___32 *);
	u8 (*getcap)(struct net_device___32 *, int, u8 *);
	int (*getnumtcs)(struct net_device___32 *, int, u8 *);
	int (*setnumtcs)(struct net_device___32 *, int, u8);
	u8 (*getpfcstate)(struct net_device___32 *);
	void (*setpfcstate)(struct net_device___32 *, u8);
	void (*getbcncfg)(struct net_device___32 *, int, u32 *);
	void (*setbcncfg)(struct net_device___32 *, int, u32);
	void (*getbcnrp)(struct net_device___32 *, int, u8 *);
	void (*setbcnrp)(struct net_device___32 *, int, u8);
	u8 (*setapp)(struct net_device___32 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___32 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___32 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___32 *, int, u8);
	u8 (*getdcbx)(struct net_device___32 *);
	u8 (*setdcbx)(struct net_device___32 *, u8);
	int (*peer_getappinfo)(struct net_device___32 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___32 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___32 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___32 *, struct cee_pfc *);
};

struct cgroupfs_root___135;

struct cgroup___135 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___135 *parent;
	struct dentry___239 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___135 *subsys[11];
	struct cgroupfs_root___135 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___241 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___135 {
	struct super_block___239 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___135 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___74 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___239 *, struct file___239 *);
	ssize_t (*read)(struct cgroup___135 *, struct cftype___74 *, struct file___239 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___135 *, struct cftype___74 *);
	s64 (*read_s64)(struct cgroup___135 *, struct cftype___74 *);
	int (*read_map)(struct cgroup___135 *, struct cftype___74 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___135 *, struct cftype___74 *, struct seq_file___164 *);
	ssize_t (*write)(struct cgroup___135 *, struct cftype___74 *, struct file___239 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___135 *, struct cftype___74 *, u64);
	int (*write_s64)(struct cgroup___135 *, struct cftype___74 *, s64);
	int (*write_string)(struct cgroup___135 *, struct cftype___74 *, const char *);
	int (*trigger)(struct cgroup___135 *, unsigned int);
	int (*release)(struct inode___239 *, struct file___239 *);
	int (*register_event)(struct cgroup___135 *, struct cftype___74 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___135 *, struct cftype___74 *, struct eventfd_ctx *);
};

struct cftype_set___70 {
	struct list_head node;
	struct cftype___74 *cfts;
};

struct task_and_cgroup___70 {
	struct task_struct___240 *task;
	struct cgroup___135 *cgrp;
	struct css_set___135 *cg;
};

struct cgroup_taskset___70 {
	struct task_and_cgroup___70 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___135 *cur_cgrp;
};

struct cgroup_subsys___70 {
	struct cgroup_subsys_state___135 * (*css_alloc)(struct cgroup___135 *);
	int (*css_online)(struct cgroup___135 *);
	void (*css_offline)(struct cgroup___135 *);
	void (*css_free)(struct cgroup___135 *);
	int (*can_attach)(struct cgroup___135 *, struct cgroup_taskset___70 *);
	void (*cancel_attach)(struct cgroup___135 *, struct cgroup_taskset___70 *);
	void (*attach)(struct cgroup___135 *, struct cgroup_taskset___70 *);
	void (*fork)(struct task_struct___240 *);
	void (*exit)(struct cgroup___135 *, struct cgroup___135 *, struct task_struct___240 *);
	void (*bind)(struct cgroup___135 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___135 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___74 *base_cftypes;
	struct cftype_set___70 base_cftset;
	struct module___142 *module;
};

struct request_sock_ops___14;

struct request_sock___15 {
	struct sock_common___22 __req_common;
	struct request_sock___15 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___14 *rsk_ops;
	struct sock___23 *sk;
	u32 secid;
	u32 peer_secid;
};

struct scm_fp_list {
	short int count;
	short int max;
	struct file___239 *fp[253];
};

struct scm_cookie {
	struct pid___94 *pid;
	struct scm_fp_list *fp;
	struct scm_creds creds;
	u32 secid;
};

struct netlink_callback___32 {
	struct sk_buff___33 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___33 *, struct netlink_callback___32 *);
	int (*done)(struct netlink_callback___32 *);
	void *data;
	struct module___142 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___30 {
	int (*create)(struct sk_buff___33 *, struct net_device___32 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___33 *, unsigned char *);
	int (*rebuild)(struct sk_buff___33 *);
	int (*cache)(const struct neighbour___22 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___32 *, const unsigned char *);
};

struct napi_struct___30 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___30 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___32 *dev;
	struct sk_buff___33 *gro_list;
	struct sk_buff___33 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___30 {
	struct net_device___32 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___25 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___30 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___25 kobj;
	struct net_device___32 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___30 {
	int (*ndo_init)(struct net_device___32 *);
	void (*ndo_uninit)(struct net_device___32 *);
	int (*ndo_open)(struct net_device___32 *);
	int (*ndo_stop)(struct net_device___32 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___33 *, struct net_device___32 *);
	u16 (*ndo_select_queue)(struct net_device___32 *, struct sk_buff___33 *);
	void (*ndo_change_rx_flags)(struct net_device___32 *, int);
	void (*ndo_set_rx_mode)(struct net_device___32 *);
	int (*ndo_set_mac_address)(struct net_device___32 *, void *);
	int (*ndo_validate_addr)(struct net_device___32 *);
	int (*ndo_do_ioctl)(struct net_device___32 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___32 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___32 *, int);
	int (*ndo_neigh_setup)(struct net_device___32 *, struct neigh_parms___22 *);
	void (*ndo_tx_timeout)(struct net_device___32 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___32 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___32 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___32 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___32 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___32 *);
	int (*ndo_netpoll_setup)(struct net_device___32 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___32 *);
	int (*ndo_busy_poll)(struct napi_struct___30 *);
	int (*ndo_set_vf_mac)(struct net_device___32 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___32 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___32 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___32 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___32 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___32 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___32 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___32 *, int, struct sk_buff___33 *);
	int (*ndo_setup_tc)(struct net_device___32 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___32 *);
	int (*ndo_fcoe_disable)(struct net_device___32 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___32 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___32 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___32 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___32 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___32 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___32 *, const struct sk_buff___33 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___32 *, struct net_device___32 *);
	int (*ndo_del_slave)(struct net_device___32 *, struct net_device___32 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___22 *);
	void (*ndo_neigh_destroy)(struct neighbour___22 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___33 *, struct netlink_callback___32 *, struct net_device___32 *, int);
	int (*ndo_bridge_setlink)(struct net_device___32 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___33 *, u32, u32, struct net_device___32 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___32 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___32 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___32 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___32 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___32 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___32 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___33 *, struct net_device___32 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___32 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___32 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___32 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___22 {
	struct net___44 *net;
	struct net_device___32 *dev;
	struct neigh_parms___22 *next;
	int (*neigh_setup)(struct neighbour___22 *);
	void (*neigh_cleanup)(struct neighbour___22 *);
	struct neigh_table___22 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

typedef int (*iw_handler___2)(struct net_device___32 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___2 {
	const iw_handler___2 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___2 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___32 *);
};

struct libipw_device;

struct iw_spy_data;

struct iw_public_data {
	struct iw_spy_data *spy_data;
	struct libipw_device *libipw;
};

struct ifmcaddr6___11;

struct ifacaddr6___11;

struct inet6_dev___11 {
	struct net_device___32 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___11 *mc_list;
	struct ifmcaddr6___11 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___11 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___22 *nd_parms;
	struct inet6_dev___11 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___22 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___32 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___44 *, struct net_device___32 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___32 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___32 *, struct list_head *);
	size_t (*get_size)(const struct net_device___32 *);
	int (*fill_info)(struct sk_buff___33 *, const struct net_device___32 *);
	size_t (*get_xstats_size)(const struct net_device___32 *);
	int (*fill_xstats)(struct sk_buff___33 *, const struct net_device___32 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___44 * (*get_link_net)(const struct net_device___32 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___32 *, struct net_device___32 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___32 *, const struct net_device___32 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___33 *, const struct net_device___32 *, const struct net_device___32 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

typedef struct poll_table_struct___129 poll_table___37;

struct module_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___141 *, struct module_kobject___141 *, char *);
	ssize_t (*store)(struct module_attribute___141 *, struct module_kobject___141 *, const char *, size_t);
	void (*setup)(struct module___142 *, const char *);
	int (*test)(struct module___142 *);
	void (*free)(struct module___142 *);
};

struct trace_event_functions___73;

struct trace_event___73 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___73 *funcs;
};

struct ftrace_event_class___73;

struct ftrace_event_call___73 {
	struct list_head list;
	struct ftrace_event_class___73 *class;
	char *name;
	struct trace_event___73 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cpu_context___84;

struct pmu___84 {
	struct list_head entry;
	struct device___237 *dev;
	const struct attribute_group___199 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___84 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___84 *);
	void (*pmu_disable)(struct pmu___84 *);
	int (*event_init)(struct perf_event___84 *);
	int (*add)(struct perf_event___84 *, int);
	void (*del)(struct perf_event___84 *, int);
	void (*start)(struct perf_event___84 *, int);
	void (*stop)(struct perf_event___84 *, int);
	void (*read)(struct perf_event___84 *);
	void (*start_txn)(struct pmu___84 *);
	int (*commit_txn)(struct pmu___84 *);
	void (*cancel_txn)(struct pmu___84 *);
	int (*event_idx)(struct perf_event___84 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module___142 *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___84 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___84 *);
};

struct perf_cpu_context___84 {
	struct perf_event_context___84 ctx;
	struct perf_event_context___84 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___84 *unique_pmu;
	struct perf_cgroup___84 *cgrp;
};

struct perf_sample_data___8 {
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 addr;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	u64 period;
	union perf_mem_data_src data_src;
	struct perf_callchain_entry *callchain;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	union {
		struct perf_regs regs_user;
		struct {
			struct perf_regs_user regs_user;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	u64 stack_user_size;
	u64 weight;
	u64 txn;
	struct perf_regs regs_intr;
	struct pt_regs regs_user_copy;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___84 {
	struct cgroup_subsys_state___135 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___73 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___241 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___73)(struct trace_iterator___73 *, int, struct trace_event___73 *);

struct trace_event_functions___73 {
	trace_print_func___73 trace;
	trace_print_func___73 raw;
	trace_print_func___73 hex;
	trace_print_func___73 binary;
};

struct ftrace_event_class___73 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___73 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___73 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___73 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___73 *);
};

struct syscall_metadata___33 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct ftrace_event_call___73 *enter_event;
	struct ftrace_event_call___73 *exit_event;
};

struct iw_param {
	__s32 value;
	__u8 fixed;
	__u8 disabled;
	__u16 flags;
};

struct iw_point {
	void *pointer;
	__u16 length;
	__u16 flags;
};

struct iw_freq {
	__s32 m;
	__s16 e;
	__u8 i;
	__u8 flags;
};

struct iw_quality {
	__u8 qual;
	__u8 level;
	__u8 noise;
	__u8 updated;
};

struct iw_discarded {
	__u32 nwid;
	__u32 code;
	__u32 fragment;
	__u32 retries;
	__u32 misc;
};

struct iw_missed {
	__u32 beacon;
};

struct iw_statistics {
	__u16 status;
	struct iw_quality qual;
	struct iw_discarded discard;
	struct iw_missed miss;
};

union iwreq_data {
	char name[16];
	struct iw_point essid;
	struct iw_param nwid;
	struct iw_freq freq;
	struct iw_param sens;
	struct iw_param bitrate;
	struct iw_param txpower;
	struct iw_param rts;
	struct iw_param frag;
	__u32 mode;
	struct iw_param retry;
	struct iw_point encoding;
	struct iw_param power;
	struct iw_quality qual;
	struct sockaddr ap_addr;
	struct sockaddr addr;
	struct iw_param param;
	struct iw_point data;
};

struct iw_priv_args {
	__u32 cmd;
	__u16 set_args;
	__u16 get_args;
	char name[16];
};

struct compat_msghdr {
	compat_uptr_t msg_name;
	compat_int_t msg_namelen;
	compat_uptr_t msg_iov;
	compat_size_t msg_iovlen;
	compat_uptr_t msg_control;
	compat_size_t msg_controllen;
	compat_uint_t msg_flags;
};

struct compat_mmsghdr {
	struct compat_msghdr msg_hdr;
	compat_uint_t msg_len;
};

struct iw_request_info {
	__u16 cmd;
	__u16 flags;
};

struct iw_spy_data {
	int spy_number;
	u_char spy_address[48];
	struct iw_quality spy_stat[8];
	struct iw_quality spy_thr_low;
	struct iw_quality spy_thr_high;
	u_char spy_thr_under[8];
};

struct sk_filter___23 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___33 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___22;

struct neigh_hash_table___22;

struct neigh_table___22 {
	struct neigh_table___22 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___32 *, __u32 *);
	int (*constructor)(struct neighbour___22 *);
	int (*pconstructor)(struct pneigh_entry___22 *);
	void (*pdestructor)(struct pneigh_entry___22 *);
	void (*proxy_redo)(struct sk_buff___33 *);
	char *id;
	struct neigh_parms___22 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___31 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___22 *nht;
	struct pneigh_entry___22 **phash_buckets;
};

struct neigh_ops___22 {
	int family;
	void (*solicit)(struct neighbour___22 *, struct sk_buff___33 *);
	void (*error_report)(struct neighbour___22 *, struct sk_buff___33 *);
	int (*output)(struct neighbour___22 *, struct sk_buff___33 *);
	int (*connected_output)(struct neighbour___22 *, struct sk_buff___33 *);
};

struct pneigh_entry___22 {
	struct pneigh_entry___22 *next;
	struct net___44 *net;
	struct net_device___32 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___22 {
	struct neighbour___22 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___6 {
	struct dst_entry___22 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___12;

struct proto___22 {
	void (*close)(struct sock___23 *, long int);
	int (*connect)(struct sock___23 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___23 *, int);
	struct sock___23 * (*accept)(struct sock___23 *, int, int *);
	int (*ioctl)(struct sock___23 *, int, long unsigned int);
	int (*init)(struct sock___23 *);
	void (*destroy)(struct sock___23 *);
	void (*shutdown)(struct sock___23 *, int);
	int (*setsockopt)(struct sock___23 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___23 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___23 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___23 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___23 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___30 *, struct sock___23 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___30 *, struct sock___23 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___23 *, struct page___238 *, int, size_t, int);
	int (*bind)(struct sock___23 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___23 *, struct sk_buff___33 *);
	void (*release_cb)(struct sock___23 *);
	void (*mtu_reduced)(struct sock___23 *);
	void (*hash)(struct sock___23 *);
	void (*unhash)(struct sock___23 *);
	void (*rehash)(struct sock___23 *);
	int (*get_port)(struct sock___23 *, short unsigned int);
	void (*clear_sk)(struct sock___23 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___23 *);
	void (*enter_memory_pressure)(struct sock___23 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___222 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___14 *rsk_prot;
	struct timewait_sock_ops___12 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___142 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___70 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___22 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___22 {
	void (*enter_memory_pressure)(struct sock___23 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___14 {
	int family;
	int obj_size;
	struct kmem_cache___222 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___23 *, struct request_sock___15 *);
	void (*send_ack)(struct sock___23 *, struct sk_buff___33 *, struct request_sock___15 *);
	void (*send_reset)(struct sock___23 *, struct sk_buff___33 *);
	void (*destructor)(struct request_sock___15 *);
	void (*syn_ack_timeout)(struct sock___23 *, struct request_sock___15 *);
};

struct timewait_sock_ops___12 {
	struct kmem_cache___222 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___23 *, struct sock___23 *, void *);
	void (*twsk_destructor)(struct sock___23 *);
};

struct sock_iocb {
	struct list_head list;
	int flags;
	int size;
	struct socket___23 *sock;
	struct sock___23 *sk;
	struct scm_cookie *scm;
	struct msghdr *msg;
	struct msghdr async_msg;
	struct kiocb___30 *kiocb;
};

struct socket_alloc___2 {
	struct socket___23 socket;
	struct inode___239 vfs_inode;
};

struct in6_rtmsg {
	struct in6_addr rtmsg_dst;
	struct in6_addr rtmsg_src;
	struct in6_addr rtmsg_gateway;
	__u32 rtmsg_type;
	__u16 rtmsg_dst_len;
	__u16 rtmsg_src_len;
	__u32 rtmsg_metric;
	long unsigned int rtmsg_info;
	__u32 rtmsg_flags;
	int rtmsg_ifindex;
};

struct rtentry {
	long unsigned int rt_pad1;
	struct sockaddr rt_dst;
	struct sockaddr rt_gateway;
	struct sockaddr rt_genmask;
	short unsigned int rt_flags;
	short int rt_pad2;
	long unsigned int rt_pad3;
	void *rt_pad4;
	short int rt_metric;
	char *rt_dev;
	long unsigned int rt_mtu;
	long unsigned int rt_window;
	short unsigned int rt_irtt;
};

struct ifmcaddr6___11 {
	struct in6_addr mca_addr;
	struct inet6_dev___11 *idev;
	struct ifmcaddr6___11 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___11 {
	struct in6_addr aca_addr;
	struct inet6_dev___11 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___11 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct used_address {
	struct __kernel_sockaddr_storage name;
	unsigned int name_len;
	int: 32;
};

struct rtentry32 {
	u32 rt_pad1;
	struct sockaddr rt_dst;
	struct sockaddr rt_gateway;
	struct sockaddr rt_genmask;
	short unsigned int rt_flags;
	short int rt_pad2;
	u32 rt_pad3;
	unsigned char rt_tos;
	unsigned char rt_class;
	short int rt_pad4;
	short int rt_metric;
	u32 rt_dev;
	u32 rt_mtu;
	u32 rt_window;
	short unsigned int rt_irtt;
};

struct in6_rtmsg32 {
	struct in6_addr rtmsg_dst;
	struct in6_addr rtmsg_src;
	struct in6_addr rtmsg_gateway;
	u32 rtmsg_type;
	u16 rtmsg_dst_len;
	u16 rtmsg_src_len;
	u32 rtmsg_metric;
	u32 rtmsg_info;
	u32 rtmsg_flags;
	s32 rtmsg_ifindex;
};

struct linger {
	int l_onoff;
	int l_linger;
};

struct ucred {
	__u32 pid;
	__u32 uid;
	__u32 gid;
};

struct page___239;

typedef struct page___239 *pgtable_t___239;

struct address_space___240;

struct kmem_cache___223;

struct page___239 {
	long unsigned int flags;
	struct address_space___240 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___239 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___239 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___223 *slab_cache;
		struct page___239 *first_page;
	};
	long: 64;
};

struct task_struct___241;

struct pv_cpu_ops___241 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___241 *);
	void (*end_context_switch)(struct task_struct___241 *);
};

struct mutex___242 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___241 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___234 {
	struct page___239 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___248;

struct nsproxy___121;

struct signal_struct___241;

struct css_set___136;

struct task_struct___241 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___241 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___248 *mm;
	struct mm_struct___248 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___241 *real_parent;
	struct task_struct___241 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___241 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___241 = 0,
		VTIME_USER___241 = 1,
		VTIME_SYS___241 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___121 *nsproxy;
	struct signal_struct___241 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___136 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___242 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___234 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___248 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___248 *, struct mm_struct___248 *);
	void (*dup_mmap)(struct mm_struct___248 *, struct mm_struct___248 *);
	void (*exit_mmap)(struct mm_struct___248 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___248 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___248 *);
	void (*pgd_free)(struct mm_struct___248 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___248 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___248 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___248 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___248 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___248 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___248 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___248 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___248 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___248 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___248 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___248 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___242 lock;
	void *vdso;
} mm_context_t___242;

struct xol_area___239;

struct uprobes_state___239 {
	struct xol_area___239 *xol_area;
};

struct vm_area_struct___248;

struct file___240;

struct core_state___241;

struct mm_struct___248 {
	struct vm_area_struct___248 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___248 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___248 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___242 context;
	long unsigned int flags;
	struct core_state___241 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___241 *owner;
	struct file___240 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___239 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___143;

struct exec_domain___67 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___143 *module;
	struct exec_domain___67 *next;
};

struct kset___26;

struct kobj_type___26;

struct kobject___26 {
	const char *name;
	struct list_head entry;
	struct kobject___26 *parent;
	struct kset___26 *kset;
	struct kobj_type___26 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___142 {
	struct kobject___26 kobj;
	struct module___143 *mod;
	struct kobject___26 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___142;

struct module___143 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___142 mkobj;
	struct module_attribute___142 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___26 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___241 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___112 {
	struct task_struct___241 *task;
	struct exec_domain___67 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___241;

struct lruvec___241 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___241 *zone;
};

struct pglist_data___241;

struct zone___241 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___241 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___241 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___241 {
	struct zone___241 *zone;
	int zone_idx;
};

struct zonelist___241 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___241 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___241 {
	struct zone___241 node_zones[4];
	struct zonelist___241 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___241 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___164;

struct x86_io_apic_ops___164 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___164 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___164;

struct irq_data___164 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___164 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___238;

struct dev_pm_ops___238 {
	int (*prepare)(struct device___238 *);
	void (*complete)(struct device___238 *);
	int (*suspend)(struct device___238 *);
	int (*resume)(struct device___238 *);
	int (*freeze)(struct device___238 *);
	int (*thaw)(struct device___238 *);
	int (*poweroff)(struct device___238 *);
	int (*restore)(struct device___238 *);
	int (*suspend_late)(struct device___238 *);
	int (*resume_early)(struct device___238 *);
	int (*freeze_late)(struct device___238 *);
	int (*thaw_early)(struct device___238 *);
	int (*poweroff_late)(struct device___238 *);
	int (*restore_early)(struct device___238 *);
	int (*suspend_noirq)(struct device___238 *);
	int (*resume_noirq)(struct device___238 *);
	int (*freeze_noirq)(struct device___238 *);
	int (*thaw_noirq)(struct device___238 *);
	int (*poweroff_noirq)(struct device___238 *);
	int (*restore_noirq)(struct device___238 *);
	int (*runtime_suspend)(struct device___238 *);
	int (*runtime_resume)(struct device___238 *);
	int (*runtime_idle)(struct device___238 *);
};

struct dev_pm_qos___42;

struct dev_pm_info___42 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___42 *qos;
};

struct dma_map_ops___103;

struct dev_archdata___103 {
	struct dma_map_ops___103 *dma_ops;
	void *iommu;
};

struct device_type___238;

struct bus_type___238;

struct device_driver___238;

struct dev_pm_domain___238;

struct class___238;

struct attribute_group___200;

struct device_rh___238;

struct device___238 {
	struct device___238 *parent;
	struct device_private *p;
	struct kobject___26 kobj;
	const char *init_name;
	const struct device_type___238 *type;
	struct mutex___242 mutex;
	struct bus_type___238 *bus;
	struct device_driver___238 *driver;
	void *platform_data;
	struct dev_pm_info___42 power;
	struct dev_pm_domain___238 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___103 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___238 *class;
	const struct attribute_group___200 **groups;
	void (*release)(struct device___238 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___238 *device_rh;
};

struct dev_pm_qos_request___43;

struct dev_pm_qos___42 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___43 *latency_req;
	struct dev_pm_qos_request___43 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___43 *latency_tolerance_req;
};

struct dev_pm_info_rh___238 {
	void (*set_latency_tolerance)(struct device___238 *, s32);
};

struct dev_pm_domain___238 {
	struct dev_pm_ops___238 ops;
};

struct smp_ops___241 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___241 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___46;

struct ctl_node___46 {
	struct rb_node node;
	struct ctl_table_header___46 *header;
};

struct ctl_table_root___46;

struct ctl_table_set___46;

struct ctl_dir___46;

struct ctl_table_header___46 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___46 *root;
	struct ctl_table_set___46 *set;
	struct ctl_dir___46 *parent;
	struct ctl_node___46 *node;
};

struct ctl_dir___46 {
	struct ctl_table_header___46 header;
	struct rb_root root;
};

struct ctl_table_set___46 {
	int (*is_seen)(struct ctl_table_set___46 *);
	struct ctl_dir___46 dir;
};

struct ctl_table_root___46 {
	struct ctl_table_set___46 default_set;
	struct ctl_table_set___46 * (*lookup)(struct ctl_table_root___46 *, struct nsproxy___121 *);
	int (*permissions)(struct ctl_table_header___46 *, struct ctl_table *);
};

struct net___45;

struct nsproxy___121 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___45 *net_ns;
};

struct sock___24;

struct kobj_ns_type_operations___23 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___24 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___23;

struct sock_common___23 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___23 *skc_prot;
	struct net___45 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___34;

struct sk_buff_head___32 {
	struct sk_buff___34 *next;
	struct sk_buff___34 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___24;

struct socket_wq___23;

struct xfrm_policy___2;

struct dst_entry___23;

struct socket___24;

struct cg_proto___23;

struct sock___24 {
	struct sock_common___23 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___32 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___34 *head;
		struct sk_buff___34 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___24 *sk_filter;
	struct socket_wq___23 *sk_wq;
	struct sk_buff_head___32 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___2 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___23 *sk_rx_dst;
	struct dst_entry___23 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___32 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___32 sk_error_queue;
	struct proto___23 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___24 *sk_socket;
	void *sk_user_data;
	struct page_frag___234 sk_frag;
	struct sk_buff___34 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___23 *sk_cgrp;
	void (*sk_state_change)(struct sock___24 *);
	void (*sk_data_ready)(struct sock___24 *, int);
	void (*sk_write_space)(struct sock___24 *);
	void (*sk_error_report)(struct sock___24 *);
	int (*sk_backlog_rcv)(struct sock___24 *, struct sk_buff___34 *);
	void (*sk_destruct)(struct sock___24 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___202;

struct attribute_group___200 {
	const char *name;
	umode_t (*is_visible)(struct kobject___26 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___202 **bin_attrs;
};

struct bin_attribute___202 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___240 *, struct kobject___26 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___240 *, struct kobject___26 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	int (*mmap)(struct file___240 *, struct kobject___26 *, struct bin_attribute___202 *, struct vm_area_struct___248 *);
};

struct dentry___240;

struct path___240 {
	struct vfsmount *mnt;
	struct dentry___240 *dentry;
};

struct inode___240;

struct file_operations___240;

struct file___240 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___240 f_path;
	struct inode___240 *f_inode;
	const struct file_operations___240 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___240 *f_mapping;
	struct mutex___242 f_pos_lock;
};

struct vm_operations_struct___214;

struct vm_area_struct___248 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___248 *vm_next;
	struct vm_area_struct___248 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___248 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___214 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___240 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___26 {
	ssize_t (*show)(struct kobject___26 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___26 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___26 *, const struct attribute *);
};

struct kset_uevent_ops___26;

struct kset___26 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___26 kobj;
	const struct kset_uevent_ops___26 *uevent_ops;
};

struct kobj_type___26 {
	void (*release)(struct kobject___26 *);
	const struct sysfs_ops___26 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___26 *);
	const void * (*namespace)(struct kobject___26 *);
};

struct kset_uevent_ops___26 {
	int (* const filter)(struct kset___26 *, struct kobject___26 *);
	const char * (* const name)(struct kset___26 *, struct kobject___26 *);
	int (* const uevent)(struct kset___26 *, struct kobject___26 *, struct kobj_uevent_env *);
};

struct module_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___142 *, struct module_kobject___142 *, char *);
	ssize_t (*store)(struct module_attribute___142 *, struct module_kobject___142 *, const char *, size_t);
	void (*setup)(struct module___143 *, const char *);
	int (*test)(struct module___143 *);
	void (*free)(struct module___143 *);
};

struct dentry_operations___240;

struct super_block___240;

struct dentry___240 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___240 *d_parent;
	struct qstr d_name;
	struct inode___240 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___240 *d_op;
	struct super_block___240 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___240;

struct address_space___240 {
	struct inode___240 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___242 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___240 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___240;

struct file_lock___240;

struct dquot___240;

struct block_device___240;

struct inode___240 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___240 *i_op;
	struct super_block___240 *i_sb;
	struct address_space___240 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___242 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___240 *i_fop;
	struct file_lock___240 *i_flock;
	struct address_space___240 i_data;
	struct dquot___240 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___240 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___240 {
	int (*d_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_hash)(const struct dentry___240 *, struct qstr *);
	int (*d_compare)(const struct dentry___240 *, const struct dentry___240 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___240 *);
	void (*d_release)(struct dentry___240 *);
	void (*d_prune)(struct dentry___240 *);
	void (*d_iput)(struct dentry___240 *, struct inode___240 *);
	char * (*d_dname)(struct dentry___240 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___240 *);
	int (*d_manage)(struct dentry___240 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___240;

struct mem_dqinfo___240 {
	struct quota_format_type___240 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___240;

struct quota_info___240 {
	unsigned int flags;
	struct mutex___242 dqio_mutex;
	struct mutex___242 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___240 *files[2];
	struct mem_dqinfo___240 info[2];
	const struct quota_format_ops___240 *ops[2];
};

struct file_system_type___240;

struct super_operations___240;

struct dquot_operations___240;

struct quotactl_ops___240;

struct xattr_handler___137;

struct super_block___240 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___240 *s_type;
	const struct super_operations___240 *s_op;
	const struct dquot_operations___240 *dq_op;
	const struct quotactl_ops___240 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___240 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___137 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___240 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___240 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___242 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___240 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___240 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___240 *bd_inode;
	struct super_block___240 *bd_super;
	struct mutex___242 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___240 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___242 bd_fsfreeze_mutex;
};

struct cgroup___136;

struct cgroup_subsys_state___136 {
	struct cgroup___136 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___31;

typedef int kiocb_cancel_fn___31(struct kiocb___31 *, struct io_event *);

struct kiocb___31 {
	atomic_t ki_users;
	struct file___240 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___31 *ki_cancel;
	void (*ki_dtor)(struct kiocb___31 *);
	union {
		void *user;
		struct task_struct___241 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___240 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___240 *ia_file;
};

struct dquot___240 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___242 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___240 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___240 {
	int qf_fmt_id;
	const struct quota_format_ops___240 *qf_ops;
	struct module___143 *qf_owner;
	struct quota_format_type___240 *qf_next;
};

struct quota_format_ops___240 {
	int (*check_quota_file)(struct super_block___240 *, int);
	int (*read_file_info)(struct super_block___240 *, int);
	int (*write_file_info)(struct super_block___240 *, int);
	int (*free_file_info)(struct super_block___240 *, int);
	int (*read_dqblk)(struct dquot___240 *);
	int (*commit_dqblk)(struct dquot___240 *);
	int (*release_dqblk)(struct dquot___240 *);
};

struct dquot_operations___240 {
	int (*write_dquot)(struct dquot___240 *);
	struct dquot___240 * (*alloc_dquot)(struct super_block___240 *, int);
	void (*destroy_dquot)(struct dquot___240 *);
	int (*acquire_dquot)(struct dquot___240 *);
	int (*release_dquot)(struct dquot___240 *);
	int (*mark_dirty)(struct dquot___240 *);
	int (*write_info)(struct super_block___240 *, int);
	qsize_t * (*get_reserved_space)(struct inode___240 *);
};

struct quotactl_ops___240 {
	int (*quota_on)(struct super_block___240 *, int, int, struct path___240 *);
	int (*quota_on_meta)(struct super_block___240 *, int, int);
	int (*quota_off)(struct super_block___240 *, int);
	int (*quota_sync)(struct super_block___240 *, int);
	int (*get_info)(struct super_block___240 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___240 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___240 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___240 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___240 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___240 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___240 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___240 *, unsigned int);
};

struct address_space_operations___240 {
	int (*writepage)(struct page___239 *, struct writeback_control *);
	int (*readpage)(struct file___240 *, struct page___239 *);
	int (*writepages)(struct address_space___240 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___239 *);
	int (*readpages)(struct file___240 *, struct address_space___240 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___240 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___239 **, void **);
	int (*write_end)(struct file___240 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___239 *, void *);
	sector_t (*bmap)(struct address_space___240 *, sector_t);
	void (*invalidatepage)(struct page___239 *, long unsigned int);
	int (*releasepage)(struct page___239 *, gfp_t);
	void (*freepage)(struct page___239 *);
	ssize_t (*direct_IO)(int, struct kiocb___31 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___240 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___240 *, struct page___239 *, struct page___239 *, enum migrate_mode);
	int (*launder_page)(struct page___239 *);
	int (*is_partially_uptodate)(struct page___239 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___239 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___240 *, struct page___239 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___240 *, sector_t *);
	void (*swap_deactivate)(struct file___240 *);
	void (*invalidatepage_range)(struct page___239 *, unsigned int, unsigned int);
};

struct inode_operations___240 {
	struct dentry___240 * (*lookup)(struct inode___240 *, struct dentry___240 *, unsigned int);
	void * (*follow_link)(struct dentry___240 *, struct nameidata *);
	int (*permission)(struct inode___240 *, int);
	struct posix_acl * (*get_acl)(struct inode___240 *, int);
	int (*readlink)(struct dentry___240 *, char *, int);
	void (*put_link)(struct dentry___240 *, struct nameidata *, void *);
	int (*create)(struct inode___240 *, struct dentry___240 *, umode_t, bool);
	int (*link)(struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*unlink)(struct inode___240 *, struct dentry___240 *);
	int (*symlink)(struct inode___240 *, struct dentry___240 *, const char *);
	int (*mkdir)(struct inode___240 *, struct dentry___240 *, umode_t);
	int (*rmdir)(struct inode___240 *, struct dentry___240 *);
	int (*mknod)(struct inode___240 *, struct dentry___240 *, umode_t, dev_t);
	int (*rename)(struct inode___240 *, struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*setattr)(struct dentry___240 *, struct iattr___240 *);
	int (*getattr)(struct vfsmount *, struct dentry___240 *, struct kstat *);
	int (*setxattr)(struct dentry___240 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___240 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___240 *, char *, size_t);
	int (*removexattr)(struct dentry___240 *, const char *);
	int (*fiemap)(struct inode___240 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___240 *, struct timespec *, int);
	int (*atomic_open)(struct inode___240 *, struct dentry___240 *, struct file___240 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___130;

struct seq_file___165;

struct file_operations___240 {
	struct module___143 *owner;
	loff_t (*llseek)(struct file___240 *, loff_t, int);
	ssize_t (*read)(struct file___240 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___240 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___31 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___31 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___240 *, void *, filldir_t);
	unsigned int (*poll)(struct file___240 *, struct poll_table_struct___130 *);
	long int (*unlocked_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___240 *, struct vm_area_struct___248 *);
	int (*open)(struct inode___240 *, struct file___240 *);
	int (*flush)(struct file___240 *, fl_owner_t);
	int (*release)(struct inode___240 *, struct file___240 *);
	int (*fsync)(struct file___240 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___31 *, int);
	int (*fasync)(int, struct file___240 *, int);
	int (*lock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*sendpage)(struct file___240 *, struct page___239 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___240 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___240 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___240 *, long int, struct file_lock___240 **, void **);
		struct {
			int (*setlease)(struct file___240 *, long int, struct file_lock___240 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___240 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___165 *, struct file___240 *);
};

struct fasync_struct___240;

struct file_lock_operations___240;

struct lock_manager_operations___240;

struct file_lock___240 {
	struct file_lock___240 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___240 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___240 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___240 *fl_ops;
	const struct lock_manager_operations___240 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___240 {
	void (*fl_copy_lock)(struct file_lock___240 *, struct file_lock___240 *);
	void (*fl_release_private)(struct file_lock___240 *);
};

struct lock_manager_operations___240 {
	int (*lm_compare_owner)(struct file_lock___240 *, struct file_lock___240 *);
	long unsigned int (*lm_owner_key)(struct file_lock___240 *);
	void (*lm_notify)(struct file_lock___240 *);
	int (*lm_grant)(struct file_lock___240 *, struct file_lock___240 *, int);
	void (*lm_break)(struct file_lock___240 *);
	int (*lm_change)(struct file_lock___240 **, int);
};

struct fasync_struct___240 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___240 *fa_next;
	struct file___240 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___240 {
	const char *name;
	int fs_flags;
	struct dentry___240 * (*mount)(struct file_system_type___240 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___240 *);
	struct module___143 *owner;
	struct file_system_type___240 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___240 {
	struct inode___240 * (*alloc_inode)(struct super_block___240 *);
	void (*destroy_inode)(struct inode___240 *);
	void (*dirty_inode)(struct inode___240 *, int);
	int (*write_inode)(struct inode___240 *, struct writeback_control *);
	int (*drop_inode)(struct inode___240 *);
	void (*evict_inode)(struct inode___240 *);
	void (*put_super)(struct super_block___240 *);
	int (*sync_fs)(struct super_block___240 *, int);
	int (*freeze_fs)(struct super_block___240 *);
	int (*unfreeze_fs)(struct super_block___240 *);
	int (*statfs)(struct dentry___240 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___240 *, int *, char *);
	void (*umount_begin)(struct super_block___240 *);
	int (*show_options)(struct seq_file___165 *, struct dentry___240 *);
	int (*show_devname)(struct seq_file___165 *, struct dentry___240 *);
	int (*show_path)(struct seq_file___165 *, struct dentry___240 *);
	int (*show_stats)(struct seq_file___165 *, struct dentry___240 *);
	ssize_t (*quota_read)(struct super_block___240 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___240 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___240 *);
	int (*bdev_try_to_free_page)(struct super_block___240 *, struct page___239 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___240 *);
	void (*free_cached_objects)(struct super_block___240 *, int);
};

struct xattr_handler___137 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___240 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___240 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___240 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___132)(struct file___240 *, wait_queue_head_t *, struct poll_table_struct___130 *);

struct poll_table_struct___130 {
	poll_queue_proc___132 _qproc;
	long unsigned int _key;
};

struct seq_operations___165;

struct seq_file___165 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___242 lock;
	const struct seq_operations___165 *op;
	int poll_event;
	struct user_namespace___2 *user_ns;
	void *private;
};

struct seq_operations___165 {
	void * (*start)(struct seq_file___165 *, loff_t *);
	void (*stop)(struct seq_file___165 *, void *);
	void * (*next)(struct seq_file___165 *, void *, loff_t *);
	int (*show)(struct seq_file___165 *, void *);
};

struct xol_area___239 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___239 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___222;

struct memcg_cache_params___223;

struct kmem_cache___223 {
	struct kmem_cache_cpu___222 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___26 kobj;
	struct memcg_cache_params___223 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___210;

struct vm_operations_struct___214 {
	void (*open)(struct vm_area_struct___248 *);
	void (*close)(struct vm_area_struct___248 *);
	int (*fault)(struct vm_area_struct___248 *, struct vm_fault___210 *);
	int (*page_mkwrite)(struct vm_area_struct___248 *, struct vm_fault___210 *);
	int (*access)(struct vm_area_struct___248 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___248 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___248 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___248 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___248 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___241 {
	struct task_struct___241 *task;
	struct core_thread___241 *next;
};

struct core_state___241 {
	atomic_t nr_threads;
	struct core_thread___241 dumper;
	struct completion startup;
};

struct signal_struct___241 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___241 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___241 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___242 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___136 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___136 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___23 {
	wait_queue_head_t wait;
	struct fasync_struct___240 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___23;

struct socket___24 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___23 *wq;
	struct file___240 *file;
	struct sock___24 *sk;
	const struct proto_ops___23 *ops;
};

struct proto_ops___23 {
	int family;
	struct module___143 *owner;
	int (*release)(struct socket___24 *);
	int (*bind)(struct socket___24 *, struct sockaddr *, int);
	int (*connect)(struct socket___24 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___24 *, struct socket___24 *);
	int (*accept)(struct socket___24 *, struct socket___24 *, int);
	int (*getname)(struct socket___24 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___240 *, struct socket___24 *, struct poll_table_struct___130 *);
	int (*ioctl)(struct socket___24 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___24 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___24 *, int);
	int (*shutdown)(struct socket___24 *, int);
	int (*setsockopt)(struct socket___24 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___24 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___24 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___24 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___31 *, struct socket___24 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___31 *, struct socket___24 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___240 *, struct socket___24 *, struct vm_area_struct___248 *);
	ssize_t (*sendpage)(struct socket___24 *, struct page___239 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___24 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___24 *, int);
		struct {
			void (*set_peek_off)(struct sock___24 *, int);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
};

struct prot_inuse___2;

struct netns_core___43 {
	struct ctl_table_header___46 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse___2 *inuse;
};

struct netns_packet___43 {
	struct mutex___242 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___43 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___46 *ctl;
};

struct netns_ipv4___43 {
	struct ctl_table_header___46 *forw_hdr;
	struct ctl_table_header___46 *frags_hdr;
	struct ctl_table_header___46 *ipv4_hdr;
	struct ctl_table_header___46 *route_hdr;
	struct ctl_table_header___46 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___24 *fibnl;
	struct sock___24 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___43 {
	struct ctl_table_header___46 *hdr;
	struct ctl_table_header___46 *route_hdr;
	struct ctl_table_header___46 *icmp_hdr;
	struct ctl_table_header___46 *frags_hdr;
	struct ctl_table_header___46 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___33;

struct neighbour___23;

struct dst_ops___44 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___44 *);
	struct dst_entry___23 * (*check)(struct dst_entry___23 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___23 *);
	unsigned int (*mtu)(const struct dst_entry___23 *);
	u32 * (*cow_metrics)(struct dst_entry___23 *, long unsigned int);
	void (*destroy)(struct dst_entry___23 *);
	void (*ifdown)(struct dst_entry___23 *, struct net_device___33 *, int);
	struct dst_entry___23 * (*negative_advice)(struct dst_entry___23 *);
	void (*link_failure)(struct sk_buff___34 *);
	void (*update_pmtu)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___34 *, u32);
	void (*redirect)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___34 *);
	int (*local_out)(struct sk_buff___34 *);
	struct neighbour___23 * (*neigh_lookup)(const struct dst_entry___23 *, struct sk_buff___34 *, const void *);
	struct kmem_cache___223 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___2;

struct fib6_table___2;

struct netns_ipv6___44 {
	struct netns_sysctl_ipv6___43 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___2 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___2 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___44 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___2 *ip6_prohibit_entry;
	struct rt6_info___2 *ip6_blk_hole_entry;
	struct fib6_table___2 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___24 **icmp_sk;
	struct sock___24 *ndisc_sk;
	struct sock___24 *tcp_sk;
	struct sock___24 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___43 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___46 *sysctl_header;
	struct sock___24 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___23 {
	struct sock___24 *v4_ctl_sk;
	struct sock___24 *v6_ctl_sk;
};

struct netns_nf___43 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___46 *nf_log_dir_header;
};

struct nf_proto_net___43 {
	struct ctl_table_header___46 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___43 {
	struct nf_proto_net___43 pn;
	unsigned int timeout;
};

struct nf_tcp_net___43 {
	struct nf_proto_net___43 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___43 {
	struct nf_proto_net___43 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___43 {
	struct nf_proto_net___43 pn;
	unsigned int timeout;
};

struct nf_ip_net___43 {
	struct nf_generic_net___43 generic;
	struct nf_tcp_net___43 tcp;
	struct nf_udp_net___43 udp;
	struct nf_icmp_net___43 icmp;
	struct nf_icmp_net___43 icmpv6;
};

struct netns_ct___43 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___46 *sysctl_header;
	struct ctl_table_header___46 *acct_sysctl_header;
	struct ctl_table_header___46 *tstamp_sysctl_header;
	struct ctl_table_header___46 *event_sysctl_header;
	struct ctl_table_header___46 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___223 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___43 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___43 {
	struct netns_sysctl_ipv6___43 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___44 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___24 *nlsk;
	struct sock___24 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___46 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___44 xfrm4_dst_ops;
	struct dst_ops___44 xfrm6_dst_ops;
};

struct net___45 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace___2 *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___46 sysctls;
	struct sock___24 *rtnl;
	struct sock___24 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___33 *loopback_dev;
	struct netns_core___43 core;
	struct netns_mib mib;
	struct netns_packet___43 packet;
	struct netns_unix___43 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___43 ipv4;
	struct netns_ipv6___44 ipv6;
	struct netns_sctp___43 sctp;
	struct netns_dccp___23 dccp;
	struct netns_nf___43 nf;
	struct netns_xt xt;
	struct netns_ct___43 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___43 nf_frag;
	struct sock___24 *nfnl;
	struct sock___24 *nfnl_stash;
	struct sk_buff_head___32 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___44 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___24 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___24 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___242 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___242 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___210 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___239 *page;
};

struct kmem_cache_cpu___222 {
	void **freelist;
	long unsigned int tid;
	struct page___239 *page;
	struct page___239 *partial;
};

struct memcg_cache_params___223 {
	bool is_root_cache;
	union {
		struct kmem_cache___223 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___223 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct irq_chip___164 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___164 *);
	void (*irq_shutdown)(struct irq_data___164 *);
	void (*irq_enable)(struct irq_data___164 *);
	void (*irq_disable)(struct irq_data___164 *);
	void (*irq_ack)(struct irq_data___164 *);
	void (*irq_mask)(struct irq_data___164 *);
	void (*irq_mask_ack)(struct irq_data___164 *);
	void (*irq_unmask)(struct irq_data___164 *);
	void (*irq_eoi)(struct irq_data___164 *);
	int (*irq_set_affinity)(struct irq_data___164 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___164 *);
	int (*irq_set_type)(struct irq_data___164 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___164 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___164 *);
	void (*irq_bus_sync_unlock)(struct irq_data___164 *);
	void (*irq_cpu_online)(struct irq_data___164 *);
	void (*irq_cpu_offline)(struct irq_data___164 *);
	void (*irq_suspend)(struct irq_data___164 *);
	void (*irq_resume)(struct irq_data___164 *);
	void (*irq_pm_shutdown)(struct irq_data___164 *);
	void (*irq_print_chip)(struct irq_data___164 *, struct seq_file___165 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___164 *, void *);
	long unsigned int flags;
};

typedef struct poll_table_struct___130 poll_table___38;

struct dma_map_ops___103 {
	void * (*alloc)(struct device___238 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___238 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___238 *, struct vm_area_struct___248 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___238 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___238 *, struct page___239 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___238 *, dma_addr_t);
	int (*dma_supported)(struct device___238 *, u64);
	int (*set_dma_mask)(struct device___238 *, u64);
	int is_phys;
};

struct bus_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___238 *, char *);
	ssize_t (*store)(struct bus_type___238 *, const char *, size_t);
};

struct device_attribute___238;

struct driver_attribute___238;

struct bus_type___238 {
	const char *name;
	const char *dev_name;
	struct device___238 *dev_root;
	struct bus_attribute___238 *bus_attrs;
	struct device_attribute___238 *dev_attrs;
	struct driver_attribute___238 *drv_attrs;
	const struct attribute_group___200 **bus_groups;
	const struct attribute_group___200 **dev_groups;
	const struct attribute_group___200 **drv_groups;
	int (*match)(struct device___238 *, struct device_driver___238 *);
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	int (*probe)(struct device___238 *);
	int (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*online)(struct device___238 *);
	int (*offline)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct device___238 *, struct device_attribute___238 *, char *);
	ssize_t (*store)(struct device___238 *, struct device_attribute___238 *, const char *, size_t);
};

struct driver_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___238 *, char *);
	ssize_t (*store)(struct device_driver___238 *, const char *, size_t);
};

struct device_driver___238 {
	const char *name;
	struct bus_type___238 *bus;
	struct module___143 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___238 *);
	int (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	const struct attribute_group___200 **groups;
	const struct dev_pm_ops___238 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___238 {
	const char *name;
	const struct attribute_group___200 **groups;
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
};

struct class_attribute___238;

struct class___238 {
	const char *name;
	struct module___143 *owner;
	struct class_attribute___238 *class_attrs;
	struct device_attribute___238 *dev_attrs;
	const struct attribute_group___200 **dev_groups;
	struct bin_attribute___202 *dev_bin_attrs;
	struct kobject___26 *dev_kobj;
	int (*dev_uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *);
	void (*class_release)(struct class___238 *);
	void (*dev_release)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
	struct subsys_private *p;
};

struct class_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct class___238 *, struct class_attribute___238 *, char *);
	ssize_t (*store)(struct class___238 *, struct class_attribute___238 *, const char *, size_t);
	const void * (*namespace)(struct class___238 *, const struct class_attribute___238 *);
};

struct device_rh___238 {
	struct dev_pm_info_rh___238 power;
};

struct nf_bridge_info___31 {
	atomic_t use;
	unsigned int mask;
	struct net_device___33 *physindev;
	struct net_device___33 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___31(struct sk_buff___34 **);

struct net_device_ops___31;

struct ethtool_ops___31;

struct header_ops___31;

struct inet6_dev___12;

struct netdev_rx_queue___31;

struct netdev_queue___31;

struct rtnl_link_ops___23;

struct dcbnl_rtnl_ops___31;

struct net_device___33 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___31 *netdev_ops;
	const struct ethtool_ops___31 *ethtool_ops;
	const struct header_ops___31 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___26 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___12 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___31 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___31 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___31 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___31 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___31 = 0,
		NETREG_REGISTERED___31 = 1,
		NETREG_UNREGISTERING___31 = 2,
		NETREG_UNREGISTERED___31 = 3,
		NETREG_RELEASED___31 = 4,
		NETREG_DUMMY___31 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___31 = 0,
		RTNL_LINK_INITIALIZING___31 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___33 *);
	struct netpoll_info *npinfo;
	struct net___45 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___238 dev;
	const struct attribute_group___200 *sysfs_groups[4];
	const struct rtnl_link_ops___23 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___31 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___2;

struct sk_buff___34 {
	struct sk_buff___34 *next;
	struct sk_buff___34 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___24 *sk;
	struct net_device___33 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___2 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___34 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___31 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___2 {
	struct {
		struct page___239 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___2 skb_frag_t___2;

struct skb_shared_info___2 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___34 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___2 frags[17];
};

enum {
	SKB_GSO_TCPV4 = 1,
	SKB_GSO_UDP = 2,
	SKB_GSO_DODGY = 4,
	SKB_GSO_TCP_ECN = 8,
	SKB_GSO_TCPV6 = 16,
	SKB_GSO_FCOE = 32,
	SKB_GSO_GRE = 64,
	SKB_GSO_IPIP = 128,
	SKB_GSO_SIT = 256,
	SKB_GSO_UDP_TUNNEL = 512,
	SKB_GSO_MPLS = 1024,
	SKB_GSO_GRE_CSUM = 2048,
	SKB_GSO_UDP_TUNNEL_CSUM = 4096,
	SKB_GSO_TUNNEL_REMCSUM = 8192,
};

struct xfrm_state___2;

struct sec_path___2 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___2 *xvec[6];
};

struct dev_pm_qos_request___43 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___238 *dev;
};

struct ethtool_ops___31 {
	int (*get_settings)(struct net_device___33 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___33 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___33 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___33 *);
	void (*get_regs)(struct net_device___33 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___33 *);
	void (*set_msglevel)(struct net_device___33 *, u32);
	int (*nway_reset)(struct net_device___33 *);
	u32 (*get_link)(struct net_device___33 *);
	int (*get_eeprom_len)(struct net_device___33 *);
	int (*get_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___33 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___33 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___33 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___33 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___33 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___33 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___33 *);
	void (*complete)(struct net_device___33 *);
	u32 (*get_priv_flags)(struct net_device___33 *);
	int (*set_priv_flags)(struct net_device___33 *, u32);
	int (*get_sset_count)(struct net_device___33 *, int);
	int (*get_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___33 *, struct ethtool_flash *);
	int (*reset)(struct net_device___33 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___33 *);
	int (*get_rxfh_indir)(struct net_device___33 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___33 *, const u32 *);
	void (*get_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___33 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___33 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___33 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___33 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___33 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___33 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___33 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___33 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct prot_inuse___2 {
	int val[64];
};

struct rtable___7;

struct dst_entry___23 {
	struct callback_head callback_head;
	struct dst_entry___23 *child;
	struct net_device___33 *dev;
	struct dst_ops___44 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___23 *path;
	struct dst_entry___23 *from;
	struct xfrm_state___2 *xfrm;
	int (*input)(struct sk_buff___34 *);
	union {
		int (*output)(struct sock___24 *, struct sk_buff___34 *);
		struct {
			int (*output)(struct sk_buff___34 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___23 *next;
		struct rtable___7 *rt_next;
		struct rt6_info___2 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___23;

struct neigh_parms___23;

struct neigh_ops___23;

struct neighbour___23 {
	struct neighbour___23 *next;
	struct neigh_table___23 *tbl;
	struct neigh_parms___23 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___32 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___23 *, struct sk_buff___34 *);
	const struct neigh_ops___23 *ops;
	struct callback_head rcu;
	struct net_device___33 *dev;
	u8 primary_key[0];
};

struct fib6_node___2;

struct rt6_info___2 {
	struct dst_entry___23 dst;
	struct fib6_table___2 *rt6i_table;
	struct fib6_node___2 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___12 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___2 {
	struct fib6_node___2 *parent;
	struct fib6_node___2 *left;
	struct fib6_node___2 *right;
	struct rt6_info___2 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___2 *rr_ptr;
};

struct fib6_table___2 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___2 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___44 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___34 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___34 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___45 *, struct dst_entry___23 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___34 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___34 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_net_private___2 {
	struct net___45 *net;
};

struct pernet_operations___4 {
	struct list_head list;
	int (*init)(struct net___45 *);
	void (*exit)(struct net___45 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___31 {
	int (*ieee_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___33 *);
	u8 (*setstate)(struct net_device___33 *, u8);
	void (*getpermhwaddr)(struct net_device___33 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___33 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___33 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___33 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___33 *, int, u8 *);
	void (*setpfccfg)(struct net_device___33 *, int, u8);
	void (*getpfccfg)(struct net_device___33 *, int, u8 *);
	u8 (*setall)(struct net_device___33 *);
	u8 (*getcap)(struct net_device___33 *, int, u8 *);
	int (*getnumtcs)(struct net_device___33 *, int, u8 *);
	int (*setnumtcs)(struct net_device___33 *, int, u8);
	u8 (*getpfcstate)(struct net_device___33 *);
	void (*setpfcstate)(struct net_device___33 *, u8);
	void (*getbcncfg)(struct net_device___33 *, int, u32 *);
	void (*setbcncfg)(struct net_device___33 *, int, u32);
	void (*getbcnrp)(struct net_device___33 *, int, u8 *);
	void (*setbcnrp)(struct net_device___33 *, int, u8);
	u8 (*setapp)(struct net_device___33 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___33 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___33 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___33 *, int, u8);
	u8 (*getdcbx)(struct net_device___33 *);
	u8 (*setdcbx)(struct net_device___33 *, u8);
	int (*peer_getappinfo)(struct net_device___33 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___33 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___33 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___33 *, struct cee_pfc *);
};

struct cgroupfs_root___136;

struct cgroup___136 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___136 *parent;
	struct dentry___240 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___136 *subsys[11];
	struct cgroupfs_root___136 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___242 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___136 {
	struct super_block___240 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___136 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___75 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___240 *, struct file___240 *);
	ssize_t (*read)(struct cgroup___136 *, struct cftype___75 *, struct file___240 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___136 *, struct cftype___75 *);
	s64 (*read_s64)(struct cgroup___136 *, struct cftype___75 *);
	int (*read_map)(struct cgroup___136 *, struct cftype___75 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___136 *, struct cftype___75 *, struct seq_file___165 *);
	ssize_t (*write)(struct cgroup___136 *, struct cftype___75 *, struct file___240 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___136 *, struct cftype___75 *, u64);
	int (*write_s64)(struct cgroup___136 *, struct cftype___75 *, s64);
	int (*write_string)(struct cgroup___136 *, struct cftype___75 *, const char *);
	int (*trigger)(struct cgroup___136 *, unsigned int);
	int (*release)(struct inode___240 *, struct file___240 *);
	int (*register_event)(struct cgroup___136 *, struct cftype___75 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___136 *, struct cftype___75 *, struct eventfd_ctx *);
};

struct cftype_set___71 {
	struct list_head node;
	struct cftype___75 *cfts;
};

struct task_and_cgroup___71 {
	struct task_struct___241 *task;
	struct cgroup___136 *cgrp;
	struct css_set___136 *cg;
};

struct cgroup_taskset___71 {
	struct task_and_cgroup___71 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___136 *cur_cgrp;
};

struct cgroup_subsys___71 {
	struct cgroup_subsys_state___136 * (*css_alloc)(struct cgroup___136 *);
	int (*css_online)(struct cgroup___136 *);
	void (*css_offline)(struct cgroup___136 *);
	void (*css_free)(struct cgroup___136 *);
	int (*can_attach)(struct cgroup___136 *, struct cgroup_taskset___71 *);
	void (*cancel_attach)(struct cgroup___136 *, struct cgroup_taskset___71 *);
	void (*attach)(struct cgroup___136 *, struct cgroup_taskset___71 *);
	void (*fork)(struct task_struct___241 *);
	void (*exit)(struct cgroup___136 *, struct cgroup___136 *, struct task_struct___241 *);
	void (*bind)(struct cgroup___136 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___136 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___75 *base_cftypes;
	struct cftype_set___71 base_cftset;
	struct module___143 *module;
};

struct request_sock_ops___15;

struct request_sock___16 {
	struct sock_common___23 __req_common;
	struct request_sock___16 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___15 *rsk_ops;
	struct sock___24 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___2;

struct xfrm_type___2;

struct xfrm_mode___2;

struct xfrm_state___2 {
	struct net___45 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___2 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___2 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___2 *type;
	struct xfrm_mode___2 *inner_mode;
	struct xfrm_mode___2 *inner_mode_iaf;
	struct xfrm_mode___2 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___2 {
	struct sk_buff_head___32 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___2 {
	struct net___45 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___2 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___33 {
	struct sk_buff___34 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___34 *, struct netlink_callback___33 *);
	int (*done)(struct netlink_callback___33 *);
	void *data;
	struct module___143 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___31 {
	int (*create)(struct sk_buff___34 *, struct net_device___33 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___34 *, unsigned char *);
	int (*rebuild)(struct sk_buff___34 *);
	int (*cache)(const struct neighbour___23 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___33 *, const unsigned char *);
};

struct napi_struct___31 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___31 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___33 *dev;
	struct sk_buff___34 *gro_list;
	struct sk_buff___34 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___31 {
	struct net_device___33 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___26 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___31 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___26 kobj;
	struct net_device___33 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___31 {
	int (*ndo_init)(struct net_device___33 *);
	void (*ndo_uninit)(struct net_device___33 *);
	int (*ndo_open)(struct net_device___33 *);
	int (*ndo_stop)(struct net_device___33 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___34 *, struct net_device___33 *);
	u16 (*ndo_select_queue)(struct net_device___33 *, struct sk_buff___34 *);
	void (*ndo_change_rx_flags)(struct net_device___33 *, int);
	void (*ndo_set_rx_mode)(struct net_device___33 *);
	int (*ndo_set_mac_address)(struct net_device___33 *, void *);
	int (*ndo_validate_addr)(struct net_device___33 *);
	int (*ndo_do_ioctl)(struct net_device___33 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___33 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___33 *, int);
	int (*ndo_neigh_setup)(struct net_device___33 *, struct neigh_parms___23 *);
	void (*ndo_tx_timeout)(struct net_device___33 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___33 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___33 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___33 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___33 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___33 *);
	int (*ndo_netpoll_setup)(struct net_device___33 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___33 *);
	int (*ndo_busy_poll)(struct napi_struct___31 *);
	int (*ndo_set_vf_mac)(struct net_device___33 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___33 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___33 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___33 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___33 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___33 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___33 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___33 *, int, struct sk_buff___34 *);
	int (*ndo_setup_tc)(struct net_device___33 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___33 *);
	int (*ndo_fcoe_disable)(struct net_device___33 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___33 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___33 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___33 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___33 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___33 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___33 *, const struct sk_buff___34 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___33 *, struct net_device___33 *);
	int (*ndo_del_slave)(struct net_device___33 *, struct net_device___33 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___23 *);
	void (*ndo_neigh_destroy)(struct neighbour___23 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___34 *, struct netlink_callback___33 *, struct net_device___33 *, int);
	int (*ndo_bridge_setlink)(struct net_device___33 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___34 *, u32, u32, struct net_device___33 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___33 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___33 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___33 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___33 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___33 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___33 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___34 *, struct net_device___33 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___33 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___33 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___33 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___23 {
	struct net___45 *net;
	struct net_device___33 *dev;
	struct neigh_parms___23 *next;
	int (*neigh_setup)(struct neighbour___23 *);
	void (*neigh_cleanup)(struct neighbour___23 *);
	struct neigh_table___23 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___12;

struct ifacaddr6___12;

struct inet6_dev___12 {
	struct net_device___33 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___12 *mc_list;
	struct ifmcaddr6___12 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___12 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___23 *nd_parms;
	struct inet6_dev___12 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___23 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___33 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___45 *, struct net_device___33 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___33 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___33 *, struct list_head *);
	size_t (*get_size)(const struct net_device___33 *);
	int (*fill_info)(struct sk_buff___34 *, const struct net_device___33 *);
	size_t (*get_xstats_size)(const struct net_device___33 *);
	int (*fill_xstats)(struct sk_buff___34 *, const struct net_device___33 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___45 * (*get_link_net)(const struct net_device___33 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___33 *, struct net_device___33 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___33 *, const struct net_device___33 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___34 *, const struct net_device___33 *, const struct net_device___33 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	UNDER_LIMIT = 0,
	SOFT_LIMIT = 1,
	OVER_LIMIT = 2,
};

struct sk_filter___24 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___34 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___23;

struct neigh_hash_table___23;

struct neigh_table___23 {
	struct neigh_table___23 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___33 *, __u32 *);
	int (*constructor)(struct neighbour___23 *);
	int (*pconstructor)(struct pneigh_entry___23 *);
	void (*pdestructor)(struct pneigh_entry___23 *);
	void (*proxy_redo)(struct sk_buff___34 *);
	char *id;
	struct neigh_parms___23 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___32 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___23 *nht;
	struct pneigh_entry___23 **phash_buckets;
};

struct neigh_ops___23 {
	int family;
	void (*solicit)(struct neighbour___23 *, struct sk_buff___34 *);
	void (*error_report)(struct neighbour___23 *, struct sk_buff___34 *);
	int (*output)(struct neighbour___23 *, struct sk_buff___34 *);
	int (*connected_output)(struct neighbour___23 *, struct sk_buff___34 *);
};

struct pneigh_entry___23 {
	struct pneigh_entry___23 *next;
	struct net___45 *net;
	struct net_device___33 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___23 {
	struct neighbour___23 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___7 {
	struct dst_entry___23 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___13;

struct inet_hashinfo___2;

struct proto___23 {
	void (*close)(struct sock___24 *, long int);
	int (*connect)(struct sock___24 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___24 *, int);
	struct sock___24 * (*accept)(struct sock___24 *, int, int *);
	int (*ioctl)(struct sock___24 *, int, long unsigned int);
	int (*init)(struct sock___24 *);
	void (*destroy)(struct sock___24 *);
	void (*shutdown)(struct sock___24 *, int);
	int (*setsockopt)(struct sock___24 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___24 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___24 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___24 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___24 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___31 *, struct sock___24 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___31 *, struct sock___24 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___24 *, struct page___239 *, int, size_t, int);
	int (*bind)(struct sock___24 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___24 *, struct sk_buff___34 *);
	void (*release_cb)(struct sock___24 *);
	void (*mtu_reduced)(struct sock___24 *);
	void (*hash)(struct sock___24 *);
	void (*unhash)(struct sock___24 *);
	void (*rehash)(struct sock___24 *);
	int (*get_port)(struct sock___24 *, short unsigned int);
	void (*clear_sk)(struct sock___24 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___24 *);
	void (*enter_memory_pressure)(struct sock___24 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___223 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___15 *rsk_prot;
	struct timewait_sock_ops___13 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___143 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___71 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___23 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___23 {
	void (*enter_memory_pressure)(struct sock___24 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___2 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___223 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___15 {
	int family;
	int obj_size;
	struct kmem_cache___223 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___24 *, struct request_sock___16 *);
	void (*send_ack)(struct sock___24 *, struct sk_buff___34 *, struct request_sock___16 *);
	void (*send_reset)(struct sock___24 *, struct sk_buff___34 *);
	void (*destructor)(struct request_sock___16 *);
	void (*syn_ack_timeout)(struct sock___24 *, struct request_sock___16 *);
};

struct timewait_sock_ops___13 {
	struct kmem_cache___223 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___24 *, struct sock___24 *, void *);
	void (*twsk_destructor)(struct sock___24 *);
};

struct socket_alloc___3 {
	struct socket___24 socket;
	struct inode___240 vfs_inode;
};

struct inet_cork___2 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___23 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___2 {
	struct inet_cork___2 base;
	struct flowi fl;
};

struct ipv6_pinfo___2;

struct inet_sock___2 {
	struct sock___24 sk;
	struct ipv6_pinfo___2 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___2 cork;
};

struct ipv6_fl_socklist___2;

struct ipv6_pinfo___2 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___2 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___34 *pktoptions;
	struct sk_buff___34 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket {
	struct net___45 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_timewait_sock {
	struct sock_common___23 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket *tw_tb;
	struct hlist_node tw_death_node;
};

struct ip6_flowlabel___2;

struct ipv6_fl_socklist___2 {
	struct ipv6_fl_socklist___2 *next;
	struct ip6_flowlabel___2 *fl;
	struct callback_head rcu;
};

enum {
	SOF_TIMESTAMPING_TX_HARDWARE = 1,
	SOF_TIMESTAMPING_TX_SOFTWARE = 2,
	SOF_TIMESTAMPING_RX_HARDWARE = 4,
	SOF_TIMESTAMPING_RX_SOFTWARE = 8,
	SOF_TIMESTAMPING_SOFTWARE = 16,
	SOF_TIMESTAMPING_SYS_HARDWARE = 32,
	SOF_TIMESTAMPING_RAW_HARDWARE = 64,
	SOF_TIMESTAMPING_MASK = 127,
};

struct ifmcaddr6___12 {
	struct in6_addr mca_addr;
	struct inet6_dev___12 *idev;
	struct ifmcaddr6___12 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___12 {
	struct in6_addr aca_addr;
	struct inet6_dev___12 *aca_idev;
	struct rt6_info___2 *aca_rt;
	struct ifacaddr6___12 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___2 {
	struct ip6_flowlabel___2 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___45 *fl_net;
};

struct xfrm_replay___2 {
	void (*advance)(struct xfrm_state___2 *, __be32);
	int (*check)(struct xfrm_state___2 *, struct sk_buff___34 *, __be32);
	int (*recheck)(struct xfrm_state___2 *, struct sk_buff___34 *, __be32);
	void (*notify)(struct xfrm_state___2 *, int);
	int (*overflow)(struct xfrm_state___2 *, struct sk_buff___34 *);
};

struct xfrm_type___2 {
	char *description;
	struct module___143 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___2 *);
	void (*destructor)(struct xfrm_state___2 *);
	int (*input)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*output)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*reject)(struct xfrm_state___2 *, struct sk_buff___34 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___2 *, struct sk_buff___34 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___2 *, int);
};

struct xfrm_state_afinfo___2;

struct xfrm_mode___2 {
	int (*input2)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*input)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*output2)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*output)(struct xfrm_state___2 *, struct sk_buff___34 *);
	struct xfrm_state_afinfo___2 *afinfo;
	struct module___143 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___2 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___143 *owner;
	const struct xfrm_type___2 *type_map[256];
	struct xfrm_mode___2 *mode_map[5];
	int (*init_flags)(struct xfrm_state___2 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___2 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___2 **, struct xfrm_state___2 **, int);
	union {
		int (*output)(struct sock___24 *, struct sk_buff___34 *);
		struct {
			int (*output)(struct sk_buff___34 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___24 *, struct sk_buff___34 *);
		struct {
			int (*output_finish)(struct sk_buff___34 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*extract_output)(struct xfrm_state___2 *, struct sk_buff___34 *);
	int (*transport_finish)(struct sk_buff___34 *, int);
};

struct cgroup_cls_state {
	struct cgroup_subsys_state___136 css;
	u32 classid;
};

struct page___240;

typedef struct page___240 *pgtable_t___240;

struct address_space___241;

struct kmem_cache___224;

struct page___240 {
	long unsigned int flags;
	struct address_space___241 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___240 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___240 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___224 *slab_cache;
		struct page___240 *first_page;
	};
	long: 64;
};

struct task_struct___242;

struct pv_cpu_ops___242 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___242 *);
	void (*end_context_switch)(struct task_struct___242 *);
};

struct mutex___243 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___242 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___235 {
	struct page___240 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___249;

struct nsproxy___122;

struct signal_struct___242;

struct css_set___137;

struct task_struct___242 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___242 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___249 *mm;
	struct mm_struct___249 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___242 *real_parent;
	struct task_struct___242 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___242 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___242 = 0,
		VTIME_USER___242 = 1,
		VTIME_SYS___242 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___122 *nsproxy;
	struct signal_struct___242 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___137 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___243 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___235 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___249 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___249 *, struct mm_struct___249 *);
	void (*dup_mmap)(struct mm_struct___249 *, struct mm_struct___249 *);
	void (*exit_mmap)(struct mm_struct___249 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___249 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___249 *);
	void (*pgd_free)(struct mm_struct___249 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___249 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___249 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___249 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___249 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___249 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___249 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___249 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___249 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___249 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___249 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___249 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___243 lock;
	void *vdso;
} mm_context_t___243;

struct xol_area___240;

struct uprobes_state___240 {
	struct xol_area___240 *xol_area;
};

struct vm_area_struct___249;

struct file___241;

struct core_state___242;

struct mm_struct___249 {
	struct vm_area_struct___249 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___249 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___249 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___243 context;
	long unsigned int flags;
	struct core_state___242 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___242 *owner;
	struct file___241 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___240 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___27;

struct kobj_type___27;

struct kobject___27 {
	const char *name;
	struct list_head entry;
	struct kobject___27 *parent;
	struct kset___27 *kset;
	struct kobj_type___27 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___144;

struct module_kobject___143 {
	struct kobject___27 kobj;
	struct module___144 *mod;
	struct kobject___27 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___143;

struct module___144 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___143 mkobj;
	struct module_attribute___143 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___27 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___242 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___242;

struct lruvec___242 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___242 *zone;
};

struct pglist_data___242;

struct zone___242 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___242 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___242 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___242 {
	struct zone___242 *zone;
	int zone_idx;
};

struct zonelist___242 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___242 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___242 {
	struct zone___242 node_zones[4];
	struct zonelist___242 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___242 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___165;

struct x86_io_apic_ops___165 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___165 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___165;

struct irq_data___165 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___165 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___239;

struct dev_pm_ops___239 {
	int (*prepare)(struct device___239 *);
	void (*complete)(struct device___239 *);
	int (*suspend)(struct device___239 *);
	int (*resume)(struct device___239 *);
	int (*freeze)(struct device___239 *);
	int (*thaw)(struct device___239 *);
	int (*poweroff)(struct device___239 *);
	int (*restore)(struct device___239 *);
	int (*suspend_late)(struct device___239 *);
	int (*resume_early)(struct device___239 *);
	int (*freeze_late)(struct device___239 *);
	int (*thaw_early)(struct device___239 *);
	int (*poweroff_late)(struct device___239 *);
	int (*restore_early)(struct device___239 *);
	int (*suspend_noirq)(struct device___239 *);
	int (*resume_noirq)(struct device___239 *);
	int (*freeze_noirq)(struct device___239 *);
	int (*thaw_noirq)(struct device___239 *);
	int (*poweroff_noirq)(struct device___239 *);
	int (*restore_noirq)(struct device___239 *);
	int (*runtime_suspend)(struct device___239 *);
	int (*runtime_resume)(struct device___239 *);
	int (*runtime_idle)(struct device___239 *);
};

struct dev_pm_qos___43;

struct dev_pm_info___43 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___43 *qos;
};

struct dma_map_ops___104;

struct dev_archdata___104 {
	struct dma_map_ops___104 *dma_ops;
	void *iommu;
};

struct device_type___239;

struct bus_type___239;

struct device_driver___239;

struct dev_pm_domain___239;

struct class___239;

struct attribute_group___201;

struct device_rh___239;

struct device___239 {
	struct device___239 *parent;
	struct device_private *p;
	struct kobject___27 kobj;
	const char *init_name;
	const struct device_type___239 *type;
	struct mutex___243 mutex;
	struct bus_type___239 *bus;
	struct device_driver___239 *driver;
	void *platform_data;
	struct dev_pm_info___43 power;
	struct dev_pm_domain___239 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___104 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___239 *class;
	const struct attribute_group___201 **groups;
	void (*release)(struct device___239 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___239 *device_rh;
};

struct dev_pm_qos_request___44;

struct dev_pm_qos___43 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___44 *latency_req;
	struct dev_pm_qos_request___44 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___44 *latency_tolerance_req;
};

struct dev_pm_info_rh___239 {
	void (*set_latency_tolerance)(struct device___239 *, s32);
};

struct dev_pm_domain___239 {
	struct dev_pm_ops___239 ops;
};

struct smp_ops___242 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___242 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___47;

struct ctl_node___47 {
	struct rb_node node;
	struct ctl_table_header___47 *header;
};

struct ctl_table_root___47;

struct ctl_table_set___47;

struct ctl_dir___47;

struct ctl_table_header___47 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___47 *root;
	struct ctl_table_set___47 *set;
	struct ctl_dir___47 *parent;
	struct ctl_node___47 *node;
};

struct ctl_dir___47 {
	struct ctl_table_header___47 header;
	struct rb_root root;
};

struct ctl_table_set___47 {
	int (*is_seen)(struct ctl_table_set___47 *);
	struct ctl_dir___47 dir;
};

struct ctl_table_root___47 {
	struct ctl_table_set___47 default_set;
	struct ctl_table_set___47 * (*lookup)(struct ctl_table_root___47 *, struct nsproxy___122 *);
	int (*permissions)(struct ctl_table_header___47 *, struct ctl_table *);
};

struct net___46;

struct nsproxy___122 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___46 *net_ns;
};

struct sock___25;

struct kobj_ns_type_operations___24 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___25 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___24;

struct sock_common___24 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___24 *skc_prot;
	struct net___46 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___35;

struct sk_buff_head___33 {
	struct sk_buff___35 *next;
	struct sk_buff___35 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___25;

struct socket_wq___24;

struct dst_entry___24;

struct socket___25;

struct cg_proto___24;

struct sock___25 {
	struct sock_common___24 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___33 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___35 *head;
		struct sk_buff___35 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___25 *sk_filter;
	struct socket_wq___24 *sk_wq;
	struct sk_buff_head___33 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___24 *sk_rx_dst;
	struct dst_entry___24 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___33 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___33 sk_error_queue;
	struct proto___24 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___25 *sk_socket;
	void *sk_user_data;
	struct page_frag___235 sk_frag;
	struct sk_buff___35 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___24 *sk_cgrp;
	void (*sk_state_change)(struct sock___25 *);
	void (*sk_data_ready)(struct sock___25 *, int);
	void (*sk_write_space)(struct sock___25 *);
	void (*sk_error_report)(struct sock___25 *);
	int (*sk_backlog_rcv)(struct sock___25 *, struct sk_buff___35 *);
	void (*sk_destruct)(struct sock___25 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___203;

struct attribute_group___201 {
	const char *name;
	umode_t (*is_visible)(struct kobject___27 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___203 **bin_attrs;
};

struct bin_attribute___203 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___241 *, struct kobject___27 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___241 *, struct kobject___27 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	int (*mmap)(struct file___241 *, struct kobject___27 *, struct bin_attribute___203 *, struct vm_area_struct___249 *);
};

struct dentry___241;

struct path___241 {
	struct vfsmount *mnt;
	struct dentry___241 *dentry;
};

struct inode___241;

struct file_operations___241;

struct file___241 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___241 f_path;
	struct inode___241 *f_inode;
	const struct file_operations___241 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___241 *f_mapping;
	struct mutex___243 f_pos_lock;
};

struct vm_operations_struct___215;

struct vm_area_struct___249 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___249 *vm_next;
	struct vm_area_struct___249 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___249 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___215 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___241 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___27 {
	ssize_t (*show)(struct kobject___27 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___27 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___27 *, const struct attribute *);
};

struct kset_uevent_ops___27;

struct kset___27 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___27 kobj;
	const struct kset_uevent_ops___27 *uevent_ops;
};

struct kobj_type___27 {
	void (*release)(struct kobject___27 *);
	const struct sysfs_ops___27 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___27 *);
	const void * (*namespace)(struct kobject___27 *);
};

struct kset_uevent_ops___27 {
	int (* const filter)(struct kset___27 *, struct kobject___27 *);
	const char * (* const name)(struct kset___27 *, struct kobject___27 *);
	int (* const uevent)(struct kset___27 *, struct kobject___27 *, struct kobj_uevent_env *);
};

struct module_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___143 *, struct module_kobject___143 *, char *);
	ssize_t (*store)(struct module_attribute___143 *, struct module_kobject___143 *, const char *, size_t);
	void (*setup)(struct module___144 *, const char *);
	int (*test)(struct module___144 *);
	void (*free)(struct module___144 *);
};

struct kmem_cache_cpu___223 {
	void **freelist;
	long unsigned int tid;
	struct page___240 *page;
	struct page___240 *partial;
};

struct memcg_cache_params___224;

struct kmem_cache___224 {
	struct kmem_cache_cpu___223 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___27 kobj;
	struct memcg_cache_params___224 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___224 {
	bool is_root_cache;
	union {
		struct kmem_cache___224 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___224 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___240 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___240 *page;
	long unsigned int vaddr;
};

struct address_space_operations___241;

struct address_space___241 {
	struct inode___241 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___243 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___241 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___211;

struct vm_operations_struct___215 {
	void (*open)(struct vm_area_struct___249 *);
	void (*close)(struct vm_area_struct___249 *);
	int (*fault)(struct vm_area_struct___249 *, struct vm_fault___211 *);
	int (*page_mkwrite)(struct vm_area_struct___249 *, struct vm_fault___211 *);
	int (*access)(struct vm_area_struct___249 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___249 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___249 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___249 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___249 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___242 {
	struct task_struct___242 *task;
	struct core_thread___242 *next;
};

struct core_state___242 {
	atomic_t nr_threads;
	struct core_thread___242 dumper;
	struct completion startup;
};

struct fasync_struct___241;

struct socket_wq___24 {
	wait_queue_head_t wait;
	struct fasync_struct___241 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___241 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___241 *fa_next;
	struct file___241 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___24;

struct socket___25 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___24 *wq;
	struct file___241 *file;
	struct sock___25 *sk;
	const struct proto_ops___24 *ops;
};

struct poll_table_struct___131;

struct kiocb___32;

struct proto_ops___24 {
	int family;
	struct module___144 *owner;
	int (*release)(struct socket___25 *);
	int (*bind)(struct socket___25 *, struct sockaddr *, int);
	int (*connect)(struct socket___25 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___25 *, struct socket___25 *);
	int (*accept)(struct socket___25 *, struct socket___25 *, int);
	int (*getname)(struct socket___25 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___241 *, struct socket___25 *, struct poll_table_struct___131 *);
	int (*ioctl)(struct socket___25 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___25 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___25 *, int);
	int (*shutdown)(struct socket___25 *, int);
	int (*setsockopt)(struct socket___25 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___25 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___25 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___25 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___32 *, struct socket___25 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___32 *, struct socket___25 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___241 *, struct socket___25 *, struct vm_area_struct___249 *);
	ssize_t (*sendpage)(struct socket___25 *, struct page___240 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___25 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___25 *, int);
		struct {
			void (*set_peek_off)(struct sock___25 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___133)(struct file___241 *, wait_queue_head_t *, struct poll_table_struct___131 *);

struct poll_table_struct___131 {
	poll_queue_proc___133 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___32(struct kiocb___32 *, struct io_event *);

struct kiocb___32 {
	atomic_t ki_users;
	struct file___241 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___32 *ki_cancel;
	void (*ki_dtor)(struct kiocb___32 *);
	union {
		void *user;
		struct task_struct___242 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___44 {
	struct ctl_table_header___47 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___44 {
	struct mutex___243 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___44 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___47 *ctl;
};

struct netns_ipv4___44 {
	struct ctl_table_header___47 *forw_hdr;
	struct ctl_table_header___47 *frags_hdr;
	struct ctl_table_header___47 *ipv4_hdr;
	struct ctl_table_header___47 *route_hdr;
	struct ctl_table_header___47 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___25 *fibnl;
	struct sock___25 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___44 {
	struct ctl_table_header___47 *hdr;
	struct ctl_table_header___47 *route_hdr;
	struct ctl_table_header___47 *icmp_hdr;
	struct ctl_table_header___47 *frags_hdr;
	struct ctl_table_header___47 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___34;

struct neighbour___24;

struct dst_ops___45 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___45 *);
	struct dst_entry___24 * (*check)(struct dst_entry___24 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___24 *);
	unsigned int (*mtu)(const struct dst_entry___24 *);
	u32 * (*cow_metrics)(struct dst_entry___24 *, long unsigned int);
	void (*destroy)(struct dst_entry___24 *);
	void (*ifdown)(struct dst_entry___24 *, struct net_device___34 *, int);
	struct dst_entry___24 * (*negative_advice)(struct dst_entry___24 *);
	void (*link_failure)(struct sk_buff___35 *);
	void (*update_pmtu)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___35 *, u32);
	void (*redirect)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___35 *);
	int (*local_out)(struct sk_buff___35 *);
	struct neighbour___24 * (*neigh_lookup)(const struct dst_entry___24 *, struct sk_buff___35 *, const void *);
	struct kmem_cache___224 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___45 {
	struct netns_sysctl_ipv6___44 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___45 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___25 **icmp_sk;
	struct sock___25 *ndisc_sk;
	struct sock___25 *tcp_sk;
	struct sock___25 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___44 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___47 *sysctl_header;
	struct sock___25 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___24 {
	struct sock___25 *v4_ctl_sk;
	struct sock___25 *v6_ctl_sk;
};

struct netns_nf___44 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___47 *nf_log_dir_header;
};

struct nf_proto_net___44 {
	struct ctl_table_header___47 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___44 {
	struct nf_proto_net___44 pn;
	unsigned int timeout;
};

struct nf_tcp_net___44 {
	struct nf_proto_net___44 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___44 {
	struct nf_proto_net___44 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___44 {
	struct nf_proto_net___44 pn;
	unsigned int timeout;
};

struct nf_ip_net___44 {
	struct nf_generic_net___44 generic;
	struct nf_tcp_net___44 tcp;
	struct nf_udp_net___44 udp;
	struct nf_icmp_net___44 icmp;
	struct nf_icmp_net___44 icmpv6;
};

struct netns_ct___44 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___47 *sysctl_header;
	struct ctl_table_header___47 *acct_sysctl_header;
	struct ctl_table_header___47 *tstamp_sysctl_header;
	struct ctl_table_header___47 *event_sysctl_header;
	struct ctl_table_header___47 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___224 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___44 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___44 {
	struct netns_sysctl_ipv6___44 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___45 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___25 *nlsk;
	struct sock___25 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___47 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___45 xfrm4_dst_ops;
	struct dst_ops___45 xfrm6_dst_ops;
};

struct net___46 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___47 sysctls;
	struct sock___25 *rtnl;
	struct sock___25 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___34 *loopback_dev;
	struct netns_core___44 core;
	struct netns_mib mib;
	struct netns_packet___44 packet;
	struct netns_unix___44 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___44 ipv4;
	struct netns_ipv6___45 ipv6;
	struct netns_sctp___44 sctp;
	struct netns_dccp___24 dccp;
	struct netns_nf___44 nf;
	struct netns_xt xt;
	struct netns_ct___44 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___44 nf_frag;
	struct sock___25 *nfnl;
	struct sock___25 *nfnl_stash;
	struct sk_buff_head___33 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___45 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___25 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___25 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___243 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___243 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___104 {
	void * (*alloc)(struct device___239 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___239 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___239 *, struct vm_area_struct___249 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___239 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___239 *, struct page___240 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___239 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___239 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___239 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___239 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___239 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___239 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___239 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___239 *, dma_addr_t);
	int (*dma_supported)(struct device___239 *, u64);
	int (*set_dma_mask)(struct device___239 *, u64);
	int is_phys;
};

struct bus_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___239 *, char *);
	ssize_t (*store)(struct bus_type___239 *, const char *, size_t);
};

struct device_attribute___239;

struct driver_attribute___239;

struct bus_type___239 {
	const char *name;
	const char *dev_name;
	struct device___239 *dev_root;
	struct bus_attribute___239 *bus_attrs;
	struct device_attribute___239 *dev_attrs;
	struct driver_attribute___239 *drv_attrs;
	const struct attribute_group___201 **bus_groups;
	const struct attribute_group___201 **dev_groups;
	const struct attribute_group___201 **drv_groups;
	int (*match)(struct device___239 *, struct device_driver___239 *);
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	int (*probe)(struct device___239 *);
	int (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*online)(struct device___239 *);
	int (*offline)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct device___239 *, struct device_attribute___239 *, char *);
	ssize_t (*store)(struct device___239 *, struct device_attribute___239 *, const char *, size_t);
};

struct driver_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___239 *, char *);
	ssize_t (*store)(struct device_driver___239 *, const char *, size_t);
};

struct device_driver___239 {
	const char *name;
	struct bus_type___239 *bus;
	struct module___144 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___239 *);
	int (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	const struct attribute_group___201 **groups;
	const struct dev_pm_ops___239 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___239 {
	const char *name;
	const struct attribute_group___201 **groups;
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
};

struct class_attribute___239;

struct class___239 {
	const char *name;
	struct module___144 *owner;
	struct class_attribute___239 *class_attrs;
	struct device_attribute___239 *dev_attrs;
	const struct attribute_group___201 **dev_groups;
	struct bin_attribute___203 *dev_bin_attrs;
	struct kobject___27 *dev_kobj;
	int (*dev_uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *);
	void (*class_release)(struct class___239 *);
	void (*dev_release)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
	struct subsys_private *p;
};

struct class_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct class___239 *, struct class_attribute___239 *, char *);
	ssize_t (*store)(struct class___239 *, struct class_attribute___239 *, const char *, size_t);
	const void * (*namespace)(struct class___239 *, const struct class_attribute___239 *);
};

struct device_rh___239 {
	struct dev_pm_info_rh___239 power;
};

struct vm_fault___211 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___240 *page;
};

struct dma_device___6;

struct dma_chan_dev___6;

struct dma_chan___7 {
	struct dma_device___6 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___6 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___6;

struct dma_device___6 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___239 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___7 *);
	void (*device_free_chan_resources)(struct dma_chan___7 *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memcpy)(struct dma_chan___7 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor)(struct dma_chan___7 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor_val)(struct dma_chan___7 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq)(struct dma_chan___7 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq_val)(struct dma_chan___7 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memset)(struct dma_chan___7 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_interrupt)(struct dma_chan___7 *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_sg)(struct dma_chan___7 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_slave_sg)(struct dma_chan___7 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_cyclic)(struct dma_chan___7 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___6 * (*device_prep_interleaved_dma)(struct dma_chan___7 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___7 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___7 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___7 *);
};

struct dma_chan_dev___6 {
	struct dma_chan___7 *chan;
	struct device___239 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___6 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___7 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___6 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list {
	char *base_address;
	int nr_pages;
	struct page___240 **pages;
};

struct dma_pinned_list {
	int nr_iovecs;
	struct dma_page_list page_list[0];
};

struct signal_struct___242 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___242 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___242 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___243 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___137;

struct css_set___137 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___137 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___32 {
	atomic_t use;
	unsigned int mask;
	struct net_device___34 *physindev;
	struct net_device___34 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___32(struct sk_buff___35 **);

struct net_device_ops___32;

struct ethtool_ops___32;

struct header_ops___32;

struct netdev_rx_queue___32;

struct netdev_queue___32;

struct rtnl_link_ops___24;

struct dcbnl_rtnl_ops___32;

struct net_device___34 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___32 *netdev_ops;
	const struct ethtool_ops___32 *ethtool_ops;
	const struct header_ops___32 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___27 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___32 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___32 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___32 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___32 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___32 = 0,
		NETREG_REGISTERED___32 = 1,
		NETREG_UNREGISTERING___32 = 2,
		NETREG_UNREGISTERED___32 = 3,
		NETREG_RELEASED___32 = 4,
		NETREG_DUMMY___32 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___32 = 0,
		RTNL_LINK_INITIALIZING___32 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___34 *);
	struct netpoll_info *npinfo;
	struct net___46 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___239 dev;
	const struct attribute_group___201 *sysfs_groups[4];
	const struct rtnl_link_ops___24 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___32 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___35 {
	struct sk_buff___35 *next;
	struct sk_buff___35 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___25 *sk;
	struct net_device___34 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___35 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___32 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct seq_file___166;

struct irq_chip___165 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___165 *);
	void (*irq_shutdown)(struct irq_data___165 *);
	void (*irq_enable)(struct irq_data___165 *);
	void (*irq_disable)(struct irq_data___165 *);
	void (*irq_ack)(struct irq_data___165 *);
	void (*irq_mask)(struct irq_data___165 *);
	void (*irq_mask_ack)(struct irq_data___165 *);
	void (*irq_unmask)(struct irq_data___165 *);
	void (*irq_eoi)(struct irq_data___165 *);
	int (*irq_set_affinity)(struct irq_data___165 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___165 *);
	int (*irq_set_type)(struct irq_data___165 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___165 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___165 *);
	void (*irq_bus_sync_unlock)(struct irq_data___165 *);
	void (*irq_cpu_online)(struct irq_data___165 *);
	void (*irq_cpu_offline)(struct irq_data___165 *);
	void (*irq_suspend)(struct irq_data___165 *);
	void (*irq_resume)(struct irq_data___165 *);
	void (*irq_pm_shutdown)(struct irq_data___165 *);
	void (*irq_print_chip)(struct irq_data___165 *, struct seq_file___166 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___165 *, void *);
	long unsigned int flags;
};

struct seq_operations___166;

struct seq_file___166 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___243 lock;
	const struct seq_operations___166 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___241;

struct file_operations___241 {
	struct module___144 *owner;
	loff_t (*llseek)(struct file___241 *, loff_t, int);
	ssize_t (*read)(struct file___241 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___241 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___32 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___32 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___241 *, void *, filldir_t);
	unsigned int (*poll)(struct file___241 *, struct poll_table_struct___131 *);
	long int (*unlocked_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___241 *, struct vm_area_struct___249 *);
	int (*open)(struct inode___241 *, struct file___241 *);
	int (*flush)(struct file___241 *, fl_owner_t);
	int (*release)(struct inode___241 *, struct file___241 *);
	int (*fsync)(struct file___241 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___32 *, int);
	int (*fasync)(int, struct file___241 *, int);
	int (*lock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*sendpage)(struct file___241 *, struct page___240 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___241 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___241 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___241 *, long int, struct file_lock___241 **, void **);
		struct {
			int (*setlease)(struct file___241 *, long int, struct file_lock___241 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___241 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___166 *, struct file___241 *);
};

struct dev_pm_qos_request___44 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___239 *dev;
};

struct dentry_operations___241;

struct super_block___241;

struct dentry___241 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___241 *d_parent;
	struct qstr d_name;
	struct inode___241 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___241 *d_op;
	struct super_block___241 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___241;

struct dquot___241;

struct block_device___241;

struct inode___241 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___241 *i_op;
	struct super_block___241 *i_sb;
	struct address_space___241 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___243 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___241 *i_fop;
	struct file_lock___241 *i_flock;
	struct address_space___241 i_data;
	struct dquot___241 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___241 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___241 {
	int (*d_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_hash)(const struct dentry___241 *, struct qstr *);
	int (*d_compare)(const struct dentry___241 *, const struct dentry___241 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___241 *);
	void (*d_release)(struct dentry___241 *);
	void (*d_prune)(struct dentry___241 *);
	void (*d_iput)(struct dentry___241 *, struct inode___241 *);
	char * (*d_dname)(struct dentry___241 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___241 *);
	int (*d_manage)(struct dentry___241 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___241;

struct mem_dqinfo___241 {
	struct quota_format_type___241 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___241;

struct quota_info___241 {
	unsigned int flags;
	struct mutex___243 dqio_mutex;
	struct mutex___243 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___241 *files[2];
	struct mem_dqinfo___241 info[2];
	const struct quota_format_ops___241 *ops[2];
};

struct file_system_type___241;

struct super_operations___241;

struct dquot_operations___241;

struct quotactl_ops___241;

struct xattr_handler___138;

struct super_block___241 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___241 *s_type;
	const struct super_operations___241 *s_op;
	const struct dquot_operations___241 *dq_op;
	const struct quotactl_ops___241 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___241 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___138 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___241 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___241 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___243 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___241 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___241 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___241 *bd_inode;
	struct super_block___241 *bd_super;
	struct mutex___243 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___241 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___243 bd_fsfreeze_mutex;
};

struct cgroup___137;

struct cgroup_subsys_state___137 {
	struct cgroup___137 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___241 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___241 *ia_file;
};

struct dquot___241 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___243 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___241 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___241 {
	int qf_fmt_id;
	const struct quota_format_ops___241 *qf_ops;
	struct module___144 *qf_owner;
	struct quota_format_type___241 *qf_next;
};

struct quota_format_ops___241 {
	int (*check_quota_file)(struct super_block___241 *, int);
	int (*read_file_info)(struct super_block___241 *, int);
	int (*write_file_info)(struct super_block___241 *, int);
	int (*free_file_info)(struct super_block___241 *, int);
	int (*read_dqblk)(struct dquot___241 *);
	int (*commit_dqblk)(struct dquot___241 *);
	int (*release_dqblk)(struct dquot___241 *);
};

struct dquot_operations___241 {
	int (*write_dquot)(struct dquot___241 *);
	struct dquot___241 * (*alloc_dquot)(struct super_block___241 *, int);
	void (*destroy_dquot)(struct dquot___241 *);
	int (*acquire_dquot)(struct dquot___241 *);
	int (*release_dquot)(struct dquot___241 *);
	int (*mark_dirty)(struct dquot___241 *);
	int (*write_info)(struct super_block___241 *, int);
	qsize_t * (*get_reserved_space)(struct inode___241 *);
};

struct quotactl_ops___241 {
	int (*quota_on)(struct super_block___241 *, int, int, struct path___241 *);
	int (*quota_on_meta)(struct super_block___241 *, int, int);
	int (*quota_off)(struct super_block___241 *, int);
	int (*quota_sync)(struct super_block___241 *, int);
	int (*get_info)(struct super_block___241 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___241 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___241 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___241 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___241 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___241 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___241 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___241 *, unsigned int);
};

struct address_space_operations___241 {
	int (*writepage)(struct page___240 *, struct writeback_control *);
	int (*readpage)(struct file___241 *, struct page___240 *);
	int (*writepages)(struct address_space___241 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___240 *);
	int (*readpages)(struct file___241 *, struct address_space___241 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___241 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___240 **, void **);
	int (*write_end)(struct file___241 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___240 *, void *);
	sector_t (*bmap)(struct address_space___241 *, sector_t);
	void (*invalidatepage)(struct page___240 *, long unsigned int);
	int (*releasepage)(struct page___240 *, gfp_t);
	void (*freepage)(struct page___240 *);
	ssize_t (*direct_IO)(int, struct kiocb___32 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___241 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___241 *, struct page___240 *, struct page___240 *, enum migrate_mode);
	int (*launder_page)(struct page___240 *);
	int (*is_partially_uptodate)(struct page___240 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___240 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___241 *, struct page___240 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___241 *, sector_t *);
	void (*swap_deactivate)(struct file___241 *);
	void (*invalidatepage_range)(struct page___240 *, unsigned int, unsigned int);
};

struct inode_operations___241 {
	struct dentry___241 * (*lookup)(struct inode___241 *, struct dentry___241 *, unsigned int);
	void * (*follow_link)(struct dentry___241 *, struct nameidata *);
	int (*permission)(struct inode___241 *, int);
	struct posix_acl * (*get_acl)(struct inode___241 *, int);
	int (*readlink)(struct dentry___241 *, char *, int);
	void (*put_link)(struct dentry___241 *, struct nameidata *, void *);
	int (*create)(struct inode___241 *, struct dentry___241 *, umode_t, bool);
	int (*link)(struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*unlink)(struct inode___241 *, struct dentry___241 *);
	int (*symlink)(struct inode___241 *, struct dentry___241 *, const char *);
	int (*mkdir)(struct inode___241 *, struct dentry___241 *, umode_t);
	int (*rmdir)(struct inode___241 *, struct dentry___241 *);
	int (*mknod)(struct inode___241 *, struct dentry___241 *, umode_t, dev_t);
	int (*rename)(struct inode___241 *, struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*setattr)(struct dentry___241 *, struct iattr___241 *);
	int (*getattr)(struct vfsmount *, struct dentry___241 *, struct kstat *);
	int (*setxattr)(struct dentry___241 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___241 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___241 *, char *, size_t);
	int (*removexattr)(struct dentry___241 *, const char *);
	int (*fiemap)(struct inode___241 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___241 *, struct timespec *, int);
	int (*atomic_open)(struct inode___241 *, struct dentry___241 *, struct file___241 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___241;

struct lock_manager_operations___241;

struct file_lock___241 {
	struct file_lock___241 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___241 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___241 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___241 *fl_ops;
	const struct lock_manager_operations___241 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___241 {
	void (*fl_copy_lock)(struct file_lock___241 *, struct file_lock___241 *);
	void (*fl_release_private)(struct file_lock___241 *);
};

struct lock_manager_operations___241 {
	int (*lm_compare_owner)(struct file_lock___241 *, struct file_lock___241 *);
	long unsigned int (*lm_owner_key)(struct file_lock___241 *);
	void (*lm_notify)(struct file_lock___241 *);
	int (*lm_grant)(struct file_lock___241 *, struct file_lock___241 *, int);
	void (*lm_break)(struct file_lock___241 *);
	int (*lm_change)(struct file_lock___241 **, int);
};

struct file_system_type___241 {
	const char *name;
	int fs_flags;
	struct dentry___241 * (*mount)(struct file_system_type___241 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___241 *);
	struct module___144 *owner;
	struct file_system_type___241 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___241 {
	struct inode___241 * (*alloc_inode)(struct super_block___241 *);
	void (*destroy_inode)(struct inode___241 *);
	void (*dirty_inode)(struct inode___241 *, int);
	int (*write_inode)(struct inode___241 *, struct writeback_control *);
	int (*drop_inode)(struct inode___241 *);
	void (*evict_inode)(struct inode___241 *);
	void (*put_super)(struct super_block___241 *);
	int (*sync_fs)(struct super_block___241 *, int);
	int (*freeze_fs)(struct super_block___241 *);
	int (*unfreeze_fs)(struct super_block___241 *);
	int (*statfs)(struct dentry___241 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___241 *, int *, char *);
	void (*umount_begin)(struct super_block___241 *);
	int (*show_options)(struct seq_file___166 *, struct dentry___241 *);
	int (*show_devname)(struct seq_file___166 *, struct dentry___241 *);
	int (*show_path)(struct seq_file___166 *, struct dentry___241 *);
	int (*show_stats)(struct seq_file___166 *, struct dentry___241 *);
	ssize_t (*quota_read)(struct super_block___241 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___241 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___241 *);
	int (*bdev_try_to_free_page)(struct super_block___241 *, struct page___240 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___241 *);
	void (*free_cached_objects)(struct super_block___241 *, int);
};

struct xattr_handler___138 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___241 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___241 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___241 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___32 {
	int (*get_settings)(struct net_device___34 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___34 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___34 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___34 *);
	void (*get_regs)(struct net_device___34 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___34 *);
	void (*set_msglevel)(struct net_device___34 *, u32);
	int (*nway_reset)(struct net_device___34 *);
	u32 (*get_link)(struct net_device___34 *);
	int (*get_eeprom_len)(struct net_device___34 *);
	int (*get_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___34 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___34 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___34 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___34 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___34 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___34 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___34 *);
	void (*complete)(struct net_device___34 *);
	u32 (*get_priv_flags)(struct net_device___34 *);
	int (*set_priv_flags)(struct net_device___34 *, u32);
	int (*get_sset_count)(struct net_device___34 *, int);
	int (*get_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___34 *, struct ethtool_flash *);
	int (*reset)(struct net_device___34 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___34 *);
	int (*get_rxfh_indir)(struct net_device___34 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___34 *, const u32 *);
	void (*get_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___34 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___34 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___34 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___34 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___34 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___34 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___34 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___34 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___24 {
	struct callback_head callback_head;
	struct dst_entry___24 *child;
	struct net_device___34 *dev;
	struct dst_ops___45 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___24 *path;
	struct dst_entry___24 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___35 *);
	union {
		int (*output)(struct sock___25 *, struct sk_buff___35 *);
		struct {
			int (*output)(struct sk_buff___35 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___24 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___24;

struct neigh_parms___24;

struct neigh_ops___24;

struct neighbour___24 {
	struct neighbour___24 *next;
	struct neigh_table___24 *tbl;
	struct neigh_parms___24 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___33 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___24 *, struct sk_buff___35 *);
	const struct neigh_ops___24 *ops;
	struct callback_head rcu;
	struct net_device___34 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___45 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___35 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___35 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___46 *, struct dst_entry___24 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___35 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___35 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___166 {
	void * (*start)(struct seq_file___166 *, loff_t *);
	void (*stop)(struct seq_file___166 *, void *);
	void * (*next)(struct seq_file___166 *, void *, loff_t *);
	int (*show)(struct seq_file___166 *, void *);
};

struct dcbnl_rtnl_ops___32 {
	int (*ieee_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___34 *);
	u8 (*setstate)(struct net_device___34 *, u8);
	void (*getpermhwaddr)(struct net_device___34 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___34 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___34 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___34 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___34 *, int, u8 *);
	void (*setpfccfg)(struct net_device___34 *, int, u8);
	void (*getpfccfg)(struct net_device___34 *, int, u8 *);
	u8 (*setall)(struct net_device___34 *);
	u8 (*getcap)(struct net_device___34 *, int, u8 *);
	int (*getnumtcs)(struct net_device___34 *, int, u8 *);
	int (*setnumtcs)(struct net_device___34 *, int, u8);
	u8 (*getpfcstate)(struct net_device___34 *);
	void (*setpfcstate)(struct net_device___34 *, u8);
	void (*getbcncfg)(struct net_device___34 *, int, u32 *);
	void (*setbcncfg)(struct net_device___34 *, int, u32);
	void (*getbcnrp)(struct net_device___34 *, int, u8 *);
	void (*setbcnrp)(struct net_device___34 *, int, u8);
	u8 (*setapp)(struct net_device___34 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___34 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___34 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___34 *, int, u8);
	u8 (*getdcbx)(struct net_device___34 *);
	u8 (*setdcbx)(struct net_device___34 *, u8);
	int (*peer_getappinfo)(struct net_device___34 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___34 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___34 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___34 *, struct cee_pfc *);
};

struct cgroupfs_root___137;

struct cgroup___137 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___137 *parent;
	struct dentry___241 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___137 *subsys[11];
	struct cgroupfs_root___137 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___243 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___137 {
	struct super_block___241 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___137 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___76 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___241 *, struct file___241 *);
	ssize_t (*read)(struct cgroup___137 *, struct cftype___76 *, struct file___241 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___137 *, struct cftype___76 *);
	s64 (*read_s64)(struct cgroup___137 *, struct cftype___76 *);
	int (*read_map)(struct cgroup___137 *, struct cftype___76 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___137 *, struct cftype___76 *, struct seq_file___166 *);
	ssize_t (*write)(struct cgroup___137 *, struct cftype___76 *, struct file___241 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___137 *, struct cftype___76 *, u64);
	int (*write_s64)(struct cgroup___137 *, struct cftype___76 *, s64);
	int (*write_string)(struct cgroup___137 *, struct cftype___76 *, const char *);
	int (*trigger)(struct cgroup___137 *, unsigned int);
	int (*release)(struct inode___241 *, struct file___241 *);
	int (*register_event)(struct cgroup___137 *, struct cftype___76 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___137 *, struct cftype___76 *, struct eventfd_ctx *);
};

struct cftype_set___72 {
	struct list_head node;
	struct cftype___76 *cfts;
};

struct task_and_cgroup___72 {
	struct task_struct___242 *task;
	struct cgroup___137 *cgrp;
	struct css_set___137 *cg;
};

struct cgroup_taskset___72 {
	struct task_and_cgroup___72 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___137 *cur_cgrp;
};

struct cgroup_subsys___72 {
	struct cgroup_subsys_state___137 * (*css_alloc)(struct cgroup___137 *);
	int (*css_online)(struct cgroup___137 *);
	void (*css_offline)(struct cgroup___137 *);
	void (*css_free)(struct cgroup___137 *);
	int (*can_attach)(struct cgroup___137 *, struct cgroup_taskset___72 *);
	void (*cancel_attach)(struct cgroup___137 *, struct cgroup_taskset___72 *);
	void (*attach)(struct cgroup___137 *, struct cgroup_taskset___72 *);
	void (*fork)(struct task_struct___242 *);
	void (*exit)(struct cgroup___137 *, struct cgroup___137 *, struct task_struct___242 *);
	void (*bind)(struct cgroup___137 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___137 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___76 *base_cftypes;
	struct cftype_set___72 base_cftset;
	struct module___144 *module;
};

struct request_sock_ops___16;

struct request_sock___17 {
	struct sock_common___24 __req_common;
	struct request_sock___17 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___16 *rsk_ops;
	struct sock___25 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___34 {
	struct sk_buff___35 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___35 *, struct netlink_callback___34 *);
	int (*done)(struct netlink_callback___34 *);
	void *data;
	struct module___144 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___32 {
	int (*create)(struct sk_buff___35 *, struct net_device___34 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___35 *, unsigned char *);
	int (*rebuild)(struct sk_buff___35 *);
	int (*cache)(const struct neighbour___24 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___34 *, const unsigned char *);
};

struct napi_struct___32 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___32 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___34 *dev;
	struct sk_buff___35 *gro_list;
	struct sk_buff___35 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___32 {
	struct net_device___34 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___27 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___32 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___27 kobj;
	struct net_device___34 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___32 {
	int (*ndo_init)(struct net_device___34 *);
	void (*ndo_uninit)(struct net_device___34 *);
	int (*ndo_open)(struct net_device___34 *);
	int (*ndo_stop)(struct net_device___34 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___35 *, struct net_device___34 *);
	u16 (*ndo_select_queue)(struct net_device___34 *, struct sk_buff___35 *);
	void (*ndo_change_rx_flags)(struct net_device___34 *, int);
	void (*ndo_set_rx_mode)(struct net_device___34 *);
	int (*ndo_set_mac_address)(struct net_device___34 *, void *);
	int (*ndo_validate_addr)(struct net_device___34 *);
	int (*ndo_do_ioctl)(struct net_device___34 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___34 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___34 *, int);
	int (*ndo_neigh_setup)(struct net_device___34 *, struct neigh_parms___24 *);
	void (*ndo_tx_timeout)(struct net_device___34 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___34 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___34 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___34 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___34 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___34 *);
	int (*ndo_netpoll_setup)(struct net_device___34 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___34 *);
	int (*ndo_busy_poll)(struct napi_struct___32 *);
	int (*ndo_set_vf_mac)(struct net_device___34 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___34 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___34 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___34 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___34 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___34 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___34 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___34 *, int, struct sk_buff___35 *);
	int (*ndo_setup_tc)(struct net_device___34 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___34 *);
	int (*ndo_fcoe_disable)(struct net_device___34 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___34 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___34 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___34 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___34 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___34 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___34 *, const struct sk_buff___35 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___34 *, struct net_device___34 *);
	int (*ndo_del_slave)(struct net_device___34 *, struct net_device___34 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___24 *);
	void (*ndo_neigh_destroy)(struct neighbour___24 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___35 *, struct netlink_callback___34 *, struct net_device___34 *, int);
	int (*ndo_bridge_setlink)(struct net_device___34 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___35 *, u32, u32, struct net_device___34 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___34 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___34 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___34 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___34 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___34 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___34 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___35 *, struct net_device___34 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___34 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___34 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___34 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___24 {
	struct net___46 *net;
	struct net_device___34 *dev;
	struct neigh_parms___24 *next;
	int (*neigh_setup)(struct neighbour___24 *);
	void (*neigh_cleanup)(struct neighbour___24 *);
	struct neigh_table___24 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___24 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___34 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___46 *, struct net_device___34 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___34 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___34 *, struct list_head *);
	size_t (*get_size)(const struct net_device___34 *);
	int (*fill_info)(struct sk_buff___35 *, const struct net_device___34 *);
	size_t (*get_xstats_size)(const struct net_device___34 *);
	int (*fill_xstats)(struct sk_buff___35 *, const struct net_device___34 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___46 * (*get_link_net)(const struct net_device___34 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___34 *, struct net_device___34 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___34 *, const struct net_device___34 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___35 *, const struct net_device___34 *, const struct net_device___34 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___25 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___35 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___24;

struct neigh_hash_table___24;

struct neigh_table___24 {
	struct neigh_table___24 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___34 *, __u32 *);
	int (*constructor)(struct neighbour___24 *);
	int (*pconstructor)(struct pneigh_entry___24 *);
	void (*pdestructor)(struct pneigh_entry___24 *);
	void (*proxy_redo)(struct sk_buff___35 *);
	char *id;
	struct neigh_parms___24 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___33 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___24 *nht;
	struct pneigh_entry___24 **phash_buckets;
};

struct neigh_ops___24 {
	int family;
	void (*solicit)(struct neighbour___24 *, struct sk_buff___35 *);
	void (*error_report)(struct neighbour___24 *, struct sk_buff___35 *);
	int (*output)(struct neighbour___24 *, struct sk_buff___35 *);
	int (*connected_output)(struct neighbour___24 *, struct sk_buff___35 *);
};

struct pneigh_entry___24 {
	struct pneigh_entry___24 *next;
	struct net___46 *net;
	struct net_device___34 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___24 {
	struct neighbour___24 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___14;

struct proto___24 {
	void (*close)(struct sock___25 *, long int);
	int (*connect)(struct sock___25 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___25 *, int);
	struct sock___25 * (*accept)(struct sock___25 *, int, int *);
	int (*ioctl)(struct sock___25 *, int, long unsigned int);
	int (*init)(struct sock___25 *);
	void (*destroy)(struct sock___25 *);
	void (*shutdown)(struct sock___25 *, int);
	int (*setsockopt)(struct sock___25 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___25 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___25 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___25 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___25 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___32 *, struct sock___25 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___32 *, struct sock___25 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___25 *, struct page___240 *, int, size_t, int);
	int (*bind)(struct sock___25 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___25 *, struct sk_buff___35 *);
	void (*release_cb)(struct sock___25 *);
	void (*mtu_reduced)(struct sock___25 *);
	void (*hash)(struct sock___25 *);
	void (*unhash)(struct sock___25 *);
	void (*rehash)(struct sock___25 *);
	int (*get_port)(struct sock___25 *, short unsigned int);
	void (*clear_sk)(struct sock___25 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___25 *);
	void (*enter_memory_pressure)(struct sock___25 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___224 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___16 *rsk_prot;
	struct timewait_sock_ops___14 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___144 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___72 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___24 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___24 {
	void (*enter_memory_pressure)(struct sock___25 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___16 {
	int family;
	int obj_size;
	struct kmem_cache___224 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___25 *, struct request_sock___17 *);
	void (*send_ack)(struct sock___25 *, struct sk_buff___35 *, struct request_sock___17 *);
	void (*send_reset)(struct sock___25 *, struct sk_buff___35 *);
	void (*destructor)(struct request_sock___17 *);
	void (*syn_ack_timeout)(struct sock___25 *, struct request_sock___17 *);
};

struct timewait_sock_ops___14 {
	struct kmem_cache___224 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___25 *, struct sock___25 *, void *);
	void (*twsk_destructor)(struct sock___25 *);
};

struct listen_sock {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___17 *syn_table[0];
};

struct fastopen_queue {
	struct request_sock___17 *rskq_rst_head;
	struct request_sock___17 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue {
	struct request_sock___17 *rskq_accept_head;
	struct request_sock___17 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock *listen_opt;
	struct fastopen_queue *fastopenq;
};

struct inet_request_sock {
	struct request_sock___17 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___35 *pktopts;
	};
};

struct inet_cork___3 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___24 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___3 {
	struct inet_cork___3 base;
	struct flowi fl;
};

struct ipv6_pinfo___3;

struct inet_sock___3 {
	struct sock___25 sk;
	struct ipv6_pinfo___3 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___3 cork;
};

struct inet_bind_bucket___2;

struct inet_connection_sock_af_ops {
	int (*queue_xmit)(struct sk_buff___35 *, struct flowi *);
	void (*send_check)(struct sock___25 *, struct sk_buff___35 *);
	int (*rebuild_header)(struct sock___25 *);
	void (*sk_rx_dst_set)(struct sock___25 *, const struct sk_buff___35 *);
	int (*conn_request)(struct sock___25 *, struct sk_buff___35 *);
	struct sock___25 * (*syn_recv_sock)(struct sock___25 *, struct sk_buff___35 *, struct request_sock___17 *, struct dst_entry___24 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___25 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___25 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___25 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___25 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___25 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___25 *, const struct inet_bind_bucket___2 *, bool);
	void (*mtu_reduced)(struct sock___25 *);
};

struct tcp_congestion_ops;

struct inet_connection_sock {
	struct inet_sock___3 icsk_inet;
	struct request_sock_queue icsk_accept_queue;
	struct inet_bind_bucket___2 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___25 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

enum tcp_ca_event {
	CA_EVENT_TX_START = 0,
	CA_EVENT_CWND_RESTART = 1,
	CA_EVENT_COMPLETE_CWR = 2,
	CA_EVENT_LOSS = 3,
	CA_EVENT_ECN_NO_CE = 4,
	CA_EVENT_ECN_IS_CE = 5,
	CA_EVENT_DELAYED_ACK = 6,
	CA_EVENT_NON_DELAYED_ACK = 7,
};

struct sock___26;

struct sk_buff___36;

struct module___145;

struct tcp_congestion_ops {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___26 *);
	void (*release)(struct sock___26 *);
	u32 (*ssthresh)(struct sock___26 *);
	void (*cong_avoid)(struct sock___26 *, u32, u32);
	void (*set_state)(struct sock___26 *, u8);
	void (*cwnd_event)(struct sock___26 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___26 *, u32);
	u32 (*undo_cwnd)(struct sock___26 *);
	void (*pkts_acked)(struct sock___26 *, u32, s32);
	int (*get_info)(struct sock___26 *, u32, struct sk_buff___36 *);
	char name[16];
	struct module___145 *owner;
};

struct tcp_sack_block {
	u32 start_seq;
	u32 end_seq;
};

struct tcp_options_received {
	long int ts_recent_stamp;
	u32 ts_recent;
	u32 rcv_tsval;
	u32 rcv_tsecr;
	u16 saw_tstamp: 1;
	u16 tstamp_ok: 1;
	u16 dsack: 1;
	u16 wscale_ok: 1;
	u16 sack_ok: 4;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u8 num_sacks;
	u16 user_mss;
	u16 mss_clamp;
};

struct tcp_request_sock_ops;

struct tcp_request_sock {
	struct inet_request_sock req;
	const struct tcp_request_sock_ops *af_specific;
	struct sock___25 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_sock_af_ops;

struct tcp_md5sig_info;

struct tcp_fastopen_request;

struct tcp_sock {
	struct inet_connection_sock inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___33 prequeue;
		struct task_struct___242 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___7 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___35 *lost_skb_hint;
	struct sk_buff___35 *retransmit_skb_hint;
	struct sk_buff_head___33 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___35 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request *fastopen_req;
	struct request_sock___17 *fastopen_rsk;
};

struct page___241;

typedef struct page___241 *pgtable_t___241;

struct address_space___242;

struct kmem_cache___225;

struct page___241 {
	long unsigned int flags;
	struct address_space___242 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___241 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___241 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___225 *slab_cache;
		struct page___241 *first_page;
	};
	long: 64;
};

struct task_struct___243;

struct pv_cpu_ops___243 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___243 *);
	void (*end_context_switch)(struct task_struct___243 *);
};

struct mutex___244 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___243 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___236 {
	struct page___241 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___250;

struct nsproxy___123;

struct signal_struct___243;

struct css_set___138;

struct pipe_inode_info___9;

struct task_struct___243 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___243 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___250 *mm;
	struct mm_struct___250 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___243 *real_parent;
	struct task_struct___243 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___243 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___243 = 0,
		VTIME_USER___243 = 1,
		VTIME_SYS___243 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___123 *nsproxy;
	struct signal_struct___243 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___138 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___244 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___9 *splice_pipe;
	struct page_frag___236 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___250 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___250 *, struct mm_struct___250 *);
	void (*dup_mmap)(struct mm_struct___250 *, struct mm_struct___250 *);
	void (*exit_mmap)(struct mm_struct___250 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___250 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___250 *);
	void (*pgd_free)(struct mm_struct___250 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___250 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___250 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___250 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___250 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___250 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___250 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___250 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___250 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___250 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___250 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___250 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___244 lock;
	void *vdso;
} mm_context_t___244;

struct xol_area___241;

struct uprobes_state___241 {
	struct xol_area___241 *xol_area;
};

struct vm_area_struct___250;

struct file___242;

struct core_state___243;

struct mm_struct___250 {
	struct vm_area_struct___250 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___250 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___250 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___244 context;
	long unsigned int flags;
	struct core_state___243 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___243 *owner;
	struct file___242 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___241 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___146;

struct exec_domain___68 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___146 *module;
	struct exec_domain___68 *next;
};

struct kset___28;

struct kobj_type___28;

struct kobject___28 {
	const char *name;
	struct list_head entry;
	struct kobject___28 *parent;
	struct kset___28 *kset;
	struct kobj_type___28 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___144 {
	struct kobject___28 kobj;
	struct module___146 *mod;
	struct kobject___28 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___144;

struct module___146 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___144 mkobj;
	struct module_attribute___144 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___28 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___243 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___113 {
	struct task_struct___243 *task;
	struct exec_domain___68 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___243;

struct lruvec___243 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___243 *zone;
};

struct pglist_data___243;

struct zone___243 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___243 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___243 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___243 {
	struct zone___243 *zone;
	int zone_idx;
};

struct zonelist___243 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___243 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___243 {
	struct zone___243 node_zones[4];
	struct zonelist___243 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___243 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___166;

struct x86_io_apic_ops___166 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___166 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___166;

struct irq_data___166 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___166 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___240;

struct dev_pm_ops___240 {
	int (*prepare)(struct device___240 *);
	void (*complete)(struct device___240 *);
	int (*suspend)(struct device___240 *);
	int (*resume)(struct device___240 *);
	int (*freeze)(struct device___240 *);
	int (*thaw)(struct device___240 *);
	int (*poweroff)(struct device___240 *);
	int (*restore)(struct device___240 *);
	int (*suspend_late)(struct device___240 *);
	int (*resume_early)(struct device___240 *);
	int (*freeze_late)(struct device___240 *);
	int (*thaw_early)(struct device___240 *);
	int (*poweroff_late)(struct device___240 *);
	int (*restore_early)(struct device___240 *);
	int (*suspend_noirq)(struct device___240 *);
	int (*resume_noirq)(struct device___240 *);
	int (*freeze_noirq)(struct device___240 *);
	int (*thaw_noirq)(struct device___240 *);
	int (*poweroff_noirq)(struct device___240 *);
	int (*restore_noirq)(struct device___240 *);
	int (*runtime_suspend)(struct device___240 *);
	int (*runtime_resume)(struct device___240 *);
	int (*runtime_idle)(struct device___240 *);
};

struct dev_pm_qos___44;

struct dev_pm_info___44 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___44 *qos;
};

struct dma_map_ops___105;

struct dev_archdata___105 {
	struct dma_map_ops___105 *dma_ops;
	void *iommu;
};

struct device_type___240;

struct bus_type___240;

struct device_driver___240;

struct dev_pm_domain___240;

struct class___240;

struct attribute_group___202;

struct device_rh___240;

struct device___240 {
	struct device___240 *parent;
	struct device_private *p;
	struct kobject___28 kobj;
	const char *init_name;
	const struct device_type___240 *type;
	struct mutex___244 mutex;
	struct bus_type___240 *bus;
	struct device_driver___240 *driver;
	void *platform_data;
	struct dev_pm_info___44 power;
	struct dev_pm_domain___240 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___105 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___240 *class;
	const struct attribute_group___202 **groups;
	void (*release)(struct device___240 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___240 *device_rh;
};

struct dev_pm_qos_request___45;

struct dev_pm_qos___44 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___45 *latency_req;
	struct dev_pm_qos_request___45 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___45 *latency_tolerance_req;
};

struct dev_pm_info_rh___240 {
	void (*set_latency_tolerance)(struct device___240 *, s32);
};

struct dev_pm_domain___240 {
	struct dev_pm_ops___240 ops;
};

struct smp_ops___243 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___243 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___48;

struct ctl_node___48 {
	struct rb_node node;
	struct ctl_table_header___48 *header;
};

struct ctl_table_root___48;

struct ctl_table_set___48;

struct ctl_dir___48;

struct ctl_table_header___48 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___48 *root;
	struct ctl_table_set___48 *set;
	struct ctl_dir___48 *parent;
	struct ctl_node___48 *node;
};

struct ctl_dir___48 {
	struct ctl_table_header___48 header;
	struct rb_root root;
};

struct ctl_table_set___48 {
	int (*is_seen)(struct ctl_table_set___48 *);
	struct ctl_dir___48 dir;
};

struct ctl_table_root___48 {
	struct ctl_table_set___48 default_set;
	struct ctl_table_set___48 * (*lookup)(struct ctl_table_root___48 *, struct nsproxy___123 *);
	int (*permissions)(struct ctl_table_header___48 *, struct ctl_table *);
};

struct net___47;

struct nsproxy___123 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___47 *net_ns;
};

struct sock___27;

struct kobj_ns_type_operations___25 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___27 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___25;

struct sock_common___25 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___25 *skc_prot;
	struct net___47 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___37;

struct sk_buff_head___34 {
	struct sk_buff___37 *next;
	struct sk_buff___37 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___26;

struct socket_wq___25;

struct xfrm_policy___3;

struct dst_entry___25;

struct socket___26;

struct cg_proto___25;

struct sock___27 {
	struct sock_common___25 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___34 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___37 *head;
		struct sk_buff___37 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___26 *sk_filter;
	struct socket_wq___25 *sk_wq;
	struct sk_buff_head___34 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___3 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___25 *sk_rx_dst;
	struct dst_entry___25 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___34 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___34 sk_error_queue;
	struct proto___25 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___26 *sk_socket;
	void *sk_user_data;
	struct page_frag___236 sk_frag;
	struct sk_buff___37 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___25 *sk_cgrp;
	void (*sk_state_change)(struct sock___27 *);
	void (*sk_data_ready)(struct sock___27 *, int);
	void (*sk_write_space)(struct sock___27 *);
	void (*sk_error_report)(struct sock___27 *);
	int (*sk_backlog_rcv)(struct sock___27 *, struct sk_buff___37 *);
	void (*sk_destruct)(struct sock___27 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___204;

struct attribute_group___202 {
	const char *name;
	umode_t (*is_visible)(struct kobject___28 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___204 **bin_attrs;
};

struct bin_attribute___204 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___242 *, struct kobject___28 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___242 *, struct kobject___28 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	int (*mmap)(struct file___242 *, struct kobject___28 *, struct bin_attribute___204 *, struct vm_area_struct___250 *);
};

struct dentry___242;

struct path___242 {
	struct vfsmount *mnt;
	struct dentry___242 *dentry;
};

struct inode___242;

struct file_operations___242;

struct file___242 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___242 f_path;
	struct inode___242 *f_inode;
	const struct file_operations___242 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___242 *f_mapping;
	struct mutex___244 f_pos_lock;
};

struct vm_operations_struct___216;

struct vm_area_struct___250 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___250 *vm_next;
	struct vm_area_struct___250 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___250 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___216 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___242 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___28 {
	ssize_t (*show)(struct kobject___28 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___28 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___28 *, const struct attribute *);
};

struct kset_uevent_ops___28;

struct kset___28 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___28 kobj;
	const struct kset_uevent_ops___28 *uevent_ops;
};

struct kobj_type___28 {
	void (*release)(struct kobject___28 *);
	const struct sysfs_ops___28 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___28 *);
	const void * (*namespace)(struct kobject___28 *);
};

struct kset_uevent_ops___28 {
	int (* const filter)(struct kset___28 *, struct kobject___28 *);
	const char * (* const name)(struct kset___28 *, struct kobject___28 *);
	int (* const uevent)(struct kset___28 *, struct kobject___28 *, struct kobj_uevent_env *);
};

struct module_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___144 *, struct module_kobject___144 *, char *);
	ssize_t (*store)(struct module_attribute___144 *, struct module_kobject___144 *, const char *, size_t);
	void (*setup)(struct module___146 *, const char *);
	int (*test)(struct module___146 *);
	void (*free)(struct module___146 *);
};

struct xol_area___241 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___241 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___224;

struct memcg_cache_params___225;

struct kmem_cache___225 {
	struct kmem_cache_cpu___224 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___28 kobj;
	struct memcg_cache_params___225 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___242;

struct address_space___242 {
	struct inode___242 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___244 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___242 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___212;

struct vm_operations_struct___216 {
	void (*open)(struct vm_area_struct___250 *);
	void (*close)(struct vm_area_struct___250 *);
	int (*fault)(struct vm_area_struct___250 *, struct vm_fault___212 *);
	int (*page_mkwrite)(struct vm_area_struct___250 *, struct vm_fault___212 *);
	int (*access)(struct vm_area_struct___250 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___250 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___250 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___250 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___250 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___243 {
	struct task_struct___243 *task;
	struct core_thread___243 *next;
};

struct core_state___243 {
	atomic_t nr_threads;
	struct core_thread___243 dumper;
	struct completion startup;
};

struct vm_fault___212 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___241 *page;
};

struct seq_file___167;

struct irq_chip___166 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___166 *);
	void (*irq_shutdown)(struct irq_data___166 *);
	void (*irq_enable)(struct irq_data___166 *);
	void (*irq_disable)(struct irq_data___166 *);
	void (*irq_ack)(struct irq_data___166 *);
	void (*irq_mask)(struct irq_data___166 *);
	void (*irq_mask_ack)(struct irq_data___166 *);
	void (*irq_unmask)(struct irq_data___166 *);
	void (*irq_eoi)(struct irq_data___166 *);
	int (*irq_set_affinity)(struct irq_data___166 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___166 *);
	int (*irq_set_type)(struct irq_data___166 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___166 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___166 *);
	void (*irq_bus_sync_unlock)(struct irq_data___166 *);
	void (*irq_cpu_online)(struct irq_data___166 *);
	void (*irq_cpu_offline)(struct irq_data___166 *);
	void (*irq_suspend)(struct irq_data___166 *);
	void (*irq_resume)(struct irq_data___166 *);
	void (*irq_pm_shutdown)(struct irq_data___166 *);
	void (*irq_print_chip)(struct irq_data___166 *, struct seq_file___167 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___166 *, void *);
	long unsigned int flags;
};

struct seq_operations___167;

struct seq_file___167 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___244 lock;
	const struct seq_operations___167 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kmem_cache_cpu___224 {
	void **freelist;
	long unsigned int tid;
	struct page___241 *page;
	struct page___241 *partial;
};

struct memcg_cache_params___225 {
	bool is_root_cache;
	union {
		struct kmem_cache___225 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___225 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct fasync_struct___242;

struct socket_wq___25 {
	wait_queue_head_t wait;
	struct fasync_struct___242 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___242 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___242 *fa_next;
	struct file___242 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___25;

struct socket___26 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___25 *wq;
	struct file___242 *file;
	struct sock___27 *sk;
	const struct proto_ops___25 *ops;
};

struct poll_table_struct___132;

struct kiocb___33;

struct proto_ops___25 {
	int family;
	struct module___146 *owner;
	int (*release)(struct socket___26 *);
	int (*bind)(struct socket___26 *, struct sockaddr *, int);
	int (*connect)(struct socket___26 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___26 *, struct socket___26 *);
	int (*accept)(struct socket___26 *, struct socket___26 *, int);
	int (*getname)(struct socket___26 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___242 *, struct socket___26 *, struct poll_table_struct___132 *);
	int (*ioctl)(struct socket___26 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___26 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___26 *, int);
	int (*shutdown)(struct socket___26 *, int);
	int (*setsockopt)(struct socket___26 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___26 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___26 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___26 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___33 *, struct socket___26 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___33 *, struct socket___26 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___242 *, struct socket___26 *, struct vm_area_struct___250 *);
	ssize_t (*sendpage)(struct socket___26 *, struct page___241 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___26 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___27 *, int);
		struct {
			void (*set_peek_off)(struct sock___27 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___134)(struct file___242 *, wait_queue_head_t *, struct poll_table_struct___132 *);

struct poll_table_struct___132 {
	poll_queue_proc___134 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___33(struct kiocb___33 *, struct io_event *);

struct kiocb___33 {
	atomic_t ki_users;
	struct file___242 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___33 *ki_cancel;
	void (*ki_dtor)(struct kiocb___33 *);
	union {
		void *user;
		struct task_struct___243 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct pipe_buffer___9;

struct pipe_inode_info___9 {
	struct mutex___244 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___241 *tmp_page;
	struct fasync_struct___242 *fasync_readers;
	struct fasync_struct___242 *fasync_writers;
	struct pipe_buffer___9 *bufs;
};

struct netns_core___45 {
	struct ctl_table_header___48 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___45 {
	struct mutex___244 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___45 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___48 *ctl;
};

struct netns_ipv4___45 {
	struct ctl_table_header___48 *forw_hdr;
	struct ctl_table_header___48 *frags_hdr;
	struct ctl_table_header___48 *ipv4_hdr;
	struct ctl_table_header___48 *route_hdr;
	struct ctl_table_header___48 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___27 *fibnl;
	struct sock___27 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___45 {
	struct ctl_table_header___48 *hdr;
	struct ctl_table_header___48 *route_hdr;
	struct ctl_table_header___48 *icmp_hdr;
	struct ctl_table_header___48 *frags_hdr;
	struct ctl_table_header___48 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___35;

struct neighbour___25;

struct dst_ops___46 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___46 *);
	struct dst_entry___25 * (*check)(struct dst_entry___25 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___25 *);
	unsigned int (*mtu)(const struct dst_entry___25 *);
	u32 * (*cow_metrics)(struct dst_entry___25 *, long unsigned int);
	void (*destroy)(struct dst_entry___25 *);
	void (*ifdown)(struct dst_entry___25 *, struct net_device___35 *, int);
	struct dst_entry___25 * (*negative_advice)(struct dst_entry___25 *);
	void (*link_failure)(struct sk_buff___37 *);
	void (*update_pmtu)(struct dst_entry___25 *, struct sock___27 *, struct sk_buff___37 *, u32);
	void (*redirect)(struct dst_entry___25 *, struct sock___27 *, struct sk_buff___37 *);
	int (*local_out)(struct sk_buff___37 *);
	struct neighbour___25 * (*neigh_lookup)(const struct dst_entry___25 *, struct sk_buff___37 *, const void *);
	struct kmem_cache___225 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___3;

struct fib6_table___3;

struct netns_ipv6___46 {
	struct netns_sysctl_ipv6___45 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___3 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___3 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___46 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___3 *ip6_prohibit_entry;
	struct rt6_info___3 *ip6_blk_hole_entry;
	struct fib6_table___3 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___27 **icmp_sk;
	struct sock___27 *ndisc_sk;
	struct sock___27 *tcp_sk;
	struct sock___27 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___45 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___48 *sysctl_header;
	struct sock___27 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___25 {
	struct sock___27 *v4_ctl_sk;
	struct sock___27 *v6_ctl_sk;
};

struct netns_nf___45 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___48 *nf_log_dir_header;
};

struct nf_proto_net___45 {
	struct ctl_table_header___48 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___45 {
	struct nf_proto_net___45 pn;
	unsigned int timeout;
};

struct nf_tcp_net___45 {
	struct nf_proto_net___45 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___45 {
	struct nf_proto_net___45 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___45 {
	struct nf_proto_net___45 pn;
	unsigned int timeout;
};

struct nf_ip_net___45 {
	struct nf_generic_net___45 generic;
	struct nf_tcp_net___45 tcp;
	struct nf_udp_net___45 udp;
	struct nf_icmp_net___45 icmp;
	struct nf_icmp_net___45 icmpv6;
};

struct netns_ct___45 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___48 *sysctl_header;
	struct ctl_table_header___48 *acct_sysctl_header;
	struct ctl_table_header___48 *tstamp_sysctl_header;
	struct ctl_table_header___48 *event_sysctl_header;
	struct ctl_table_header___48 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___225 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___45 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___45 {
	struct netns_sysctl_ipv6___45 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___46 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___27 *nlsk;
	struct sock___27 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___48 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___46 xfrm4_dst_ops;
	struct dst_ops___46 xfrm6_dst_ops;
};

struct net___47 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___48 sysctls;
	struct sock___27 *rtnl;
	struct sock___27 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___35 *loopback_dev;
	struct netns_core___45 core;
	struct netns_mib mib;
	struct netns_packet___45 packet;
	struct netns_unix___45 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___45 ipv4;
	struct netns_ipv6___46 ipv6;
	struct netns_sctp___45 sctp;
	struct netns_dccp___25 dccp;
	struct netns_nf___45 nf;
	struct netns_xt xt;
	struct netns_ct___45 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___45 nf_frag;
	struct sock___27 *nfnl;
	struct sock___27 *nfnl_stash;
	struct sk_buff_head___34 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___46 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___27 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___27 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___244 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___244 flow_flush_sem;
	long: 64;
	long: 64;
};

struct ts_config___2;

struct ts_ops___2 {
	const char *name;
	struct ts_config___2 * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config___2 *, struct ts_state *);
	void (*destroy)(struct ts_config___2 *);
	void * (*get_pattern)(struct ts_config___2 *);
	unsigned int (*get_pattern_len)(struct ts_config___2 *);
	struct module___146 *owner;
	struct list_head list;
};

struct ts_config___2 {
	struct ts_ops___2 *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config___2 *, struct ts_state *);
	void (*finish)(struct ts_config___2 *, struct ts_state *);
};

struct dma_map_ops___105 {
	void * (*alloc)(struct device___240 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___240 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___240 *, struct vm_area_struct___250 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___240 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___240 *, struct page___241 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___240 *, dma_addr_t);
	int (*dma_supported)(struct device___240 *, u64);
	int (*set_dma_mask)(struct device___240 *, u64);
	int is_phys;
};

struct bus_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___240 *, char *);
	ssize_t (*store)(struct bus_type___240 *, const char *, size_t);
};

struct device_attribute___240;

struct driver_attribute___240;

struct bus_type___240 {
	const char *name;
	const char *dev_name;
	struct device___240 *dev_root;
	struct bus_attribute___240 *bus_attrs;
	struct device_attribute___240 *dev_attrs;
	struct driver_attribute___240 *drv_attrs;
	const struct attribute_group___202 **bus_groups;
	const struct attribute_group___202 **dev_groups;
	const struct attribute_group___202 **drv_groups;
	int (*match)(struct device___240 *, struct device_driver___240 *);
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	int (*probe)(struct device___240 *);
	int (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*online)(struct device___240 *);
	int (*offline)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct device___240 *, struct device_attribute___240 *, char *);
	ssize_t (*store)(struct device___240 *, struct device_attribute___240 *, const char *, size_t);
};

struct driver_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___240 *, char *);
	ssize_t (*store)(struct device_driver___240 *, const char *, size_t);
};

struct device_driver___240 {
	const char *name;
	struct bus_type___240 *bus;
	struct module___146 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___240 *);
	int (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	const struct attribute_group___202 **groups;
	const struct dev_pm_ops___240 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___240 {
	const char *name;
	const struct attribute_group___202 **groups;
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
};

struct class_attribute___240;

struct class___240 {
	const char *name;
	struct module___146 *owner;
	struct class_attribute___240 *class_attrs;
	struct device_attribute___240 *dev_attrs;
	const struct attribute_group___202 **dev_groups;
	struct bin_attribute___204 *dev_bin_attrs;
	struct kobject___28 *dev_kobj;
	int (*dev_uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *);
	void (*class_release)(struct class___240 *);
	void (*dev_release)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
	struct subsys_private *p;
};

struct class_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct class___240 *, struct class_attribute___240 *, char *);
	ssize_t (*store)(struct class___240 *, struct class_attribute___240 *, const char *, size_t);
	const void * (*namespace)(struct class___240 *, const struct class_attribute___240 *);
};

struct device_rh___240 {
	struct dev_pm_info_rh___240 power;
};

struct signal_struct___243 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___243 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___243 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___244 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___138;

struct css_set___138 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___138 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___33 {
	atomic_t use;
	unsigned int mask;
	struct net_device___35 *physindev;
	struct net_device___35 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___33(struct sk_buff___37 **);

struct net_device_ops___33;

struct ethtool_ops___33;

struct header_ops___33;

struct inet6_dev___13;

struct netdev_rx_queue___33;

struct netdev_queue___33;

struct rtnl_link_ops___25;

struct dcbnl_rtnl_ops___33;

struct net_device___35 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___33 *netdev_ops;
	const struct ethtool_ops___33 *ethtool_ops;
	const struct header_ops___33 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___28 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___13 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___33 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___33 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___33 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___33 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___33 = 0,
		NETREG_REGISTERED___33 = 1,
		NETREG_UNREGISTERING___33 = 2,
		NETREG_UNREGISTERED___33 = 3,
		NETREG_RELEASED___33 = 4,
		NETREG_DUMMY___33 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___33 = 0,
		RTNL_LINK_INITIALIZING___33 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___35 *);
	struct netpoll_info *npinfo;
	struct net___47 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___240 dev;
	const struct attribute_group___202 *sysfs_groups[4];
	const struct rtnl_link_ops___25 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___33 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___3;

struct sk_buff___37 {
	struct sk_buff___37 *next;
	struct sk_buff___37 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___27 *sk;
	struct net_device___35 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___3 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___37 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___33 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___3 {
	struct {
		struct page___241 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___3 skb_frag_t___3;

struct ubuf_info {
	void (*callback)(struct ubuf_info *, bool);
	void *ctx;
	long unsigned int desc;
};

struct skb_shared_info___3 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___37 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___3 frags[17];
};

enum {
	SKB_FCLONE_UNAVAILABLE = 0,
	SKB_FCLONE_ORIG = 1,
	SKB_FCLONE_CLONE = 2,
};

struct xfrm_state___3;

struct sec_path___3 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___3 *xvec[6];
};

struct sk_buff_fclones {
	struct sk_buff___37 skb1;
	struct sk_buff___37 skb2;
	atomic_t fclone_ref;
};

struct skb_seq_state {
	__u32 lower_offset;
	__u32 upper_offset;
	__u32 frag_idx;
	__u32 stepped_offset;
	struct sk_buff___37 *root_skb;
	struct sk_buff___37 *cur_skb;
	__u8 *frag_data;
};

struct skb_checksum_ops {
	__wsum (*update)(const void *, int, __wsum);
	__wsum (*combine)(__wsum, __wsum, int, int);
};

struct skb_gso_cb {
	int mac_offset;
	int encap_level;
	__u16 csum_start;
};

struct file_lock___242;

struct file_operations___242 {
	struct module___146 *owner;
	loff_t (*llseek)(struct file___242 *, loff_t, int);
	ssize_t (*read)(struct file___242 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___242 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___33 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___33 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___242 *, void *, filldir_t);
	unsigned int (*poll)(struct file___242 *, struct poll_table_struct___132 *);
	long int (*unlocked_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___242 *, struct vm_area_struct___250 *);
	int (*open)(struct inode___242 *, struct file___242 *);
	int (*flush)(struct file___242 *, fl_owner_t);
	int (*release)(struct inode___242 *, struct file___242 *);
	int (*fsync)(struct file___242 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___33 *, int);
	int (*fasync)(int, struct file___242 *, int);
	int (*lock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*sendpage)(struct file___242 *, struct page___241 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*splice_write)(struct pipe_inode_info___9 *, struct file___242 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___242 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___242 *, long int, struct file_lock___242 **, void **);
		struct {
			int (*setlease)(struct file___242 *, long int, struct file_lock___242 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___242 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___167 *, struct file___242 *);
};

struct dev_pm_qos_request___45 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___240 *dev;
};

struct dentry_operations___242;

struct super_block___242;

struct dentry___242 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___242 *d_parent;
	struct qstr d_name;
	struct inode___242 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___242 *d_op;
	struct super_block___242 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___242;

struct dquot___242;

struct block_device___242;

struct inode___242 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___242 *i_op;
	struct super_block___242 *i_sb;
	struct address_space___242 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___244 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___242 *i_fop;
	struct file_lock___242 *i_flock;
	struct address_space___242 i_data;
	struct dquot___242 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___9 *i_pipe;
		struct block_device___242 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___242 {
	int (*d_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_hash)(const struct dentry___242 *, struct qstr *);
	int (*d_compare)(const struct dentry___242 *, const struct dentry___242 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___242 *);
	void (*d_release)(struct dentry___242 *);
	void (*d_prune)(struct dentry___242 *);
	void (*d_iput)(struct dentry___242 *, struct inode___242 *);
	char * (*d_dname)(struct dentry___242 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___242 *);
	int (*d_manage)(struct dentry___242 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___242;

struct mem_dqinfo___242 {
	struct quota_format_type___242 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___242;

struct quota_info___242 {
	unsigned int flags;
	struct mutex___244 dqio_mutex;
	struct mutex___244 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___242 *files[2];
	struct mem_dqinfo___242 info[2];
	const struct quota_format_ops___242 *ops[2];
};

struct file_system_type___242;

struct super_operations___242;

struct dquot_operations___242;

struct quotactl_ops___242;

struct xattr_handler___139;

struct super_block___242 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___242 *s_type;
	const struct super_operations___242 *s_op;
	const struct dquot_operations___242 *dq_op;
	const struct quotactl_ops___242 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___242 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___139 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___242 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___242 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___244 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___242 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___242 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___242 *bd_inode;
	struct super_block___242 *bd_super;
	struct mutex___244 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___242 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___244 bd_fsfreeze_mutex;
};

struct cgroup___138;

struct cgroup_subsys_state___138 {
	struct cgroup___138 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___242 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___242 *ia_file;
};

struct dquot___242 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___244 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___242 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___242 {
	int qf_fmt_id;
	const struct quota_format_ops___242 *qf_ops;
	struct module___146 *qf_owner;
	struct quota_format_type___242 *qf_next;
};

struct quota_format_ops___242 {
	int (*check_quota_file)(struct super_block___242 *, int);
	int (*read_file_info)(struct super_block___242 *, int);
	int (*write_file_info)(struct super_block___242 *, int);
	int (*free_file_info)(struct super_block___242 *, int);
	int (*read_dqblk)(struct dquot___242 *);
	int (*commit_dqblk)(struct dquot___242 *);
	int (*release_dqblk)(struct dquot___242 *);
};

struct dquot_operations___242 {
	int (*write_dquot)(struct dquot___242 *);
	struct dquot___242 * (*alloc_dquot)(struct super_block___242 *, int);
	void (*destroy_dquot)(struct dquot___242 *);
	int (*acquire_dquot)(struct dquot___242 *);
	int (*release_dquot)(struct dquot___242 *);
	int (*mark_dirty)(struct dquot___242 *);
	int (*write_info)(struct super_block___242 *, int);
	qsize_t * (*get_reserved_space)(struct inode___242 *);
};

struct quotactl_ops___242 {
	int (*quota_on)(struct super_block___242 *, int, int, struct path___242 *);
	int (*quota_on_meta)(struct super_block___242 *, int, int);
	int (*quota_off)(struct super_block___242 *, int);
	int (*quota_sync)(struct super_block___242 *, int);
	int (*get_info)(struct super_block___242 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___242 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___242 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___242 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___242 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___242 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___242 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___242 *, unsigned int);
};

struct address_space_operations___242 {
	int (*writepage)(struct page___241 *, struct writeback_control *);
	int (*readpage)(struct file___242 *, struct page___241 *);
	int (*writepages)(struct address_space___242 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___241 *);
	int (*readpages)(struct file___242 *, struct address_space___242 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___242 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___241 **, void **);
	int (*write_end)(struct file___242 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___241 *, void *);
	sector_t (*bmap)(struct address_space___242 *, sector_t);
	void (*invalidatepage)(struct page___241 *, long unsigned int);
	int (*releasepage)(struct page___241 *, gfp_t);
	void (*freepage)(struct page___241 *);
	ssize_t (*direct_IO)(int, struct kiocb___33 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___242 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___242 *, struct page___241 *, struct page___241 *, enum migrate_mode);
	int (*launder_page)(struct page___241 *);
	int (*is_partially_uptodate)(struct page___241 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___241 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___242 *, struct page___241 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___242 *, sector_t *);
	void (*swap_deactivate)(struct file___242 *);
	void (*invalidatepage_range)(struct page___241 *, unsigned int, unsigned int);
};

struct inode_operations___242 {
	struct dentry___242 * (*lookup)(struct inode___242 *, struct dentry___242 *, unsigned int);
	void * (*follow_link)(struct dentry___242 *, struct nameidata *);
	int (*permission)(struct inode___242 *, int);
	struct posix_acl * (*get_acl)(struct inode___242 *, int);
	int (*readlink)(struct dentry___242 *, char *, int);
	void (*put_link)(struct dentry___242 *, struct nameidata *, void *);
	int (*create)(struct inode___242 *, struct dentry___242 *, umode_t, bool);
	int (*link)(struct dentry___242 *, struct inode___242 *, struct dentry___242 *);
	int (*unlink)(struct inode___242 *, struct dentry___242 *);
	int (*symlink)(struct inode___242 *, struct dentry___242 *, const char *);
	int (*mkdir)(struct inode___242 *, struct dentry___242 *, umode_t);
	int (*rmdir)(struct inode___242 *, struct dentry___242 *);
	int (*mknod)(struct inode___242 *, struct dentry___242 *, umode_t, dev_t);
	int (*rename)(struct inode___242 *, struct dentry___242 *, struct inode___242 *, struct dentry___242 *);
	int (*setattr)(struct dentry___242 *, struct iattr___242 *);
	int (*getattr)(struct vfsmount *, struct dentry___242 *, struct kstat *);
	int (*setxattr)(struct dentry___242 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___242 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___242 *, char *, size_t);
	int (*removexattr)(struct dentry___242 *, const char *);
	int (*fiemap)(struct inode___242 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___242 *, struct timespec *, int);
	int (*atomic_open)(struct inode___242 *, struct dentry___242 *, struct file___242 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___242;

struct lock_manager_operations___242;

struct file_lock___242 {
	struct file_lock___242 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___242 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___242 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___242 *fl_ops;
	const struct lock_manager_operations___242 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___242 {
	void (*fl_copy_lock)(struct file_lock___242 *, struct file_lock___242 *);
	void (*fl_release_private)(struct file_lock___242 *);
};

struct lock_manager_operations___242 {
	int (*lm_compare_owner)(struct file_lock___242 *, struct file_lock___242 *);
	long unsigned int (*lm_owner_key)(struct file_lock___242 *);
	void (*lm_notify)(struct file_lock___242 *);
	int (*lm_grant)(struct file_lock___242 *, struct file_lock___242 *, int);
	void (*lm_break)(struct file_lock___242 *);
	int (*lm_change)(struct file_lock___242 **, int);
};

struct file_system_type___242 {
	const char *name;
	int fs_flags;
	struct dentry___242 * (*mount)(struct file_system_type___242 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___242 *);
	struct module___146 *owner;
	struct file_system_type___242 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___242 {
	struct inode___242 * (*alloc_inode)(struct super_block___242 *);
	void (*destroy_inode)(struct inode___242 *);
	void (*dirty_inode)(struct inode___242 *, int);
	int (*write_inode)(struct inode___242 *, struct writeback_control *);
	int (*drop_inode)(struct inode___242 *);
	void (*evict_inode)(struct inode___242 *);
	void (*put_super)(struct super_block___242 *);
	int (*sync_fs)(struct super_block___242 *, int);
	int (*freeze_fs)(struct super_block___242 *);
	int (*unfreeze_fs)(struct super_block___242 *);
	int (*statfs)(struct dentry___242 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___242 *, int *, char *);
	void (*umount_begin)(struct super_block___242 *);
	int (*show_options)(struct seq_file___167 *, struct dentry___242 *);
	int (*show_devname)(struct seq_file___167 *, struct dentry___242 *);
	int (*show_path)(struct seq_file___167 *, struct dentry___242 *);
	int (*show_stats)(struct seq_file___167 *, struct dentry___242 *);
	ssize_t (*quota_read)(struct super_block___242 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___242 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___242 *);
	int (*bdev_try_to_free_page)(struct super_block___242 *, struct page___241 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___242 *);
	void (*free_cached_objects)(struct super_block___242 *, int);
};

struct xattr_handler___139 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___242 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___242 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___242 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___33 {
	int (*get_settings)(struct net_device___35 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___35 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___35 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___35 *);
	void (*get_regs)(struct net_device___35 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___35 *);
	void (*set_msglevel)(struct net_device___35 *, u32);
	int (*nway_reset)(struct net_device___35 *);
	u32 (*get_link)(struct net_device___35 *);
	int (*get_eeprom_len)(struct net_device___35 *);
	int (*get_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___35 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___35 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___35 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___35 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___35 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___35 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___35 *);
	void (*complete)(struct net_device___35 *);
	u32 (*get_priv_flags)(struct net_device___35 *);
	int (*set_priv_flags)(struct net_device___35 *, u32);
	int (*get_sset_count)(struct net_device___35 *, int);
	int (*get_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___35 *, struct ethtool_flash *);
	int (*reset)(struct net_device___35 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___35 *);
	int (*get_rxfh_indir)(struct net_device___35 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___35 *, const u32 *);
	void (*get_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___35 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___35 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___35 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___35 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___35 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___35 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___35 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___35 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___8;

struct dst_entry___25 {
	struct callback_head callback_head;
	struct dst_entry___25 *child;
	struct net_device___35 *dev;
	struct dst_ops___46 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___25 *path;
	struct dst_entry___25 *from;
	struct xfrm_state___3 *xfrm;
	int (*input)(struct sk_buff___37 *);
	union {
		int (*output)(struct sock___27 *, struct sk_buff___37 *);
		struct {
			int (*output)(struct sk_buff___37 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___25 *next;
		struct rtable___8 *rt_next;
		struct rt6_info___3 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___25;

struct neigh_parms___25;

struct neigh_ops___25;

struct neighbour___25 {
	struct neighbour___25 *next;
	struct neigh_table___25 *tbl;
	struct neigh_parms___25 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___34 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___25 *, struct sk_buff___37 *);
	const struct neigh_ops___25 *ops;
	struct callback_head rcu;
	struct net_device___35 *dev;
	u8 primary_key[0];
};

struct fib6_node___3;

struct rt6_info___3 {
	struct dst_entry___25 dst;
	struct fib6_table___3 *rt6i_table;
	struct fib6_node___3 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___13 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___3 {
	struct fib6_node___3 *parent;
	struct fib6_node___3 *left;
	struct fib6_node___3 *right;
	struct rt6_info___3 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___3 *rr_ptr;
};

struct fib6_table___3 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___3 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___46 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___37 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___37 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___47 *, struct dst_entry___25 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___37 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___37 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___167 {
	void * (*start)(struct seq_file___167 *, loff_t *);
	void (*stop)(struct seq_file___167 *, void *);
	void * (*next)(struct seq_file___167 *, void *, loff_t *);
	int (*show)(struct seq_file___167 *, void *);
};

struct dcbnl_rtnl_ops___33 {
	int (*ieee_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___35 *);
	u8 (*setstate)(struct net_device___35 *, u8);
	void (*getpermhwaddr)(struct net_device___35 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___35 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___35 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___35 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___35 *, int, u8 *);
	void (*setpfccfg)(struct net_device___35 *, int, u8);
	void (*getpfccfg)(struct net_device___35 *, int, u8 *);
	u8 (*setall)(struct net_device___35 *);
	u8 (*getcap)(struct net_device___35 *, int, u8 *);
	int (*getnumtcs)(struct net_device___35 *, int, u8 *);
	int (*setnumtcs)(struct net_device___35 *, int, u8);
	u8 (*getpfcstate)(struct net_device___35 *);
	void (*setpfcstate)(struct net_device___35 *, u8);
	void (*getbcncfg)(struct net_device___35 *, int, u32 *);
	void (*setbcncfg)(struct net_device___35 *, int, u32);
	void (*getbcnrp)(struct net_device___35 *, int, u8 *);
	void (*setbcnrp)(struct net_device___35 *, int, u8);
	u8 (*setapp)(struct net_device___35 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___35 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___35 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___35 *, int, u8);
	u8 (*getdcbx)(struct net_device___35 *);
	u8 (*setdcbx)(struct net_device___35 *, u8);
	int (*peer_getappinfo)(struct net_device___35 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___35 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___35 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___35 *, struct cee_pfc *);
};

struct cgroupfs_root___138;

struct cgroup___138 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___138 *parent;
	struct dentry___242 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___138 *subsys[11];
	struct cgroupfs_root___138 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___244 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___138 {
	struct super_block___242 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___138 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___77 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___242 *, struct file___242 *);
	ssize_t (*read)(struct cgroup___138 *, struct cftype___77 *, struct file___242 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___138 *, struct cftype___77 *);
	s64 (*read_s64)(struct cgroup___138 *, struct cftype___77 *);
	int (*read_map)(struct cgroup___138 *, struct cftype___77 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___138 *, struct cftype___77 *, struct seq_file___167 *);
	ssize_t (*write)(struct cgroup___138 *, struct cftype___77 *, struct file___242 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___138 *, struct cftype___77 *, u64);
	int (*write_s64)(struct cgroup___138 *, struct cftype___77 *, s64);
	int (*write_string)(struct cgroup___138 *, struct cftype___77 *, const char *);
	int (*trigger)(struct cgroup___138 *, unsigned int);
	int (*release)(struct inode___242 *, struct file___242 *);
	int (*register_event)(struct cgroup___138 *, struct cftype___77 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___138 *, struct cftype___77 *, struct eventfd_ctx *);
};

struct cftype_set___73 {
	struct list_head node;
	struct cftype___77 *cfts;
};

struct task_and_cgroup___73 {
	struct task_struct___243 *task;
	struct cgroup___138 *cgrp;
	struct css_set___138 *cg;
};

struct cgroup_taskset___73 {
	struct task_and_cgroup___73 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___138 *cur_cgrp;
};

struct cgroup_subsys___73 {
	struct cgroup_subsys_state___138 * (*css_alloc)(struct cgroup___138 *);
	int (*css_online)(struct cgroup___138 *);
	void (*css_offline)(struct cgroup___138 *);
	void (*css_free)(struct cgroup___138 *);
	int (*can_attach)(struct cgroup___138 *, struct cgroup_taskset___73 *);
	void (*cancel_attach)(struct cgroup___138 *, struct cgroup_taskset___73 *);
	void (*attach)(struct cgroup___138 *, struct cgroup_taskset___73 *);
	void (*fork)(struct task_struct___243 *);
	void (*exit)(struct cgroup___138 *, struct cgroup___138 *, struct task_struct___243 *);
	void (*bind)(struct cgroup___138 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___138 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___77 *base_cftypes;
	struct cftype_set___73 base_cftset;
	struct module___146 *module;
};

struct request_sock_ops___17;

struct request_sock___18 {
	struct sock_common___25 __req_common;
	struct request_sock___18 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___17 *rsk_ops;
	struct sock___27 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___3;

struct xfrm_type___3;

struct xfrm_mode___3;

struct xfrm_state___3 {
	struct net___47 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___3 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___3 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___3 *type;
	struct xfrm_mode___3 *inner_mode;
	struct xfrm_mode___3 *inner_mode_iaf;
	struct xfrm_mode___3 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___3 {
	struct sk_buff_head___34 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___3 {
	struct net___47 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___3 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___35 {
	struct sk_buff___37 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___37 *, struct netlink_callback___35 *);
	int (*done)(struct netlink_callback___35 *);
	void *data;
	struct module___146 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___33 {
	int (*create)(struct sk_buff___37 *, struct net_device___35 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___37 *, unsigned char *);
	int (*rebuild)(struct sk_buff___37 *);
	int (*cache)(const struct neighbour___25 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___35 *, const unsigned char *);
};

struct napi_struct___33 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___33 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___35 *dev;
	struct sk_buff___37 *gro_list;
	struct sk_buff___37 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___33 {
	struct net_device___35 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___28 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct gnet_stats_rate_est64 {
	__u64 bps;
	__u64 pps;
};

struct gnet_stats_basic_packed {
	__u64 bytes;
	__u32 packets;
} __attribute__((packed));

struct gnet_stats_queue {
	__u32 qlen;
	__u32 backlog;
	__u32 drops;
	__u32 requeues;
	__u32 overlimits;
};

struct Qdisc_ops;

struct qdisc_size_table;

struct Qdisc {
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc *);
	struct sk_buff___37 * (*dequeue)(struct Qdisc *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___37 *, struct Qdisc *);
	void *u32_node;
	struct Qdisc *__parent;
	struct netdev_queue___33 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc *next_sched;
	struct sk_buff___37 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___34 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___33 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___28 kobj;
	struct net_device___35 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___33 {
	int (*ndo_init)(struct net_device___35 *);
	void (*ndo_uninit)(struct net_device___35 *);
	int (*ndo_open)(struct net_device___35 *);
	int (*ndo_stop)(struct net_device___35 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___37 *, struct net_device___35 *);
	u16 (*ndo_select_queue)(struct net_device___35 *, struct sk_buff___37 *);
	void (*ndo_change_rx_flags)(struct net_device___35 *, int);
	void (*ndo_set_rx_mode)(struct net_device___35 *);
	int (*ndo_set_mac_address)(struct net_device___35 *, void *);
	int (*ndo_validate_addr)(struct net_device___35 *);
	int (*ndo_do_ioctl)(struct net_device___35 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___35 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___35 *, int);
	int (*ndo_neigh_setup)(struct net_device___35 *, struct neigh_parms___25 *);
	void (*ndo_tx_timeout)(struct net_device___35 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___35 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___35 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___35 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___35 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___35 *);
	int (*ndo_netpoll_setup)(struct net_device___35 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___35 *);
	int (*ndo_busy_poll)(struct napi_struct___33 *);
	int (*ndo_set_vf_mac)(struct net_device___35 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___35 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___35 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___35 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___35 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___35 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___35 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___35 *, int, struct sk_buff___37 *);
	int (*ndo_setup_tc)(struct net_device___35 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___35 *);
	int (*ndo_fcoe_disable)(struct net_device___35 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___35 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___35 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___35 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___35 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___35 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___35 *, const struct sk_buff___37 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___35 *, struct net_device___35 *);
	int (*ndo_del_slave)(struct net_device___35 *, struct net_device___35 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___25 *);
	void (*ndo_neigh_destroy)(struct neighbour___25 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___37 *, struct netlink_callback___35 *, struct net_device___35 *, int);
	int (*ndo_bridge_setlink)(struct net_device___35 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___37 *, u32, u32, struct net_device___35 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___35 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___35 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___35 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___35 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___35 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___35 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___37 *, struct net_device___35 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___35 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___35 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___35 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___25 {
	struct net___47 *net;
	struct net_device___35 *dev;
	struct neigh_parms___25 *next;
	int (*neigh_setup)(struct neighbour___25 *);
	void (*neigh_cleanup)(struct neighbour___25 *);
	struct neigh_table___25 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___13;

struct ifacaddr6___13;

struct inet6_dev___13 {
	struct net_device___35 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___13 *mc_list;
	struct ifmcaddr6___13 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___13 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___25 *nd_parms;
	struct inet6_dev___13 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___25 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___35 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___47 *, struct net_device___35 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___35 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___35 *, struct list_head *);
	size_t (*get_size)(const struct net_device___35 *);
	int (*fill_info)(struct sk_buff___37 *, const struct net_device___35 *);
	size_t (*get_xstats_size)(const struct net_device___35 *);
	int (*fill_xstats)(struct sk_buff___37 *, const struct net_device___35 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___47 * (*get_link_net)(const struct net_device___35 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___35 *, struct net_device___35 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___35 *, const struct net_device___35 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___37 *, const struct net_device___35 *, const struct net_device___35 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct napi_gro_cb {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___37 *last;
};

struct sk_filter___26 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___37 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct tcmsg {
	unsigned char tcm_family;
	unsigned char tcm__pad1;
	short unsigned int tcm__pad2;
	int tcm_ifindex;
	__u32 tcm_handle;
	__u32 tcm_parent;
	__u32 tcm_info;
};

struct pneigh_entry___25;

struct neigh_hash_table___25;

struct neigh_table___25 {
	struct neigh_table___25 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___35 *, __u32 *);
	int (*constructor)(struct neighbour___25 *);
	int (*pconstructor)(struct pneigh_entry___25 *);
	void (*pdestructor)(struct pneigh_entry___25 *);
	void (*proxy_redo)(struct sk_buff___37 *);
	char *id;
	struct neigh_parms___25 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___34 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___25 *nht;
	struct pneigh_entry___25 **phash_buckets;
};

struct neigh_ops___25 {
	int family;
	void (*solicit)(struct neighbour___25 *, struct sk_buff___37 *);
	void (*error_report)(struct neighbour___25 *, struct sk_buff___37 *);
	int (*output)(struct neighbour___25 *, struct sk_buff___37 *);
	int (*connected_output)(struct neighbour___25 *, struct sk_buff___37 *);
};

struct pneigh_entry___25 {
	struct pneigh_entry___25 *next;
	struct net___47 *net;
	struct net_device___35 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___25 {
	struct neighbour___25 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___8 {
	struct dst_entry___25 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___15;

struct proto___25 {
	void (*close)(struct sock___27 *, long int);
	int (*connect)(struct sock___27 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___27 *, int);
	struct sock___27 * (*accept)(struct sock___27 *, int, int *);
	int (*ioctl)(struct sock___27 *, int, long unsigned int);
	int (*init)(struct sock___27 *);
	void (*destroy)(struct sock___27 *);
	void (*shutdown)(struct sock___27 *, int);
	int (*setsockopt)(struct sock___27 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___27 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___27 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___27 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___27 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___33 *, struct sock___27 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___33 *, struct sock___27 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___27 *, struct page___241 *, int, size_t, int);
	int (*bind)(struct sock___27 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___27 *, struct sk_buff___37 *);
	void (*release_cb)(struct sock___27 *);
	void (*mtu_reduced)(struct sock___27 *);
	void (*hash)(struct sock___27 *);
	void (*unhash)(struct sock___27 *);
	void (*rehash)(struct sock___27 *);
	int (*get_port)(struct sock___27 *, short unsigned int);
	void (*clear_sk)(struct sock___27 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___27 *);
	void (*enter_memory_pressure)(struct sock___27 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___225 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___17 *rsk_prot;
	struct timewait_sock_ops___15 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___146 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___73 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___25 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___25 {
	void (*enter_memory_pressure)(struct sock___27 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___17 {
	int family;
	int obj_size;
	struct kmem_cache___225 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___27 *, struct request_sock___18 *);
	void (*send_ack)(struct sock___27 *, struct sk_buff___37 *, struct request_sock___18 *);
	void (*send_reset)(struct sock___27 *, struct sk_buff___37 *);
	void (*destructor)(struct request_sock___18 *);
	void (*syn_ack_timeout)(struct sock___27 *, struct request_sock___18 *);
};

struct timewait_sock_ops___15 {
	struct kmem_cache___225 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___27 *, struct sock___27 *, void *);
	void (*twsk_destructor)(struct sock___27 *);
};

struct tc_stats {
	__u64 bytes;
	__u32 packets;
	__u32 drops;
	__u32 overlimits;
	__u32 bps;
	__u32 pps;
	__u32 qlen;
	__u32 backlog;
};

struct tc_sizespec {
	unsigned char cell_log;
	unsigned char size_log;
	short int cell_align;
	int overhead;
	unsigned int linklayer;
	unsigned int mpu;
	unsigned int mtu;
	unsigned int tsize;
};

struct gnet_dump {
	spinlock_t *lock;
	struct sk_buff___37 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct qdisc_size_table {
	struct callback_head rcu;
	struct list_head list;
	struct tc_sizespec szopts;
	int refcnt;
	u16 data[0];
};

struct Qdisc_class_ops;

struct Qdisc_ops {
	struct Qdisc_ops *next;
	const struct Qdisc_class_ops *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc *);
	struct sk_buff___37 * (*dequeue)(struct Qdisc *);
	struct sk_buff___37 * (*peek)(struct Qdisc *);
	unsigned int (*drop)(struct Qdisc *);
	int (*init)(struct Qdisc *, struct nlattr *);
	void (*reset)(struct Qdisc *);
	void (*destroy)(struct Qdisc *);
	int (*change)(struct Qdisc *, struct nlattr *);
	void (*attach)(struct Qdisc *);
	int (*dump)(struct Qdisc *, struct sk_buff___37 *);
	int (*dump_stats)(struct Qdisc *, struct gnet_dump *);
	struct module___146 *owner;
};

struct qdisc_walker;

struct tcf_proto;

struct Qdisc_class_ops {
	struct netdev_queue___33 * (*select_queue)(struct Qdisc *, struct tcmsg *);
	int (*graft)(struct Qdisc *, long unsigned int, struct Qdisc *, struct Qdisc **);
	struct Qdisc * (*leaf)(struct Qdisc *, long unsigned int);
	void (*qlen_notify)(struct Qdisc *, long unsigned int);
	long unsigned int (*get)(struct Qdisc *, u32);
	void (*put)(struct Qdisc *, long unsigned int);
	int (*change)(struct Qdisc *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc *, long unsigned int);
	void (*walk)(struct Qdisc *, struct qdisc_walker *);
	struct tcf_proto ** (*tcf_chain)(struct Qdisc *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc *, long unsigned int);
	int (*dump)(struct Qdisc *, long unsigned int, struct sk_buff___37 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc *, long unsigned int, struct gnet_dump *);
};

struct qdisc_walker {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc *, long unsigned int, struct qdisc_walker *);
};

struct tcf_result;

struct tcf_proto_ops;

struct tcf_proto {
	struct tcf_proto *next;
	void *root;
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc *q;
	void *data;
	const struct tcf_proto_ops *ops;
};

struct tcf_result {
	long unsigned int class;
	u32 classid;
};

struct tcf_walker;

struct tcf_proto_ops {
	struct tcf_proto_ops *next;
	char kind[16];
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto *, struct tcf_result *);
	int (*init)(struct tcf_proto *);
	void (*destroy)(struct tcf_proto *);
	long unsigned int (*get)(struct tcf_proto *, u32);
	void (*put)(struct tcf_proto *, long unsigned int);
	int (*change)(struct net___47 *, struct sk_buff___37 *, struct tcf_proto *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto *, long unsigned int);
	void (*walk)(struct tcf_proto *, struct tcf_walker *);
	int (*dump)(struct tcf_proto *, long unsigned int, struct sk_buff___37 *, struct tcmsg *);
	struct module___146 *owner;
};

struct pipe_buf_operations___9;

struct pipe_buffer___9 {
	struct page___241 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___9 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___9 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *, int);
	void (*unmap)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *, void *);
	int (*confirm)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	void (*release)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	int (*steal)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	void (*get)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
};

struct splice_pipe_desc___4 {
	struct page___241 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___9 *ops;
	void (*spd_release)(struct splice_pipe_desc___4 *, unsigned int);
};

struct ifmcaddr6___13 {
	struct in6_addr mca_addr;
	struct inet6_dev___13 *idev;
	struct ifmcaddr6___13 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___13 {
	struct in6_addr aca_addr;
	struct inet6_dev___13 *aca_idev;
	struct rt6_info___3 *aca_rt;
	struct ifacaddr6___13 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct sock_extended_err {
	__u32 ee_errno;
	__u8 ee_origin;
	__u8 ee_type;
	__u8 ee_code;
	__u8 ee_pad;
	__u32 ee_info;
	__u32 ee_data;
};

struct sock_exterr_skb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	struct sock_extended_err ee;
	u16 addr_offset;
	__be16 port;
};

struct vlan_hdr {
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct vlan_ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct xfrm_replay___3 {
	void (*advance)(struct xfrm_state___3 *, __be32);
	int (*check)(struct xfrm_state___3 *, struct sk_buff___37 *, __be32);
	int (*recheck)(struct xfrm_state___3 *, struct sk_buff___37 *, __be32);
	void (*notify)(struct xfrm_state___3 *, int);
	int (*overflow)(struct xfrm_state___3 *, struct sk_buff___37 *);
};

struct xfrm_type___3 {
	char *description;
	struct module___146 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___3 *);
	void (*destructor)(struct xfrm_state___3 *);
	int (*input)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*output)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*reject)(struct xfrm_state___3 *, struct sk_buff___37 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___3 *, struct sk_buff___37 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___3 *, int);
};

struct xfrm_state_afinfo___3;

struct xfrm_mode___3 {
	int (*input2)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*input)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*output2)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*output)(struct xfrm_state___3 *, struct sk_buff___37 *);
	struct xfrm_state_afinfo___3 *afinfo;
	struct module___146 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___3 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___146 *owner;
	const struct xfrm_type___3 *type_map[256];
	struct xfrm_mode___3 *mode_map[5];
	int (*init_flags)(struct xfrm_state___3 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___3 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___3 **, struct xfrm_state___3 **, int);
	union {
		int (*output)(struct sock___27 *, struct sk_buff___37 *);
		struct {
			int (*output)(struct sk_buff___37 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___27 *, struct sk_buff___37 *);
		struct {
			int (*output_finish)(struct sk_buff___37 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*extract_output)(struct xfrm_state___3 *, struct sk_buff___37 *);
	int (*transport_finish)(struct sk_buff___37 *, int);
};

struct netdev_alloc_cache {
	struct page_frag___236 frag;
	unsigned int pagecnt_bias;
};

struct page___242;

typedef struct page___242 *pgtable_t___242;

struct address_space___243;

struct kmem_cache___226;

struct page___242 {
	long unsigned int flags;
	struct address_space___243 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___242 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___242 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___226 *slab_cache;
		struct page___242 *first_page;
	};
	long: 64;
};

struct task_struct___244;

struct pv_cpu_ops___244 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___244 *);
	void (*end_context_switch)(struct task_struct___244 *);
};

struct mutex___245 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___244 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___237 {
	struct page___242 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___251;

struct nsproxy___124;

struct signal_struct___244;

struct css_set___139;

struct task_struct___244 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___244 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___251 *mm;
	struct mm_struct___251 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___244 *real_parent;
	struct task_struct___244 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___244 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___244 = 0,
		VTIME_USER___244 = 1,
		VTIME_SYS___244 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___124 *nsproxy;
	struct signal_struct___244 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___139 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___245 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___237 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___251 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___251 *, struct mm_struct___251 *);
	void (*dup_mmap)(struct mm_struct___251 *, struct mm_struct___251 *);
	void (*exit_mmap)(struct mm_struct___251 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___251 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___251 *);
	void (*pgd_free)(struct mm_struct___251 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___251 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___251 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___251 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___251 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___251 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___251 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___251 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___251 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___251 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___251 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___251 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___245 lock;
	void *vdso;
} mm_context_t___245;

struct xol_area___242;

struct uprobes_state___242 {
	struct xol_area___242 *xol_area;
};

struct vm_area_struct___251;

struct file___243;

struct core_state___244;

struct mm_struct___251 {
	struct vm_area_struct___251 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___251 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___251 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___245 context;
	long unsigned int flags;
	struct core_state___244 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___244 *owner;
	struct file___243 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___242 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___29;

struct kobj_type___29;

struct kobject___29 {
	const char *name;
	struct list_head entry;
	struct kobject___29 *parent;
	struct kset___29 *kset;
	struct kobj_type___29 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___147;

struct module_kobject___145 {
	struct kobject___29 kobj;
	struct module___147 *mod;
	struct kobject___29 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___145;

struct module___147 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___145 mkobj;
	struct module_attribute___145 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___29 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___244 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___244;

struct lruvec___244 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___244 *zone;
};

struct pglist_data___244;

struct zone___244 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___244 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___244 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___244 {
	struct zone___244 *zone;
	int zone_idx;
};

struct zonelist___244 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___244 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___244 {
	struct zone___244 node_zones[4];
	struct zonelist___244 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___244 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___167;

struct x86_io_apic_ops___167 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___167 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___167;

struct irq_data___167 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___167 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___241;

struct dev_pm_ops___241 {
	int (*prepare)(struct device___241 *);
	void (*complete)(struct device___241 *);
	int (*suspend)(struct device___241 *);
	int (*resume)(struct device___241 *);
	int (*freeze)(struct device___241 *);
	int (*thaw)(struct device___241 *);
	int (*poweroff)(struct device___241 *);
	int (*restore)(struct device___241 *);
	int (*suspend_late)(struct device___241 *);
	int (*resume_early)(struct device___241 *);
	int (*freeze_late)(struct device___241 *);
	int (*thaw_early)(struct device___241 *);
	int (*poweroff_late)(struct device___241 *);
	int (*restore_early)(struct device___241 *);
	int (*suspend_noirq)(struct device___241 *);
	int (*resume_noirq)(struct device___241 *);
	int (*freeze_noirq)(struct device___241 *);
	int (*thaw_noirq)(struct device___241 *);
	int (*poweroff_noirq)(struct device___241 *);
	int (*restore_noirq)(struct device___241 *);
	int (*runtime_suspend)(struct device___241 *);
	int (*runtime_resume)(struct device___241 *);
	int (*runtime_idle)(struct device___241 *);
};

struct dev_pm_qos___45;

struct dev_pm_info___45 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___45 *qos;
};

struct dma_map_ops___106;

struct dev_archdata___106 {
	struct dma_map_ops___106 *dma_ops;
	void *iommu;
};

struct device_type___241;

struct bus_type___241;

struct device_driver___241;

struct dev_pm_domain___241;

struct class___241;

struct attribute_group___203;

struct device_rh___241;

struct device___241 {
	struct device___241 *parent;
	struct device_private *p;
	struct kobject___29 kobj;
	const char *init_name;
	const struct device_type___241 *type;
	struct mutex___245 mutex;
	struct bus_type___241 *bus;
	struct device_driver___241 *driver;
	void *platform_data;
	struct dev_pm_info___45 power;
	struct dev_pm_domain___241 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___106 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___241 *class;
	const struct attribute_group___203 **groups;
	void (*release)(struct device___241 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___241 *device_rh;
};

struct dev_pm_qos_request___46;

struct dev_pm_qos___45 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___46 *latency_req;
	struct dev_pm_qos_request___46 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___46 *latency_tolerance_req;
};

struct dev_pm_info_rh___241 {
	void (*set_latency_tolerance)(struct device___241 *, s32);
};

struct dev_pm_domain___241 {
	struct dev_pm_ops___241 ops;
};

struct smp_ops___244 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___244 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___49;

struct ctl_node___49 {
	struct rb_node node;
	struct ctl_table_header___49 *header;
};

struct ctl_table_root___49;

struct ctl_table_set___49;

struct ctl_dir___49;

struct ctl_table_header___49 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___49 *root;
	struct ctl_table_set___49 *set;
	struct ctl_dir___49 *parent;
	struct ctl_node___49 *node;
};

struct ctl_dir___49 {
	struct ctl_table_header___49 header;
	struct rb_root root;
};

struct ctl_table_set___49 {
	int (*is_seen)(struct ctl_table_set___49 *);
	struct ctl_dir___49 dir;
};

struct ctl_table_root___49 {
	struct ctl_table_set___49 default_set;
	struct ctl_table_set___49 * (*lookup)(struct ctl_table_root___49 *, struct nsproxy___124 *);
	int (*permissions)(struct ctl_table_header___49 *, struct ctl_table *);
};

struct net___48;

struct nsproxy___124 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___48 *net_ns;
};

struct sock___28;

struct kobj_ns_type_operations___26 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___28 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___26;

struct sock_common___26 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___26 *skc_prot;
	struct net___48 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___38;

struct sk_buff_head___35 {
	struct sk_buff___38 *next;
	struct sk_buff___38 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___27;

struct socket_wq___26;

struct dst_entry___26;

struct socket___27;

struct cg_proto___26;

struct sock___28 {
	struct sock_common___26 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___35 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___38 *head;
		struct sk_buff___38 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___27 *sk_filter;
	struct socket_wq___26 *sk_wq;
	struct sk_buff_head___35 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___26 *sk_rx_dst;
	struct dst_entry___26 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___35 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___35 sk_error_queue;
	struct proto___26 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___27 *sk_socket;
	void *sk_user_data;
	struct page_frag___237 sk_frag;
	struct sk_buff___38 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___26 *sk_cgrp;
	void (*sk_state_change)(struct sock___28 *);
	void (*sk_data_ready)(struct sock___28 *, int);
	void (*sk_write_space)(struct sock___28 *);
	void (*sk_error_report)(struct sock___28 *);
	int (*sk_backlog_rcv)(struct sock___28 *, struct sk_buff___38 *);
	void (*sk_destruct)(struct sock___28 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___205;

struct attribute_group___203 {
	const char *name;
	umode_t (*is_visible)(struct kobject___29 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___205 **bin_attrs;
};

struct bin_attribute___205 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___243 *, struct kobject___29 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___243 *, struct kobject___29 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	int (*mmap)(struct file___243 *, struct kobject___29 *, struct bin_attribute___205 *, struct vm_area_struct___251 *);
};

struct dentry___243;

struct path___243 {
	struct vfsmount *mnt;
	struct dentry___243 *dentry;
};

struct inode___243;

struct file_operations___243;

struct file___243 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___243 f_path;
	struct inode___243 *f_inode;
	const struct file_operations___243 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___243 *f_mapping;
	struct mutex___245 f_pos_lock;
};

struct vm_operations_struct___217;

struct vm_area_struct___251 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___251 *vm_next;
	struct vm_area_struct___251 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___251 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___217 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___243 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___29 {
	ssize_t (*show)(struct kobject___29 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___29 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___29 *, const struct attribute *);
};

struct kset_uevent_ops___29;

struct kset___29 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___29 kobj;
	const struct kset_uevent_ops___29 *uevent_ops;
};

struct kobj_type___29 {
	void (*release)(struct kobject___29 *);
	const struct sysfs_ops___29 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___26 * (*child_ns_type)(struct kobject___29 *);
	const void * (*namespace)(struct kobject___29 *);
};

struct kset_uevent_ops___29 {
	int (* const filter)(struct kset___29 *, struct kobject___29 *);
	const char * (* const name)(struct kset___29 *, struct kobject___29 *);
	int (* const uevent)(struct kset___29 *, struct kobject___29 *, struct kobj_uevent_env *);
};

struct module_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___145 *, struct module_kobject___145 *, char *);
	ssize_t (*store)(struct module_attribute___145 *, struct module_kobject___145 *, const char *, size_t);
	void (*setup)(struct module___147 *, const char *);
	int (*test)(struct module___147 *);
	void (*free)(struct module___147 *);
};

struct xol_area___242 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___242 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___225;

struct memcg_cache_params___226;

struct kmem_cache___226 {
	struct kmem_cache_cpu___225 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___29 kobj;
	struct memcg_cache_params___226 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___243;

struct address_space___243 {
	struct inode___243 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___245 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___243 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___213;

struct vm_operations_struct___217 {
	void (*open)(struct vm_area_struct___251 *);
	void (*close)(struct vm_area_struct___251 *);
	int (*fault)(struct vm_area_struct___251 *, struct vm_fault___213 *);
	int (*page_mkwrite)(struct vm_area_struct___251 *, struct vm_fault___213 *);
	int (*access)(struct vm_area_struct___251 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___251 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___251 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___251 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___251 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___244 {
	struct task_struct___244 *task;
	struct core_thread___244 *next;
};

struct core_state___244 {
	atomic_t nr_threads;
	struct core_thread___244 dumper;
	struct completion startup;
};

struct vm_fault___213 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___242 *page;
};

struct fasync_struct___243;

struct socket_wq___26 {
	wait_queue_head_t wait;
	struct fasync_struct___243 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___243 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___243 *fa_next;
	struct file___243 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___26;

struct socket___27 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___26 *wq;
	struct file___243 *file;
	struct sock___28 *sk;
	const struct proto_ops___26 *ops;
};

struct poll_table_struct___133;

struct kiocb___34;

struct proto_ops___26 {
	int family;
	struct module___147 *owner;
	int (*release)(struct socket___27 *);
	int (*bind)(struct socket___27 *, struct sockaddr *, int);
	int (*connect)(struct socket___27 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___27 *, struct socket___27 *);
	int (*accept)(struct socket___27 *, struct socket___27 *, int);
	int (*getname)(struct socket___27 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___243 *, struct socket___27 *, struct poll_table_struct___133 *);
	int (*ioctl)(struct socket___27 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___27 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___27 *, int);
	int (*shutdown)(struct socket___27 *, int);
	int (*setsockopt)(struct socket___27 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___27 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___27 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___27 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___34 *, struct socket___27 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___34 *, struct socket___27 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___243 *, struct socket___27 *, struct vm_area_struct___251 *);
	ssize_t (*sendpage)(struct socket___27 *, struct page___242 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___27 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___28 *, int);
		struct {
			void (*set_peek_off)(struct sock___28 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___135)(struct file___243 *, wait_queue_head_t *, struct poll_table_struct___133 *);

struct poll_table_struct___133 {
	poll_queue_proc___135 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___34(struct kiocb___34 *, struct io_event *);

struct kiocb___34 {
	atomic_t ki_users;
	struct file___243 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___34 *ki_cancel;
	void (*ki_dtor)(struct kiocb___34 *);
	union {
		void *user;
		struct task_struct___244 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___46 {
	struct ctl_table_header___49 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___46 {
	struct mutex___245 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___46 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___49 *ctl;
};

struct netns_ipv4___46 {
	struct ctl_table_header___49 *forw_hdr;
	struct ctl_table_header___49 *frags_hdr;
	struct ctl_table_header___49 *ipv4_hdr;
	struct ctl_table_header___49 *route_hdr;
	struct ctl_table_header___49 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___28 *fibnl;
	struct sock___28 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___46 {
	struct ctl_table_header___49 *hdr;
	struct ctl_table_header___49 *route_hdr;
	struct ctl_table_header___49 *icmp_hdr;
	struct ctl_table_header___49 *frags_hdr;
	struct ctl_table_header___49 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___36;

struct neighbour___26;

struct dst_ops___47 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___47 *);
	struct dst_entry___26 * (*check)(struct dst_entry___26 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___26 *);
	unsigned int (*mtu)(const struct dst_entry___26 *);
	u32 * (*cow_metrics)(struct dst_entry___26 *, long unsigned int);
	void (*destroy)(struct dst_entry___26 *);
	void (*ifdown)(struct dst_entry___26 *, struct net_device___36 *, int);
	struct dst_entry___26 * (*negative_advice)(struct dst_entry___26 *);
	void (*link_failure)(struct sk_buff___38 *);
	void (*update_pmtu)(struct dst_entry___26 *, struct sock___28 *, struct sk_buff___38 *, u32);
	void (*redirect)(struct dst_entry___26 *, struct sock___28 *, struct sk_buff___38 *);
	int (*local_out)(struct sk_buff___38 *);
	struct neighbour___26 * (*neigh_lookup)(const struct dst_entry___26 *, struct sk_buff___38 *, const void *);
	struct kmem_cache___226 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___47 {
	struct netns_sysctl_ipv6___46 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___47 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___28 **icmp_sk;
	struct sock___28 *ndisc_sk;
	struct sock___28 *tcp_sk;
	struct sock___28 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___46 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___49 *sysctl_header;
	struct sock___28 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___26 {
	struct sock___28 *v4_ctl_sk;
	struct sock___28 *v6_ctl_sk;
};

struct netns_nf___46 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___49 *nf_log_dir_header;
};

struct nf_proto_net___46 {
	struct ctl_table_header___49 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___46 {
	struct nf_proto_net___46 pn;
	unsigned int timeout;
};

struct nf_tcp_net___46 {
	struct nf_proto_net___46 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___46 {
	struct nf_proto_net___46 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___46 {
	struct nf_proto_net___46 pn;
	unsigned int timeout;
};

struct nf_ip_net___46 {
	struct nf_generic_net___46 generic;
	struct nf_tcp_net___46 tcp;
	struct nf_udp_net___46 udp;
	struct nf_icmp_net___46 icmp;
	struct nf_icmp_net___46 icmpv6;
};

struct netns_ct___46 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___49 *sysctl_header;
	struct ctl_table_header___49 *acct_sysctl_header;
	struct ctl_table_header___49 *tstamp_sysctl_header;
	struct ctl_table_header___49 *event_sysctl_header;
	struct ctl_table_header___49 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___226 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___46 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___46 {
	struct netns_sysctl_ipv6___46 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___47 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___28 *nlsk;
	struct sock___28 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___49 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___47 xfrm4_dst_ops;
	struct dst_ops___47 xfrm6_dst_ops;
};

struct net___48 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___49 sysctls;
	struct sock___28 *rtnl;
	struct sock___28 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___36 *loopback_dev;
	struct netns_core___46 core;
	struct netns_mib mib;
	struct netns_packet___46 packet;
	struct netns_unix___46 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___46 ipv4;
	struct netns_ipv6___47 ipv6;
	struct netns_sctp___46 sctp;
	struct netns_dccp___26 dccp;
	struct netns_nf___46 nf;
	struct netns_xt xt;
	struct netns_ct___46 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___46 nf_frag;
	struct sock___28 *nfnl;
	struct sock___28 *nfnl_stash;
	struct sk_buff_head___35 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___47 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___28 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___28 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___245 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___245 flow_flush_sem;
	long: 64;
	long: 64;
};

struct seq_file___168;

struct irq_chip___167 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___167 *);
	void (*irq_shutdown)(struct irq_data___167 *);
	void (*irq_enable)(struct irq_data___167 *);
	void (*irq_disable)(struct irq_data___167 *);
	void (*irq_ack)(struct irq_data___167 *);
	void (*irq_mask)(struct irq_data___167 *);
	void (*irq_mask_ack)(struct irq_data___167 *);
	void (*irq_unmask)(struct irq_data___167 *);
	void (*irq_eoi)(struct irq_data___167 *);
	int (*irq_set_affinity)(struct irq_data___167 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___167 *);
	int (*irq_set_type)(struct irq_data___167 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___167 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___167 *);
	void (*irq_bus_sync_unlock)(struct irq_data___167 *);
	void (*irq_cpu_online)(struct irq_data___167 *);
	void (*irq_cpu_offline)(struct irq_data___167 *);
	void (*irq_suspend)(struct irq_data___167 *);
	void (*irq_resume)(struct irq_data___167 *);
	void (*irq_pm_shutdown)(struct irq_data___167 *);
	void (*irq_print_chip)(struct irq_data___167 *, struct seq_file___168 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___167 *, void *);
	long unsigned int flags;
};

struct seq_operations___168;

struct seq_file___168 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___245 lock;
	const struct seq_operations___168 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___243;

struct file_operations___243 {
	struct module___147 *owner;
	loff_t (*llseek)(struct file___243 *, loff_t, int);
	ssize_t (*read)(struct file___243 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___243 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___34 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___34 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___243 *, void *, filldir_t);
	unsigned int (*poll)(struct file___243 *, struct poll_table_struct___133 *);
	long int (*unlocked_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___243 *, struct vm_area_struct___251 *);
	int (*open)(struct inode___243 *, struct file___243 *);
	int (*flush)(struct file___243 *, fl_owner_t);
	int (*release)(struct inode___243 *, struct file___243 *);
	int (*fsync)(struct file___243 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___34 *, int);
	int (*fasync)(int, struct file___243 *, int);
	int (*lock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*sendpage)(struct file___243 *, struct page___242 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___243 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___243 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___243 *, long int, struct file_lock___243 **, void **);
		struct {
			int (*setlease)(struct file___243 *, long int, struct file_lock___243 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___243 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___168 *, struct file___243 *);
};

struct dma_map_ops___106 {
	void * (*alloc)(struct device___241 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___241 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___241 *, struct vm_area_struct___251 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___241 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___241 *, struct page___242 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___241 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___241 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___241 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___241 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___241 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___241 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___241 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___241 *, dma_addr_t);
	int (*dma_supported)(struct device___241 *, u64);
	int (*set_dma_mask)(struct device___241 *, u64);
	int is_phys;
};

struct bus_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___241 *, char *);
	ssize_t (*store)(struct bus_type___241 *, const char *, size_t);
};

struct device_attribute___241;

struct driver_attribute___241;

struct bus_type___241 {
	const char *name;
	const char *dev_name;
	struct device___241 *dev_root;
	struct bus_attribute___241 *bus_attrs;
	struct device_attribute___241 *dev_attrs;
	struct driver_attribute___241 *drv_attrs;
	const struct attribute_group___203 **bus_groups;
	const struct attribute_group___203 **dev_groups;
	const struct attribute_group___203 **drv_groups;
	int (*match)(struct device___241 *, struct device_driver___241 *);
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	int (*probe)(struct device___241 *);
	int (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*online)(struct device___241 *);
	int (*offline)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct device___241 *, struct device_attribute___241 *, char *);
	ssize_t (*store)(struct device___241 *, struct device_attribute___241 *, const char *, size_t);
};

struct driver_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___241 *, char *);
	ssize_t (*store)(struct device_driver___241 *, const char *, size_t);
};

struct device_driver___241 {
	const char *name;
	struct bus_type___241 *bus;
	struct module___147 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___241 *);
	int (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	const struct attribute_group___203 **groups;
	const struct dev_pm_ops___241 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___241 {
	const char *name;
	const struct attribute_group___203 **groups;
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
};

struct class_attribute___241;

struct class___241 {
	const char *name;
	struct module___147 *owner;
	struct class_attribute___241 *class_attrs;
	struct device_attribute___241 *dev_attrs;
	const struct attribute_group___203 **dev_groups;
	struct bin_attribute___205 *dev_bin_attrs;
	struct kobject___29 *dev_kobj;
	int (*dev_uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *);
	void (*class_release)(struct class___241 *);
	void (*dev_release)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	const struct kobj_ns_type_operations___26 *ns_type;
	const void * (*namespace)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
	struct subsys_private *p;
};

struct class_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct class___241 *, struct class_attribute___241 *, char *);
	ssize_t (*store)(struct class___241 *, struct class_attribute___241 *, const char *, size_t);
	const void * (*namespace)(struct class___241 *, const struct class_attribute___241 *);
};

struct device_rh___241 {
	struct dev_pm_info_rh___241 power;
};

struct dev_pm_qos_request___46 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___241 *dev;
};

struct dentry_operations___243;

struct super_block___243;

struct dentry___243 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___243 *d_parent;
	struct qstr d_name;
	struct inode___243 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___243 *d_op;
	struct super_block___243 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___243;

struct dquot___243;

struct block_device___243;

struct inode___243 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___243 *i_op;
	struct super_block___243 *i_sb;
	struct address_space___243 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___245 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___243 *i_fop;
	struct file_lock___243 *i_flock;
	struct address_space___243 i_data;
	struct dquot___243 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___243 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___243 {
	int (*d_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_hash)(const struct dentry___243 *, struct qstr *);
	int (*d_compare)(const struct dentry___243 *, const struct dentry___243 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___243 *);
	void (*d_release)(struct dentry___243 *);
	void (*d_prune)(struct dentry___243 *);
	void (*d_iput)(struct dentry___243 *, struct inode___243 *);
	char * (*d_dname)(struct dentry___243 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___243 *);
	int (*d_manage)(struct dentry___243 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___243;

struct mem_dqinfo___243 {
	struct quota_format_type___243 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___243;

struct quota_info___243 {
	unsigned int flags;
	struct mutex___245 dqio_mutex;
	struct mutex___245 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___243 *files[2];
	struct mem_dqinfo___243 info[2];
	const struct quota_format_ops___243 *ops[2];
};

struct file_system_type___243;

struct super_operations___243;

struct dquot_operations___243;

struct quotactl_ops___243;

struct xattr_handler___140;

struct super_block___243 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___243 *s_type;
	const struct super_operations___243 *s_op;
	const struct dquot_operations___243 *dq_op;
	const struct quotactl_ops___243 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___243 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___140 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___243 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___243 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___245 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___243 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___243 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___243 *bd_inode;
	struct super_block___243 *bd_super;
	struct mutex___245 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___243 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___245 bd_fsfreeze_mutex;
};

struct cgroup___139;

struct cgroup_subsys_state___139 {
	struct cgroup___139 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___243 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___243 *ia_file;
};

struct dquot___243 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___245 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___243 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___243 {
	int qf_fmt_id;
	const struct quota_format_ops___243 *qf_ops;
	struct module___147 *qf_owner;
	struct quota_format_type___243 *qf_next;
};

struct quota_format_ops___243 {
	int (*check_quota_file)(struct super_block___243 *, int);
	int (*read_file_info)(struct super_block___243 *, int);
	int (*write_file_info)(struct super_block___243 *, int);
	int (*free_file_info)(struct super_block___243 *, int);
	int (*read_dqblk)(struct dquot___243 *);
	int (*commit_dqblk)(struct dquot___243 *);
	int (*release_dqblk)(struct dquot___243 *);
};

struct dquot_operations___243 {
	int (*write_dquot)(struct dquot___243 *);
	struct dquot___243 * (*alloc_dquot)(struct super_block___243 *, int);
	void (*destroy_dquot)(struct dquot___243 *);
	int (*acquire_dquot)(struct dquot___243 *);
	int (*release_dquot)(struct dquot___243 *);
	int (*mark_dirty)(struct dquot___243 *);
	int (*write_info)(struct super_block___243 *, int);
	qsize_t * (*get_reserved_space)(struct inode___243 *);
};

struct quotactl_ops___243 {
	int (*quota_on)(struct super_block___243 *, int, int, struct path___243 *);
	int (*quota_on_meta)(struct super_block___243 *, int, int);
	int (*quota_off)(struct super_block___243 *, int);
	int (*quota_sync)(struct super_block___243 *, int);
	int (*get_info)(struct super_block___243 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___243 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___243 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___243 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___243 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___243 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___243 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___243 *, unsigned int);
};

struct address_space_operations___243 {
	int (*writepage)(struct page___242 *, struct writeback_control *);
	int (*readpage)(struct file___243 *, struct page___242 *);
	int (*writepages)(struct address_space___243 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___242 *);
	int (*readpages)(struct file___243 *, struct address_space___243 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___243 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___242 **, void **);
	int (*write_end)(struct file___243 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___242 *, void *);
	sector_t (*bmap)(struct address_space___243 *, sector_t);
	void (*invalidatepage)(struct page___242 *, long unsigned int);
	int (*releasepage)(struct page___242 *, gfp_t);
	void (*freepage)(struct page___242 *);
	ssize_t (*direct_IO)(int, struct kiocb___34 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___243 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___243 *, struct page___242 *, struct page___242 *, enum migrate_mode);
	int (*launder_page)(struct page___242 *);
	int (*is_partially_uptodate)(struct page___242 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___242 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___243 *, struct page___242 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___243 *, sector_t *);
	void (*swap_deactivate)(struct file___243 *);
	void (*invalidatepage_range)(struct page___242 *, unsigned int, unsigned int);
};

struct inode_operations___243 {
	struct dentry___243 * (*lookup)(struct inode___243 *, struct dentry___243 *, unsigned int);
	void * (*follow_link)(struct dentry___243 *, struct nameidata *);
	int (*permission)(struct inode___243 *, int);
	struct posix_acl * (*get_acl)(struct inode___243 *, int);
	int (*readlink)(struct dentry___243 *, char *, int);
	void (*put_link)(struct dentry___243 *, struct nameidata *, void *);
	int (*create)(struct inode___243 *, struct dentry___243 *, umode_t, bool);
	int (*link)(struct dentry___243 *, struct inode___243 *, struct dentry___243 *);
	int (*unlink)(struct inode___243 *, struct dentry___243 *);
	int (*symlink)(struct inode___243 *, struct dentry___243 *, const char *);
	int (*mkdir)(struct inode___243 *, struct dentry___243 *, umode_t);
	int (*rmdir)(struct inode___243 *, struct dentry___243 *);
	int (*mknod)(struct inode___243 *, struct dentry___243 *, umode_t, dev_t);
	int (*rename)(struct inode___243 *, struct dentry___243 *, struct inode___243 *, struct dentry___243 *);
	int (*setattr)(struct dentry___243 *, struct iattr___243 *);
	int (*getattr)(struct vfsmount *, struct dentry___243 *, struct kstat *);
	int (*setxattr)(struct dentry___243 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___243 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___243 *, char *, size_t);
	int (*removexattr)(struct dentry___243 *, const char *);
	int (*fiemap)(struct inode___243 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___243 *, struct timespec *, int);
	int (*atomic_open)(struct inode___243 *, struct dentry___243 *, struct file___243 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___243;

struct lock_manager_operations___243;

struct file_lock___243 {
	struct file_lock___243 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___243 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___243 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___243 *fl_ops;
	const struct lock_manager_operations___243 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___243 {
	void (*fl_copy_lock)(struct file_lock___243 *, struct file_lock___243 *);
	void (*fl_release_private)(struct file_lock___243 *);
};

struct lock_manager_operations___243 {
	int (*lm_compare_owner)(struct file_lock___243 *, struct file_lock___243 *);
	long unsigned int (*lm_owner_key)(struct file_lock___243 *);
	void (*lm_notify)(struct file_lock___243 *);
	int (*lm_grant)(struct file_lock___243 *, struct file_lock___243 *, int);
	void (*lm_break)(struct file_lock___243 *);
	int (*lm_change)(struct file_lock___243 **, int);
};

struct file_system_type___243 {
	const char *name;
	int fs_flags;
	struct dentry___243 * (*mount)(struct file_system_type___243 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___243 *);
	struct module___147 *owner;
	struct file_system_type___243 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___243 {
	struct inode___243 * (*alloc_inode)(struct super_block___243 *);
	void (*destroy_inode)(struct inode___243 *);
	void (*dirty_inode)(struct inode___243 *, int);
	int (*write_inode)(struct inode___243 *, struct writeback_control *);
	int (*drop_inode)(struct inode___243 *);
	void (*evict_inode)(struct inode___243 *);
	void (*put_super)(struct super_block___243 *);
	int (*sync_fs)(struct super_block___243 *, int);
	int (*freeze_fs)(struct super_block___243 *);
	int (*unfreeze_fs)(struct super_block___243 *);
	int (*statfs)(struct dentry___243 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___243 *, int *, char *);
	void (*umount_begin)(struct super_block___243 *);
	int (*show_options)(struct seq_file___168 *, struct dentry___243 *);
	int (*show_devname)(struct seq_file___168 *, struct dentry___243 *);
	int (*show_path)(struct seq_file___168 *, struct dentry___243 *);
	int (*show_stats)(struct seq_file___168 *, struct dentry___243 *);
	ssize_t (*quota_read)(struct super_block___243 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___243 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___243 *);
	int (*bdev_try_to_free_page)(struct super_block___243 *, struct page___242 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___243 *);
	void (*free_cached_objects)(struct super_block___243 *, int);
};

struct xattr_handler___140 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___243 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___243 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___243 *, const char *, const void *, size_t, int, int);
};

struct signal_struct___244 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___244 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___244 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___245 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___139 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___139 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___225 {
	void **freelist;
	long unsigned int tid;
	struct page___242 *page;
	struct page___242 *partial;
};

struct memcg_cache_params___226 {
	bool is_root_cache;
	union {
		struct kmem_cache___226 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___226 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___34 {
	atomic_t use;
	unsigned int mask;
	struct net_device___36 *physindev;
	struct net_device___36 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___34(struct sk_buff___38 **);

struct net_device_ops___34;

struct ethtool_ops___34;

struct header_ops___34;

struct netdev_rx_queue___34;

struct netdev_queue___34;

struct rtnl_link_ops___26;

struct dcbnl_rtnl_ops___34;

struct net_device___36 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___34 *netdev_ops;
	const struct ethtool_ops___34 *ethtool_ops;
	const struct header_ops___34 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___29 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___34 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___34 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___34 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___34 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___34 = 0,
		NETREG_REGISTERED___34 = 1,
		NETREG_UNREGISTERING___34 = 2,
		NETREG_UNREGISTERED___34 = 3,
		NETREG_RELEASED___34 = 4,
		NETREG_DUMMY___34 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___34 = 0,
		RTNL_LINK_INITIALIZING___34 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___36 *);
	struct netpoll_info *npinfo;
	struct net___48 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___241 dev;
	const struct attribute_group___203 *sysfs_groups[4];
	const struct rtnl_link_ops___26 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___34 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___38 {
	struct sk_buff___38 *next;
	struct sk_buff___38 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___28 *sk;
	struct net_device___36 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___38 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___34 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___34 {
	int (*get_settings)(struct net_device___36 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___36 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___36 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___36 *);
	void (*get_regs)(struct net_device___36 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___36 *);
	void (*set_msglevel)(struct net_device___36 *, u32);
	int (*nway_reset)(struct net_device___36 *);
	u32 (*get_link)(struct net_device___36 *);
	int (*get_eeprom_len)(struct net_device___36 *);
	int (*get_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___36 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___36 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___36 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___36 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___36 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___36 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___36 *);
	void (*complete)(struct net_device___36 *);
	u32 (*get_priv_flags)(struct net_device___36 *);
	int (*set_priv_flags)(struct net_device___36 *, u32);
	int (*get_sset_count)(struct net_device___36 *, int);
	int (*get_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___36 *, struct ethtool_flash *);
	int (*reset)(struct net_device___36 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___36 *);
	int (*get_rxfh_indir)(struct net_device___36 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___36 *, const u32 *);
	void (*get_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___36 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___36 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___36 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___36 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___36 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___36 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___36 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___36 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___26 {
	struct callback_head callback_head;
	struct dst_entry___26 *child;
	struct net_device___36 *dev;
	struct dst_ops___47 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___26 *path;
	struct dst_entry___26 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___38 *);
	union {
		int (*output)(struct sock___28 *, struct sk_buff___38 *);
		struct {
			int (*output)(struct sk_buff___38 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___26 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___26;

struct neigh_parms___26;

struct neigh_ops___26;

struct neighbour___26 {
	struct neighbour___26 *next;
	struct neigh_table___26 *tbl;
	struct neigh_parms___26 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___35 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___26 *, struct sk_buff___38 *);
	const struct neigh_ops___26 *ops;
	struct callback_head rcu;
	struct net_device___36 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___47 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___38 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___38 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___48 *, struct dst_entry___26 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___38 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___38 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___168 {
	void * (*start)(struct seq_file___168 *, loff_t *);
	void (*stop)(struct seq_file___168 *, void *);
	void * (*next)(struct seq_file___168 *, void *, loff_t *);
	int (*show)(struct seq_file___168 *, void *);
};

struct dcbnl_rtnl_ops___34 {
	int (*ieee_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___36 *);
	u8 (*setstate)(struct net_device___36 *, u8);
	void (*getpermhwaddr)(struct net_device___36 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___36 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___36 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___36 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___36 *, int, u8 *);
	void (*setpfccfg)(struct net_device___36 *, int, u8);
	void (*getpfccfg)(struct net_device___36 *, int, u8 *);
	u8 (*setall)(struct net_device___36 *);
	u8 (*getcap)(struct net_device___36 *, int, u8 *);
	int (*getnumtcs)(struct net_device___36 *, int, u8 *);
	int (*setnumtcs)(struct net_device___36 *, int, u8);
	u8 (*getpfcstate)(struct net_device___36 *);
	void (*setpfcstate)(struct net_device___36 *, u8);
	void (*getbcncfg)(struct net_device___36 *, int, u32 *);
	void (*setbcncfg)(struct net_device___36 *, int, u32);
	void (*getbcnrp)(struct net_device___36 *, int, u8 *);
	void (*setbcnrp)(struct net_device___36 *, int, u8);
	u8 (*setapp)(struct net_device___36 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___36 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___36 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___36 *, int, u8);
	u8 (*getdcbx)(struct net_device___36 *);
	u8 (*setdcbx)(struct net_device___36 *, u8);
	int (*peer_getappinfo)(struct net_device___36 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___36 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___36 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___36 *, struct cee_pfc *);
};

struct cgroupfs_root___139;

struct cgroup___139 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___139 *parent;
	struct dentry___243 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___139 *subsys[11];
	struct cgroupfs_root___139 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___245 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___139 {
	struct super_block___243 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___139 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___78 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___243 *, struct file___243 *);
	ssize_t (*read)(struct cgroup___139 *, struct cftype___78 *, struct file___243 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___139 *, struct cftype___78 *);
	s64 (*read_s64)(struct cgroup___139 *, struct cftype___78 *);
	int (*read_map)(struct cgroup___139 *, struct cftype___78 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___139 *, struct cftype___78 *, struct seq_file___168 *);
	ssize_t (*write)(struct cgroup___139 *, struct cftype___78 *, struct file___243 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___139 *, struct cftype___78 *, u64);
	int (*write_s64)(struct cgroup___139 *, struct cftype___78 *, s64);
	int (*write_string)(struct cgroup___139 *, struct cftype___78 *, const char *);
	int (*trigger)(struct cgroup___139 *, unsigned int);
	int (*release)(struct inode___243 *, struct file___243 *);
	int (*register_event)(struct cgroup___139 *, struct cftype___78 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___139 *, struct cftype___78 *, struct eventfd_ctx *);
};

struct cftype_set___74 {
	struct list_head node;
	struct cftype___78 *cfts;
};

struct task_and_cgroup___74 {
	struct task_struct___244 *task;
	struct cgroup___139 *cgrp;
	struct css_set___139 *cg;
};

struct cgroup_taskset___74 {
	struct task_and_cgroup___74 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___139 *cur_cgrp;
};

struct cgroup_subsys___74 {
	struct cgroup_subsys_state___139 * (*css_alloc)(struct cgroup___139 *);
	int (*css_online)(struct cgroup___139 *);
	void (*css_offline)(struct cgroup___139 *);
	void (*css_free)(struct cgroup___139 *);
	int (*can_attach)(struct cgroup___139 *, struct cgroup_taskset___74 *);
	void (*cancel_attach)(struct cgroup___139 *, struct cgroup_taskset___74 *);
	void (*attach)(struct cgroup___139 *, struct cgroup_taskset___74 *);
	void (*fork)(struct task_struct___244 *);
	void (*exit)(struct cgroup___139 *, struct cgroup___139 *, struct task_struct___244 *);
	void (*bind)(struct cgroup___139 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___139 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___78 *base_cftypes;
	struct cftype_set___74 base_cftset;
	struct module___147 *module;
};

struct netlink_callback___36 {
	struct sk_buff___38 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___38 *, struct netlink_callback___36 *);
	int (*done)(struct netlink_callback___36 *);
	void *data;
	struct module___147 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___34 {
	int (*create)(struct sk_buff___38 *, struct net_device___36 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___38 *, unsigned char *);
	int (*rebuild)(struct sk_buff___38 *);
	int (*cache)(const struct neighbour___26 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___36 *, const unsigned char *);
};

struct napi_struct___34 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___34 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___36 *dev;
	struct sk_buff___38 *gro_list;
	struct sk_buff___38 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___34 {
	struct net_device___36 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___29 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___34 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___29 kobj;
	struct net_device___36 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___34 {
	int (*ndo_init)(struct net_device___36 *);
	void (*ndo_uninit)(struct net_device___36 *);
	int (*ndo_open)(struct net_device___36 *);
	int (*ndo_stop)(struct net_device___36 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___38 *, struct net_device___36 *);
	u16 (*ndo_select_queue)(struct net_device___36 *, struct sk_buff___38 *);
	void (*ndo_change_rx_flags)(struct net_device___36 *, int);
	void (*ndo_set_rx_mode)(struct net_device___36 *);
	int (*ndo_set_mac_address)(struct net_device___36 *, void *);
	int (*ndo_validate_addr)(struct net_device___36 *);
	int (*ndo_do_ioctl)(struct net_device___36 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___36 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___36 *, int);
	int (*ndo_neigh_setup)(struct net_device___36 *, struct neigh_parms___26 *);
	void (*ndo_tx_timeout)(struct net_device___36 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___36 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___36 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___36 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___36 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___36 *);
	int (*ndo_netpoll_setup)(struct net_device___36 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___36 *);
	int (*ndo_busy_poll)(struct napi_struct___34 *);
	int (*ndo_set_vf_mac)(struct net_device___36 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___36 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___36 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___36 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___36 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___36 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___36 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___36 *, int, struct sk_buff___38 *);
	int (*ndo_setup_tc)(struct net_device___36 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___36 *);
	int (*ndo_fcoe_disable)(struct net_device___36 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___36 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___36 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___36 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___36 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___36 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___36 *, const struct sk_buff___38 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___36 *, struct net_device___36 *);
	int (*ndo_del_slave)(struct net_device___36 *, struct net_device___36 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___26 *);
	void (*ndo_neigh_destroy)(struct neighbour___26 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___38 *, struct netlink_callback___36 *, struct net_device___36 *, int);
	int (*ndo_bridge_setlink)(struct net_device___36 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___38 *, u32, u32, struct net_device___36 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___36 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___36 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___36 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___36 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___36 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___36 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___38 *, struct net_device___36 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___36 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___36 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___36 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___26 {
	struct net___48 *net;
	struct net_device___36 *dev;
	struct neigh_parms___26 *next;
	int (*neigh_setup)(struct neighbour___26 *);
	void (*neigh_cleanup)(struct neighbour___26 *);
	struct neigh_table___26 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___26 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___36 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___48 *, struct net_device___36 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___36 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___36 *, struct list_head *);
	size_t (*get_size)(const struct net_device___36 *);
	int (*fill_info)(struct sk_buff___38 *, const struct net_device___36 *);
	size_t (*get_xstats_size)(const struct net_device___36 *);
	int (*fill_xstats)(struct sk_buff___38 *, const struct net_device___36 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___48 * (*get_link_net)(const struct net_device___36 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___36 *, struct net_device___36 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___36 *, const struct net_device___36 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___38 *, const struct net_device___36 *, const struct net_device___36 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___27 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___38 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___26;

struct neigh_hash_table___26;

struct neigh_table___26 {
	struct neigh_table___26 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___36 *, __u32 *);
	int (*constructor)(struct neighbour___26 *);
	int (*pconstructor)(struct pneigh_entry___26 *);
	void (*pdestructor)(struct pneigh_entry___26 *);
	void (*proxy_redo)(struct sk_buff___38 *);
	char *id;
	struct neigh_parms___26 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___35 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___26 *nht;
	struct pneigh_entry___26 **phash_buckets;
};

struct neigh_ops___26 {
	int family;
	void (*solicit)(struct neighbour___26 *, struct sk_buff___38 *);
	void (*error_report)(struct neighbour___26 *, struct sk_buff___38 *);
	int (*output)(struct neighbour___26 *, struct sk_buff___38 *);
	int (*connected_output)(struct neighbour___26 *, struct sk_buff___38 *);
};

struct pneigh_entry___26 {
	struct pneigh_entry___26 *next;
	struct net___48 *net;
	struct net_device___36 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___26 {
	struct neighbour___26 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___26 {
	void (*close)(struct sock___28 *, long int);
	int (*connect)(struct sock___28 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___28 *, int);
	struct sock___28 * (*accept)(struct sock___28 *, int, int *);
	int (*ioctl)(struct sock___28 *, int, long unsigned int);
	int (*init)(struct sock___28 *);
	void (*destroy)(struct sock___28 *);
	void (*shutdown)(struct sock___28 *, int);
	int (*setsockopt)(struct sock___28 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___28 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___28 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___28 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___28 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___34 *, struct sock___28 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___34 *, struct sock___28 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___28 *, struct page___242 *, int, size_t, int);
	int (*bind)(struct sock___28 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___28 *, struct sk_buff___38 *);
	void (*release_cb)(struct sock___28 *);
	void (*mtu_reduced)(struct sock___28 *);
	void (*hash)(struct sock___28 *);
	void (*unhash)(struct sock___28 *);
	void (*rehash)(struct sock___28 *);
	int (*get_port)(struct sock___28 *, short unsigned int);
	void (*clear_sk)(struct sock___28 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___28 *);
	void (*enter_memory_pressure)(struct sock___28 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___226 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___147 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___74 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___26 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___26 {
	void (*enter_memory_pressure)(struct sock___28 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct page___243;

typedef struct page___243 *pgtable_t___243;

struct address_space___244;

struct kmem_cache___227;

struct page___243 {
	long unsigned int flags;
	struct address_space___244 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___243 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___243 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___227 *slab_cache;
		struct page___243 *first_page;
	};
	long: 64;
};

struct task_struct___245;

struct pv_cpu_ops___245 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___245 *);
	void (*end_context_switch)(struct task_struct___245 *);
};

struct mutex___246 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___245 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___238 {
	struct page___243 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___252;

struct nsproxy___125;

struct signal_struct___245;

struct css_set___140;

struct task_struct___245 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___245 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___252 *mm;
	struct mm_struct___252 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___245 *real_parent;
	struct task_struct___245 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___245 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___94 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___245 = 0,
		VTIME_USER___245 = 1,
		VTIME_SYS___245 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___125 *nsproxy;
	struct signal_struct___245 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___140 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___246 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___238 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___252 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___252 *, struct mm_struct___252 *);
	void (*dup_mmap)(struct mm_struct___252 *, struct mm_struct___252 *);
	void (*exit_mmap)(struct mm_struct___252 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___252 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___252 *);
	void (*pgd_free)(struct mm_struct___252 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___252 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___252 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___252 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___252 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___252 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___252 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___252 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___252 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___252 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___252 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___252 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___246 lock;
	void *vdso;
} mm_context_t___246;

struct xol_area___243;

struct uprobes_state___243 {
	struct xol_area___243 *xol_area;
};

struct vm_area_struct___252;

struct file___244;

struct core_state___245;

struct mm_struct___252 {
	struct vm_area_struct___252 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___252 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___252 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___246 context;
	long unsigned int flags;
	struct core_state___245 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___245 *owner;
	struct file___244 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___243 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___148;

struct exec_domain___69 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___148 *module;
	struct exec_domain___69 *next;
};

struct kset___30;

struct kobj_type___30;

struct kobject___30 {
	const char *name;
	struct list_head entry;
	struct kobject___30 *parent;
	struct kset___30 *kset;
	struct kobj_type___30 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___146 {
	struct kobject___30 kobj;
	struct module___148 *mod;
	struct kobject___30 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___146;

struct module___148 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___146 mkobj;
	struct module_attribute___146 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___30 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___245 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___114 {
	struct task_struct___245 *task;
	struct exec_domain___69 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___245;

struct lruvec___245 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___245 *zone;
};

struct pglist_data___245;

struct zone___245 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___245 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___245 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___245 {
	struct zone___245 *zone;
	int zone_idx;
};

struct zonelist___245 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___245 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___245 {
	struct zone___245 node_zones[4];
	struct zonelist___245 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___245 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___168;

struct x86_io_apic_ops___168 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___168 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___168;

struct irq_data___168 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___168 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___242;

struct dev_pm_ops___242 {
	int (*prepare)(struct device___242 *);
	void (*complete)(struct device___242 *);
	int (*suspend)(struct device___242 *);
	int (*resume)(struct device___242 *);
	int (*freeze)(struct device___242 *);
	int (*thaw)(struct device___242 *);
	int (*poweroff)(struct device___242 *);
	int (*restore)(struct device___242 *);
	int (*suspend_late)(struct device___242 *);
	int (*resume_early)(struct device___242 *);
	int (*freeze_late)(struct device___242 *);
	int (*thaw_early)(struct device___242 *);
	int (*poweroff_late)(struct device___242 *);
	int (*restore_early)(struct device___242 *);
	int (*suspend_noirq)(struct device___242 *);
	int (*resume_noirq)(struct device___242 *);
	int (*freeze_noirq)(struct device___242 *);
	int (*thaw_noirq)(struct device___242 *);
	int (*poweroff_noirq)(struct device___242 *);
	int (*restore_noirq)(struct device___242 *);
	int (*runtime_suspend)(struct device___242 *);
	int (*runtime_resume)(struct device___242 *);
	int (*runtime_idle)(struct device___242 *);
};

struct dev_pm_qos___46;

struct dev_pm_info___46 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___46 *qos;
};

struct dma_map_ops___107;

struct dev_archdata___107 {
	struct dma_map_ops___107 *dma_ops;
	void *iommu;
};

struct device_type___242;

struct bus_type___242;

struct device_driver___242;

struct dev_pm_domain___242;

struct class___242;

struct attribute_group___204;

struct device_rh___242;

struct device___242 {
	struct device___242 *parent;
	struct device_private *p;
	struct kobject___30 kobj;
	const char *init_name;
	const struct device_type___242 *type;
	struct mutex___246 mutex;
	struct bus_type___242 *bus;
	struct device_driver___242 *driver;
	void *platform_data;
	struct dev_pm_info___46 power;
	struct dev_pm_domain___242 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___107 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___242 *class;
	const struct attribute_group___204 **groups;
	void (*release)(struct device___242 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___242 *device_rh;
};

struct dev_pm_qos_request___47;

struct dev_pm_qos___46 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___47 *latency_req;
	struct dev_pm_qos_request___47 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___47 *latency_tolerance_req;
};

struct dev_pm_info_rh___242 {
	void (*set_latency_tolerance)(struct device___242 *, s32);
};

struct dev_pm_domain___242 {
	struct dev_pm_ops___242 ops;
};

struct smp_ops___245 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___245 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___50;

struct ctl_node___50 {
	struct rb_node node;
	struct ctl_table_header___50 *header;
};

struct ctl_table_root___50;

struct ctl_table_set___50;

struct ctl_dir___50;

struct ctl_table_header___50 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___50 *root;
	struct ctl_table_set___50 *set;
	struct ctl_dir___50 *parent;
	struct ctl_node___50 *node;
};

struct ctl_dir___50 {
	struct ctl_table_header___50 header;
	struct rb_root root;
};

struct ctl_table_set___50 {
	int (*is_seen)(struct ctl_table_set___50 *);
	struct ctl_dir___50 dir;
};

struct ctl_table_root___50 {
	struct ctl_table_set___50 default_set;
	struct ctl_table_set___50 * (*lookup)(struct ctl_table_root___50 *, struct nsproxy___125 *);
	int (*permissions)(struct ctl_table_header___50 *, struct ctl_table *);
};

struct net___49;

struct nsproxy___125 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___49 *net_ns;
};

struct sock___29;

struct kobj_ns_type_operations___27 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___29 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___27;

struct sock_common___27 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___27 *skc_prot;
	struct net___49 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___39;

struct sk_buff_head___36 {
	struct sk_buff___39 *next;
	struct sk_buff___39 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___28;

struct socket_wq___27;

struct dst_entry___27;

struct socket___28;

struct cg_proto___27;

struct sock___29 {
	struct sock_common___27 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___36 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___39 *head;
		struct sk_buff___39 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___28 *sk_filter;
	struct socket_wq___27 *sk_wq;
	struct sk_buff_head___36 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___27 *sk_rx_dst;
	struct dst_entry___27 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___36 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___36 sk_error_queue;
	struct proto___27 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___94 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___28 *sk_socket;
	void *sk_user_data;
	struct page_frag___238 sk_frag;
	struct sk_buff___39 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___27 *sk_cgrp;
	void (*sk_state_change)(struct sock___29 *);
	void (*sk_data_ready)(struct sock___29 *, int);
	void (*sk_write_space)(struct sock___29 *);
	void (*sk_error_report)(struct sock___29 *);
	int (*sk_backlog_rcv)(struct sock___29 *, struct sk_buff___39 *);
	void (*sk_destruct)(struct sock___29 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___206;

struct attribute_group___204 {
	const char *name;
	umode_t (*is_visible)(struct kobject___30 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___206 **bin_attrs;
};

struct bin_attribute___206 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___244 *, struct kobject___30 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___244 *, struct kobject___30 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	int (*mmap)(struct file___244 *, struct kobject___30 *, struct bin_attribute___206 *, struct vm_area_struct___252 *);
};

struct dentry___244;

struct path___244 {
	struct vfsmount *mnt;
	struct dentry___244 *dentry;
};

struct inode___244;

struct file_operations___244;

struct file___244 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___244 f_path;
	struct inode___244 *f_inode;
	const struct file_operations___244 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___244 *f_mapping;
	struct mutex___246 f_pos_lock;
};

struct vm_operations_struct___218;

struct vm_area_struct___252 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___252 *vm_next;
	struct vm_area_struct___252 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___252 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___218 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___244 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___30 {
	ssize_t (*show)(struct kobject___30 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___30 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___30 *, const struct attribute *);
};

struct kset_uevent_ops___30;

struct kset___30 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___30 kobj;
	const struct kset_uevent_ops___30 *uevent_ops;
};

struct kobj_type___30 {
	void (*release)(struct kobject___30 *);
	const struct sysfs_ops___30 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___30 *);
	const void * (*namespace)(struct kobject___30 *);
};

struct kset_uevent_ops___30 {
	int (* const filter)(struct kset___30 *, struct kobject___30 *);
	const char * (* const name)(struct kset___30 *, struct kobject___30 *);
	int (* const uevent)(struct kset___30 *, struct kobject___30 *, struct kobj_uevent_env *);
};

struct module_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___146 *, struct module_kobject___146 *, char *);
	ssize_t (*store)(struct module_attribute___146 *, struct module_kobject___146 *, const char *, size_t);
	void (*setup)(struct module___148 *, const char *);
	int (*test)(struct module___148 *);
	void (*free)(struct module___148 *);
};

struct xol_area___243 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___243 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___226;

struct memcg_cache_params___227;

struct kmem_cache___227 {
	struct kmem_cache_cpu___226 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___30 kobj;
	struct memcg_cache_params___227 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___244;

struct address_space___244 {
	struct inode___244 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___246 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___244 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___214;

struct vm_operations_struct___218 {
	void (*open)(struct vm_area_struct___252 *);
	void (*close)(struct vm_area_struct___252 *);
	int (*fault)(struct vm_area_struct___252 *, struct vm_fault___214 *);
	int (*page_mkwrite)(struct vm_area_struct___252 *, struct vm_fault___214 *);
	int (*access)(struct vm_area_struct___252 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___252 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___252 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___252 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___252 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___245 {
	struct task_struct___245 *task;
	struct core_thread___245 *next;
};

struct core_state___245 {
	atomic_t nr_threads;
	struct core_thread___245 dumper;
	struct completion startup;
};

struct vm_fault___214 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___243 *page;
};

struct seq_file___169;

struct irq_chip___168 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___168 *);
	void (*irq_shutdown)(struct irq_data___168 *);
	void (*irq_enable)(struct irq_data___168 *);
	void (*irq_disable)(struct irq_data___168 *);
	void (*irq_ack)(struct irq_data___168 *);
	void (*irq_mask)(struct irq_data___168 *);
	void (*irq_mask_ack)(struct irq_data___168 *);
	void (*irq_unmask)(struct irq_data___168 *);
	void (*irq_eoi)(struct irq_data___168 *);
	int (*irq_set_affinity)(struct irq_data___168 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___168 *);
	int (*irq_set_type)(struct irq_data___168 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___168 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___168 *);
	void (*irq_bus_sync_unlock)(struct irq_data___168 *);
	void (*irq_cpu_online)(struct irq_data___168 *);
	void (*irq_cpu_offline)(struct irq_data___168 *);
	void (*irq_suspend)(struct irq_data___168 *);
	void (*irq_resume)(struct irq_data___168 *);
	void (*irq_pm_shutdown)(struct irq_data___168 *);
	void (*irq_print_chip)(struct irq_data___168 *, struct seq_file___169 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___168 *, void *);
	long unsigned int flags;
};

struct seq_operations___169;

struct seq_file___169 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___246 lock;
	const struct seq_operations___169 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___245 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___245 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___245 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___94 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___246 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___140;

struct css_set___140 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___140 *subsys[11];
	struct callback_head callback_head;
};

struct kiocb___35;

struct poll_table_struct___134;

struct file_lock___244;

struct file_operations___244 {
	struct module___148 *owner;
	loff_t (*llseek)(struct file___244 *, loff_t, int);
	ssize_t (*read)(struct file___244 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___244 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___35 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___35 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___244 *, void *, filldir_t);
	unsigned int (*poll)(struct file___244 *, struct poll_table_struct___134 *);
	long int (*unlocked_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___244 *, struct vm_area_struct___252 *);
	int (*open)(struct inode___244 *, struct file___244 *);
	int (*flush)(struct file___244 *, fl_owner_t);
	int (*release)(struct inode___244 *, struct file___244 *);
	int (*fsync)(struct file___244 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___35 *, int);
	int (*fasync)(int, struct file___244 *, int);
	int (*lock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*sendpage)(struct file___244 *, struct page___243 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___244 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___244 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___244 *, long int, struct file_lock___244 **, void **);
		struct {
			int (*setlease)(struct file___244 *, long int, struct file_lock___244 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___244 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___169 *, struct file___244 *);
};

struct dma_map_ops___107 {
	void * (*alloc)(struct device___242 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___242 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___242 *, struct vm_area_struct___252 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___242 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___242 *, struct page___243 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___242 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___242 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___242 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___242 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___242 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___242 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___242 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___242 *, dma_addr_t);
	int (*dma_supported)(struct device___242 *, u64);
	int (*set_dma_mask)(struct device___242 *, u64);
	int is_phys;
};

struct bus_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___242 *, char *);
	ssize_t (*store)(struct bus_type___242 *, const char *, size_t);
};

struct device_attribute___242;

struct driver_attribute___242;

struct bus_type___242 {
	const char *name;
	const char *dev_name;
	struct device___242 *dev_root;
	struct bus_attribute___242 *bus_attrs;
	struct device_attribute___242 *dev_attrs;
	struct driver_attribute___242 *drv_attrs;
	const struct attribute_group___204 **bus_groups;
	const struct attribute_group___204 **dev_groups;
	const struct attribute_group___204 **drv_groups;
	int (*match)(struct device___242 *, struct device_driver___242 *);
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	int (*probe)(struct device___242 *);
	int (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*online)(struct device___242 *);
	int (*offline)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct device___242 *, struct device_attribute___242 *, char *);
	ssize_t (*store)(struct device___242 *, struct device_attribute___242 *, const char *, size_t);
};

struct driver_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___242 *, char *);
	ssize_t (*store)(struct device_driver___242 *, const char *, size_t);
};

struct device_driver___242 {
	const char *name;
	struct bus_type___242 *bus;
	struct module___148 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___242 *);
	int (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	const struct attribute_group___204 **groups;
	const struct dev_pm_ops___242 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___242 {
	const char *name;
	const struct attribute_group___204 **groups;
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
};

struct class_attribute___242;

struct class___242 {
	const char *name;
	struct module___148 *owner;
	struct class_attribute___242 *class_attrs;
	struct device_attribute___242 *dev_attrs;
	const struct attribute_group___204 **dev_groups;
	struct bin_attribute___206 *dev_bin_attrs;
	struct kobject___30 *dev_kobj;
	int (*dev_uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *);
	void (*class_release)(struct class___242 *);
	void (*dev_release)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
	struct subsys_private *p;
};

struct class_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct class___242 *, struct class_attribute___242 *, char *);
	ssize_t (*store)(struct class___242 *, struct class_attribute___242 *, const char *, size_t);
	const void * (*namespace)(struct class___242 *, const struct class_attribute___242 *);
};

struct device_rh___242 {
	struct dev_pm_info_rh___242 power;
};

struct dev_pm_qos_request___47 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___242 *dev;
};

struct dentry_operations___244;

struct super_block___244;

struct dentry___244 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___244 *d_parent;
	struct qstr d_name;
	struct inode___244 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___244 *d_op;
	struct super_block___244 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___244;

struct dquot___244;

struct block_device___244;

struct inode___244 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___244 *i_op;
	struct super_block___244 *i_sb;
	struct address_space___244 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___246 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___244 *i_fop;
	struct file_lock___244 *i_flock;
	struct address_space___244 i_data;
	struct dquot___244 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___244 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___244 {
	int (*d_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_hash)(const struct dentry___244 *, struct qstr *);
	int (*d_compare)(const struct dentry___244 *, const struct dentry___244 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___244 *);
	void (*d_release)(struct dentry___244 *);
	void (*d_prune)(struct dentry___244 *);
	void (*d_iput)(struct dentry___244 *, struct inode___244 *);
	char * (*d_dname)(struct dentry___244 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___244 *);
	int (*d_manage)(struct dentry___244 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___244;

struct mem_dqinfo___244 {
	struct quota_format_type___244 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___244;

struct quota_info___244 {
	unsigned int flags;
	struct mutex___246 dqio_mutex;
	struct mutex___246 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___244 *files[2];
	struct mem_dqinfo___244 info[2];
	const struct quota_format_ops___244 *ops[2];
};

struct file_system_type___244;

struct super_operations___244;

struct dquot_operations___244;

struct quotactl_ops___244;

struct xattr_handler___141;

struct super_block___244 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___244 *s_type;
	const struct super_operations___244 *s_op;
	const struct dquot_operations___244 *dq_op;
	const struct quotactl_ops___244 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___244 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___141 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___244 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___244 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___246 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___244 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___244 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___244 *bd_inode;
	struct super_block___244 *bd_super;
	struct mutex___246 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___244 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___246 bd_fsfreeze_mutex;
};

struct cgroup___140;

struct cgroup_subsys_state___140 {
	struct cgroup___140 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___35(struct kiocb___35 *, struct io_event *);

struct kiocb___35 {
	atomic_t ki_users;
	struct file___244 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___35 *ki_cancel;
	void (*ki_dtor)(struct kiocb___35 *);
	union {
		void *user;
		struct task_struct___245 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___244 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___244 *ia_file;
};

struct dquot___244 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___246 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___244 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___244 {
	int qf_fmt_id;
	const struct quota_format_ops___244 *qf_ops;
	struct module___148 *qf_owner;
	struct quota_format_type___244 *qf_next;
};

struct quota_format_ops___244 {
	int (*check_quota_file)(struct super_block___244 *, int);
	int (*read_file_info)(struct super_block___244 *, int);
	int (*write_file_info)(struct super_block___244 *, int);
	int (*free_file_info)(struct super_block___244 *, int);
	int (*read_dqblk)(struct dquot___244 *);
	int (*commit_dqblk)(struct dquot___244 *);
	int (*release_dqblk)(struct dquot___244 *);
};

struct dquot_operations___244 {
	int (*write_dquot)(struct dquot___244 *);
	struct dquot___244 * (*alloc_dquot)(struct super_block___244 *, int);
	void (*destroy_dquot)(struct dquot___244 *);
	int (*acquire_dquot)(struct dquot___244 *);
	int (*release_dquot)(struct dquot___244 *);
	int (*mark_dirty)(struct dquot___244 *);
	int (*write_info)(struct super_block___244 *, int);
	qsize_t * (*get_reserved_space)(struct inode___244 *);
};

struct quotactl_ops___244 {
	int (*quota_on)(struct super_block___244 *, int, int, struct path___244 *);
	int (*quota_on_meta)(struct super_block___244 *, int, int);
	int (*quota_off)(struct super_block___244 *, int);
	int (*quota_sync)(struct super_block___244 *, int);
	int (*get_info)(struct super_block___244 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___244 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___244 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___244 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___244 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___244 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___244 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___244 *, unsigned int);
};

struct address_space_operations___244 {
	int (*writepage)(struct page___243 *, struct writeback_control *);
	int (*readpage)(struct file___244 *, struct page___243 *);
	int (*writepages)(struct address_space___244 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___243 *);
	int (*readpages)(struct file___244 *, struct address_space___244 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___244 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___243 **, void **);
	int (*write_end)(struct file___244 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___243 *, void *);
	sector_t (*bmap)(struct address_space___244 *, sector_t);
	void (*invalidatepage)(struct page___243 *, long unsigned int);
	int (*releasepage)(struct page___243 *, gfp_t);
	void (*freepage)(struct page___243 *);
	ssize_t (*direct_IO)(int, struct kiocb___35 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___244 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___244 *, struct page___243 *, struct page___243 *, enum migrate_mode);
	int (*launder_page)(struct page___243 *);
	int (*is_partially_uptodate)(struct page___243 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___243 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___244 *, struct page___243 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___244 *, sector_t *);
	void (*swap_deactivate)(struct file___244 *);
	void (*invalidatepage_range)(struct page___243 *, unsigned int, unsigned int);
};

struct inode_operations___244 {
	struct dentry___244 * (*lookup)(struct inode___244 *, struct dentry___244 *, unsigned int);
	void * (*follow_link)(struct dentry___244 *, struct nameidata *);
	int (*permission)(struct inode___244 *, int);
	struct posix_acl * (*get_acl)(struct inode___244 *, int);
	int (*readlink)(struct dentry___244 *, char *, int);
	void (*put_link)(struct dentry___244 *, struct nameidata *, void *);
	int (*create)(struct inode___244 *, struct dentry___244 *, umode_t, bool);
	int (*link)(struct dentry___244 *, struct inode___244 *, struct dentry___244 *);
	int (*unlink)(struct inode___244 *, struct dentry___244 *);
	int (*symlink)(struct inode___244 *, struct dentry___244 *, const char *);
	int (*mkdir)(struct inode___244 *, struct dentry___244 *, umode_t);
	int (*rmdir)(struct inode___244 *, struct dentry___244 *);
	int (*mknod)(struct inode___244 *, struct dentry___244 *, umode_t, dev_t);
	int (*rename)(struct inode___244 *, struct dentry___244 *, struct inode___244 *, struct dentry___244 *);
	int (*setattr)(struct dentry___244 *, struct iattr___244 *);
	int (*getattr)(struct vfsmount *, struct dentry___244 *, struct kstat *);
	int (*setxattr)(struct dentry___244 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___244 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___244 *, char *, size_t);
	int (*removexattr)(struct dentry___244 *, const char *);
	int (*fiemap)(struct inode___244 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___244 *, struct timespec *, int);
	int (*atomic_open)(struct inode___244 *, struct dentry___244 *, struct file___244 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___244;

struct file_lock_operations___244;

struct lock_manager_operations___244;

struct file_lock___244 {
	struct file_lock___244 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___94 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___244 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___244 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___244 *fl_ops;
	const struct lock_manager_operations___244 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___244 {
	void (*fl_copy_lock)(struct file_lock___244 *, struct file_lock___244 *);
	void (*fl_release_private)(struct file_lock___244 *);
};

struct lock_manager_operations___244 {
	int (*lm_compare_owner)(struct file_lock___244 *, struct file_lock___244 *);
	long unsigned int (*lm_owner_key)(struct file_lock___244 *);
	void (*lm_notify)(struct file_lock___244 *);
	int (*lm_grant)(struct file_lock___244 *, struct file_lock___244 *, int);
	void (*lm_break)(struct file_lock___244 *);
	int (*lm_change)(struct file_lock___244 **, int);
};

struct fasync_struct___244 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___244 *fa_next;
	struct file___244 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___244 {
	const char *name;
	int fs_flags;
	struct dentry___244 * (*mount)(struct file_system_type___244 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___244 *);
	struct module___148 *owner;
	struct file_system_type___244 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___244 {
	struct inode___244 * (*alloc_inode)(struct super_block___244 *);
	void (*destroy_inode)(struct inode___244 *);
	void (*dirty_inode)(struct inode___244 *, int);
	int (*write_inode)(struct inode___244 *, struct writeback_control *);
	int (*drop_inode)(struct inode___244 *);
	void (*evict_inode)(struct inode___244 *);
	void (*put_super)(struct super_block___244 *);
	int (*sync_fs)(struct super_block___244 *, int);
	int (*freeze_fs)(struct super_block___244 *);
	int (*unfreeze_fs)(struct super_block___244 *);
	int (*statfs)(struct dentry___244 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___244 *, int *, char *);
	void (*umount_begin)(struct super_block___244 *);
	int (*show_options)(struct seq_file___169 *, struct dentry___244 *);
	int (*show_devname)(struct seq_file___169 *, struct dentry___244 *);
	int (*show_path)(struct seq_file___169 *, struct dentry___244 *);
	int (*show_stats)(struct seq_file___169 *, struct dentry___244 *);
	ssize_t (*quota_read)(struct super_block___244 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___244 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___244 *);
	int (*bdev_try_to_free_page)(struct super_block___244 *, struct page___243 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___244 *);
	void (*free_cached_objects)(struct super_block___244 *, int);
};

struct xattr_handler___141 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___244 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___244 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___244 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___136)(struct file___244 *, wait_queue_head_t *, struct poll_table_struct___134 *);

struct poll_table_struct___134 {
	poll_queue_proc___136 _qproc;
	long unsigned int _key;
};

struct socket_wq___27 {
	wait_queue_head_t wait;
	struct fasync_struct___244 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___27;

struct socket___28 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___27 *wq;
	struct file___244 *file;
	struct sock___29 *sk;
	const struct proto_ops___27 *ops;
};

struct proto_ops___27 {
	int family;
	struct module___148 *owner;
	int (*release)(struct socket___28 *);
	int (*bind)(struct socket___28 *, struct sockaddr *, int);
	int (*connect)(struct socket___28 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___28 *, struct socket___28 *);
	int (*accept)(struct socket___28 *, struct socket___28 *, int);
	int (*getname)(struct socket___28 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___244 *, struct socket___28 *, struct poll_table_struct___134 *);
	int (*ioctl)(struct socket___28 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___28 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___28 *, int);
	int (*shutdown)(struct socket___28 *, int);
	int (*setsockopt)(struct socket___28 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___28 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___28 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___28 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___35 *, struct socket___28 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___35 *, struct socket___28 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___244 *, struct socket___28 *, struct vm_area_struct___252 *);
	ssize_t (*sendpage)(struct socket___28 *, struct page___243 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___28 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___29 *, int);
		struct {
			void (*set_peek_off)(struct sock___29 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___47 {
	struct ctl_table_header___50 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___47 {
	struct mutex___246 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___47 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___50 *ctl;
};

struct netns_ipv4___47 {
	struct ctl_table_header___50 *forw_hdr;
	struct ctl_table_header___50 *frags_hdr;
	struct ctl_table_header___50 *ipv4_hdr;
	struct ctl_table_header___50 *route_hdr;
	struct ctl_table_header___50 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___29 *fibnl;
	struct sock___29 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___47 {
	struct ctl_table_header___50 *hdr;
	struct ctl_table_header___50 *route_hdr;
	struct ctl_table_header___50 *icmp_hdr;
	struct ctl_table_header___50 *frags_hdr;
	struct ctl_table_header___50 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___37;

struct neighbour___27;

struct dst_ops___48 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___48 *);
	struct dst_entry___27 * (*check)(struct dst_entry___27 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___27 *);
	unsigned int (*mtu)(const struct dst_entry___27 *);
	u32 * (*cow_metrics)(struct dst_entry___27 *, long unsigned int);
	void (*destroy)(struct dst_entry___27 *);
	void (*ifdown)(struct dst_entry___27 *, struct net_device___37 *, int);
	struct dst_entry___27 * (*negative_advice)(struct dst_entry___27 *);
	void (*link_failure)(struct sk_buff___39 *);
	void (*update_pmtu)(struct dst_entry___27 *, struct sock___29 *, struct sk_buff___39 *, u32);
	void (*redirect)(struct dst_entry___27 *, struct sock___29 *, struct sk_buff___39 *);
	int (*local_out)(struct sk_buff___39 *);
	struct neighbour___27 * (*neigh_lookup)(const struct dst_entry___27 *, struct sk_buff___39 *, const void *);
	struct kmem_cache___227 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___48 {
	struct netns_sysctl_ipv6___47 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___48 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___29 **icmp_sk;
	struct sock___29 *ndisc_sk;
	struct sock___29 *tcp_sk;
	struct sock___29 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___47 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___50 *sysctl_header;
	struct sock___29 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___27 {
	struct sock___29 *v4_ctl_sk;
	struct sock___29 *v6_ctl_sk;
};

struct netns_nf___47 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___50 *nf_log_dir_header;
};

struct nf_proto_net___47 {
	struct ctl_table_header___50 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___47 {
	struct nf_proto_net___47 pn;
	unsigned int timeout;
};

struct nf_tcp_net___47 {
	struct nf_proto_net___47 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___47 {
	struct nf_proto_net___47 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___47 {
	struct nf_proto_net___47 pn;
	unsigned int timeout;
};

struct nf_ip_net___47 {
	struct nf_generic_net___47 generic;
	struct nf_tcp_net___47 tcp;
	struct nf_udp_net___47 udp;
	struct nf_icmp_net___47 icmp;
	struct nf_icmp_net___47 icmpv6;
};

struct netns_ct___47 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___50 *sysctl_header;
	struct ctl_table_header___50 *acct_sysctl_header;
	struct ctl_table_header___50 *tstamp_sysctl_header;
	struct ctl_table_header___50 *event_sysctl_header;
	struct ctl_table_header___50 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___227 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___47 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___47 {
	struct netns_sysctl_ipv6___47 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___48 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___29 *nlsk;
	struct sock___29 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___50 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___48 xfrm4_dst_ops;
	struct dst_ops___48 xfrm6_dst_ops;
};

struct net___49 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___50 sysctls;
	struct sock___29 *rtnl;
	struct sock___29 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___37 *loopback_dev;
	struct netns_core___47 core;
	struct netns_mib mib;
	struct netns_packet___47 packet;
	struct netns_unix___47 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___47 ipv4;
	struct netns_ipv6___48 ipv6;
	struct netns_sctp___47 sctp;
	struct netns_dccp___27 dccp;
	struct netns_nf___47 nf;
	struct netns_xt xt;
	struct netns_ct___47 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___47 nf_frag;
	struct sock___29 *nfnl;
	struct sock___29 *nfnl_stash;
	struct sk_buff_head___36 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___48 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___29 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___29 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___246 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___246 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___226 {
	void **freelist;
	long unsigned int tid;
	struct page___243 *page;
	struct page___243 *partial;
};

struct memcg_cache_params___227 {
	bool is_root_cache;
	union {
		struct kmem_cache___227 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___227 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___35 {
	atomic_t use;
	unsigned int mask;
	struct net_device___37 *physindev;
	struct net_device___37 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___35(struct sk_buff___39 **);

struct net_device_ops___35;

struct ethtool_ops___35;

struct header_ops___35;

struct inet6_dev___14;

struct netdev_rx_queue___35;

struct netdev_queue___35;

struct rtnl_link_ops___27;

struct dcbnl_rtnl_ops___35;

struct net_device___37 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___35 *netdev_ops;
	const struct ethtool_ops___35 *ethtool_ops;
	const struct header_ops___35 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___30 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___14 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___35 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___35 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___35 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___35 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___35 = 0,
		NETREG_REGISTERED___35 = 1,
		NETREG_UNREGISTERING___35 = 2,
		NETREG_UNREGISTERED___35 = 3,
		NETREG_RELEASED___35 = 4,
		NETREG_DUMMY___35 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___35 = 0,
		RTNL_LINK_INITIALIZING___35 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___37 *);
	struct netpoll_info *npinfo;
	struct net___49 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___242 dev;
	const struct attribute_group___204 *sysfs_groups[4];
	const struct rtnl_link_ops___27 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___35 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___39 {
	struct sk_buff___39 *next;
	struct sk_buff___39 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___29 *sk;
	struct net_device___37 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___39 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___35 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___4 {
	struct {
		struct page___243 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___4 skb_frag_t___4;

struct skb_shared_info___4 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___39 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___4 frags[17];
};

struct ethtool_ops___35 {
	int (*get_settings)(struct net_device___37 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___37 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___37 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___37 *);
	void (*get_regs)(struct net_device___37 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___37 *);
	void (*set_msglevel)(struct net_device___37 *, u32);
	int (*nway_reset)(struct net_device___37 *);
	u32 (*get_link)(struct net_device___37 *);
	int (*get_eeprom_len)(struct net_device___37 *);
	int (*get_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___37 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___37 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___37 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___37 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___37 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___37 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___37 *);
	void (*complete)(struct net_device___37 *);
	u32 (*get_priv_flags)(struct net_device___37 *);
	int (*set_priv_flags)(struct net_device___37 *, u32);
	int (*get_sset_count)(struct net_device___37 *, int);
	int (*get_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___37 *, struct ethtool_flash *);
	int (*reset)(struct net_device___37 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___37 *);
	int (*get_rxfh_indir)(struct net_device___37 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___37 *, const u32 *);
	void (*get_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___37 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___37 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___37 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___37 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___37 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___37 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___37 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___37 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___9;

struct dst_entry___27 {
	struct callback_head callback_head;
	struct dst_entry___27 *child;
	struct net_device___37 *dev;
	struct dst_ops___48 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___27 *path;
	struct dst_entry___27 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___39 *);
	union {
		int (*output)(struct sock___29 *, struct sk_buff___39 *);
		struct {
			int (*output)(struct sk_buff___39 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___27 *next;
		struct rtable___9 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___27;

struct neigh_parms___27;

struct neigh_ops___27;

struct neighbour___27 {
	struct neighbour___27 *next;
	struct neigh_table___27 *tbl;
	struct neigh_parms___27 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___36 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___27 *, struct sk_buff___39 *);
	const struct neigh_ops___27 *ops;
	struct callback_head rcu;
	struct net_device___37 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___48 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___39 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___39 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___49 *, struct dst_entry___27 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___39 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___39 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___169 {
	void * (*start)(struct seq_file___169 *, loff_t *);
	void (*stop)(struct seq_file___169 *, void *);
	void * (*next)(struct seq_file___169 *, void *, loff_t *);
	int (*show)(struct seq_file___169 *, void *);
};

struct dcbnl_rtnl_ops___35 {
	int (*ieee_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___37 *);
	u8 (*setstate)(struct net_device___37 *, u8);
	void (*getpermhwaddr)(struct net_device___37 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___37 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___37 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___37 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___37 *, int, u8 *);
	void (*setpfccfg)(struct net_device___37 *, int, u8);
	void (*getpfccfg)(struct net_device___37 *, int, u8 *);
	u8 (*setall)(struct net_device___37 *);
	u8 (*getcap)(struct net_device___37 *, int, u8 *);
	int (*getnumtcs)(struct net_device___37 *, int, u8 *);
	int (*setnumtcs)(struct net_device___37 *, int, u8);
	u8 (*getpfcstate)(struct net_device___37 *);
	void (*setpfcstate)(struct net_device___37 *, u8);
	void (*getbcncfg)(struct net_device___37 *, int, u32 *);
	void (*setbcncfg)(struct net_device___37 *, int, u32);
	void (*getbcnrp)(struct net_device___37 *, int, u8 *);
	void (*setbcnrp)(struct net_device___37 *, int, u8);
	u8 (*setapp)(struct net_device___37 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___37 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___37 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___37 *, int, u8);
	u8 (*getdcbx)(struct net_device___37 *);
	u8 (*setdcbx)(struct net_device___37 *, u8);
	int (*peer_getappinfo)(struct net_device___37 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___37 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___37 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___37 *, struct cee_pfc *);
};

struct cgroupfs_root___140;

struct cgroup___140 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___140 *parent;
	struct dentry___244 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___140 *subsys[11];
	struct cgroupfs_root___140 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___246 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___140 {
	struct super_block___244 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___140 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___79 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___244 *, struct file___244 *);
	ssize_t (*read)(struct cgroup___140 *, struct cftype___79 *, struct file___244 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___140 *, struct cftype___79 *);
	s64 (*read_s64)(struct cgroup___140 *, struct cftype___79 *);
	int (*read_map)(struct cgroup___140 *, struct cftype___79 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___140 *, struct cftype___79 *, struct seq_file___169 *);
	ssize_t (*write)(struct cgroup___140 *, struct cftype___79 *, struct file___244 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___140 *, struct cftype___79 *, u64);
	int (*write_s64)(struct cgroup___140 *, struct cftype___79 *, s64);
	int (*write_string)(struct cgroup___140 *, struct cftype___79 *, const char *);
	int (*trigger)(struct cgroup___140 *, unsigned int);
	int (*release)(struct inode___244 *, struct file___244 *);
	int (*register_event)(struct cgroup___140 *, struct cftype___79 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___140 *, struct cftype___79 *, struct eventfd_ctx *);
};

struct cftype_set___75 {
	struct list_head node;
	struct cftype___79 *cfts;
};

struct task_and_cgroup___75 {
	struct task_struct___245 *task;
	struct cgroup___140 *cgrp;
	struct css_set___140 *cg;
};

struct cgroup_taskset___75 {
	struct task_and_cgroup___75 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___140 *cur_cgrp;
};

struct cgroup_subsys___75 {
	struct cgroup_subsys_state___140 * (*css_alloc)(struct cgroup___140 *);
	int (*css_online)(struct cgroup___140 *);
	void (*css_offline)(struct cgroup___140 *);
	void (*css_free)(struct cgroup___140 *);
	int (*can_attach)(struct cgroup___140 *, struct cgroup_taskset___75 *);
	void (*cancel_attach)(struct cgroup___140 *, struct cgroup_taskset___75 *);
	void (*attach)(struct cgroup___140 *, struct cgroup_taskset___75 *);
	void (*fork)(struct task_struct___245 *);
	void (*exit)(struct cgroup___140 *, struct cgroup___140 *, struct task_struct___245 *);
	void (*bind)(struct cgroup___140 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___140 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___79 *base_cftypes;
	struct cftype_set___75 base_cftset;
	struct module___148 *module;
};

struct request_sock_ops___18;

struct request_sock___19 {
	struct sock_common___27 __req_common;
	struct request_sock___19 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___18 *rsk_ops;
	struct sock___29 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___37 {
	struct sk_buff___39 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___39 *, struct netlink_callback___37 *);
	int (*done)(struct netlink_callback___37 *);
	void *data;
	struct module___148 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___35 {
	int (*create)(struct sk_buff___39 *, struct net_device___37 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___39 *, unsigned char *);
	int (*rebuild)(struct sk_buff___39 *);
	int (*cache)(const struct neighbour___27 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___37 *, const unsigned char *);
};

struct napi_struct___35 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___35 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___37 *dev;
	struct sk_buff___39 *gro_list;
	struct sk_buff___39 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___35 {
	struct net_device___37 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___30 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___35 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___30 kobj;
	struct net_device___37 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___35 {
	int (*ndo_init)(struct net_device___37 *);
	void (*ndo_uninit)(struct net_device___37 *);
	int (*ndo_open)(struct net_device___37 *);
	int (*ndo_stop)(struct net_device___37 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___39 *, struct net_device___37 *);
	u16 (*ndo_select_queue)(struct net_device___37 *, struct sk_buff___39 *);
	void (*ndo_change_rx_flags)(struct net_device___37 *, int);
	void (*ndo_set_rx_mode)(struct net_device___37 *);
	int (*ndo_set_mac_address)(struct net_device___37 *, void *);
	int (*ndo_validate_addr)(struct net_device___37 *);
	int (*ndo_do_ioctl)(struct net_device___37 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___37 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___37 *, int);
	int (*ndo_neigh_setup)(struct net_device___37 *, struct neigh_parms___27 *);
	void (*ndo_tx_timeout)(struct net_device___37 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___37 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___37 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___37 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___37 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___37 *);
	int (*ndo_netpoll_setup)(struct net_device___37 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___37 *);
	int (*ndo_busy_poll)(struct napi_struct___35 *);
	int (*ndo_set_vf_mac)(struct net_device___37 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___37 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___37 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___37 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___37 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___37 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___37 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___37 *, int, struct sk_buff___39 *);
	int (*ndo_setup_tc)(struct net_device___37 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___37 *);
	int (*ndo_fcoe_disable)(struct net_device___37 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___37 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___37 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___37 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___37 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___37 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___37 *, const struct sk_buff___39 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___37 *, struct net_device___37 *);
	int (*ndo_del_slave)(struct net_device___37 *, struct net_device___37 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___27 *);
	void (*ndo_neigh_destroy)(struct neighbour___27 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___39 *, struct netlink_callback___37 *, struct net_device___37 *, int);
	int (*ndo_bridge_setlink)(struct net_device___37 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___39 *, u32, u32, struct net_device___37 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___37 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___37 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___37 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___37 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___37 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___37 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___39 *, struct net_device___37 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___37 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___37 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___37 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___27 {
	struct net___49 *net;
	struct net_device___37 *dev;
	struct neigh_parms___27 *next;
	int (*neigh_setup)(struct neighbour___27 *);
	void (*neigh_cleanup)(struct neighbour___27 *);
	struct neigh_table___27 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___14;

struct ifacaddr6___14;

struct inet6_dev___14 {
	struct net_device___37 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___14 *mc_list;
	struct ifmcaddr6___14 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___14 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___27 *nd_parms;
	struct inet6_dev___14 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___27 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___37 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___49 *, struct net_device___37 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___37 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___37 *, struct list_head *);
	size_t (*get_size)(const struct net_device___37 *);
	int (*fill_info)(struct sk_buff___39 *, const struct net_device___37 *);
	size_t (*get_xstats_size)(const struct net_device___37 *);
	int (*fill_xstats)(struct sk_buff___39 *, const struct net_device___37 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___49 * (*get_link_net)(const struct net_device___37 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___37 *, struct net_device___37 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___37 *, const struct net_device___37 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___39 *, const struct net_device___37 *, const struct net_device___37 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

typedef struct poll_table_struct___134 poll_table___39;

struct sk_filter___28 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___39 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___27;

struct neigh_hash_table___27;

struct neigh_table___27 {
	struct neigh_table___27 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___37 *, __u32 *);
	int (*constructor)(struct neighbour___27 *);
	int (*pconstructor)(struct pneigh_entry___27 *);
	void (*pdestructor)(struct pneigh_entry___27 *);
	void (*proxy_redo)(struct sk_buff___39 *);
	char *id;
	struct neigh_parms___27 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___36 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___27 *nht;
	struct pneigh_entry___27 **phash_buckets;
};

struct neigh_ops___27 {
	int family;
	void (*solicit)(struct neighbour___27 *, struct sk_buff___39 *);
	void (*error_report)(struct neighbour___27 *, struct sk_buff___39 *);
	int (*output)(struct neighbour___27 *, struct sk_buff___39 *);
	int (*connected_output)(struct neighbour___27 *, struct sk_buff___39 *);
};

struct pneigh_entry___27 {
	struct pneigh_entry___27 *next;
	struct net___49 *net;
	struct net_device___37 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___27 {
	struct neighbour___27 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___9 {
	struct dst_entry___27 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___16;

struct proto___27 {
	void (*close)(struct sock___29 *, long int);
	int (*connect)(struct sock___29 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___29 *, int);
	struct sock___29 * (*accept)(struct sock___29 *, int, int *);
	int (*ioctl)(struct sock___29 *, int, long unsigned int);
	int (*init)(struct sock___29 *);
	void (*destroy)(struct sock___29 *);
	void (*shutdown)(struct sock___29 *, int);
	int (*setsockopt)(struct sock___29 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___29 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___29 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___29 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___29 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___35 *, struct sock___29 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___35 *, struct sock___29 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___29 *, struct page___243 *, int, size_t, int);
	int (*bind)(struct sock___29 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___29 *, struct sk_buff___39 *);
	void (*release_cb)(struct sock___29 *);
	void (*mtu_reduced)(struct sock___29 *);
	void (*hash)(struct sock___29 *);
	void (*unhash)(struct sock___29 *);
	void (*rehash)(struct sock___29 *);
	int (*get_port)(struct sock___29 *, short unsigned int);
	void (*clear_sk)(struct sock___29 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___29 *);
	void (*enter_memory_pressure)(struct sock___29 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___227 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___18 *rsk_prot;
	struct timewait_sock_ops___16 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___148 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___75 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___27 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___27 {
	void (*enter_memory_pressure)(struct sock___29 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___18 {
	int family;
	int obj_size;
	struct kmem_cache___227 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___29 *, struct request_sock___19 *);
	void (*send_ack)(struct sock___29 *, struct sk_buff___39 *, struct request_sock___19 *);
	void (*send_reset)(struct sock___29 *, struct sk_buff___39 *);
	void (*destructor)(struct request_sock___19 *);
	void (*syn_ack_timeout)(struct sock___29 *, struct request_sock___19 *);
};

struct timewait_sock_ops___16 {
	struct kmem_cache___227 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___29 *, struct sock___29 *, void *);
	void (*twsk_destructor)(struct sock___29 *);
};

struct ifmcaddr6___14 {
	struct in6_addr mca_addr;
	struct inet6_dev___14 *idev;
	struct ifmcaddr6___14 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___14 {
	struct in6_addr aca_addr;
	struct inet6_dev___14 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___14 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct page___244;

typedef struct page___244 *pgtable_t___244;

struct address_space___245;

struct kmem_cache___228;

struct page___244 {
	long unsigned int flags;
	struct address_space___245 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___244 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___244 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___228 *slab_cache;
		struct page___244 *first_page;
	};
	long: 64;
};

struct task_struct___246;

struct pv_cpu_ops___246 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___246 *);
	void (*end_context_switch)(struct task_struct___246 *);
};

struct pid___95;

struct pid_link___95 {
	struct hlist_node node;
	struct pid___95 *pid;
};

struct mutex___247 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___246 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___239 {
	struct page___244 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___253;

struct nsproxy___126;

struct signal_struct___246;

struct css_set___141;

struct task_struct___246 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___246 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___253 *mm;
	struct mm_struct___253 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___246 *real_parent;
	struct task_struct___246 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___246 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___246 = 0,
		VTIME_USER___246 = 1,
		VTIME_SYS___246 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___126 *nsproxy;
	struct signal_struct___246 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___141 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___247 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___239 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___253 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___253 *, struct mm_struct___253 *);
	void (*dup_mmap)(struct mm_struct___253 *, struct mm_struct___253 *);
	void (*exit_mmap)(struct mm_struct___253 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___253 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___253 *);
	void (*pgd_free)(struct mm_struct___253 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___253 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___253 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___253 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___253 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___253 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___253 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___253 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___253 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___253 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___253 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___253 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___247 lock;
	void *vdso;
} mm_context_t___247;

struct xol_area___244;

struct uprobes_state___244 {
	struct xol_area___244 *xol_area;
};

struct vm_area_struct___253;

struct file___245;

struct core_state___246;

struct mm_struct___253 {
	struct vm_area_struct___253 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___253 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___253 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___247 context;
	long unsigned int flags;
	struct core_state___246 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___246 *owner;
	struct file___245 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___244 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___31;

struct kobj_type___31;

struct kobject___31 {
	const char *name;
	struct list_head entry;
	struct kobject___31 *parent;
	struct kset___31 *kset;
	struct kobj_type___31 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___149;

struct module_kobject___147 {
	struct kobject___31 kobj;
	struct module___149 *mod;
	struct kobject___31 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___147;

struct module___149 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___147 mkobj;
	struct module_attribute___147 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___31 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___246 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___246;

struct lruvec___246 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___246 *zone;
};

struct pglist_data___246;

struct zone___246 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___246 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___246 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___246 {
	struct zone___246 *zone;
	int zone_idx;
};

struct zonelist___246 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___246 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___246 {
	struct zone___246 node_zones[4];
	struct zonelist___246 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___246 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___169;

struct x86_io_apic_ops___169 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___169 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___169;

struct irq_data___169 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___169 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___243;

struct dev_pm_ops___243 {
	int (*prepare)(struct device___243 *);
	void (*complete)(struct device___243 *);
	int (*suspend)(struct device___243 *);
	int (*resume)(struct device___243 *);
	int (*freeze)(struct device___243 *);
	int (*thaw)(struct device___243 *);
	int (*poweroff)(struct device___243 *);
	int (*restore)(struct device___243 *);
	int (*suspend_late)(struct device___243 *);
	int (*resume_early)(struct device___243 *);
	int (*freeze_late)(struct device___243 *);
	int (*thaw_early)(struct device___243 *);
	int (*poweroff_late)(struct device___243 *);
	int (*restore_early)(struct device___243 *);
	int (*suspend_noirq)(struct device___243 *);
	int (*resume_noirq)(struct device___243 *);
	int (*freeze_noirq)(struct device___243 *);
	int (*thaw_noirq)(struct device___243 *);
	int (*poweroff_noirq)(struct device___243 *);
	int (*restore_noirq)(struct device___243 *);
	int (*runtime_suspend)(struct device___243 *);
	int (*runtime_resume)(struct device___243 *);
	int (*runtime_idle)(struct device___243 *);
};

struct dev_pm_qos___47;

struct dev_pm_info___47 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___47 *qos;
};

struct dma_map_ops___108;

struct dev_archdata___108 {
	struct dma_map_ops___108 *dma_ops;
	void *iommu;
};

struct device_type___243;

struct bus_type___243;

struct device_driver___243;

struct dev_pm_domain___243;

struct class___243;

struct attribute_group___205;

struct device_rh___243;

struct device___243 {
	struct device___243 *parent;
	struct device_private *p;
	struct kobject___31 kobj;
	const char *init_name;
	const struct device_type___243 *type;
	struct mutex___247 mutex;
	struct bus_type___243 *bus;
	struct device_driver___243 *driver;
	void *platform_data;
	struct dev_pm_info___47 power;
	struct dev_pm_domain___243 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___108 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___243 *class;
	const struct attribute_group___205 **groups;
	void (*release)(struct device___243 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___243 *device_rh;
};

struct dev_pm_qos_request___48;

struct dev_pm_qos___47 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___48 *latency_req;
	struct dev_pm_qos_request___48 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___48 *latency_tolerance_req;
};

struct dev_pm_info_rh___243 {
	void (*set_latency_tolerance)(struct device___243 *, s32);
};

struct dev_pm_domain___243 {
	struct dev_pm_ops___243 ops;
};

struct smp_ops___246 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___246 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___51;

struct ctl_node___51 {
	struct rb_node node;
	struct ctl_table_header___51 *header;
};

struct ctl_table_root___51;

struct ctl_table_set___51;

struct ctl_dir___51;

struct ctl_table_header___51 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___51 *root;
	struct ctl_table_set___51 *set;
	struct ctl_dir___51 *parent;
	struct ctl_node___51 *node;
};

struct ctl_dir___51 {
	struct ctl_table_header___51 header;
	struct rb_root root;
};

struct ctl_table_set___51 {
	int (*is_seen)(struct ctl_table_set___51 *);
	struct ctl_dir___51 dir;
};

struct ctl_table_root___51 {
	struct ctl_table_set___51 default_set;
	struct ctl_table_set___51 * (*lookup)(struct ctl_table_root___51 *, struct nsproxy___126 *);
	int (*permissions)(struct ctl_table_header___51 *, struct ctl_table *);
};

struct pid_namespace___95;

struct net___50;

struct nsproxy___126 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___95 *pid_ns;
	struct net___50 *net_ns;
};

struct sock___30;

struct kobj_ns_type_operations___28 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___30 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___28;

struct sock_common___28 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___28 *skc_prot;
	struct net___50 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___40;

struct sk_buff_head___37 {
	struct sk_buff___40 *next;
	struct sk_buff___40 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___29;

struct socket_wq___28;

struct dst_entry___28;

struct socket___29;

struct cg_proto___28;

struct sock___30 {
	struct sock_common___28 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___37 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___40 *head;
		struct sk_buff___40 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___29 *sk_filter;
	struct socket_wq___28 *sk_wq;
	struct sk_buff_head___37 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___28 *sk_rx_dst;
	struct dst_entry___28 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___37 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___37 sk_error_queue;
	struct proto___28 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___29 *sk_socket;
	void *sk_user_data;
	struct page_frag___239 sk_frag;
	struct sk_buff___40 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___28 *sk_cgrp;
	void (*sk_state_change)(struct sock___30 *);
	void (*sk_data_ready)(struct sock___30 *, int);
	void (*sk_write_space)(struct sock___30 *);
	void (*sk_error_report)(struct sock___30 *);
	int (*sk_backlog_rcv)(struct sock___30 *, struct sk_buff___40 *);
	void (*sk_destruct)(struct sock___30 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___207;

struct attribute_group___205 {
	const char *name;
	umode_t (*is_visible)(struct kobject___31 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___207 **bin_attrs;
};

struct bin_attribute___207 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___245 *, struct kobject___31 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___245 *, struct kobject___31 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	int (*mmap)(struct file___245 *, struct kobject___31 *, struct bin_attribute___207 *, struct vm_area_struct___253 *);
};

struct dentry___245;

struct path___245 {
	struct vfsmount *mnt;
	struct dentry___245 *dentry;
};

struct fown_struct___95 {
	rwlock_t lock;
	struct pid___95 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___245;

struct file_operations___245;

struct file___245 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___245 f_path;
	struct inode___245 *f_inode;
	const struct file_operations___245 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___245 *f_mapping;
	struct mutex___247 f_pos_lock;
};

struct vm_operations_struct___219;

struct vm_area_struct___253 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___253 *vm_next;
	struct vm_area_struct___253 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___253 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___219 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___245 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___31 {
	ssize_t (*show)(struct kobject___31 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___31 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___31 *, const struct attribute *);
};

struct kset_uevent_ops___31;

struct kset___31 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___31 kobj;
	const struct kset_uevent_ops___31 *uevent_ops;
};

struct kobj_type___31 {
	void (*release)(struct kobject___31 *);
	const struct sysfs_ops___31 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___31 *);
	const void * (*namespace)(struct kobject___31 *);
};

struct kset_uevent_ops___31 {
	int (* const filter)(struct kset___31 *, struct kobject___31 *);
	const char * (* const name)(struct kset___31 *, struct kobject___31 *);
	int (* const uevent)(struct kset___31 *, struct kobject___31 *, struct kobj_uevent_env *);
};

struct module_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___147 *, struct module_kobject___147 *, char *);
	ssize_t (*store)(struct module_attribute___147 *, struct module_kobject___147 *, const char *, size_t);
	void (*setup)(struct module___149 *, const char *);
	int (*test)(struct module___149 *);
	void (*free)(struct module___149 *);
};

struct xol_area___244 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___244 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___227;

struct memcg_cache_params___228;

struct kmem_cache___228 {
	struct kmem_cache_cpu___227 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___31 kobj;
	struct memcg_cache_params___228 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___245;

struct address_space___245 {
	struct inode___245 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___247 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___245 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___215;

struct vm_operations_struct___219 {
	void (*open)(struct vm_area_struct___253 *);
	void (*close)(struct vm_area_struct___253 *);
	int (*fault)(struct vm_area_struct___253 *, struct vm_fault___215 *);
	int (*page_mkwrite)(struct vm_area_struct___253 *, struct vm_fault___215 *);
	int (*access)(struct vm_area_struct___253 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___253 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___253 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___253 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___253 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___246 {
	struct task_struct___246 *task;
	struct core_thread___246 *next;
};

struct core_state___246 {
	atomic_t nr_threads;
	struct core_thread___246 dumper;
	struct completion startup;
};

struct upid___95 {
	int nr;
	struct pid_namespace___95 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___95 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___246 *child_reaper;
	struct kmem_cache___228 *pid_cachep;
	unsigned int level;
	struct pid_namespace___95 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___245 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___95 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___95 numbers[1];
};

struct signal_struct___246 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___246 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___246 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___247 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___141;

struct css_set___141 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___141 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___215 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___244 *page;
};

struct fasync_struct___245;

struct socket_wq___28 {
	wait_queue_head_t wait;
	struct fasync_struct___245 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___245 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___245 *fa_next;
	struct file___245 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___28;

struct socket___29 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___28 *wq;
	struct file___245 *file;
	struct sock___30 *sk;
	const struct proto_ops___28 *ops;
};

struct poll_table_struct___135;

struct kiocb___36;

struct proto_ops___28 {
	int family;
	struct module___149 *owner;
	int (*release)(struct socket___29 *);
	int (*bind)(struct socket___29 *, struct sockaddr *, int);
	int (*connect)(struct socket___29 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___29 *, struct socket___29 *);
	int (*accept)(struct socket___29 *, struct socket___29 *, int);
	int (*getname)(struct socket___29 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___245 *, struct socket___29 *, struct poll_table_struct___135 *);
	int (*ioctl)(struct socket___29 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___29 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___29 *, int);
	int (*shutdown)(struct socket___29 *, int);
	int (*setsockopt)(struct socket___29 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___29 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___29 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___29 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___36 *, struct socket___29 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___36 *, struct socket___29 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___245 *, struct socket___29 *, struct vm_area_struct___253 *);
	ssize_t (*sendpage)(struct socket___29 *, struct page___244 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___29 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___30 *, int);
		struct {
			void (*set_peek_off)(struct sock___30 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___137)(struct file___245 *, wait_queue_head_t *, struct poll_table_struct___135 *);

struct poll_table_struct___135 {
	poll_queue_proc___137 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___36(struct kiocb___36 *, struct io_event *);

struct kiocb___36 {
	atomic_t ki_users;
	struct file___245 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___36 *ki_cancel;
	void (*ki_dtor)(struct kiocb___36 *);
	union {
		void *user;
		struct task_struct___246 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___48 {
	struct ctl_table_header___51 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___48 {
	struct mutex___247 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___48 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___51 *ctl;
};

struct netns_ipv4___48 {
	struct ctl_table_header___51 *forw_hdr;
	struct ctl_table_header___51 *frags_hdr;
	struct ctl_table_header___51 *ipv4_hdr;
	struct ctl_table_header___51 *route_hdr;
	struct ctl_table_header___51 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___30 *fibnl;
	struct sock___30 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___48 {
	struct ctl_table_header___51 *hdr;
	struct ctl_table_header___51 *route_hdr;
	struct ctl_table_header___51 *icmp_hdr;
	struct ctl_table_header___51 *frags_hdr;
	struct ctl_table_header___51 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___38;

struct neighbour___28;

struct dst_ops___49 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___49 *);
	struct dst_entry___28 * (*check)(struct dst_entry___28 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___28 *);
	unsigned int (*mtu)(const struct dst_entry___28 *);
	u32 * (*cow_metrics)(struct dst_entry___28 *, long unsigned int);
	void (*destroy)(struct dst_entry___28 *);
	void (*ifdown)(struct dst_entry___28 *, struct net_device___38 *, int);
	struct dst_entry___28 * (*negative_advice)(struct dst_entry___28 *);
	void (*link_failure)(struct sk_buff___40 *);
	void (*update_pmtu)(struct dst_entry___28 *, struct sock___30 *, struct sk_buff___40 *, u32);
	void (*redirect)(struct dst_entry___28 *, struct sock___30 *, struct sk_buff___40 *);
	int (*local_out)(struct sk_buff___40 *);
	struct neighbour___28 * (*neigh_lookup)(const struct dst_entry___28 *, struct sk_buff___40 *, const void *);
	struct kmem_cache___228 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___49 {
	struct netns_sysctl_ipv6___48 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___49 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___30 **icmp_sk;
	struct sock___30 *ndisc_sk;
	struct sock___30 *tcp_sk;
	struct sock___30 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___48 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___51 *sysctl_header;
	struct sock___30 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___28 {
	struct sock___30 *v4_ctl_sk;
	struct sock___30 *v6_ctl_sk;
};

struct netns_nf___48 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___51 *nf_log_dir_header;
};

struct nf_proto_net___48 {
	struct ctl_table_header___51 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___48 {
	struct nf_proto_net___48 pn;
	unsigned int timeout;
};

struct nf_tcp_net___48 {
	struct nf_proto_net___48 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___48 {
	struct nf_proto_net___48 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___48 {
	struct nf_proto_net___48 pn;
	unsigned int timeout;
};

struct nf_ip_net___48 {
	struct nf_generic_net___48 generic;
	struct nf_tcp_net___48 tcp;
	struct nf_udp_net___48 udp;
	struct nf_icmp_net___48 icmp;
	struct nf_icmp_net___48 icmpv6;
};

struct netns_ct___48 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___51 *sysctl_header;
	struct ctl_table_header___51 *acct_sysctl_header;
	struct ctl_table_header___51 *tstamp_sysctl_header;
	struct ctl_table_header___51 *event_sysctl_header;
	struct ctl_table_header___51 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___228 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___48 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___48 {
	struct netns_sysctl_ipv6___48 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___49 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___30 *nlsk;
	struct sock___30 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___51 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___49 xfrm4_dst_ops;
	struct dst_ops___49 xfrm6_dst_ops;
};

struct net___50 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___51 sysctls;
	struct sock___30 *rtnl;
	struct sock___30 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___38 *loopback_dev;
	struct netns_core___48 core;
	struct netns_mib mib;
	struct netns_packet___48 packet;
	struct netns_unix___48 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___48 ipv4;
	struct netns_ipv6___49 ipv6;
	struct netns_sctp___48 sctp;
	struct netns_dccp___28 dccp;
	struct netns_nf___48 nf;
	struct netns_xt xt;
	struct netns_ct___48 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___48 nf_frag;
	struct sock___30 *nfnl;
	struct sock___30 *nfnl_stash;
	struct sk_buff_head___37 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___49 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___30 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___30 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___247 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___247 flow_flush_sem;
	long: 64;
	long: 64;
};

struct seq_file___170;

struct irq_chip___169 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___169 *);
	void (*irq_shutdown)(struct irq_data___169 *);
	void (*irq_enable)(struct irq_data___169 *);
	void (*irq_disable)(struct irq_data___169 *);
	void (*irq_ack)(struct irq_data___169 *);
	void (*irq_mask)(struct irq_data___169 *);
	void (*irq_mask_ack)(struct irq_data___169 *);
	void (*irq_unmask)(struct irq_data___169 *);
	void (*irq_eoi)(struct irq_data___169 *);
	int (*irq_set_affinity)(struct irq_data___169 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___169 *);
	int (*irq_set_type)(struct irq_data___169 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___169 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___169 *);
	void (*irq_bus_sync_unlock)(struct irq_data___169 *);
	void (*irq_cpu_online)(struct irq_data___169 *);
	void (*irq_cpu_offline)(struct irq_data___169 *);
	void (*irq_suspend)(struct irq_data___169 *);
	void (*irq_resume)(struct irq_data___169 *);
	void (*irq_pm_shutdown)(struct irq_data___169 *);
	void (*irq_print_chip)(struct irq_data___169 *, struct seq_file___170 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___169 *, void *);
	long unsigned int flags;
};

struct seq_operations___170;

struct seq_file___170 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___247 lock;
	const struct seq_operations___170 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___245;

struct file_operations___245 {
	struct module___149 *owner;
	loff_t (*llseek)(struct file___245 *, loff_t, int);
	ssize_t (*read)(struct file___245 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___245 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___36 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___36 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___245 *, void *, filldir_t);
	unsigned int (*poll)(struct file___245 *, struct poll_table_struct___135 *);
	long int (*unlocked_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___245 *, struct vm_area_struct___253 *);
	int (*open)(struct inode___245 *, struct file___245 *);
	int (*flush)(struct file___245 *, fl_owner_t);
	int (*release)(struct inode___245 *, struct file___245 *);
	int (*fsync)(struct file___245 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___36 *, int);
	int (*fasync)(int, struct file___245 *, int);
	int (*lock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*sendpage)(struct file___245 *, struct page___244 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___245 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___245 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___245 *, long int, struct file_lock___245 **, void **);
		struct {
			int (*setlease)(struct file___245 *, long int, struct file_lock___245 **);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long int (*fallocate)(struct file___245 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___170 *, struct file___245 *);
};

struct dma_map_ops___108 {
	void * (*alloc)(struct device___243 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___243 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___243 *, struct vm_area_struct___253 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___243 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___243 *, struct page___244 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___243 *, dma_addr_t);
	int (*dma_supported)(struct device___243 *, u64);
	int (*set_dma_mask)(struct device___243 *, u64);
	int is_phys;
};

struct bus_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___243 *, char *);
	ssize_t (*store)(struct bus_type___243 *, const char *, size_t);
};

struct device_attribute___243;

struct driver_attribute___243;

struct bus_type___243 {
	const char *name;
	const char *dev_name;
	struct device___243 *dev_root;
	struct bus_attribute___243 *bus_attrs;
	struct device_attribute___243 *dev_attrs;
	struct driver_attribute___243 *drv_attrs;
	const struct attribute_group___205 **bus_groups;
	const struct attribute_group___205 **dev_groups;
	const struct attribute_group___205 **drv_groups;
	int (*match)(struct device___243 *, struct device_driver___243 *);
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	int (*probe)(struct device___243 *);
	int (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*online)(struct device___243 *);
	int (*offline)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct device___243 *, struct device_attribute___243 *, char *);
	ssize_t (*store)(struct device___243 *, struct device_attribute___243 *, const char *, size_t);
};

struct driver_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___243 *, char *);
	ssize_t (*store)(struct device_driver___243 *, const char *, size_t);
};

struct device_driver___243 {
	const char *name;
	struct bus_type___243 *bus;
	struct module___149 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___243 *);
	int (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	const struct attribute_group___205 **groups;
	const struct dev_pm_ops___243 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___243 {
	const char *name;
	const struct attribute_group___205 **groups;
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
};

struct class_attribute___243;

struct class___243 {
	const char *name;
	struct module___149 *owner;
	struct class_attribute___243 *class_attrs;
	struct device_attribute___243 *dev_attrs;
	const struct attribute_group___205 **dev_groups;
	struct bin_attribute___207 *dev_bin_attrs;
	struct kobject___31 *dev_kobj;
	int (*dev_uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *);
	void (*class_release)(struct class___243 *);
	void (*dev_release)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
	struct subsys_private *p;
};

struct class_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct class___243 *, struct class_attribute___243 *, char *);
	ssize_t (*store)(struct class___243 *, struct class_attribute___243 *, const char *, size_t);
	const void * (*namespace)(struct class___243 *, const struct class_attribute___243 *);
};

struct device_rh___243 {
	struct dev_pm_info_rh___243 power;
};

struct dev_pm_qos_request___48 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___243 *dev;
};

struct dentry_operations___245;

struct super_block___245;

struct dentry___245 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___245 *d_parent;
	struct qstr d_name;
	struct inode___245 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___245 *d_op;
	struct super_block___245 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___245;

struct dquot___245;

struct block_device___245;

struct inode___245 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___245 *i_op;
	struct super_block___245 *i_sb;
	struct address_space___245 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___247 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___245 *i_fop;
	struct file_lock___245 *i_flock;
	struct address_space___245 i_data;
	struct dquot___245 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___245 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___245 {
	int (*d_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_hash)(const struct dentry___245 *, struct qstr *);
	int (*d_compare)(const struct dentry___245 *, const struct dentry___245 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___245 *);
	void (*d_release)(struct dentry___245 *);
	void (*d_prune)(struct dentry___245 *);
	void (*d_iput)(struct dentry___245 *, struct inode___245 *);
	char * (*d_dname)(struct dentry___245 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___245 *);
	int (*d_manage)(struct dentry___245 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___245;

struct mem_dqinfo___245 {
	struct quota_format_type___245 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___245;

struct quota_info___245 {
	unsigned int flags;
	struct mutex___247 dqio_mutex;
	struct mutex___247 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___245 *files[2];
	struct mem_dqinfo___245 info[2];
	const struct quota_format_ops___245 *ops[2];
};

struct file_system_type___245;

struct super_operations___245;

struct dquot_operations___245;

struct quotactl_ops___245;

struct xattr_handler___142;

struct super_block___245 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___245 *s_type;
	const struct super_operations___245 *s_op;
	const struct dquot_operations___245 *dq_op;
	const struct quotactl_ops___245 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___245 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___142 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___245 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___245 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___247 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___245 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___245 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___245 *bd_inode;
	struct super_block___245 *bd_super;
	struct mutex___247 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___245 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___247 bd_fsfreeze_mutex;
};

struct cgroup___141;

struct cgroup_subsys_state___141 {
	struct cgroup___141 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___245 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___245 *ia_file;
};

struct dquot___245 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___247 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___245 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___245 {
	int qf_fmt_id;
	const struct quota_format_ops___245 *qf_ops;
	struct module___149 *qf_owner;
	struct quota_format_type___245 *qf_next;
};

struct quota_format_ops___245 {
	int (*check_quota_file)(struct super_block___245 *, int);
	int (*read_file_info)(struct super_block___245 *, int);
	int (*write_file_info)(struct super_block___245 *, int);
	int (*free_file_info)(struct super_block___245 *, int);
	int (*read_dqblk)(struct dquot___245 *);
	int (*commit_dqblk)(struct dquot___245 *);
	int (*release_dqblk)(struct dquot___245 *);
};

struct dquot_operations___245 {
	int (*write_dquot)(struct dquot___245 *);
	struct dquot___245 * (*alloc_dquot)(struct super_block___245 *, int);
	void (*destroy_dquot)(struct dquot___245 *);
	int (*acquire_dquot)(struct dquot___245 *);
	int (*release_dquot)(struct dquot___245 *);
	int (*mark_dirty)(struct dquot___245 *);
	int (*write_info)(struct super_block___245 *, int);
	qsize_t * (*get_reserved_space)(struct inode___245 *);
};

struct quotactl_ops___245 {
	int (*quota_on)(struct super_block___245 *, int, int, struct path___245 *);
	int (*quota_on_meta)(struct super_block___245 *, int, int);
	int (*quota_off)(struct super_block___245 *, int);
	int (*quota_sync)(struct super_block___245 *, int);
	int (*get_info)(struct super_block___245 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___245 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___245 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___245 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___245 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___245 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___245 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___245 *, unsigned int);
};

struct address_space_operations___245 {
	int (*writepage)(struct page___244 *, struct writeback_control *);
	int (*readpage)(struct file___245 *, struct page___244 *);
	int (*writepages)(struct address_space___245 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___244 *);
	int (*readpages)(struct file___245 *, struct address_space___245 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___245 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___244 **, void **);
	int (*write_end)(struct file___245 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___244 *, void *);
	sector_t (*bmap)(struct address_space___245 *, sector_t);
	void (*invalidatepage)(struct page___244 *, long unsigned int);
	int (*releasepage)(struct page___244 *, gfp_t);
	void (*freepage)(struct page___244 *);
	ssize_t (*direct_IO)(int, struct kiocb___36 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___245 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___245 *, struct page___244 *, struct page___244 *, enum migrate_mode);
	int (*launder_page)(struct page___244 *);
	int (*is_partially_uptodate)(struct page___244 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___244 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___245 *, struct page___244 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___245 *, sector_t *);
	void (*swap_deactivate)(struct file___245 *);
	void (*invalidatepage_range)(struct page___244 *, unsigned int, unsigned int);
};

struct inode_operations___245 {
	struct dentry___245 * (*lookup)(struct inode___245 *, struct dentry___245 *, unsigned int);
	void * (*follow_link)(struct dentry___245 *, struct nameidata *);
	int (*permission)(struct inode___245 *, int);
	struct posix_acl * (*get_acl)(struct inode___245 *, int);
	int (*readlink)(struct dentry___245 *, char *, int);
	void (*put_link)(struct dentry___245 *, struct nameidata *, void *);
	int (*create)(struct inode___245 *, struct dentry___245 *, umode_t, bool);
	int (*link)(struct dentry___245 *, struct inode___245 *, struct dentry___245 *);
	int (*unlink)(struct inode___245 *, struct dentry___245 *);
	int (*symlink)(struct inode___245 *, struct dentry___245 *, const char *);
	int (*mkdir)(struct inode___245 *, struct dentry___245 *, umode_t);
	int (*rmdir)(struct inode___245 *, struct dentry___245 *);
	int (*mknod)(struct inode___245 *, struct dentry___245 *, umode_t, dev_t);
	int (*rename)(struct inode___245 *, struct dentry___245 *, struct inode___245 *, struct dentry___245 *);
	int (*setattr)(struct dentry___245 *, struct iattr___245 *);
	int (*getattr)(struct vfsmount *, struct dentry___245 *, struct kstat *);
	int (*setxattr)(struct dentry___245 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___245 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___245 *, char *, size_t);
	int (*removexattr)(struct dentry___245 *, const char *);
	int (*fiemap)(struct inode___245 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___245 *, struct timespec *, int);
	int (*atomic_open)(struct inode___245 *, struct dentry___245 *, struct file___245 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___245;

struct lock_manager_operations___245;

struct file_lock___245 {
	struct file_lock___245 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___245 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___245 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___245 *fl_ops;
	const struct lock_manager_operations___245 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___245 {
	void (*fl_copy_lock)(struct file_lock___245 *, struct file_lock___245 *);
	void (*fl_release_private)(struct file_lock___245 *);
};

struct lock_manager_operations___245 {
	int (*lm_compare_owner)(struct file_lock___245 *, struct file_lock___245 *);
	long unsigned int (*lm_owner_key)(struct file_lock___245 *);
	void (*lm_notify)(struct file_lock___245 *);
	int (*lm_grant)(struct file_lock___245 *, struct file_lock___245 *, int);
	void (*lm_break)(struct file_lock___245 *);
	int (*lm_change)(struct file_lock___245 **, int);
};

struct file_system_type___245 {
	const char *name;
	int fs_flags;
	struct dentry___245 * (*mount)(struct file_system_type___245 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___245 *);
	struct module___149 *owner;
	struct file_system_type___245 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___245 {
	struct inode___245 * (*alloc_inode)(struct super_block___245 *);
	void (*destroy_inode)(struct inode___245 *);
	void (*dirty_inode)(struct inode___245 *, int);
	int (*write_inode)(struct inode___245 *, struct writeback_control *);
	int (*drop_inode)(struct inode___245 *);
	void (*evict_inode)(struct inode___245 *);
	void (*put_super)(struct super_block___245 *);
	int (*sync_fs)(struct super_block___245 *, int);
	int (*freeze_fs)(struct super_block___245 *);
	int (*unfreeze_fs)(struct super_block___245 *);
	int (*statfs)(struct dentry___245 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___245 *, int *, char *);
	void (*umount_begin)(struct super_block___245 *);
	int (*show_options)(struct seq_file___170 *, struct dentry___245 *);
	int (*show_devname)(struct seq_file___170 *, struct dentry___245 *);
	int (*show_path)(struct seq_file___170 *, struct dentry___245 *);
	int (*show_stats)(struct seq_file___170 *, struct dentry___245 *);
	ssize_t (*quota_read)(struct super_block___245 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___245 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___245 *);
	int (*bdev_try_to_free_page)(struct super_block___245 *, struct page___244 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___245 *);
	void (*free_cached_objects)(struct super_block___245 *, int);
};

struct xattr_handler___142 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___245 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___245 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___245 *, const char *, const void *, size_t, int, int);
};

struct kmem_cache_cpu___227 {
	void **freelist;
	long unsigned int tid;
	struct page___244 *page;
	struct page___244 *partial;
};

struct memcg_cache_params___228 {
	bool is_root_cache;
	union {
		struct kmem_cache___228 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___228 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___36 {
	atomic_t use;
	unsigned int mask;
	struct net_device___38 *physindev;
	struct net_device___38 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___36(struct sk_buff___40 **);

struct net_device_ops___36;

struct ethtool_ops___36;

struct header_ops___36;

struct netdev_rx_queue___36;

struct netdev_queue___36;

struct rtnl_link_ops___28;

struct dcbnl_rtnl_ops___36;

struct net_device___38 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___36 *netdev_ops;
	const struct ethtool_ops___36 *ethtool_ops;
	const struct header_ops___36 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___31 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___36 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___36 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___36 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___36 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___36 = 0,
		NETREG_REGISTERED___36 = 1,
		NETREG_UNREGISTERING___36 = 2,
		NETREG_UNREGISTERED___36 = 3,
		NETREG_RELEASED___36 = 4,
		NETREG_DUMMY___36 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___36 = 0,
		RTNL_LINK_INITIALIZING___36 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___38 *);
	struct netpoll_info *npinfo;
	struct net___50 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___243 dev;
	const struct attribute_group___205 *sysfs_groups[4];
	const struct rtnl_link_ops___28 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___36 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___40 {
	struct sk_buff___40 *next;
	struct sk_buff___40 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___30 *sk;
	struct net_device___38 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___40 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___36 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___36 {
	int (*get_settings)(struct net_device___38 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___38 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___38 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___38 *);
	void (*get_regs)(struct net_device___38 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___38 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___38 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___38 *);
	void (*set_msglevel)(struct net_device___38 *, u32);
	int (*nway_reset)(struct net_device___38 *);
	u32 (*get_link)(struct net_device___38 *);
	int (*get_eeprom_len)(struct net_device___38 *);
	int (*get_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___38 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___38 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___38 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___38 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___38 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___38 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___38 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___38 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___38 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___38 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___38 *);
	void (*complete)(struct net_device___38 *);
	u32 (*get_priv_flags)(struct net_device___38 *);
	int (*set_priv_flags)(struct net_device___38 *, u32);
	int (*get_sset_count)(struct net_device___38 *, int);
	int (*get_rxnfc)(struct net_device___38 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___38 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___38 *, struct ethtool_flash *);
	int (*reset)(struct net_device___38 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___38 *);
	int (*get_rxfh_indir)(struct net_device___38 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___38 *, const u32 *);
	void (*get_channels)(struct net_device___38 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___38 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___38 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___38 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___38 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___38 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___38 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___38 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___38 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___38 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___38 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___38 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___28 {
	struct callback_head callback_head;
	struct dst_entry___28 *child;
	struct net_device___38 *dev;
	struct dst_ops___49 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___28 *path;
	struct dst_entry___28 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___40 *);
	union {
		int (*output)(struct sock___30 *, struct sk_buff___40 *);
		struct {
			int (*output)(struct sk_buff___40 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___28 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___28;

struct neigh_parms___28;

struct neigh_ops___28;

struct neighbour___28 {
	struct neighbour___28 *next;
	struct neigh_table___28 *tbl;
	struct neigh_parms___28 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___37 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___28 *, struct sk_buff___40 *);
	const struct neigh_ops___28 *ops;
	struct callback_head rcu;
	struct net_device___38 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___49 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___40 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___40 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___50 *, struct dst_entry___28 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___40 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___40 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___170 {
	void * (*start)(struct seq_file___170 *, loff_t *);
	void (*stop)(struct seq_file___170 *, void *);
	void * (*next)(struct seq_file___170 *, void *, loff_t *);
	int (*show)(struct seq_file___170 *, void *);
};

struct dcbnl_rtnl_ops___36 {
	int (*ieee_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___38 *);
	u8 (*setstate)(struct net_device___38 *, u8);
	void (*getpermhwaddr)(struct net_device___38 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___38 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___38 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___38 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___38 *, int, u8 *);
	void (*setpfccfg)(struct net_device___38 *, int, u8);
	void (*getpfccfg)(struct net_device___38 *, int, u8 *);
	u8 (*setall)(struct net_device___38 *);
	u8 (*getcap)(struct net_device___38 *, int, u8 *);
	int (*getnumtcs)(struct net_device___38 *, int, u8 *);
	int (*setnumtcs)(struct net_device___38 *, int, u8);
	u8 (*getpfcstate)(struct net_device___38 *);
	void (*setpfcstate)(struct net_device___38 *, u8);
	void (*getbcncfg)(struct net_device___38 *, int, u32 *);
	void (*setbcncfg)(struct net_device___38 *, int, u32);
	void (*getbcnrp)(struct net_device___38 *, int, u8 *);
	void (*setbcnrp)(struct net_device___38 *, int, u8);
	u8 (*setapp)(struct net_device___38 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___38 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___38 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___38 *, int, u8);
	u8 (*getdcbx)(struct net_device___38 *);
	u8 (*setdcbx)(struct net_device___38 *, u8);
	int (*peer_getappinfo)(struct net_device___38 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___38 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___38 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___38 *, struct cee_pfc *);
};

struct cgroupfs_root___141;

struct cgroup___141 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___141 *parent;
	struct dentry___245 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___141 *subsys[11];
	struct cgroupfs_root___141 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___247 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___141 {
	struct super_block___245 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___141 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___80 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___245 *, struct file___245 *);
	ssize_t (*read)(struct cgroup___141 *, struct cftype___80 *, struct file___245 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___141 *, struct cftype___80 *);
	s64 (*read_s64)(struct cgroup___141 *, struct cftype___80 *);
	int (*read_map)(struct cgroup___141 *, struct cftype___80 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___141 *, struct cftype___80 *, struct seq_file___170 *);
	ssize_t (*write)(struct cgroup___141 *, struct cftype___80 *, struct file___245 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___141 *, struct cftype___80 *, u64);
	int (*write_s64)(struct cgroup___141 *, struct cftype___80 *, s64);
	int (*write_string)(struct cgroup___141 *, struct cftype___80 *, const char *);
	int (*trigger)(struct cgroup___141 *, unsigned int);
	int (*release)(struct inode___245 *, struct file___245 *);
	int (*register_event)(struct cgroup___141 *, struct cftype___80 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___141 *, struct cftype___80 *, struct eventfd_ctx *);
};

struct cftype_set___76 {
	struct list_head node;
	struct cftype___80 *cfts;
};

struct task_and_cgroup___76 {
	struct task_struct___246 *task;
	struct cgroup___141 *cgrp;
	struct css_set___141 *cg;
};

struct cgroup_taskset___76 {
	struct task_and_cgroup___76 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___141 *cur_cgrp;
};

struct cgroup_subsys___76 {
	struct cgroup_subsys_state___141 * (*css_alloc)(struct cgroup___141 *);
	int (*css_online)(struct cgroup___141 *);
	void (*css_offline)(struct cgroup___141 *);
	void (*css_free)(struct cgroup___141 *);
	int (*can_attach)(struct cgroup___141 *, struct cgroup_taskset___76 *);
	void (*cancel_attach)(struct cgroup___141 *, struct cgroup_taskset___76 *);
	void (*attach)(struct cgroup___141 *, struct cgroup_taskset___76 *);
	void (*fork)(struct task_struct___246 *);
	void (*exit)(struct cgroup___141 *, struct cgroup___141 *, struct task_struct___246 *);
	void (*bind)(struct cgroup___141 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___141 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___80 *base_cftypes;
	struct cftype_set___76 base_cftset;
	struct module___149 *module;
};

struct request_sock_ops___19;

struct request_sock___20 {
	struct sock_common___28 __req_common;
	struct request_sock___20 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___19 *rsk_ops;
	struct sock___30 *sk;
	u32 secid;
	u32 peer_secid;
};

struct scm_fp_list___2 {
	short int count;
	short int max;
	struct file___245 *fp[253];
};

struct scm_cookie___2 {
	struct pid___95 *pid;
	struct scm_fp_list___2 *fp;
	struct scm_creds creds;
	u32 secid;
};

struct netlink_callback___38 {
	struct sk_buff___40 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___40 *, struct netlink_callback___38 *);
	int (*done)(struct netlink_callback___38 *);
	void *data;
	struct module___149 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___36 {
	int (*create)(struct sk_buff___40 *, struct net_device___38 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___40 *, unsigned char *);
	int (*rebuild)(struct sk_buff___40 *);
	int (*cache)(const struct neighbour___28 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___38 *, const unsigned char *);
};

struct napi_struct___36 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___36 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___38 *dev;
	struct sk_buff___40 *gro_list;
	struct sk_buff___40 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___36 {
	struct net_device___38 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___31 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___36 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___31 kobj;
	struct net_device___38 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___36 {
	int (*ndo_init)(struct net_device___38 *);
	void (*ndo_uninit)(struct net_device___38 *);
	int (*ndo_open)(struct net_device___38 *);
	int (*ndo_stop)(struct net_device___38 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___40 *, struct net_device___38 *);
	u16 (*ndo_select_queue)(struct net_device___38 *, struct sk_buff___40 *);
	void (*ndo_change_rx_flags)(struct net_device___38 *, int);
	void (*ndo_set_rx_mode)(struct net_device___38 *);
	int (*ndo_set_mac_address)(struct net_device___38 *, void *);
	int (*ndo_validate_addr)(struct net_device___38 *);
	int (*ndo_do_ioctl)(struct net_device___38 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___38 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___38 *, int);
	int (*ndo_neigh_setup)(struct net_device___38 *, struct neigh_parms___28 *);
	void (*ndo_tx_timeout)(struct net_device___38 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___38 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___38 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___38 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___38 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___38 *);
	int (*ndo_netpoll_setup)(struct net_device___38 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___38 *);
	int (*ndo_busy_poll)(struct napi_struct___36 *);
	int (*ndo_set_vf_mac)(struct net_device___38 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___38 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___38 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___38 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___38 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___38 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___38 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___38 *, int, struct sk_buff___40 *);
	int (*ndo_setup_tc)(struct net_device___38 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___38 *);
	int (*ndo_fcoe_disable)(struct net_device___38 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___38 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___38 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___38 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___38 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___38 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___38 *, const struct sk_buff___40 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___38 *, struct net_device___38 *);
	int (*ndo_del_slave)(struct net_device___38 *, struct net_device___38 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___28 *);
	void (*ndo_neigh_destroy)(struct neighbour___28 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___40 *, struct netlink_callback___38 *, struct net_device___38 *, int);
	int (*ndo_bridge_setlink)(struct net_device___38 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___40 *, u32, u32, struct net_device___38 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___38 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___38 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___38 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___38 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___38 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___38 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___40 *, struct net_device___38 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___38 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___38 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___38 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___28 {
	struct net___50 *net;
	struct net_device___38 *dev;
	struct neigh_parms___28 *next;
	int (*neigh_setup)(struct neighbour___28 *);
	void (*neigh_cleanup)(struct neighbour___28 *);
	struct neigh_table___28 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___28 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___38 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___50 *, struct net_device___38 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___38 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___38 *, struct list_head *);
	size_t (*get_size)(const struct net_device___38 *);
	int (*fill_info)(struct sk_buff___40 *, const struct net_device___38 *);
	size_t (*get_xstats_size)(const struct net_device___38 *);
	int (*fill_xstats)(struct sk_buff___40 *, const struct net_device___38 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___50 * (*get_link_net)(const struct net_device___38 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___38 *, struct net_device___38 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___38 *, const struct net_device___38 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___40 *, const struct net_device___38 *, const struct net_device___38 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___29 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___40 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___28;

struct neigh_hash_table___28;

struct neigh_table___28 {
	struct neigh_table___28 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___38 *, __u32 *);
	int (*constructor)(struct neighbour___28 *);
	int (*pconstructor)(struct pneigh_entry___28 *);
	void (*pdestructor)(struct pneigh_entry___28 *);
	void (*proxy_redo)(struct sk_buff___40 *);
	char *id;
	struct neigh_parms___28 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___37 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___28 *nht;
	struct pneigh_entry___28 **phash_buckets;
};

struct neigh_ops___28 {
	int family;
	void (*solicit)(struct neighbour___28 *, struct sk_buff___40 *);
	void (*error_report)(struct neighbour___28 *, struct sk_buff___40 *);
	int (*output)(struct neighbour___28 *, struct sk_buff___40 *);
	int (*connected_output)(struct neighbour___28 *, struct sk_buff___40 *);
};

struct pneigh_entry___28 {
	struct pneigh_entry___28 *next;
	struct net___50 *net;
	struct net_device___38 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___28 {
	struct neighbour___28 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___17;

struct proto___28 {
	void (*close)(struct sock___30 *, long int);
	int (*connect)(struct sock___30 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___30 *, int);
	struct sock___30 * (*accept)(struct sock___30 *, int, int *);
	int (*ioctl)(struct sock___30 *, int, long unsigned int);
	int (*init)(struct sock___30 *);
	void (*destroy)(struct sock___30 *);
	void (*shutdown)(struct sock___30 *, int);
	int (*setsockopt)(struct sock___30 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___30 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___30 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___30 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___30 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___36 *, struct sock___30 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___36 *, struct sock___30 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___30 *, struct page___244 *, int, size_t, int);
	int (*bind)(struct sock___30 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___30 *, struct sk_buff___40 *);
	void (*release_cb)(struct sock___30 *);
	void (*mtu_reduced)(struct sock___30 *);
	void (*hash)(struct sock___30 *);
	void (*unhash)(struct sock___30 *);
	void (*rehash)(struct sock___30 *);
	int (*get_port)(struct sock___30 *, short unsigned int);
	void (*clear_sk)(struct sock___30 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___30 *);
	void (*enter_memory_pressure)(struct sock___30 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___228 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___19 *rsk_prot;
	struct timewait_sock_ops___17 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___149 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___76 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___28 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___28 {
	void (*enter_memory_pressure)(struct sock___30 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___19 {
	int family;
	int obj_size;
	struct kmem_cache___228 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___30 *, struct request_sock___20 *);
	void (*send_ack)(struct sock___30 *, struct sk_buff___40 *, struct request_sock___20 *);
	void (*send_reset)(struct sock___30 *, struct sk_buff___40 *);
	void (*destructor)(struct request_sock___20 *);
	void (*syn_ack_timeout)(struct sock___30 *, struct request_sock___20 *);
};

struct timewait_sock_ops___17 {
	struct kmem_cache___228 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___30 *, struct sock___30 *, void *);
	void (*twsk_destructor)(struct sock___30 *);
};

enum {
	TCA_STATS_UNSPEC = 0,
	TCA_STATS_BASIC = 1,
	TCA_STATS_RATE_EST = 2,
	TCA_STATS_QUEUE = 3,
	TCA_STATS_APP = 4,
	TCA_STATS_RATE_EST64 = 5,
	__TCA_STATS_MAX = 6,
};

struct gnet_stats_basic {
	__u64 bytes;
	__u32 packets;
};

struct gnet_stats_rate_est {
	__u32 bps;
	__u32 pps;
};

struct gnet_dump___2 {
	spinlock_t *lock;
	struct sk_buff___27 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct gnet_estimator {
	signed char interval;
	unsigned char ewma_log;
};

struct gen_estimator {
	struct list_head list;
	struct gnet_stats_basic_packed *bstats;
	struct gnet_stats_rate_est64 *rate_est;
	spinlock_t *stats_lock;
	int ewma_log;
	u64 last_bytes;
	u64 avbps;
	u32 last_packets;
	u32 avpps;
	struct callback_head e_rcu;
	struct rb_node node;
};

struct gen_estimator_head {
	struct timer_list timer;
	struct list_head list;
};

struct net_generic {
	unsigned int len;
	struct callback_head rcu;
	void *ptr[0];
};

struct pernet_operations___5 {
	struct list_head list;
	int (*init)(struct net___39 *);
	void (*exit)(struct net___39 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct rtgenmsg {
	unsigned char rtgen_family;
};

enum rtnetlink_groups {
	RTNLGRP_NONE = 0,
	RTNLGRP_LINK = 1,
	RTNLGRP_NOTIFY = 2,
	RTNLGRP_NEIGH = 3,
	RTNLGRP_TC = 4,
	RTNLGRP_IPV4_IFADDR = 5,
	RTNLGRP_IPV4_MROUTE = 6,
	RTNLGRP_IPV4_ROUTE = 7,
	RTNLGRP_IPV4_RULE = 8,
	RTNLGRP_IPV6_IFADDR = 9,
	RTNLGRP_IPV6_MROUTE = 10,
	RTNLGRP_IPV6_ROUTE = 11,
	RTNLGRP_IPV6_IFINFO = 12,
	RTNLGRP_DECnet_IFADDR = 13,
	RTNLGRP_NOP2 = 14,
	RTNLGRP_DECnet_ROUTE = 15,
	RTNLGRP_DECnet_RULE = 16,
	RTNLGRP_NOP4 = 17,
	RTNLGRP_IPV6_PREFIX = 18,
	RTNLGRP_IPV6_RULE = 19,
	RTNLGRP_ND_USEROPT = 20,
	RTNLGRP_PHONET_IFADDR = 21,
	RTNLGRP_PHONET_ROUTE = 22,
	RTNLGRP_DCB = 23,
	RTNLGRP_IPV4_NETCONF = 24,
	RTNLGRP_IPV6_NETCONF = 25,
	RTNLGRP_MDB = 26,
	__RH_RESERVED_RTNLGRP_MPLS_ROUTE = 27,
	RTNLGRP_NSID = 28,
	__RTNLGRP_MAX = 29,
};

struct proc_ns_operations___14 {
	const char *name;
	int type;
	void * (*get)(struct task_struct___215 *);
	void (*put)(void *);
	int (*install)(struct nsproxy___113 *, void *);
	unsigned int (*inum)(void *);
};

struct proc_ns___10 {
	void *ns;
	const struct proc_ns_operations___14 *ns_ops;
};

enum {
	NETNSA_NONE = 0,
	NETNSA_NSID = 1,
	NETNSA_PID = 2,
	NETNSA_FD = 3,
	__NETNSA_MAX = 4,
};

typedef int (*rtnl_doit_func)(struct sk_buff___29 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func)(struct sk_buff___29 *, struct netlink_callback___27 *);

typedef u16 (*rtnl_calcit_func)(struct sk_buff___29 *, struct nlmsghdr *);

struct rtnl_net_dump_cb {
	struct net___39 *net;
	struct sk_buff___29 *skb;
	struct netlink_callback___27 *cb;
	int idx;
	int s_idx;
};

struct page___245;

typedef struct page___245 *pgtable_t___245;

struct address_space___246;

struct kmem_cache___229;

struct page___245 {
	long unsigned int flags;
	struct address_space___246 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___245 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___245 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___229 *slab_cache;
		struct page___245 *first_page;
	};
	long: 64;
};

struct task_struct___247;

struct pv_cpu_ops___247 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___247 *);
	void (*end_context_switch)(struct task_struct___247 *);
};

struct mutex___248 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___247 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___240 {
	struct page___245 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___254;

struct nsproxy___127;

struct signal_struct___247;

struct css_set___142;

struct task_struct___247 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___247 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___254 *mm;
	struct mm_struct___254 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___247 *real_parent;
	struct task_struct___247 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___247 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___247 = 0,
		VTIME_USER___247 = 1,
		VTIME_SYS___247 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___127 *nsproxy;
	struct signal_struct___247 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___142 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___248 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___240 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___254 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___254 *, struct mm_struct___254 *);
	void (*dup_mmap)(struct mm_struct___254 *, struct mm_struct___254 *);
	void (*exit_mmap)(struct mm_struct___254 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___254 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___254 *);
	void (*pgd_free)(struct mm_struct___254 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___254 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___254 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___254 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___254 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___254 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___254 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___254 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___254 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___254 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___254 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___254 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___248 lock;
	void *vdso;
} mm_context_t___248;

struct xol_area___245;

struct uprobes_state___245 {
	struct xol_area___245 *xol_area;
};

struct vm_area_struct___254;

struct file___246;

struct core_state___247;

struct mm_struct___254 {
	struct vm_area_struct___254 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___254 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___254 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___248 context;
	long unsigned int flags;
	struct core_state___247 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___247 *owner;
	struct file___246 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___245 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___245 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___245 *page;
	long unsigned int vaddr;
};

struct kset___32;

struct kobj_type___32;

struct kobject___32 {
	const char *name;
	struct list_head entry;
	struct kobject___32 *parent;
	struct kset___32 *kset;
	struct kobj_type___32 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___228;

struct memcg_cache_params___229;

struct kmem_cache___229 {
	struct kmem_cache_cpu___228 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___32 kobj;
	struct memcg_cache_params___229 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___246;

struct address_space_operations___246;

struct address_space___246 {
	struct inode___246 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___248 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___246 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___246;

struct path___246 {
	struct vfsmount *mnt;
	struct dentry___246 *dentry;
};

struct file_operations___246;

struct file___246 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___246 f_path;
	struct inode___246 *f_inode;
	const struct file_operations___246 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___246 *f_mapping;
	struct mutex___248 f_pos_lock;
};

struct vm_operations_struct___220;

struct vm_area_struct___254 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___254 *vm_next;
	struct vm_area_struct___254 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___254 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___220 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___246 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___216;

struct vm_operations_struct___220 {
	void (*open)(struct vm_area_struct___254 *);
	void (*close)(struct vm_area_struct___254 *);
	int (*fault)(struct vm_area_struct___254 *, struct vm_fault___216 *);
	int (*page_mkwrite)(struct vm_area_struct___254 *, struct vm_fault___216 *);
	int (*access)(struct vm_area_struct___254 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___254 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___254 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___254 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___254 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___247 {
	struct task_struct___247 *task;
	struct core_thread___247 *next;
};

struct core_state___247 {
	atomic_t nr_threads;
	struct core_thread___247 dumper;
	struct completion startup;
};

struct fasync_struct___246;

struct socket_wq___29 {
	wait_queue_head_t wait;
	struct fasync_struct___246 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___246 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___246 *fa_next;
	struct file___246 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___31;

struct proto_ops___29;

struct socket___30 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___29 *wq;
	struct file___246 *file;
	struct sock___31 *sk;
	const struct proto_ops___29 *ops;
};

struct proto___29;

struct net___51;

struct sock_common___29 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___29 *skc_prot;
	struct net___51 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___41;

struct sk_buff_head___38 {
	struct sk_buff___41 *next;
	struct sk_buff___41 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___30;

struct dst_entry___29;

struct cg_proto___29;

struct sock___31 {
	struct sock_common___29 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___38 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___41 *head;
		struct sk_buff___41 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___30 *sk_filter;
	struct socket_wq___29 *sk_wq;
	struct sk_buff_head___38 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___29 *sk_rx_dst;
	struct dst_entry___29 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___38 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___38 sk_error_queue;
	struct proto___29 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___30 *sk_socket;
	void *sk_user_data;
	struct page_frag___240 sk_frag;
	struct sk_buff___41 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___29 *sk_cgrp;
	void (*sk_state_change)(struct sock___31 *);
	void (*sk_data_ready)(struct sock___31 *, int);
	void (*sk_write_space)(struct sock___31 *);
	void (*sk_error_report)(struct sock___31 *);
	int (*sk_backlog_rcv)(struct sock___31 *, struct sk_buff___41 *);
	void (*sk_destruct)(struct sock___31 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___136;

struct kiocb___37;

struct proto_ops___29 {
	int family;
	struct module *owner;
	int (*release)(struct socket___30 *);
	int (*bind)(struct socket___30 *, struct sockaddr *, int);
	int (*connect)(struct socket___30 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___30 *, struct socket___30 *);
	int (*accept)(struct socket___30 *, struct socket___30 *, int);
	int (*getname)(struct socket___30 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___246 *, struct socket___30 *, struct poll_table_struct___136 *);
	int (*ioctl)(struct socket___30 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___30 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___30 *, int);
	int (*shutdown)(struct socket___30 *, int);
	int (*setsockopt)(struct socket___30 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___30 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___30 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___30 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___37 *, struct socket___30 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___37 *, struct socket___30 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___246 *, struct socket___30 *, struct vm_area_struct___254 *);
	ssize_t (*sendpage)(struct socket___30 *, struct page___245 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___30 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___31 *, int);
		struct {
			void (*set_peek_off)(struct sock___31 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___138)(struct file___246 *, wait_queue_head_t *, struct poll_table_struct___136 *);

struct poll_table_struct___136 {
	poll_queue_proc___138 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___37(struct kiocb___37 *, struct io_event *);

struct kiocb___37 {
	atomic_t ki_users;
	struct file___246 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___37 *ki_cancel;
	void (*ki_dtor)(struct kiocb___37 *);
	union {
		void *user;
		struct task_struct___247 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___52;

struct ctl_table_set___52;

struct ctl_dir___52;

struct ctl_node___52;

struct ctl_table_header___52 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___52 *root;
	struct ctl_table_set___52 *set;
	struct ctl_dir___52 *parent;
	struct ctl_node___52 *node;
};

struct ctl_dir___52 {
	struct ctl_table_header___52 header;
	struct rb_root root;
};

struct ctl_table_set___52 {
	int (*is_seen)(struct ctl_table_set___52 *);
	struct ctl_dir___52 dir;
};

struct netns_core___49 {
	struct ctl_table_header___52 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___49 {
	struct mutex___248 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___49 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___52 *ctl;
};

struct netns_ipv4___49 {
	struct ctl_table_header___52 *forw_hdr;
	struct ctl_table_header___52 *frags_hdr;
	struct ctl_table_header___52 *ipv4_hdr;
	struct ctl_table_header___52 *route_hdr;
	struct ctl_table_header___52 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___31 *fibnl;
	struct sock___31 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___49 {
	struct ctl_table_header___52 *hdr;
	struct ctl_table_header___52 *route_hdr;
	struct ctl_table_header___52 *icmp_hdr;
	struct ctl_table_header___52 *frags_hdr;
	struct ctl_table_header___52 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___39;

struct neighbour___29;

struct dst_ops___50 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___50 *);
	struct dst_entry___29 * (*check)(struct dst_entry___29 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___29 *);
	unsigned int (*mtu)(const struct dst_entry___29 *);
	u32 * (*cow_metrics)(struct dst_entry___29 *, long unsigned int);
	void (*destroy)(struct dst_entry___29 *);
	void (*ifdown)(struct dst_entry___29 *, struct net_device___39 *, int);
	struct dst_entry___29 * (*negative_advice)(struct dst_entry___29 *);
	void (*link_failure)(struct sk_buff___41 *);
	void (*update_pmtu)(struct dst_entry___29 *, struct sock___31 *, struct sk_buff___41 *, u32);
	void (*redirect)(struct dst_entry___29 *, struct sock___31 *, struct sk_buff___41 *);
	int (*local_out)(struct sk_buff___41 *);
	struct neighbour___29 * (*neigh_lookup)(const struct dst_entry___29 *, struct sk_buff___41 *, const void *);
	struct kmem_cache___229 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___50 {
	struct netns_sysctl_ipv6___49 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___50 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___31 **icmp_sk;
	struct sock___31 *ndisc_sk;
	struct sock___31 *tcp_sk;
	struct sock___31 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___49 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___52 *sysctl_header;
	struct sock___31 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___29 {
	struct sock___31 *v4_ctl_sk;
	struct sock___31 *v6_ctl_sk;
};

struct netns_nf___49 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___52 *nf_log_dir_header;
};

struct nf_proto_net___49 {
	struct ctl_table_header___52 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___49 {
	struct nf_proto_net___49 pn;
	unsigned int timeout;
};

struct nf_tcp_net___49 {
	struct nf_proto_net___49 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___49 {
	struct nf_proto_net___49 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___49 {
	struct nf_proto_net___49 pn;
	unsigned int timeout;
};

struct nf_ip_net___49 {
	struct nf_generic_net___49 generic;
	struct nf_tcp_net___49 tcp;
	struct nf_udp_net___49 udp;
	struct nf_icmp_net___49 icmp;
	struct nf_icmp_net___49 icmpv6;
};

struct netns_ct___49 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___52 *sysctl_header;
	struct ctl_table_header___52 *acct_sysctl_header;
	struct ctl_table_header___52 *tstamp_sysctl_header;
	struct ctl_table_header___52 *event_sysctl_header;
	struct ctl_table_header___52 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___229 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___49 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___49 {
	struct netns_sysctl_ipv6___49 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___50 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___31 *nlsk;
	struct sock___31 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___52 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___50 xfrm4_dst_ops;
	struct dst_ops___50 xfrm6_dst_ops;
};

struct net___51 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___52 sysctls;
	struct sock___31 *rtnl;
	struct sock___31 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___39 *loopback_dev;
	struct netns_core___49 core;
	struct netns_mib mib;
	struct netns_packet___49 packet;
	struct netns_unix___49 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___49 ipv4;
	struct netns_ipv6___50 ipv6;
	struct netns_sctp___49 sctp;
	struct netns_dccp___29 dccp;
	struct netns_nf___49 nf;
	struct netns_xt xt;
	struct netns_ct___49 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___49 nf_frag;
	struct sock___31 *nfnl;
	struct sock___31 *nfnl_stash;
	struct sk_buff_head___38 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___50 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___31 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___31 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___248 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___248 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___247;

struct lruvec___247 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___247 *zone;
};

struct pglist_data___247;

struct zone___247 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___247 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___247 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___247 {
	struct zone___247 *zone;
	int zone_idx;
};

struct zonelist___247 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___247 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___247 {
	struct zone___247 node_zones[4];
	struct zonelist___247 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___247 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___170;

struct x86_io_apic_ops___170 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___170 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___170;

struct irq_data___170 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___170 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___244;

struct dev_pm_ops___244 {
	int (*prepare)(struct device___244 *);
	void (*complete)(struct device___244 *);
	int (*suspend)(struct device___244 *);
	int (*resume)(struct device___244 *);
	int (*freeze)(struct device___244 *);
	int (*thaw)(struct device___244 *);
	int (*poweroff)(struct device___244 *);
	int (*restore)(struct device___244 *);
	int (*suspend_late)(struct device___244 *);
	int (*resume_early)(struct device___244 *);
	int (*freeze_late)(struct device___244 *);
	int (*thaw_early)(struct device___244 *);
	int (*poweroff_late)(struct device___244 *);
	int (*restore_early)(struct device___244 *);
	int (*suspend_noirq)(struct device___244 *);
	int (*resume_noirq)(struct device___244 *);
	int (*freeze_noirq)(struct device___244 *);
	int (*thaw_noirq)(struct device___244 *);
	int (*poweroff_noirq)(struct device___244 *);
	int (*restore_noirq)(struct device___244 *);
	int (*runtime_suspend)(struct device___244 *);
	int (*runtime_resume)(struct device___244 *);
	int (*runtime_idle)(struct device___244 *);
};

struct dev_pm_qos___48;

struct dev_pm_info___48 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___48 *qos;
};

struct dma_map_ops___109;

struct dev_archdata___109 {
	struct dma_map_ops___109 *dma_ops;
	void *iommu;
};

struct device_type___244;

struct bus_type___244;

struct device_driver___244;

struct dev_pm_domain___244;

struct class___244;

struct attribute_group___206;

struct device_rh___244;

struct device___244 {
	struct device___244 *parent;
	struct device_private *p;
	struct kobject___32 kobj;
	const char *init_name;
	const struct device_type___244 *type;
	struct mutex___248 mutex;
	struct bus_type___244 *bus;
	struct device_driver___244 *driver;
	void *platform_data;
	struct dev_pm_info___48 power;
	struct dev_pm_domain___244 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___109 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___244 *class;
	const struct attribute_group___206 **groups;
	void (*release)(struct device___244 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___244 *device_rh;
};

struct dev_pm_qos_request___49;

struct dev_pm_qos___48 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___49 *latency_req;
	struct dev_pm_qos_request___49 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___49 *latency_tolerance_req;
};

struct dev_pm_info_rh___244 {
	void (*set_latency_tolerance)(struct device___244 *, s32);
};

struct dev_pm_domain___244 {
	struct dev_pm_ops___244 ops;
};

struct smp_ops___247 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___247 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___29 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___31 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___208;

struct attribute_group___206 {
	const char *name;
	umode_t (*is_visible)(struct kobject___32 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___208 **bin_attrs;
};

struct bin_attribute___208 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___246 *, struct kobject___32 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___246 *, struct kobject___32 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	int (*mmap)(struct file___246 *, struct kobject___32 *, struct bin_attribute___208 *, struct vm_area_struct___254 *);
};

struct sysfs_ops___32 {
	ssize_t (*show)(struct kobject___32 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___32 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___32 *, const struct attribute *);
};

struct kset_uevent_ops___32;

struct kset___32 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___32 kobj;
	const struct kset_uevent_ops___32 *uevent_ops;
};

struct kobj_type___32 {
	void (*release)(struct kobject___32 *);
	const struct sysfs_ops___32 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___32 *);
	const void * (*namespace)(struct kobject___32 *);
};

struct kset_uevent_ops___32 {
	int (* const filter)(struct kset___32 *, struct kobject___32 *);
	const char * (* const name)(struct kset___32 *, struct kobject___32 *);
	int (* const uevent)(struct kset___32 *, struct kobject___32 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___228 {
	void **freelist;
	long unsigned int tid;
	struct page___245 *page;
	struct page___245 *partial;
};

struct memcg_cache_params___229 {
	bool is_root_cache;
	union {
		struct kmem_cache___229 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___229 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___109 {
	void * (*alloc)(struct device___244 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___244 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___244 *, struct vm_area_struct___254 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___244 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___244 *, struct page___245 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___244 *, dma_addr_t);
	int (*dma_supported)(struct device___244 *, u64);
	int (*set_dma_mask)(struct device___244 *, u64);
	int is_phys;
};

struct bus_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___244 *, char *);
	ssize_t (*store)(struct bus_type___244 *, const char *, size_t);
};

struct device_attribute___244;

struct driver_attribute___244;

struct bus_type___244 {
	const char *name;
	const char *dev_name;
	struct device___244 *dev_root;
	struct bus_attribute___244 *bus_attrs;
	struct device_attribute___244 *dev_attrs;
	struct driver_attribute___244 *drv_attrs;
	const struct attribute_group___206 **bus_groups;
	const struct attribute_group___206 **dev_groups;
	const struct attribute_group___206 **drv_groups;
	int (*match)(struct device___244 *, struct device_driver___244 *);
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	int (*probe)(struct device___244 *);
	int (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*online)(struct device___244 *);
	int (*offline)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct device___244 *, struct device_attribute___244 *, char *);
	ssize_t (*store)(struct device___244 *, struct device_attribute___244 *, const char *, size_t);
};

struct driver_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___244 *, char *);
	ssize_t (*store)(struct device_driver___244 *, const char *, size_t);
};

struct device_driver___244 {
	const char *name;
	struct bus_type___244 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___244 *);
	int (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	const struct attribute_group___206 **groups;
	const struct dev_pm_ops___244 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___244 {
	const char *name;
	const struct attribute_group___206 **groups;
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
};

struct class_attribute___244;

struct class___244 {
	const char *name;
	struct module *owner;
	struct class_attribute___244 *class_attrs;
	struct device_attribute___244 *dev_attrs;
	const struct attribute_group___206 **dev_groups;
	struct bin_attribute___208 *dev_bin_attrs;
	struct kobject___32 *dev_kobj;
	int (*dev_uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *);
	void (*class_release)(struct class___244 *);
	void (*dev_release)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
	struct subsys_private *p;
};

struct class_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct class___244 *, struct class_attribute___244 *, char *);
	ssize_t (*store)(struct class___244 *, struct class_attribute___244 *, const char *, size_t);
	const void * (*namespace)(struct class___244 *, const struct class_attribute___244 *);
};

struct device_rh___244 {
	struct dev_pm_info_rh___244 power;
};

struct vm_fault___216 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___245 *page;
};

struct ctl_node___52 {
	struct rb_node node;
	struct ctl_table_header___52 *header;
};

struct ctl_table_root___52 {
	struct ctl_table_set___52 default_set;
	struct ctl_table_set___52 * (*lookup)(struct ctl_table_root___52 *, struct nsproxy___127 *);
	int (*permissions)(struct ctl_table_header___52 *, struct ctl_table *);
};

struct nsproxy___127 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___51 *net_ns;
};

struct signal_struct___247 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___247 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___247 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___248 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___142;

struct css_set___142 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___142 *subsys[11];
	struct callback_head callback_head;
};

struct flow_keys {
	__be32 src;
	__be32 dst;
	union {
		__be32 ports;
		__be16 port16[2];
	};
	u16 thoff;
	u16 n_proto;
	u8 ip_proto;
};

struct nf_bridge_info___37 {
	atomic_t use;
	unsigned int mask;
	struct net_device___39 *physindev;
	struct net_device___39 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___37(struct sk_buff___41 **);

struct net_device_ops___37;

struct ethtool_ops___37;

struct header_ops___37;

struct inet6_dev___15;

struct netdev_rx_queue___37;

struct netdev_queue___37;

struct rtnl_link_ops___29;

struct dcbnl_rtnl_ops___37;

struct net_device___39 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___37 *netdev_ops;
	const struct ethtool_ops___37 *ethtool_ops;
	const struct header_ops___37 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___32 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___15 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___37 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___37 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___37 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___37 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___37 = 0,
		NETREG_REGISTERED___37 = 1,
		NETREG_UNREGISTERING___37 = 2,
		NETREG_UNREGISTERED___37 = 3,
		NETREG_RELEASED___37 = 4,
		NETREG_DUMMY___37 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___37 = 0,
		RTNL_LINK_INITIALIZING___37 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___39 *);
	struct netpoll_info *npinfo;
	struct net___51 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___244 dev;
	const struct attribute_group___206 *sysfs_groups[4];
	const struct rtnl_link_ops___29 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___37 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___41 {
	struct sk_buff___41 *next;
	struct sk_buff___41 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___31 *sk;
	struct net_device___39 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___41 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___37 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct file_lock___246;

struct seq_file___171;

struct file_operations___246 {
	struct module *owner;
	loff_t (*llseek)(struct file___246 *, loff_t, int);
	ssize_t (*read)(struct file___246 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___246 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___37 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___37 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___246 *, void *, filldir_t);
	unsigned int (*poll)(struct file___246 *, struct poll_table_struct___136 *);
	long int (*unlocked_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___246 *, struct vm_area_struct___254 *);
	int (*open)(struct inode___246 *, struct file___246 *);
	int (*flush)(struct file___246 *, fl_owner_t);
	int (*release)(struct inode___246 *, struct file___246 *);
	int (*fsync)(struct file___246 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___37 *, int);
	int (*fasync)(int, struct file___246 *, int);
	int (*lock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*sendpage)(struct file___246 *, struct page___245 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___246 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___246 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___246 *, long int, struct file_lock___246 **, void **);
		struct {
			int (*setlease)(struct file___246 *, long int, struct file_lock___246 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___246 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___171 *, struct file___246 *);
};

struct dev_pm_qos_request___49 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___244 *dev;
};

struct dentry_operations___246;

struct super_block___246;

struct dentry___246 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___246 *d_parent;
	struct qstr d_name;
	struct inode___246 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___246 *d_op;
	struct super_block___246 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___246;

struct dquot___246;

struct block_device___246;

struct inode___246 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___246 *i_op;
	struct super_block___246 *i_sb;
	struct address_space___246 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___248 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___246 *i_fop;
	struct file_lock___246 *i_flock;
	struct address_space___246 i_data;
	struct dquot___246 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___246 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___246 {
	int (*d_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_hash)(const struct dentry___246 *, struct qstr *);
	int (*d_compare)(const struct dentry___246 *, const struct dentry___246 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___246 *);
	void (*d_release)(struct dentry___246 *);
	void (*d_prune)(struct dentry___246 *);
	void (*d_iput)(struct dentry___246 *, struct inode___246 *);
	char * (*d_dname)(struct dentry___246 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___246 *);
	int (*d_manage)(struct dentry___246 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___246;

struct mem_dqinfo___246 {
	struct quota_format_type___246 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___246;

struct quota_info___246 {
	unsigned int flags;
	struct mutex___248 dqio_mutex;
	struct mutex___248 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___246 *files[2];
	struct mem_dqinfo___246 info[2];
	const struct quota_format_ops___246 *ops[2];
};

struct file_system_type___246;

struct super_operations___246;

struct dquot_operations___246;

struct quotactl_ops___246;

struct xattr_handler___143;

struct super_block___246 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___246 *s_type;
	const struct super_operations___246 *s_op;
	const struct dquot_operations___246 *dq_op;
	const struct quotactl_ops___246 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___246 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___143 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___246 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___246 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___248 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___246 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___246 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___246 *bd_inode;
	struct super_block___246 *bd_super;
	struct mutex___248 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___246 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___248 bd_fsfreeze_mutex;
};

struct cgroup___142;

struct cgroup_subsys_state___142 {
	struct cgroup___142 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___246 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___246 *ia_file;
};

struct dquot___246 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___248 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___246 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___246 {
	int qf_fmt_id;
	const struct quota_format_ops___246 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___246 *qf_next;
};

struct quota_format_ops___246 {
	int (*check_quota_file)(struct super_block___246 *, int);
	int (*read_file_info)(struct super_block___246 *, int);
	int (*write_file_info)(struct super_block___246 *, int);
	int (*free_file_info)(struct super_block___246 *, int);
	int (*read_dqblk)(struct dquot___246 *);
	int (*commit_dqblk)(struct dquot___246 *);
	int (*release_dqblk)(struct dquot___246 *);
};

struct dquot_operations___246 {
	int (*write_dquot)(struct dquot___246 *);
	struct dquot___246 * (*alloc_dquot)(struct super_block___246 *, int);
	void (*destroy_dquot)(struct dquot___246 *);
	int (*acquire_dquot)(struct dquot___246 *);
	int (*release_dquot)(struct dquot___246 *);
	int (*mark_dirty)(struct dquot___246 *);
	int (*write_info)(struct super_block___246 *, int);
	qsize_t * (*get_reserved_space)(struct inode___246 *);
};

struct quotactl_ops___246 {
	int (*quota_on)(struct super_block___246 *, int, int, struct path___246 *);
	int (*quota_on_meta)(struct super_block___246 *, int, int);
	int (*quota_off)(struct super_block___246 *, int);
	int (*quota_sync)(struct super_block___246 *, int);
	int (*get_info)(struct super_block___246 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___246 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___246 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___246 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___246 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___246 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___246 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___246 *, unsigned int);
};

struct address_space_operations___246 {
	int (*writepage)(struct page___245 *, struct writeback_control *);
	int (*readpage)(struct file___246 *, struct page___245 *);
	int (*writepages)(struct address_space___246 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___245 *);
	int (*readpages)(struct file___246 *, struct address_space___246 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___246 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___245 **, void **);
	int (*write_end)(struct file___246 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___245 *, void *);
	sector_t (*bmap)(struct address_space___246 *, sector_t);
	void (*invalidatepage)(struct page___245 *, long unsigned int);
	int (*releasepage)(struct page___245 *, gfp_t);
	void (*freepage)(struct page___245 *);
	ssize_t (*direct_IO)(int, struct kiocb___37 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___246 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___246 *, struct page___245 *, struct page___245 *, enum migrate_mode);
	int (*launder_page)(struct page___245 *);
	int (*is_partially_uptodate)(struct page___245 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___245 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___246 *, struct page___245 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___246 *, sector_t *);
	void (*swap_deactivate)(struct file___246 *);
	void (*invalidatepage_range)(struct page___245 *, unsigned int, unsigned int);
};

struct inode_operations___246 {
	struct dentry___246 * (*lookup)(struct inode___246 *, struct dentry___246 *, unsigned int);
	void * (*follow_link)(struct dentry___246 *, struct nameidata *);
	int (*permission)(struct inode___246 *, int);
	struct posix_acl * (*get_acl)(struct inode___246 *, int);
	int (*readlink)(struct dentry___246 *, char *, int);
	void (*put_link)(struct dentry___246 *, struct nameidata *, void *);
	int (*create)(struct inode___246 *, struct dentry___246 *, umode_t, bool);
	int (*link)(struct dentry___246 *, struct inode___246 *, struct dentry___246 *);
	int (*unlink)(struct inode___246 *, struct dentry___246 *);
	int (*symlink)(struct inode___246 *, struct dentry___246 *, const char *);
	int (*mkdir)(struct inode___246 *, struct dentry___246 *, umode_t);
	int (*rmdir)(struct inode___246 *, struct dentry___246 *);
	int (*mknod)(struct inode___246 *, struct dentry___246 *, umode_t, dev_t);
	int (*rename)(struct inode___246 *, struct dentry___246 *, struct inode___246 *, struct dentry___246 *);
	int (*setattr)(struct dentry___246 *, struct iattr___246 *);
	int (*getattr)(struct vfsmount *, struct dentry___246 *, struct kstat *);
	int (*setxattr)(struct dentry___246 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___246 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___246 *, char *, size_t);
	int (*removexattr)(struct dentry___246 *, const char *);
	int (*fiemap)(struct inode___246 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___246 *, struct timespec *, int);
	int (*atomic_open)(struct inode___246 *, struct dentry___246 *, struct file___246 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___246;

struct lock_manager_operations___246;

struct file_lock___246 {
	struct file_lock___246 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___246 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___246 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___246 *fl_ops;
	const struct lock_manager_operations___246 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___246 {
	void (*fl_copy_lock)(struct file_lock___246 *, struct file_lock___246 *);
	void (*fl_release_private)(struct file_lock___246 *);
};

struct lock_manager_operations___246 {
	int (*lm_compare_owner)(struct file_lock___246 *, struct file_lock___246 *);
	long unsigned int (*lm_owner_key)(struct file_lock___246 *);
	void (*lm_notify)(struct file_lock___246 *);
	int (*lm_grant)(struct file_lock___246 *, struct file_lock___246 *, int);
	void (*lm_break)(struct file_lock___246 *);
	int (*lm_change)(struct file_lock___246 **, int);
};

struct file_system_type___246 {
	const char *name;
	int fs_flags;
	struct dentry___246 * (*mount)(struct file_system_type___246 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___246 *);
	struct module *owner;
	struct file_system_type___246 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___246 {
	struct inode___246 * (*alloc_inode)(struct super_block___246 *);
	void (*destroy_inode)(struct inode___246 *);
	void (*dirty_inode)(struct inode___246 *, int);
	int (*write_inode)(struct inode___246 *, struct writeback_control *);
	int (*drop_inode)(struct inode___246 *);
	void (*evict_inode)(struct inode___246 *);
	void (*put_super)(struct super_block___246 *);
	int (*sync_fs)(struct super_block___246 *, int);
	int (*freeze_fs)(struct super_block___246 *);
	int (*unfreeze_fs)(struct super_block___246 *);
	int (*statfs)(struct dentry___246 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___246 *, int *, char *);
	void (*umount_begin)(struct super_block___246 *);
	int (*show_options)(struct seq_file___171 *, struct dentry___246 *);
	int (*show_devname)(struct seq_file___171 *, struct dentry___246 *);
	int (*show_path)(struct seq_file___171 *, struct dentry___246 *);
	int (*show_stats)(struct seq_file___171 *, struct dentry___246 *);
	ssize_t (*quota_read)(struct super_block___246 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___246 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___246 *);
	int (*bdev_try_to_free_page)(struct super_block___246 *, struct page___245 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___246 *);
	void (*free_cached_objects)(struct super_block___246 *, int);
};

struct xattr_handler___143 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___246 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___246 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___246 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___171;

struct seq_file___171 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___248 lock;
	const struct seq_operations___171 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___37 {
	int (*get_settings)(struct net_device___39 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___39 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___39 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___39 *);
	void (*get_regs)(struct net_device___39 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___39 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___39 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___39 *);
	void (*set_msglevel)(struct net_device___39 *, u32);
	int (*nway_reset)(struct net_device___39 *);
	u32 (*get_link)(struct net_device___39 *);
	int (*get_eeprom_len)(struct net_device___39 *);
	int (*get_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___39 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___39 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___39 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___39 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___39 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___39 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___39 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___39 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___39 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___39 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___39 *);
	void (*complete)(struct net_device___39 *);
	u32 (*get_priv_flags)(struct net_device___39 *);
	int (*set_priv_flags)(struct net_device___39 *, u32);
	int (*get_sset_count)(struct net_device___39 *, int);
	int (*get_rxnfc)(struct net_device___39 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___39 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___39 *, struct ethtool_flash *);
	int (*reset)(struct net_device___39 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___39 *);
	int (*get_rxfh_indir)(struct net_device___39 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___39 *, const u32 *);
	void (*get_channels)(struct net_device___39 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___39 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___39 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___39 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___39 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___39 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___39 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___39 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___39 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___39 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___39 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___39 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___10;

struct dst_entry___29 {
	struct callback_head callback_head;
	struct dst_entry___29 *child;
	struct net_device___39 *dev;
	struct dst_ops___50 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___29 *path;
	struct dst_entry___29 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___41 *);
	union {
		int (*output)(struct sock___31 *, struct sk_buff___41 *);
		struct {
			int (*output)(struct sk_buff___41 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___29 *next;
		struct rtable___10 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___29;

struct neigh_parms___29;

struct neigh_ops___29;

struct neighbour___29 {
	struct neighbour___29 *next;
	struct neigh_table___29 *tbl;
	struct neigh_parms___29 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___38 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___29 *, struct sk_buff___41 *);
	const struct neigh_ops___29 *ops;
	struct callback_head rcu;
	struct net_device___39 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___50 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___41 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___41 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___51 *, struct dst_entry___29 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___41 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___41 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___170 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___170 *);
	void (*irq_shutdown)(struct irq_data___170 *);
	void (*irq_enable)(struct irq_data___170 *);
	void (*irq_disable)(struct irq_data___170 *);
	void (*irq_ack)(struct irq_data___170 *);
	void (*irq_mask)(struct irq_data___170 *);
	void (*irq_mask_ack)(struct irq_data___170 *);
	void (*irq_unmask)(struct irq_data___170 *);
	void (*irq_eoi)(struct irq_data___170 *);
	int (*irq_set_affinity)(struct irq_data___170 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___170 *);
	int (*irq_set_type)(struct irq_data___170 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___170 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___170 *);
	void (*irq_bus_sync_unlock)(struct irq_data___170 *);
	void (*irq_cpu_online)(struct irq_data___170 *);
	void (*irq_cpu_offline)(struct irq_data___170 *);
	void (*irq_suspend)(struct irq_data___170 *);
	void (*irq_resume)(struct irq_data___170 *);
	void (*irq_pm_shutdown)(struct irq_data___170 *);
	void (*irq_print_chip)(struct irq_data___170 *, struct seq_file___171 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___170 *, void *);
	long unsigned int flags;
};

struct seq_operations___171 {
	void * (*start)(struct seq_file___171 *, loff_t *);
	void (*stop)(struct seq_file___171 *, void *);
	void * (*next)(struct seq_file___171 *, void *, loff_t *);
	int (*show)(struct seq_file___171 *, void *);
};

struct dcbnl_rtnl_ops___37 {
	int (*ieee_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___39 *);
	u8 (*setstate)(struct net_device___39 *, u8);
	void (*getpermhwaddr)(struct net_device___39 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___39 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___39 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___39 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___39 *, int, u8 *);
	void (*setpfccfg)(struct net_device___39 *, int, u8);
	void (*getpfccfg)(struct net_device___39 *, int, u8 *);
	u8 (*setall)(struct net_device___39 *);
	u8 (*getcap)(struct net_device___39 *, int, u8 *);
	int (*getnumtcs)(struct net_device___39 *, int, u8 *);
	int (*setnumtcs)(struct net_device___39 *, int, u8);
	u8 (*getpfcstate)(struct net_device___39 *);
	void (*setpfcstate)(struct net_device___39 *, u8);
	void (*getbcncfg)(struct net_device___39 *, int, u32 *);
	void (*setbcncfg)(struct net_device___39 *, int, u32);
	void (*getbcnrp)(struct net_device___39 *, int, u8 *);
	void (*setbcnrp)(struct net_device___39 *, int, u8);
	u8 (*setapp)(struct net_device___39 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___39 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___39 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___39 *, int, u8);
	u8 (*getdcbx)(struct net_device___39 *);
	u8 (*setdcbx)(struct net_device___39 *, u8);
	int (*peer_getappinfo)(struct net_device___39 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___39 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___39 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___39 *, struct cee_pfc *);
};

struct cgroupfs_root___142;

struct cgroup___142 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___142 *parent;
	struct dentry___246 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___142 *subsys[11];
	struct cgroupfs_root___142 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___248 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___142 {
	struct super_block___246 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___142 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___81 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___246 *, struct file___246 *);
	ssize_t (*read)(struct cgroup___142 *, struct cftype___81 *, struct file___246 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___142 *, struct cftype___81 *);
	s64 (*read_s64)(struct cgroup___142 *, struct cftype___81 *);
	int (*read_map)(struct cgroup___142 *, struct cftype___81 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___142 *, struct cftype___81 *, struct seq_file___171 *);
	ssize_t (*write)(struct cgroup___142 *, struct cftype___81 *, struct file___246 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___142 *, struct cftype___81 *, u64);
	int (*write_s64)(struct cgroup___142 *, struct cftype___81 *, s64);
	int (*write_string)(struct cgroup___142 *, struct cftype___81 *, const char *);
	int (*trigger)(struct cgroup___142 *, unsigned int);
	int (*release)(struct inode___246 *, struct file___246 *);
	int (*register_event)(struct cgroup___142 *, struct cftype___81 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___142 *, struct cftype___81 *, struct eventfd_ctx *);
};

struct cftype_set___77 {
	struct list_head node;
	struct cftype___81 *cfts;
};

struct task_and_cgroup___77 {
	struct task_struct___247 *task;
	struct cgroup___142 *cgrp;
	struct css_set___142 *cg;
};

struct cgroup_taskset___77 {
	struct task_and_cgroup___77 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___142 *cur_cgrp;
};

struct cgroup_subsys___77 {
	struct cgroup_subsys_state___142 * (*css_alloc)(struct cgroup___142 *);
	int (*css_online)(struct cgroup___142 *);
	void (*css_offline)(struct cgroup___142 *);
	void (*css_free)(struct cgroup___142 *);
	int (*can_attach)(struct cgroup___142 *, struct cgroup_taskset___77 *);
	void (*cancel_attach)(struct cgroup___142 *, struct cgroup_taskset___77 *);
	void (*attach)(struct cgroup___142 *, struct cgroup_taskset___77 *);
	void (*fork)(struct task_struct___247 *);
	void (*exit)(struct cgroup___142 *, struct cgroup___142 *, struct task_struct___247 *);
	void (*bind)(struct cgroup___142 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___142 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___81 *base_cftypes;
	struct cftype_set___77 base_cftset;
	struct module *module;
};

struct request_sock_ops___20;

struct request_sock___21 {
	struct sock_common___29 __req_common;
	struct request_sock___21 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___20 *rsk_ops;
	struct sock___31 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___39 {
	struct sk_buff___41 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___41 *, struct netlink_callback___39 *);
	int (*done)(struct netlink_callback___39 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___37 {
	int (*create)(struct sk_buff___41 *, struct net_device___39 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___41 *, unsigned char *);
	int (*rebuild)(struct sk_buff___41 *);
	int (*cache)(const struct neighbour___29 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___39 *, const unsigned char *);
};

struct napi_struct___37 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___37 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___39 *dev;
	struct sk_buff___41 *gro_list;
	struct sk_buff___41 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___37 {
	struct net_device___39 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___32 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___37 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___32 kobj;
	struct net_device___39 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___37 {
	int (*ndo_init)(struct net_device___39 *);
	void (*ndo_uninit)(struct net_device___39 *);
	int (*ndo_open)(struct net_device___39 *);
	int (*ndo_stop)(struct net_device___39 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___41 *, struct net_device___39 *);
	u16 (*ndo_select_queue)(struct net_device___39 *, struct sk_buff___41 *);
	void (*ndo_change_rx_flags)(struct net_device___39 *, int);
	void (*ndo_set_rx_mode)(struct net_device___39 *);
	int (*ndo_set_mac_address)(struct net_device___39 *, void *);
	int (*ndo_validate_addr)(struct net_device___39 *);
	int (*ndo_do_ioctl)(struct net_device___39 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___39 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___39 *, int);
	int (*ndo_neigh_setup)(struct net_device___39 *, struct neigh_parms___29 *);
	void (*ndo_tx_timeout)(struct net_device___39 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___39 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___39 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___39 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___39 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___39 *);
	int (*ndo_netpoll_setup)(struct net_device___39 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___39 *);
	int (*ndo_busy_poll)(struct napi_struct___37 *);
	int (*ndo_set_vf_mac)(struct net_device___39 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___39 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___39 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___39 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___39 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___39 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___39 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___39 *, int, struct sk_buff___41 *);
	int (*ndo_setup_tc)(struct net_device___39 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___39 *);
	int (*ndo_fcoe_disable)(struct net_device___39 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___39 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___39 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___39 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___39 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___39 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___39 *, const struct sk_buff___41 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___39 *, struct net_device___39 *);
	int (*ndo_del_slave)(struct net_device___39 *, struct net_device___39 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___29 *);
	void (*ndo_neigh_destroy)(struct neighbour___29 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___41 *, struct netlink_callback___39 *, struct net_device___39 *, int);
	int (*ndo_bridge_setlink)(struct net_device___39 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___41 *, u32, u32, struct net_device___39 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___39 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___39 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___39 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___39 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___39 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___39 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___41 *, struct net_device___39 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___39 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___39 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___39 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___29 {
	struct net___51 *net;
	struct net_device___39 *dev;
	struct neigh_parms___29 *next;
	int (*neigh_setup)(struct neighbour___29 *);
	void (*neigh_cleanup)(struct neighbour___29 *);
	struct neigh_table___29 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___15;

struct ifacaddr6___15;

struct inet6_dev___15 {
	struct net_device___39 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___15 *mc_list;
	struct ifmcaddr6___15 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___15 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___29 *nd_parms;
	struct inet6_dev___15 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___29 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___39 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___51 *, struct net_device___39 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___39 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___39 *, struct list_head *);
	size_t (*get_size)(const struct net_device___39 *);
	int (*fill_info)(struct sk_buff___41 *, const struct net_device___39 *);
	size_t (*get_xstats_size)(const struct net_device___39 *);
	int (*fill_xstats)(struct sk_buff___41 *, const struct net_device___39 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___51 * (*get_link_net)(const struct net_device___39 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___39 *, struct net_device___39 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___39 *, const struct net_device___39 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___41 *, const struct net_device___39 *, const struct net_device___39 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___30 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___41 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___29;

struct neigh_hash_table___29;

struct neigh_table___29 {
	struct neigh_table___29 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___39 *, __u32 *);
	int (*constructor)(struct neighbour___29 *);
	int (*pconstructor)(struct pneigh_entry___29 *);
	void (*pdestructor)(struct pneigh_entry___29 *);
	void (*proxy_redo)(struct sk_buff___41 *);
	char *id;
	struct neigh_parms___29 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___38 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___29 *nht;
	struct pneigh_entry___29 **phash_buckets;
};

struct neigh_ops___29 {
	int family;
	void (*solicit)(struct neighbour___29 *, struct sk_buff___41 *);
	void (*error_report)(struct neighbour___29 *, struct sk_buff___41 *);
	int (*output)(struct neighbour___29 *, struct sk_buff___41 *);
	int (*connected_output)(struct neighbour___29 *, struct sk_buff___41 *);
};

struct pneigh_entry___29 {
	struct pneigh_entry___29 *next;
	struct net___51 *net;
	struct net_device___39 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___29 {
	struct neighbour___29 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___10 {
	struct dst_entry___29 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___18;

struct proto___29 {
	void (*close)(struct sock___31 *, long int);
	int (*connect)(struct sock___31 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___31 *, int);
	struct sock___31 * (*accept)(struct sock___31 *, int, int *);
	int (*ioctl)(struct sock___31 *, int, long unsigned int);
	int (*init)(struct sock___31 *);
	void (*destroy)(struct sock___31 *);
	void (*shutdown)(struct sock___31 *, int);
	int (*setsockopt)(struct sock___31 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___31 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___31 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___31 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___31 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___37 *, struct sock___31 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___37 *, struct sock___31 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___31 *, struct page___245 *, int, size_t, int);
	int (*bind)(struct sock___31 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___31 *, struct sk_buff___41 *);
	void (*release_cb)(struct sock___31 *);
	void (*mtu_reduced)(struct sock___31 *);
	void (*hash)(struct sock___31 *);
	void (*unhash)(struct sock___31 *);
	void (*rehash)(struct sock___31 *);
	int (*get_port)(struct sock___31 *, short unsigned int);
	void (*clear_sk)(struct sock___31 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___31 *);
	void (*enter_memory_pressure)(struct sock___31 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___229 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___20 *rsk_prot;
	struct timewait_sock_ops___18 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___77 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___29 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___29 {
	void (*enter_memory_pressure)(struct sock___31 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___20 {
	int family;
	int obj_size;
	struct kmem_cache___229 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___31 *, struct request_sock___21 *);
	void (*send_ack)(struct sock___31 *, struct sk_buff___41 *, struct request_sock___21 *);
	void (*send_reset)(struct sock___31 *, struct sk_buff___41 *);
	void (*destructor)(struct request_sock___21 *);
	void (*syn_ack_timeout)(struct sock___31 *, struct request_sock___21 *);
};

struct timewait_sock_ops___18 {
	struct kmem_cache___229 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___31 *, struct sock___31 *, void *);
	void (*twsk_destructor)(struct sock___31 *);
};

struct ifmcaddr6___15 {
	struct in6_addr mca_addr;
	struct inet6_dev___15 *idev;
	struct ifmcaddr6___15 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___15 {
	struct in6_addr aca_addr;
	struct inet6_dev___15 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___15 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct pppoe_tag {
	__be16 tag_type;
	__be16 tag_len;
	char tag_data[0];
};

struct pppoe_hdr {
	__u8 type: 4;
	__u8 ver: 4;
	__u8 code;
	__be16 sid;
	__be16 length;
	struct pppoe_tag tag[0];
};

struct gre_hdr {
	__be16 flags;
	__be16 proto;
};

struct page___246;

typedef struct page___246 *pgtable_t___246;

struct address_space___247;

struct kmem_cache___230;

struct page___246 {
	long unsigned int flags;
	struct address_space___247 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___246 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___246 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___230 *slab_cache;
		struct page___246 *first_page;
	};
	long: 64;
};

struct task_struct___248;

struct pv_cpu_ops___248 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___248 *);
	void (*end_context_switch)(struct task_struct___248 *);
};

struct mutex___249 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___248 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___241 {
	struct page___246 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___255;

struct nsproxy___128;

struct signal_struct___248;

struct css_set___143;

struct task_struct___248 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___248 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___255 *mm;
	struct mm_struct___255 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___248 *real_parent;
	struct task_struct___248 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___248 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___248 = 0,
		VTIME_USER___248 = 1,
		VTIME_SYS___248 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___128 *nsproxy;
	struct signal_struct___248 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___143 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___249 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___241 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___255 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___255 *, struct mm_struct___255 *);
	void (*dup_mmap)(struct mm_struct___255 *, struct mm_struct___255 *);
	void (*exit_mmap)(struct mm_struct___255 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___255 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___255 *);
	void (*pgd_free)(struct mm_struct___255 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___255 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___255 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___255 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___255 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___255 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___255 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___255 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___255 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___255 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___255 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___255 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___249 lock;
	void *vdso;
} mm_context_t___249;

struct xol_area___246;

struct uprobes_state___246 {
	struct xol_area___246 *xol_area;
};

struct vm_area_struct___255;

struct file___247;

struct core_state___248;

struct mm_struct___255 {
	struct vm_area_struct___255 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___255 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___255 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___249 context;
	long unsigned int flags;
	struct core_state___248 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___248 *owner;
	struct file___247 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___246 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___33;

struct kobj_type___33;

struct kobject___33 {
	const char *name;
	struct list_head entry;
	struct kobject___33 *parent;
	struct kset___33 *kset;
	struct kobj_type___33 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___150;

struct module_kobject___148 {
	struct kobject___33 kobj;
	struct module___150 *mod;
	struct kobject___33 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___148;

struct module___150 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___148 mkobj;
	struct module_attribute___148 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___33 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___248 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___248;

struct lruvec___248 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___248 *zone;
};

struct pglist_data___248;

struct zone___248 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___248 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___248 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___248 {
	struct zone___248 *zone;
	int zone_idx;
};

struct zonelist___248 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___248 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___248 {
	struct zone___248 node_zones[4];
	struct zonelist___248 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___248 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___171;

struct x86_io_apic_ops___171 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___171 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___171;

struct irq_data___171 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___171 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___245;

struct dev_pm_ops___245 {
	int (*prepare)(struct device___245 *);
	void (*complete)(struct device___245 *);
	int (*suspend)(struct device___245 *);
	int (*resume)(struct device___245 *);
	int (*freeze)(struct device___245 *);
	int (*thaw)(struct device___245 *);
	int (*poweroff)(struct device___245 *);
	int (*restore)(struct device___245 *);
	int (*suspend_late)(struct device___245 *);
	int (*resume_early)(struct device___245 *);
	int (*freeze_late)(struct device___245 *);
	int (*thaw_early)(struct device___245 *);
	int (*poweroff_late)(struct device___245 *);
	int (*restore_early)(struct device___245 *);
	int (*suspend_noirq)(struct device___245 *);
	int (*resume_noirq)(struct device___245 *);
	int (*freeze_noirq)(struct device___245 *);
	int (*thaw_noirq)(struct device___245 *);
	int (*poweroff_noirq)(struct device___245 *);
	int (*restore_noirq)(struct device___245 *);
	int (*runtime_suspend)(struct device___245 *);
	int (*runtime_resume)(struct device___245 *);
	int (*runtime_idle)(struct device___245 *);
};

struct dev_pm_qos___49;

struct dev_pm_info___49 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___49 *qos;
};

struct dma_map_ops___110;

struct dev_archdata___110 {
	struct dma_map_ops___110 *dma_ops;
	void *iommu;
};

struct device_type___245;

struct bus_type___245;

struct device_driver___245;

struct dev_pm_domain___245;

struct class___245;

struct attribute_group___207;

struct device_rh___245;

struct device___245 {
	struct device___245 *parent;
	struct device_private *p;
	struct kobject___33 kobj;
	const char *init_name;
	const struct device_type___245 *type;
	struct mutex___249 mutex;
	struct bus_type___245 *bus;
	struct device_driver___245 *driver;
	void *platform_data;
	struct dev_pm_info___49 power;
	struct dev_pm_domain___245 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___110 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___42 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___245 *class;
	const struct attribute_group___207 **groups;
	void (*release)(struct device___245 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___245 *device_rh;
};

struct dev_pm_qos_request___50;

struct dev_pm_qos___49 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___50 *latency_req;
	struct dev_pm_qos_request___50 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___50 *latency_tolerance_req;
};

struct dev_pm_info_rh___245 {
	void (*set_latency_tolerance)(struct device___245 *, s32);
};

struct dev_pm_domain___245 {
	struct dev_pm_ops___245 ops;
};

struct smp_ops___248 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___248 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___246 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___246 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___229;

struct memcg_cache_params___230;

struct kmem_cache___230 {
	struct kmem_cache_cpu___229 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___33 kobj;
	struct memcg_cache_params___230 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___247;

struct address_space_operations___247;

struct address_space___247 {
	struct inode___247 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___249 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___247 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___247;

struct path___247 {
	struct vfsmount *mnt;
	struct dentry___247 *dentry;
};

struct file_operations___247;

struct file___247 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___247 f_path;
	struct inode___247 *f_inode;
	const struct file_operations___247 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___247 *f_mapping;
	struct mutex___249 f_pos_lock;
};

struct vm_operations_struct___221;

struct vm_area_struct___255 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___255 *vm_next;
	struct vm_area_struct___255 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___255 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___221 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___247 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___217;

struct vm_operations_struct___221 {
	void (*open)(struct vm_area_struct___255 *);
	void (*close)(struct vm_area_struct___255 *);
	int (*fault)(struct vm_area_struct___255 *, struct vm_fault___217 *);
	int (*page_mkwrite)(struct vm_area_struct___255 *, struct vm_fault___217 *);
	int (*access)(struct vm_area_struct___255 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___255 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___255 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___255 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___255 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___248 {
	struct task_struct___248 *task;
	struct core_thread___248 *next;
};

struct core_state___248 {
	atomic_t nr_threads;
	struct core_thread___248 dumper;
	struct completion startup;
};

struct vm_fault___217 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___246 *page;
};

struct ctl_table_header___53;

struct ctl_node___53 {
	struct rb_node node;
	struct ctl_table_header___53 *header;
};

struct ctl_table_root___53;

struct ctl_table_set___53;

struct ctl_dir___53;

struct ctl_table_header___53 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___53 *root;
	struct ctl_table_set___53 *set;
	struct ctl_dir___53 *parent;
	struct ctl_node___53 *node;
};

struct ctl_dir___53 {
	struct ctl_table_header___53 header;
	struct rb_root root;
};

struct ctl_table_set___53 {
	int (*is_seen)(struct ctl_table_set___53 *);
	struct ctl_dir___53 dir;
};

struct ctl_table_root___53 {
	struct ctl_table_set___53 default_set;
	struct ctl_table_set___53 * (*lookup)(struct ctl_table_root___53 *, struct nsproxy___128 *);
	int (*permissions)(struct ctl_table_header___53 *, struct ctl_table *);
};

struct net___52;

struct nsproxy___128 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___52 *net_ns;
};

struct sock___32;

struct kobj_ns_type_operations___30 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___32 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___30;

struct sock_common___30 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___30 *skc_prot;
	struct net___52 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___42;

struct sk_buff_head___39 {
	struct sk_buff___42 *next;
	struct sk_buff___42 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___31;

struct socket_wq___30;

struct dst_entry___30;

struct socket___31;

struct cg_proto___30;

struct sock___32 {
	struct sock_common___30 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___39 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___42 *head;
		struct sk_buff___42 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___31 *sk_filter;
	struct socket_wq___30 *sk_wq;
	struct sk_buff_head___39 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___30 *sk_rx_dst;
	struct dst_entry___30 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___39 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___39 sk_error_queue;
	struct proto___30 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___31 *sk_socket;
	void *sk_user_data;
	struct page_frag___241 sk_frag;
	struct sk_buff___42 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___30 *sk_cgrp;
	void (*sk_state_change)(struct sock___32 *);
	void (*sk_data_ready)(struct sock___32 *, int);
	void (*sk_write_space)(struct sock___32 *);
	void (*sk_error_report)(struct sock___32 *);
	int (*sk_backlog_rcv)(struct sock___32 *, struct sk_buff___42 *);
	void (*sk_destruct)(struct sock___32 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___209;

struct attribute_group___207 {
	const char *name;
	umode_t (*is_visible)(struct kobject___33 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___209 **bin_attrs;
};

struct bin_attribute___209 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___247 *, struct kobject___33 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___247 *, struct kobject___33 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	int (*mmap)(struct file___247 *, struct kobject___33 *, struct bin_attribute___209 *, struct vm_area_struct___255 *);
};

struct sysfs_ops___33 {
	ssize_t (*show)(struct kobject___33 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___33 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___33 *, const struct attribute *);
};

struct kset_uevent_ops___33;

struct kset___33 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___33 kobj;
	const struct kset_uevent_ops___33 *uevent_ops;
};

struct kobj_type___33 {
	void (*release)(struct kobject___33 *);
	const struct sysfs_ops___33 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___30 * (*child_ns_type)(struct kobject___33 *);
	const void * (*namespace)(struct kobject___33 *);
};

struct kset_uevent_ops___33 {
	int (* const filter)(struct kset___33 *, struct kobject___33 *);
	const char * (* const name)(struct kset___33 *, struct kobject___33 *);
	int (* const uevent)(struct kset___33 *, struct kobject___33 *, struct kobj_uevent_env *);
};

struct module_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___148 *, struct module_kobject___148 *, char *);
	ssize_t (*store)(struct module_attribute___148 *, struct module_kobject___148 *, const char *, size_t);
	void (*setup)(struct module___150 *, const char *);
	int (*test)(struct module___150 *);
	void (*free)(struct module___150 *);
};

struct kiocb___38;

struct poll_table_struct___137;

struct file_lock___247;

struct seq_file___172;

struct file_operations___247 {
	struct module___150 *owner;
	loff_t (*llseek)(struct file___247 *, loff_t, int);
	ssize_t (*read)(struct file___247 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___247 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___38 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___38 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___247 *, void *, filldir_t);
	unsigned int (*poll)(struct file___247 *, struct poll_table_struct___137 *);
	long int (*unlocked_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___247 *, struct vm_area_struct___255 *);
	int (*open)(struct inode___247 *, struct file___247 *);
	int (*flush)(struct file___247 *, fl_owner_t);
	int (*release)(struct inode___247 *, struct file___247 *);
	int (*fsync)(struct file___247 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___38 *, int);
	int (*fasync)(int, struct file___247 *, int);
	int (*lock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*sendpage)(struct file___247 *, struct page___246 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___247 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___247 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___247 *, long int, struct file_lock___247 **, void **);
		struct {
			int (*setlease)(struct file___247 *, long int, struct file_lock___247 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___247 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___172 *, struct file___247 *);
};

struct dma_map_ops___110 {
	void * (*alloc)(struct device___245 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___245 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___245 *, struct vm_area_struct___255 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___245 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___245 *, struct page___246 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___245 *, dma_addr_t);
	int (*dma_supported)(struct device___245 *, u64);
	int (*set_dma_mask)(struct device___245 *, u64);
	int is_phys;
};

struct bus_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___245 *, char *);
	ssize_t (*store)(struct bus_type___245 *, const char *, size_t);
};

struct device_attribute___245;

struct driver_attribute___245;

struct bus_type___245 {
	const char *name;
	const char *dev_name;
	struct device___245 *dev_root;
	struct bus_attribute___245 *bus_attrs;
	struct device_attribute___245 *dev_attrs;
	struct driver_attribute___245 *drv_attrs;
	const struct attribute_group___207 **bus_groups;
	const struct attribute_group___207 **dev_groups;
	const struct attribute_group___207 **drv_groups;
	int (*match)(struct device___245 *, struct device_driver___245 *);
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	int (*probe)(struct device___245 *);
	int (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*online)(struct device___245 *);
	int (*offline)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct device___245 *, struct device_attribute___245 *, char *);
	ssize_t (*store)(struct device___245 *, struct device_attribute___245 *, const char *, size_t);
};

struct driver_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___245 *, char *);
	ssize_t (*store)(struct device_driver___245 *, const char *, size_t);
};

struct device_driver___245 {
	const char *name;
	struct bus_type___245 *bus;
	struct module___150 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___245 *);
	int (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	const struct attribute_group___207 **groups;
	const struct dev_pm_ops___245 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___245 {
	const char *name;
	const struct attribute_group___207 **groups;
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
};

struct class_attribute___245;

struct class___245 {
	const char *name;
	struct module___150 *owner;
	struct class_attribute___245 *class_attrs;
	struct device_attribute___245 *dev_attrs;
	const struct attribute_group___207 **dev_groups;
	struct bin_attribute___209 *dev_bin_attrs;
	struct kobject___33 *dev_kobj;
	int (*dev_uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *);
	void (*class_release)(struct class___245 *);
	void (*dev_release)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	const struct kobj_ns_type_operations___30 *ns_type;
	const void * (*namespace)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
	struct subsys_private *p;
};

struct class_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct class___245 *, struct class_attribute___245 *, char *);
	ssize_t (*store)(struct class___245 *, struct class_attribute___245 *, const char *, size_t);
	const void * (*namespace)(struct class___245 *, const struct class_attribute___245 *);
};

struct device_rh___245 {
	struct dev_pm_info_rh___245 power;
};

struct dev_pm_qos_request___50 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___245 *dev;
};

struct dentry_operations___247;

struct super_block___247;

struct dentry___247 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___247 *d_parent;
	struct qstr d_name;
	struct inode___247 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___247 *d_op;
	struct super_block___247 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___247;

struct dquot___247;

struct block_device___247;

struct inode___247 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___247 *i_op;
	struct super_block___247 *i_sb;
	struct address_space___247 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___249 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___247 *i_fop;
	struct file_lock___247 *i_flock;
	struct address_space___247 i_data;
	struct dquot___247 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___247 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___247 {
	int (*d_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_hash)(const struct dentry___247 *, struct qstr *);
	int (*d_compare)(const struct dentry___247 *, const struct dentry___247 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___247 *);
	void (*d_release)(struct dentry___247 *);
	void (*d_prune)(struct dentry___247 *);
	void (*d_iput)(struct dentry___247 *, struct inode___247 *);
	char * (*d_dname)(struct dentry___247 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___247 *);
	int (*d_manage)(struct dentry___247 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___247;

struct mem_dqinfo___247 {
	struct quota_format_type___247 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___247;

struct quota_info___247 {
	unsigned int flags;
	struct mutex___249 dqio_mutex;
	struct mutex___249 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___247 *files[2];
	struct mem_dqinfo___247 info[2];
	const struct quota_format_ops___247 *ops[2];
};

struct file_system_type___247;

struct super_operations___247;

struct dquot_operations___247;

struct quotactl_ops___247;

struct xattr_handler___144;

struct super_block___247 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___247 *s_type;
	const struct super_operations___247 *s_op;
	const struct dquot_operations___247 *dq_op;
	const struct quotactl_ops___247 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___247 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___144 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___247 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___247 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___249 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___247 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___247 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___247 *bd_inode;
	struct super_block___247 *bd_super;
	struct mutex___249 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___247 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___249 bd_fsfreeze_mutex;
};

struct cgroup___143;

struct cgroup_subsys_state___143 {
	struct cgroup___143 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___38(struct kiocb___38 *, struct io_event *);

struct kiocb___38 {
	atomic_t ki_users;
	struct file___247 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___38 *ki_cancel;
	void (*ki_dtor)(struct kiocb___38 *);
	union {
		void *user;
		struct task_struct___248 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___247 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___247 *ia_file;
};

struct dquot___247 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___249 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___247 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___247 {
	int qf_fmt_id;
	const struct quota_format_ops___247 *qf_ops;
	struct module___150 *qf_owner;
	struct quota_format_type___247 *qf_next;
};

struct quota_format_ops___247 {
	int (*check_quota_file)(struct super_block___247 *, int);
	int (*read_file_info)(struct super_block___247 *, int);
	int (*write_file_info)(struct super_block___247 *, int);
	int (*free_file_info)(struct super_block___247 *, int);
	int (*read_dqblk)(struct dquot___247 *);
	int (*commit_dqblk)(struct dquot___247 *);
	int (*release_dqblk)(struct dquot___247 *);
};

struct dquot_operations___247 {
	int (*write_dquot)(struct dquot___247 *);
	struct dquot___247 * (*alloc_dquot)(struct super_block___247 *, int);
	void (*destroy_dquot)(struct dquot___247 *);
	int (*acquire_dquot)(struct dquot___247 *);
	int (*release_dquot)(struct dquot___247 *);
	int (*mark_dirty)(struct dquot___247 *);
	int (*write_info)(struct super_block___247 *, int);
	qsize_t * (*get_reserved_space)(struct inode___247 *);
};

struct quotactl_ops___247 {
	int (*quota_on)(struct super_block___247 *, int, int, struct path___247 *);
	int (*quota_on_meta)(struct super_block___247 *, int, int);
	int (*quota_off)(struct super_block___247 *, int);
	int (*quota_sync)(struct super_block___247 *, int);
	int (*get_info)(struct super_block___247 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___247 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___247 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___247 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___247 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___247 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___247 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___247 *, unsigned int);
};

struct address_space_operations___247 {
	int (*writepage)(struct page___246 *, struct writeback_control *);
	int (*readpage)(struct file___247 *, struct page___246 *);
	int (*writepages)(struct address_space___247 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___246 *);
	int (*readpages)(struct file___247 *, struct address_space___247 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___247 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___246 **, void **);
	int (*write_end)(struct file___247 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___246 *, void *);
	sector_t (*bmap)(struct address_space___247 *, sector_t);
	void (*invalidatepage)(struct page___246 *, long unsigned int);
	int (*releasepage)(struct page___246 *, gfp_t);
	void (*freepage)(struct page___246 *);
	ssize_t (*direct_IO)(int, struct kiocb___38 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___247 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___247 *, struct page___246 *, struct page___246 *, enum migrate_mode);
	int (*launder_page)(struct page___246 *);
	int (*is_partially_uptodate)(struct page___246 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___246 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___247 *, struct page___246 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___247 *, sector_t *);
	void (*swap_deactivate)(struct file___247 *);
	void (*invalidatepage_range)(struct page___246 *, unsigned int, unsigned int);
};

struct inode_operations___247 {
	struct dentry___247 * (*lookup)(struct inode___247 *, struct dentry___247 *, unsigned int);
	void * (*follow_link)(struct dentry___247 *, struct nameidata *);
	int (*permission)(struct inode___247 *, int);
	struct posix_acl * (*get_acl)(struct inode___247 *, int);
	int (*readlink)(struct dentry___247 *, char *, int);
	void (*put_link)(struct dentry___247 *, struct nameidata *, void *);
	int (*create)(struct inode___247 *, struct dentry___247 *, umode_t, bool);
	int (*link)(struct dentry___247 *, struct inode___247 *, struct dentry___247 *);
	int (*unlink)(struct inode___247 *, struct dentry___247 *);
	int (*symlink)(struct inode___247 *, struct dentry___247 *, const char *);
	int (*mkdir)(struct inode___247 *, struct dentry___247 *, umode_t);
	int (*rmdir)(struct inode___247 *, struct dentry___247 *);
	int (*mknod)(struct inode___247 *, struct dentry___247 *, umode_t, dev_t);
	int (*rename)(struct inode___247 *, struct dentry___247 *, struct inode___247 *, struct dentry___247 *);
	int (*setattr)(struct dentry___247 *, struct iattr___247 *);
	int (*getattr)(struct vfsmount *, struct dentry___247 *, struct kstat *);
	int (*setxattr)(struct dentry___247 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___247 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___247 *, char *, size_t);
	int (*removexattr)(struct dentry___247 *, const char *);
	int (*fiemap)(struct inode___247 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___247 *, struct timespec *, int);
	int (*atomic_open)(struct inode___247 *, struct dentry___247 *, struct file___247 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___247;

struct file_lock_operations___247;

struct lock_manager_operations___247;

struct file_lock___247 {
	struct file_lock___247 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___247 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___247 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___247 *fl_ops;
	const struct lock_manager_operations___247 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___247 {
	void (*fl_copy_lock)(struct file_lock___247 *, struct file_lock___247 *);
	void (*fl_release_private)(struct file_lock___247 *);
};

struct lock_manager_operations___247 {
	int (*lm_compare_owner)(struct file_lock___247 *, struct file_lock___247 *);
	long unsigned int (*lm_owner_key)(struct file_lock___247 *);
	void (*lm_notify)(struct file_lock___247 *);
	int (*lm_grant)(struct file_lock___247 *, struct file_lock___247 *, int);
	void (*lm_break)(struct file_lock___247 *);
	int (*lm_change)(struct file_lock___247 **, int);
};

struct fasync_struct___247 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___247 *fa_next;
	struct file___247 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___247 {
	const char *name;
	int fs_flags;
	struct dentry___247 * (*mount)(struct file_system_type___247 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___247 *);
	struct module___150 *owner;
	struct file_system_type___247 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___247 {
	struct inode___247 * (*alloc_inode)(struct super_block___247 *);
	void (*destroy_inode)(struct inode___247 *);
	void (*dirty_inode)(struct inode___247 *, int);
	int (*write_inode)(struct inode___247 *, struct writeback_control *);
	int (*drop_inode)(struct inode___247 *);
	void (*evict_inode)(struct inode___247 *);
	void (*put_super)(struct super_block___247 *);
	int (*sync_fs)(struct super_block___247 *, int);
	int (*freeze_fs)(struct super_block___247 *);
	int (*unfreeze_fs)(struct super_block___247 *);
	int (*statfs)(struct dentry___247 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___247 *, int *, char *);
	void (*umount_begin)(struct super_block___247 *);
	int (*show_options)(struct seq_file___172 *, struct dentry___247 *);
	int (*show_devname)(struct seq_file___172 *, struct dentry___247 *);
	int (*show_path)(struct seq_file___172 *, struct dentry___247 *);
	int (*show_stats)(struct seq_file___172 *, struct dentry___247 *);
	ssize_t (*quota_read)(struct super_block___247 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___247 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___247 *);
	int (*bdev_try_to_free_page)(struct super_block___247 *, struct page___246 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___247 *);
	void (*free_cached_objects)(struct super_block___247 *, int);
};

struct xattr_handler___144 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___247 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___247 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___247 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___139)(struct file___247 *, wait_queue_head_t *, struct poll_table_struct___137 *);

struct poll_table_struct___137 {
	poll_queue_proc___139 _qproc;
	long unsigned int _key;
};

struct seq_operations___172;

struct seq_file___172 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___249 lock;
	const struct seq_operations___172 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___248 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___248 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___248 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___249 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___143 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___143 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___30 {
	wait_queue_head_t wait;
	struct fasync_struct___247 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___30;

struct socket___31 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___30 *wq;
	struct file___247 *file;
	struct sock___32 *sk;
	const struct proto_ops___30 *ops;
};

struct proto_ops___30 {
	int family;
	struct module___150 *owner;
	int (*release)(struct socket___31 *);
	int (*bind)(struct socket___31 *, struct sockaddr *, int);
	int (*connect)(struct socket___31 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___31 *, struct socket___31 *);
	int (*accept)(struct socket___31 *, struct socket___31 *, int);
	int (*getname)(struct socket___31 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___247 *, struct socket___31 *, struct poll_table_struct___137 *);
	int (*ioctl)(struct socket___31 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___31 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___31 *, int);
	int (*shutdown)(struct socket___31 *, int);
	int (*setsockopt)(struct socket___31 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___31 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___31 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___31 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___38 *, struct socket___31 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___38 *, struct socket___31 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___247 *, struct socket___31 *, struct vm_area_struct___255 *);
	ssize_t (*sendpage)(struct socket___31 *, struct page___246 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___31 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___32 *, int);
		struct {
			void (*set_peek_off)(struct sock___32 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___50 {
	struct ctl_table_header___53 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___50 {
	struct mutex___249 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___50 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___53 *ctl;
};

struct netns_ipv4___50 {
	struct ctl_table_header___53 *forw_hdr;
	struct ctl_table_header___53 *frags_hdr;
	struct ctl_table_header___53 *ipv4_hdr;
	struct ctl_table_header___53 *route_hdr;
	struct ctl_table_header___53 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___32 *fibnl;
	struct sock___32 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___50 {
	struct ctl_table_header___53 *hdr;
	struct ctl_table_header___53 *route_hdr;
	struct ctl_table_header___53 *icmp_hdr;
	struct ctl_table_header___53 *frags_hdr;
	struct ctl_table_header___53 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___40;

struct neighbour___30;

struct dst_ops___51 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___51 *);
	struct dst_entry___30 * (*check)(struct dst_entry___30 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___30 *);
	unsigned int (*mtu)(const struct dst_entry___30 *);
	u32 * (*cow_metrics)(struct dst_entry___30 *, long unsigned int);
	void (*destroy)(struct dst_entry___30 *);
	void (*ifdown)(struct dst_entry___30 *, struct net_device___40 *, int);
	struct dst_entry___30 * (*negative_advice)(struct dst_entry___30 *);
	void (*link_failure)(struct sk_buff___42 *);
	void (*update_pmtu)(struct dst_entry___30 *, struct sock___32 *, struct sk_buff___42 *, u32);
	void (*redirect)(struct dst_entry___30 *, struct sock___32 *, struct sk_buff___42 *);
	int (*local_out)(struct sk_buff___42 *);
	struct neighbour___30 * (*neigh_lookup)(const struct dst_entry___30 *, struct sk_buff___42 *, const void *);
	struct kmem_cache___230 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___51 {
	struct netns_sysctl_ipv6___50 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___51 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___32 **icmp_sk;
	struct sock___32 *ndisc_sk;
	struct sock___32 *tcp_sk;
	struct sock___32 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___50 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___53 *sysctl_header;
	struct sock___32 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___30 {
	struct sock___32 *v4_ctl_sk;
	struct sock___32 *v6_ctl_sk;
};

struct netns_nf___50 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___53 *nf_log_dir_header;
};

struct nf_proto_net___50 {
	struct ctl_table_header___53 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___50 {
	struct nf_proto_net___50 pn;
	unsigned int timeout;
};

struct nf_tcp_net___50 {
	struct nf_proto_net___50 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___50 {
	struct nf_proto_net___50 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___50 {
	struct nf_proto_net___50 pn;
	unsigned int timeout;
};

struct nf_ip_net___50 {
	struct nf_generic_net___50 generic;
	struct nf_tcp_net___50 tcp;
	struct nf_udp_net___50 udp;
	struct nf_icmp_net___50 icmp;
	struct nf_icmp_net___50 icmpv6;
};

struct netns_ct___50 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___53 *sysctl_header;
	struct ctl_table_header___53 *acct_sysctl_header;
	struct ctl_table_header___53 *tstamp_sysctl_header;
	struct ctl_table_header___53 *event_sysctl_header;
	struct ctl_table_header___53 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___230 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___50 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___50 {
	struct netns_sysctl_ipv6___50 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___51 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___32 *nlsk;
	struct sock___32 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___53 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___51 xfrm4_dst_ops;
	struct dst_ops___51 xfrm6_dst_ops;
};

struct net___52 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___53 sysctls;
	struct sock___32 *rtnl;
	struct sock___32 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___40 *loopback_dev;
	struct netns_core___50 core;
	struct netns_mib mib;
	struct netns_packet___50 packet;
	struct netns_unix___50 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___50 ipv4;
	struct netns_ipv6___51 ipv6;
	struct netns_sctp___50 sctp;
	struct netns_dccp___30 dccp;
	struct netns_nf___50 nf;
	struct netns_xt xt;
	struct netns_ct___50 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___50 nf_frag;
	struct sock___32 *nfnl;
	struct sock___32 *nfnl_stash;
	struct sk_buff_head___39 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___51 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___32 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___32 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___249 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___249 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___229 {
	void **freelist;
	long unsigned int tid;
	struct page___246 *page;
	struct page___246 *partial;
};

struct memcg_cache_params___230 {
	bool is_root_cache;
	union {
		struct kmem_cache___230 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___230 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___38 {
	atomic_t use;
	unsigned int mask;
	struct net_device___40 *physindev;
	struct net_device___40 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___38(struct sk_buff___42 **);

struct net_device_ops___38;

struct ethtool_ops___38;

struct header_ops___38;

struct inet6_dev___16;

struct netdev_rx_queue___38;

struct netdev_queue___38;

struct Qdisc___2;

struct rtnl_link_ops___30;

struct dcbnl_rtnl_ops___38;

struct net_device___40 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___38 *netdev_ops;
	const struct ethtool_ops___38 *ethtool_ops;
	const struct header_ops___38 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___33 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___16 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___38 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___38 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___38 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___38 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___38 = 0,
		NETREG_REGISTERED___38 = 1,
		NETREG_UNREGISTERING___38 = 2,
		NETREG_UNREGISTERED___38 = 3,
		NETREG_RELEASED___38 = 4,
		NETREG_DUMMY___38 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___38 = 0,
		RTNL_LINK_INITIALIZING___38 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___40 *);
	struct netpoll_info *npinfo;
	struct net___52 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___245 dev;
	const struct attribute_group___207 *sysfs_groups[4];
	const struct rtnl_link_ops___30 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___38 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___42 {
	struct sk_buff___42 *next;
	struct sk_buff___42 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___32 *sk;
	struct net_device___40 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___42 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___38 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___38 {
	int (*get_settings)(struct net_device___40 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___40 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___40 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___40 *);
	void (*get_regs)(struct net_device___40 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___40 *);
	void (*set_msglevel)(struct net_device___40 *, u32);
	int (*nway_reset)(struct net_device___40 *);
	u32 (*get_link)(struct net_device___40 *);
	int (*get_eeprom_len)(struct net_device___40 *);
	int (*get_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___40 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___40 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___40 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___40 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___40 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___40 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___40 *);
	void (*complete)(struct net_device___40 *);
	u32 (*get_priv_flags)(struct net_device___40 *);
	int (*set_priv_flags)(struct net_device___40 *, u32);
	int (*get_sset_count)(struct net_device___40 *, int);
	int (*get_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___40 *, struct ethtool_flash *);
	int (*reset)(struct net_device___40 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___40 *);
	int (*get_rxfh_indir)(struct net_device___40 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___40 *, const u32 *);
	void (*get_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___40 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___40 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___40 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___40 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___40 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___40 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___40 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___40 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___11;

struct dst_entry___30 {
	struct callback_head callback_head;
	struct dst_entry___30 *child;
	struct net_device___40 *dev;
	struct dst_ops___51 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___30 *path;
	struct dst_entry___30 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___42 *);
	union {
		int (*output)(struct sock___32 *, struct sk_buff___42 *);
		struct {
			int (*output)(struct sk_buff___42 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___30 *next;
		struct rtable___11 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___30;

struct neigh_parms___30;

struct neigh_ops___30;

struct neighbour___30 {
	struct neighbour___30 *next;
	struct neigh_table___30 *tbl;
	struct neigh_parms___30 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___39 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___30 *, struct sk_buff___42 *);
	const struct neigh_ops___30 *ops;
	struct callback_head rcu;
	struct net_device___40 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___51 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___42 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___42 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___52 *, struct dst_entry___30 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___42 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___42 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___171 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___171 *);
	void (*irq_shutdown)(struct irq_data___171 *);
	void (*irq_enable)(struct irq_data___171 *);
	void (*irq_disable)(struct irq_data___171 *);
	void (*irq_ack)(struct irq_data___171 *);
	void (*irq_mask)(struct irq_data___171 *);
	void (*irq_mask_ack)(struct irq_data___171 *);
	void (*irq_unmask)(struct irq_data___171 *);
	void (*irq_eoi)(struct irq_data___171 *);
	int (*irq_set_affinity)(struct irq_data___171 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___171 *);
	int (*irq_set_type)(struct irq_data___171 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___171 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___171 *);
	void (*irq_bus_sync_unlock)(struct irq_data___171 *);
	void (*irq_cpu_online)(struct irq_data___171 *);
	void (*irq_cpu_offline)(struct irq_data___171 *);
	void (*irq_suspend)(struct irq_data___171 *);
	void (*irq_resume)(struct irq_data___171 *);
	void (*irq_pm_shutdown)(struct irq_data___171 *);
	void (*irq_print_chip)(struct irq_data___171 *, struct seq_file___172 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___171 *, void *);
	long unsigned int flags;
};

struct seq_operations___172 {
	void * (*start)(struct seq_file___172 *, loff_t *);
	void (*stop)(struct seq_file___172 *, void *);
	void * (*next)(struct seq_file___172 *, void *, loff_t *);
	int (*show)(struct seq_file___172 *, void *);
};

struct pernet_operations___6 {
	struct list_head list;
	int (*init)(struct net___52 *);
	void (*exit)(struct net___52 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___38 {
	int (*ieee_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___40 *);
	u8 (*setstate)(struct net_device___40 *, u8);
	void (*getpermhwaddr)(struct net_device___40 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___40 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___40 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___40 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___40 *, int, u8 *);
	void (*setpfccfg)(struct net_device___40 *, int, u8);
	void (*getpfccfg)(struct net_device___40 *, int, u8 *);
	u8 (*setall)(struct net_device___40 *);
	u8 (*getcap)(struct net_device___40 *, int, u8 *);
	int (*getnumtcs)(struct net_device___40 *, int, u8 *);
	int (*setnumtcs)(struct net_device___40 *, int, u8);
	u8 (*getpfcstate)(struct net_device___40 *);
	void (*setpfcstate)(struct net_device___40 *, u8);
	void (*getbcncfg)(struct net_device___40 *, int, u32 *);
	void (*setbcncfg)(struct net_device___40 *, int, u32);
	void (*getbcnrp)(struct net_device___40 *, int, u8 *);
	void (*setbcnrp)(struct net_device___40 *, int, u8);
	u8 (*setapp)(struct net_device___40 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___40 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___40 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___40 *, int, u8);
	u8 (*getdcbx)(struct net_device___40 *);
	u8 (*setdcbx)(struct net_device___40 *, u8);
	int (*peer_getappinfo)(struct net_device___40 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___40 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___40 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___40 *, struct cee_pfc *);
};

struct cgroupfs_root___143;

struct cgroup___143 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___143 *parent;
	struct dentry___247 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___143 *subsys[11];
	struct cgroupfs_root___143 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___249 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___143 {
	struct super_block___247 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___143 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___82 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___247 *, struct file___247 *);
	ssize_t (*read)(struct cgroup___143 *, struct cftype___82 *, struct file___247 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___143 *, struct cftype___82 *);
	s64 (*read_s64)(struct cgroup___143 *, struct cftype___82 *);
	int (*read_map)(struct cgroup___143 *, struct cftype___82 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___143 *, struct cftype___82 *, struct seq_file___172 *);
	ssize_t (*write)(struct cgroup___143 *, struct cftype___82 *, struct file___247 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___143 *, struct cftype___82 *, u64);
	int (*write_s64)(struct cgroup___143 *, struct cftype___82 *, s64);
	int (*write_string)(struct cgroup___143 *, struct cftype___82 *, const char *);
	int (*trigger)(struct cgroup___143 *, unsigned int);
	int (*release)(struct inode___247 *, struct file___247 *);
	int (*register_event)(struct cgroup___143 *, struct cftype___82 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___143 *, struct cftype___82 *, struct eventfd_ctx *);
};

struct cftype_set___78 {
	struct list_head node;
	struct cftype___82 *cfts;
};

struct task_and_cgroup___78 {
	struct task_struct___248 *task;
	struct cgroup___143 *cgrp;
	struct css_set___143 *cg;
};

struct cgroup_taskset___78 {
	struct task_and_cgroup___78 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___143 *cur_cgrp;
};

struct cgroup_subsys___78 {
	struct cgroup_subsys_state___143 * (*css_alloc)(struct cgroup___143 *);
	int (*css_online)(struct cgroup___143 *);
	void (*css_offline)(struct cgroup___143 *);
	void (*css_free)(struct cgroup___143 *);
	int (*can_attach)(struct cgroup___143 *, struct cgroup_taskset___78 *);
	void (*cancel_attach)(struct cgroup___143 *, struct cgroup_taskset___78 *);
	void (*attach)(struct cgroup___143 *, struct cgroup_taskset___78 *);
	void (*fork)(struct task_struct___248 *);
	void (*exit)(struct cgroup___143 *, struct cgroup___143 *, struct task_struct___248 *);
	void (*bind)(struct cgroup___143 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___143 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___82 *base_cftypes;
	struct cftype_set___78 base_cftset;
	struct module___150 *module;
};

struct request_sock_ops___21;

struct request_sock___22 {
	struct sock_common___30 __req_common;
	struct request_sock___22 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___21 *rsk_ops;
	struct sock___32 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___40 {
	struct sk_buff___42 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___42 *, struct netlink_callback___40 *);
	int (*done)(struct netlink_callback___40 *);
	void *data;
	struct module___150 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___38 {
	int (*create)(struct sk_buff___42 *, struct net_device___40 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___42 *, unsigned char *);
	int (*rebuild)(struct sk_buff___42 *);
	int (*cache)(const struct neighbour___30 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___40 *, const unsigned char *);
};

struct napi_struct___38 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___38 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___40 *dev;
	struct sk_buff___42 *gro_list;
	struct sk_buff___42 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___38 {
	struct net_device___40 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___33 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___2;

struct Qdisc___2 {
	int (*enqueue)(struct sk_buff___42 *, struct Qdisc___2 *);
	struct sk_buff___42 * (*dequeue)(struct Qdisc___2 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___2 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___42 *, struct Qdisc___2 *);
	void *u32_node;
	struct Qdisc___2 *__parent;
	struct netdev_queue___38 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___2 *next_sched;
	struct sk_buff___42 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___39 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___38 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___33 kobj;
	struct net_device___40 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___38 {
	int (*ndo_init)(struct net_device___40 *);
	void (*ndo_uninit)(struct net_device___40 *);
	int (*ndo_open)(struct net_device___40 *);
	int (*ndo_stop)(struct net_device___40 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___42 *, struct net_device___40 *);
	u16 (*ndo_select_queue)(struct net_device___40 *, struct sk_buff___42 *);
	void (*ndo_change_rx_flags)(struct net_device___40 *, int);
	void (*ndo_set_rx_mode)(struct net_device___40 *);
	int (*ndo_set_mac_address)(struct net_device___40 *, void *);
	int (*ndo_validate_addr)(struct net_device___40 *);
	int (*ndo_do_ioctl)(struct net_device___40 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___40 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___40 *, int);
	int (*ndo_neigh_setup)(struct net_device___40 *, struct neigh_parms___30 *);
	void (*ndo_tx_timeout)(struct net_device___40 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___40 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___40 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___40 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___40 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___40 *);
	int (*ndo_netpoll_setup)(struct net_device___40 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___40 *);
	int (*ndo_busy_poll)(struct napi_struct___38 *);
	int (*ndo_set_vf_mac)(struct net_device___40 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___40 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___40 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___40 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___40 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___40 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___40 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___40 *, int, struct sk_buff___42 *);
	int (*ndo_setup_tc)(struct net_device___40 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___40 *);
	int (*ndo_fcoe_disable)(struct net_device___40 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___40 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___40 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___40 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___40 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___40 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___40 *, const struct sk_buff___42 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___40 *, struct net_device___40 *);
	int (*ndo_del_slave)(struct net_device___40 *, struct net_device___40 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___30 *);
	void (*ndo_neigh_destroy)(struct neighbour___30 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___42 *, struct netlink_callback___40 *, struct net_device___40 *, int);
	int (*ndo_bridge_setlink)(struct net_device___40 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___42 *, u32, u32, struct net_device___40 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___40 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___40 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___40 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___40 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___40 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___40 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___42 *, struct net_device___40 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___40 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___40 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___40 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___30 {
	struct net___52 *net;
	struct net_device___40 *dev;
	struct neigh_parms___30 *next;
	int (*neigh_setup)(struct neighbour___30 *);
	void (*neigh_cleanup)(struct neighbour___30 *);
	struct neigh_table___30 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___16;

struct ifacaddr6___16;

struct inet6_dev___16 {
	struct net_device___40 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___16 *mc_list;
	struct ifmcaddr6___16 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___16 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___30 *nd_parms;
	struct inet6_dev___16 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___30 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___40 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___52 *, struct net_device___40 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___40 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___40 *, struct list_head *);
	size_t (*get_size)(const struct net_device___40 *);
	int (*fill_info)(struct sk_buff___42 *, const struct net_device___40 *);
	size_t (*get_xstats_size)(const struct net_device___40 *);
	int (*fill_xstats)(struct sk_buff___42 *, const struct net_device___40 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___52 * (*get_link_net)(const struct net_device___40 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___40 *, struct net_device___40 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___40 *, const struct net_device___40 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___42 *, const struct net_device___40 *, const struct net_device___40 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___31 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___42 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___30;

struct neigh_hash_table___30;

struct neigh_table___30 {
	struct neigh_table___30 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___40 *, __u32 *);
	int (*constructor)(struct neighbour___30 *);
	int (*pconstructor)(struct pneigh_entry___30 *);
	void (*pdestructor)(struct pneigh_entry___30 *);
	void (*proxy_redo)(struct sk_buff___42 *);
	char *id;
	struct neigh_parms___30 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___39 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___30 *nht;
	struct pneigh_entry___30 **phash_buckets;
};

struct neigh_ops___30 {
	int family;
	void (*solicit)(struct neighbour___30 *, struct sk_buff___42 *);
	void (*error_report)(struct neighbour___30 *, struct sk_buff___42 *);
	int (*output)(struct neighbour___30 *, struct sk_buff___42 *);
	int (*connected_output)(struct neighbour___30 *, struct sk_buff___42 *);
};

struct pneigh_entry___30 {
	struct pneigh_entry___30 *next;
	struct net___52 *net;
	struct net_device___40 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___30 {
	struct neighbour___30 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___11 {
	struct dst_entry___30 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___19;

struct proto___30 {
	void (*close)(struct sock___32 *, long int);
	int (*connect)(struct sock___32 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___32 *, int);
	struct sock___32 * (*accept)(struct sock___32 *, int, int *);
	int (*ioctl)(struct sock___32 *, int, long unsigned int);
	int (*init)(struct sock___32 *);
	void (*destroy)(struct sock___32 *);
	void (*shutdown)(struct sock___32 *, int);
	int (*setsockopt)(struct sock___32 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___32 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___32 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___32 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___32 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___38 *, struct sock___32 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___38 *, struct sock___32 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___32 *, struct page___246 *, int, size_t, int);
	int (*bind)(struct sock___32 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___32 *, struct sk_buff___42 *);
	void (*release_cb)(struct sock___32 *);
	void (*mtu_reduced)(struct sock___32 *);
	void (*hash)(struct sock___32 *);
	void (*unhash)(struct sock___32 *);
	void (*rehash)(struct sock___32 *);
	int (*get_port)(struct sock___32 *, short unsigned int);
	void (*clear_sk)(struct sock___32 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___32 *);
	void (*enter_memory_pressure)(struct sock___32 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___230 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___21 *rsk_prot;
	struct timewait_sock_ops___19 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___150 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___78 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___30 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___30 {
	void (*enter_memory_pressure)(struct sock___32 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___21 {
	int family;
	int obj_size;
	struct kmem_cache___230 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___32 *, struct request_sock___22 *);
	void (*send_ack)(struct sock___32 *, struct sk_buff___42 *, struct request_sock___22 *);
	void (*send_reset)(struct sock___32 *, struct sk_buff___42 *);
	void (*destructor)(struct request_sock___22 *);
	void (*syn_ack_timeout)(struct sock___32 *, struct request_sock___22 *);
};

struct timewait_sock_ops___19 {
	struct kmem_cache___230 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___32 *, struct sock___32 *, void *);
	void (*twsk_destructor)(struct sock___32 *);
};

struct ifmcaddr6___16 {
	struct in6_addr mca_addr;
	struct inet6_dev___16 *idev;
	struct ifmcaddr6___16 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___16 {
	struct in6_addr aca_addr;
	struct inet6_dev___16 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___16 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct gnet_dump___3 {
	spinlock_t *lock;
	struct sk_buff___42 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___2;

struct Qdisc_ops___2 {
	struct Qdisc_ops___2 *next;
	const struct Qdisc_class_ops___2 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___42 *, struct Qdisc___2 *);
	struct sk_buff___42 * (*dequeue)(struct Qdisc___2 *);
	struct sk_buff___42 * (*peek)(struct Qdisc___2 *);
	unsigned int (*drop)(struct Qdisc___2 *);
	int (*init)(struct Qdisc___2 *, struct nlattr *);
	void (*reset)(struct Qdisc___2 *);
	void (*destroy)(struct Qdisc___2 *);
	int (*change)(struct Qdisc___2 *, struct nlattr *);
	void (*attach)(struct Qdisc___2 *);
	int (*dump)(struct Qdisc___2 *, struct sk_buff___42 *);
	int (*dump_stats)(struct Qdisc___2 *, struct gnet_dump___3 *);
	struct module___150 *owner;
};

struct qdisc_walker___2;

struct tcf_proto___2;

struct Qdisc_class_ops___2 {
	struct netdev_queue___38 * (*select_queue)(struct Qdisc___2 *, struct tcmsg *);
	int (*graft)(struct Qdisc___2 *, long unsigned int, struct Qdisc___2 *, struct Qdisc___2 **);
	struct Qdisc___2 * (*leaf)(struct Qdisc___2 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___2 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___2 *, u32);
	void (*put)(struct Qdisc___2 *, long unsigned int);
	int (*change)(struct Qdisc___2 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___2 *, long unsigned int);
	void (*walk)(struct Qdisc___2 *, struct qdisc_walker___2 *);
	struct tcf_proto___2 ** (*tcf_chain)(struct Qdisc___2 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___2 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___2 *, long unsigned int);
	int (*dump)(struct Qdisc___2 *, long unsigned int, struct sk_buff___42 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___2 *, long unsigned int, struct gnet_dump___3 *);
};

struct qdisc_walker___2 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___2 *, long unsigned int, struct qdisc_walker___2 *);
};

struct tcf_proto_ops___2;

struct tcf_proto___2 {
	struct tcf_proto___2 *next;
	void *root;
	int (*classify)(struct sk_buff___42 *, const struct tcf_proto___2 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___2 *q;
	void *data;
	const struct tcf_proto_ops___2 *ops;
};

struct tcf_proto_ops___2 {
	struct tcf_proto_ops___2 *next;
	char kind[16];
	int (*classify)(struct sk_buff___42 *, const struct tcf_proto___2 *, struct tcf_result *);
	int (*init)(struct tcf_proto___2 *);
	void (*destroy)(struct tcf_proto___2 *);
	long unsigned int (*get)(struct tcf_proto___2 *, u32);
	void (*put)(struct tcf_proto___2 *, long unsigned int);
	int (*change)(struct net___52 *, struct sk_buff___42 *, struct tcf_proto___2 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___2 *, long unsigned int);
	void (*walk)(struct tcf_proto___2 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___2 *, long unsigned int, struct sk_buff___42 *, struct tcmsg *);
	struct module___150 *owner;
};

struct page___247;

typedef struct page___247 *pgtable_t___247;

struct address_space___248;

struct kmem_cache___231;

struct page___247 {
	long unsigned int flags;
	struct address_space___248 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___247 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___247 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___231 *slab_cache;
		struct page___247 *first_page;
	};
	long: 64;
};

struct task_struct___249;

struct pv_cpu_ops___249 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___249 *);
	void (*end_context_switch)(struct task_struct___249 *);
};

struct mutex___250 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___249 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___242 {
	struct page___247 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___256;

struct nsproxy___129;

struct signal_struct___249;

struct css_set___144;

struct task_struct___249 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___249 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___256 *mm;
	struct mm_struct___256 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___249 *real_parent;
	struct task_struct___249 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___249 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___249 = 0,
		VTIME_USER___249 = 1,
		VTIME_SYS___249 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___129 *nsproxy;
	struct signal_struct___249 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___144 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___250 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___242 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___256 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___256 *, struct mm_struct___256 *);
	void (*dup_mmap)(struct mm_struct___256 *, struct mm_struct___256 *);
	void (*exit_mmap)(struct mm_struct___256 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___256 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___256 *);
	void (*pgd_free)(struct mm_struct___256 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___256 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___256 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___256 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___256 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___256 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___256 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___256 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___256 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___256 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___256 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___256 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___250 lock;
	void *vdso;
} mm_context_t___250;

struct xol_area___247;

struct uprobes_state___247 {
	struct xol_area___247 *xol_area;
};

struct vm_area_struct___256;

struct file___248;

struct core_state___249;

struct mm_struct___256 {
	struct vm_area_struct___256 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___256 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___256 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___250 context;
	long unsigned int flags;
	struct core_state___249 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___249 *owner;
	struct file___248 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___247 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___151;

struct exec_domain___70 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___151 *module;
	struct exec_domain___70 *next;
};

struct kset___34;

struct kobj_type___34;

struct kobject___34 {
	const char *name;
	struct list_head entry;
	struct kobject___34 *parent;
	struct kset___34 *kset;
	struct kobj_type___34 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___149 {
	struct kobject___34 kobj;
	struct module___151 *mod;
	struct kobject___34 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___149;

struct module___151 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___149 mkobj;
	struct module_attribute___149 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___34 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___249 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___115 {
	struct task_struct___249 *task;
	struct exec_domain___70 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct sock___33;

struct kobj_ns_type_operations___31 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___33 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___31;

struct net___53;

struct sock_common___31 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___31 *skc_prot;
	struct net___53 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___43;

struct sk_buff_head___40 {
	struct sk_buff___43 *next;
	struct sk_buff___43 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___32;

struct socket_wq___31;

struct xfrm_policy___4;

struct dst_entry___31;

struct socket___32;

struct cg_proto___31;

struct sock___33 {
	struct sock_common___31 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___40 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___43 *head;
		struct sk_buff___43 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___32 *sk_filter;
	struct socket_wq___31 *sk_wq;
	struct sk_buff_head___40 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___4 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___31 *sk_rx_dst;
	struct dst_entry___31 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___40 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___40 sk_error_queue;
	struct proto___31 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___32 *sk_socket;
	void *sk_user_data;
	struct page_frag___242 sk_frag;
	struct sk_buff___43 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___31 *sk_cgrp;
	void (*sk_state_change)(struct sock___33 *);
	void (*sk_data_ready)(struct sock___33 *, int);
	void (*sk_write_space)(struct sock___33 *);
	void (*sk_error_report)(struct sock___33 *);
	int (*sk_backlog_rcv)(struct sock___33 *, struct sk_buff___43 *);
	void (*sk_destruct)(struct sock___33 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___210;

struct attribute_group___208 {
	const char *name;
	umode_t (*is_visible)(struct kobject___34 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___210 **bin_attrs;
};

struct bin_attribute___210 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___248 *, struct kobject___34 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___248 *, struct kobject___34 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	int (*mmap)(struct file___248 *, struct kobject___34 *, struct bin_attribute___210 *, struct vm_area_struct___256 *);
};

struct dentry___248;

struct path___248 {
	struct vfsmount *mnt;
	struct dentry___248 *dentry;
};

struct inode___248;

struct file_operations___248;

struct file___248 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___248 f_path;
	struct inode___248 *f_inode;
	const struct file_operations___248 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___248 *f_mapping;
	struct mutex___250 f_pos_lock;
};

struct vm_operations_struct___222;

struct vm_area_struct___256 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___256 *vm_next;
	struct vm_area_struct___256 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___256 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___222 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___248 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___34 {
	ssize_t (*show)(struct kobject___34 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___34 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___34 *, const struct attribute *);
};

struct kset_uevent_ops___34;

struct kset___34 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___34 kobj;
	const struct kset_uevent_ops___34 *uevent_ops;
};

struct kobj_type___34 {
	void (*release)(struct kobject___34 *);
	const struct sysfs_ops___34 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___31 * (*child_ns_type)(struct kobject___34 *);
	const void * (*namespace)(struct kobject___34 *);
};

struct kset_uevent_ops___34 {
	int (* const filter)(struct kset___34 *, struct kobject___34 *);
	const char * (* const name)(struct kset___34 *, struct kobject___34 *);
	int (* const uevent)(struct kset___34 *, struct kobject___34 *, struct kobj_uevent_env *);
};

struct device___246;

struct dev_pm_ops___246 {
	int (*prepare)(struct device___246 *);
	void (*complete)(struct device___246 *);
	int (*suspend)(struct device___246 *);
	int (*resume)(struct device___246 *);
	int (*freeze)(struct device___246 *);
	int (*thaw)(struct device___246 *);
	int (*poweroff)(struct device___246 *);
	int (*restore)(struct device___246 *);
	int (*suspend_late)(struct device___246 *);
	int (*resume_early)(struct device___246 *);
	int (*freeze_late)(struct device___246 *);
	int (*thaw_early)(struct device___246 *);
	int (*poweroff_late)(struct device___246 *);
	int (*restore_early)(struct device___246 *);
	int (*suspend_noirq)(struct device___246 *);
	int (*resume_noirq)(struct device___246 *);
	int (*freeze_noirq)(struct device___246 *);
	int (*thaw_noirq)(struct device___246 *);
	int (*poweroff_noirq)(struct device___246 *);
	int (*restore_noirq)(struct device___246 *);
	int (*runtime_suspend)(struct device___246 *);
	int (*runtime_resume)(struct device___246 *);
	int (*runtime_idle)(struct device___246 *);
};

struct dev_pm_qos___50;

struct dev_pm_info___50 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___50 *qos;
};

struct dma_map_ops___111;

struct dev_archdata___111 {
	struct dma_map_ops___111 *dma_ops;
	void *iommu;
};

struct device_type___246;

struct bus_type___246;

struct device_driver___246;

struct dev_pm_domain___246;

struct class___246;

struct device_rh___246;

struct device___246 {
	struct device___246 *parent;
	struct device_private *p;
	struct kobject___34 kobj;
	const char *init_name;
	const struct device_type___246 *type;
	struct mutex___250 mutex;
	struct bus_type___246 *bus;
	struct device_driver___246 *driver;
	void *platform_data;
	struct dev_pm_info___50 power;
	struct dev_pm_domain___246 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___111 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___246 *class;
	const struct attribute_group___208 **groups;
	void (*release)(struct device___246 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___246 *device_rh;
};

struct dev_pm_qos_request___51;

struct dev_pm_qos___50 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___51 *latency_req;
	struct dev_pm_qos_request___51 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___51 *latency_tolerance_req;
};

struct dev_pm_info_rh___246 {
	void (*set_latency_tolerance)(struct device___246 *, s32);
};

struct dev_pm_domain___246 {
	struct dev_pm_ops___246 ops;
};

struct zone___249;

struct lruvec___249 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___249 *zone;
};

struct pglist_data___249;

struct zone___249 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___249 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___249 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___249 {
	struct zone___249 *zone;
	int zone_idx;
};

struct zonelist___249 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___249 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___249 {
	struct zone___249 node_zones[4];
	struct zonelist___249 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___249 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___172;

struct x86_io_apic_ops___172 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___172 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___172;

struct irq_data___172 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___172 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___249 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___249 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___111 {
	void * (*alloc)(struct device___246 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___246 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___246 *, struct vm_area_struct___256 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___246 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___246 *, struct page___247 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___246 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___246 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___246 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___246 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___246 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___246 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___246 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___246 *, dma_addr_t);
	int (*dma_supported)(struct device___246 *, u64);
	int (*set_dma_mask)(struct device___246 *, u64);
	int is_phys;
};

struct bus_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___246 *, char *);
	ssize_t (*store)(struct bus_type___246 *, const char *, size_t);
};

struct device_attribute___246;

struct driver_attribute___246;

struct bus_type___246 {
	const char *name;
	const char *dev_name;
	struct device___246 *dev_root;
	struct bus_attribute___246 *bus_attrs;
	struct device_attribute___246 *dev_attrs;
	struct driver_attribute___246 *drv_attrs;
	const struct attribute_group___208 **bus_groups;
	const struct attribute_group___208 **dev_groups;
	const struct attribute_group___208 **drv_groups;
	int (*match)(struct device___246 *, struct device_driver___246 *);
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	int (*probe)(struct device___246 *);
	int (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*online)(struct device___246 *);
	int (*offline)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct device___246 *, struct device_attribute___246 *, char *);
	ssize_t (*store)(struct device___246 *, struct device_attribute___246 *, const char *, size_t);
};

struct driver_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___246 *, char *);
	ssize_t (*store)(struct device_driver___246 *, const char *, size_t);
};

struct device_driver___246 {
	const char *name;
	struct bus_type___246 *bus;
	struct module___151 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___246 *);
	int (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	const struct attribute_group___208 **groups;
	const struct dev_pm_ops___246 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___246 {
	const char *name;
	const struct attribute_group___208 **groups;
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
};

struct class_attribute___246;

struct class___246 {
	const char *name;
	struct module___151 *owner;
	struct class_attribute___246 *class_attrs;
	struct device_attribute___246 *dev_attrs;
	const struct attribute_group___208 **dev_groups;
	struct bin_attribute___210 *dev_bin_attrs;
	struct kobject___34 *dev_kobj;
	int (*dev_uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *);
	void (*class_release)(struct class___246 *);
	void (*dev_release)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	const struct kobj_ns_type_operations___31 *ns_type;
	const void * (*namespace)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
	struct subsys_private *p;
};

struct class_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct class___246 *, struct class_attribute___246 *, char *);
	ssize_t (*store)(struct class___246 *, struct class_attribute___246 *, const char *, size_t);
	const void * (*namespace)(struct class___246 *, const struct class_attribute___246 *);
};

struct device_rh___246 {
	struct dev_pm_info_rh___246 power;
};

struct kmem_cache_cpu___230 {
	void **freelist;
	long unsigned int tid;
	struct page___247 *page;
	struct page___247 *partial;
};

struct memcg_cache_params___231;

struct kmem_cache___231 {
	struct kmem_cache_cpu___230 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___34 kobj;
	struct memcg_cache_params___231 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___231 {
	bool is_root_cache;
	union {
		struct kmem_cache___231 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___231 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___247 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___247 *page;
	long unsigned int vaddr;
};

struct address_space_operations___248;

struct address_space___248 {
	struct inode___248 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___250 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___248 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___218;

struct vm_operations_struct___222 {
	void (*open)(struct vm_area_struct___256 *);
	void (*close)(struct vm_area_struct___256 *);
	int (*fault)(struct vm_area_struct___256 *, struct vm_fault___218 *);
	int (*page_mkwrite)(struct vm_area_struct___256 *, struct vm_fault___218 *);
	int (*access)(struct vm_area_struct___256 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___256 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___256 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___256 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___256 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___249 {
	struct task_struct___249 *task;
	struct core_thread___249 *next;
};

struct core_state___249 {
	atomic_t nr_threads;
	struct core_thread___249 dumper;
	struct completion startup;
};

struct ctl_table_header___54;

struct ctl_node___54 {
	struct rb_node node;
	struct ctl_table_header___54 *header;
};

struct ctl_table_root___54;

struct ctl_table_set___54;

struct ctl_dir___54;

struct ctl_table_header___54 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___54 *root;
	struct ctl_table_set___54 *set;
	struct ctl_dir___54 *parent;
	struct ctl_node___54 *node;
};

struct ctl_dir___54 {
	struct ctl_table_header___54 header;
	struct rb_root root;
};

struct ctl_table_set___54 {
	int (*is_seen)(struct ctl_table_set___54 *);
	struct ctl_dir___54 dir;
};

struct ctl_table_root___54 {
	struct ctl_table_set___54 default_set;
	struct ctl_table_set___54 * (*lookup)(struct ctl_table_root___54 *, struct nsproxy___129 *);
	int (*permissions)(struct ctl_table_header___54 *, struct ctl_table *);
};

struct nsproxy___129 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___53 *net_ns;
};

struct signal_struct___249 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___249 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___249 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___250 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___144;

struct css_set___144 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___144 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___218 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___247 *page;
};

struct seq_file___173;

struct irq_chip___172 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___172 *);
	void (*irq_shutdown)(struct irq_data___172 *);
	void (*irq_enable)(struct irq_data___172 *);
	void (*irq_disable)(struct irq_data___172 *);
	void (*irq_ack)(struct irq_data___172 *);
	void (*irq_mask)(struct irq_data___172 *);
	void (*irq_mask_ack)(struct irq_data___172 *);
	void (*irq_unmask)(struct irq_data___172 *);
	void (*irq_eoi)(struct irq_data___172 *);
	int (*irq_set_affinity)(struct irq_data___172 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___172 *);
	int (*irq_set_type)(struct irq_data___172 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___172 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___172 *);
	void (*irq_bus_sync_unlock)(struct irq_data___172 *);
	void (*irq_cpu_online)(struct irq_data___172 *);
	void (*irq_cpu_offline)(struct irq_data___172 *);
	void (*irq_suspend)(struct irq_data___172 *);
	void (*irq_resume)(struct irq_data___172 *);
	void (*irq_pm_shutdown)(struct irq_data___172 *);
	void (*irq_print_chip)(struct irq_data___172 *, struct seq_file___173 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___172 *, void *);
	long unsigned int flags;
};

struct seq_operations___173;

struct seq_file___173 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___250 lock;
	const struct seq_operations___173 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct fasync_struct___248;

struct socket_wq___31 {
	wait_queue_head_t wait;
	struct fasync_struct___248 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___248 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___248 *fa_next;
	struct file___248 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___31;

struct socket___32 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___31 *wq;
	struct file___248 *file;
	struct sock___33 *sk;
	const struct proto_ops___31 *ops;
};

struct poll_table_struct___138;

struct kiocb___39;

struct proto_ops___31 {
	int family;
	struct module___151 *owner;
	int (*release)(struct socket___32 *);
	int (*bind)(struct socket___32 *, struct sockaddr *, int);
	int (*connect)(struct socket___32 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___32 *, struct socket___32 *);
	int (*accept)(struct socket___32 *, struct socket___32 *, int);
	int (*getname)(struct socket___32 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___248 *, struct socket___32 *, struct poll_table_struct___138 *);
	int (*ioctl)(struct socket___32 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___32 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___32 *, int);
	int (*shutdown)(struct socket___32 *, int);
	int (*setsockopt)(struct socket___32 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___32 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___32 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___32 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___39 *, struct socket___32 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___39 *, struct socket___32 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___248 *, struct socket___32 *, struct vm_area_struct___256 *);
	ssize_t (*sendpage)(struct socket___32 *, struct page___247 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___32 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___33 *, int);
		struct {
			void (*set_peek_off)(struct sock___33 *, int);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
};

typedef void (*poll_queue_proc___140)(struct file___248 *, wait_queue_head_t *, struct poll_table_struct___138 *);

struct poll_table_struct___138 {
	poll_queue_proc___140 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___39(struct kiocb___39 *, struct io_event *);

struct kiocb___39 {
	atomic_t ki_users;
	struct file___248 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___39 *ki_cancel;
	void (*ki_dtor)(struct kiocb___39 *);
	union {
		void *user;
		struct task_struct___249 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___51 {
	struct ctl_table_header___54 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___51 {
	struct mutex___250 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___51 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___54 *ctl;
};

struct netns_ipv4___51 {
	struct ctl_table_header___54 *forw_hdr;
	struct ctl_table_header___54 *frags_hdr;
	struct ctl_table_header___54 *ipv4_hdr;
	struct ctl_table_header___54 *route_hdr;
	struct ctl_table_header___54 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___33 *fibnl;
	struct sock___33 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___51 {
	struct ctl_table_header___54 *hdr;
	struct ctl_table_header___54 *route_hdr;
	struct ctl_table_header___54 *icmp_hdr;
	struct ctl_table_header___54 *frags_hdr;
	struct ctl_table_header___54 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___41;

struct neighbour___31;

struct dst_ops___52 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___52 *);
	struct dst_entry___31 * (*check)(struct dst_entry___31 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___31 *);
	unsigned int (*mtu)(const struct dst_entry___31 *);
	u32 * (*cow_metrics)(struct dst_entry___31 *, long unsigned int);
	void (*destroy)(struct dst_entry___31 *);
	void (*ifdown)(struct dst_entry___31 *, struct net_device___41 *, int);
	struct dst_entry___31 * (*negative_advice)(struct dst_entry___31 *);
	void (*link_failure)(struct sk_buff___43 *);
	void (*update_pmtu)(struct dst_entry___31 *, struct sock___33 *, struct sk_buff___43 *, u32);
	void (*redirect)(struct dst_entry___31 *, struct sock___33 *, struct sk_buff___43 *);
	int (*local_out)(struct sk_buff___43 *);
	struct neighbour___31 * (*neigh_lookup)(const struct dst_entry___31 *, struct sk_buff___43 *, const void *);
	struct kmem_cache___231 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___4;

struct fib6_table___4;

struct netns_ipv6___52 {
	struct netns_sysctl_ipv6___51 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___4 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___4 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___52 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___4 *ip6_prohibit_entry;
	struct rt6_info___4 *ip6_blk_hole_entry;
	struct fib6_table___4 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___33 **icmp_sk;
	struct sock___33 *ndisc_sk;
	struct sock___33 *tcp_sk;
	struct sock___33 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___51 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___54 *sysctl_header;
	struct sock___33 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___31 {
	struct sock___33 *v4_ctl_sk;
	struct sock___33 *v6_ctl_sk;
};

struct netns_nf___51 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___54 *nf_log_dir_header;
};

struct nf_proto_net___51 {
	struct ctl_table_header___54 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___51 {
	struct nf_proto_net___51 pn;
	unsigned int timeout;
};

struct nf_tcp_net___51 {
	struct nf_proto_net___51 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___51 {
	struct nf_proto_net___51 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___51 {
	struct nf_proto_net___51 pn;
	unsigned int timeout;
};

struct nf_ip_net___51 {
	struct nf_generic_net___51 generic;
	struct nf_tcp_net___51 tcp;
	struct nf_udp_net___51 udp;
	struct nf_icmp_net___51 icmp;
	struct nf_icmp_net___51 icmpv6;
};

struct netns_ct___51 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___54 *sysctl_header;
	struct ctl_table_header___54 *acct_sysctl_header;
	struct ctl_table_header___54 *tstamp_sysctl_header;
	struct ctl_table_header___54 *event_sysctl_header;
	struct ctl_table_header___54 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___231 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___51 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___51 {
	struct netns_sysctl_ipv6___51 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___52 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___33 *nlsk;
	struct sock___33 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___54 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___52 xfrm4_dst_ops;
	struct dst_ops___52 xfrm6_dst_ops;
};

struct net___53 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___54 sysctls;
	struct sock___33 *rtnl;
	struct sock___33 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___41 *loopback_dev;
	struct netns_core___51 core;
	struct netns_mib mib;
	struct netns_packet___51 packet;
	struct netns_unix___51 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___51 ipv4;
	struct netns_ipv6___52 ipv6;
	struct netns_sctp___51 sctp;
	struct netns_dccp___31 dccp;
	struct netns_nf___51 nf;
	struct netns_xt xt;
	struct netns_ct___51 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___51 nf_frag;
	struct sock___33 *nfnl;
	struct sock___33 *nfnl_stash;
	struct sk_buff_head___40 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___52 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___33 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___33 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___250 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___250 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___39 {
	atomic_t use;
	unsigned int mask;
	struct net_device___41 *physindev;
	struct net_device___41 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___39(struct sk_buff___43 **);

struct iw_handler_def___3;

struct net_device_ops___39;

struct ethtool_ops___39;

struct header_ops___39;

struct in_device___2;

struct inet6_dev___17;

struct netdev_rx_queue___39;

struct netdev_queue___39;

struct Qdisc___3;

struct netpoll_info___2;

struct rtnl_link_ops___31;

struct dcbnl_rtnl_ops___39;

struct net_device___41 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def___3 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___39 *netdev_ops;
	const struct ethtool_ops___39 *ethtool_ops;
	const struct header_ops___39 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___34 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___2 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___17 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___39 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___39 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___39 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___39 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___3 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap___2 *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___39 = 0,
		NETREG_REGISTERED___39 = 1,
		NETREG_UNREGISTERING___39 = 2,
		NETREG_UNREGISTERED___39 = 3,
		NETREG_RELEASED___39 = 4,
		NETREG_DUMMY___39 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___39 = 0,
		RTNL_LINK_INITIALIZING___39 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___41 *);
	struct netpoll_info___2 *npinfo;
	struct net___53 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___246 dev;
	const struct attribute_group___208 *sysfs_groups[4];
	const struct rtnl_link_ops___31 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___39 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___4;

struct sk_buff___43 {
	struct sk_buff___43 *next;
	struct sk_buff___43 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___33 *sk;
	struct net_device___41 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___4 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___43 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___39 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___5 {
	struct {
		struct page___247 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___5 skb_frag_t___5;

struct skb_shared_info___5 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___43 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___5 frags[17];
};

struct xfrm_state___4;

struct sec_path___4 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___4 *xvec[6];
};

struct file_lock___248;

struct file_operations___248 {
	struct module___151 *owner;
	loff_t (*llseek)(struct file___248 *, loff_t, int);
	ssize_t (*read)(struct file___248 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___248 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___39 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___39 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___248 *, void *, filldir_t);
	unsigned int (*poll)(struct file___248 *, struct poll_table_struct___138 *);
	long int (*unlocked_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___248 *, struct vm_area_struct___256 *);
	int (*open)(struct inode___248 *, struct file___248 *);
	int (*flush)(struct file___248 *, fl_owner_t);
	int (*release)(struct inode___248 *, struct file___248 *);
	int (*fsync)(struct file___248 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___39 *, int);
	int (*fasync)(int, struct file___248 *, int);
	int (*lock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*sendpage)(struct file___248 *, struct page___247 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___248 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___248 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___248 *, long int, struct file_lock___248 **, void **);
		struct {
			int (*setlease)(struct file___248 *, long int, struct file_lock___248 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___248 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___173 *, struct file___248 *);
};

struct dev_pm_qos_request___51 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___246 *dev;
};

enum {
	IF_OPER_UNKNOWN = 0,
	IF_OPER_NOTPRESENT = 1,
	IF_OPER_DOWN = 2,
	IF_OPER_LOWERLAYERDOWN = 3,
	IF_OPER_TESTING = 4,
	IF_OPER_DORMANT = 5,
	IF_OPER_UP = 6,
};

struct dentry_operations___248;

struct super_block___248;

struct dentry___248 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___248 *d_parent;
	struct qstr d_name;
	struct inode___248 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___248 *d_op;
	struct super_block___248 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___248;

struct dquot___248;

struct block_device___248;

struct inode___248 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___248 *i_op;
	struct super_block___248 *i_sb;
	struct address_space___248 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___250 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___248 *i_fop;
	struct file_lock___248 *i_flock;
	struct address_space___248 i_data;
	struct dquot___248 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___248 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___248 {
	int (*d_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_hash)(const struct dentry___248 *, struct qstr *);
	int (*d_compare)(const struct dentry___248 *, const struct dentry___248 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___248 *);
	void (*d_release)(struct dentry___248 *);
	void (*d_prune)(struct dentry___248 *);
	void (*d_iput)(struct dentry___248 *, struct inode___248 *);
	char * (*d_dname)(struct dentry___248 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___248 *);
	int (*d_manage)(struct dentry___248 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___248;

struct mem_dqinfo___248 {
	struct quota_format_type___248 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___248;

struct quota_info___248 {
	unsigned int flags;
	struct mutex___250 dqio_mutex;
	struct mutex___250 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___248 *files[2];
	struct mem_dqinfo___248 info[2];
	const struct quota_format_ops___248 *ops[2];
};

struct file_system_type___248;

struct super_operations___248;

struct dquot_operations___248;

struct quotactl_ops___248;

struct xattr_handler___145;

struct super_block___248 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___248 *s_type;
	const struct super_operations___248 *s_op;
	const struct dquot_operations___248 *dq_op;
	const struct quotactl_ops___248 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___248 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___145 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___248 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___248 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___250 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___248 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___248 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___248 *bd_inode;
	struct super_block___248 *bd_super;
	struct mutex___250 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___248 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___250 bd_fsfreeze_mutex;
};

struct cgroup___144;

struct cgroup_subsys_state___144 {
	struct cgroup___144 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___248 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___248 *ia_file;
};

struct dquot___248 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___250 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___248 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___248 {
	int qf_fmt_id;
	const struct quota_format_ops___248 *qf_ops;
	struct module___151 *qf_owner;
	struct quota_format_type___248 *qf_next;
};

struct quota_format_ops___248 {
	int (*check_quota_file)(struct super_block___248 *, int);
	int (*read_file_info)(struct super_block___248 *, int);
	int (*write_file_info)(struct super_block___248 *, int);
	int (*free_file_info)(struct super_block___248 *, int);
	int (*read_dqblk)(struct dquot___248 *);
	int (*commit_dqblk)(struct dquot___248 *);
	int (*release_dqblk)(struct dquot___248 *);
};

struct dquot_operations___248 {
	int (*write_dquot)(struct dquot___248 *);
	struct dquot___248 * (*alloc_dquot)(struct super_block___248 *, int);
	void (*destroy_dquot)(struct dquot___248 *);
	int (*acquire_dquot)(struct dquot___248 *);
	int (*release_dquot)(struct dquot___248 *);
	int (*mark_dirty)(struct dquot___248 *);
	int (*write_info)(struct super_block___248 *, int);
	qsize_t * (*get_reserved_space)(struct inode___248 *);
};

struct quotactl_ops___248 {
	int (*quota_on)(struct super_block___248 *, int, int, struct path___248 *);
	int (*quota_on_meta)(struct super_block___248 *, int, int);
	int (*quota_off)(struct super_block___248 *, int);
	int (*quota_sync)(struct super_block___248 *, int);
	int (*get_info)(struct super_block___248 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___248 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___248 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___248 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___248 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___248 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___248 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___248 *, unsigned int);
};

struct address_space_operations___248 {
	int (*writepage)(struct page___247 *, struct writeback_control *);
	int (*readpage)(struct file___248 *, struct page___247 *);
	int (*writepages)(struct address_space___248 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___247 *);
	int (*readpages)(struct file___248 *, struct address_space___248 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___248 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___247 **, void **);
	int (*write_end)(struct file___248 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___247 *, void *);
	sector_t (*bmap)(struct address_space___248 *, sector_t);
	void (*invalidatepage)(struct page___247 *, long unsigned int);
	int (*releasepage)(struct page___247 *, gfp_t);
	void (*freepage)(struct page___247 *);
	ssize_t (*direct_IO)(int, struct kiocb___39 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___248 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___248 *, struct page___247 *, struct page___247 *, enum migrate_mode);
	int (*launder_page)(struct page___247 *);
	int (*is_partially_uptodate)(struct page___247 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___247 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___248 *, struct page___247 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___248 *, sector_t *);
	void (*swap_deactivate)(struct file___248 *);
	void (*invalidatepage_range)(struct page___247 *, unsigned int, unsigned int);
};

struct inode_operations___248 {
	struct dentry___248 * (*lookup)(struct inode___248 *, struct dentry___248 *, unsigned int);
	void * (*follow_link)(struct dentry___248 *, struct nameidata *);
	int (*permission)(struct inode___248 *, int);
	struct posix_acl * (*get_acl)(struct inode___248 *, int);
	int (*readlink)(struct dentry___248 *, char *, int);
	void (*put_link)(struct dentry___248 *, struct nameidata *, void *);
	int (*create)(struct inode___248 *, struct dentry___248 *, umode_t, bool);
	int (*link)(struct dentry___248 *, struct inode___248 *, struct dentry___248 *);
	int (*unlink)(struct inode___248 *, struct dentry___248 *);
	int (*symlink)(struct inode___248 *, struct dentry___248 *, const char *);
	int (*mkdir)(struct inode___248 *, struct dentry___248 *, umode_t);
	int (*rmdir)(struct inode___248 *, struct dentry___248 *);
	int (*mknod)(struct inode___248 *, struct dentry___248 *, umode_t, dev_t);
	int (*rename)(struct inode___248 *, struct dentry___248 *, struct inode___248 *, struct dentry___248 *);
	int (*setattr)(struct dentry___248 *, struct iattr___248 *);
	int (*getattr)(struct vfsmount *, struct dentry___248 *, struct kstat *);
	int (*setxattr)(struct dentry___248 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___248 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___248 *, char *, size_t);
	int (*removexattr)(struct dentry___248 *, const char *);
	int (*fiemap)(struct inode___248 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___248 *, struct timespec *, int);
	int (*atomic_open)(struct inode___248 *, struct dentry___248 *, struct file___248 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___248;

struct lock_manager_operations___248;

struct file_lock___248 {
	struct file_lock___248 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___248 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___248 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___248 *fl_ops;
	const struct lock_manager_operations___248 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___248 {
	void (*fl_copy_lock)(struct file_lock___248 *, struct file_lock___248 *);
	void (*fl_release_private)(struct file_lock___248 *);
};

struct lock_manager_operations___248 {
	int (*lm_compare_owner)(struct file_lock___248 *, struct file_lock___248 *);
	long unsigned int (*lm_owner_key)(struct file_lock___248 *);
	void (*lm_notify)(struct file_lock___248 *);
	int (*lm_grant)(struct file_lock___248 *, struct file_lock___248 *, int);
	void (*lm_break)(struct file_lock___248 *);
	int (*lm_change)(struct file_lock___248 **, int);
};

struct file_system_type___248 {
	const char *name;
	int fs_flags;
	struct dentry___248 * (*mount)(struct file_system_type___248 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___248 *);
	struct module___151 *owner;
	struct file_system_type___248 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___248 {
	struct inode___248 * (*alloc_inode)(struct super_block___248 *);
	void (*destroy_inode)(struct inode___248 *);
	void (*dirty_inode)(struct inode___248 *, int);
	int (*write_inode)(struct inode___248 *, struct writeback_control *);
	int (*drop_inode)(struct inode___248 *);
	void (*evict_inode)(struct inode___248 *);
	void (*put_super)(struct super_block___248 *);
	int (*sync_fs)(struct super_block___248 *, int);
	int (*freeze_fs)(struct super_block___248 *);
	int (*unfreeze_fs)(struct super_block___248 *);
	int (*statfs)(struct dentry___248 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___248 *, int *, char *);
	void (*umount_begin)(struct super_block___248 *);
	int (*show_options)(struct seq_file___173 *, struct dentry___248 *);
	int (*show_devname)(struct seq_file___173 *, struct dentry___248 *);
	int (*show_path)(struct seq_file___173 *, struct dentry___248 *);
	int (*show_stats)(struct seq_file___173 *, struct dentry___248 *);
	ssize_t (*quota_read)(struct super_block___248 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___248 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___248 *);
	int (*bdev_try_to_free_page)(struct super_block___248 *, struct page___247 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___248 *);
	void (*free_cached_objects)(struct super_block___248 *, int);
};

struct xattr_handler___145 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___248 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___248 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___248 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___39 {
	int (*get_settings)(struct net_device___41 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___41 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___41 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___41 *);
	void (*get_regs)(struct net_device___41 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___41 *);
	void (*set_msglevel)(struct net_device___41 *, u32);
	int (*nway_reset)(struct net_device___41 *);
	u32 (*get_link)(struct net_device___41 *);
	int (*get_eeprom_len)(struct net_device___41 *);
	int (*get_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___41 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___41 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___41 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___41 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___41 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___41 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___41 *);
	void (*complete)(struct net_device___41 *);
	u32 (*get_priv_flags)(struct net_device___41 *);
	int (*set_priv_flags)(struct net_device___41 *, u32);
	int (*get_sset_count)(struct net_device___41 *, int);
	int (*get_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___41 *, struct ethtool_flash *);
	int (*reset)(struct net_device___41 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___41 *);
	int (*get_rxfh_indir)(struct net_device___41 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___41 *, const u32 *);
	void (*get_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___41 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___41 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___41 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___41 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___41 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___41 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___41 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___41 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct ipv4_devconf {
	void *sysctl;
	int data[26];
	long unsigned int state[1];
};

struct rtable___12;

struct dst_entry___31 {
	struct callback_head callback_head;
	struct dst_entry___31 *child;
	struct net_device___41 *dev;
	struct dst_ops___52 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___31 *path;
	struct dst_entry___31 *from;
	struct xfrm_state___4 *xfrm;
	int (*input)(struct sk_buff___43 *);
	union {
		int (*output)(struct sock___33 *, struct sk_buff___43 *);
		struct {
			int (*output)(struct sk_buff___43 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___31 *next;
		struct rtable___12 *rt_next;
		struct rt6_info___4 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___31;

struct neigh_parms___31;

struct neigh_ops___31;

struct neighbour___31 {
	struct neighbour___31 *next;
	struct neigh_table___31 *tbl;
	struct neigh_parms___31 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___40 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___31 *, struct sk_buff___43 *);
	const struct neigh_ops___31 *ops;
	struct callback_head rcu;
	struct net_device___41 *dev;
	u8 primary_key[0];
};

struct fib6_node___4;

struct rt6_info___4 {
	struct dst_entry___31 dst;
	struct fib6_table___4 *rt6i_table;
	struct fib6_node___4 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___17 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___4 {
	struct fib6_node___4 *parent;
	struct fib6_node___4 *left;
	struct fib6_node___4 *right;
	struct rt6_info___4 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___4 *rr_ptr;
};

struct fib6_table___4 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___4 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___52 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___43 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___43 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___53 *, struct dst_entry___31 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___43 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___43 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___173 {
	void * (*start)(struct seq_file___173 *, loff_t *);
	void (*stop)(struct seq_file___173 *, void *);
	void * (*next)(struct seq_file___173 *, void *, loff_t *);
	int (*show)(struct seq_file___173 *, void *);
};

struct pernet_operations___7 {
	struct list_head list;
	int (*init)(struct net___53 *);
	void (*exit)(struct net___53 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___39 {
	int (*ieee_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___41 *);
	u8 (*setstate)(struct net_device___41 *, u8);
	void (*getpermhwaddr)(struct net_device___41 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___41 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___41 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___41 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___41 *, int, u8 *);
	void (*setpfccfg)(struct net_device___41 *, int, u8);
	void (*getpfccfg)(struct net_device___41 *, int, u8 *);
	u8 (*setall)(struct net_device___41 *);
	u8 (*getcap)(struct net_device___41 *, int, u8 *);
	int (*getnumtcs)(struct net_device___41 *, int, u8 *);
	int (*setnumtcs)(struct net_device___41 *, int, u8);
	u8 (*getpfcstate)(struct net_device___41 *);
	void (*setpfcstate)(struct net_device___41 *, u8);
	void (*getbcncfg)(struct net_device___41 *, int, u32 *);
	void (*setbcncfg)(struct net_device___41 *, int, u32);
	void (*getbcnrp)(struct net_device___41 *, int, u8 *);
	void (*setbcnrp)(struct net_device___41 *, int, u8);
	u8 (*setapp)(struct net_device___41 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___41 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___41 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___41 *, int, u8);
	u8 (*getdcbx)(struct net_device___41 *);
	u8 (*setdcbx)(struct net_device___41 *, u8);
	int (*peer_getappinfo)(struct net_device___41 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___41 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___41 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___41 *, struct cee_pfc *);
};

struct cgroupfs_root___144;

struct cgroup___144 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___144 *parent;
	struct dentry___248 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___144 *subsys[11];
	struct cgroupfs_root___144 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___250 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___144 {
	struct super_block___248 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___144 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___83 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___248 *, struct file___248 *);
	ssize_t (*read)(struct cgroup___144 *, struct cftype___83 *, struct file___248 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___144 *, struct cftype___83 *);
	s64 (*read_s64)(struct cgroup___144 *, struct cftype___83 *);
	int (*read_map)(struct cgroup___144 *, struct cftype___83 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___144 *, struct cftype___83 *, struct seq_file___173 *);
	ssize_t (*write)(struct cgroup___144 *, struct cftype___83 *, struct file___248 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___144 *, struct cftype___83 *, u64);
	int (*write_s64)(struct cgroup___144 *, struct cftype___83 *, s64);
	int (*write_string)(struct cgroup___144 *, struct cftype___83 *, const char *);
	int (*trigger)(struct cgroup___144 *, unsigned int);
	int (*release)(struct inode___248 *, struct file___248 *);
	int (*register_event)(struct cgroup___144 *, struct cftype___83 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___144 *, struct cftype___83 *, struct eventfd_ctx *);
};

struct cftype_set___79 {
	struct list_head node;
	struct cftype___83 *cfts;
};

struct task_and_cgroup___79 {
	struct task_struct___249 *task;
	struct cgroup___144 *cgrp;
	struct css_set___144 *cg;
};

struct cgroup_taskset___79 {
	struct task_and_cgroup___79 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___144 *cur_cgrp;
};

struct cgroup_subsys___79 {
	struct cgroup_subsys_state___144 * (*css_alloc)(struct cgroup___144 *);
	int (*css_online)(struct cgroup___144 *);
	void (*css_offline)(struct cgroup___144 *);
	void (*css_free)(struct cgroup___144 *);
	int (*can_attach)(struct cgroup___144 *, struct cgroup_taskset___79 *);
	void (*cancel_attach)(struct cgroup___144 *, struct cgroup_taskset___79 *);
	void (*attach)(struct cgroup___144 *, struct cgroup_taskset___79 *);
	void (*fork)(struct task_struct___249 *);
	void (*exit)(struct cgroup___144 *, struct cgroup___144 *, struct task_struct___249 *);
	void (*bind)(struct cgroup___144 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___144 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___83 *base_cftypes;
	struct cftype_set___79 base_cftset;
	struct module___151 *module;
};

struct request_sock_ops___22;

struct request_sock___23 {
	struct sock_common___31 __req_common;
	struct request_sock___23 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___22 *rsk_ops;
	struct sock___33 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___4;

struct xfrm_type___4;

struct xfrm_mode___4;

struct xfrm_state___4 {
	struct net___53 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___4 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___4 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___4 *type;
	struct xfrm_mode___4 *inner_mode;
	struct xfrm_mode___4 *inner_mode_iaf;
	struct xfrm_mode___4 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___4 {
	struct sk_buff_head___40 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___4 {
	struct net___53 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___4 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___41 {
	struct sk_buff___43 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___43 *, struct netlink_callback___41 *);
	int (*done)(struct netlink_callback___41 *);
	void *data;
	struct module___151 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___39 {
	int (*create)(struct sk_buff___43 *, struct net_device___41 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___43 *, unsigned char *);
	int (*rebuild)(struct sk_buff___43 *);
	int (*cache)(const struct neighbour___31 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___41 *, const unsigned char *);
};

enum netdev_state_t {
	__LINK_STATE_START = 0,
	__LINK_STATE_PRESENT = 1,
	__LINK_STATE_NOCARRIER = 2,
	__LINK_STATE_LINKWATCH_PENDING = 3,
	__LINK_STATE_DORMANT = 4,
};

struct netdev_boot_setup {
	char name[16];
	struct ifmap map;
};

struct napi_struct___39 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___39 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___41 *dev;
	struct sk_buff___43 *gro_list;
	struct sk_buff___43 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

enum {
	NAPI_STATE_SCHED = 0,
	NAPI_STATE_DISABLE = 1,
	NAPI_STATE_NPSVC = 2,
	NAPI_STATE_HASHED = 3,
	NAPI_STATE_EXT = 4,
};

enum gro_result {
	GRO_MERGED = 0,
	GRO_MERGED_FREE = 1,
	GRO_HELD = 2,
	GRO_NORMAL = 3,
	GRO_DROP = 4,
};

typedef enum gro_result gro_result_t;

enum netdev_queue_state_t {
	__QUEUE_STATE_DRV_XOFF = 0,
	__QUEUE_STATE_STACK_XOFF = 1,
	__QUEUE_STATE_FROZEN = 2,
};

struct netdev_queue___39 {
	struct net_device___41 *dev;
	struct Qdisc___3 *qdisc;
	struct Qdisc___3 *qdisc_sleeping;
	struct kobject___34 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___3;

struct Qdisc___3 {
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___3 *);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___3 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___3 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___43 *, struct Qdisc___3 *);
	void *u32_node;
	struct Qdisc___3 *__parent;
	struct netdev_queue___39 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___3 *next_sched;
	struct sk_buff___43 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___40 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___39 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___34 kobj;
	struct net_device___41 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___39 {
	int (*ndo_init)(struct net_device___41 *);
	void (*ndo_uninit)(struct net_device___41 *);
	int (*ndo_open)(struct net_device___41 *);
	int (*ndo_stop)(struct net_device___41 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___43 *, struct net_device___41 *);
	u16 (*ndo_select_queue)(struct net_device___41 *, struct sk_buff___43 *);
	void (*ndo_change_rx_flags)(struct net_device___41 *, int);
	void (*ndo_set_rx_mode)(struct net_device___41 *);
	int (*ndo_set_mac_address)(struct net_device___41 *, void *);
	int (*ndo_validate_addr)(struct net_device___41 *);
	int (*ndo_do_ioctl)(struct net_device___41 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___41 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___41 *, int);
	int (*ndo_neigh_setup)(struct net_device___41 *, struct neigh_parms___31 *);
	void (*ndo_tx_timeout)(struct net_device___41 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___41 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___41 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___41 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___41 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___41 *);
	int (*ndo_netpoll_setup)(struct net_device___41 *, struct netpoll_info___2 *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___41 *);
	int (*ndo_busy_poll)(struct napi_struct___39 *);
	int (*ndo_set_vf_mac)(struct net_device___41 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___41 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___41 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___41 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___41 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___41 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___41 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___41 *, int, struct sk_buff___43 *);
	int (*ndo_setup_tc)(struct net_device___41 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___41 *);
	int (*ndo_fcoe_disable)(struct net_device___41 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___41 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___41 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___41 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___41 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___41 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___41 *, const struct sk_buff___43 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___41 *, struct net_device___41 *);
	int (*ndo_del_slave)(struct net_device___41 *, struct net_device___41 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___31 *);
	void (*ndo_neigh_destroy)(struct neighbour___31 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___43 *, struct netlink_callback___41 *, struct net_device___41 *, int);
	int (*ndo_bridge_setlink)(struct net_device___41 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___43 *, u32, u32, struct net_device___41 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___41 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___41 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___41 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___41 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___41 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___41 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___43 *, struct net_device___41 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___41 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___41 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___41 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___31 {
	struct net___53 *net;
	struct net_device___41 *dev;
	struct neigh_parms___31 *next;
	int (*neigh_setup)(struct neighbour___31 *);
	void (*neigh_cleanup)(struct neighbour___31 *);
	struct neigh_table___31 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct netpoll;

struct netpoll_info___2 {
	atomic_t refcnt;
	long unsigned int rx_flags;
	spinlock_t rx_lock;
	struct semaphore dev_lock;
	struct list_head rx_np;
	struct sk_buff_head___40 neigh_tx;
	struct sk_buff_head___40 txq;
	struct delayed_work tx_work;
	struct netpoll *netpoll;
	struct callback_head rcu;
};

typedef int (*iw_handler___3)(struct net_device___41 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___3 {
	const iw_handler___3 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___3 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___41 *);
};

struct in_ifaddr;

struct ip_mc_list;

struct in_device___2 {
	struct net_device___41 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___31 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___17;

struct ifacaddr6___17;

struct inet6_dev___17 {
	struct net_device___41 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___17 *mc_list;
	struct ifmcaddr6___17 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___17 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___31 *nd_parms;
	struct inet6_dev___17 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___31 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___41 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___53 *, struct net_device___41 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___41 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___41 *, struct list_head *);
	size_t (*get_size)(const struct net_device___41 *);
	int (*fill_info)(struct sk_buff___43 *, const struct net_device___41 *);
	size_t (*get_xstats_size)(const struct net_device___41 *);
	int (*fill_xstats)(struct sk_buff___43 *, const struct net_device___41 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___53 * (*get_link_net)(const struct net_device___41 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___41 *, struct net_device___41 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___41 *, const struct net_device___41 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___43 *, const struct net_device___41 *, const struct net_device___41 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct napi_gro_cb___2 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___43 *last;
};

struct packet_type {
	__be16 type;
	struct net_device___41 *dev;
	int (*func)(struct sk_buff___43 *, struct net_device___41 *, struct packet_type *, struct net_device___41 *);
	bool (*id_match)(struct packet_type *, struct sock___33 *);
	void *af_packet_priv;
	struct list_head list;
};

struct offload_callbacks {
	struct sk_buff___43 * (*gso_segment)(struct sk_buff___43 *, netdev_features_t);
	struct sk_buff___43 ** (*gro_receive)(struct sk_buff___43 **, struct sk_buff___43 *);
	int (*gro_complete)(struct sk_buff___43 *, int);
};

struct packet_offload {
	__be16 type;
	u16 priority;
	struct offload_callbacks callbacks;
	struct list_head list;
};

struct softnet_data {
	struct Qdisc___3 *output_queue;
	struct Qdisc___3 **output_queue_tailp;
	struct list_head poll_list;
	struct sk_buff___43 *completion_queue;
	struct sk_buff_head___40 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int cpu_collision;
	unsigned int received_rps;
	struct softnet_data *rps_ipi_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct call_single_data csd;
	struct softnet_data *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_head;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___40 input_pkt_queue;
	struct napi_struct___39 backlog;
	long: 64;
	long: 64;
};

enum skb_free_reason {
	SKB_REASON_CONSUMED = 0,
	SKB_REASON_DROPPED = 1,
};

struct sk_filter___32 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___43 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___31;

struct neigh_hash_table___31;

struct neigh_table___31 {
	struct neigh_table___31 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___41 *, __u32 *);
	int (*constructor)(struct neighbour___31 *);
	int (*pconstructor)(struct pneigh_entry___31 *);
	void (*pdestructor)(struct pneigh_entry___31 *);
	void (*proxy_redo)(struct sk_buff___43 *);
	char *id;
	struct neigh_parms___31 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___40 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___31 *nht;
	struct pneigh_entry___31 **phash_buckets;
};

struct neigh_ops___31 {
	int family;
	void (*solicit)(struct neighbour___31 *, struct sk_buff___43 *);
	void (*error_report)(struct neighbour___31 *, struct sk_buff___43 *);
	int (*output)(struct neighbour___31 *, struct sk_buff___43 *);
	int (*connected_output)(struct neighbour___31 *, struct sk_buff___43 *);
};

struct pneigh_entry___31 {
	struct pneigh_entry___31 *next;
	struct net___53 *net;
	struct net_device___41 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___31 {
	struct neighbour___31 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___12 {
	struct dst_entry___31 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___20;

struct proto___31 {
	void (*close)(struct sock___33 *, long int);
	int (*connect)(struct sock___33 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___33 *, int);
	struct sock___33 * (*accept)(struct sock___33 *, int, int *);
	int (*ioctl)(struct sock___33 *, int, long unsigned int);
	int (*init)(struct sock___33 *);
	void (*destroy)(struct sock___33 *);
	void (*shutdown)(struct sock___33 *, int);
	int (*setsockopt)(struct sock___33 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___33 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___33 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___33 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___33 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___39 *, struct sock___33 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___39 *, struct sock___33 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___33 *, struct page___247 *, int, size_t, int);
	int (*bind)(struct sock___33 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___33 *, struct sk_buff___43 *);
	void (*release_cb)(struct sock___33 *);
	void (*mtu_reduced)(struct sock___33 *);
	void (*hash)(struct sock___33 *);
	void (*unhash)(struct sock___33 *);
	void (*rehash)(struct sock___33 *);
	int (*get_port)(struct sock___33 *, short unsigned int);
	void (*clear_sk)(struct sock___33 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___33 *);
	void (*enter_memory_pressure)(struct sock___33 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___231 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___22 *rsk_prot;
	struct timewait_sock_ops___20 *twsk_prot;
	union {
		struct inet_hashinfo___2 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___151 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___79 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___31 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___31 {
	void (*enter_memory_pressure)(struct sock___33 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___22 {
	int family;
	int obj_size;
	struct kmem_cache___231 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___33 *, struct request_sock___23 *);
	void (*send_ack)(struct sock___33 *, struct sk_buff___43 *, struct request_sock___23 *);
	void (*send_reset)(struct sock___33 *, struct sk_buff___43 *);
	void (*destructor)(struct request_sock___23 *);
	void (*syn_ack_timeout)(struct sock___33 *, struct request_sock___23 *);
};

struct timewait_sock_ops___20 {
	struct kmem_cache___231 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___33 *, struct sock___33 *, void *);
	void (*twsk_destructor)(struct sock___33 *);
};

struct gnet_dump___4 {
	spinlock_t *lock;
	struct sk_buff___43 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

enum qdisc_state_t {
	__QDISC_STATE_SCHED = 0,
	__QDISC_STATE_DEACTIVATED = 1,
	__QDISC_STATE_THROTTLED = 2,
};

enum qdisc___state_t {
	__QDISC___STATE_RUNNING = 1,
};

struct Qdisc_class_ops___3;

struct Qdisc_ops___3 {
	struct Qdisc_ops___3 *next;
	const struct Qdisc_class_ops___3 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___3 *);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___3 *);
	struct sk_buff___43 * (*peek)(struct Qdisc___3 *);
	unsigned int (*drop)(struct Qdisc___3 *);
	int (*init)(struct Qdisc___3 *, struct nlattr *);
	void (*reset)(struct Qdisc___3 *);
	void (*destroy)(struct Qdisc___3 *);
	int (*change)(struct Qdisc___3 *, struct nlattr *);
	void (*attach)(struct Qdisc___3 *);
	int (*dump)(struct Qdisc___3 *, struct sk_buff___43 *);
	int (*dump_stats)(struct Qdisc___3 *, struct gnet_dump___4 *);
	struct module___151 *owner;
};

struct qdisc_walker___3;

struct tcf_proto___3;

struct Qdisc_class_ops___3 {
	struct netdev_queue___39 * (*select_queue)(struct Qdisc___3 *, struct tcmsg *);
	int (*graft)(struct Qdisc___3 *, long unsigned int, struct Qdisc___3 *, struct Qdisc___3 **);
	struct Qdisc___3 * (*leaf)(struct Qdisc___3 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___3 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___3 *, u32);
	void (*put)(struct Qdisc___3 *, long unsigned int);
	int (*change)(struct Qdisc___3 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___3 *, long unsigned int);
	void (*walk)(struct Qdisc___3 *, struct qdisc_walker___3 *);
	struct tcf_proto___3 ** (*tcf_chain)(struct Qdisc___3 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___3 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___3 *, long unsigned int);
	int (*dump)(struct Qdisc___3 *, long unsigned int, struct sk_buff___43 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___3 *, long unsigned int, struct gnet_dump___4 *);
};

struct qdisc_walker___3 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___3 *, long unsigned int, struct qdisc_walker___3 *);
};

struct tcf_proto_ops___3;

struct tcf_proto___3 {
	struct tcf_proto___3 *next;
	void *root;
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___3 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___3 *q;
	void *data;
	const struct tcf_proto_ops___3 *ops;
};

struct tcf_proto_ops___3 {
	struct tcf_proto_ops___3 *next;
	char kind[16];
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___3 *, struct tcf_result *);
	int (*init)(struct tcf_proto___3 *);
	void (*destroy)(struct tcf_proto___3 *);
	long unsigned int (*get)(struct tcf_proto___3 *, u32);
	void (*put)(struct tcf_proto___3 *, long unsigned int);
	int (*change)(struct net___53 *, struct sk_buff___43 *, struct tcf_proto___3 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___3 *, long unsigned int);
	void (*walk)(struct tcf_proto___3 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___3 *, long unsigned int, struct sk_buff___43 *, struct tcmsg *);
	struct module___151 *owner;
};

struct qdisc_skb_cb {
	unsigned int pkt_len;
	u16 slave_dev_queue_mapping;
	u16 _pad;
	unsigned char data[20];
};

struct ifmcaddr6___17 {
	struct in6_addr mca_addr;
	struct inet6_dev___17 *idev;
	struct ifmcaddr6___17 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___17 {
	struct in6_addr aca_addr;
	struct inet6_dev___17 *aca_idev;
	struct rt6_info___4 *aca_rt;
	struct ifacaddr6___17 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct xfrm_replay___4 {
	void (*advance)(struct xfrm_state___4 *, __be32);
	int (*check)(struct xfrm_state___4 *, struct sk_buff___43 *, __be32);
	int (*recheck)(struct xfrm_state___4 *, struct sk_buff___43 *, __be32);
	void (*notify)(struct xfrm_state___4 *, int);
	int (*overflow)(struct xfrm_state___4 *, struct sk_buff___43 *);
};

struct xfrm_type___4 {
	char *description;
	struct module___151 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___4 *);
	void (*destructor)(struct xfrm_state___4 *);
	int (*input)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*output)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*reject)(struct xfrm_state___4 *, struct sk_buff___43 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___4 *, struct sk_buff___43 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___4 *, int);
};

struct xfrm_state_afinfo___4;

struct xfrm_mode___4 {
	int (*input2)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*input)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*output2)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*output)(struct xfrm_state___4 *, struct sk_buff___43 *);
	struct xfrm_state_afinfo___4 *afinfo;
	struct module___151 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___4 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___151 *owner;
	const struct xfrm_type___4 *type_map[256];
	struct xfrm_mode___4 *mode_map[5];
	int (*init_flags)(struct xfrm_state___4 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___4 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___4 **, struct xfrm_state___4 **, int);
	union {
		int (*output)(struct sock___33 *, struct sk_buff___43 *);
		struct {
			int (*output)(struct sk_buff___43 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___33 *, struct sk_buff___43 *);
		struct {
			int (*output_finish)(struct sk_buff___43 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*extract_output)(struct xfrm_state___4 *, struct sk_buff___43 *);
	int (*transport_finish)(struct sk_buff___43 *, int);
};

struct module_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___149 *, struct module_kobject___149 *, char *);
	ssize_t (*store)(struct module_attribute___149 *, struct module_kobject___149 *, const char *, size_t);
	void (*setup)(struct module___151 *, const char *);
	int (*test)(struct module___151 *);
	void (*free)(struct module___151 *);
};

union inet_addr {
	__u32 all[4];
	__be32 ip;
	__be32 ip6[4];
	struct in_addr in;
	struct in6_addr in6;
};

struct netpoll {
	struct net_device___41 *dev;
	char dev_name[16];
	const char *name;
	void (*rx_hook)(struct netpoll *, int, char *, int);
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct list_head rx;
	struct work_struct cleanup_work;
};

enum {
	IPV4_DEVCONF_FORWARDING = 1,
	IPV4_DEVCONF_MC_FORWARDING = 2,
	IPV4_DEVCONF_PROXY_ARP = 3,
	IPV4_DEVCONF_ACCEPT_REDIRECTS = 4,
	IPV4_DEVCONF_SECURE_REDIRECTS = 5,
	IPV4_DEVCONF_SEND_REDIRECTS = 6,
	IPV4_DEVCONF_SHARED_MEDIA = 7,
	IPV4_DEVCONF_RP_FILTER = 8,
	IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE = 9,
	IPV4_DEVCONF_BOOTP_RELAY = 10,
	IPV4_DEVCONF_LOG_MARTIANS = 11,
	IPV4_DEVCONF_TAG = 12,
	IPV4_DEVCONF_ARPFILTER = 13,
	IPV4_DEVCONF_MEDIUM_ID = 14,
	IPV4_DEVCONF_NOXFRM = 15,
	IPV4_DEVCONF_NOPOLICY = 16,
	IPV4_DEVCONF_FORCE_IGMP_VERSION = 17,
	IPV4_DEVCONF_ARP_ANNOUNCE = 18,
	IPV4_DEVCONF_ARP_IGNORE = 19,
	IPV4_DEVCONF_PROMOTE_SECONDARIES = 20,
	IPV4_DEVCONF_ARP_ACCEPT = 21,
	IPV4_DEVCONF_ARP_NOTIFY = 22,
	IPV4_DEVCONF_ACCEPT_LOCAL = 23,
	IPV4_DEVCONF_SRC_VMARK = 24,
	IPV4_DEVCONF_PROXY_ARP_PVLAN = 25,
	IPV4_DEVCONF_ROUTE_LOCALNET = 26,
	__IPV4_DEVCONF_MAX = 27,
};

struct in_ifaddr {
	struct hlist_node hash;
	struct in_ifaddr *ifa_next;
	struct in_device___2 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct dev_kfree_skb_cb {
	enum skb_free_reason reason;
};

struct netdev_upper {
	struct net_device___41 *dev;
	bool master;
	struct list_head list;
	struct callback_head rcu;
	struct list_head search_list;
};

struct page___248;

typedef struct page___248 *pgtable_t___248;

struct address_space___249;

struct kmem_cache___232;

struct page___248 {
	long unsigned int flags;
	struct address_space___249 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___248 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___248 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___232 *slab_cache;
		struct page___248 *first_page;
	};
	long: 64;
};

struct task_struct___250;

struct pv_cpu_ops___250 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___250 *);
	void (*end_context_switch)(struct task_struct___250 *);
};

struct mutex___251 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___250 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___243 {
	struct page___248 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___257;

struct nsproxy___130;

struct signal_struct___250;

struct css_set___145;

struct task_struct___250 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___250 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___257 *mm;
	struct mm_struct___257 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___250 *real_parent;
	struct task_struct___250 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___250 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___250 = 0,
		VTIME_USER___250 = 1,
		VTIME_SYS___250 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___130 *nsproxy;
	struct signal_struct___250 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___145 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___251 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___243 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___257 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___257 *, struct mm_struct___257 *);
	void (*dup_mmap)(struct mm_struct___257 *, struct mm_struct___257 *);
	void (*exit_mmap)(struct mm_struct___257 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___257 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___257 *);
	void (*pgd_free)(struct mm_struct___257 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___257 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___257 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___257 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___257 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___257 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___257 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___257 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___257 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___257 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___257 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___257 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___251 lock;
	void *vdso;
} mm_context_t___251;

struct xol_area___248;

struct uprobes_state___248 {
	struct xol_area___248 *xol_area;
};

struct vm_area_struct___257;

struct file___249;

struct core_state___250;

struct mm_struct___257 {
	struct vm_area_struct___257 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___257 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___257 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___251 context;
	long unsigned int flags;
	struct core_state___250 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___250 *owner;
	struct file___249 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___248 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___152;

struct exec_domain___71 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___152 *module;
	struct exec_domain___71 *next;
};

struct module_kobject___150 {
	struct kobject___34 kobj;
	struct module___152 *mod;
	struct kobject___34 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___150;

struct module___152 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___150 mkobj;
	struct module_attribute___150 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___34 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___250 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___116 {
	struct task_struct___250 *task;
	struct exec_domain___71 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___250;

struct lruvec___250 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___250 *zone;
};

struct pglist_data___250;

struct zone___250 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___250 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___250 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___250 {
	struct zone___250 *zone;
	int zone_idx;
};

struct zonelist___250 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___250 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___250 {
	struct zone___250 node_zones[4];
	struct zonelist___250 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___250 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___173;

struct x86_io_apic_ops___173 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___173 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___173;

struct irq_data___173 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___173 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___247;

struct dev_pm_ops___247 {
	int (*prepare)(struct device___247 *);
	void (*complete)(struct device___247 *);
	int (*suspend)(struct device___247 *);
	int (*resume)(struct device___247 *);
	int (*freeze)(struct device___247 *);
	int (*thaw)(struct device___247 *);
	int (*poweroff)(struct device___247 *);
	int (*restore)(struct device___247 *);
	int (*suspend_late)(struct device___247 *);
	int (*resume_early)(struct device___247 *);
	int (*freeze_late)(struct device___247 *);
	int (*thaw_early)(struct device___247 *);
	int (*poweroff_late)(struct device___247 *);
	int (*restore_early)(struct device___247 *);
	int (*suspend_noirq)(struct device___247 *);
	int (*resume_noirq)(struct device___247 *);
	int (*freeze_noirq)(struct device___247 *);
	int (*thaw_noirq)(struct device___247 *);
	int (*poweroff_noirq)(struct device___247 *);
	int (*restore_noirq)(struct device___247 *);
	int (*runtime_suspend)(struct device___247 *);
	int (*runtime_resume)(struct device___247 *);
	int (*runtime_idle)(struct device___247 *);
};

struct dev_pm_qos___51;

struct dev_pm_info___51 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___51 *qos;
};

struct dma_map_ops___112;

struct dev_archdata___112 {
	struct dma_map_ops___112 *dma_ops;
	void *iommu;
};

struct device_type___247;

struct bus_type___247;

struct device_driver___247;

struct dev_pm_domain___247;

struct class___247;

struct attribute_group___209;

struct device_rh___247;

struct device___247 {
	struct device___247 *parent;
	struct device_private *p;
	struct kobject___34 kobj;
	const char *init_name;
	const struct device_type___247 *type;
	struct mutex___251 mutex;
	struct bus_type___247 *bus;
	struct device_driver___247 *driver;
	void *platform_data;
	struct dev_pm_info___51 power;
	struct dev_pm_domain___247 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___112 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___247 *class;
	const struct attribute_group___209 **groups;
	void (*release)(struct device___247 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___247 *device_rh;
};

struct dev_pm_qos_request___52;

struct dev_pm_qos___51 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___52 *latency_req;
	struct dev_pm_qos_request___52 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___52 *latency_tolerance_req;
};

struct dev_pm_info_rh___247 {
	void (*set_latency_tolerance)(struct device___247 *, s32);
};

struct dev_pm_domain___247 {
	struct dev_pm_ops___247 ops;
};

struct smp_ops___250 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___250 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___55;

struct ctl_node___55 {
	struct rb_node node;
	struct ctl_table_header___55 *header;
};

struct ctl_table_root___55;

struct ctl_table_set___55;

struct ctl_dir___55;

struct ctl_table_header___55 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___55 *root;
	struct ctl_table_set___55 *set;
	struct ctl_dir___55 *parent;
	struct ctl_node___55 *node;
};

struct ctl_dir___55 {
	struct ctl_table_header___55 header;
	struct rb_root root;
};

struct ctl_table_set___55 {
	int (*is_seen)(struct ctl_table_set___55 *);
	struct ctl_dir___55 dir;
};

struct ctl_table_root___55 {
	struct ctl_table_set___55 default_set;
	struct ctl_table_set___55 * (*lookup)(struct ctl_table_root___55 *, struct nsproxy___130 *);
	int (*permissions)(struct ctl_table_header___55 *, struct ctl_table *);
};

struct net___54;

struct nsproxy___130 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___54 *net_ns;
};

struct bin_attribute___211;

struct attribute_group___209 {
	const char *name;
	umode_t (*is_visible)(struct kobject___34 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___211 **bin_attrs;
};

struct bin_attribute___211 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___249 *, struct kobject___34 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___249 *, struct kobject___34 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	int (*mmap)(struct file___249 *, struct kobject___34 *, struct bin_attribute___211 *, struct vm_area_struct___257 *);
};

struct dentry___249;

struct path___249 {
	struct vfsmount *mnt;
	struct dentry___249 *dentry;
};

struct inode___249;

struct file_operations___249;

struct file___249 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___249 f_path;
	struct inode___249 *f_inode;
	const struct file_operations___249 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___249 *f_mapping;
	struct mutex___251 f_pos_lock;
};

struct vm_operations_struct___223;

struct vm_area_struct___257 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___257 *vm_next;
	struct vm_area_struct___257 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___257 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___223 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___249 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___150 *, struct module_kobject___150 *, char *);
	ssize_t (*store)(struct module_attribute___150 *, struct module_kobject___150 *, const char *, size_t);
	void (*setup)(struct module___152 *, const char *);
	int (*test)(struct module___152 *);
	void (*free)(struct module___152 *);
};

struct dentry_operations___249;

struct super_block___249;

struct dentry___249 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___249 *d_parent;
	struct qstr d_name;
	struct inode___249 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___249 *d_op;
	struct super_block___249 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___249;

struct address_space___249 {
	struct inode___249 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___251 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___249 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___249;

struct file_lock___249;

struct dquot___249;

struct block_device___249;

struct inode___249 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___249 *i_op;
	struct super_block___249 *i_sb;
	struct address_space___249 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___251 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___249 *i_fop;
	struct file_lock___249 *i_flock;
	struct address_space___249 i_data;
	struct dquot___249 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___249 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___249 {
	int (*d_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_hash)(const struct dentry___249 *, struct qstr *);
	int (*d_compare)(const struct dentry___249 *, const struct dentry___249 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___249 *);
	void (*d_release)(struct dentry___249 *);
	void (*d_prune)(struct dentry___249 *);
	void (*d_iput)(struct dentry___249 *, struct inode___249 *);
	char * (*d_dname)(struct dentry___249 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___249 *);
	int (*d_manage)(struct dentry___249 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___249;

struct mem_dqinfo___249 {
	struct quota_format_type___249 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___249;

struct quota_info___249 {
	unsigned int flags;
	struct mutex___251 dqio_mutex;
	struct mutex___251 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___249 *files[2];
	struct mem_dqinfo___249 info[2];
	const struct quota_format_ops___249 *ops[2];
};

struct file_system_type___249;

struct super_operations___249;

struct dquot_operations___249;

struct quotactl_ops___249;

struct xattr_handler___146;

struct super_block___249 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___249 *s_type;
	const struct super_operations___249 *s_op;
	const struct dquot_operations___249 *dq_op;
	const struct quotactl_ops___249 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___249 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___146 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___249 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___249 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___251 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___249 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___249 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___249 *bd_inode;
	struct super_block___249 *bd_super;
	struct mutex___251 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___249 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___251 bd_fsfreeze_mutex;
};

struct cgroup___145;

struct cgroup_subsys_state___145 {
	struct cgroup___145 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___249 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___249 *ia_file;
};

struct dquot___249 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___251 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___249 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___249 {
	int qf_fmt_id;
	const struct quota_format_ops___249 *qf_ops;
	struct module___152 *qf_owner;
	struct quota_format_type___249 *qf_next;
};

struct quota_format_ops___249 {
	int (*check_quota_file)(struct super_block___249 *, int);
	int (*read_file_info)(struct super_block___249 *, int);
	int (*write_file_info)(struct super_block___249 *, int);
	int (*free_file_info)(struct super_block___249 *, int);
	int (*read_dqblk)(struct dquot___249 *);
	int (*commit_dqblk)(struct dquot___249 *);
	int (*release_dqblk)(struct dquot___249 *);
};

struct dquot_operations___249 {
	int (*write_dquot)(struct dquot___249 *);
	struct dquot___249 * (*alloc_dquot)(struct super_block___249 *, int);
	void (*destroy_dquot)(struct dquot___249 *);
	int (*acquire_dquot)(struct dquot___249 *);
	int (*release_dquot)(struct dquot___249 *);
	int (*mark_dirty)(struct dquot___249 *);
	int (*write_info)(struct super_block___249 *, int);
	qsize_t * (*get_reserved_space)(struct inode___249 *);
};

struct quotactl_ops___249 {
	int (*quota_on)(struct super_block___249 *, int, int, struct path___249 *);
	int (*quota_on_meta)(struct super_block___249 *, int, int);
	int (*quota_off)(struct super_block___249 *, int);
	int (*quota_sync)(struct super_block___249 *, int);
	int (*get_info)(struct super_block___249 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___249 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___249 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___249 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___249 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___249 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___249 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___249 *, unsigned int);
};

struct address_space_operations___249 {
	int (*writepage)(struct page___248 *, struct writeback_control *);
	int (*readpage)(struct file___249 *, struct page___248 *);
	int (*writepages)(struct address_space___249 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___248 *);
	int (*readpages)(struct file___249 *, struct address_space___249 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___249 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___248 **, void **);
	int (*write_end)(struct file___249 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___248 *, void *);
	sector_t (*bmap)(struct address_space___249 *, sector_t);
	void (*invalidatepage)(struct page___248 *, long unsigned int);
	int (*releasepage)(struct page___248 *, gfp_t);
	void (*freepage)(struct page___248 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___249 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___249 *, struct page___248 *, struct page___248 *, enum migrate_mode);
	int (*launder_page)(struct page___248 *);
	int (*is_partially_uptodate)(struct page___248 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___248 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___249 *, struct page___248 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___249 *, sector_t *);
	void (*swap_deactivate)(struct file___249 *);
	void (*invalidatepage_range)(struct page___248 *, unsigned int, unsigned int);
};

struct inode_operations___249 {
	struct dentry___249 * (*lookup)(struct inode___249 *, struct dentry___249 *, unsigned int);
	void * (*follow_link)(struct dentry___249 *, struct nameidata *);
	int (*permission)(struct inode___249 *, int);
	struct posix_acl * (*get_acl)(struct inode___249 *, int);
	int (*readlink)(struct dentry___249 *, char *, int);
	void (*put_link)(struct dentry___249 *, struct nameidata *, void *);
	int (*create)(struct inode___249 *, struct dentry___249 *, umode_t, bool);
	int (*link)(struct dentry___249 *, struct inode___249 *, struct dentry___249 *);
	int (*unlink)(struct inode___249 *, struct dentry___249 *);
	int (*symlink)(struct inode___249 *, struct dentry___249 *, const char *);
	int (*mkdir)(struct inode___249 *, struct dentry___249 *, umode_t);
	int (*rmdir)(struct inode___249 *, struct dentry___249 *);
	int (*mknod)(struct inode___249 *, struct dentry___249 *, umode_t, dev_t);
	int (*rename)(struct inode___249 *, struct dentry___249 *, struct inode___249 *, struct dentry___249 *);
	int (*setattr)(struct dentry___249 *, struct iattr___249 *);
	int (*getattr)(struct vfsmount *, struct dentry___249 *, struct kstat *);
	int (*setxattr)(struct dentry___249 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___249 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___249 *, char *, size_t);
	int (*removexattr)(struct dentry___249 *, const char *);
	int (*fiemap)(struct inode___249 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___249 *, struct timespec *, int);
	int (*atomic_open)(struct inode___249 *, struct dentry___249 *, struct file___249 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___174;

struct file_operations___249 {
	struct module___152 *owner;
	loff_t (*llseek)(struct file___249 *, loff_t, int);
	ssize_t (*read)(struct file___249 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___249 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___249 *, void *, filldir_t);
	unsigned int (*poll)(struct file___249 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___249 *, struct vm_area_struct___257 *);
	int (*open)(struct inode___249 *, struct file___249 *);
	int (*flush)(struct file___249 *, fl_owner_t);
	int (*release)(struct inode___249 *, struct file___249 *);
	int (*fsync)(struct file___249 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___249 *, int);
	int (*lock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*sendpage)(struct file___249 *, struct page___248 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___249 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___249 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___249 *, long int, struct file_lock___249 **, void **);
		struct {
			int (*setlease)(struct file___249 *, long int, struct file_lock___249 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___249 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___174 *, struct file___249 *);
};

struct fasync_struct___249;

struct file_lock_operations___249;

struct lock_manager_operations___249;

struct file_lock___249 {
	struct file_lock___249 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___249 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___249 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___249 *fl_ops;
	const struct lock_manager_operations___249 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___249 {
	void (*fl_copy_lock)(struct file_lock___249 *, struct file_lock___249 *);
	void (*fl_release_private)(struct file_lock___249 *);
};

struct lock_manager_operations___249 {
	int (*lm_compare_owner)(struct file_lock___249 *, struct file_lock___249 *);
	long unsigned int (*lm_owner_key)(struct file_lock___249 *);
	void (*lm_notify)(struct file_lock___249 *);
	int (*lm_grant)(struct file_lock___249 *, struct file_lock___249 *, int);
	void (*lm_break)(struct file_lock___249 *);
	int (*lm_change)(struct file_lock___249 **, int);
};

struct fasync_struct___249 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___249 *fa_next;
	struct file___249 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___249 {
	const char *name;
	int fs_flags;
	struct dentry___249 * (*mount)(struct file_system_type___249 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___249 *);
	struct module___152 *owner;
	struct file_system_type___249 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___249 {
	struct inode___249 * (*alloc_inode)(struct super_block___249 *);
	void (*destroy_inode)(struct inode___249 *);
	void (*dirty_inode)(struct inode___249 *, int);
	int (*write_inode)(struct inode___249 *, struct writeback_control *);
	int (*drop_inode)(struct inode___249 *);
	void (*evict_inode)(struct inode___249 *);
	void (*put_super)(struct super_block___249 *);
	int (*sync_fs)(struct super_block___249 *, int);
	int (*freeze_fs)(struct super_block___249 *);
	int (*unfreeze_fs)(struct super_block___249 *);
	int (*statfs)(struct dentry___249 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___249 *, int *, char *);
	void (*umount_begin)(struct super_block___249 *);
	int (*show_options)(struct seq_file___174 *, struct dentry___249 *);
	int (*show_devname)(struct seq_file___174 *, struct dentry___249 *);
	int (*show_path)(struct seq_file___174 *, struct dentry___249 *);
	int (*show_stats)(struct seq_file___174 *, struct dentry___249 *);
	ssize_t (*quota_read)(struct super_block___249 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___249 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___249 *);
	int (*bdev_try_to_free_page)(struct super_block___249 *, struct page___248 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___249 *);
	void (*free_cached_objects)(struct super_block___249 *, int);
};

struct xattr_handler___146 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___249 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___249 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___249 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___174;

struct seq_file___174 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___251 lock;
	const struct seq_operations___174 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___248 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___248 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___231;

struct memcg_cache_params___232;

struct kmem_cache___232 {
	struct kmem_cache_cpu___231 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___34 kobj;
	struct memcg_cache_params___232 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___219;

struct vm_operations_struct___223 {
	void (*open)(struct vm_area_struct___257 *);
	void (*close)(struct vm_area_struct___257 *);
	int (*fault)(struct vm_area_struct___257 *, struct vm_fault___219 *);
	int (*page_mkwrite)(struct vm_area_struct___257 *, struct vm_fault___219 *);
	int (*access)(struct vm_area_struct___257 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___257 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___257 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___257 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___257 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___250 {
	struct task_struct___250 *task;
	struct core_thread___250 *next;
};

struct core_state___250 {
	atomic_t nr_threads;
	struct core_thread___250 dumper;
	struct completion startup;
};

struct signal_struct___250 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___250 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___250 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___251 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___145 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___145 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___52 {
	struct ctl_table_header___55 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___52 {
	struct mutex___251 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___52 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___55 *ctl;
};

struct netns_ipv4___52 {
	struct ctl_table_header___55 *forw_hdr;
	struct ctl_table_header___55 *frags_hdr;
	struct ctl_table_header___55 *ipv4_hdr;
	struct ctl_table_header___55 *route_hdr;
	struct ctl_table_header___55 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___52 {
	struct ctl_table_header___55 *hdr;
	struct ctl_table_header___55 *route_hdr;
	struct ctl_table_header___55 *icmp_hdr;
	struct ctl_table_header___55 *frags_hdr;
	struct ctl_table_header___55 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___42;

struct sk_buff___44;

struct dst_ops___53 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___53 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___42 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___44 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___44 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___44 *);
	int (*local_out)(struct sk_buff___44 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___44 *, const void *);
	struct kmem_cache___232 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___53 {
	struct netns_sysctl_ipv6___52 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___53 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___52 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___55 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___52 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___55 *nf_log_dir_header;
};

struct nf_proto_net___52 {
	struct ctl_table_header___55 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___52 {
	struct nf_proto_net___52 pn;
	unsigned int timeout;
};

struct nf_tcp_net___52 {
	struct nf_proto_net___52 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___52 {
	struct nf_proto_net___52 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___52 {
	struct nf_proto_net___52 pn;
	unsigned int timeout;
};

struct nf_ip_net___52 {
	struct nf_generic_net___52 generic;
	struct nf_tcp_net___52 tcp;
	struct nf_udp_net___52 udp;
	struct nf_icmp_net___52 icmp;
	struct nf_icmp_net___52 icmpv6;
};

struct netns_ct___52 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___55 *sysctl_header;
	struct ctl_table_header___55 *acct_sysctl_header;
	struct ctl_table_header___55 *tstamp_sysctl_header;
	struct ctl_table_header___55 *event_sysctl_header;
	struct ctl_table_header___55 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___232 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___52 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___52 {
	struct netns_sysctl_ipv6___52 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___41 {
	struct sk_buff___44 *next;
	struct sk_buff___44 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___53 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___55 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___53 xfrm4_dst_ops;
	struct dst_ops___53 xfrm6_dst_ops;
};

struct net___54 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___55 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___42 *loopback_dev;
	struct netns_core___52 core;
	struct netns_mib mib;
	struct netns_packet___52 packet;
	struct netns_unix___52 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___52 ipv4;
	struct netns_ipv6___53 ipv6;
	struct netns_sctp___52 sctp;
	struct netns_dccp___31 dccp;
	struct netns_nf___52 nf;
	struct netns_xt xt;
	struct netns_ct___52 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___52 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___41 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___53 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___251 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___251 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___231 {
	void **freelist;
	long unsigned int tid;
	struct page___248 *page;
	struct page___248 *partial;
};

struct memcg_cache_params___232 {
	bool is_root_cache;
	union {
		struct kmem_cache___232 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___232 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___112 {
	void * (*alloc)(struct device___247 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___247 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___247 *, struct vm_area_struct___257 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___247 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___247 *, struct page___248 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___247 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___247 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___247 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___247 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___247 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___247 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___247 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___247 *, dma_addr_t);
	int (*dma_supported)(struct device___247 *, u64);
	int (*set_dma_mask)(struct device___247 *, u64);
	int is_phys;
};

struct bus_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___247 *, char *);
	ssize_t (*store)(struct bus_type___247 *, const char *, size_t);
};

struct device_attribute___247;

struct driver_attribute___247;

struct bus_type___247 {
	const char *name;
	const char *dev_name;
	struct device___247 *dev_root;
	struct bus_attribute___247 *bus_attrs;
	struct device_attribute___247 *dev_attrs;
	struct driver_attribute___247 *drv_attrs;
	const struct attribute_group___209 **bus_groups;
	const struct attribute_group___209 **dev_groups;
	const struct attribute_group___209 **drv_groups;
	int (*match)(struct device___247 *, struct device_driver___247 *);
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	int (*probe)(struct device___247 *);
	int (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*online)(struct device___247 *);
	int (*offline)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct device___247 *, struct device_attribute___247 *, char *);
	ssize_t (*store)(struct device___247 *, struct device_attribute___247 *, const char *, size_t);
};

struct driver_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___247 *, char *);
	ssize_t (*store)(struct device_driver___247 *, const char *, size_t);
};

struct device_driver___247 {
	const char *name;
	struct bus_type___247 *bus;
	struct module___152 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___247 *);
	int (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	const struct attribute_group___209 **groups;
	const struct dev_pm_ops___247 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___247 {
	const char *name;
	const struct attribute_group___209 **groups;
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
};

struct class_attribute___247;

struct class___247 {
	const char *name;
	struct module___152 *owner;
	struct class_attribute___247 *class_attrs;
	struct device_attribute___247 *dev_attrs;
	const struct attribute_group___209 **dev_groups;
	struct bin_attribute___211 *dev_bin_attrs;
	struct kobject___34 *dev_kobj;
	int (*dev_uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *);
	void (*class_release)(struct class___247 *);
	void (*dev_release)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	const struct kobj_ns_type_operations___31 *ns_type;
	const void * (*namespace)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
	struct subsys_private *p;
};

struct class_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct class___247 *, struct class_attribute___247 *, char *);
	ssize_t (*store)(struct class___247 *, struct class_attribute___247 *, const char *, size_t);
	const void * (*namespace)(struct class___247 *, const struct class_attribute___247 *);
};

struct device_rh___247 {
	struct dev_pm_info_rh___247 power;
};

struct vm_fault___219 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___248 *page;
};

struct nf_bridge_info___40 {
	atomic_t use;
	unsigned int mask;
	struct net_device___42 *physindev;
	struct net_device___42 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___40(struct sk_buff___44 **);

struct net_device_ops___40;

struct ethtool_ops___40;

struct header_ops___40;

struct netdev_rx_queue___40;

struct netdev_queue___40;

struct dcbnl_rtnl_ops___40;

struct phy_device___4;

struct net_device___42 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___40 *netdev_ops;
	const struct ethtool_ops___40 *ethtool_ops;
	const struct header_ops___40 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___34 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___40 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___40 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___40 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___40 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___40 = 0,
		NETREG_REGISTERED___40 = 1,
		NETREG_UNREGISTERING___40 = 2,
		NETREG_UNREGISTERED___40 = 3,
		NETREG_RELEASED___40 = 4,
		NETREG_DUMMY___40 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___40 = 0,
		RTNL_LINK_INITIALIZING___40 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___42 *);
	struct netpoll_info *npinfo;
	struct net___54 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___247 dev;
	const struct attribute_group___209 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___40 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___4 *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___44 {
	struct sk_buff___44 *next;
	struct sk_buff___44 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___42 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___44 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___40 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_value {
	__u32 cmd;
	__u32 data;
};

enum ethtool_stringset {
	ETH_SS_TEST = 0,
	ETH_SS_STATS = 1,
	ETH_SS_PRIV_FLAGS = 2,
	ETH_SS_NTUPLE_FILTERS = 3,
	ETH_SS_FEATURES = 4,
	ETH_SS_RSS_HASH_FUNCS = 5,
};

struct ethtool_gstrings {
	__u32 cmd;
	__u32 string_set;
	__u32 len;
	__u8 data[0];
};

struct ethtool_sset_info {
	__u32 cmd;
	__u32 reserved;
	__u64 sset_mask;
	__u32 data[0];
};

struct ethtool_perm_addr {
	__u32 cmd;
	__u32 size;
	__u8 data[0];
};

enum ethtool_flags {
	ETH_FLAG_TXVLAN = 128,
	ETH_FLAG_RXVLAN = 256,
	ETH_FLAG_LRO = 32768,
	ETH_FLAG_NTUPLE = 134217728,
	ETH_FLAG_RXHASH = 268435456,
};

struct ethtool_rxfh {
	__u32 cmd;
	__u32 rss_context;
	__u32 indir_size;
	__u32 key_size;
	__u8 hfunc;
	__u8 rsvd8[3];
	__u32 rsvd32;
	__u32 rss_config[0];
};

struct ethtool_get_features_block {
	__u32 available;
	__u32 requested;
	__u32 active;
	__u32 never_changed;
};

struct ethtool_gfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_get_features_block features[0];
};

struct ethtool_set_features_block {
	__u32 valid;
	__u32 requested;
};

struct ethtool_sfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_set_features_block features[0];
};

enum ethtool_sfeatures_retval_bits {
	ETHTOOL_F_UNSUPPORTED__BIT = 0,
	ETHTOOL_F_WISH__BIT = 1,
	ETHTOOL_F_COMPAT__BIT = 2,
};

enum {
	ETH_RSS_HASH_TOP_BIT = 0,
	ETH_RSS_HASH_XOR_BIT = 1,
	ETH_RSS_HASH_FUNCS_COUNT = 2,
};

struct ethtool_ops___40 {
	int (*get_settings)(struct net_device___42 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___42 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___42 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___42 *);
	void (*get_regs)(struct net_device___42 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___42 *);
	void (*set_msglevel)(struct net_device___42 *, u32);
	int (*nway_reset)(struct net_device___42 *);
	u32 (*get_link)(struct net_device___42 *);
	int (*get_eeprom_len)(struct net_device___42 *);
	int (*get_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___42 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___42 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___42 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___42 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___42 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___42 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___42 *);
	void (*complete)(struct net_device___42 *);
	u32 (*get_priv_flags)(struct net_device___42 *);
	int (*set_priv_flags)(struct net_device___42 *, u32);
	int (*get_sset_count)(struct net_device___42 *, int);
	int (*get_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___42 *, struct ethtool_flash *);
	int (*reset)(struct net_device___42 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___42 *);
	int (*get_rxfh_indir)(struct net_device___42 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___42 *, const u32 *);
	void (*get_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___42 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___42 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___42 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___42 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___42 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___42 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___42 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___42 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dev_pm_qos_request___52 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___247 *dev;
};

struct nf_afinfo___53 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___44 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___44 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___54 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___44 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___44 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___173 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___173 *);
	void (*irq_shutdown)(struct irq_data___173 *);
	void (*irq_enable)(struct irq_data___173 *);
	void (*irq_disable)(struct irq_data___173 *);
	void (*irq_ack)(struct irq_data___173 *);
	void (*irq_mask)(struct irq_data___173 *);
	void (*irq_mask_ack)(struct irq_data___173 *);
	void (*irq_unmask)(struct irq_data___173 *);
	void (*irq_eoi)(struct irq_data___173 *);
	int (*irq_set_affinity)(struct irq_data___173 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___173 *);
	int (*irq_set_type)(struct irq_data___173 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___173 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___173 *);
	void (*irq_bus_sync_unlock)(struct irq_data___173 *);
	void (*irq_cpu_online)(struct irq_data___173 *);
	void (*irq_cpu_offline)(struct irq_data___173 *);
	void (*irq_suspend)(struct irq_data___173 *);
	void (*irq_resume)(struct irq_data___173 *);
	void (*irq_pm_shutdown)(struct irq_data___173 *);
	void (*irq_print_chip)(struct irq_data___173 *, struct seq_file___174 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___173 *, void *);
	long unsigned int flags;
};

struct seq_operations___174 {
	void * (*start)(struct seq_file___174 *, loff_t *);
	void (*stop)(struct seq_file___174 *, void *);
	void * (*next)(struct seq_file___174 *, void *, loff_t *);
	int (*show)(struct seq_file___174 *, void *);
};

struct mii_bus___4 {
	const char *name;
	char id[17];
	void *priv;
	int (*read)(struct mii_bus___4 *, int, int);
	int (*write)(struct mii_bus___4 *, int, int, u16);
	int (*reset)(struct mii_bus___4 *);
	struct mutex___251 mdio_lock;
	struct device___247 *parent;
	enum {
		MDIOBUS_ALLOCATED___4 = 1,
		MDIOBUS_REGISTERED___4 = 2,
		MDIOBUS_UNREGISTERED___4 = 3,
		MDIOBUS_RELEASED___4 = 4,
	} state;
	struct device___247 dev;
	struct phy_device___4 *phy_map[32];
	u32 phy_mask;
	int *irq;
};

struct dcbnl_rtnl_ops___40 {
	int (*ieee_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___42 *);
	u8 (*setstate)(struct net_device___42 *, u8);
	void (*getpermhwaddr)(struct net_device___42 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___42 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___42 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___42 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___42 *, int, u8 *);
	void (*setpfccfg)(struct net_device___42 *, int, u8);
	void (*getpfccfg)(struct net_device___42 *, int, u8 *);
	u8 (*setall)(struct net_device___42 *);
	u8 (*getcap)(struct net_device___42 *, int, u8 *);
	int (*getnumtcs)(struct net_device___42 *, int, u8 *);
	int (*setnumtcs)(struct net_device___42 *, int, u8);
	u8 (*getpfcstate)(struct net_device___42 *);
	void (*setpfcstate)(struct net_device___42 *, u8);
	void (*getbcncfg)(struct net_device___42 *, int, u32 *);
	void (*setbcncfg)(struct net_device___42 *, int, u32);
	void (*getbcnrp)(struct net_device___42 *, int, u8 *);
	void (*setbcnrp)(struct net_device___42 *, int, u8);
	u8 (*setapp)(struct net_device___42 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___42 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___42 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___42 *, int, u8);
	u8 (*getdcbx)(struct net_device___42 *);
	u8 (*setdcbx)(struct net_device___42 *, u8);
	int (*peer_getappinfo)(struct net_device___42 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___42 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___42 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___42 *, struct cee_pfc *);
};

struct cgroupfs_root___145;

struct cgroup___145 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___145 *parent;
	struct dentry___249 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___145 *subsys[11];
	struct cgroupfs_root___145 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___251 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___145 {
	struct super_block___249 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___145 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___42 {
	struct sk_buff___44 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___44 *, struct netlink_callback___42 *);
	int (*done)(struct netlink_callback___42 *);
	void *data;
	struct module___152 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___40 {
	int (*create)(struct sk_buff___44 *, struct net_device___42 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___44 *, unsigned char *);
	int (*rebuild)(struct sk_buff___44 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___42 *, const unsigned char *);
};

struct napi_struct___40 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___40 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___42 *dev;
	struct sk_buff___44 *gro_list;
	struct sk_buff___44 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___40 {
	struct net_device___42 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___34 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___40 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___34 kobj;
	struct net_device___42 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___40 {
	int (*ndo_init)(struct net_device___42 *);
	void (*ndo_uninit)(struct net_device___42 *);
	int (*ndo_open)(struct net_device___42 *);
	int (*ndo_stop)(struct net_device___42 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___44 *, struct net_device___42 *);
	u16 (*ndo_select_queue)(struct net_device___42 *, struct sk_buff___44 *);
	void (*ndo_change_rx_flags)(struct net_device___42 *, int);
	void (*ndo_set_rx_mode)(struct net_device___42 *);
	int (*ndo_set_mac_address)(struct net_device___42 *, void *);
	int (*ndo_validate_addr)(struct net_device___42 *);
	int (*ndo_do_ioctl)(struct net_device___42 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___42 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___42 *, int);
	int (*ndo_neigh_setup)(struct net_device___42 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___42 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___42 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___42 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___42 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___42 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___42 *);
	int (*ndo_netpoll_setup)(struct net_device___42 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___42 *);
	int (*ndo_busy_poll)(struct napi_struct___40 *);
	int (*ndo_set_vf_mac)(struct net_device___42 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___42 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___42 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___42 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___42 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___42 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___42 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___42 *, int, struct sk_buff___44 *);
	int (*ndo_setup_tc)(struct net_device___42 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___42 *);
	int (*ndo_fcoe_disable)(struct net_device___42 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___42 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___42 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___42 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___42 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___42 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___42 *, const struct sk_buff___44 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___42 *, struct net_device___42 *);
	int (*ndo_del_slave)(struct net_device___42 *, struct net_device___42 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___44 *, struct netlink_callback___42 *, struct net_device___42 *, int);
	int (*ndo_bridge_setlink)(struct net_device___42 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___44 *, u32, u32, struct net_device___42 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___42 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___42 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___42 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___42 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___42 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___42 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___44 *, struct net_device___42 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___42 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___42 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___42 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct phy_driver___4;

struct phy_device___4 {
	struct phy_driver___4 *drv;
	struct mii_bus___4 *bus;
	struct device___247 dev;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	bool is_c45;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int addr;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	int link;
	u32 interrupts;
	u32 supported;
	u32 advertising;
	int autoneg;
	int link_timeout;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	atomic_t irq_disable;
	struct mutex___251 lock;
	struct net_device___42 *attached_dev;
	void (*adjust_link)(struct net_device___42 *);
	void (*adjust_state)(struct net_device___42 *);
};

struct phy_driver___4 {
	u32 phy_id;
	char *name;
	unsigned int phy_id_mask;
	u32 features;
	u32 flags;
	int (*config_init)(struct phy_device___4 *);
	int (*probe)(struct phy_device___4 *);
	int (*suspend)(struct phy_device___4 *);
	int (*resume)(struct phy_device___4 *);
	int (*config_aneg)(struct phy_device___4 *);
	int (*read_status)(struct phy_device___4 *);
	int (*ack_interrupt)(struct phy_device___4 *);
	int (*config_intr)(struct phy_device___4 *);
	int (*did_interrupt)(struct phy_device___4 *);
	void (*remove)(struct phy_device___4 *);
	int (*match_phy_device)(struct phy_device___4 *);
	int (*ts_info)(struct phy_device___4 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___4 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___4 *, struct sk_buff___44 *, int);
	void (*txtstamp)(struct phy_device___4 *, struct sk_buff___44 *, int);
	int (*set_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	struct device_driver___247 driver;
};

struct netdev_hw_addr {
	struct list_head list;
	unsigned char addr[32];
	unsigned char type;
	bool global_use;
	int sync_cnt;
	int refcount;
	int synced;
	struct callback_head callback_head;
};

struct seq_net_private___3 {
	struct net___34 *net;
};

struct netlink_skb_parms___5 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___18 *sk;
	bool nsid_is_set;
	int nsid;
};

enum {
	NDA_UNSPEC = 0,
	NDA_DST = 1,
	NDA_LLADDR = 2,
	NDA_CACHEINFO = 3,
	NDA_PROBES = 4,
	NDA_VLAN = 5,
	NDA_PORT = 6,
	NDA_VNI = 7,
	NDA_IFINDEX = 8,
	NDA_MASTER = 9,
	NDA_LINK_NETNSID = 10,
	__NDA_MAX = 11,
};

struct nda_cacheinfo {
	__u32 ndm_confirmed;
	__u32 ndm_used;
	__u32 ndm_updated;
	__u32 ndm_refcnt;
};

struct ndt_stats {
	__u64 ndts_allocs;
	__u64 ndts_destroys;
	__u64 ndts_hash_grows;
	__u64 ndts_res_failed;
	__u64 ndts_lookups;
	__u64 ndts_hits;
	__u64 ndts_rcv_probes_mcast;
	__u64 ndts_rcv_probes_ucast;
	__u64 ndts_periodic_gc_runs;
	__u64 ndts_forced_gc_runs;
	__u64 ndts_table_fulls;
};

enum {
	NDTPA_UNSPEC = 0,
	NDTPA_IFINDEX = 1,
	NDTPA_REFCNT = 2,
	NDTPA_REACHABLE_TIME = 3,
	NDTPA_BASE_REACHABLE_TIME = 4,
	NDTPA_RETRANS_TIME = 5,
	NDTPA_GC_STALETIME = 6,
	NDTPA_DELAY_PROBE_TIME = 7,
	NDTPA_QUEUE_LEN = 8,
	NDTPA_APP_PROBES = 9,
	NDTPA_UCAST_PROBES = 10,
	NDTPA_MCAST_PROBES = 11,
	NDTPA_ANYCAST_DELAY = 12,
	NDTPA_PROXY_DELAY = 13,
	NDTPA_PROXY_QLEN = 14,
	NDTPA_LOCKTIME = 15,
	NDTPA_QUEUE_LENBYTES = 16,
	__NDTPA_MAX = 17,
};

struct ndtmsg {
	__u8 ndtm_family;
	__u8 ndtm_pad1;
	__u16 ndtm_pad2;
};

struct ndt_config {
	__u16 ndtc_key_len;
	__u16 ndtc_entry_size;
	__u32 ndtc_entries;
	__u32 ndtc_last_flush;
	__u32 ndtc_last_rand;
	__u32 ndtc_hash_rnd;
	__u32 ndtc_hash_mask;
	__u32 ndtc_hash_chain_gc;
	__u32 ndtc_proxy_qlen;
};

enum {
	NDTA_UNSPEC = 0,
	NDTA_NAME = 1,
	NDTA_THRESH1 = 2,
	NDTA_THRESH2 = 3,
	NDTA_THRESH3 = 4,
	NDTA_CONFIG = 5,
	NDTA_PARMS = 6,
	NDTA_STATS = 7,
	NDTA_GC_INTERVAL = 8,
	__NDTA_MAX = 9,
};

struct in_ifaddr___2;

struct in_device {
	struct net_device___23 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___2 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___17 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

enum {
	RTN_UNSPEC = 0,
	RTN_UNICAST = 1,
	RTN_LOCAL = 2,
	RTN_BROADCAST = 3,
	RTN_ANYCAST = 4,
	RTN_MULTICAST = 5,
	RTN_BLACKHOLE = 6,
	RTN_UNREACHABLE = 7,
	RTN_PROHIBIT = 8,
	RTN_THROW = 9,
	RTN_NAT = 10,
	RTN_XRESOLVE = 11,
	__RTN_MAX = 12,
};

typedef int (*rtnl_doit_func___2)(struct sk_buff___24 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___2)(struct sk_buff___24 *, struct netlink_callback___22 *);

typedef u16 (*rtnl_calcit_func___2)(struct sk_buff___24 *, struct nlmsghdr *);

struct neigh_seq_state {
	struct seq_net_private___3 p;
	struct neigh_table___17 *tbl;
	struct neigh_hash_table___17 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state *, struct neighbour___17 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

struct neighbour_cb {
	long unsigned int sched_next;
	unsigned int flags;
};

enum netevent_notif_type {
	NETEVENT_NEIGH_UPDATE = 1,
	NETEVENT_REDIRECT = 2,
};

struct in_ifaddr___2 {
	struct hlist_node hash;
	struct in_ifaddr___2 *ifa_next;
	struct in_device *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct neigh_sysctl_table {
	struct ctl_table_header___35 *sysctl_header;
	struct ctl_table neigh_vars[20];
};

struct page___249;

typedef struct page___249 *pgtable_t___249;

struct address_space___250;

struct kmem_cache___233;

struct page___249 {
	long unsigned int flags;
	struct address_space___250 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___249 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___249 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___233 *slab_cache;
		struct page___249 *first_page;
	};
	long: 64;
};

struct task_struct___251;

struct pv_cpu_ops___251 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___251 *);
	void (*end_context_switch)(struct task_struct___251 *);
};

struct mutex___252 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___251 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___244 {
	struct page___249 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___258;

struct nsproxy___131;

struct signal_struct___251;

struct css_set___146;

struct task_struct___251 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___251 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___258 *mm;
	struct mm_struct___258 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___251 *real_parent;
	struct task_struct___251 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___251 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___251 = 0,
		VTIME_USER___251 = 1,
		VTIME_SYS___251 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___131 *nsproxy;
	struct signal_struct___251 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___146 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___252 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___244 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___258 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___258 *, struct mm_struct___258 *);
	void (*dup_mmap)(struct mm_struct___258 *, struct mm_struct___258 *);
	void (*exit_mmap)(struct mm_struct___258 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___258 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___258 *);
	void (*pgd_free)(struct mm_struct___258 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___258 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___258 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___258 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___258 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___258 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___258 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___258 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___258 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___258 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___258 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___258 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___252 lock;
	void *vdso;
} mm_context_t___252;

struct xol_area___249;

struct uprobes_state___249 {
	struct xol_area___249 *xol_area;
};

struct vm_area_struct___258;

struct file___250;

struct core_state___251;

struct mm_struct___258 {
	struct vm_area_struct___258 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___258 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___258 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___252 context;
	long unsigned int flags;
	struct core_state___251 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___251 *owner;
	struct file___250 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___249 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___35;

struct kobj_type___35;

struct kobject___35 {
	const char *name;
	struct list_head entry;
	struct kobject___35 *parent;
	struct kset___35 *kset;
	struct kobj_type___35 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___153;

struct module_kobject___151 {
	struct kobject___35 kobj;
	struct module___153 *mod;
	struct kobject___35 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___151;

struct module___153 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___151 mkobj;
	struct module_attribute___151 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___35 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___251 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___251;

struct lruvec___251 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___251 *zone;
};

struct pglist_data___251;

struct zone___251 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___251 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___251 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___251 {
	struct zone___251 *zone;
	int zone_idx;
};

struct zonelist___251 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___251 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___251 {
	struct zone___251 node_zones[4];
	struct zonelist___251 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___251 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___174;

struct x86_io_apic_ops___174 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___174 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___174;

struct irq_data___174 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___174 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___248;

struct dev_pm_ops___248 {
	int (*prepare)(struct device___248 *);
	void (*complete)(struct device___248 *);
	int (*suspend)(struct device___248 *);
	int (*resume)(struct device___248 *);
	int (*freeze)(struct device___248 *);
	int (*thaw)(struct device___248 *);
	int (*poweroff)(struct device___248 *);
	int (*restore)(struct device___248 *);
	int (*suspend_late)(struct device___248 *);
	int (*resume_early)(struct device___248 *);
	int (*freeze_late)(struct device___248 *);
	int (*thaw_early)(struct device___248 *);
	int (*poweroff_late)(struct device___248 *);
	int (*restore_early)(struct device___248 *);
	int (*suspend_noirq)(struct device___248 *);
	int (*resume_noirq)(struct device___248 *);
	int (*freeze_noirq)(struct device___248 *);
	int (*thaw_noirq)(struct device___248 *);
	int (*poweroff_noirq)(struct device___248 *);
	int (*restore_noirq)(struct device___248 *);
	int (*runtime_suspend)(struct device___248 *);
	int (*runtime_resume)(struct device___248 *);
	int (*runtime_idle)(struct device___248 *);
};

struct dev_pm_qos___52;

struct dev_pm_info___52 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___52 *qos;
};

struct dma_map_ops___113;

struct dev_archdata___113 {
	struct dma_map_ops___113 *dma_ops;
	void *iommu;
};

struct device_type___248;

struct bus_type___248;

struct device_driver___248;

struct dev_pm_domain___248;

struct class___248;

struct attribute_group___210;

struct device_rh___248;

struct device___248 {
	struct device___248 *parent;
	struct device_private *p;
	struct kobject___35 kobj;
	const char *init_name;
	const struct device_type___248 *type;
	struct mutex___252 mutex;
	struct bus_type___248 *bus;
	struct device_driver___248 *driver;
	void *platform_data;
	struct dev_pm_info___52 power;
	struct dev_pm_domain___248 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___113 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___248 *class;
	const struct attribute_group___210 **groups;
	void (*release)(struct device___248 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___248 *device_rh;
};

struct dev_pm_qos_request___53;

struct dev_pm_qos___52 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___53 *latency_req;
	struct dev_pm_qos_request___53 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___53 *latency_tolerance_req;
};

struct dev_pm_info_rh___248 {
	void (*set_latency_tolerance)(struct device___248 *, s32);
};

struct dev_pm_domain___248 {
	struct dev_pm_ops___248 ops;
};

struct smp_ops___251 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___251 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___56;

struct ctl_node___56 {
	struct rb_node node;
	struct ctl_table_header___56 *header;
};

struct ctl_table_root___56;

struct ctl_table_set___56;

struct ctl_dir___56;

struct ctl_table_header___56 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___56 *root;
	struct ctl_table_set___56 *set;
	struct ctl_dir___56 *parent;
	struct ctl_node___56 *node;
};

struct ctl_dir___56 {
	struct ctl_table_header___56 header;
	struct rb_root root;
};

struct ctl_table_set___56 {
	int (*is_seen)(struct ctl_table_set___56 *);
	struct ctl_dir___56 dir;
};

struct ctl_table_root___56 {
	struct ctl_table_set___56 default_set;
	struct ctl_table_set___56 * (*lookup)(struct ctl_table_root___56 *, struct nsproxy___131 *);
	int (*permissions)(struct ctl_table_header___56 *, struct ctl_table *);
};

struct net___55;

struct nsproxy___131 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___55 *net_ns;
};

struct sock___34;

struct kobj_ns_type_operations___32 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___34 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___32;

struct sock_common___32 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___32 *skc_prot;
	struct net___55 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___45;

struct sk_buff_head___42 {
	struct sk_buff___45 *next;
	struct sk_buff___45 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___33;

struct socket_wq___32;

struct dst_entry___32;

struct socket___33;

struct cg_proto___32;

struct sock___34 {
	struct sock_common___32 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___42 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___45 *head;
		struct sk_buff___45 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___33 *sk_filter;
	struct socket_wq___32 *sk_wq;
	struct sk_buff_head___42 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___32 *sk_rx_dst;
	struct dst_entry___32 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___42 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___42 sk_error_queue;
	struct proto___32 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___33 *sk_socket;
	void *sk_user_data;
	struct page_frag___244 sk_frag;
	struct sk_buff___45 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___32 *sk_cgrp;
	void (*sk_state_change)(struct sock___34 *);
	void (*sk_data_ready)(struct sock___34 *, int);
	void (*sk_write_space)(struct sock___34 *);
	void (*sk_error_report)(struct sock___34 *);
	int (*sk_backlog_rcv)(struct sock___34 *, struct sk_buff___45 *);
	void (*sk_destruct)(struct sock___34 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___212;

struct attribute_group___210 {
	const char *name;
	umode_t (*is_visible)(struct kobject___35 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___212 **bin_attrs;
};

struct bin_attribute___212 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___250 *, struct kobject___35 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___250 *, struct kobject___35 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	int (*mmap)(struct file___250 *, struct kobject___35 *, struct bin_attribute___212 *, struct vm_area_struct___258 *);
};

struct dentry___250;

struct path___250 {
	struct vfsmount *mnt;
	struct dentry___250 *dentry;
};

struct inode___250;

struct file_operations___250;

struct file___250 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___250 f_path;
	struct inode___250 *f_inode;
	const struct file_operations___250 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___250 *f_mapping;
	struct mutex___252 f_pos_lock;
};

struct vm_operations_struct___224;

struct vm_area_struct___258 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___258 *vm_next;
	struct vm_area_struct___258 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___258 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___224 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___250 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___35 {
	ssize_t (*show)(struct kobject___35 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___35 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___35 *, const struct attribute *);
};

struct kset_uevent_ops___35;

struct kset___35 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___35 kobj;
	const struct kset_uevent_ops___35 *uevent_ops;
};

struct kobj_type___35 {
	void (*release)(struct kobject___35 *);
	const struct sysfs_ops___35 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___32 * (*child_ns_type)(struct kobject___35 *);
	const void * (*namespace)(struct kobject___35 *);
};

struct kset_uevent_ops___35 {
	int (* const filter)(struct kset___35 *, struct kobject___35 *);
	const char * (* const name)(struct kset___35 *, struct kobject___35 *);
	int (* const uevent)(struct kset___35 *, struct kobject___35 *, struct kobj_uevent_env *);
};

struct module_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___151 *, struct module_kobject___151 *, char *);
	ssize_t (*store)(struct module_attribute___151 *, struct module_kobject___151 *, const char *, size_t);
	void (*setup)(struct module___153 *, const char *);
	int (*test)(struct module___153 *);
	void (*free)(struct module___153 *);
};

struct xol_area___249 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___249 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___232;

struct memcg_cache_params___233;

struct kmem_cache___233 {
	struct kmem_cache_cpu___232 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___35 kobj;
	struct memcg_cache_params___233 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___250;

struct address_space___250 {
	struct inode___250 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___252 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___250 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___220;

struct vm_operations_struct___224 {
	void (*open)(struct vm_area_struct___258 *);
	void (*close)(struct vm_area_struct___258 *);
	int (*fault)(struct vm_area_struct___258 *, struct vm_fault___220 *);
	int (*page_mkwrite)(struct vm_area_struct___258 *, struct vm_fault___220 *);
	int (*access)(struct vm_area_struct___258 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___258 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___258 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___258 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___258 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___251 {
	struct task_struct___251 *task;
	struct core_thread___251 *next;
};

struct core_state___251 {
	atomic_t nr_threads;
	struct core_thread___251 dumper;
	struct completion startup;
};

struct fasync_struct___250;

struct socket_wq___32 {
	wait_queue_head_t wait;
	struct fasync_struct___250 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___250 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___250 *fa_next;
	struct file___250 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___32;

struct socket___33 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___32 *wq;
	struct file___250 *file;
	struct sock___34 *sk;
	const struct proto_ops___32 *ops;
};

struct poll_table_struct___139;

struct kiocb___40;

struct proto_ops___32 {
	int family;
	struct module___153 *owner;
	int (*release)(struct socket___33 *);
	int (*bind)(struct socket___33 *, struct sockaddr *, int);
	int (*connect)(struct socket___33 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___33 *, struct socket___33 *);
	int (*accept)(struct socket___33 *, struct socket___33 *, int);
	int (*getname)(struct socket___33 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___250 *, struct socket___33 *, struct poll_table_struct___139 *);
	int (*ioctl)(struct socket___33 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___33 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___33 *, int);
	int (*shutdown)(struct socket___33 *, int);
	int (*setsockopt)(struct socket___33 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___33 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___33 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___33 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___40 *, struct socket___33 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___40 *, struct socket___33 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___250 *, struct socket___33 *, struct vm_area_struct___258 *);
	ssize_t (*sendpage)(struct socket___33 *, struct page___249 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___33 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___34 *, int);
		struct {
			void (*set_peek_off)(struct sock___34 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___141)(struct file___250 *, wait_queue_head_t *, struct poll_table_struct___139 *);

struct poll_table_struct___139 {
	poll_queue_proc___141 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___40(struct kiocb___40 *, struct io_event *);

struct kiocb___40 {
	atomic_t ki_users;
	struct file___250 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___40 *ki_cancel;
	void (*ki_dtor)(struct kiocb___40 *);
	union {
		void *user;
		struct task_struct___251 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___53 {
	struct ctl_table_header___56 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___53 {
	struct mutex___252 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___53 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___56 *ctl;
};

struct netns_ipv4___53 {
	struct ctl_table_header___56 *forw_hdr;
	struct ctl_table_header___56 *frags_hdr;
	struct ctl_table_header___56 *ipv4_hdr;
	struct ctl_table_header___56 *route_hdr;
	struct ctl_table_header___56 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___34 *fibnl;
	struct sock___34 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___53 {
	struct ctl_table_header___56 *hdr;
	struct ctl_table_header___56 *route_hdr;
	struct ctl_table_header___56 *icmp_hdr;
	struct ctl_table_header___56 *frags_hdr;
	struct ctl_table_header___56 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___43;

struct neighbour___32;

struct dst_ops___54 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___54 *);
	struct dst_entry___32 * (*check)(struct dst_entry___32 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___32 *);
	unsigned int (*mtu)(const struct dst_entry___32 *);
	u32 * (*cow_metrics)(struct dst_entry___32 *, long unsigned int);
	void (*destroy)(struct dst_entry___32 *);
	void (*ifdown)(struct dst_entry___32 *, struct net_device___43 *, int);
	struct dst_entry___32 * (*negative_advice)(struct dst_entry___32 *);
	void (*link_failure)(struct sk_buff___45 *);
	void (*update_pmtu)(struct dst_entry___32 *, struct sock___34 *, struct sk_buff___45 *, u32);
	void (*redirect)(struct dst_entry___32 *, struct sock___34 *, struct sk_buff___45 *);
	int (*local_out)(struct sk_buff___45 *);
	struct neighbour___32 * (*neigh_lookup)(const struct dst_entry___32 *, struct sk_buff___45 *, const void *);
	struct kmem_cache___233 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___54 {
	struct netns_sysctl_ipv6___53 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___54 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___34 **icmp_sk;
	struct sock___34 *ndisc_sk;
	struct sock___34 *tcp_sk;
	struct sock___34 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___53 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___56 *sysctl_header;
	struct sock___34 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___32 {
	struct sock___34 *v4_ctl_sk;
	struct sock___34 *v6_ctl_sk;
};

struct netns_nf___53 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___56 *nf_log_dir_header;
};

struct nf_proto_net___53 {
	struct ctl_table_header___56 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___53 {
	struct nf_proto_net___53 pn;
	unsigned int timeout;
};

struct nf_tcp_net___53 {
	struct nf_proto_net___53 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___53 {
	struct nf_proto_net___53 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___53 {
	struct nf_proto_net___53 pn;
	unsigned int timeout;
};

struct nf_ip_net___53 {
	struct nf_generic_net___53 generic;
	struct nf_tcp_net___53 tcp;
	struct nf_udp_net___53 udp;
	struct nf_icmp_net___53 icmp;
	struct nf_icmp_net___53 icmpv6;
};

struct netns_ct___53 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___56 *sysctl_header;
	struct ctl_table_header___56 *acct_sysctl_header;
	struct ctl_table_header___56 *tstamp_sysctl_header;
	struct ctl_table_header___56 *event_sysctl_header;
	struct ctl_table_header___56 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___233 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___53 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___53 {
	struct netns_sysctl_ipv6___53 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___54 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___34 *nlsk;
	struct sock___34 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___56 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___54 xfrm4_dst_ops;
	struct dst_ops___54 xfrm6_dst_ops;
};

struct net___55 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___56 sysctls;
	struct sock___34 *rtnl;
	struct sock___34 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___43 *loopback_dev;
	struct netns_core___53 core;
	struct netns_mib mib;
	struct netns_packet___53 packet;
	struct netns_unix___53 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___53 ipv4;
	struct netns_ipv6___54 ipv6;
	struct netns_sctp___53 sctp;
	struct netns_dccp___32 dccp;
	struct netns_nf___53 nf;
	struct netns_xt xt;
	struct netns_ct___53 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___53 nf_frag;
	struct sock___34 *nfnl;
	struct sock___34 *nfnl_stash;
	struct sk_buff_head___42 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___54 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___34 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___34 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___252 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___252 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___220 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___249 *page;
};

struct kmem_cache_cpu___232 {
	void **freelist;
	long unsigned int tid;
	struct page___249 *page;
	struct page___249 *partial;
};

struct memcg_cache_params___233 {
	bool is_root_cache;
	union {
		struct kmem_cache___233 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___233 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct seq_file___175;

struct irq_chip___174 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___174 *);
	void (*irq_shutdown)(struct irq_data___174 *);
	void (*irq_enable)(struct irq_data___174 *);
	void (*irq_disable)(struct irq_data___174 *);
	void (*irq_ack)(struct irq_data___174 *);
	void (*irq_mask)(struct irq_data___174 *);
	void (*irq_mask_ack)(struct irq_data___174 *);
	void (*irq_unmask)(struct irq_data___174 *);
	void (*irq_eoi)(struct irq_data___174 *);
	int (*irq_set_affinity)(struct irq_data___174 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___174 *);
	int (*irq_set_type)(struct irq_data___174 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___174 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___174 *);
	void (*irq_bus_sync_unlock)(struct irq_data___174 *);
	void (*irq_cpu_online)(struct irq_data___174 *);
	void (*irq_cpu_offline)(struct irq_data___174 *);
	void (*irq_suspend)(struct irq_data___174 *);
	void (*irq_resume)(struct irq_data___174 *);
	void (*irq_pm_shutdown)(struct irq_data___174 *);
	void (*irq_print_chip)(struct irq_data___174 *, struct seq_file___175 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___174 *, void *);
	long unsigned int flags;
};

struct seq_operations___175;

struct seq_file___175 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___252 lock;
	const struct seq_operations___175 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dma_map_ops___113 {
	void * (*alloc)(struct device___248 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___248 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___248 *, struct vm_area_struct___258 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___248 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___248 *, struct page___249 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___248 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___248 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___248 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___248 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___248 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___248 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___248 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___248 *, dma_addr_t);
	int (*dma_supported)(struct device___248 *, u64);
	int (*set_dma_mask)(struct device___248 *, u64);
	int is_phys;
};

struct bus_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___248 *, char *);
	ssize_t (*store)(struct bus_type___248 *, const char *, size_t);
};

struct device_attribute___248;

struct driver_attribute___248;

struct bus_type___248 {
	const char *name;
	const char *dev_name;
	struct device___248 *dev_root;
	struct bus_attribute___248 *bus_attrs;
	struct device_attribute___248 *dev_attrs;
	struct driver_attribute___248 *drv_attrs;
	const struct attribute_group___210 **bus_groups;
	const struct attribute_group___210 **dev_groups;
	const struct attribute_group___210 **drv_groups;
	int (*match)(struct device___248 *, struct device_driver___248 *);
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	int (*probe)(struct device___248 *);
	int (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*online)(struct device___248 *);
	int (*offline)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct device___248 *, struct device_attribute___248 *, char *);
	ssize_t (*store)(struct device___248 *, struct device_attribute___248 *, const char *, size_t);
};

struct driver_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___248 *, char *);
	ssize_t (*store)(struct device_driver___248 *, const char *, size_t);
};

struct device_driver___248 {
	const char *name;
	struct bus_type___248 *bus;
	struct module___153 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___248 *);
	int (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	const struct attribute_group___210 **groups;
	const struct dev_pm_ops___248 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___248 {
	const char *name;
	const struct attribute_group___210 **groups;
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
};

struct class_attribute___248;

struct class___248 {
	const char *name;
	struct module___153 *owner;
	struct class_attribute___248 *class_attrs;
	struct device_attribute___248 *dev_attrs;
	const struct attribute_group___210 **dev_groups;
	struct bin_attribute___212 *dev_bin_attrs;
	struct kobject___35 *dev_kobj;
	int (*dev_uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *);
	void (*class_release)(struct class___248 *);
	void (*dev_release)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	const struct kobj_ns_type_operations___32 *ns_type;
	const void * (*namespace)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
	struct subsys_private *p;
};

struct class_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct class___248 *, struct class_attribute___248 *, char *);
	ssize_t (*store)(struct class___248 *, struct class_attribute___248 *, const char *, size_t);
	const void * (*namespace)(struct class___248 *, const struct class_attribute___248 *);
};

struct device_rh___248 {
	struct dev_pm_info_rh___248 power;
};

struct signal_struct___251 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___251 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___251 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___252 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___146;

struct css_set___146 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___146 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___41 {
	atomic_t use;
	unsigned int mask;
	struct net_device___43 *physindev;
	struct net_device___43 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___41(struct sk_buff___45 **);

struct net_device_ops___41;

struct ethtool_ops___41;

struct header_ops___41;

struct inet6_dev___18;

struct netdev_rx_queue___41;

struct netdev_queue___41;

struct Qdisc___4;

struct rtnl_link_ops___32;

struct dcbnl_rtnl_ops___41;

struct net_device___43 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___41 *netdev_ops;
	const struct ethtool_ops___41 *ethtool_ops;
	const struct header_ops___41 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___35 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___18 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___41 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___41 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___41 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___41 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___4 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___41 = 0,
		NETREG_REGISTERED___41 = 1,
		NETREG_UNREGISTERING___41 = 2,
		NETREG_UNREGISTERED___41 = 3,
		NETREG_RELEASED___41 = 4,
		NETREG_DUMMY___41 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___41 = 0,
		RTNL_LINK_INITIALIZING___41 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___43 *);
	struct netpoll_info *npinfo;
	struct net___55 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___248 dev;
	const struct attribute_group___210 *sysfs_groups[4];
	const struct rtnl_link_ops___32 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___41 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___45 {
	struct sk_buff___45 *next;
	struct sk_buff___45 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___34 *sk;
	struct net_device___43 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___45 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___41 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct inode_operations___250;

struct super_block___250;

struct file_lock___250;

struct dquot___250;

struct block_device___250;

struct inode___250 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___250 *i_op;
	struct super_block___250 *i_sb;
	struct address_space___250 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___252 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___250 *i_fop;
	struct file_lock___250 *i_flock;
	struct address_space___250 i_data;
	struct dquot___250 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___250 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___250;

struct mem_dqinfo___250 {
	struct quota_format_type___250 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___250;

struct quota_info___250 {
	unsigned int flags;
	struct mutex___252 dqio_mutex;
	struct mutex___252 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___250 *files[2];
	struct mem_dqinfo___250 info[2];
	const struct quota_format_ops___250 *ops[2];
};

struct file_system_type___250;

struct super_operations___250;

struct dquot_operations___250;

struct quotactl_ops___250;

struct xattr_handler___147;

struct dentry_operations___250;

struct super_block___250 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___250 *s_type;
	const struct super_operations___250 *s_op;
	const struct dquot_operations___250 *dq_op;
	const struct quotactl_ops___250 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___250 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___147 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___250 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___250 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___252 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___250 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___250 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___250 *d_parent;
	struct qstr d_name;
	struct inode___250 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___250 *d_op;
	struct super_block___250 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct iattr___250 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___250 *ia_file;
};

struct request_sock_ops___23;

struct request_sock___24 {
	struct sock_common___32 __req_common;
	struct request_sock___24 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___23 *rsk_ops;
	struct sock___34 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_skb_parms___6 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___34 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___6 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___45 *);
	struct mutex___252 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___55 *, struct sock___34 *);
};

struct netlink_callback___43 {
	struct sk_buff___45 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___45 *, struct netlink_callback___43 *);
	int (*done)(struct netlink_callback___43 *);
	void *data;
	struct module___153 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct netlink_dump_control {
	int (*dump)(struct sk_buff___45 *, struct netlink_callback___43 *);
	int (*done)(struct netlink_callback___43 *);
	void *data;
	struct module___153 *module;
	u16 min_dump_alloc;
};

struct file_operations___250 {
	struct module___153 *owner;
	loff_t (*llseek)(struct file___250 *, loff_t, int);
	ssize_t (*read)(struct file___250 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___250 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___40 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___40 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___250 *, void *, filldir_t);
	unsigned int (*poll)(struct file___250 *, struct poll_table_struct___139 *);
	long int (*unlocked_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___250 *, struct vm_area_struct___258 *);
	int (*open)(struct inode___250 *, struct file___250 *);
	int (*flush)(struct file___250 *, fl_owner_t);
	int (*release)(struct inode___250 *, struct file___250 *);
	int (*fsync)(struct file___250 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___40 *, int);
	int (*fasync)(int, struct file___250 *, int);
	int (*lock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*sendpage)(struct file___250 *, struct page___249 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___250 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___250 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___250 *, long int, struct file_lock___250 **, void **);
		struct {
			int (*setlease)(struct file___250 *, long int, struct file_lock___250 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___250 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___175 *, struct file___250 *);
};

struct dev_pm_qos_request___53 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___248 *dev;
};

struct dentry_operations___250 {
	int (*d_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_hash)(const struct dentry___250 *, struct qstr *);
	int (*d_compare)(const struct dentry___250 *, const struct dentry___250 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___250 *);
	void (*d_release)(struct dentry___250 *);
	void (*d_prune)(struct dentry___250 *);
	void (*d_iput)(struct dentry___250 *, struct inode___250 *);
	char * (*d_dname)(struct dentry___250 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___250 *);
	int (*d_manage)(struct dentry___250 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___250 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___250 *bd_inode;
	struct super_block___250 *bd_super;
	struct mutex___252 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___250 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___252 bd_fsfreeze_mutex;
};

struct cgroup___146;

struct cgroup_subsys_state___146 {
	struct cgroup___146 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___250 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___252 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___250 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___250 {
	int qf_fmt_id;
	const struct quota_format_ops___250 *qf_ops;
	struct module___153 *qf_owner;
	struct quota_format_type___250 *qf_next;
};

struct quota_format_ops___250 {
	int (*check_quota_file)(struct super_block___250 *, int);
	int (*read_file_info)(struct super_block___250 *, int);
	int (*write_file_info)(struct super_block___250 *, int);
	int (*free_file_info)(struct super_block___250 *, int);
	int (*read_dqblk)(struct dquot___250 *);
	int (*commit_dqblk)(struct dquot___250 *);
	int (*release_dqblk)(struct dquot___250 *);
};

struct dquot_operations___250 {
	int (*write_dquot)(struct dquot___250 *);
	struct dquot___250 * (*alloc_dquot)(struct super_block___250 *, int);
	void (*destroy_dquot)(struct dquot___250 *);
	int (*acquire_dquot)(struct dquot___250 *);
	int (*release_dquot)(struct dquot___250 *);
	int (*mark_dirty)(struct dquot___250 *);
	int (*write_info)(struct super_block___250 *, int);
	qsize_t * (*get_reserved_space)(struct inode___250 *);
};

struct quotactl_ops___250 {
	int (*quota_on)(struct super_block___250 *, int, int, struct path___250 *);
	int (*quota_on_meta)(struct super_block___250 *, int, int);
	int (*quota_off)(struct super_block___250 *, int);
	int (*quota_sync)(struct super_block___250 *, int);
	int (*get_info)(struct super_block___250 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___250 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___250 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___250 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___250 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___250 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___250 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___250 *, unsigned int);
};

struct address_space_operations___250 {
	int (*writepage)(struct page___249 *, struct writeback_control *);
	int (*readpage)(struct file___250 *, struct page___249 *);
	int (*writepages)(struct address_space___250 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___249 *);
	int (*readpages)(struct file___250 *, struct address_space___250 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___250 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___249 **, void **);
	int (*write_end)(struct file___250 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___249 *, void *);
	sector_t (*bmap)(struct address_space___250 *, sector_t);
	void (*invalidatepage)(struct page___249 *, long unsigned int);
	int (*releasepage)(struct page___249 *, gfp_t);
	void (*freepage)(struct page___249 *);
	ssize_t (*direct_IO)(int, struct kiocb___40 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___250 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___250 *, struct page___249 *, struct page___249 *, enum migrate_mode);
	int (*launder_page)(struct page___249 *);
	int (*is_partially_uptodate)(struct page___249 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___249 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___250 *, struct page___249 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___250 *, sector_t *);
	void (*swap_deactivate)(struct file___250 *);
	void (*invalidatepage_range)(struct page___249 *, unsigned int, unsigned int);
};

struct inode_operations___250 {
	struct dentry___250 * (*lookup)(struct inode___250 *, struct dentry___250 *, unsigned int);
	void * (*follow_link)(struct dentry___250 *, struct nameidata *);
	int (*permission)(struct inode___250 *, int);
	struct posix_acl * (*get_acl)(struct inode___250 *, int);
	int (*readlink)(struct dentry___250 *, char *, int);
	void (*put_link)(struct dentry___250 *, struct nameidata *, void *);
	int (*create)(struct inode___250 *, struct dentry___250 *, umode_t, bool);
	int (*link)(struct dentry___250 *, struct inode___250 *, struct dentry___250 *);
	int (*unlink)(struct inode___250 *, struct dentry___250 *);
	int (*symlink)(struct inode___250 *, struct dentry___250 *, const char *);
	int (*mkdir)(struct inode___250 *, struct dentry___250 *, umode_t);
	int (*rmdir)(struct inode___250 *, struct dentry___250 *);
	int (*mknod)(struct inode___250 *, struct dentry___250 *, umode_t, dev_t);
	int (*rename)(struct inode___250 *, struct dentry___250 *, struct inode___250 *, struct dentry___250 *);
	int (*setattr)(struct dentry___250 *, struct iattr___250 *);
	int (*getattr)(struct vfsmount *, struct dentry___250 *, struct kstat *);
	int (*setxattr)(struct dentry___250 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___250 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___250 *, char *, size_t);
	int (*removexattr)(struct dentry___250 *, const char *);
	int (*fiemap)(struct inode___250 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___250 *, struct timespec *, int);
	int (*atomic_open)(struct inode___250 *, struct dentry___250 *, struct file___250 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___250;

struct lock_manager_operations___250;

struct file_lock___250 {
	struct file_lock___250 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___250 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___250 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___250 *fl_ops;
	const struct lock_manager_operations___250 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___250 {
	void (*fl_copy_lock)(struct file_lock___250 *, struct file_lock___250 *);
	void (*fl_release_private)(struct file_lock___250 *);
};

struct lock_manager_operations___250 {
	int (*lm_compare_owner)(struct file_lock___250 *, struct file_lock___250 *);
	long unsigned int (*lm_owner_key)(struct file_lock___250 *);
	void (*lm_notify)(struct file_lock___250 *);
	int (*lm_grant)(struct file_lock___250 *, struct file_lock___250 *, int);
	void (*lm_break)(struct file_lock___250 *);
	int (*lm_change)(struct file_lock___250 **, int);
};

struct file_system_type___250 {
	const char *name;
	int fs_flags;
	struct dentry___250 * (*mount)(struct file_system_type___250 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___250 *);
	struct module___153 *owner;
	struct file_system_type___250 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___250 {
	struct inode___250 * (*alloc_inode)(struct super_block___250 *);
	void (*destroy_inode)(struct inode___250 *);
	void (*dirty_inode)(struct inode___250 *, int);
	int (*write_inode)(struct inode___250 *, struct writeback_control *);
	int (*drop_inode)(struct inode___250 *);
	void (*evict_inode)(struct inode___250 *);
	void (*put_super)(struct super_block___250 *);
	int (*sync_fs)(struct super_block___250 *, int);
	int (*freeze_fs)(struct super_block___250 *);
	int (*unfreeze_fs)(struct super_block___250 *);
	int (*statfs)(struct dentry___250 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___250 *, int *, char *);
	void (*umount_begin)(struct super_block___250 *);
	int (*show_options)(struct seq_file___175 *, struct dentry___250 *);
	int (*show_devname)(struct seq_file___175 *, struct dentry___250 *);
	int (*show_path)(struct seq_file___175 *, struct dentry___250 *);
	int (*show_stats)(struct seq_file___175 *, struct dentry___250 *);
	ssize_t (*quota_read)(struct super_block___250 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___250 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___250 *);
	int (*bdev_try_to_free_page)(struct super_block___250 *, struct page___249 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___250 *);
	void (*free_cached_objects)(struct super_block___250 *, int);
};

struct xattr_handler___147 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___250 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___250 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___250 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___41 {
	int (*get_settings)(struct net_device___43 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___43 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___43 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___43 *);
	void (*get_regs)(struct net_device___43 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___43 *);
	void (*set_msglevel)(struct net_device___43 *, u32);
	int (*nway_reset)(struct net_device___43 *);
	u32 (*get_link)(struct net_device___43 *);
	int (*get_eeprom_len)(struct net_device___43 *);
	int (*get_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___43 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___43 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___43 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___43 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___43 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___43 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___43 *);
	void (*complete)(struct net_device___43 *);
	u32 (*get_priv_flags)(struct net_device___43 *);
	int (*set_priv_flags)(struct net_device___43 *, u32);
	int (*get_sset_count)(struct net_device___43 *, int);
	int (*get_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___43 *, struct ethtool_flash *);
	int (*reset)(struct net_device___43 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___43 *);
	int (*get_rxfh_indir)(struct net_device___43 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___43 *, const u32 *);
	void (*get_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___43 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___43 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___43 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___43 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___43 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___43 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___43 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___43 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib_rule;

struct fib_lookup_arg;

struct fib_rule_hdr;

struct fib_rules_ops {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule *, struct flowi *, int, struct fib_lookup_arg *);
	int (*match)(struct fib_rule *, struct flowi *, int);
	int (*configure)(struct fib_rule *, struct sk_buff___45 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule *);
	int (*compare)(struct fib_rule *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule *, struct sk_buff___45 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops *);
	size_t (*nlmsg_payload)(struct fib_rule *);
	void (*flush_cache)(struct fib_rules_ops *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___153 *owner;
	struct net___55 *fro_net;
	struct callback_head rcu;
};

struct rtable___13;

struct dst_entry___32 {
	struct callback_head callback_head;
	struct dst_entry___32 *child;
	struct net_device___43 *dev;
	struct dst_ops___54 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___32 *path;
	struct dst_entry___32 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___45 *);
	union {
		int (*output)(struct sock___34 *, struct sk_buff___45 *);
		struct {
			int (*output)(struct sk_buff___45 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___32 *next;
		struct rtable___13 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___32;

struct neigh_parms___32;

struct neigh_ops___32;

struct neighbour___32 {
	struct neighbour___32 *next;
	struct neigh_table___32 *tbl;
	struct neigh_parms___32 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___42 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___32 *, struct sk_buff___45 *);
	const struct neigh_ops___32 *ops;
	struct callback_head rcu;
	struct net_device___43 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___54 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___45 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___45 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___55 *, struct dst_entry___32 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___45 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___45 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___175 {
	void * (*start)(struct seq_file___175 *, loff_t *);
	void (*stop)(struct seq_file___175 *, void *);
	void * (*next)(struct seq_file___175 *, void *, loff_t *);
	int (*show)(struct seq_file___175 *, void *);
};

struct pernet_operations___8 {
	struct list_head list;
	int (*init)(struct net___55 *);
	void (*exit)(struct net___55 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___41 {
	int (*ieee_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___43 *);
	u8 (*setstate)(struct net_device___43 *, u8);
	void (*getpermhwaddr)(struct net_device___43 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___43 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___43 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___43 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___43 *, int, u8 *);
	void (*setpfccfg)(struct net_device___43 *, int, u8);
	void (*getpfccfg)(struct net_device___43 *, int, u8 *);
	u8 (*setall)(struct net_device___43 *);
	u8 (*getcap)(struct net_device___43 *, int, u8 *);
	int (*getnumtcs)(struct net_device___43 *, int, u8 *);
	int (*setnumtcs)(struct net_device___43 *, int, u8);
	u8 (*getpfcstate)(struct net_device___43 *);
	void (*setpfcstate)(struct net_device___43 *, u8);
	void (*getbcncfg)(struct net_device___43 *, int, u32 *);
	void (*setbcncfg)(struct net_device___43 *, int, u32);
	void (*getbcnrp)(struct net_device___43 *, int, u8 *);
	void (*setbcnrp)(struct net_device___43 *, int, u8);
	u8 (*setapp)(struct net_device___43 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___43 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___43 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___43 *, int, u8);
	u8 (*getdcbx)(struct net_device___43 *);
	u8 (*setdcbx)(struct net_device___43 *, u8);
	int (*peer_getappinfo)(struct net_device___43 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___43 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___43 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___43 *, struct cee_pfc *);
};

struct cgroupfs_root___146;

struct cgroup___146 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___146 *parent;
	struct dentry___250 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___146 *subsys[11];
	struct cgroupfs_root___146 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___252 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___146 {
	struct super_block___250 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___146 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___84 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___250 *, struct file___250 *);
	ssize_t (*read)(struct cgroup___146 *, struct cftype___84 *, struct file___250 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___146 *, struct cftype___84 *);
	s64 (*read_s64)(struct cgroup___146 *, struct cftype___84 *);
	int (*read_map)(struct cgroup___146 *, struct cftype___84 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___146 *, struct cftype___84 *, struct seq_file___175 *);
	ssize_t (*write)(struct cgroup___146 *, struct cftype___84 *, struct file___250 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___146 *, struct cftype___84 *, u64);
	int (*write_s64)(struct cgroup___146 *, struct cftype___84 *, s64);
	int (*write_string)(struct cgroup___146 *, struct cftype___84 *, const char *);
	int (*trigger)(struct cgroup___146 *, unsigned int);
	int (*release)(struct inode___250 *, struct file___250 *);
	int (*register_event)(struct cgroup___146 *, struct cftype___84 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___146 *, struct cftype___84 *, struct eventfd_ctx *);
};

struct cftype_set___80 {
	struct list_head node;
	struct cftype___84 *cfts;
};

struct task_and_cgroup___80 {
	struct task_struct___251 *task;
	struct cgroup___146 *cgrp;
	struct css_set___146 *cg;
};

struct cgroup_taskset___80 {
	struct task_and_cgroup___80 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___146 *cur_cgrp;
};

struct cgroup_subsys___80 {
	struct cgroup_subsys_state___146 * (*css_alloc)(struct cgroup___146 *);
	int (*css_online)(struct cgroup___146 *);
	void (*css_offline)(struct cgroup___146 *);
	void (*css_free)(struct cgroup___146 *);
	int (*can_attach)(struct cgroup___146 *, struct cgroup_taskset___80 *);
	void (*cancel_attach)(struct cgroup___146 *, struct cgroup_taskset___80 *);
	void (*attach)(struct cgroup___146 *, struct cgroup_taskset___80 *);
	void (*fork)(struct task_struct___251 *);
	void (*exit)(struct cgroup___146 *, struct cgroup___146 *, struct task_struct___251 *);
	void (*bind)(struct cgroup___146 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___146 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___84 *base_cftypes;
	struct cftype_set___80 base_cftset;
	struct module___153 *module;
};

struct rtnl_link_stats {
	__u32 rx_packets;
	__u32 tx_packets;
	__u32 rx_bytes;
	__u32 tx_bytes;
	__u32 rx_errors;
	__u32 tx_errors;
	__u32 rx_dropped;
	__u32 tx_dropped;
	__u32 multicast;
	__u32 collisions;
	__u32 rx_length_errors;
	__u32 rx_over_errors;
	__u32 rx_crc_errors;
	__u32 rx_frame_errors;
	__u32 rx_fifo_errors;
	__u32 rx_missed_errors;
	__u32 tx_aborted_errors;
	__u32 tx_carrier_errors;
	__u32 tx_fifo_errors;
	__u32 tx_heartbeat_errors;
	__u32 tx_window_errors;
	__u32 rx_compressed;
	__u32 tx_compressed;
};

struct rtnl_link_ifmap {
	__u64 mem_start;
	__u64 mem_end;
	__u64 base_addr;
	__u16 irq;
	__u8 dma;
	__u8 port;
};

enum {
	IFLA_UNSPEC = 0,
	IFLA_ADDRESS = 1,
	IFLA_BROADCAST = 2,
	IFLA_IFNAME = 3,
	IFLA_MTU = 4,
	IFLA_LINK = 5,
	IFLA_QDISC = 6,
	IFLA_STATS = 7,
	IFLA_COST = 8,
	IFLA_PRIORITY = 9,
	IFLA_MASTER = 10,
	IFLA_WIRELESS = 11,
	IFLA_PROTINFO = 12,
	IFLA_TXQLEN = 13,
	IFLA_MAP = 14,
	IFLA_WEIGHT = 15,
	IFLA_OPERSTATE = 16,
	IFLA_LINKMODE = 17,
	IFLA_LINKINFO = 18,
	IFLA_NET_NS_PID = 19,
	IFLA_IFALIAS = 20,
	IFLA_NUM_VF = 21,
	IFLA_VFINFO_LIST = 22,
	IFLA_STATS64 = 23,
	IFLA_VF_PORTS = 24,
	IFLA_PORT_SELF = 25,
	IFLA_AF_SPEC = 26,
	IFLA_GROUP = 27,
	IFLA_NET_NS_FD = 28,
	IFLA_EXT_MASK = 29,
	IFLA_PROMISCUITY = 30,
	IFLA_NUM_TX_QUEUES = 31,
	IFLA_NUM_RX_QUEUES = 32,
	IFLA_CARRIER = 33,
	IFLA_PHYS_PORT_ID = 34,
	__RH_RESERVED_IFLA_CARRIER_CHANGES = 35,
	__RH_RESERVED_IFLA_PHYS_SWITCH_ID = 36,
	IFLA_LINK_NETNSID = 37,
	__IFLA_MAX = 38,
};

enum {
	IFLA_BRPORT_UNSPEC = 0,
	IFLA_BRPORT_STATE = 1,
	IFLA_BRPORT_PRIORITY = 2,
	IFLA_BRPORT_COST = 3,
	IFLA_BRPORT_MODE = 4,
	IFLA_BRPORT_GUARD = 5,
	IFLA_BRPORT_PROTECT = 6,
	IFLA_BRPORT_FAST_LEAVE = 7,
	IFLA_BRPORT_LEARNING = 8,
	IFLA_BRPORT_UNICAST_FLOOD = 9,
	RESERVED_IFLA_BRPORT_PROXYARP = 10,
	IFLA_BRPORT_LEARNING_SYNC = 11,
	__IFLA_BRPORT_MAX = 12,
};

enum {
	IFLA_INFO_UNSPEC = 0,
	IFLA_INFO_KIND = 1,
	IFLA_INFO_DATA = 2,
	IFLA_INFO_XSTATS = 3,
	IFLA_INFO_SLAVE_KIND = 4,
	IFLA_INFO_SLAVE_DATA = 5,
	__IFLA_INFO_MAX = 6,
};

enum {
	IFLA_VF_INFO_UNSPEC = 0,
	IFLA_VF_INFO = 1,
	__IFLA_VF_INFO_MAX = 2,
};

enum {
	IFLA_VF_UNSPEC = 0,
	IFLA_VF_MAC = 1,
	IFLA_VF_VLAN = 2,
	IFLA_VF_TX_RATE = 3,
	IFLA_VF_SPOOFCHK = 4,
	IFLA_VF_LINK_STATE = 5,
	IFLA_VF_RATE = 6,
	IFLA_VF_RSS_QUERY_EN = 7,
	IFLA_VF_STATS = 8,
	__IFLA_VF_MAX = 9,
};

struct ifla_vf_mac {
	__u32 vf;
	__u8 mac[32];
};

struct ifla_vf_vlan {
	__u32 vf;
	__u32 vlan;
	__u32 qos;
};

struct ifla_vf_tx_rate {
	__u32 vf;
	__u32 rate;
};

struct ifla_vf_rate {
	__u32 vf;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
};

struct ifla_vf_spoofchk {
	__u32 vf;
	__u32 setting;
};

struct ifla_vf_link_state {
	__u32 vf;
	__u32 link_state;
};

struct ifla_vf_rss_query_en {
	__u32 vf;
	__u32 setting;
};

enum {
	IFLA_VF_STATS_RX_PACKETS = 0,
	IFLA_VF_STATS_TX_PACKETS = 1,
	IFLA_VF_STATS_RX_BYTES = 2,
	IFLA_VF_STATS_TX_BYTES = 3,
	IFLA_VF_STATS_BROADCAST = 4,
	IFLA_VF_STATS_MULTICAST = 5,
	__IFLA_VF_STATS_MAX = 6,
};

enum {
	IFLA_VF_PORT_UNSPEC = 0,
	IFLA_VF_PORT = 1,
	__IFLA_VF_PORT_MAX = 2,
};

enum {
	IFLA_PORT_UNSPEC = 0,
	IFLA_PORT_VF = 1,
	IFLA_PORT_PROFILE = 2,
	IFLA_PORT_VSI_TYPE = 3,
	IFLA_PORT_INSTANCE_UUID = 4,
	IFLA_PORT_HOST_UUID = 5,
	IFLA_PORT_REQUEST = 6,
	IFLA_PORT_RESPONSE = 7,
	__IFLA_PORT_MAX = 8,
};

struct header_ops___41 {
	int (*create)(struct sk_buff___45 *, struct net_device___43 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___45 *, unsigned char *);
	int (*rebuild)(struct sk_buff___45 *);
	int (*cache)(const struct neighbour___32 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___43 *, const unsigned char *);
};

struct napi_struct___41 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___41 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___43 *dev;
	struct sk_buff___45 *gro_list;
	struct sk_buff___45 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___41 {
	struct net_device___43 *dev;
	struct Qdisc___4 *qdisc;
	struct Qdisc___4 *qdisc_sleeping;
	struct kobject___35 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___4;

struct Qdisc___4 {
	int (*enqueue)(struct sk_buff___45 *, struct Qdisc___4 *);
	struct sk_buff___45 * (*dequeue)(struct Qdisc___4 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___4 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___45 *, struct Qdisc___4 *);
	void *u32_node;
	struct Qdisc___4 *__parent;
	struct netdev_queue___41 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___4 *next_sched;
	struct sk_buff___45 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___42 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___41 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___35 kobj;
	struct net_device___43 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___41 {
	int (*ndo_init)(struct net_device___43 *);
	void (*ndo_uninit)(struct net_device___43 *);
	int (*ndo_open)(struct net_device___43 *);
	int (*ndo_stop)(struct net_device___43 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___45 *, struct net_device___43 *);
	u16 (*ndo_select_queue)(struct net_device___43 *, struct sk_buff___45 *);
	void (*ndo_change_rx_flags)(struct net_device___43 *, int);
	void (*ndo_set_rx_mode)(struct net_device___43 *);
	int (*ndo_set_mac_address)(struct net_device___43 *, void *);
	int (*ndo_validate_addr)(struct net_device___43 *);
	int (*ndo_do_ioctl)(struct net_device___43 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___43 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___43 *, int);
	int (*ndo_neigh_setup)(struct net_device___43 *, struct neigh_parms___32 *);
	void (*ndo_tx_timeout)(struct net_device___43 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___43 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___43 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___43 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___43 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___43 *);
	int (*ndo_netpoll_setup)(struct net_device___43 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___43 *);
	int (*ndo_busy_poll)(struct napi_struct___41 *);
	int (*ndo_set_vf_mac)(struct net_device___43 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___43 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___43 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___43 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___43 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___43 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___43 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___43 *, int, struct sk_buff___45 *);
	int (*ndo_setup_tc)(struct net_device___43 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___43 *);
	int (*ndo_fcoe_disable)(struct net_device___43 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___43 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___43 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___43 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___43 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___43 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___43 *, const struct sk_buff___45 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___43 *, struct net_device___43 *);
	int (*ndo_del_slave)(struct net_device___43 *, struct net_device___43 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___32 *);
	void (*ndo_neigh_destroy)(struct neighbour___32 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___45 *, struct netlink_callback___43 *, struct net_device___43 *, int);
	int (*ndo_bridge_setlink)(struct net_device___43 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___45 *, u32, u32, struct net_device___43 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___43 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___43 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___43 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___43 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___43 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___43 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___45 *, struct net_device___43 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___43 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___43 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___43 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___32 {
	struct net___55 *net;
	struct net_device___43 *dev;
	struct neigh_parms___32 *next;
	int (*neigh_setup)(struct neighbour___32 *);
	void (*neigh_cleanup)(struct neighbour___32 *);
	struct neigh_table___32 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___18;

struct ifacaddr6___18;

struct inet6_dev___18 {
	struct net_device___43 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___18 *mc_list;
	struct ifmcaddr6___18 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___18 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___32 *nd_parms;
	struct inet6_dev___18 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___32 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___43 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___55 *, struct net_device___43 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___43 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___43 *, struct list_head *);
	size_t (*get_size)(const struct net_device___43 *);
	int (*fill_info)(struct sk_buff___45 *, const struct net_device___43 *);
	size_t (*get_xstats_size)(const struct net_device___43 *);
	int (*fill_xstats)(struct sk_buff___45 *, const struct net_device___43 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___55 * (*get_link_net)(const struct net_device___43 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___43 *, struct net_device___43 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___43 *, const struct net_device___43 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___45 *, const struct net_device___43 *, const struct net_device___43 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	IFLA_BRIDGE_FLAGS = 0,
	IFLA_BRIDGE_MODE = 1,
	IFLA_BRIDGE_VLAN_INFO = 2,
	__IFLA_BRIDGE_MAX = 3,
};

struct sk_filter___33 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___45 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

enum rtattr_type_t {
	RTA_UNSPEC = 0,
	RTA_DST = 1,
	RTA_SRC = 2,
	RTA_IIF = 3,
	RTA_OIF = 4,
	RTA_GATEWAY = 5,
	RTA_PRIORITY = 6,
	RTA_PREFSRC = 7,
	RTA_METRICS = 8,
	RTA_MULTIPATH = 9,
	RTA_PROTOINFO = 10,
	RTA_FLOW = 11,
	RTA_CACHEINFO = 12,
	RTA_SESSION = 13,
	RTA_MP_ALGO = 14,
	RTA_TABLE = 15,
	RTA_MARK = 16,
	RTA_MFC_STATS = 17,
	__RTA_MAX = 18,
};

struct rta_cacheinfo {
	__u32 rta_clntref;
	__u32 rta_lastuse;
	__s32 rta_expires;
	__u32 rta_error;
	__u32 rta_used;
	__u32 rta_id;
	__u32 rta_ts;
	__u32 rta_tsage;
};

struct ifinfomsg {
	unsigned char ifi_family;
	unsigned char __ifi_pad;
	short unsigned int ifi_type;
	int ifi_index;
	unsigned int ifi_flags;
	unsigned int ifi_change;
};

typedef int (*rtnl_doit_func___3)(struct sk_buff___45 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___3)(struct sk_buff___45 *, struct netlink_callback___43 *);

typedef u16 (*rtnl_calcit_func___3)(struct sk_buff___45 *, struct nlmsghdr *);

struct rtnl_af_ops {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___45 *, const struct net_device___43 *);
	size_t (*get_link_af_size)(const struct net_device___43 *);
	int (*validate_link_af)(const struct net_device___43 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___43 *, const struct nlattr *);
};

struct pneigh_entry___32;

struct neigh_hash_table___32;

struct neigh_table___32 {
	struct neigh_table___32 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___43 *, __u32 *);
	int (*constructor)(struct neighbour___32 *);
	int (*pconstructor)(struct pneigh_entry___32 *);
	void (*pdestructor)(struct pneigh_entry___32 *);
	void (*proxy_redo)(struct sk_buff___45 *);
	char *id;
	struct neigh_parms___32 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___42 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___32 *nht;
	struct pneigh_entry___32 **phash_buckets;
};

struct neigh_ops___32 {
	int family;
	void (*solicit)(struct neighbour___32 *, struct sk_buff___45 *);
	void (*error_report)(struct neighbour___32 *, struct sk_buff___45 *);
	int (*output)(struct neighbour___32 *, struct sk_buff___45 *);
	int (*connected_output)(struct neighbour___32 *, struct sk_buff___45 *);
};

struct pneigh_entry___32 {
	struct pneigh_entry___32 *next;
	struct net___55 *net;
	struct net_device___43 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___32 {
	struct neighbour___32 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___13 {
	struct dst_entry___32 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___21;

struct inet_hashinfo___3;

struct proto___32 {
	void (*close)(struct sock___34 *, long int);
	int (*connect)(struct sock___34 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___34 *, int);
	struct sock___34 * (*accept)(struct sock___34 *, int, int *);
	int (*ioctl)(struct sock___34 *, int, long unsigned int);
	int (*init)(struct sock___34 *);
	void (*destroy)(struct sock___34 *);
	void (*shutdown)(struct sock___34 *, int);
	int (*setsockopt)(struct sock___34 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___34 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___34 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___34 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___34 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___40 *, struct sock___34 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___40 *, struct sock___34 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___34 *, struct page___249 *, int, size_t, int);
	int (*bind)(struct sock___34 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___34 *, struct sk_buff___45 *);
	void (*release_cb)(struct sock___34 *);
	void (*mtu_reduced)(struct sock___34 *);
	void (*hash)(struct sock___34 *);
	void (*unhash)(struct sock___34 *);
	void (*rehash)(struct sock___34 *);
	int (*get_port)(struct sock___34 *, short unsigned int);
	void (*clear_sk)(struct sock___34 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___34 *);
	void (*enter_memory_pressure)(struct sock___34 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___233 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___23 *rsk_prot;
	struct timewait_sock_ops___21 *twsk_prot;
	union {
		struct inet_hashinfo___3 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___153 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___80 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___32 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___32 {
	void (*enter_memory_pressure)(struct sock___34 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___3 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___233 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___23 {
	int family;
	int obj_size;
	struct kmem_cache___233 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___34 *, struct request_sock___24 *);
	void (*send_ack)(struct sock___34 *, struct sk_buff___45 *, struct request_sock___24 *);
	void (*send_reset)(struct sock___34 *, struct sk_buff___45 *);
	void (*destructor)(struct request_sock___24 *);
	void (*syn_ack_timeout)(struct sock___34 *, struct request_sock___24 *);
};

struct timewait_sock_ops___21 {
	struct kmem_cache___233 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___34 *, struct sock___34 *, void *);
	void (*twsk_destructor)(struct sock___34 *);
};

struct ifmcaddr6___18 {
	struct in6_addr mca_addr;
	struct inet6_dev___18 *idev;
	struct ifmcaddr6___18 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___18 {
	struct in6_addr aca_addr;
	struct inet6_dev___18 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___18 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct gnet_dump___5 {
	spinlock_t *lock;
	struct sk_buff___45 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___4;

struct Qdisc_ops___4 {
	struct Qdisc_ops___4 *next;
	const struct Qdisc_class_ops___4 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___45 *, struct Qdisc___4 *);
	struct sk_buff___45 * (*dequeue)(struct Qdisc___4 *);
	struct sk_buff___45 * (*peek)(struct Qdisc___4 *);
	unsigned int (*drop)(struct Qdisc___4 *);
	int (*init)(struct Qdisc___4 *, struct nlattr *);
	void (*reset)(struct Qdisc___4 *);
	void (*destroy)(struct Qdisc___4 *);
	int (*change)(struct Qdisc___4 *, struct nlattr *);
	void (*attach)(struct Qdisc___4 *);
	int (*dump)(struct Qdisc___4 *, struct sk_buff___45 *);
	int (*dump_stats)(struct Qdisc___4 *, struct gnet_dump___5 *);
	struct module___153 *owner;
};

struct qdisc_walker___4;

struct tcf_proto___4;

struct Qdisc_class_ops___4 {
	struct netdev_queue___41 * (*select_queue)(struct Qdisc___4 *, struct tcmsg *);
	int (*graft)(struct Qdisc___4 *, long unsigned int, struct Qdisc___4 *, struct Qdisc___4 **);
	struct Qdisc___4 * (*leaf)(struct Qdisc___4 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___4 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___4 *, u32);
	void (*put)(struct Qdisc___4 *, long unsigned int);
	int (*change)(struct Qdisc___4 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___4 *, long unsigned int);
	void (*walk)(struct Qdisc___4 *, struct qdisc_walker___4 *);
	struct tcf_proto___4 ** (*tcf_chain)(struct Qdisc___4 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___4 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___4 *, long unsigned int);
	int (*dump)(struct Qdisc___4 *, long unsigned int, struct sk_buff___45 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___4 *, long unsigned int, struct gnet_dump___5 *);
};

struct qdisc_walker___4 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___4 *, long unsigned int, struct qdisc_walker___4 *);
};

struct tcf_proto_ops___4;

struct tcf_proto___4 {
	struct tcf_proto___4 *next;
	void *root;
	int (*classify)(struct sk_buff___45 *, const struct tcf_proto___4 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___4 *q;
	void *data;
	const struct tcf_proto_ops___4 *ops;
};

struct tcf_proto_ops___4 {
	struct tcf_proto_ops___4 *next;
	char kind[16];
	int (*classify)(struct sk_buff___45 *, const struct tcf_proto___4 *, struct tcf_result *);
	int (*init)(struct tcf_proto___4 *);
	void (*destroy)(struct tcf_proto___4 *);
	long unsigned int (*get)(struct tcf_proto___4 *, u32);
	void (*put)(struct tcf_proto___4 *, long unsigned int);
	int (*change)(struct net___55 *, struct sk_buff___45 *, struct tcf_proto___4 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___4 *, long unsigned int);
	void (*walk)(struct tcf_proto___4 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___4 *, long unsigned int, struct sk_buff___45 *, struct tcmsg *);
	struct module___153 *owner;
};

struct fib_rule_hdr {
	__u8 family;
	__u8 dst_len;
	__u8 src_len;
	__u8 tos;
	__u8 table;
	__u8 res1;
	__u8 res2;
	__u8 action;
	__u32 flags;
};

struct fib_rule {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___55 *fr_net;
};

struct fib_lookup_arg {
	void *lookup_ptr;
	void *result;
	struct fib_rule *rule;
	int flags;
};

struct rtnl_link {
	rtnl_doit_func___3 doit;
	rtnl_dumpit_func___3 dumpit;
	rtnl_calcit_func___3 calcit;
};

struct __net_random_once_work {
	struct work_struct work;
	struct static_key *key;
};

struct page___250;

typedef struct page___250 *pgtable_t___250;

struct address_space___251;

struct kmem_cache___234;

struct page___250 {
	long unsigned int flags;
	struct address_space___251 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___250 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___250 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___234 *slab_cache;
		struct page___250 *first_page;
	};
	long: 64;
};

struct task_struct___252;

struct pv_cpu_ops___252 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___252 *);
	void (*end_context_switch)(struct task_struct___252 *);
};

struct mutex___253 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___252 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___245 {
	struct page___250 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___259;

struct nsproxy___132;

struct signal_struct___252;

struct css_set___147;

struct task_struct___252 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___252 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___259 *mm;
	struct mm_struct___259 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___252 *real_parent;
	struct task_struct___252 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___252 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___252 = 0,
		VTIME_USER___252 = 1,
		VTIME_SYS___252 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___132 *nsproxy;
	struct signal_struct___252 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___147 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___253 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___245 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___259 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___259 *, struct mm_struct___259 *);
	void (*dup_mmap)(struct mm_struct___259 *, struct mm_struct___259 *);
	void (*exit_mmap)(struct mm_struct___259 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___259 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___259 *);
	void (*pgd_free)(struct mm_struct___259 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___259 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___259 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___259 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___259 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___259 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___259 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___259 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___259 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___259 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___259 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___259 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___253 lock;
	void *vdso;
} mm_context_t___253;

struct xol_area___250;

struct uprobes_state___250 {
	struct xol_area___250 *xol_area;
};

struct vm_area_struct___259;

struct file___251;

struct core_state___252;

struct mm_struct___259 {
	struct vm_area_struct___259 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___259 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___259 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___253 context;
	long unsigned int flags;
	struct core_state___252 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___252 *owner;
	struct file___251 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___250 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___36;

struct kobj_type___36;

struct kobject___36 {
	const char *name;
	struct list_head entry;
	struct kobject___36 *parent;
	struct kset___36 *kset;
	struct kobj_type___36 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___154;

struct module_kobject___152 {
	struct kobject___36 kobj;
	struct module___154 *mod;
	struct kobject___36 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___152;

struct module___154 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___152 mkobj;
	struct module_attribute___152 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___36 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___252 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___252;

struct lruvec___252 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___252 *zone;
};

struct pglist_data___252;

struct zone___252 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___252 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___252 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___252 {
	struct zone___252 *zone;
	int zone_idx;
};

struct zonelist___252 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___252 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___252 {
	struct zone___252 node_zones[4];
	struct zonelist___252 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___252 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___175;

struct x86_io_apic_ops___175 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___175 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___175;

struct irq_data___175 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___175 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___249;

struct dev_pm_ops___249 {
	int (*prepare)(struct device___249 *);
	void (*complete)(struct device___249 *);
	int (*suspend)(struct device___249 *);
	int (*resume)(struct device___249 *);
	int (*freeze)(struct device___249 *);
	int (*thaw)(struct device___249 *);
	int (*poweroff)(struct device___249 *);
	int (*restore)(struct device___249 *);
	int (*suspend_late)(struct device___249 *);
	int (*resume_early)(struct device___249 *);
	int (*freeze_late)(struct device___249 *);
	int (*thaw_early)(struct device___249 *);
	int (*poweroff_late)(struct device___249 *);
	int (*restore_early)(struct device___249 *);
	int (*suspend_noirq)(struct device___249 *);
	int (*resume_noirq)(struct device___249 *);
	int (*freeze_noirq)(struct device___249 *);
	int (*thaw_noirq)(struct device___249 *);
	int (*poweroff_noirq)(struct device___249 *);
	int (*restore_noirq)(struct device___249 *);
	int (*runtime_suspend)(struct device___249 *);
	int (*runtime_resume)(struct device___249 *);
	int (*runtime_idle)(struct device___249 *);
};

struct dev_pm_qos___53;

struct dev_pm_info___53 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___53 *qos;
};

struct dma_map_ops___114;

struct dev_archdata___114 {
	struct dma_map_ops___114 *dma_ops;
	void *iommu;
};

struct device_type___249;

struct bus_type___249;

struct device_driver___249;

struct dev_pm_domain___249;

struct class___249;

struct attribute_group___211;

struct device_rh___249;

struct device___249 {
	struct device___249 *parent;
	struct device_private *p;
	struct kobject___36 kobj;
	const char *init_name;
	const struct device_type___249 *type;
	struct mutex___253 mutex;
	struct bus_type___249 *bus;
	struct device_driver___249 *driver;
	void *platform_data;
	struct dev_pm_info___53 power;
	struct dev_pm_domain___249 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___114 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___249 *class;
	const struct attribute_group___211 **groups;
	void (*release)(struct device___249 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___249 *device_rh;
};

struct dev_pm_qos_request___54;

struct dev_pm_qos___53 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___54 *latency_req;
	struct dev_pm_qos_request___54 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___54 *latency_tolerance_req;
};

struct dev_pm_info_rh___249 {
	void (*set_latency_tolerance)(struct device___249 *, s32);
};

struct dev_pm_domain___249 {
	struct dev_pm_ops___249 ops;
};

struct smp_ops___252 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___252 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___57;

struct ctl_node___57 {
	struct rb_node node;
	struct ctl_table_header___57 *header;
};

struct ctl_table_root___57;

struct ctl_table_set___57;

struct ctl_dir___57;

struct ctl_table_header___57 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___57 *root;
	struct ctl_table_set___57 *set;
	struct ctl_dir___57 *parent;
	struct ctl_node___57 *node;
};

struct ctl_dir___57 {
	struct ctl_table_header___57 header;
	struct rb_root root;
};

struct ctl_table_set___57 {
	int (*is_seen)(struct ctl_table_set___57 *);
	struct ctl_dir___57 dir;
};

struct ctl_table_root___57 {
	struct ctl_table_set___57 default_set;
	struct ctl_table_set___57 * (*lookup)(struct ctl_table_root___57 *, struct nsproxy___132 *);
	int (*permissions)(struct ctl_table_header___57 *, struct ctl_table *);
};

struct net___56;

struct nsproxy___132 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___56 *net_ns;
};

struct sock___35;

struct kobj_ns_type_operations___33 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___35 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___33;

struct sock_common___33 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___33 *skc_prot;
	struct net___56 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___46;

struct sk_buff_head___43 {
	struct sk_buff___46 *next;
	struct sk_buff___46 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___34;

struct socket_wq___33;

struct dst_entry___33;

struct socket___34;

struct cg_proto___33;

struct sock___35 {
	struct sock_common___33 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___43 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___46 *head;
		struct sk_buff___46 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___34 *sk_filter;
	struct socket_wq___33 *sk_wq;
	struct sk_buff_head___43 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___33 *sk_rx_dst;
	struct dst_entry___33 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___43 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___43 sk_error_queue;
	struct proto___33 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___34 *sk_socket;
	void *sk_user_data;
	struct page_frag___245 sk_frag;
	struct sk_buff___46 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___33 *sk_cgrp;
	void (*sk_state_change)(struct sock___35 *);
	void (*sk_data_ready)(struct sock___35 *, int);
	void (*sk_write_space)(struct sock___35 *);
	void (*sk_error_report)(struct sock___35 *);
	int (*sk_backlog_rcv)(struct sock___35 *, struct sk_buff___46 *);
	void (*sk_destruct)(struct sock___35 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___213;

struct attribute_group___211 {
	const char *name;
	umode_t (*is_visible)(struct kobject___36 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___213 **bin_attrs;
};

struct bin_attribute___213 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___251 *, struct kobject___36 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___251 *, struct kobject___36 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	int (*mmap)(struct file___251 *, struct kobject___36 *, struct bin_attribute___213 *, struct vm_area_struct___259 *);
};

struct dentry___251;

struct path___251 {
	struct vfsmount *mnt;
	struct dentry___251 *dentry;
};

struct inode___251;

struct file_operations___251;

struct file___251 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___251 f_path;
	struct inode___251 *f_inode;
	const struct file_operations___251 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___251 *f_mapping;
	struct mutex___253 f_pos_lock;
};

struct vm_operations_struct___225;

struct vm_area_struct___259 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___259 *vm_next;
	struct vm_area_struct___259 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___259 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___225 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___251 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___36 {
	ssize_t (*show)(struct kobject___36 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___36 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___36 *, const struct attribute *);
};

struct kset_uevent_ops___36;

struct kset___36 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___36 kobj;
	const struct kset_uevent_ops___36 *uevent_ops;
};

struct kobj_type___36 {
	void (*release)(struct kobject___36 *);
	const struct sysfs_ops___36 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___33 * (*child_ns_type)(struct kobject___36 *);
	const void * (*namespace)(struct kobject___36 *);
};

struct kset_uevent_ops___36 {
	int (* const filter)(struct kset___36 *, struct kobject___36 *);
	const char * (* const name)(struct kset___36 *, struct kobject___36 *);
	int (* const uevent)(struct kset___36 *, struct kobject___36 *, struct kobj_uevent_env *);
};

struct module_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___152 *, struct module_kobject___152 *, char *);
	ssize_t (*store)(struct module_attribute___152 *, struct module_kobject___152 *, const char *, size_t);
	void (*setup)(struct module___154 *, const char *);
	int (*test)(struct module___154 *);
	void (*free)(struct module___154 *);
};

struct kiocb___41;

struct poll_table_struct___140;

struct file_lock___251;

struct seq_file___176;

struct file_operations___251 {
	struct module___154 *owner;
	loff_t (*llseek)(struct file___251 *, loff_t, int);
	ssize_t (*read)(struct file___251 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___251 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___41 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___41 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___251 *, void *, filldir_t);
	unsigned int (*poll)(struct file___251 *, struct poll_table_struct___140 *);
	long int (*unlocked_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___251 *, struct vm_area_struct___259 *);
	int (*open)(struct inode___251 *, struct file___251 *);
	int (*flush)(struct file___251 *, fl_owner_t);
	int (*release)(struct inode___251 *, struct file___251 *);
	int (*fsync)(struct file___251 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___41 *, int);
	int (*fasync)(int, struct file___251 *, int);
	int (*lock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*sendpage)(struct file___251 *, struct page___250 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___251 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___251 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___251 *, long int, struct file_lock___251 **, void **);
		struct {
			int (*setlease)(struct file___251 *, long int, struct file_lock___251 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___251 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___176 *, struct file___251 *);
};

struct dma_map_ops___114 {
	void * (*alloc)(struct device___249 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___249 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___249 *, struct vm_area_struct___259 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___249 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___249 *, struct page___250 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___249 *, dma_addr_t);
	int (*dma_supported)(struct device___249 *, u64);
	int (*set_dma_mask)(struct device___249 *, u64);
	int is_phys;
};

struct bus_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___249 *, char *);
	ssize_t (*store)(struct bus_type___249 *, const char *, size_t);
};

struct device_attribute___249;

struct driver_attribute___249;

struct bus_type___249 {
	const char *name;
	const char *dev_name;
	struct device___249 *dev_root;
	struct bus_attribute___249 *bus_attrs;
	struct device_attribute___249 *dev_attrs;
	struct driver_attribute___249 *drv_attrs;
	const struct attribute_group___211 **bus_groups;
	const struct attribute_group___211 **dev_groups;
	const struct attribute_group___211 **drv_groups;
	int (*match)(struct device___249 *, struct device_driver___249 *);
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	int (*probe)(struct device___249 *);
	int (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*online)(struct device___249 *);
	int (*offline)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct device___249 *, struct device_attribute___249 *, char *);
	ssize_t (*store)(struct device___249 *, struct device_attribute___249 *, const char *, size_t);
};

struct driver_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___249 *, char *);
	ssize_t (*store)(struct device_driver___249 *, const char *, size_t);
};

struct device_driver___249 {
	const char *name;
	struct bus_type___249 *bus;
	struct module___154 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___249 *);
	int (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	const struct attribute_group___211 **groups;
	const struct dev_pm_ops___249 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___249 {
	const char *name;
	const struct attribute_group___211 **groups;
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
};

struct class_attribute___249;

struct class___249 {
	const char *name;
	struct module___154 *owner;
	struct class_attribute___249 *class_attrs;
	struct device_attribute___249 *dev_attrs;
	const struct attribute_group___211 **dev_groups;
	struct bin_attribute___213 *dev_bin_attrs;
	struct kobject___36 *dev_kobj;
	int (*dev_uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *);
	void (*class_release)(struct class___249 *);
	void (*dev_release)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	const struct kobj_ns_type_operations___33 *ns_type;
	const void * (*namespace)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
	struct subsys_private *p;
};

struct class_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct class___249 *, struct class_attribute___249 *, char *);
	ssize_t (*store)(struct class___249 *, struct class_attribute___249 *, const char *, size_t);
	const void * (*namespace)(struct class___249 *, const struct class_attribute___249 *);
};

struct device_rh___249 {
	struct dev_pm_info_rh___249 power;
};

struct dev_pm_qos_request___54 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___249 *dev;
};

struct xol_area___250 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___250 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___233;

struct memcg_cache_params___234;

struct kmem_cache___234 {
	struct kmem_cache_cpu___233 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___36 kobj;
	struct memcg_cache_params___234 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___251;

struct address_space___251 {
	struct inode___251 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___253 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___251 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___221;

struct vm_operations_struct___225 {
	void (*open)(struct vm_area_struct___259 *);
	void (*close)(struct vm_area_struct___259 *);
	int (*fault)(struct vm_area_struct___259 *, struct vm_fault___221 *);
	int (*page_mkwrite)(struct vm_area_struct___259 *, struct vm_fault___221 *);
	int (*access)(struct vm_area_struct___259 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___259 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___259 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___259 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___259 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___252 {
	struct task_struct___252 *task;
	struct core_thread___252 *next;
};

struct core_state___252 {
	atomic_t nr_threads;
	struct core_thread___252 dumper;
	struct completion startup;
};

struct vm_fault___221 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___250 *page;
};

enum {
	IF_LINK_MODE_DEFAULT = 0,
	IF_LINK_MODE_DORMANT = 1,
};

struct dentry_operations___251;

struct super_block___251;

struct dentry___251 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___251 *d_parent;
	struct qstr d_name;
	struct inode___251 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___251 *d_op;
	struct super_block___251 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___251;

struct dquot___251;

struct block_device___251;

struct inode___251 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___251 *i_op;
	struct super_block___251 *i_sb;
	struct address_space___251 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___253 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___251 *i_fop;
	struct file_lock___251 *i_flock;
	struct address_space___251 i_data;
	struct dquot___251 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___251 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___251 {
	int (*d_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_hash)(const struct dentry___251 *, struct qstr *);
	int (*d_compare)(const struct dentry___251 *, const struct dentry___251 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___251 *);
	void (*d_release)(struct dentry___251 *);
	void (*d_prune)(struct dentry___251 *);
	void (*d_iput)(struct dentry___251 *, struct inode___251 *);
	char * (*d_dname)(struct dentry___251 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___251 *);
	int (*d_manage)(struct dentry___251 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___251;

struct mem_dqinfo___251 {
	struct quota_format_type___251 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___251;

struct quota_info___251 {
	unsigned int flags;
	struct mutex___253 dqio_mutex;
	struct mutex___253 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___251 *files[2];
	struct mem_dqinfo___251 info[2];
	const struct quota_format_ops___251 *ops[2];
};

struct file_system_type___251;

struct super_operations___251;

struct dquot_operations___251;

struct quotactl_ops___251;

struct xattr_handler___148;

struct super_block___251 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___251 *s_type;
	const struct super_operations___251 *s_op;
	const struct dquot_operations___251 *dq_op;
	const struct quotactl_ops___251 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___251 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___148 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___251 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___251 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___253 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___251 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___251 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___251 *bd_inode;
	struct super_block___251 *bd_super;
	struct mutex___253 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___251 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___253 bd_fsfreeze_mutex;
};

struct cgroup___147;

struct cgroup_subsys_state___147 {
	struct cgroup___147 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___41(struct kiocb___41 *, struct io_event *);

struct kiocb___41 {
	atomic_t ki_users;
	struct file___251 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___41 *ki_cancel;
	void (*ki_dtor)(struct kiocb___41 *);
	union {
		void *user;
		struct task_struct___252 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___251 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___251 *ia_file;
};

struct dquot___251 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___253 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___251 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___251 {
	int qf_fmt_id;
	const struct quota_format_ops___251 *qf_ops;
	struct module___154 *qf_owner;
	struct quota_format_type___251 *qf_next;
};

struct quota_format_ops___251 {
	int (*check_quota_file)(struct super_block___251 *, int);
	int (*read_file_info)(struct super_block___251 *, int);
	int (*write_file_info)(struct super_block___251 *, int);
	int (*free_file_info)(struct super_block___251 *, int);
	int (*read_dqblk)(struct dquot___251 *);
	int (*commit_dqblk)(struct dquot___251 *);
	int (*release_dqblk)(struct dquot___251 *);
};

struct dquot_operations___251 {
	int (*write_dquot)(struct dquot___251 *);
	struct dquot___251 * (*alloc_dquot)(struct super_block___251 *, int);
	void (*destroy_dquot)(struct dquot___251 *);
	int (*acquire_dquot)(struct dquot___251 *);
	int (*release_dquot)(struct dquot___251 *);
	int (*mark_dirty)(struct dquot___251 *);
	int (*write_info)(struct super_block___251 *, int);
	qsize_t * (*get_reserved_space)(struct inode___251 *);
};

struct quotactl_ops___251 {
	int (*quota_on)(struct super_block___251 *, int, int, struct path___251 *);
	int (*quota_on_meta)(struct super_block___251 *, int, int);
	int (*quota_off)(struct super_block___251 *, int);
	int (*quota_sync)(struct super_block___251 *, int);
	int (*get_info)(struct super_block___251 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___251 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___251 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___251 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___251 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___251 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___251 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___251 *, unsigned int);
};

struct address_space_operations___251 {
	int (*writepage)(struct page___250 *, struct writeback_control *);
	int (*readpage)(struct file___251 *, struct page___250 *);
	int (*writepages)(struct address_space___251 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___250 *);
	int (*readpages)(struct file___251 *, struct address_space___251 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___251 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___250 **, void **);
	int (*write_end)(struct file___251 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___250 *, void *);
	sector_t (*bmap)(struct address_space___251 *, sector_t);
	void (*invalidatepage)(struct page___250 *, long unsigned int);
	int (*releasepage)(struct page___250 *, gfp_t);
	void (*freepage)(struct page___250 *);
	ssize_t (*direct_IO)(int, struct kiocb___41 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___251 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___251 *, struct page___250 *, struct page___250 *, enum migrate_mode);
	int (*launder_page)(struct page___250 *);
	int (*is_partially_uptodate)(struct page___250 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___250 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___251 *, struct page___250 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___251 *, sector_t *);
	void (*swap_deactivate)(struct file___251 *);
	void (*invalidatepage_range)(struct page___250 *, unsigned int, unsigned int);
};

struct inode_operations___251 {
	struct dentry___251 * (*lookup)(struct inode___251 *, struct dentry___251 *, unsigned int);
	void * (*follow_link)(struct dentry___251 *, struct nameidata *);
	int (*permission)(struct inode___251 *, int);
	struct posix_acl * (*get_acl)(struct inode___251 *, int);
	int (*readlink)(struct dentry___251 *, char *, int);
	void (*put_link)(struct dentry___251 *, struct nameidata *, void *);
	int (*create)(struct inode___251 *, struct dentry___251 *, umode_t, bool);
	int (*link)(struct dentry___251 *, struct inode___251 *, struct dentry___251 *);
	int (*unlink)(struct inode___251 *, struct dentry___251 *);
	int (*symlink)(struct inode___251 *, struct dentry___251 *, const char *);
	int (*mkdir)(struct inode___251 *, struct dentry___251 *, umode_t);
	int (*rmdir)(struct inode___251 *, struct dentry___251 *);
	int (*mknod)(struct inode___251 *, struct dentry___251 *, umode_t, dev_t);
	int (*rename)(struct inode___251 *, struct dentry___251 *, struct inode___251 *, struct dentry___251 *);
	int (*setattr)(struct dentry___251 *, struct iattr___251 *);
	int (*getattr)(struct vfsmount *, struct dentry___251 *, struct kstat *);
	int (*setxattr)(struct dentry___251 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___251 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___251 *, char *, size_t);
	int (*removexattr)(struct dentry___251 *, const char *);
	int (*fiemap)(struct inode___251 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___251 *, struct timespec *, int);
	int (*atomic_open)(struct inode___251 *, struct dentry___251 *, struct file___251 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___251;

struct file_lock_operations___251;

struct lock_manager_operations___251;

struct file_lock___251 {
	struct file_lock___251 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___251 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___251 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___251 *fl_ops;
	const struct lock_manager_operations___251 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___251 {
	void (*fl_copy_lock)(struct file_lock___251 *, struct file_lock___251 *);
	void (*fl_release_private)(struct file_lock___251 *);
};

struct lock_manager_operations___251 {
	int (*lm_compare_owner)(struct file_lock___251 *, struct file_lock___251 *);
	long unsigned int (*lm_owner_key)(struct file_lock___251 *);
	void (*lm_notify)(struct file_lock___251 *);
	int (*lm_grant)(struct file_lock___251 *, struct file_lock___251 *, int);
	void (*lm_break)(struct file_lock___251 *);
	int (*lm_change)(struct file_lock___251 **, int);
};

struct fasync_struct___251 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___251 *fa_next;
	struct file___251 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___251 {
	const char *name;
	int fs_flags;
	struct dentry___251 * (*mount)(struct file_system_type___251 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___251 *);
	struct module___154 *owner;
	struct file_system_type___251 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___251 {
	struct inode___251 * (*alloc_inode)(struct super_block___251 *);
	void (*destroy_inode)(struct inode___251 *);
	void (*dirty_inode)(struct inode___251 *, int);
	int (*write_inode)(struct inode___251 *, struct writeback_control *);
	int (*drop_inode)(struct inode___251 *);
	void (*evict_inode)(struct inode___251 *);
	void (*put_super)(struct super_block___251 *);
	int (*sync_fs)(struct super_block___251 *, int);
	int (*freeze_fs)(struct super_block___251 *);
	int (*unfreeze_fs)(struct super_block___251 *);
	int (*statfs)(struct dentry___251 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___251 *, int *, char *);
	void (*umount_begin)(struct super_block___251 *);
	int (*show_options)(struct seq_file___176 *, struct dentry___251 *);
	int (*show_devname)(struct seq_file___176 *, struct dentry___251 *);
	int (*show_path)(struct seq_file___176 *, struct dentry___251 *);
	int (*show_stats)(struct seq_file___176 *, struct dentry___251 *);
	ssize_t (*quota_read)(struct super_block___251 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___251 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___251 *);
	int (*bdev_try_to_free_page)(struct super_block___251 *, struct page___250 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___251 *);
	void (*free_cached_objects)(struct super_block___251 *, int);
};

struct xattr_handler___148 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___251 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___251 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___251 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___142)(struct file___251 *, wait_queue_head_t *, struct poll_table_struct___140 *);

struct poll_table_struct___140 {
	poll_queue_proc___142 _qproc;
	long unsigned int _key;
};

struct seq_operations___176;

struct seq_file___176 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___253 lock;
	const struct seq_operations___176 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___252 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___252 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___252 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___253 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___147 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___147 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___33 {
	wait_queue_head_t wait;
	struct fasync_struct___251 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___33;

struct socket___34 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___33 *wq;
	struct file___251 *file;
	struct sock___35 *sk;
	const struct proto_ops___33 *ops;
};

struct proto_ops___33 {
	int family;
	struct module___154 *owner;
	int (*release)(struct socket___34 *);
	int (*bind)(struct socket___34 *, struct sockaddr *, int);
	int (*connect)(struct socket___34 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___34 *, struct socket___34 *);
	int (*accept)(struct socket___34 *, struct socket___34 *, int);
	int (*getname)(struct socket___34 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___251 *, struct socket___34 *, struct poll_table_struct___140 *);
	int (*ioctl)(struct socket___34 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___34 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___34 *, int);
	int (*shutdown)(struct socket___34 *, int);
	int (*setsockopt)(struct socket___34 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___34 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___34 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___34 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___41 *, struct socket___34 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___41 *, struct socket___34 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___251 *, struct socket___34 *, struct vm_area_struct___259 *);
	ssize_t (*sendpage)(struct socket___34 *, struct page___250 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___34 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___35 *, int);
		struct {
			void (*set_peek_off)(struct sock___35 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___54 {
	struct ctl_table_header___57 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___54 {
	struct mutex___253 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___54 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___57 *ctl;
};

struct netns_ipv4___54 {
	struct ctl_table_header___57 *forw_hdr;
	struct ctl_table_header___57 *frags_hdr;
	struct ctl_table_header___57 *ipv4_hdr;
	struct ctl_table_header___57 *route_hdr;
	struct ctl_table_header___57 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___35 *fibnl;
	struct sock___35 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___54 {
	struct ctl_table_header___57 *hdr;
	struct ctl_table_header___57 *route_hdr;
	struct ctl_table_header___57 *icmp_hdr;
	struct ctl_table_header___57 *frags_hdr;
	struct ctl_table_header___57 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___33;

struct dst_ops___55 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___55 *);
	struct dst_entry___33 * (*check)(struct dst_entry___33 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___33 *);
	unsigned int (*mtu)(const struct dst_entry___33 *);
	u32 * (*cow_metrics)(struct dst_entry___33 *, long unsigned int);
	void (*destroy)(struct dst_entry___33 *);
	void (*ifdown)(struct dst_entry___33 *, struct net_device___3 *, int);
	struct dst_entry___33 * (*negative_advice)(struct dst_entry___33 *);
	void (*link_failure)(struct sk_buff___46 *);
	void (*update_pmtu)(struct dst_entry___33 *, struct sock___35 *, struct sk_buff___46 *, u32);
	void (*redirect)(struct dst_entry___33 *, struct sock___35 *, struct sk_buff___46 *);
	int (*local_out)(struct sk_buff___46 *);
	struct neighbour___33 * (*neigh_lookup)(const struct dst_entry___33 *, struct sk_buff___46 *, const void *);
	struct kmem_cache___234 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___55 {
	struct netns_sysctl_ipv6___54 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___55 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___35 **icmp_sk;
	struct sock___35 *ndisc_sk;
	struct sock___35 *tcp_sk;
	struct sock___35 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___54 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___57 *sysctl_header;
	struct sock___35 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___33 {
	struct sock___35 *v4_ctl_sk;
	struct sock___35 *v6_ctl_sk;
};

struct netns_nf___54 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___57 *nf_log_dir_header;
};

struct nf_proto_net___54 {
	struct ctl_table_header___57 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___54 {
	struct nf_proto_net___54 pn;
	unsigned int timeout;
};

struct nf_tcp_net___54 {
	struct nf_proto_net___54 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___54 {
	struct nf_proto_net___54 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___54 {
	struct nf_proto_net___54 pn;
	unsigned int timeout;
};

struct nf_ip_net___54 {
	struct nf_generic_net___54 generic;
	struct nf_tcp_net___54 tcp;
	struct nf_udp_net___54 udp;
	struct nf_icmp_net___54 icmp;
	struct nf_icmp_net___54 icmpv6;
};

struct netns_ct___54 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___57 *sysctl_header;
	struct ctl_table_header___57 *acct_sysctl_header;
	struct ctl_table_header___57 *tstamp_sysctl_header;
	struct ctl_table_header___57 *event_sysctl_header;
	struct ctl_table_header___57 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___234 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___54 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___54 {
	struct netns_sysctl_ipv6___54 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___55 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___35 *nlsk;
	struct sock___35 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___57 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___55 xfrm4_dst_ops;
	struct dst_ops___55 xfrm6_dst_ops;
};

struct net___56 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___57 sysctls;
	struct sock___35 *rtnl;
	struct sock___35 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___3 *loopback_dev;
	struct netns_core___54 core;
	struct netns_mib mib;
	struct netns_packet___54 packet;
	struct netns_unix___54 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___54 ipv4;
	struct netns_ipv6___55 ipv6;
	struct netns_sctp___54 sctp;
	struct netns_dccp___33 dccp;
	struct netns_nf___54 nf;
	struct netns_xt xt;
	struct netns_ct___54 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___54 nf_frag;
	struct sock___35 *nfnl;
	struct sock___35 *nfnl_stash;
	struct sk_buff_head___43 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___55 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___35 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___35 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___253 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___253 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___233 {
	void **freelist;
	long unsigned int tid;
	struct page___250 *page;
	struct page___250 *partial;
};

struct memcg_cache_params___234 {
	bool is_root_cache;
	union {
		struct kmem_cache___234 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___234 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___42 {
	atomic_t use;
	unsigned int mask;
	struct net_device___3 *physindev;
	struct net_device___3 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___42(struct sk_buff___46 **);

struct net_device_ops___42;

struct ethtool_ops___42;

struct header_ops___42;

struct netdev_rx_queue___42;

struct netdev_queue___42;

struct Qdisc___5;

struct rtnl_link_ops___33;

struct dcbnl_rtnl_ops___42;

struct net_device___3 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___42 *netdev_ops;
	const struct ethtool_ops___42 *ethtool_ops;
	const struct header_ops___42 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___36 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___42 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___42 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___42 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___42 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___5 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___42 = 0,
		NETREG_REGISTERED___42 = 1,
		NETREG_UNREGISTERING___42 = 2,
		NETREG_UNREGISTERED___42 = 3,
		NETREG_RELEASED___42 = 4,
		NETREG_DUMMY___42 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___42 = 0,
		RTNL_LINK_INITIALIZING___42 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___3 *);
	struct netpoll_info *npinfo;
	struct net___56 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___249 dev;
	const struct attribute_group___211 *sysfs_groups[4];
	const struct rtnl_link_ops___33 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___42 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___46 {
	struct sk_buff___46 *next;
	struct sk_buff___46 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___35 *sk;
	struct net_device___3 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___46 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___42 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___42 {
	int (*get_settings)(struct net_device___3 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___3 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___3 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___3 *);
	void (*get_regs)(struct net_device___3 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___3 *);
	void (*set_msglevel)(struct net_device___3 *, u32);
	int (*nway_reset)(struct net_device___3 *);
	u32 (*get_link)(struct net_device___3 *);
	int (*get_eeprom_len)(struct net_device___3 *);
	int (*get_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___3 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___3 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___3 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___3 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___3 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___3 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___3 *);
	void (*complete)(struct net_device___3 *);
	u32 (*get_priv_flags)(struct net_device___3 *);
	int (*set_priv_flags)(struct net_device___3 *, u32);
	int (*get_sset_count)(struct net_device___3 *, int);
	int (*get_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___3 *, struct ethtool_flash *);
	int (*reset)(struct net_device___3 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___3 *);
	int (*get_rxfh_indir)(struct net_device___3 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___3 *, const u32 *);
	void (*get_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___3 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___3 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___3 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___3 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___3 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___3 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___3 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___3 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___33 {
	struct callback_head callback_head;
	struct dst_entry___33 *child;
	struct net_device___3 *dev;
	struct dst_ops___55 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___33 *path;
	struct dst_entry___33 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___46 *);
	union {
		int (*output)(struct sock___35 *, struct sk_buff___46 *);
		struct {
			int (*output)(struct sk_buff___46 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___33 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___33;

struct neigh_parms___33;

struct neigh_ops___33;

struct neighbour___33 {
	struct neighbour___33 *next;
	struct neigh_table___33 *tbl;
	struct neigh_parms___33 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___43 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___33 *, struct sk_buff___46 *);
	const struct neigh_ops___33 *ops;
	struct callback_head rcu;
	struct net_device___3 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___55 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___46 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___46 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___56 *, struct dst_entry___33 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___46 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___46 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___175 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___175 *);
	void (*irq_shutdown)(struct irq_data___175 *);
	void (*irq_enable)(struct irq_data___175 *);
	void (*irq_disable)(struct irq_data___175 *);
	void (*irq_ack)(struct irq_data___175 *);
	void (*irq_mask)(struct irq_data___175 *);
	void (*irq_mask_ack)(struct irq_data___175 *);
	void (*irq_unmask)(struct irq_data___175 *);
	void (*irq_eoi)(struct irq_data___175 *);
	int (*irq_set_affinity)(struct irq_data___175 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___175 *);
	int (*irq_set_type)(struct irq_data___175 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___175 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___175 *);
	void (*irq_bus_sync_unlock)(struct irq_data___175 *);
	void (*irq_cpu_online)(struct irq_data___175 *);
	void (*irq_cpu_offline)(struct irq_data___175 *);
	void (*irq_suspend)(struct irq_data___175 *);
	void (*irq_resume)(struct irq_data___175 *);
	void (*irq_pm_shutdown)(struct irq_data___175 *);
	void (*irq_print_chip)(struct irq_data___175 *, struct seq_file___176 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___175 *, void *);
	long unsigned int flags;
};

struct seq_operations___176 {
	void * (*start)(struct seq_file___176 *, loff_t *);
	void (*stop)(struct seq_file___176 *, void *);
	void * (*next)(struct seq_file___176 *, void *, loff_t *);
	int (*show)(struct seq_file___176 *, void *);
};

struct dcbnl_rtnl_ops___42 {
	int (*ieee_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___3 *);
	u8 (*setstate)(struct net_device___3 *, u8);
	void (*getpermhwaddr)(struct net_device___3 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___3 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___3 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___3 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___3 *, int, u8 *);
	void (*setpfccfg)(struct net_device___3 *, int, u8);
	void (*getpfccfg)(struct net_device___3 *, int, u8 *);
	u8 (*setall)(struct net_device___3 *);
	u8 (*getcap)(struct net_device___3 *, int, u8 *);
	int (*getnumtcs)(struct net_device___3 *, int, u8 *);
	int (*setnumtcs)(struct net_device___3 *, int, u8);
	u8 (*getpfcstate)(struct net_device___3 *);
	void (*setpfcstate)(struct net_device___3 *, u8);
	void (*getbcncfg)(struct net_device___3 *, int, u32 *);
	void (*setbcncfg)(struct net_device___3 *, int, u32);
	void (*getbcnrp)(struct net_device___3 *, int, u8 *);
	void (*setbcnrp)(struct net_device___3 *, int, u8);
	u8 (*setapp)(struct net_device___3 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___3 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___3 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___3 *, int, u8);
	u8 (*getdcbx)(struct net_device___3 *);
	u8 (*setdcbx)(struct net_device___3 *, u8);
	int (*peer_getappinfo)(struct net_device___3 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___3 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___3 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___3 *, struct cee_pfc *);
};

struct cgroupfs_root___147;

struct cgroup___147 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___147 *parent;
	struct dentry___251 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___147 *subsys[11];
	struct cgroupfs_root___147 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___253 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___147 {
	struct super_block___251 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___147 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___85 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___251 *, struct file___251 *);
	ssize_t (*read)(struct cgroup___147 *, struct cftype___85 *, struct file___251 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___147 *, struct cftype___85 *);
	s64 (*read_s64)(struct cgroup___147 *, struct cftype___85 *);
	int (*read_map)(struct cgroup___147 *, struct cftype___85 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___147 *, struct cftype___85 *, struct seq_file___176 *);
	ssize_t (*write)(struct cgroup___147 *, struct cftype___85 *, struct file___251 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___147 *, struct cftype___85 *, u64);
	int (*write_s64)(struct cgroup___147 *, struct cftype___85 *, s64);
	int (*write_string)(struct cgroup___147 *, struct cftype___85 *, const char *);
	int (*trigger)(struct cgroup___147 *, unsigned int);
	int (*release)(struct inode___251 *, struct file___251 *);
	int (*register_event)(struct cgroup___147 *, struct cftype___85 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___147 *, struct cftype___85 *, struct eventfd_ctx *);
};

struct cftype_set___81 {
	struct list_head node;
	struct cftype___85 *cfts;
};

struct task_and_cgroup___81 {
	struct task_struct___252 *task;
	struct cgroup___147 *cgrp;
	struct css_set___147 *cg;
};

struct cgroup_taskset___81 {
	struct task_and_cgroup___81 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___147 *cur_cgrp;
};

struct cgroup_subsys___81 {
	struct cgroup_subsys_state___147 * (*css_alloc)(struct cgroup___147 *);
	int (*css_online)(struct cgroup___147 *);
	void (*css_offline)(struct cgroup___147 *);
	void (*css_free)(struct cgroup___147 *);
	int (*can_attach)(struct cgroup___147 *, struct cgroup_taskset___81 *);
	void (*cancel_attach)(struct cgroup___147 *, struct cgroup_taskset___81 *);
	void (*attach)(struct cgroup___147 *, struct cgroup_taskset___81 *);
	void (*fork)(struct task_struct___252 *);
	void (*exit)(struct cgroup___147 *, struct cgroup___147 *, struct task_struct___252 *);
	void (*bind)(struct cgroup___147 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___147 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___85 *base_cftypes;
	struct cftype_set___81 base_cftset;
	struct module___154 *module;
};

struct netlink_callback___44 {
	struct sk_buff___46 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___46 *, struct netlink_callback___44 *);
	int (*done)(struct netlink_callback___44 *);
	void *data;
	struct module___154 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___42 {
	int (*create)(struct sk_buff___46 *, struct net_device___3 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___46 *, unsigned char *);
	int (*rebuild)(struct sk_buff___46 *);
	int (*cache)(const struct neighbour___33 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___3 *, const unsigned char *);
};

struct napi_struct___42 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___42 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___3 *dev;
	struct sk_buff___46 *gro_list;
	struct sk_buff___46 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___42 {
	struct net_device___3 *dev;
	struct Qdisc___5 *qdisc;
	struct Qdisc___5 *qdisc_sleeping;
	struct kobject___36 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___5;

struct Qdisc___5 {
	int (*enqueue)(struct sk_buff___46 *, struct Qdisc___5 *);
	struct sk_buff___46 * (*dequeue)(struct Qdisc___5 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___5 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___46 *, struct Qdisc___5 *);
	void *u32_node;
	struct Qdisc___5 *__parent;
	struct netdev_queue___42 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___5 *next_sched;
	struct sk_buff___46 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___43 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___42 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___36 kobj;
	struct net_device___3 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___42 {
	int (*ndo_init)(struct net_device___3 *);
	void (*ndo_uninit)(struct net_device___3 *);
	int (*ndo_open)(struct net_device___3 *);
	int (*ndo_stop)(struct net_device___3 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___46 *, struct net_device___3 *);
	u16 (*ndo_select_queue)(struct net_device___3 *, struct sk_buff___46 *);
	void (*ndo_change_rx_flags)(struct net_device___3 *, int);
	void (*ndo_set_rx_mode)(struct net_device___3 *);
	int (*ndo_set_mac_address)(struct net_device___3 *, void *);
	int (*ndo_validate_addr)(struct net_device___3 *);
	int (*ndo_do_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___3 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___3 *, int);
	int (*ndo_neigh_setup)(struct net_device___3 *, struct neigh_parms___33 *);
	void (*ndo_tx_timeout)(struct net_device___3 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___3 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___3 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___3 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___3 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___3 *);
	int (*ndo_netpoll_setup)(struct net_device___3 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___3 *);
	int (*ndo_busy_poll)(struct napi_struct___42 *);
	int (*ndo_set_vf_mac)(struct net_device___3 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___3 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___3 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___3 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___3 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___3 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___3 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___3 *, int, struct sk_buff___46 *);
	int (*ndo_setup_tc)(struct net_device___3 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___3 *);
	int (*ndo_fcoe_disable)(struct net_device___3 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___3 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___3 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___3 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___3 *, const struct sk_buff___46 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___3 *, struct net_device___3 *);
	int (*ndo_del_slave)(struct net_device___3 *, struct net_device___3 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___33 *);
	void (*ndo_neigh_destroy)(struct neighbour___33 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___46 *, struct netlink_callback___44 *, struct net_device___3 *, int);
	int (*ndo_bridge_setlink)(struct net_device___3 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___46 *, u32, u32, struct net_device___3 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___3 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___3 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___3 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___3 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___3 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___3 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___46 *, struct net_device___3 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___3 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___3 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___3 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___33 {
	struct net___56 *net;
	struct net_device___3 *dev;
	struct neigh_parms___33 *next;
	int (*neigh_setup)(struct neighbour___33 *);
	void (*neigh_cleanup)(struct neighbour___33 *);
	struct neigh_table___33 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___33 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___3 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___56 *, struct net_device___3 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___3 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___3 *, struct list_head *);
	size_t (*get_size)(const struct net_device___3 *);
	int (*fill_info)(struct sk_buff___46 *, const struct net_device___3 *);
	size_t (*get_xstats_size)(const struct net_device___3 *);
	int (*fill_xstats)(struct sk_buff___46 *, const struct net_device___3 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___56 * (*get_link_net)(const struct net_device___3 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___3 *, struct net_device___3 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___3 *, const struct net_device___3 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___46 *, const struct net_device___3 *, const struct net_device___3 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___34 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___46 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___33;

struct neigh_hash_table___33;

struct neigh_table___33 {
	struct neigh_table___33 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___3 *, __u32 *);
	int (*constructor)(struct neighbour___33 *);
	int (*pconstructor)(struct pneigh_entry___33 *);
	void (*pdestructor)(struct pneigh_entry___33 *);
	void (*proxy_redo)(struct sk_buff___46 *);
	char *id;
	struct neigh_parms___33 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___43 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___33 *nht;
	struct pneigh_entry___33 **phash_buckets;
};

struct neigh_ops___33 {
	int family;
	void (*solicit)(struct neighbour___33 *, struct sk_buff___46 *);
	void (*error_report)(struct neighbour___33 *, struct sk_buff___46 *);
	int (*output)(struct neighbour___33 *, struct sk_buff___46 *);
	int (*connected_output)(struct neighbour___33 *, struct sk_buff___46 *);
};

struct pneigh_entry___33 {
	struct pneigh_entry___33 *next;
	struct net___56 *net;
	struct net_device___3 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___33 {
	struct neighbour___33 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___33 {
	void (*close)(struct sock___35 *, long int);
	int (*connect)(struct sock___35 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___35 *, int);
	struct sock___35 * (*accept)(struct sock___35 *, int, int *);
	int (*ioctl)(struct sock___35 *, int, long unsigned int);
	int (*init)(struct sock___35 *);
	void (*destroy)(struct sock___35 *);
	void (*shutdown)(struct sock___35 *, int);
	int (*setsockopt)(struct sock___35 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___35 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___35 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___35 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___35 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___41 *, struct sock___35 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___41 *, struct sock___35 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___35 *, struct page___250 *, int, size_t, int);
	int (*bind)(struct sock___35 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___35 *, struct sk_buff___46 *);
	void (*release_cb)(struct sock___35 *);
	void (*mtu_reduced)(struct sock___35 *);
	void (*hash)(struct sock___35 *);
	void (*unhash)(struct sock___35 *);
	void (*rehash)(struct sock___35 *);
	int (*get_port)(struct sock___35 *, short unsigned int);
	void (*clear_sk)(struct sock___35 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___35 *);
	void (*enter_memory_pressure)(struct sock___35 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___234 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___3 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___154 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___81 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___33 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___33 {
	void (*enter_memory_pressure)(struct sock___35 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct gnet_dump___6 {
	spinlock_t *lock;
	struct sk_buff___46 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___5;

struct Qdisc_ops___5 {
	struct Qdisc_ops___5 *next;
	const struct Qdisc_class_ops___5 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___46 *, struct Qdisc___5 *);
	struct sk_buff___46 * (*dequeue)(struct Qdisc___5 *);
	struct sk_buff___46 * (*peek)(struct Qdisc___5 *);
	unsigned int (*drop)(struct Qdisc___5 *);
	int (*init)(struct Qdisc___5 *, struct nlattr *);
	void (*reset)(struct Qdisc___5 *);
	void (*destroy)(struct Qdisc___5 *);
	int (*change)(struct Qdisc___5 *, struct nlattr *);
	void (*attach)(struct Qdisc___5 *);
	int (*dump)(struct Qdisc___5 *, struct sk_buff___46 *);
	int (*dump_stats)(struct Qdisc___5 *, struct gnet_dump___6 *);
	struct module___154 *owner;
};

struct qdisc_walker___5;

struct tcf_proto___5;

struct Qdisc_class_ops___5 {
	struct netdev_queue___42 * (*select_queue)(struct Qdisc___5 *, struct tcmsg *);
	int (*graft)(struct Qdisc___5 *, long unsigned int, struct Qdisc___5 *, struct Qdisc___5 **);
	struct Qdisc___5 * (*leaf)(struct Qdisc___5 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___5 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___5 *, u32);
	void (*put)(struct Qdisc___5 *, long unsigned int);
	int (*change)(struct Qdisc___5 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___5 *, long unsigned int);
	void (*walk)(struct Qdisc___5 *, struct qdisc_walker___5 *);
	struct tcf_proto___5 ** (*tcf_chain)(struct Qdisc___5 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___5 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___5 *, long unsigned int);
	int (*dump)(struct Qdisc___5 *, long unsigned int, struct sk_buff___46 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___5 *, long unsigned int, struct gnet_dump___6 *);
};

struct qdisc_walker___5 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___5 *, long unsigned int, struct qdisc_walker___5 *);
};

struct tcf_proto_ops___5;

struct tcf_proto___5 {
	struct tcf_proto___5 *next;
	void *root;
	int (*classify)(struct sk_buff___46 *, const struct tcf_proto___5 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___5 *q;
	void *data;
	const struct tcf_proto_ops___5 *ops;
};

struct tcf_proto_ops___5 {
	struct tcf_proto_ops___5 *next;
	char kind[16];
	int (*classify)(struct sk_buff___46 *, const struct tcf_proto___5 *, struct tcf_result *);
	int (*init)(struct tcf_proto___5 *);
	void (*destroy)(struct tcf_proto___5 *);
	long unsigned int (*get)(struct tcf_proto___5 *, u32);
	void (*put)(struct tcf_proto___5 *, long unsigned int);
	int (*change)(struct net___56 *, struct sk_buff___46 *, struct tcf_proto___5 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___5 *, long unsigned int);
	void (*walk)(struct tcf_proto___5 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___5 *, long unsigned int, struct sk_buff___46 *, struct tcmsg *);
	struct module___154 *owner;
};

enum lw_bits {
	LW_URGENT = 0,
};

struct page___251;

typedef struct page___251 *pgtable_t___251;

struct address_space___252;

struct kmem_cache___235;

struct page___251 {
	long unsigned int flags;
	struct address_space___252 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___251 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___251 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___235 *slab_cache;
		struct page___251 *first_page;
	};
	long: 64;
};

struct task_struct___253;

struct pv_cpu_ops___253 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___253 *);
	void (*end_context_switch)(struct task_struct___253 *);
};

struct mutex___254 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___253 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___246 {
	struct page___251 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___260;

struct nsproxy___133;

struct signal_struct___253;

struct css_set___148;

struct task_struct___253 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___253 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___260 *mm;
	struct mm_struct___260 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___253 *real_parent;
	struct task_struct___253 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___253 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___253 = 0,
		VTIME_USER___253 = 1,
		VTIME_SYS___253 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___133 *nsproxy;
	struct signal_struct___253 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___148 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___254 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___246 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___260 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___260 *, struct mm_struct___260 *);
	void (*dup_mmap)(struct mm_struct___260 *, struct mm_struct___260 *);
	void (*exit_mmap)(struct mm_struct___260 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___260 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___260 *);
	void (*pgd_free)(struct mm_struct___260 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___260 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___260 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___260 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___260 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___260 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___260 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___260 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___260 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___260 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___260 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___260 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___254 lock;
	void *vdso;
} mm_context_t___254;

struct xol_area___251;

struct uprobes_state___251 {
	struct xol_area___251 *xol_area;
};

struct vm_area_struct___260;

struct file___252;

struct core_state___253;

struct mm_struct___260 {
	struct vm_area_struct___260 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___260 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___260 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___254 context;
	long unsigned int flags;
	struct core_state___253 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___253 *owner;
	struct file___252 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___251 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___37;

struct kobj_type___37;

struct kobject___37 {
	const char *name;
	struct list_head entry;
	struct kobject___37 *parent;
	struct kset___37 *kset;
	struct kobj_type___37 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___155;

struct module_kobject___153 {
	struct kobject___37 kobj;
	struct module___155 *mod;
	struct kobject___37 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___153;

struct module___155 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___153 mkobj;
	struct module_attribute___153 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___37 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___253 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___251 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___251 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___234;

struct memcg_cache_params___235;

struct kmem_cache___235 {
	struct kmem_cache_cpu___234 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___37 kobj;
	struct memcg_cache_params___235 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___252;

struct address_space_operations___252;

struct address_space___252 {
	struct inode___252 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___254 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___252 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___252;

struct path___252 {
	struct vfsmount *mnt;
	struct dentry___252 *dentry;
};

struct file_operations___252;

struct file___252 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___252 f_path;
	struct inode___252 *f_inode;
	const struct file_operations___252 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___252 *f_mapping;
	struct mutex___254 f_pos_lock;
};

struct vm_operations_struct___226;

struct vm_area_struct___260 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___260 *vm_next;
	struct vm_area_struct___260 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___260 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___226 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___252 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___222;

struct vm_operations_struct___226 {
	void (*open)(struct vm_area_struct___260 *);
	void (*close)(struct vm_area_struct___260 *);
	int (*fault)(struct vm_area_struct___260 *, struct vm_fault___222 *);
	int (*page_mkwrite)(struct vm_area_struct___260 *, struct vm_fault___222 *);
	int (*access)(struct vm_area_struct___260 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___260 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___260 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___260 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___260 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___253 {
	struct task_struct___253 *task;
	struct core_thread___253 *next;
};

struct core_state___253 {
	atomic_t nr_threads;
	struct core_thread___253 dumper;
	struct completion startup;
};

struct fasync_struct___252;

struct socket_wq___34 {
	wait_queue_head_t wait;
	struct fasync_struct___252 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___252 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___252 *fa_next;
	struct file___252 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___36;

struct proto_ops___34;

struct socket___35 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___34 *wq;
	struct file___252 *file;
	struct sock___36 *sk;
	const struct proto_ops___34 *ops;
};

struct proto___34;

struct net___57;

struct sock_common___34 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___34 *skc_prot;
	struct net___57 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___47;

struct sk_buff_head___44 {
	struct sk_buff___47 *next;
	struct sk_buff___47 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___35;

struct dst_entry___34;

struct cg_proto___34;

struct sock___36 {
	struct sock_common___34 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___44 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___47 *head;
		struct sk_buff___47 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___35 *sk_filter;
	struct socket_wq___34 *sk_wq;
	struct sk_buff_head___44 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___34 *sk_rx_dst;
	struct dst_entry___34 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___44 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___44 sk_error_queue;
	struct proto___34 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___35 *sk_socket;
	void *sk_user_data;
	struct page_frag___246 sk_frag;
	struct sk_buff___47 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___34 *sk_cgrp;
	void (*sk_state_change)(struct sock___36 *);
	void (*sk_data_ready)(struct sock___36 *, int);
	void (*sk_write_space)(struct sock___36 *);
	void (*sk_error_report)(struct sock___36 *);
	int (*sk_backlog_rcv)(struct sock___36 *, struct sk_buff___47 *);
	void (*sk_destruct)(struct sock___36 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___141;

struct kiocb___42;

struct proto_ops___34 {
	int family;
	struct module___155 *owner;
	int (*release)(struct socket___35 *);
	int (*bind)(struct socket___35 *, struct sockaddr *, int);
	int (*connect)(struct socket___35 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___35 *, struct socket___35 *);
	int (*accept)(struct socket___35 *, struct socket___35 *, int);
	int (*getname)(struct socket___35 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___252 *, struct socket___35 *, struct poll_table_struct___141 *);
	int (*ioctl)(struct socket___35 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___35 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___35 *, int);
	int (*shutdown)(struct socket___35 *, int);
	int (*setsockopt)(struct socket___35 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___35 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___35 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___35 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___42 *, struct socket___35 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___42 *, struct socket___35 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___252 *, struct socket___35 *, struct vm_area_struct___260 *);
	ssize_t (*sendpage)(struct socket___35 *, struct page___251 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___35 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___36 *, int);
		struct {
			void (*set_peek_off)(struct sock___36 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___143)(struct file___252 *, wait_queue_head_t *, struct poll_table_struct___141 *);

struct poll_table_struct___141 {
	poll_queue_proc___143 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___42(struct kiocb___42 *, struct io_event *);

struct kiocb___42 {
	atomic_t ki_users;
	struct file___252 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___42 *ki_cancel;
	void (*ki_dtor)(struct kiocb___42 *);
	union {
		void *user;
		struct task_struct___253 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___58;

struct ctl_table_set___58;

struct ctl_dir___58;

struct ctl_node___58;

struct ctl_table_header___58 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___58 *root;
	struct ctl_table_set___58 *set;
	struct ctl_dir___58 *parent;
	struct ctl_node___58 *node;
};

struct ctl_dir___58 {
	struct ctl_table_header___58 header;
	struct rb_root root;
};

struct ctl_table_set___58 {
	int (*is_seen)(struct ctl_table_set___58 *);
	struct ctl_dir___58 dir;
};

struct netns_core___55 {
	struct ctl_table_header___58 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___55 {
	struct mutex___254 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___55 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___58 *ctl;
};

struct netns_ipv4___55 {
	struct ctl_table_header___58 *forw_hdr;
	struct ctl_table_header___58 *frags_hdr;
	struct ctl_table_header___58 *ipv4_hdr;
	struct ctl_table_header___58 *route_hdr;
	struct ctl_table_header___58 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___36 *fibnl;
	struct sock___36 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___55 {
	struct ctl_table_header___58 *hdr;
	struct ctl_table_header___58 *route_hdr;
	struct ctl_table_header___58 *icmp_hdr;
	struct ctl_table_header___58 *frags_hdr;
	struct ctl_table_header___58 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___44;

struct neighbour___34;

struct dst_ops___56 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___56 *);
	struct dst_entry___34 * (*check)(struct dst_entry___34 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___34 *);
	unsigned int (*mtu)(const struct dst_entry___34 *);
	u32 * (*cow_metrics)(struct dst_entry___34 *, long unsigned int);
	void (*destroy)(struct dst_entry___34 *);
	void (*ifdown)(struct dst_entry___34 *, struct net_device___44 *, int);
	struct dst_entry___34 * (*negative_advice)(struct dst_entry___34 *);
	void (*link_failure)(struct sk_buff___47 *);
	void (*update_pmtu)(struct dst_entry___34 *, struct sock___36 *, struct sk_buff___47 *, u32);
	void (*redirect)(struct dst_entry___34 *, struct sock___36 *, struct sk_buff___47 *);
	int (*local_out)(struct sk_buff___47 *);
	struct neighbour___34 * (*neigh_lookup)(const struct dst_entry___34 *, struct sk_buff___47 *, const void *);
	struct kmem_cache___235 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___56 {
	struct netns_sysctl_ipv6___55 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___56 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___36 **icmp_sk;
	struct sock___36 *ndisc_sk;
	struct sock___36 *tcp_sk;
	struct sock___36 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___55 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___58 *sysctl_header;
	struct sock___36 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___34 {
	struct sock___36 *v4_ctl_sk;
	struct sock___36 *v6_ctl_sk;
};

struct netns_nf___55 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___58 *nf_log_dir_header;
};

struct nf_proto_net___55 {
	struct ctl_table_header___58 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___55 {
	struct nf_proto_net___55 pn;
	unsigned int timeout;
};

struct nf_tcp_net___55 {
	struct nf_proto_net___55 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___55 {
	struct nf_proto_net___55 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___55 {
	struct nf_proto_net___55 pn;
	unsigned int timeout;
};

struct nf_ip_net___55 {
	struct nf_generic_net___55 generic;
	struct nf_tcp_net___55 tcp;
	struct nf_udp_net___55 udp;
	struct nf_icmp_net___55 icmp;
	struct nf_icmp_net___55 icmpv6;
};

struct netns_ct___55 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___58 *sysctl_header;
	struct ctl_table_header___58 *acct_sysctl_header;
	struct ctl_table_header___58 *tstamp_sysctl_header;
	struct ctl_table_header___58 *event_sysctl_header;
	struct ctl_table_header___58 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___235 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___55 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___55 {
	struct netns_sysctl_ipv6___55 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___56 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___36 *nlsk;
	struct sock___36 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___58 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___56 xfrm4_dst_ops;
	struct dst_ops___56 xfrm6_dst_ops;
};

struct net___57 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace___2 *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___58 sysctls;
	struct sock___36 *rtnl;
	struct sock___36 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___44 *loopback_dev;
	struct netns_core___55 core;
	struct netns_mib mib;
	struct netns_packet___55 packet;
	struct netns_unix___55 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___55 ipv4;
	struct netns_ipv6___56 ipv6;
	struct netns_sctp___55 sctp;
	struct netns_dccp___34 dccp;
	struct netns_nf___55 nf;
	struct netns_xt xt;
	struct netns_ct___55 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___55 nf_frag;
	struct sock___36 *nfnl;
	struct sock___36 *nfnl_stash;
	struct sk_buff_head___44 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___56 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___36 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___36 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___254 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___254 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___253;

struct lruvec___253 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___253 *zone;
};

struct pglist_data___253;

struct zone___253 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___253 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___253 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___253 {
	struct zone___253 *zone;
	int zone_idx;
};

struct zonelist___253 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___253 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___253 {
	struct zone___253 node_zones[4];
	struct zonelist___253 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___253 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___176;

struct x86_io_apic_ops___176 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___176 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___176;

struct irq_data___176 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___176 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___250;

struct dev_pm_ops___250 {
	int (*prepare)(struct device___250 *);
	void (*complete)(struct device___250 *);
	int (*suspend)(struct device___250 *);
	int (*resume)(struct device___250 *);
	int (*freeze)(struct device___250 *);
	int (*thaw)(struct device___250 *);
	int (*poweroff)(struct device___250 *);
	int (*restore)(struct device___250 *);
	int (*suspend_late)(struct device___250 *);
	int (*resume_early)(struct device___250 *);
	int (*freeze_late)(struct device___250 *);
	int (*thaw_early)(struct device___250 *);
	int (*poweroff_late)(struct device___250 *);
	int (*restore_early)(struct device___250 *);
	int (*suspend_noirq)(struct device___250 *);
	int (*resume_noirq)(struct device___250 *);
	int (*freeze_noirq)(struct device___250 *);
	int (*thaw_noirq)(struct device___250 *);
	int (*poweroff_noirq)(struct device___250 *);
	int (*restore_noirq)(struct device___250 *);
	int (*runtime_suspend)(struct device___250 *);
	int (*runtime_resume)(struct device___250 *);
	int (*runtime_idle)(struct device___250 *);
};

struct dev_pm_qos___54;

struct dev_pm_info___54 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___54 *qos;
};

struct dma_map_ops___115;

struct dev_archdata___115 {
	struct dma_map_ops___115 *dma_ops;
	void *iommu;
};

struct device_type___250;

struct bus_type___250;

struct device_driver___250;

struct dev_pm_domain___250;

struct class___250;

struct attribute_group___212;

struct device_rh___250;

struct device___250 {
	struct device___250 *parent;
	struct device_private *p;
	struct kobject___37 kobj;
	const char *init_name;
	const struct device_type___250 *type;
	struct mutex___254 mutex;
	struct bus_type___250 *bus;
	struct device_driver___250 *driver;
	void *platform_data;
	struct dev_pm_info___54 power;
	struct dev_pm_domain___250 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___115 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___250 *class;
	const struct attribute_group___212 **groups;
	void (*release)(struct device___250 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___250 *device_rh;
};

struct dev_pm_qos_request___55;

struct dev_pm_qos___54 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___55 *latency_req;
	struct dev_pm_qos_request___55 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___55 *latency_tolerance_req;
};

struct dev_pm_info_rh___250 {
	void (*set_latency_tolerance)(struct device___250 *, s32);
};

struct dev_pm_domain___250 {
	struct dev_pm_ops___250 ops;
};

struct smp_ops___253 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___253 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___34 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___36 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___214;

struct attribute_group___212 {
	const char *name;
	umode_t (*is_visible)(struct kobject___37 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___214 **bin_attrs;
};

struct bin_attribute___214 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___252 *, struct kobject___37 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___252 *, struct kobject___37 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	int (*mmap)(struct file___252 *, struct kobject___37 *, struct bin_attribute___214 *, struct vm_area_struct___260 *);
};

struct sysfs_ops___37 {
	ssize_t (*show)(struct kobject___37 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___37 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___37 *, const struct attribute *);
};

struct kset_uevent_ops___37;

struct kset___37 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___37 kobj;
	const struct kset_uevent_ops___37 *uevent_ops;
};

struct kobj_type___37 {
	void (*release)(struct kobject___37 *);
	const struct sysfs_ops___37 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___34 * (*child_ns_type)(struct kobject___37 *);
	const void * (*namespace)(struct kobject___37 *);
};

struct kset_uevent_ops___37 {
	int (* const filter)(struct kset___37 *, struct kobject___37 *);
	const char * (* const name)(struct kset___37 *, struct kobject___37 *);
	int (* const uevent)(struct kset___37 *, struct kobject___37 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___234 {
	void **freelist;
	long unsigned int tid;
	struct page___251 *page;
	struct page___251 *partial;
};

struct memcg_cache_params___235 {
	bool is_root_cache;
	union {
		struct kmem_cache___235 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___235 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___115 {
	void * (*alloc)(struct device___250 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___250 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___250 *, struct vm_area_struct___260 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___250 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___250 *, struct page___251 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___250 *, dma_addr_t);
	int (*dma_supported)(struct device___250 *, u64);
	int (*set_dma_mask)(struct device___250 *, u64);
	int is_phys;
};

struct bus_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___250 *, char *);
	ssize_t (*store)(struct bus_type___250 *, const char *, size_t);
};

struct device_attribute___250;

struct driver_attribute___250;

struct bus_type___250 {
	const char *name;
	const char *dev_name;
	struct device___250 *dev_root;
	struct bus_attribute___250 *bus_attrs;
	struct device_attribute___250 *dev_attrs;
	struct driver_attribute___250 *drv_attrs;
	const struct attribute_group___212 **bus_groups;
	const struct attribute_group___212 **dev_groups;
	const struct attribute_group___212 **drv_groups;
	int (*match)(struct device___250 *, struct device_driver___250 *);
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	int (*probe)(struct device___250 *);
	int (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*online)(struct device___250 *);
	int (*offline)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct device___250 *, struct device_attribute___250 *, char *);
	ssize_t (*store)(struct device___250 *, struct device_attribute___250 *, const char *, size_t);
};

struct driver_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___250 *, char *);
	ssize_t (*store)(struct device_driver___250 *, const char *, size_t);
};

struct device_driver___250 {
	const char *name;
	struct bus_type___250 *bus;
	struct module___155 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___250 *);
	int (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	const struct attribute_group___212 **groups;
	const struct dev_pm_ops___250 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___250 {
	const char *name;
	const struct attribute_group___212 **groups;
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
};

struct class_attribute___250;

struct class___250 {
	const char *name;
	struct module___155 *owner;
	struct class_attribute___250 *class_attrs;
	struct device_attribute___250 *dev_attrs;
	const struct attribute_group___212 **dev_groups;
	struct bin_attribute___214 *dev_bin_attrs;
	struct kobject___37 *dev_kobj;
	int (*dev_uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *);
	void (*class_release)(struct class___250 *);
	void (*dev_release)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	const struct kobj_ns_type_operations___34 *ns_type;
	const void * (*namespace)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
	struct subsys_private *p;
};

struct class_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct class___250 *, struct class_attribute___250 *, char *);
	ssize_t (*store)(struct class___250 *, struct class_attribute___250 *, const char *, size_t);
	const void * (*namespace)(struct class___250 *, const struct class_attribute___250 *);
};

struct device_rh___250 {
	struct dev_pm_info_rh___250 power;
};

struct vm_fault___222 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___251 *page;
};

struct ctl_node___58 {
	struct rb_node node;
	struct ctl_table_header___58 *header;
};

struct ctl_table_root___58 {
	struct ctl_table_set___58 default_set;
	struct ctl_table_set___58 * (*lookup)(struct ctl_table_root___58 *, struct nsproxy___133 *);
	int (*permissions)(struct ctl_table_header___58 *, struct ctl_table *);
};

struct nsproxy___133 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___57 *net_ns;
};

struct signal_struct___253 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___253 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___253 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___254 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___148;

struct css_set___148 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___148 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___43 {
	atomic_t use;
	unsigned int mask;
	struct net_device___44 *physindev;
	struct net_device___44 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___43(struct sk_buff___47 **);

struct net_device_ops___43;

struct ethtool_ops___43;

struct header_ops___43;

struct netdev_rx_queue___43;

struct netdev_queue___43;

struct rtnl_link_ops___34;

struct dcbnl_rtnl_ops___43;

struct net_device___44 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___43 *netdev_ops;
	const struct ethtool_ops___43 *ethtool_ops;
	const struct header_ops___43 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___37 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___43 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___43 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___43 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___43 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___43 = 0,
		NETREG_REGISTERED___43 = 1,
		NETREG_UNREGISTERING___43 = 2,
		NETREG_UNREGISTERED___43 = 3,
		NETREG_RELEASED___43 = 4,
		NETREG_DUMMY___43 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___43 = 0,
		RTNL_LINK_INITIALIZING___43 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___44 *);
	struct netpoll_info *npinfo;
	struct net___57 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___250 dev;
	const struct attribute_group___212 *sysfs_groups[4];
	const struct rtnl_link_ops___34 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___43 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___47 {
	struct sk_buff___47 *next;
	struct sk_buff___47 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___36 *sk;
	struct net_device___44 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___47 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___43 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct inode_operations___252;

struct super_block___252;

struct file_lock___252;

struct dquot___252;

struct block_device___252;

struct inode___252 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___252 *i_op;
	struct super_block___252 *i_sb;
	struct address_space___252 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___254 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___252 *i_fop;
	struct file_lock___252 *i_flock;
	struct address_space___252 i_data;
	struct dquot___252 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___252 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___252;

struct mem_dqinfo___252 {
	struct quota_format_type___252 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___252;

struct quota_info___252 {
	unsigned int flags;
	struct mutex___254 dqio_mutex;
	struct mutex___254 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___252 *files[2];
	struct mem_dqinfo___252 info[2];
	const struct quota_format_ops___252 *ops[2];
};

struct file_system_type___252;

struct super_operations___252;

struct dquot_operations___252;

struct quotactl_ops___252;

struct xattr_handler___149;

struct dentry_operations___252;

struct super_block___252 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___252 *s_type;
	const struct super_operations___252 *s_op;
	const struct dquot_operations___252 *dq_op;
	const struct quotactl_ops___252 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___252 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___149 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___252 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___252 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___254 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___252 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___252 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___252 *d_parent;
	struct qstr d_name;
	struct inode___252 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___252 *d_op;
	struct super_block___252 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct seq_operations___177;

struct seq_file___177 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___254 lock;
	const struct seq_operations___177 *op;
	int poll_event;
	struct user_namespace___2 *user_ns;
	void *private;
};

struct iattr___252 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___252 *ia_file;
};

struct netlink_kernel_cfg___7 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___47 *);
	struct mutex___254 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___57 *, struct sock___36 *);
};

struct netlink_callback___45 {
	struct sk_buff___47 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___47 *, struct netlink_callback___45 *);
	int (*done)(struct netlink_callback___45 *);
	void *data;
	struct module___155 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct dst_entry___34 {
	struct callback_head callback_head;
	struct dst_entry___34 *child;
	struct net_device___44 *dev;
	struct dst_ops___56 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___34 *path;
	struct dst_entry___34 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___47 *);
	union {
		int (*output)(struct sock___36 *, struct sk_buff___47 *);
		struct {
			int (*output)(struct sk_buff___47 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___34 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___34;

struct neigh_parms___34;

struct neigh_ops___34;

struct neighbour___34 {
	struct neighbour___34 *next;
	struct neigh_table___34 *tbl;
	struct neigh_parms___34 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___44 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___34 *, struct sk_buff___47 *);
	const struct neigh_ops___34 *ops;
	struct callback_head rcu;
	struct net_device___44 *dev;
	u8 primary_key[0];
};

struct dentry_operations___252 {
	int (*d_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_hash)(const struct dentry___252 *, struct qstr *);
	int (*d_compare)(const struct dentry___252 *, const struct dentry___252 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___252 *);
	void (*d_release)(struct dentry___252 *);
	void (*d_prune)(struct dentry___252 *);
	void (*d_iput)(struct dentry___252 *, struct inode___252 *);
	char * (*d_dname)(struct dentry___252 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___252 *);
	int (*d_manage)(struct dentry___252 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___252 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___252 *bd_inode;
	struct super_block___252 *bd_super;
	struct mutex___254 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___252 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___254 bd_fsfreeze_mutex;
};

struct cgroup___148;

struct cgroup_subsys_state___148 {
	struct cgroup___148 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___252 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___254 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___252 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___252 {
	int qf_fmt_id;
	const struct quota_format_ops___252 *qf_ops;
	struct module___155 *qf_owner;
	struct quota_format_type___252 *qf_next;
};

struct quota_format_ops___252 {
	int (*check_quota_file)(struct super_block___252 *, int);
	int (*read_file_info)(struct super_block___252 *, int);
	int (*write_file_info)(struct super_block___252 *, int);
	int (*free_file_info)(struct super_block___252 *, int);
	int (*read_dqblk)(struct dquot___252 *);
	int (*commit_dqblk)(struct dquot___252 *);
	int (*release_dqblk)(struct dquot___252 *);
};

struct dquot_operations___252 {
	int (*write_dquot)(struct dquot___252 *);
	struct dquot___252 * (*alloc_dquot)(struct super_block___252 *, int);
	void (*destroy_dquot)(struct dquot___252 *);
	int (*acquire_dquot)(struct dquot___252 *);
	int (*release_dquot)(struct dquot___252 *);
	int (*mark_dirty)(struct dquot___252 *);
	int (*write_info)(struct super_block___252 *, int);
	qsize_t * (*get_reserved_space)(struct inode___252 *);
};

struct quotactl_ops___252 {
	int (*quota_on)(struct super_block___252 *, int, int, struct path___252 *);
	int (*quota_on_meta)(struct super_block___252 *, int, int);
	int (*quota_off)(struct super_block___252 *, int);
	int (*quota_sync)(struct super_block___252 *, int);
	int (*get_info)(struct super_block___252 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___252 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___252 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___252 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___252 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___252 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___252 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___252 *, unsigned int);
};

struct address_space_operations___252 {
	int (*writepage)(struct page___251 *, struct writeback_control *);
	int (*readpage)(struct file___252 *, struct page___251 *);
	int (*writepages)(struct address_space___252 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___251 *);
	int (*readpages)(struct file___252 *, struct address_space___252 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___252 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___251 **, void **);
	int (*write_end)(struct file___252 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___251 *, void *);
	sector_t (*bmap)(struct address_space___252 *, sector_t);
	void (*invalidatepage)(struct page___251 *, long unsigned int);
	int (*releasepage)(struct page___251 *, gfp_t);
	void (*freepage)(struct page___251 *);
	ssize_t (*direct_IO)(int, struct kiocb___42 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___252 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___252 *, struct page___251 *, struct page___251 *, enum migrate_mode);
	int (*launder_page)(struct page___251 *);
	int (*is_partially_uptodate)(struct page___251 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___251 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___252 *, struct page___251 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___252 *, sector_t *);
	void (*swap_deactivate)(struct file___252 *);
	void (*invalidatepage_range)(struct page___251 *, unsigned int, unsigned int);
};

struct inode_operations___252 {
	struct dentry___252 * (*lookup)(struct inode___252 *, struct dentry___252 *, unsigned int);
	void * (*follow_link)(struct dentry___252 *, struct nameidata *);
	int (*permission)(struct inode___252 *, int);
	struct posix_acl * (*get_acl)(struct inode___252 *, int);
	int (*readlink)(struct dentry___252 *, char *, int);
	void (*put_link)(struct dentry___252 *, struct nameidata *, void *);
	int (*create)(struct inode___252 *, struct dentry___252 *, umode_t, bool);
	int (*link)(struct dentry___252 *, struct inode___252 *, struct dentry___252 *);
	int (*unlink)(struct inode___252 *, struct dentry___252 *);
	int (*symlink)(struct inode___252 *, struct dentry___252 *, const char *);
	int (*mkdir)(struct inode___252 *, struct dentry___252 *, umode_t);
	int (*rmdir)(struct inode___252 *, struct dentry___252 *);
	int (*mknod)(struct inode___252 *, struct dentry___252 *, umode_t, dev_t);
	int (*rename)(struct inode___252 *, struct dentry___252 *, struct inode___252 *, struct dentry___252 *);
	int (*setattr)(struct dentry___252 *, struct iattr___252 *);
	int (*getattr)(struct vfsmount *, struct dentry___252 *, struct kstat *);
	int (*setxattr)(struct dentry___252 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___252 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___252 *, char *, size_t);
	int (*removexattr)(struct dentry___252 *, const char *);
	int (*fiemap)(struct inode___252 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___252 *, struct timespec *, int);
	int (*atomic_open)(struct inode___252 *, struct dentry___252 *, struct file___252 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___252 {
	struct module___155 *owner;
	loff_t (*llseek)(struct file___252 *, loff_t, int);
	ssize_t (*read)(struct file___252 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___252 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___42 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___42 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___252 *, void *, filldir_t);
	unsigned int (*poll)(struct file___252 *, struct poll_table_struct___141 *);
	long int (*unlocked_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___252 *, struct vm_area_struct___260 *);
	int (*open)(struct inode___252 *, struct file___252 *);
	int (*flush)(struct file___252 *, fl_owner_t);
	int (*release)(struct inode___252 *, struct file___252 *);
	int (*fsync)(struct file___252 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___42 *, int);
	int (*fasync)(int, struct file___252 *, int);
	int (*lock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*sendpage)(struct file___252 *, struct page___251 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___252 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___252 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___252 *, long int, struct file_lock___252 **, void **);
		struct {
			int (*setlease)(struct file___252 *, long int, struct file_lock___252 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___252 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___177 *, struct file___252 *);
};

struct file_lock_operations___252;

struct lock_manager_operations___252;

struct file_lock___252 {
	struct file_lock___252 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___252 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___252 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___252 *fl_ops;
	const struct lock_manager_operations___252 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___252 {
	void (*fl_copy_lock)(struct file_lock___252 *, struct file_lock___252 *);
	void (*fl_release_private)(struct file_lock___252 *);
};

struct lock_manager_operations___252 {
	int (*lm_compare_owner)(struct file_lock___252 *, struct file_lock___252 *);
	long unsigned int (*lm_owner_key)(struct file_lock___252 *);
	void (*lm_notify)(struct file_lock___252 *);
	int (*lm_grant)(struct file_lock___252 *, struct file_lock___252 *, int);
	void (*lm_break)(struct file_lock___252 *);
	int (*lm_change)(struct file_lock___252 **, int);
};

struct file_system_type___252 {
	const char *name;
	int fs_flags;
	struct dentry___252 * (*mount)(struct file_system_type___252 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___252 *);
	struct module___155 *owner;
	struct file_system_type___252 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___252 {
	struct inode___252 * (*alloc_inode)(struct super_block___252 *);
	void (*destroy_inode)(struct inode___252 *);
	void (*dirty_inode)(struct inode___252 *, int);
	int (*write_inode)(struct inode___252 *, struct writeback_control *);
	int (*drop_inode)(struct inode___252 *);
	void (*evict_inode)(struct inode___252 *);
	void (*put_super)(struct super_block___252 *);
	int (*sync_fs)(struct super_block___252 *, int);
	int (*freeze_fs)(struct super_block___252 *);
	int (*unfreeze_fs)(struct super_block___252 *);
	int (*statfs)(struct dentry___252 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___252 *, int *, char *);
	void (*umount_begin)(struct super_block___252 *);
	int (*show_options)(struct seq_file___177 *, struct dentry___252 *);
	int (*show_devname)(struct seq_file___177 *, struct dentry___252 *);
	int (*show_path)(struct seq_file___177 *, struct dentry___252 *);
	int (*show_stats)(struct seq_file___177 *, struct dentry___252 *);
	ssize_t (*quota_read)(struct super_block___252 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___252 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___252 *);
	int (*bdev_try_to_free_page)(struct super_block___252 *, struct page___251 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___252 *);
	void (*free_cached_objects)(struct super_block___252 *, int);
};

struct xattr_handler___149 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___252 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___252 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___252 *, const char *, const void *, size_t, int, int);
};

struct nf_afinfo___56 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___47 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___47 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___57 *, struct dst_entry___34 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___47 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___47 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___176 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___176 *);
	void (*irq_shutdown)(struct irq_data___176 *);
	void (*irq_enable)(struct irq_data___176 *);
	void (*irq_disable)(struct irq_data___176 *);
	void (*irq_ack)(struct irq_data___176 *);
	void (*irq_mask)(struct irq_data___176 *);
	void (*irq_mask_ack)(struct irq_data___176 *);
	void (*irq_unmask)(struct irq_data___176 *);
	void (*irq_eoi)(struct irq_data___176 *);
	int (*irq_set_affinity)(struct irq_data___176 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___176 *);
	int (*irq_set_type)(struct irq_data___176 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___176 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___176 *);
	void (*irq_bus_sync_unlock)(struct irq_data___176 *);
	void (*irq_cpu_online)(struct irq_data___176 *);
	void (*irq_cpu_offline)(struct irq_data___176 *);
	void (*irq_suspend)(struct irq_data___176 *);
	void (*irq_resume)(struct irq_data___176 *);
	void (*irq_pm_shutdown)(struct irq_data___176 *);
	void (*irq_print_chip)(struct irq_data___176 *, struct seq_file___177 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___176 *, void *);
	long unsigned int flags;
};

struct seq_operations___177 {
	void * (*start)(struct seq_file___177 *, loff_t *);
	void (*stop)(struct seq_file___177 *, void *);
	void * (*next)(struct seq_file___177 *, void *, loff_t *);
	int (*show)(struct seq_file___177 *, void *);
};

struct pernet_operations___9 {
	struct list_head list;
	int (*init)(struct net___57 *);
	void (*exit)(struct net___57 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct module_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___153 *, struct module_kobject___153 *, char *);
	ssize_t (*store)(struct module_attribute___153 *, struct module_kobject___153 *, const char *, size_t);
	void (*setup)(struct module___155 *, const char *);
	int (*test)(struct module___155 *);
	void (*free)(struct module___155 *);
};

struct dev_pm_qos_request___55 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___250 *dev;
};

struct ethtool_ops___43 {
	int (*get_settings)(struct net_device___44 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___44 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___44 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___44 *);
	void (*get_regs)(struct net_device___44 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___44 *);
	void (*set_msglevel)(struct net_device___44 *, u32);
	int (*nway_reset)(struct net_device___44 *);
	u32 (*get_link)(struct net_device___44 *);
	int (*get_eeprom_len)(struct net_device___44 *);
	int (*get_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___44 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___44 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___44 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___44 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___44 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___44 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___44 *);
	void (*complete)(struct net_device___44 *);
	u32 (*get_priv_flags)(struct net_device___44 *);
	int (*set_priv_flags)(struct net_device___44 *, u32);
	int (*get_sset_count)(struct net_device___44 *, int);
	int (*get_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___44 *, struct ethtool_flash *);
	int (*reset)(struct net_device___44 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___44 *);
	int (*get_rxfh_indir)(struct net_device___44 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___44 *, const u32 *);
	void (*get_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___44 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___44 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___44 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___44 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___44 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___44 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___44 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___44 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dcbnl_rtnl_ops___43 {
	int (*ieee_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___44 *);
	u8 (*setstate)(struct net_device___44 *, u8);
	void (*getpermhwaddr)(struct net_device___44 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___44 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___44 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___44 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___44 *, int, u8 *);
	void (*setpfccfg)(struct net_device___44 *, int, u8);
	void (*getpfccfg)(struct net_device___44 *, int, u8 *);
	u8 (*setall)(struct net_device___44 *);
	u8 (*getcap)(struct net_device___44 *, int, u8 *);
	int (*getnumtcs)(struct net_device___44 *, int, u8 *);
	int (*setnumtcs)(struct net_device___44 *, int, u8);
	u8 (*getpfcstate)(struct net_device___44 *);
	void (*setpfcstate)(struct net_device___44 *, u8);
	void (*getbcncfg)(struct net_device___44 *, int, u32 *);
	void (*setbcncfg)(struct net_device___44 *, int, u32);
	void (*getbcnrp)(struct net_device___44 *, int, u8 *);
	void (*setbcnrp)(struct net_device___44 *, int, u8);
	u8 (*setapp)(struct net_device___44 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___44 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___44 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___44 *, int, u8);
	u8 (*getdcbx)(struct net_device___44 *);
	u8 (*setdcbx)(struct net_device___44 *, u8);
	int (*peer_getappinfo)(struct net_device___44 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___44 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___44 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___44 *, struct cee_pfc *);
};

struct cgroupfs_root___148;

struct cgroup___148 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___148 *parent;
	struct dentry___252 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___148 *subsys[11];
	struct cgroupfs_root___148 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___254 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___148 {
	struct super_block___252 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___148 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___86 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___252 *, struct file___252 *);
	ssize_t (*read)(struct cgroup___148 *, struct cftype___86 *, struct file___252 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___148 *, struct cftype___86 *);
	s64 (*read_s64)(struct cgroup___148 *, struct cftype___86 *);
	int (*read_map)(struct cgroup___148 *, struct cftype___86 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___148 *, struct cftype___86 *, struct seq_file___177 *);
	ssize_t (*write)(struct cgroup___148 *, struct cftype___86 *, struct file___252 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___148 *, struct cftype___86 *, u64);
	int (*write_s64)(struct cgroup___148 *, struct cftype___86 *, s64);
	int (*write_string)(struct cgroup___148 *, struct cftype___86 *, const char *);
	int (*trigger)(struct cgroup___148 *, unsigned int);
	int (*release)(struct inode___252 *, struct file___252 *);
	int (*register_event)(struct cgroup___148 *, struct cftype___86 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___148 *, struct cftype___86 *, struct eventfd_ctx *);
};

struct cftype_set___82 {
	struct list_head node;
	struct cftype___86 *cfts;
};

struct task_and_cgroup___82 {
	struct task_struct___253 *task;
	struct cgroup___148 *cgrp;
	struct css_set___148 *cg;
};

struct cgroup_taskset___82 {
	struct task_and_cgroup___82 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___148 *cur_cgrp;
};

struct cgroup_subsys___82 {
	struct cgroup_subsys_state___148 * (*css_alloc)(struct cgroup___148 *);
	int (*css_online)(struct cgroup___148 *);
	void (*css_offline)(struct cgroup___148 *);
	void (*css_free)(struct cgroup___148 *);
	int (*can_attach)(struct cgroup___148 *, struct cgroup_taskset___82 *);
	void (*cancel_attach)(struct cgroup___148 *, struct cgroup_taskset___82 *);
	void (*attach)(struct cgroup___148 *, struct cgroup_taskset___82 *);
	void (*fork)(struct task_struct___253 *);
	void (*exit)(struct cgroup___148 *, struct cgroup___148 *, struct task_struct___253 *);
	void (*bind)(struct cgroup___148 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___148 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___86 *base_cftypes;
	struct cftype_set___82 base_cftset;
	struct module___155 *module;
};

struct header_ops___43 {
	int (*create)(struct sk_buff___47 *, struct net_device___44 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___47 *, unsigned char *);
	int (*rebuild)(struct sk_buff___47 *);
	int (*cache)(const struct neighbour___34 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___44 *, const unsigned char *);
};

struct napi_struct___43 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___43 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___44 *dev;
	struct sk_buff___47 *gro_list;
	struct sk_buff___47 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___43 {
	struct net_device___44 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___37 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___43 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___37 kobj;
	struct net_device___44 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___43 {
	int (*ndo_init)(struct net_device___44 *);
	void (*ndo_uninit)(struct net_device___44 *);
	int (*ndo_open)(struct net_device___44 *);
	int (*ndo_stop)(struct net_device___44 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___47 *, struct net_device___44 *);
	u16 (*ndo_select_queue)(struct net_device___44 *, struct sk_buff___47 *);
	void (*ndo_change_rx_flags)(struct net_device___44 *, int);
	void (*ndo_set_rx_mode)(struct net_device___44 *);
	int (*ndo_set_mac_address)(struct net_device___44 *, void *);
	int (*ndo_validate_addr)(struct net_device___44 *);
	int (*ndo_do_ioctl)(struct net_device___44 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___44 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___44 *, int);
	int (*ndo_neigh_setup)(struct net_device___44 *, struct neigh_parms___34 *);
	void (*ndo_tx_timeout)(struct net_device___44 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___44 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___44 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___44 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___44 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___44 *);
	int (*ndo_netpoll_setup)(struct net_device___44 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___44 *);
	int (*ndo_busy_poll)(struct napi_struct___43 *);
	int (*ndo_set_vf_mac)(struct net_device___44 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___44 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___44 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___44 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___44 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___44 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___44 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___44 *, int, struct sk_buff___47 *);
	int (*ndo_setup_tc)(struct net_device___44 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___44 *);
	int (*ndo_fcoe_disable)(struct net_device___44 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___44 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___44 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___44 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___44 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___44 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___44 *, const struct sk_buff___47 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___44 *, struct net_device___44 *);
	int (*ndo_del_slave)(struct net_device___44 *, struct net_device___44 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___34 *);
	void (*ndo_neigh_destroy)(struct neighbour___34 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___47 *, struct netlink_callback___45 *, struct net_device___44 *, int);
	int (*ndo_bridge_setlink)(struct net_device___44 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___47 *, u32, u32, struct net_device___44 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___44 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___44 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___44 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___44 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___44 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___44 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___47 *, struct net_device___44 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___44 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___44 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___44 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___34 {
	struct net___57 *net;
	struct net_device___44 *dev;
	struct neigh_parms___34 *next;
	int (*neigh_setup)(struct neighbour___34 *);
	void (*neigh_cleanup)(struct neighbour___34 *);
	struct neigh_table___34 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___34 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___44 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___57 *, struct net_device___44 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___44 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___44 *, struct list_head *);
	size_t (*get_size)(const struct net_device___44 *);
	int (*fill_info)(struct sk_buff___47 *, const struct net_device___44 *);
	size_t (*get_xstats_size)(const struct net_device___44 *);
	int (*fill_xstats)(struct sk_buff___47 *, const struct net_device___44 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___57 * (*get_link_net)(const struct net_device___44 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___44 *, struct net_device___44 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___44 *, const struct net_device___44 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___47 *, const struct net_device___44 *, const struct net_device___44 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___35 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___47 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___34;

struct neigh_hash_table___34;

struct neigh_table___34 {
	struct neigh_table___34 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___44 *, __u32 *);
	int (*constructor)(struct neighbour___34 *);
	int (*pconstructor)(struct pneigh_entry___34 *);
	void (*pdestructor)(struct pneigh_entry___34 *);
	void (*proxy_redo)(struct sk_buff___47 *);
	char *id;
	struct neigh_parms___34 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___44 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___34 *nht;
	struct pneigh_entry___34 **phash_buckets;
};

struct neigh_ops___34 {
	int family;
	void (*solicit)(struct neighbour___34 *, struct sk_buff___47 *);
	void (*error_report)(struct neighbour___34 *, struct sk_buff___47 *);
	int (*output)(struct neighbour___34 *, struct sk_buff___47 *);
	int (*connected_output)(struct neighbour___34 *, struct sk_buff___47 *);
};

struct pneigh_entry___34 {
	struct pneigh_entry___34 *next;
	struct net___57 *net;
	struct net_device___44 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___34 {
	struct neighbour___34 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___34 {
	void (*close)(struct sock___36 *, long int);
	int (*connect)(struct sock___36 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___36 *, int);
	struct sock___36 * (*accept)(struct sock___36 *, int, int *);
	int (*ioctl)(struct sock___36 *, int, long unsigned int);
	int (*init)(struct sock___36 *);
	void (*destroy)(struct sock___36 *);
	void (*shutdown)(struct sock___36 *, int);
	int (*setsockopt)(struct sock___36 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___36 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___36 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___36 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___36 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___42 *, struct sock___36 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___42 *, struct sock___36 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___36 *, struct page___251 *, int, size_t, int);
	int (*bind)(struct sock___36 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___36 *, struct sk_buff___47 *);
	void (*release_cb)(struct sock___36 *);
	void (*mtu_reduced)(struct sock___36 *);
	void (*hash)(struct sock___36 *);
	void (*unhash)(struct sock___36 *);
	void (*rehash)(struct sock___36 *);
	int (*get_port)(struct sock___36 *, short unsigned int);
	void (*clear_sk)(struct sock___36 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___36 *);
	void (*enter_memory_pressure)(struct sock___36 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___235 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___3 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___155 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___82 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___34 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___34 {
	void (*enter_memory_pressure)(struct sock___36 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct sock_diag_req {
	__u8 sdiag_family;
	__u8 sdiag_protocol;
};

enum {
	SK_MEMINFO_RMEM_ALLOC = 0,
	SK_MEMINFO_RCVBUF = 1,
	SK_MEMINFO_WMEM_ALLOC = 2,
	SK_MEMINFO_SNDBUF = 3,
	SK_MEMINFO_FWD_ALLOC = 4,
	SK_MEMINFO_WMEM_QUEUED = 5,
	SK_MEMINFO_OPTMEM = 6,
	SK_MEMINFO_BACKLOG = 7,
	SK_MEMINFO_VARS = 8,
};

struct sock_diag_handler {
	__u8 family;
	int (*dump)(struct sk_buff___47 *, struct nlmsghdr *);
};

typedef int gifconf_func_t(struct net_device___3 *, char *, int);

struct hwtstamp_config {
	int flags;
	int tx_type;
	int rx_filter;
};

enum hwtstamp_tx_types {
	HWTSTAMP_TX_OFF = 0,
	HWTSTAMP_TX_ON = 1,
	HWTSTAMP_TX_ONESTEP_SYNC = 2,
};

enum hwtstamp_rx_filters {
	HWTSTAMP_FILTER_NONE = 0,
	HWTSTAMP_FILTER_ALL = 1,
	HWTSTAMP_FILTER_SOME = 2,
	HWTSTAMP_FILTER_PTP_V1_L4_EVENT = 3,
	HWTSTAMP_FILTER_PTP_V1_L4_SYNC = 4,
	HWTSTAMP_FILTER_PTP_V1_L4_DELAY_REQ = 5,
	HWTSTAMP_FILTER_PTP_V2_L4_EVENT = 6,
	HWTSTAMP_FILTER_PTP_V2_L4_SYNC = 7,
	HWTSTAMP_FILTER_PTP_V2_L4_DELAY_REQ = 8,
	HWTSTAMP_FILTER_PTP_V2_L2_EVENT = 9,
	HWTSTAMP_FILTER_PTP_V2_L2_SYNC = 10,
	HWTSTAMP_FILTER_PTP_V2_L2_DELAY_REQ = 11,
	HWTSTAMP_FILTER_PTP_V2_EVENT = 12,
	HWTSTAMP_FILTER_PTP_V2_SYNC = 13,
	HWTSTAMP_FILTER_PTP_V2_DELAY_REQ = 14,
};

struct page___252;

typedef struct page___252 *pgtable_t___252;

struct address_space___253;

struct kmem_cache___236;

struct page___252 {
	long unsigned int flags;
	struct address_space___253 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___252 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___252 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___236 *slab_cache;
		struct page___252 *first_page;
	};
	long: 64;
};

struct task_struct___254;

struct pv_cpu_ops___254 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___254 *);
	void (*end_context_switch)(struct task_struct___254 *);
};

struct mutex___255 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___254 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___247 {
	struct page___252 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___261;

struct signal_struct___254;

struct task_struct___254 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___254 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___261 *mm;
	struct mm_struct___261 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___254 *real_parent;
	struct task_struct___254 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___254 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___254 = 0,
		VTIME_USER___254 = 1,
		VTIME_SYS___254 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct___254 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___255 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___247 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___261 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___261 *, struct mm_struct___261 *);
	void (*dup_mmap)(struct mm_struct___261 *, struct mm_struct___261 *);
	void (*exit_mmap)(struct mm_struct___261 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___261 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___261 *);
	void (*pgd_free)(struct mm_struct___261 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___261 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___261 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___261 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___261 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___261 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___261 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___261 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___261 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___261 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___261 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___261 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___255 lock;
	void *vdso;
} mm_context_t___255;

struct xol_area___252;

struct uprobes_state___252 {
	struct xol_area___252 *xol_area;
};

struct vm_area_struct___261;

struct file___253;

struct core_state___254;

struct mm_struct___261 {
	struct vm_area_struct___261 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___261 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___261 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___255 context;
	long unsigned int flags;
	struct core_state___254 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___254 *owner;
	struct file___253 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___252 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___156;

struct module_kobject___154 {
	struct kobject___37 kobj;
	struct module___156 *mod;
	struct kobject___37 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___154;

struct module___156 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___154 mkobj;
	struct module_attribute___154 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___37 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___254 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___254;

struct lruvec___254 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___254 *zone;
};

struct pglist_data___254;

struct zone___254 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___254 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___254 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___254 {
	struct zone___254 *zone;
	int zone_idx;
};

struct zonelist___254 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___254 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___254 {
	struct zone___254 node_zones[4];
	struct zonelist___254 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___254 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___177;

struct x86_io_apic_ops___177 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___177 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___177;

struct irq_data___177 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___177 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___251;

struct dev_pm_ops___251 {
	int (*prepare)(struct device___251 *);
	void (*complete)(struct device___251 *);
	int (*suspend)(struct device___251 *);
	int (*resume)(struct device___251 *);
	int (*freeze)(struct device___251 *);
	int (*thaw)(struct device___251 *);
	int (*poweroff)(struct device___251 *);
	int (*restore)(struct device___251 *);
	int (*suspend_late)(struct device___251 *);
	int (*resume_early)(struct device___251 *);
	int (*freeze_late)(struct device___251 *);
	int (*thaw_early)(struct device___251 *);
	int (*poweroff_late)(struct device___251 *);
	int (*restore_early)(struct device___251 *);
	int (*suspend_noirq)(struct device___251 *);
	int (*resume_noirq)(struct device___251 *);
	int (*freeze_noirq)(struct device___251 *);
	int (*thaw_noirq)(struct device___251 *);
	int (*poweroff_noirq)(struct device___251 *);
	int (*restore_noirq)(struct device___251 *);
	int (*runtime_suspend)(struct device___251 *);
	int (*runtime_resume)(struct device___251 *);
	int (*runtime_idle)(struct device___251 *);
};

struct dma_map_ops___116;

struct dev_archdata___116 {
	struct dma_map_ops___116 *dma_ops;
	void *iommu;
};

struct device_type___251;

struct bus_type___251;

struct device_driver___251;

struct dev_pm_domain___251;

struct class___251;

struct attribute_group___213;

struct device_rh___251;

struct device___251 {
	struct device___251 *parent;
	struct device_private *p;
	struct kobject___37 kobj;
	const char *init_name;
	const struct device_type___251 *type;
	struct mutex___255 mutex;
	struct bus_type___251 *bus;
	struct device_driver___251 *driver;
	void *platform_data;
	struct dev_pm_info___54 power;
	struct dev_pm_domain___251 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___116 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___42 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___251 *class;
	const struct attribute_group___213 **groups;
	void (*release)(struct device___251 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___251 *device_rh;
};

struct dev_pm_info_rh___251 {
	void (*set_latency_tolerance)(struct device___251 *, s32);
};

struct dev_pm_domain___251 {
	struct dev_pm_ops___251 ops;
};

struct smp_ops___254 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___254 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___215;

struct attribute_group___213 {
	const char *name;
	umode_t (*is_visible)(struct kobject___37 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___215 **bin_attrs;
};

struct bin_attribute___215 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___253 *, struct kobject___37 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___253 *, struct kobject___37 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	int (*mmap)(struct file___253 *, struct kobject___37 *, struct bin_attribute___215 *, struct vm_area_struct___261 *);
};

struct dentry___253;

struct path___253 {
	struct vfsmount *mnt;
	struct dentry___253 *dentry;
};

struct inode___253;

struct file_operations___253;

struct file___253 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___253 f_path;
	struct inode___253 *f_inode;
	const struct file_operations___253 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___253 *f_mapping;
	struct mutex___255 f_pos_lock;
};

struct vm_operations_struct___227;

struct vm_area_struct___261 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___261 *vm_next;
	struct vm_area_struct___261 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___261 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___227 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___253 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___154 *, struct module_kobject___154 *, char *);
	ssize_t (*store)(struct module_attribute___154 *, struct module_kobject___154 *, const char *, size_t);
	void (*setup)(struct module___156 *, const char *);
	int (*test)(struct module___156 *);
	void (*free)(struct module___156 *);
};

struct seq_file___178;

struct irq_chip___177 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___177 *);
	void (*irq_shutdown)(struct irq_data___177 *);
	void (*irq_enable)(struct irq_data___177 *);
	void (*irq_disable)(struct irq_data___177 *);
	void (*irq_ack)(struct irq_data___177 *);
	void (*irq_mask)(struct irq_data___177 *);
	void (*irq_mask_ack)(struct irq_data___177 *);
	void (*irq_unmask)(struct irq_data___177 *);
	void (*irq_eoi)(struct irq_data___177 *);
	int (*irq_set_affinity)(struct irq_data___177 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___177 *);
	int (*irq_set_type)(struct irq_data___177 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___177 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___177 *);
	void (*irq_bus_sync_unlock)(struct irq_data___177 *);
	void (*irq_cpu_online)(struct irq_data___177 *);
	void (*irq_cpu_offline)(struct irq_data___177 *);
	void (*irq_suspend)(struct irq_data___177 *);
	void (*irq_resume)(struct irq_data___177 *);
	void (*irq_pm_shutdown)(struct irq_data___177 *);
	void (*irq_print_chip)(struct irq_data___177 *, struct seq_file___178 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___177 *, void *);
	long unsigned int flags;
};

struct seq_operations___178;

struct seq_file___178 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___255 lock;
	const struct seq_operations___178 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___252 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___252 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___235;

struct memcg_cache_params___236;

struct kmem_cache___236 {
	struct kmem_cache_cpu___235 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___37 kobj;
	struct memcg_cache_params___236 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___253;

struct address_space___253 {
	struct inode___253 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___255 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___253 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___223;

struct vm_operations_struct___227 {
	void (*open)(struct vm_area_struct___261 *);
	void (*close)(struct vm_area_struct___261 *);
	int (*fault)(struct vm_area_struct___261 *, struct vm_fault___223 *);
	int (*page_mkwrite)(struct vm_area_struct___261 *, struct vm_fault___223 *);
	int (*access)(struct vm_area_struct___261 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___261 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___261 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___261 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___261 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___254 {
	struct task_struct___254 *task;
	struct core_thread___254 *next;
};

struct core_state___254 {
	atomic_t nr_threads;
	struct core_thread___254 dumper;
	struct completion startup;
};

struct vm_fault___223 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___252 *page;
};

struct kmem_cache_cpu___235 {
	void **freelist;
	long unsigned int tid;
	struct page___252 *page;
	struct page___252 *partial;
};

struct memcg_cache_params___236 {
	bool is_root_cache;
	union {
		struct kmem_cache___236 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___236 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___116 {
	void * (*alloc)(struct device___251 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___251 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___251 *, struct vm_area_struct___261 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___251 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___251 *, struct page___252 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___251 *, dma_addr_t);
	int (*dma_supported)(struct device___251 *, u64);
	int (*set_dma_mask)(struct device___251 *, u64);
	int is_phys;
};

struct bus_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___251 *, char *);
	ssize_t (*store)(struct bus_type___251 *, const char *, size_t);
};

struct device_attribute___251;

struct driver_attribute___251;

struct bus_type___251 {
	const char *name;
	const char *dev_name;
	struct device___251 *dev_root;
	struct bus_attribute___251 *bus_attrs;
	struct device_attribute___251 *dev_attrs;
	struct driver_attribute___251 *drv_attrs;
	const struct attribute_group___213 **bus_groups;
	const struct attribute_group___213 **dev_groups;
	const struct attribute_group___213 **drv_groups;
	int (*match)(struct device___251 *, struct device_driver___251 *);
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	int (*probe)(struct device___251 *);
	int (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*online)(struct device___251 *);
	int (*offline)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct device___251 *, struct device_attribute___251 *, char *);
	ssize_t (*store)(struct device___251 *, struct device_attribute___251 *, const char *, size_t);
};

struct driver_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___251 *, char *);
	ssize_t (*store)(struct device_driver___251 *, const char *, size_t);
};

struct device_driver___251 {
	const char *name;
	struct bus_type___251 *bus;
	struct module___156 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___251 *);
	int (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	const struct attribute_group___213 **groups;
	const struct dev_pm_ops___251 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___251 {
	const char *name;
	const struct attribute_group___213 **groups;
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
};

struct class_attribute___251;

struct class___251 {
	const char *name;
	struct module___156 *owner;
	struct class_attribute___251 *class_attrs;
	struct device_attribute___251 *dev_attrs;
	const struct attribute_group___213 **dev_groups;
	struct bin_attribute___215 *dev_bin_attrs;
	struct kobject___37 *dev_kobj;
	int (*dev_uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *);
	void (*class_release)(struct class___251 *);
	void (*dev_release)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	const struct kobj_ns_type_operations___34 *ns_type;
	const void * (*namespace)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
	struct subsys_private *p;
};

struct class_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct class___251 *, struct class_attribute___251 *, char *);
	ssize_t (*store)(struct class___251 *, struct class_attribute___251 *, const char *, size_t);
	const void * (*namespace)(struct class___251 *, const struct class_attribute___251 *);
};

struct device_rh___251 {
	struct dev_pm_info_rh___251 power;
};

typedef long unsigned int flow_compare_t;

struct net___58;

typedef struct flow_cache_object * (*flow_resolve_t)(struct net___58 *, const struct flowi *, u16, u8, struct flow_cache_object *, void *);

struct netns_packet___56 {
	struct mutex___255 sklist_lock;
	struct hlist_head sklist;
};

struct dst_ops___57 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___57 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___46 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *);
	int (*local_out)(struct sk_buff___46 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___46 *, const void *);
	struct kmem_cache___236 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___57 {
	struct netns_sysctl_ipv6___55 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___57 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_ct___56 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___58 *sysctl_header;
	struct ctl_table_header___58 *acct_sysctl_header;
	struct ctl_table_header___58 *tstamp_sysctl_header;
	struct ctl_table_header___58 *event_sysctl_header;
	struct ctl_table_header___58 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___236 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___55 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_xfrm___57 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___58 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___57 xfrm4_dst_ops;
	struct dst_ops___57 xfrm6_dst_ops;
};

struct net___58 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___58 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device *loopback_dev;
	struct netns_core___55 core;
	struct netns_mib mib;
	struct netns_packet___56 packet;
	struct netns_unix___55 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___55 ipv4;
	struct netns_ipv6___57 ipv6;
	struct netns_sctp___55 sctp;
	struct netns_dccp___34 dccp;
	struct netns_nf___55 nf;
	struct netns_xt xt;
	struct netns_ct___56 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___55 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___43 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___57 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___255 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___255 flow_flush_sem;
	long: 64;
	long: 64;
};

struct inode_operations___253;

struct super_block___253;

struct file_lock___253;

struct dquot___253;

struct block_device___253;

struct inode___253 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___253 *i_op;
	struct super_block___253 *i_sb;
	struct address_space___253 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___255 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___253 *i_fop;
	struct file_lock___253 *i_flock;
	struct address_space___253 i_data;
	struct dquot___253 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___253 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___253;

struct mem_dqinfo___253 {
	struct quota_format_type___253 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___253;

struct quota_info___253 {
	unsigned int flags;
	struct mutex___255 dqio_mutex;
	struct mutex___255 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___253 *files[2];
	struct mem_dqinfo___253 info[2];
	const struct quota_format_ops___253 *ops[2];
};

struct file_system_type___253;

struct super_operations___253;

struct dquot_operations___253;

struct quotactl_ops___253;

struct dentry_operations___253;

struct super_block___253 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___253 *s_type;
	const struct super_operations___253 *s_op;
	const struct dquot_operations___253 *dq_op;
	const struct quotactl_ops___253 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___253 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___253 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___253 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___255 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___253 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___253 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___253 *d_parent;
	struct qstr d_name;
	struct inode___253 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___253 *d_op;
	struct super_block___253 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct iattr___253 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___253 *ia_file;
};

struct dentry_operations___253 {
	int (*d_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_hash)(const struct dentry___253 *, struct qstr *);
	int (*d_compare)(const struct dentry___253 *, const struct dentry___253 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___253 *);
	void (*d_release)(struct dentry___253 *);
	void (*d_prune)(struct dentry___253 *);
	void (*d_iput)(struct dentry___253 *, struct inode___253 *);
	char * (*d_dname)(struct dentry___253 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___253 *);
	int (*d_manage)(struct dentry___253 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___253 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___253 *bd_inode;
	struct super_block___253 *bd_super;
	struct mutex___255 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___253 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___255 bd_fsfreeze_mutex;
};

struct dquot___253 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___255 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___253 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___253 {
	int qf_fmt_id;
	const struct quota_format_ops___253 *qf_ops;
	struct module___156 *qf_owner;
	struct quota_format_type___253 *qf_next;
};

struct quota_format_ops___253 {
	int (*check_quota_file)(struct super_block___253 *, int);
	int (*read_file_info)(struct super_block___253 *, int);
	int (*write_file_info)(struct super_block___253 *, int);
	int (*free_file_info)(struct super_block___253 *, int);
	int (*read_dqblk)(struct dquot___253 *);
	int (*commit_dqblk)(struct dquot___253 *);
	int (*release_dqblk)(struct dquot___253 *);
};

struct dquot_operations___253 {
	int (*write_dquot)(struct dquot___253 *);
	struct dquot___253 * (*alloc_dquot)(struct super_block___253 *, int);
	void (*destroy_dquot)(struct dquot___253 *);
	int (*acquire_dquot)(struct dquot___253 *);
	int (*release_dquot)(struct dquot___253 *);
	int (*mark_dirty)(struct dquot___253 *);
	int (*write_info)(struct super_block___253 *, int);
	qsize_t * (*get_reserved_space)(struct inode___253 *);
};

struct quotactl_ops___253 {
	int (*quota_on)(struct super_block___253 *, int, int, struct path___253 *);
	int (*quota_on_meta)(struct super_block___253 *, int, int);
	int (*quota_off)(struct super_block___253 *, int);
	int (*quota_sync)(struct super_block___253 *, int);
	int (*get_info)(struct super_block___253 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___253 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___253 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___253 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___253 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___253 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___253 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___253 *, unsigned int);
};

struct address_space_operations___253 {
	int (*writepage)(struct page___252 *, struct writeback_control *);
	int (*readpage)(struct file___253 *, struct page___252 *);
	int (*writepages)(struct address_space___253 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___252 *);
	int (*readpages)(struct file___253 *, struct address_space___253 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___253 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___252 **, void **);
	int (*write_end)(struct file___253 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___252 *, void *);
	sector_t (*bmap)(struct address_space___253 *, sector_t);
	void (*invalidatepage)(struct page___252 *, long unsigned int);
	int (*releasepage)(struct page___252 *, gfp_t);
	void (*freepage)(struct page___252 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___253 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___253 *, struct page___252 *, struct page___252 *, enum migrate_mode);
	int (*launder_page)(struct page___252 *);
	int (*is_partially_uptodate)(struct page___252 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___252 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___253 *, struct page___252 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___253 *, sector_t *);
	void (*swap_deactivate)(struct file___253 *);
	void (*invalidatepage_range)(struct page___252 *, unsigned int, unsigned int);
};

struct inode_operations___253 {
	struct dentry___253 * (*lookup)(struct inode___253 *, struct dentry___253 *, unsigned int);
	void * (*follow_link)(struct dentry___253 *, struct nameidata *);
	int (*permission)(struct inode___253 *, int);
	struct posix_acl * (*get_acl)(struct inode___253 *, int);
	int (*readlink)(struct dentry___253 *, char *, int);
	void (*put_link)(struct dentry___253 *, struct nameidata *, void *);
	int (*create)(struct inode___253 *, struct dentry___253 *, umode_t, bool);
	int (*link)(struct dentry___253 *, struct inode___253 *, struct dentry___253 *);
	int (*unlink)(struct inode___253 *, struct dentry___253 *);
	int (*symlink)(struct inode___253 *, struct dentry___253 *, const char *);
	int (*mkdir)(struct inode___253 *, struct dentry___253 *, umode_t);
	int (*rmdir)(struct inode___253 *, struct dentry___253 *);
	int (*mknod)(struct inode___253 *, struct dentry___253 *, umode_t, dev_t);
	int (*rename)(struct inode___253 *, struct dentry___253 *, struct inode___253 *, struct dentry___253 *);
	int (*setattr)(struct dentry___253 *, struct iattr___253 *);
	int (*getattr)(struct vfsmount *, struct dentry___253 *, struct kstat *);
	int (*setxattr)(struct dentry___253 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___253 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___253 *, char *, size_t);
	int (*removexattr)(struct dentry___253 *, const char *);
	int (*fiemap)(struct inode___253 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___253 *, struct timespec *, int);
	int (*atomic_open)(struct inode___253 *, struct dentry___253 *, struct file___253 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___253 {
	struct module___156 *owner;
	loff_t (*llseek)(struct file___253 *, loff_t, int);
	ssize_t (*read)(struct file___253 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___253 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___253 *, void *, filldir_t);
	unsigned int (*poll)(struct file___253 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___253 *, struct vm_area_struct___261 *);
	int (*open)(struct inode___253 *, struct file___253 *);
	int (*flush)(struct file___253 *, fl_owner_t);
	int (*release)(struct inode___253 *, struct file___253 *);
	int (*fsync)(struct file___253 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___253 *, int);
	int (*lock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*sendpage)(struct file___253 *, struct page___252 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___253 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___253 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___253 *, long int, struct file_lock___253 **, void **);
		struct {
			int (*setlease)(struct file___253 *, long int, struct file_lock___253 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___253 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___178 *, struct file___253 *);
};

struct fasync_struct___253;

struct file_lock_operations___253;

struct lock_manager_operations___253;

struct file_lock___253 {
	struct file_lock___253 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___253 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___253 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___253 *fl_ops;
	const struct lock_manager_operations___253 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___253 {
	void (*fl_copy_lock)(struct file_lock___253 *, struct file_lock___253 *);
	void (*fl_release_private)(struct file_lock___253 *);
};

struct lock_manager_operations___253 {
	int (*lm_compare_owner)(struct file_lock___253 *, struct file_lock___253 *);
	long unsigned int (*lm_owner_key)(struct file_lock___253 *);
	void (*lm_notify)(struct file_lock___253 *);
	int (*lm_grant)(struct file_lock___253 *, struct file_lock___253 *, int);
	void (*lm_break)(struct file_lock___253 *);
	int (*lm_change)(struct file_lock___253 **, int);
};

struct fasync_struct___253 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___253 *fa_next;
	struct file___253 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___253 {
	const char *name;
	int fs_flags;
	struct dentry___253 * (*mount)(struct file_system_type___253 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___253 *);
	struct module___156 *owner;
	struct file_system_type___253 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___253 {
	struct inode___253 * (*alloc_inode)(struct super_block___253 *);
	void (*destroy_inode)(struct inode___253 *);
	void (*dirty_inode)(struct inode___253 *, int);
	int (*write_inode)(struct inode___253 *, struct writeback_control *);
	int (*drop_inode)(struct inode___253 *);
	void (*evict_inode)(struct inode___253 *);
	void (*put_super)(struct super_block___253 *);
	int (*sync_fs)(struct super_block___253 *, int);
	int (*freeze_fs)(struct super_block___253 *);
	int (*unfreeze_fs)(struct super_block___253 *);
	int (*statfs)(struct dentry___253 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___253 *, int *, char *);
	void (*umount_begin)(struct super_block___253 *);
	int (*show_options)(struct seq_file___178 *, struct dentry___253 *);
	int (*show_devname)(struct seq_file___178 *, struct dentry___253 *);
	int (*show_path)(struct seq_file___178 *, struct dentry___253 *);
	int (*show_stats)(struct seq_file___178 *, struct dentry___253 *);
	ssize_t (*quota_read)(struct super_block___253 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___253 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___253 *);
	int (*bdev_try_to_free_page)(struct super_block___253 *, struct page___252 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___253 *);
	void (*free_cached_objects)(struct super_block___253 *, int);
};

struct signal_struct___254 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___254 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___254 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___255 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct nf_afinfo___57 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___46 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___46 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___58 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___46 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___46 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___178 {
	void * (*start)(struct seq_file___178 *, loff_t *);
	void (*stop)(struct seq_file___178 *, void *);
	void * (*next)(struct seq_file___178 *, void *, loff_t *);
	int (*show)(struct seq_file___178 *, void *);
};

struct flow_cache_entry {
	union {
		struct hlist_node hlist;
		struct list_head gc_list;
	} u;
	struct net___58 *net;
	u16 family;
	u8 dir;
	u32 genid;
	struct flowi key;
	struct flow_cache_object *object;
};

struct flow_flush_info {
	struct flow_cache *cache;
	atomic_t cpuleft;
	struct completion completion;
};

struct rx_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_rx_queue___42 *, struct rx_queue_attribute *, char *);
	ssize_t (*store)(struct netdev_rx_queue___42 *, struct rx_queue_attribute *, const char *, size_t);
};

struct netdev_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_queue___42 *, struct netdev_queue_attribute *, char *);
	ssize_t (*store)(struct netdev_queue___42 *, struct netdev_queue_attribute *, const char *, size_t);
};

struct packet_type___2 {
	__be16 type;
	struct net_device___3 *dev;
	int (*func)(struct sk_buff___46 *, struct net_device___3 *, struct packet_type___2 *, struct net_device___3 *);
	bool (*id_match)(struct packet_type___2 *, struct sock *);
	void *af_packet_priv;
	struct list_head list;
};

struct softnet_data___2 {
	struct Qdisc *output_queue;
	struct Qdisc **output_queue_tailp;
	struct list_head poll_list;
	struct sk_buff___46 *completion_queue;
	struct sk_buff_head___43 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int cpu_collision;
	unsigned int received_rps;
	struct softnet_data___2 *rps_ipi_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct call_single_data csd;
	struct softnet_data___2 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_head;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___43 input_pkt_queue;
	struct napi_struct___42 backlog;
	long: 64;
	long: 64;
};

struct page___253;

typedef struct page___253 *pgtable_t___253;

struct address_space___254;

struct kmem_cache___237;

struct page___253 {
	long unsigned int flags;
	struct address_space___254 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___253 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___253 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___237 *slab_cache;
		struct page___253 *first_page;
	};
	long: 64;
};

struct task_struct___255;

struct pv_cpu_ops___255 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___255 *);
	void (*end_context_switch)(struct task_struct___255 *);
};

struct mutex___256 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___255 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___248 {
	struct page___253 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___262;

struct nsproxy___134;

struct signal_struct___255;

struct css_set___149;

struct task_struct___255 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___255 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___262 *mm;
	struct mm_struct___262 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___255 *real_parent;
	struct task_struct___255 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___255 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___255 = 0,
		VTIME_USER___255 = 1,
		VTIME_SYS___255 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___134 *nsproxy;
	struct signal_struct___255 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___149 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___256 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___248 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___262 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___262 *, struct mm_struct___262 *);
	void (*dup_mmap)(struct mm_struct___262 *, struct mm_struct___262 *);
	void (*exit_mmap)(struct mm_struct___262 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___262 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___262 *);
	void (*pgd_free)(struct mm_struct___262 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___262 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___262 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___262 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___262 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___262 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___262 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___262 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___262 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___262 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___262 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___262 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___256 lock;
	void *vdso;
} mm_context_t___256;

struct xol_area___253;

struct uprobes_state___253 {
	struct xol_area___253 *xol_area;
};

struct vm_area_struct___262;

struct file___254;

struct core_state___255;

struct mm_struct___262 {
	struct vm_area_struct___262 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___262 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___262 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___256 context;
	long unsigned int flags;
	struct core_state___255 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___255 *owner;
	struct file___254 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___253 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kiocb___43;

struct poll_table_struct___142;

struct inode___254;

struct file_lock___254;

struct seq_file___179;

struct file_operations___254 {
	struct module *owner;
	loff_t (*llseek)(struct file___254 *, loff_t, int);
	ssize_t (*read)(struct file___254 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___254 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___43 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___43 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___254 *, void *, filldir_t);
	unsigned int (*poll)(struct file___254 *, struct poll_table_struct___142 *);
	long int (*unlocked_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___254 *, struct vm_area_struct___262 *);
	int (*open)(struct inode___254 *, struct file___254 *);
	int (*flush)(struct file___254 *, fl_owner_t);
	int (*release)(struct inode___254 *, struct file___254 *);
	int (*fsync)(struct file___254 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___43 *, int);
	int (*fasync)(int, struct file___254 *, int);
	int (*lock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*sendpage)(struct file___254 *, struct page___253 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___254 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___254 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___254 *, long int, struct file_lock___254 **, void **);
		struct {
			int (*setlease)(struct file___254 *, long int, struct file_lock___254 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___254 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___179 *, struct file___254 *);
};

struct kset___38;

struct kobj_type___38;

struct kobject___38 {
	const char *name;
	struct list_head entry;
	struct kobject___38 *parent;
	struct kset___38 *kset;
	struct kobj_type___38 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___55;

struct dev_pm_info___55 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___55 *qos;
};

struct dma_map_ops___117;

struct dev_archdata___117 {
	struct dma_map_ops___117 *dma_ops;
	void *iommu;
};

struct device_type___252;

struct bus_type___252;

struct device_driver___252;

struct dev_pm_domain___252;

struct class___252;

struct attribute_group___214;

struct device_rh___252;

struct device___252 {
	struct device___252 *parent;
	struct device_private *p;
	struct kobject___38 kobj;
	const char *init_name;
	const struct device_type___252 *type;
	struct mutex___256 mutex;
	struct bus_type___252 *bus;
	struct device_driver___252 *driver;
	void *platform_data;
	struct dev_pm_info___55 power;
	struct dev_pm_domain___252 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___117 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___252 *class;
	const struct attribute_group___214 **groups;
	void (*release)(struct device___252 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___252 *device_rh;
};

struct sock___37;

struct kobj_ns_type_operations___35 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___37 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___35;

struct net___59;

struct sock_common___35 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___35 *skc_prot;
	struct net___59 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___48;

struct sk_buff_head___45 {
	struct sk_buff___48 *next;
	struct sk_buff___48 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___36;

struct socket_wq___35;

struct dst_entry___35;

struct socket___36;

struct cg_proto___35;

struct sock___37 {
	struct sock_common___35 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___45 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___48 *head;
		struct sk_buff___48 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___36 *sk_filter;
	struct socket_wq___35 *sk_wq;
	struct sk_buff_head___45 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___35 *sk_rx_dst;
	struct dst_entry___35 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___45 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___45 sk_error_queue;
	struct proto___35 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___36 *sk_socket;
	void *sk_user_data;
	struct page_frag___248 sk_frag;
	struct sk_buff___48 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___35 *sk_cgrp;
	void (*sk_state_change)(struct sock___37 *);
	void (*sk_data_ready)(struct sock___37 *, int);
	void (*sk_write_space)(struct sock___37 *);
	void (*sk_error_report)(struct sock___37 *);
	int (*sk_backlog_rcv)(struct sock___37 *, struct sk_buff___48 *);
	void (*sk_destruct)(struct sock___37 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___216;

struct attribute_group___214 {
	const char *name;
	umode_t (*is_visible)(struct kobject___38 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___216 **bin_attrs;
};

struct bin_attribute___216 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___254 *, struct kobject___38 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___254 *, struct kobject___38 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	int (*mmap)(struct file___254 *, struct kobject___38 *, struct bin_attribute___216 *, struct vm_area_struct___262 *);
};

struct dentry___254;

struct path___254 {
	struct vfsmount *mnt;
	struct dentry___254 *dentry;
};

struct file___254 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___254 f_path;
	struct inode___254 *f_inode;
	const struct file_operations___254 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___254 *f_mapping;
	struct mutex___256 f_pos_lock;
};

struct vm_operations_struct___228;

struct vm_area_struct___262 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___262 *vm_next;
	struct vm_area_struct___262 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___262 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___228 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___254 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___38 {
	ssize_t (*show)(struct kobject___38 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___38 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___38 *, const struct attribute *);
};

struct kset_uevent_ops___38;

struct kset___38 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___38 kobj;
	const struct kset_uevent_ops___38 *uevent_ops;
};

struct kobj_type___38 {
	void (*release)(struct kobject___38 *);
	const struct sysfs_ops___38 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___38 *);
	const void * (*namespace)(struct kobject___38 *);
};

struct kset_uevent_ops___38 {
	int (* const filter)(struct kset___38 *, struct kobject___38 *);
	const char * (* const name)(struct kset___38 *, struct kobject___38 *);
	int (* const uevent)(struct kset___38 *, struct kobject___38 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___252 {
	int (*prepare)(struct device___252 *);
	void (*complete)(struct device___252 *);
	int (*suspend)(struct device___252 *);
	int (*resume)(struct device___252 *);
	int (*freeze)(struct device___252 *);
	int (*thaw)(struct device___252 *);
	int (*poweroff)(struct device___252 *);
	int (*restore)(struct device___252 *);
	int (*suspend_late)(struct device___252 *);
	int (*resume_early)(struct device___252 *);
	int (*freeze_late)(struct device___252 *);
	int (*thaw_early)(struct device___252 *);
	int (*poweroff_late)(struct device___252 *);
	int (*restore_early)(struct device___252 *);
	int (*suspend_noirq)(struct device___252 *);
	int (*resume_noirq)(struct device___252 *);
	int (*freeze_noirq)(struct device___252 *);
	int (*thaw_noirq)(struct device___252 *);
	int (*poweroff_noirq)(struct device___252 *);
	int (*restore_noirq)(struct device___252 *);
	int (*runtime_suspend)(struct device___252 *);
	int (*runtime_resume)(struct device___252 *);
	int (*runtime_idle)(struct device___252 *);
};

struct dev_pm_qos_request___56;

struct dev_pm_qos___55 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___56 *latency_req;
	struct dev_pm_qos_request___56 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___56 *latency_tolerance_req;
};

struct dev_pm_info_rh___252 {
	void (*set_latency_tolerance)(struct device___252 *, s32);
};

struct dev_pm_domain___252 {
	struct dev_pm_ops___252 ops;
};

struct zone___255;

struct lruvec___255 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___255 *zone;
};

struct pglist_data___255;

struct zone___255 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___255 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___255 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___255 {
	struct zone___255 *zone;
	int zone_idx;
};

struct zonelist___255 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___255 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___255 {
	struct zone___255 node_zones[4];
	struct zonelist___255 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___255 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___178;

struct x86_io_apic_ops___178 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___178 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___178;

struct irq_data___178 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___178 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___255 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___255 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___117 {
	void * (*alloc)(struct device___252 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___252 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___252 *, struct vm_area_struct___262 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___252 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___252 *, struct page___253 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___252 *, dma_addr_t);
	int (*dma_supported)(struct device___252 *, u64);
	int (*set_dma_mask)(struct device___252 *, u64);
	int is_phys;
};

struct bus_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___252 *, char *);
	ssize_t (*store)(struct bus_type___252 *, const char *, size_t);
};

struct device_attribute___252;

struct driver_attribute___252;

struct bus_type___252 {
	const char *name;
	const char *dev_name;
	struct device___252 *dev_root;
	struct bus_attribute___252 *bus_attrs;
	struct device_attribute___252 *dev_attrs;
	struct driver_attribute___252 *drv_attrs;
	const struct attribute_group___214 **bus_groups;
	const struct attribute_group___214 **dev_groups;
	const struct attribute_group___214 **drv_groups;
	int (*match)(struct device___252 *, struct device_driver___252 *);
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	int (*probe)(struct device___252 *);
	int (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*online)(struct device___252 *);
	int (*offline)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct device___252 *, struct device_attribute___252 *, char *);
	ssize_t (*store)(struct device___252 *, struct device_attribute___252 *, const char *, size_t);
};

struct driver_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___252 *, char *);
	ssize_t (*store)(struct device_driver___252 *, const char *, size_t);
};

struct device_driver___252 {
	const char *name;
	struct bus_type___252 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___252 *);
	int (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	const struct attribute_group___214 **groups;
	const struct dev_pm_ops___252 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___252 {
	const char *name;
	const struct attribute_group___214 **groups;
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
};

struct class_attribute___252;

struct class___252 {
	const char *name;
	struct module *owner;
	struct class_attribute___252 *class_attrs;
	struct device_attribute___252 *dev_attrs;
	const struct attribute_group___214 **dev_groups;
	struct bin_attribute___216 *dev_bin_attrs;
	struct kobject___38 *dev_kobj;
	int (*dev_uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *);
	void (*class_release)(struct class___252 *);
	void (*dev_release)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
	struct subsys_private *p;
};

struct class_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct class___252 *, struct class_attribute___252 *, char *);
	ssize_t (*store)(struct class___252 *, struct class_attribute___252 *, const char *, size_t);
	const void * (*namespace)(struct class___252 *, const struct class_attribute___252 *);
};

struct device_rh___252 {
	struct dev_pm_info_rh___252 power;
};

struct dev_pm_qos_request___56 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___252 *dev;
};

struct xol_area___253 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___253 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___236;

struct memcg_cache_params___237;

struct kmem_cache___237 {
	struct kmem_cache_cpu___236 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___38 kobj;
	struct memcg_cache_params___237 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___254;

struct address_space___254 {
	struct inode___254 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___256 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___254 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___224;

struct vm_operations_struct___228 {
	void (*open)(struct vm_area_struct___262 *);
	void (*close)(struct vm_area_struct___262 *);
	int (*fault)(struct vm_area_struct___262 *, struct vm_fault___224 *);
	int (*page_mkwrite)(struct vm_area_struct___262 *, struct vm_fault___224 *);
	int (*access)(struct vm_area_struct___262 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___262 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___262 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___262 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___262 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___255 {
	struct task_struct___255 *task;
	struct core_thread___255 *next;
};

struct core_state___255 {
	atomic_t nr_threads;
	struct core_thread___255 dumper;
	struct completion startup;
};

struct vm_fault___224 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___253 *page;
};

struct dentry_operations___254;

struct super_block___254;

struct dentry___254 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___254 *d_parent;
	struct qstr d_name;
	struct inode___254 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___254 *d_op;
	struct super_block___254 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___254;

struct dquot___254;

struct block_device___254;

struct inode___254 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___254 *i_op;
	struct super_block___254 *i_sb;
	struct address_space___254 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___256 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___254 *i_fop;
	struct file_lock___254 *i_flock;
	struct address_space___254 i_data;
	struct dquot___254 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___254 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___254 {
	int (*d_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_hash)(const struct dentry___254 *, struct qstr *);
	int (*d_compare)(const struct dentry___254 *, const struct dentry___254 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___254 *);
	void (*d_release)(struct dentry___254 *);
	void (*d_prune)(struct dentry___254 *);
	void (*d_iput)(struct dentry___254 *, struct inode___254 *);
	char * (*d_dname)(struct dentry___254 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___254 *);
	int (*d_manage)(struct dentry___254 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___254;

struct mem_dqinfo___254 {
	struct quota_format_type___254 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___254;

struct quota_info___254 {
	unsigned int flags;
	struct mutex___256 dqio_mutex;
	struct mutex___256 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___254 *files[2];
	struct mem_dqinfo___254 info[2];
	const struct quota_format_ops___254 *ops[2];
};

struct file_system_type___254;

struct super_operations___254;

struct dquot_operations___254;

struct quotactl_ops___254;

struct xattr_handler___150;

struct super_block___254 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___254 *s_type;
	const struct super_operations___254 *s_op;
	const struct dquot_operations___254 *dq_op;
	const struct quotactl_ops___254 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___254 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___150 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___254 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___254 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___256 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___254 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___254 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___254 *bd_inode;
	struct super_block___254 *bd_super;
	struct mutex___256 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___254 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___256 bd_fsfreeze_mutex;
};

struct cgroup___149;

struct cgroup_subsys_state___149 {
	struct cgroup___149 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___43(struct kiocb___43 *, struct io_event *);

struct kiocb___43 {
	atomic_t ki_users;
	struct file___254 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___43 *ki_cancel;
	void (*ki_dtor)(struct kiocb___43 *);
	union {
		void *user;
		struct task_struct___255 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___254 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___254 *ia_file;
};

struct dquot___254 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___256 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___254 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___254 {
	int qf_fmt_id;
	const struct quota_format_ops___254 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___254 *qf_next;
};

struct quota_format_ops___254 {
	int (*check_quota_file)(struct super_block___254 *, int);
	int (*read_file_info)(struct super_block___254 *, int);
	int (*write_file_info)(struct super_block___254 *, int);
	int (*free_file_info)(struct super_block___254 *, int);
	int (*read_dqblk)(struct dquot___254 *);
	int (*commit_dqblk)(struct dquot___254 *);
	int (*release_dqblk)(struct dquot___254 *);
};

struct dquot_operations___254 {
	int (*write_dquot)(struct dquot___254 *);
	struct dquot___254 * (*alloc_dquot)(struct super_block___254 *, int);
	void (*destroy_dquot)(struct dquot___254 *);
	int (*acquire_dquot)(struct dquot___254 *);
	int (*release_dquot)(struct dquot___254 *);
	int (*mark_dirty)(struct dquot___254 *);
	int (*write_info)(struct super_block___254 *, int);
	qsize_t * (*get_reserved_space)(struct inode___254 *);
};

struct quotactl_ops___254 {
	int (*quota_on)(struct super_block___254 *, int, int, struct path___254 *);
	int (*quota_on_meta)(struct super_block___254 *, int, int);
	int (*quota_off)(struct super_block___254 *, int);
	int (*quota_sync)(struct super_block___254 *, int);
	int (*get_info)(struct super_block___254 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___254 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___254 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___254 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___254 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___254 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___254 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___254 *, unsigned int);
};

struct address_space_operations___254 {
	int (*writepage)(struct page___253 *, struct writeback_control *);
	int (*readpage)(struct file___254 *, struct page___253 *);
	int (*writepages)(struct address_space___254 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___253 *);
	int (*readpages)(struct file___254 *, struct address_space___254 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___254 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___253 **, void **);
	int (*write_end)(struct file___254 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___253 *, void *);
	sector_t (*bmap)(struct address_space___254 *, sector_t);
	void (*invalidatepage)(struct page___253 *, long unsigned int);
	int (*releasepage)(struct page___253 *, gfp_t);
	void (*freepage)(struct page___253 *);
	ssize_t (*direct_IO)(int, struct kiocb___43 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___254 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___254 *, struct page___253 *, struct page___253 *, enum migrate_mode);
	int (*launder_page)(struct page___253 *);
	int (*is_partially_uptodate)(struct page___253 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___253 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___254 *, struct page___253 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___254 *, sector_t *);
	void (*swap_deactivate)(struct file___254 *);
	void (*invalidatepage_range)(struct page___253 *, unsigned int, unsigned int);
};

struct inode_operations___254 {
	struct dentry___254 * (*lookup)(struct inode___254 *, struct dentry___254 *, unsigned int);
	void * (*follow_link)(struct dentry___254 *, struct nameidata *);
	int (*permission)(struct inode___254 *, int);
	struct posix_acl * (*get_acl)(struct inode___254 *, int);
	int (*readlink)(struct dentry___254 *, char *, int);
	void (*put_link)(struct dentry___254 *, struct nameidata *, void *);
	int (*create)(struct inode___254 *, struct dentry___254 *, umode_t, bool);
	int (*link)(struct dentry___254 *, struct inode___254 *, struct dentry___254 *);
	int (*unlink)(struct inode___254 *, struct dentry___254 *);
	int (*symlink)(struct inode___254 *, struct dentry___254 *, const char *);
	int (*mkdir)(struct inode___254 *, struct dentry___254 *, umode_t);
	int (*rmdir)(struct inode___254 *, struct dentry___254 *);
	int (*mknod)(struct inode___254 *, struct dentry___254 *, umode_t, dev_t);
	int (*rename)(struct inode___254 *, struct dentry___254 *, struct inode___254 *, struct dentry___254 *);
	int (*setattr)(struct dentry___254 *, struct iattr___254 *);
	int (*getattr)(struct vfsmount *, struct dentry___254 *, struct kstat *);
	int (*setxattr)(struct dentry___254 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___254 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___254 *, char *, size_t);
	int (*removexattr)(struct dentry___254 *, const char *);
	int (*fiemap)(struct inode___254 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___254 *, struct timespec *, int);
	int (*atomic_open)(struct inode___254 *, struct dentry___254 *, struct file___254 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___254;

struct file_lock_operations___254;

struct lock_manager_operations___254;

struct file_lock___254 {
	struct file_lock___254 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___254 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___254 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___254 *fl_ops;
	const struct lock_manager_operations___254 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___254 {
	void (*fl_copy_lock)(struct file_lock___254 *, struct file_lock___254 *);
	void (*fl_release_private)(struct file_lock___254 *);
};

struct lock_manager_operations___254 {
	int (*lm_compare_owner)(struct file_lock___254 *, struct file_lock___254 *);
	long unsigned int (*lm_owner_key)(struct file_lock___254 *);
	void (*lm_notify)(struct file_lock___254 *);
	int (*lm_grant)(struct file_lock___254 *, struct file_lock___254 *, int);
	void (*lm_break)(struct file_lock___254 *);
	int (*lm_change)(struct file_lock___254 **, int);
};

struct fasync_struct___254 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___254 *fa_next;
	struct file___254 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___254 {
	const char *name;
	int fs_flags;
	struct dentry___254 * (*mount)(struct file_system_type___254 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___254 *);
	struct module *owner;
	struct file_system_type___254 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___254 {
	struct inode___254 * (*alloc_inode)(struct super_block___254 *);
	void (*destroy_inode)(struct inode___254 *);
	void (*dirty_inode)(struct inode___254 *, int);
	int (*write_inode)(struct inode___254 *, struct writeback_control *);
	int (*drop_inode)(struct inode___254 *);
	void (*evict_inode)(struct inode___254 *);
	void (*put_super)(struct super_block___254 *);
	int (*sync_fs)(struct super_block___254 *, int);
	int (*freeze_fs)(struct super_block___254 *);
	int (*unfreeze_fs)(struct super_block___254 *);
	int (*statfs)(struct dentry___254 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___254 *, int *, char *);
	void (*umount_begin)(struct super_block___254 *);
	int (*show_options)(struct seq_file___179 *, struct dentry___254 *);
	int (*show_devname)(struct seq_file___179 *, struct dentry___254 *);
	int (*show_path)(struct seq_file___179 *, struct dentry___254 *);
	int (*show_stats)(struct seq_file___179 *, struct dentry___254 *);
	ssize_t (*quota_read)(struct super_block___254 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___254 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___254 *);
	int (*bdev_try_to_free_page)(struct super_block___254 *, struct page___253 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___254 *);
	void (*free_cached_objects)(struct super_block___254 *, int);
};

struct xattr_handler___150 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___254 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___254 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___254 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___144)(struct file___254 *, wait_queue_head_t *, struct poll_table_struct___142 *);

struct poll_table_struct___142 {
	poll_queue_proc___144 _qproc;
	long unsigned int _key;
};

struct seq_operations___179;

struct seq_file___179 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___256 lock;
	const struct seq_operations___179 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_table_header___59;

struct ctl_node___59 {
	struct rb_node node;
	struct ctl_table_header___59 *header;
};

struct ctl_table_root___59;

struct ctl_table_set___59;

struct ctl_dir___59;

struct ctl_table_header___59 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___59 *root;
	struct ctl_table_set___59 *set;
	struct ctl_dir___59 *parent;
	struct ctl_node___59 *node;
};

struct ctl_dir___59 {
	struct ctl_table_header___59 header;
	struct rb_root root;
};

struct ctl_table_set___59 {
	int (*is_seen)(struct ctl_table_set___59 *);
	struct ctl_dir___59 dir;
};

struct ctl_table_root___59 {
	struct ctl_table_set___59 default_set;
	struct ctl_table_set___59 * (*lookup)(struct ctl_table_root___59 *, struct nsproxy___134 *);
	int (*permissions)(struct ctl_table_header___59 *, struct ctl_table *);
};

struct nsproxy___134 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___59 *net_ns;
};

struct signal_struct___255 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___255 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___255 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___256 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___149 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___149 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___35 {
	wait_queue_head_t wait;
	struct fasync_struct___254 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___35;

struct socket___36 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___35 *wq;
	struct file___254 *file;
	struct sock___37 *sk;
	const struct proto_ops___35 *ops;
};

struct proto_ops___35 {
	int family;
	struct module *owner;
	int (*release)(struct socket___36 *);
	int (*bind)(struct socket___36 *, struct sockaddr *, int);
	int (*connect)(struct socket___36 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___36 *, struct socket___36 *);
	int (*accept)(struct socket___36 *, struct socket___36 *, int);
	int (*getname)(struct socket___36 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___254 *, struct socket___36 *, struct poll_table_struct___142 *);
	int (*ioctl)(struct socket___36 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___36 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___36 *, int);
	int (*shutdown)(struct socket___36 *, int);
	int (*setsockopt)(struct socket___36 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___36 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___36 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___36 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___43 *, struct socket___36 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___43 *, struct socket___36 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___254 *, struct socket___36 *, struct vm_area_struct___262 *);
	ssize_t (*sendpage)(struct socket___36 *, struct page___253 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___36 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___37 *, int);
		struct {
			void (*set_peek_off)(struct sock___37 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___56 {
	struct ctl_table_header___59 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___57 {
	struct mutex___256 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___56 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___59 *ctl;
};

struct netns_ipv4___56 {
	struct ctl_table_header___59 *forw_hdr;
	struct ctl_table_header___59 *frags_hdr;
	struct ctl_table_header___59 *ipv4_hdr;
	struct ctl_table_header___59 *route_hdr;
	struct ctl_table_header___59 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___37 *fibnl;
	struct sock___37 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___56 {
	struct ctl_table_header___59 *hdr;
	struct ctl_table_header___59 *route_hdr;
	struct ctl_table_header___59 *icmp_hdr;
	struct ctl_table_header___59 *frags_hdr;
	struct ctl_table_header___59 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___45;

struct neighbour___35;

struct dst_ops___58 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___58 *);
	struct dst_entry___35 * (*check)(struct dst_entry___35 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___35 *);
	unsigned int (*mtu)(const struct dst_entry___35 *);
	u32 * (*cow_metrics)(struct dst_entry___35 *, long unsigned int);
	void (*destroy)(struct dst_entry___35 *);
	void (*ifdown)(struct dst_entry___35 *, struct net_device___45 *, int);
	struct dst_entry___35 * (*negative_advice)(struct dst_entry___35 *);
	void (*link_failure)(struct sk_buff___48 *);
	void (*update_pmtu)(struct dst_entry___35 *, struct sock___37 *, struct sk_buff___48 *, u32);
	void (*redirect)(struct dst_entry___35 *, struct sock___37 *, struct sk_buff___48 *);
	int (*local_out)(struct sk_buff___48 *);
	struct neighbour___35 * (*neigh_lookup)(const struct dst_entry___35 *, struct sk_buff___48 *, const void *);
	struct kmem_cache___237 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___58 {
	struct netns_sysctl_ipv6___56 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___58 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___37 **icmp_sk;
	struct sock___37 *ndisc_sk;
	struct sock___37 *tcp_sk;
	struct sock___37 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___56 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___59 *sysctl_header;
	struct sock___37 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___35 {
	struct sock___37 *v4_ctl_sk;
	struct sock___37 *v6_ctl_sk;
};

struct netns_nf___56 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___59 *nf_log_dir_header;
};

struct nf_proto_net___56 {
	struct ctl_table_header___59 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___56 {
	struct nf_proto_net___56 pn;
	unsigned int timeout;
};

struct nf_tcp_net___56 {
	struct nf_proto_net___56 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___56 {
	struct nf_proto_net___56 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___56 {
	struct nf_proto_net___56 pn;
	unsigned int timeout;
};

struct nf_ip_net___56 {
	struct nf_generic_net___56 generic;
	struct nf_tcp_net___56 tcp;
	struct nf_udp_net___56 udp;
	struct nf_icmp_net___56 icmp;
	struct nf_icmp_net___56 icmpv6;
};

struct netns_ct___57 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___59 *sysctl_header;
	struct ctl_table_header___59 *acct_sysctl_header;
	struct ctl_table_header___59 *tstamp_sysctl_header;
	struct ctl_table_header___59 *event_sysctl_header;
	struct ctl_table_header___59 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___237 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___56 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___56 {
	struct netns_sysctl_ipv6___56 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___58 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___37 *nlsk;
	struct sock___37 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___59 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___58 xfrm4_dst_ops;
	struct dst_ops___58 xfrm6_dst_ops;
};

struct net___59 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___59 sysctls;
	struct sock___37 *rtnl;
	struct sock___37 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___45 *loopback_dev;
	struct netns_core___56 core;
	struct netns_mib mib;
	struct netns_packet___57 packet;
	struct netns_unix___56 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___56 ipv4;
	struct netns_ipv6___58 ipv6;
	struct netns_sctp___56 sctp;
	struct netns_dccp___35 dccp;
	struct netns_nf___56 nf;
	struct netns_xt xt;
	struct netns_ct___57 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___56 nf_frag;
	struct sock___37 *nfnl;
	struct sock___37 *nfnl_stash;
	struct sk_buff_head___45 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___58 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___37 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___37 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___256 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___256 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___236 {
	void **freelist;
	long unsigned int tid;
	struct page___253 *page;
	struct page___253 *partial;
};

struct memcg_cache_params___237 {
	bool is_root_cache;
	union {
		struct kmem_cache___237 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___237 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___44 {
	atomic_t use;
	unsigned int mask;
	struct net_device___45 *physindev;
	struct net_device___45 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___44(struct sk_buff___48 **);

struct net_device_ops___44;

struct ethtool_ops___44;

struct header_ops___44;

struct in_device___3;

struct inet6_dev___19;

struct netdev_rx_queue___44;

struct netdev_queue___44;

struct netpoll_info___3;

struct rtnl_link_ops___35;

struct dcbnl_rtnl_ops___44;

struct net_device___45 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___44 *netdev_ops;
	const struct ethtool_ops___44 *ethtool_ops;
	const struct header_ops___44 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___38 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___3 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___19 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___44 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___44 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___44 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___44 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___44 = 0,
		NETREG_REGISTERED___44 = 1,
		NETREG_UNREGISTERING___44 = 2,
		NETREG_UNREGISTERED___44 = 3,
		NETREG_RELEASED___44 = 4,
		NETREG_DUMMY___44 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___44 = 0,
		RTNL_LINK_INITIALIZING___44 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___45 *);
	struct netpoll_info___3 *npinfo;
	struct net___59 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___252 dev;
	const struct attribute_group___214 *sysfs_groups[4];
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___44 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___48 {
	struct sk_buff___48 *next;
	struct sk_buff___48 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___37 *sk;
	struct net_device___45 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___48 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___44 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___6 {
	struct {
		struct page___253 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___6 skb_frag_t___6;

struct skb_shared_info___6 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___48 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___6 frags[17];
};

struct ethtool_ops___44 {
	int (*get_settings)(struct net_device___45 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___45 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___45 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___45 *);
	void (*get_regs)(struct net_device___45 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___45 *);
	void (*set_msglevel)(struct net_device___45 *, u32);
	int (*nway_reset)(struct net_device___45 *);
	u32 (*get_link)(struct net_device___45 *);
	int (*get_eeprom_len)(struct net_device___45 *);
	int (*get_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___45 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___45 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___45 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___45 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___45 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___45 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___45 *);
	void (*complete)(struct net_device___45 *);
	u32 (*get_priv_flags)(struct net_device___45 *);
	int (*set_priv_flags)(struct net_device___45 *, u32);
	int (*get_sset_count)(struct net_device___45 *, int);
	int (*get_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___45 *, struct ethtool_flash *);
	int (*reset)(struct net_device___45 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___45 *);
	int (*get_rxfh_indir)(struct net_device___45 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___45 *, const u32 *);
	void (*get_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___45 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___45 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___45 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___45 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___45 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___45 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___45 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___45 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___14;

struct dst_entry___35 {
	struct callback_head callback_head;
	struct dst_entry___35 *child;
	struct net_device___45 *dev;
	struct dst_ops___58 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___35 *path;
	struct dst_entry___35 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___48 *);
	union {
		int (*output)(struct sock___37 *, struct sk_buff___48 *);
		struct {
			int (*output)(struct sk_buff___48 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___35 *next;
		struct rtable___14 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___35;

struct neigh_parms___35;

struct neigh_ops___35;

struct neighbour___35 {
	struct neighbour___35 *next;
	struct neigh_table___35 *tbl;
	struct neigh_parms___35 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___45 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___35 *, struct sk_buff___48 *);
	const struct neigh_ops___35 *ops;
	struct callback_head rcu;
	struct net_device___45 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___58 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___48 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___48 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___59 *, struct dst_entry___35 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___48 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___48 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___178 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___178 *);
	void (*irq_shutdown)(struct irq_data___178 *);
	void (*irq_enable)(struct irq_data___178 *);
	void (*irq_disable)(struct irq_data___178 *);
	void (*irq_ack)(struct irq_data___178 *);
	void (*irq_mask)(struct irq_data___178 *);
	void (*irq_mask_ack)(struct irq_data___178 *);
	void (*irq_unmask)(struct irq_data___178 *);
	void (*irq_eoi)(struct irq_data___178 *);
	int (*irq_set_affinity)(struct irq_data___178 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___178 *);
	int (*irq_set_type)(struct irq_data___178 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___178 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___178 *);
	void (*irq_bus_sync_unlock)(struct irq_data___178 *);
	void (*irq_cpu_online)(struct irq_data___178 *);
	void (*irq_cpu_offline)(struct irq_data___178 *);
	void (*irq_suspend)(struct irq_data___178 *);
	void (*irq_resume)(struct irq_data___178 *);
	void (*irq_pm_shutdown)(struct irq_data___178 *);
	void (*irq_print_chip)(struct irq_data___178 *, struct seq_file___179 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___178 *, void *);
	long unsigned int flags;
};

struct seq_operations___179 {
	void * (*start)(struct seq_file___179 *, loff_t *);
	void (*stop)(struct seq_file___179 *, void *);
	void * (*next)(struct seq_file___179 *, void *, loff_t *);
	int (*show)(struct seq_file___179 *, void *);
};

struct dcbnl_rtnl_ops___44 {
	int (*ieee_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___45 *);
	u8 (*setstate)(struct net_device___45 *, u8);
	void (*getpermhwaddr)(struct net_device___45 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___45 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___45 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___45 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___45 *, int, u8 *);
	void (*setpfccfg)(struct net_device___45 *, int, u8);
	void (*getpfccfg)(struct net_device___45 *, int, u8 *);
	u8 (*setall)(struct net_device___45 *);
	u8 (*getcap)(struct net_device___45 *, int, u8 *);
	int (*getnumtcs)(struct net_device___45 *, int, u8 *);
	int (*setnumtcs)(struct net_device___45 *, int, u8);
	u8 (*getpfcstate)(struct net_device___45 *);
	void (*setpfcstate)(struct net_device___45 *, u8);
	void (*getbcncfg)(struct net_device___45 *, int, u32 *);
	void (*setbcncfg)(struct net_device___45 *, int, u32);
	void (*getbcnrp)(struct net_device___45 *, int, u8 *);
	void (*setbcnrp)(struct net_device___45 *, int, u8);
	u8 (*setapp)(struct net_device___45 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___45 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___45 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___45 *, int, u8);
	u8 (*getdcbx)(struct net_device___45 *);
	u8 (*setdcbx)(struct net_device___45 *, u8);
	int (*peer_getappinfo)(struct net_device___45 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___45 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___45 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___45 *, struct cee_pfc *);
};

struct cgroupfs_root___149;

struct cgroup___149 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___149 *parent;
	struct dentry___254 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___149 *subsys[11];
	struct cgroupfs_root___149 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___256 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___149 {
	struct super_block___254 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___149 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___87 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___254 *, struct file___254 *);
	ssize_t (*read)(struct cgroup___149 *, struct cftype___87 *, struct file___254 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___149 *, struct cftype___87 *);
	s64 (*read_s64)(struct cgroup___149 *, struct cftype___87 *);
	int (*read_map)(struct cgroup___149 *, struct cftype___87 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___149 *, struct cftype___87 *, struct seq_file___179 *);
	ssize_t (*write)(struct cgroup___149 *, struct cftype___87 *, struct file___254 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___149 *, struct cftype___87 *, u64);
	int (*write_s64)(struct cgroup___149 *, struct cftype___87 *, s64);
	int (*write_string)(struct cgroup___149 *, struct cftype___87 *, const char *);
	int (*trigger)(struct cgroup___149 *, unsigned int);
	int (*release)(struct inode___254 *, struct file___254 *);
	int (*register_event)(struct cgroup___149 *, struct cftype___87 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___149 *, struct cftype___87 *, struct eventfd_ctx *);
};

struct cftype_set___83 {
	struct list_head node;
	struct cftype___87 *cfts;
};

struct task_and_cgroup___83 {
	struct task_struct___255 *task;
	struct cgroup___149 *cgrp;
	struct css_set___149 *cg;
};

struct cgroup_taskset___83 {
	struct task_and_cgroup___83 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___149 *cur_cgrp;
};

struct cgroup_subsys___83 {
	struct cgroup_subsys_state___149 * (*css_alloc)(struct cgroup___149 *);
	int (*css_online)(struct cgroup___149 *);
	void (*css_offline)(struct cgroup___149 *);
	void (*css_free)(struct cgroup___149 *);
	int (*can_attach)(struct cgroup___149 *, struct cgroup_taskset___83 *);
	void (*cancel_attach)(struct cgroup___149 *, struct cgroup_taskset___83 *);
	void (*attach)(struct cgroup___149 *, struct cgroup_taskset___83 *);
	void (*fork)(struct task_struct___255 *);
	void (*exit)(struct cgroup___149 *, struct cgroup___149 *, struct task_struct___255 *);
	void (*bind)(struct cgroup___149 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___149 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___87 *base_cftypes;
	struct cftype_set___83 base_cftset;
	struct module *module;
};

struct request_sock_ops___24;

struct request_sock___25 {
	struct sock_common___35 __req_common;
	struct request_sock___25 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___24 *rsk_ops;
	struct sock___37 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___46 {
	struct sk_buff___48 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___48 *, struct netlink_callback___46 *);
	int (*done)(struct netlink_callback___46 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___44 {
	int (*create)(struct sk_buff___48 *, struct net_device___45 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___48 *, unsigned char *);
	int (*rebuild)(struct sk_buff___48 *);
	int (*cache)(const struct neighbour___35 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___45 *, const unsigned char *);
};

struct napi_struct___44 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___44 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___45 *dev;
	struct sk_buff___48 *gro_list;
	struct sk_buff___48 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___44 {
	struct net_device___45 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___38 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___44 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___38 kobj;
	struct net_device___45 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___44 {
	int (*ndo_init)(struct net_device___45 *);
	void (*ndo_uninit)(struct net_device___45 *);
	int (*ndo_open)(struct net_device___45 *);
	int (*ndo_stop)(struct net_device___45 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___48 *, struct net_device___45 *);
	u16 (*ndo_select_queue)(struct net_device___45 *, struct sk_buff___48 *);
	void (*ndo_change_rx_flags)(struct net_device___45 *, int);
	void (*ndo_set_rx_mode)(struct net_device___45 *);
	int (*ndo_set_mac_address)(struct net_device___45 *, void *);
	int (*ndo_validate_addr)(struct net_device___45 *);
	int (*ndo_do_ioctl)(struct net_device___45 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___45 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___45 *, int);
	int (*ndo_neigh_setup)(struct net_device___45 *, struct neigh_parms___35 *);
	void (*ndo_tx_timeout)(struct net_device___45 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___45 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___45 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___45 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___45 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___45 *);
	int (*ndo_netpoll_setup)(struct net_device___45 *, struct netpoll_info___3 *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___45 *);
	int (*ndo_busy_poll)(struct napi_struct___44 *);
	int (*ndo_set_vf_mac)(struct net_device___45 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___45 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___45 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___45 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___45 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___45 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___45 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___45 *, int, struct sk_buff___48 *);
	int (*ndo_setup_tc)(struct net_device___45 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___45 *);
	int (*ndo_fcoe_disable)(struct net_device___45 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___45 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___45 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___45 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___45 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___45 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___45 *, const struct sk_buff___48 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___45 *, struct net_device___45 *);
	int (*ndo_del_slave)(struct net_device___45 *, struct net_device___45 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___35 *);
	void (*ndo_neigh_destroy)(struct neighbour___35 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___48 *, struct netlink_callback___46 *, struct net_device___45 *, int);
	int (*ndo_bridge_setlink)(struct net_device___45 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___48 *, u32, u32, struct net_device___45 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___45 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___45 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___45 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___45 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___45 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___45 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___48 *, struct net_device___45 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___45 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___45 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___45 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___35 {
	struct net___59 *net;
	struct net_device___45 *dev;
	struct neigh_parms___35 *next;
	int (*neigh_setup)(struct neighbour___35 *);
	void (*neigh_cleanup)(struct neighbour___35 *);
	struct neigh_table___35 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct netpoll___2;

struct netpoll_info___3 {
	atomic_t refcnt;
	long unsigned int rx_flags;
	spinlock_t rx_lock;
	struct semaphore dev_lock;
	struct list_head rx_np;
	struct sk_buff_head___45 neigh_tx;
	struct sk_buff_head___45 txq;
	struct delayed_work tx_work;
	struct netpoll___2 *netpoll;
	struct callback_head rcu;
};

struct in_ifaddr___3;

struct in_device___3 {
	struct net_device___45 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___3 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___35 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___19;

struct ifacaddr6___19;

struct inet6_dev___19 {
	struct net_device___45 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___19 *mc_list;
	struct ifmcaddr6___19 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___19 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___35 *nd_parms;
	struct inet6_dev___19 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___35 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___45 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___59 *, struct net_device___45 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___45 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___45 *, struct list_head *);
	size_t (*get_size)(const struct net_device___45 *);
	int (*fill_info)(struct sk_buff___48 *, const struct net_device___45 *);
	size_t (*get_xstats_size)(const struct net_device___45 *);
	int (*fill_xstats)(struct sk_buff___48 *, const struct net_device___45 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___59 * (*get_link_net)(const struct net_device___45 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___45 *, struct net_device___45 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___45 *, const struct net_device___45 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___48 *, const struct net_device___45 *, const struct net_device___45 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct softnet_data___3 {
	struct Qdisc *output_queue;
	struct Qdisc **output_queue_tailp;
	struct list_head poll_list;
	struct sk_buff___48 *completion_queue;
	struct sk_buff_head___45 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int cpu_collision;
	unsigned int received_rps;
	struct softnet_data___3 *rps_ipi_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct call_single_data csd;
	struct softnet_data___3 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_head;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___45 input_pkt_queue;
	struct napi_struct___44 backlog;
	long: 64;
	long: 64;
};

struct in_ifaddr___3 {
	struct hlist_node hash;
	struct in_ifaddr___3 *ifa_next;
	struct in_device___3 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___2 {
	struct net_device___45 *dev;
	char dev_name[16];
	const char *name;
	void (*rx_hook)(struct netpoll___2 *, int, char *, int);
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct list_head rx;
	struct work_struct cleanup_work;
};

struct sk_filter___36 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___48 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___35;

struct neigh_hash_table___35;

struct neigh_table___35 {
	struct neigh_table___35 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___45 *, __u32 *);
	int (*constructor)(struct neighbour___35 *);
	int (*pconstructor)(struct pneigh_entry___35 *);
	void (*pdestructor)(struct pneigh_entry___35 *);
	void (*proxy_redo)(struct sk_buff___48 *);
	char *id;
	struct neigh_parms___35 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___45 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___35 *nht;
	struct pneigh_entry___35 **phash_buckets;
};

struct neigh_ops___35 {
	int family;
	void (*solicit)(struct neighbour___35 *, struct sk_buff___48 *);
	void (*error_report)(struct neighbour___35 *, struct sk_buff___48 *);
	int (*output)(struct neighbour___35 *, struct sk_buff___48 *);
	int (*connected_output)(struct neighbour___35 *, struct sk_buff___48 *);
};

struct pneigh_entry___35 {
	struct pneigh_entry___35 *next;
	struct net___59 *net;
	struct net_device___45 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___35 {
	struct neighbour___35 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___14 {
	struct dst_entry___35 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___22;

struct inet_hashinfo___4;

struct proto___35 {
	void (*close)(struct sock___37 *, long int);
	int (*connect)(struct sock___37 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___37 *, int);
	struct sock___37 * (*accept)(struct sock___37 *, int, int *);
	int (*ioctl)(struct sock___37 *, int, long unsigned int);
	int (*init)(struct sock___37 *);
	void (*destroy)(struct sock___37 *);
	void (*shutdown)(struct sock___37 *, int);
	int (*setsockopt)(struct sock___37 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___37 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___37 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___37 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___37 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___43 *, struct sock___37 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___43 *, struct sock___37 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___37 *, struct page___253 *, int, size_t, int);
	int (*bind)(struct sock___37 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___37 *, struct sk_buff___48 *);
	void (*release_cb)(struct sock___37 *);
	void (*mtu_reduced)(struct sock___37 *);
	void (*hash)(struct sock___37 *);
	void (*unhash)(struct sock___37 *);
	void (*rehash)(struct sock___37 *);
	int (*get_port)(struct sock___37 *, short unsigned int);
	void (*clear_sk)(struct sock___37 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___37 *);
	void (*enter_memory_pressure)(struct sock___37 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___237 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___24 *rsk_prot;
	struct timewait_sock_ops___22 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___83 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___35 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___35 {
	void (*enter_memory_pressure)(struct sock___37 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___4 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___237 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___24 {
	int family;
	int obj_size;
	struct kmem_cache___237 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___37 *, struct request_sock___25 *);
	void (*send_ack)(struct sock___37 *, struct sk_buff___48 *, struct request_sock___25 *);
	void (*send_reset)(struct sock___37 *, struct sk_buff___48 *);
	void (*destructor)(struct request_sock___25 *);
	void (*syn_ack_timeout)(struct sock___37 *, struct request_sock___25 *);
};

struct timewait_sock_ops___22 {
	struct kmem_cache___237 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___37 *, struct sock___37 *, void *);
	void (*twsk_destructor)(struct sock___37 *);
};

struct inet6_ifaddr {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 valid_lft;
	__u32 prefered_lft;
	atomic_t refcnt;
	spinlock_t lock;
	spinlock_t state_lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u16 scope;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___19 *idev;
	struct rt6_info *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___19 {
	struct in6_addr mca_addr;
	struct inet6_dev___19 *idev;
	struct ifmcaddr6___19 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___19 {
	struct in6_addr aca_addr;
	struct inet6_dev___19 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___19 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct page___254;

typedef struct page___254 *pgtable_t___254;

struct address_space___255;

struct kmem_cache___238;

struct page___254 {
	long unsigned int flags;
	struct address_space___255 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___254 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___254 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___238 *slab_cache;
		struct page___254 *first_page;
	};
	long: 64;
};

struct task_struct___256;

struct pv_cpu_ops___256 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___84 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___84 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___256 *);
	void (*end_context_switch)(struct task_struct___256 *);
};

struct mutex___257 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___256 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___249 {
	struct page___254 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___263;

struct nsproxy___135;

struct signal_struct___256;

struct css_set___150;

struct task_struct___256 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___256 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___263 *mm;
	struct mm_struct___263 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___256 *real_parent;
	struct task_struct___256 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___256 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___95 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___256 = 0,
		VTIME_USER___256 = 1,
		VTIME_SYS___256 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___84 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___135 *nsproxy;
	struct signal_struct___256 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___150 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___257 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___249 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___263 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___263 *, struct mm_struct___263 *);
	void (*dup_mmap)(struct mm_struct___263 *, struct mm_struct___263 *);
	void (*exit_mmap)(struct mm_struct___263 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___263 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___263 *);
	void (*pgd_free)(struct mm_struct___263 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___263 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___263 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___263 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___263 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___263 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___263 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___263 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___263 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___263 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___263 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___263 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___257 lock;
	void *vdso;
} mm_context_t___257;

struct xol_area___254;

struct uprobes_state___254 {
	struct xol_area___254 *xol_area;
};

struct vm_area_struct___263;

struct file___255;

struct core_state___256;

struct mm_struct___263 {
	struct vm_area_struct___263 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___263 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___263 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___257 context;
	long unsigned int flags;
	struct core_state___256 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___256 *owner;
	struct file___255 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___254 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___39;

struct kobj_type___39;

struct kobject___39 {
	const char *name;
	struct list_head entry;
	struct kobject___39 *parent;
	struct kset___39 *kset;
	struct kobj_type___39 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___157;

struct module_kobject___155 {
	struct kobject___39 kobj;
	struct module___157 *mod;
	struct kobject___39 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___155;

struct module___157 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___155 mkobj;
	struct module_attribute___155 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___39 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___256 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___256;

struct lruvec___256 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___256 *zone;
};

struct pglist_data___256;

struct zone___256 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___256 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___256 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___256 {
	struct zone___256 *zone;
	int zone_idx;
};

struct zonelist___256 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___256 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___256 {
	struct zone___256 node_zones[4];
	struct zonelist___256 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___256 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___179;

struct x86_io_apic_ops___179 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___179 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___179;

struct irq_data___179 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___179 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___253;

struct dev_pm_ops___253 {
	int (*prepare)(struct device___253 *);
	void (*complete)(struct device___253 *);
	int (*suspend)(struct device___253 *);
	int (*resume)(struct device___253 *);
	int (*freeze)(struct device___253 *);
	int (*thaw)(struct device___253 *);
	int (*poweroff)(struct device___253 *);
	int (*restore)(struct device___253 *);
	int (*suspend_late)(struct device___253 *);
	int (*resume_early)(struct device___253 *);
	int (*freeze_late)(struct device___253 *);
	int (*thaw_early)(struct device___253 *);
	int (*poweroff_late)(struct device___253 *);
	int (*restore_early)(struct device___253 *);
	int (*suspend_noirq)(struct device___253 *);
	int (*resume_noirq)(struct device___253 *);
	int (*freeze_noirq)(struct device___253 *);
	int (*thaw_noirq)(struct device___253 *);
	int (*poweroff_noirq)(struct device___253 *);
	int (*restore_noirq)(struct device___253 *);
	int (*runtime_suspend)(struct device___253 *);
	int (*runtime_resume)(struct device___253 *);
	int (*runtime_idle)(struct device___253 *);
};

struct dev_pm_qos___56;

struct dev_pm_info___56 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___56 *qos;
};

struct dma_map_ops___118;

struct dev_archdata___118 {
	struct dma_map_ops___118 *dma_ops;
	void *iommu;
};

struct device_type___253;

struct bus_type___253;

struct device_driver___253;

struct dev_pm_domain___253;

struct class___253;

struct attribute_group___215;

struct device_rh___253;

struct device___253 {
	struct device___253 *parent;
	struct device_private *p;
	struct kobject___39 kobj;
	const char *init_name;
	const struct device_type___253 *type;
	struct mutex___257 mutex;
	struct bus_type___253 *bus;
	struct device_driver___253 *driver;
	void *platform_data;
	struct dev_pm_info___56 power;
	struct dev_pm_domain___253 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___118 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___253 *class;
	const struct attribute_group___215 **groups;
	void (*release)(struct device___253 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___253 *device_rh;
};

struct dev_pm_qos_request___57;

struct dev_pm_qos___56 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___57 *latency_req;
	struct dev_pm_qos_request___57 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___57 *latency_tolerance_req;
};

struct dev_pm_info_rh___253 {
	void (*set_latency_tolerance)(struct device___253 *, s32);
};

struct dev_pm_domain___253 {
	struct dev_pm_ops___253 ops;
};

struct smp_ops___256 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___256 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___38;

struct kobj_ns_type_operations___36 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___38 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___36;

struct net___60;

struct sock_common___36 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___36 *skc_prot;
	struct net___60 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___49;

struct sk_buff_head___46 {
	struct sk_buff___49 *next;
	struct sk_buff___49 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___37;

struct socket_wq___36;

struct dst_entry___36;

struct socket___37;

struct cg_proto___36;

struct sock___38 {
	struct sock_common___36 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___46 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___49 *head;
		struct sk_buff___49 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___37 *sk_filter;
	struct socket_wq___36 *sk_wq;
	struct sk_buff_head___46 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___36 *sk_rx_dst;
	struct dst_entry___36 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___46 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___46 sk_error_queue;
	struct proto___36 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___95 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___37 *sk_socket;
	void *sk_user_data;
	struct page_frag___249 sk_frag;
	struct sk_buff___49 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___36 *sk_cgrp;
	void (*sk_state_change)(struct sock___38 *);
	void (*sk_data_ready)(struct sock___38 *, int);
	void (*sk_write_space)(struct sock___38 *);
	void (*sk_error_report)(struct sock___38 *);
	int (*sk_backlog_rcv)(struct sock___38 *, struct sk_buff___49 *);
	void (*sk_destruct)(struct sock___38 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___217;

struct attribute_group___215 {
	const char *name;
	umode_t (*is_visible)(struct kobject___39 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___217 **bin_attrs;
};

struct bin_attribute___217 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___255 *, struct kobject___39 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___255 *, struct kobject___39 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	int (*mmap)(struct file___255 *, struct kobject___39 *, struct bin_attribute___217 *, struct vm_area_struct___263 *);
};

struct dentry___255;

struct path___255 {
	struct vfsmount *mnt;
	struct dentry___255 *dentry;
};

struct inode___255;

struct file_operations___255;

struct file___255 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___255 f_path;
	struct inode___255 *f_inode;
	const struct file_operations___255 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___255 *f_mapping;
	struct mutex___257 f_pos_lock;
};

struct vm_operations_struct___229;

struct vm_area_struct___263 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___263 *vm_next;
	struct vm_area_struct___263 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___263 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___229 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___255 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___39 {
	ssize_t (*show)(struct kobject___39 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___39 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___39 *, const struct attribute *);
};

struct kset_uevent_ops___39;

struct kset___39 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___39 kobj;
	const struct kset_uevent_ops___39 *uevent_ops;
};

struct kobj_type___39 {
	void (*release)(struct kobject___39 *);
	const struct sysfs_ops___39 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___36 * (*child_ns_type)(struct kobject___39 *);
	const void * (*namespace)(struct kobject___39 *);
};

struct kset_uevent_ops___39 {
	int (* const filter)(struct kset___39 *, struct kobject___39 *);
	const char * (* const name)(struct kset___39 *, struct kobject___39 *);
	int (* const uevent)(struct kset___39 *, struct kobject___39 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___237 {
	void **freelist;
	long unsigned int tid;
	struct page___254 *page;
	struct page___254 *partial;
};

struct memcg_cache_params___238;

struct kmem_cache___238 {
	struct kmem_cache_cpu___237 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___39 kobj;
	struct memcg_cache_params___238 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___238 {
	bool is_root_cache;
	union {
		struct kmem_cache___238 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___238 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct ctl_table_header___60;

struct ctl_node___60 {
	struct rb_node node;
	struct ctl_table_header___60 *header;
};

struct ctl_table_root___60;

struct ctl_table_set___60;

struct ctl_dir___60;

struct ctl_table_header___60 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___60 *root;
	struct ctl_table_set___60 *set;
	struct ctl_dir___60 *parent;
	struct ctl_node___60 *node;
};

struct ctl_dir___60 {
	struct ctl_table_header___60 header;
	struct rb_root root;
};

struct ctl_table_set___60 {
	int (*is_seen)(struct ctl_table_set___60 *);
	struct ctl_dir___60 dir;
};

struct ctl_table_root___60 {
	struct ctl_table_set___60 default_set;
	struct ctl_table_set___60 * (*lookup)(struct ctl_table_root___60 *, struct nsproxy___135 *);
	int (*permissions)(struct ctl_table_header___60 *, struct ctl_table *);
};

struct nsproxy___135 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___60 *net_ns;
};

struct module_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___155 *, struct module_kobject___155 *, char *);
	ssize_t (*store)(struct module_attribute___155 *, struct module_kobject___155 *, const char *, size_t);
	void (*setup)(struct module___157 *, const char *);
	int (*test)(struct module___157 *);
	void (*free)(struct module___157 *);
};

struct netns_core___57 {
	struct ctl_table_header___60 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_unix___57 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___60 *ctl;
};

struct netns_packet___58 {
	struct mutex___257 sklist_lock;
	struct hlist_head sklist;
};

struct net_device___46;

struct nf_bridge_info___45;

struct sk_buff___49 {
	struct sk_buff___49 *next;
	struct sk_buff___49 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___38 *sk;
	struct net_device___46 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___49 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___45 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct fib_rules_ops___2;

struct netns_ipv4___57 {
	struct ctl_table_header___60 *forw_hdr;
	struct ctl_table_header___60 *frags_hdr;
	struct ctl_table_header___60 *ipv4_hdr;
	struct ctl_table_header___60 *route_hdr;
	struct ctl_table_header___60 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___2 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___38 *fibnl;
	struct sock___38 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___2 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rule___2;

struct fib_lookup_arg___2;

struct fib_rules_ops___2 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___2 *, struct flowi *, int, struct fib_lookup_arg___2 *);
	int (*match)(struct fib_rule___2 *, struct flowi *, int);
	int (*configure)(struct fib_rule___2 *, struct sk_buff___49 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___2 *);
	int (*compare)(struct fib_rule___2 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___2 *, struct sk_buff___49 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___2 *);
	size_t (*nlmsg_payload)(struct fib_rule___2 *);
	void (*flush_cache)(struct fib_rules_ops___2 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___157 *owner;
	struct net___60 *fro_net;
	struct callback_head rcu;
};

struct neighbour___36;

struct dst_ops___59 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___59 *);
	struct dst_entry___36 * (*check)(struct dst_entry___36 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___36 *);
	unsigned int (*mtu)(const struct dst_entry___36 *);
	u32 * (*cow_metrics)(struct dst_entry___36 *, long unsigned int);
	void (*destroy)(struct dst_entry___36 *);
	void (*ifdown)(struct dst_entry___36 *, struct net_device___46 *, int);
	struct dst_entry___36 * (*negative_advice)(struct dst_entry___36 *);
	void (*link_failure)(struct sk_buff___49 *);
	void (*update_pmtu)(struct dst_entry___36 *, struct sock___38 *, struct sk_buff___49 *, u32);
	void (*redirect)(struct dst_entry___36 *, struct sock___38 *, struct sk_buff___49 *);
	int (*local_out)(struct sk_buff___49 *);
	struct neighbour___36 * (*neigh_lookup)(const struct dst_entry___36 *, struct sk_buff___49 *, const void *);
	struct kmem_cache___238 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___36 {
	struct callback_head callback_head;
	struct dst_entry___36 *child;
	struct net_device___46 *dev;
	struct dst_ops___59 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___36 *path;
	struct dst_entry___36 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___49 *);
	union {
		int (*output)(struct sock___38 *, struct sk_buff___49 *);
		struct {
			int (*output)(struct sk_buff___49 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___36 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

typedef rx_handler_result_t rx_handler_func_t___45(struct sk_buff___49 **);

struct net_device_ops___45;

struct ethtool_ops___45;

struct header_ops___45;

struct netdev_rx_queue___45;

struct netdev_queue___45;

struct rtnl_link_ops___36;

struct dcbnl_rtnl_ops___45;

struct net_device___46 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___45 *netdev_ops;
	const struct ethtool_ops___45 *ethtool_ops;
	const struct header_ops___45 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___39 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___45 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___45 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___45 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___45 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___45 = 0,
		NETREG_REGISTERED___45 = 1,
		NETREG_UNREGISTERING___45 = 2,
		NETREG_UNREGISTERED___45 = 3,
		NETREG_RELEASED___45 = 4,
		NETREG_DUMMY___45 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___45 = 0,
		RTNL_LINK_INITIALIZING___45 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___46 *);
	struct netpoll_info *npinfo;
	struct net___60 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___253 dev;
	const struct attribute_group___215 *sysfs_groups[4];
	const struct rtnl_link_ops___36 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___45 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___36;

struct neigh_parms___36;

struct neigh_ops___36;

struct neighbour___36 {
	struct neighbour___36 *next;
	struct neigh_table___36 *tbl;
	struct neigh_parms___36 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___46 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___36 *, struct sk_buff___49 *);
	const struct neigh_ops___36 *ops;
	struct callback_head rcu;
	struct net_device___46 *dev;
	u8 primary_key[0];
};

struct netns_sysctl_ipv6___57 {
	struct ctl_table_header___60 *hdr;
	struct ctl_table_header___60 *route_hdr;
	struct ctl_table_header___60 *icmp_hdr;
	struct ctl_table_header___60 *frags_hdr;
	struct ctl_table_header___60 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct netns_ipv6___59 {
	struct netns_sysctl_ipv6___57 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___59 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___2 *fib6_rules_ops;
	struct sock___38 **icmp_sk;
	struct sock___38 *ndisc_sk;
	struct sock___38 *tcp_sk;
	struct sock___38 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___2 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_nf_frag___57 {
	struct netns_sysctl_ipv6___57 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_sctp___57 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___60 *sysctl_header;
	struct sock___38 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___36 {
	struct sock___38 *v4_ctl_sk;
	struct sock___38 *v6_ctl_sk;
};

struct dentry_operations___255;

struct super_block___255;

struct dentry___255 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___255 *d_parent;
	struct qstr d_name;
	struct inode___255 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___255 *d_op;
	struct super_block___255 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___255;

struct address_space___255 {
	struct inode___255 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___257 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___255 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___255;

struct file_lock___255;

struct dquot___255;

struct block_device___255;

struct inode___255 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___255 *i_op;
	struct super_block___255 *i_sb;
	struct address_space___255 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___257 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___255 *i_fop;
	struct file_lock___255 *i_flock;
	struct address_space___255 i_data;
	struct dquot___255 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___255 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___255 {
	int (*d_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_hash)(const struct dentry___255 *, struct qstr *);
	int (*d_compare)(const struct dentry___255 *, const struct dentry___255 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___255 *);
	void (*d_release)(struct dentry___255 *);
	void (*d_prune)(struct dentry___255 *);
	void (*d_iput)(struct dentry___255 *, struct inode___255 *);
	char * (*d_dname)(struct dentry___255 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___255 *);
	int (*d_manage)(struct dentry___255 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___255;

struct mem_dqinfo___255 {
	struct quota_format_type___255 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___255;

struct quota_info___255 {
	unsigned int flags;
	struct mutex___257 dqio_mutex;
	struct mutex___257 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___255 *files[2];
	struct mem_dqinfo___255 info[2];
	const struct quota_format_ops___255 *ops[2];
};

struct file_system_type___255;

struct super_operations___255;

struct dquot_operations___255;

struct quotactl_ops___255;

struct xattr_handler___151;

struct super_block___255 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___255 *s_type;
	const struct super_operations___255 *s_op;
	const struct dquot_operations___255 *dq_op;
	const struct quotactl_ops___255 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___255 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___151 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___255 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___255 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___257 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___255 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___255 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___255 *bd_inode;
	struct super_block___255 *bd_super;
	struct mutex___257 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___255 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___257 bd_fsfreeze_mutex;
};

struct cgroup___150;

struct cgroup_subsys_state___150 {
	struct cgroup___150 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___44;

typedef int kiocb_cancel_fn___44(struct kiocb___44 *, struct io_event *);

struct kiocb___44 {
	atomic_t ki_users;
	struct file___255 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___44 *ki_cancel;
	void (*ki_dtor)(struct kiocb___44 *);
	union {
		void *user;
		struct task_struct___256 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___255 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___255 *ia_file;
};

struct dquot___255 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___257 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___255 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___255 {
	int qf_fmt_id;
	const struct quota_format_ops___255 *qf_ops;
	struct module___157 *qf_owner;
	struct quota_format_type___255 *qf_next;
};

struct quota_format_ops___255 {
	int (*check_quota_file)(struct super_block___255 *, int);
	int (*read_file_info)(struct super_block___255 *, int);
	int (*write_file_info)(struct super_block___255 *, int);
	int (*free_file_info)(struct super_block___255 *, int);
	int (*read_dqblk)(struct dquot___255 *);
	int (*commit_dqblk)(struct dquot___255 *);
	int (*release_dqblk)(struct dquot___255 *);
};

struct dquot_operations___255 {
	int (*write_dquot)(struct dquot___255 *);
	struct dquot___255 * (*alloc_dquot)(struct super_block___255 *, int);
	void (*destroy_dquot)(struct dquot___255 *);
	int (*acquire_dquot)(struct dquot___255 *);
	int (*release_dquot)(struct dquot___255 *);
	int (*mark_dirty)(struct dquot___255 *);
	int (*write_info)(struct super_block___255 *, int);
	qsize_t * (*get_reserved_space)(struct inode___255 *);
};

struct quotactl_ops___255 {
	int (*quota_on)(struct super_block___255 *, int, int, struct path___255 *);
	int (*quota_on_meta)(struct super_block___255 *, int, int);
	int (*quota_off)(struct super_block___255 *, int);
	int (*quota_sync)(struct super_block___255 *, int);
	int (*get_info)(struct super_block___255 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___255 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___255 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___255 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___255 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___255 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___255 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___255 *, unsigned int);
};

struct address_space_operations___255 {
	int (*writepage)(struct page___254 *, struct writeback_control *);
	int (*readpage)(struct file___255 *, struct page___254 *);
	int (*writepages)(struct address_space___255 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___254 *);
	int (*readpages)(struct file___255 *, struct address_space___255 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___255 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___254 **, void **);
	int (*write_end)(struct file___255 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___254 *, void *);
	sector_t (*bmap)(struct address_space___255 *, sector_t);
	void (*invalidatepage)(struct page___254 *, long unsigned int);
	int (*releasepage)(struct page___254 *, gfp_t);
	void (*freepage)(struct page___254 *);
	ssize_t (*direct_IO)(int, struct kiocb___44 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___255 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___255 *, struct page___254 *, struct page___254 *, enum migrate_mode);
	int (*launder_page)(struct page___254 *);
	int (*is_partially_uptodate)(struct page___254 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___254 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___255 *, struct page___254 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___255 *, sector_t *);
	void (*swap_deactivate)(struct file___255 *);
	void (*invalidatepage_range)(struct page___254 *, unsigned int, unsigned int);
};

struct inode_operations___255 {
	struct dentry___255 * (*lookup)(struct inode___255 *, struct dentry___255 *, unsigned int);
	void * (*follow_link)(struct dentry___255 *, struct nameidata *);
	int (*permission)(struct inode___255 *, int);
	struct posix_acl * (*get_acl)(struct inode___255 *, int);
	int (*readlink)(struct dentry___255 *, char *, int);
	void (*put_link)(struct dentry___255 *, struct nameidata *, void *);
	int (*create)(struct inode___255 *, struct dentry___255 *, umode_t, bool);
	int (*link)(struct dentry___255 *, struct inode___255 *, struct dentry___255 *);
	int (*unlink)(struct inode___255 *, struct dentry___255 *);
	int (*symlink)(struct inode___255 *, struct dentry___255 *, const char *);
	int (*mkdir)(struct inode___255 *, struct dentry___255 *, umode_t);
	int (*rmdir)(struct inode___255 *, struct dentry___255 *);
	int (*mknod)(struct inode___255 *, struct dentry___255 *, umode_t, dev_t);
	int (*rename)(struct inode___255 *, struct dentry___255 *, struct inode___255 *, struct dentry___255 *);
	int (*setattr)(struct dentry___255 *, struct iattr___255 *);
	int (*getattr)(struct vfsmount *, struct dentry___255 *, struct kstat *);
	int (*setxattr)(struct dentry___255 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___255 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___255 *, char *, size_t);
	int (*removexattr)(struct dentry___255 *, const char *);
	int (*fiemap)(struct inode___255 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___255 *, struct timespec *, int);
	int (*atomic_open)(struct inode___255 *, struct dentry___255 *, struct file___255 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___143;

struct seq_file___180;

struct file_operations___255 {
	struct module___157 *owner;
	loff_t (*llseek)(struct file___255 *, loff_t, int);
	ssize_t (*read)(struct file___255 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___255 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___44 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___44 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___255 *, void *, filldir_t);
	unsigned int (*poll)(struct file___255 *, struct poll_table_struct___143 *);
	long int (*unlocked_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___255 *, struct vm_area_struct___263 *);
	int (*open)(struct inode___255 *, struct file___255 *);
	int (*flush)(struct file___255 *, fl_owner_t);
	int (*release)(struct inode___255 *, struct file___255 *);
	int (*fsync)(struct file___255 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___44 *, int);
	int (*fasync)(int, struct file___255 *, int);
	int (*lock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*sendpage)(struct file___255 *, struct page___254 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___255 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___255 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___255 *, long int, struct file_lock___255 **, void **);
		struct {
			int (*setlease)(struct file___255 *, long int, struct file_lock___255 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___255 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___180 *, struct file___255 *);
};

struct fasync_struct___255;

struct file_lock_operations___255;

struct lock_manager_operations___255;

struct file_lock___255 {
	struct file_lock___255 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___95 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___255 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___255 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___255 *fl_ops;
	const struct lock_manager_operations___255 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___255 {
	void (*fl_copy_lock)(struct file_lock___255 *, struct file_lock___255 *);
	void (*fl_release_private)(struct file_lock___255 *);
};

struct lock_manager_operations___255 {
	int (*lm_compare_owner)(struct file_lock___255 *, struct file_lock___255 *);
	long unsigned int (*lm_owner_key)(struct file_lock___255 *);
	void (*lm_notify)(struct file_lock___255 *);
	int (*lm_grant)(struct file_lock___255 *, struct file_lock___255 *, int);
	void (*lm_break)(struct file_lock___255 *);
	int (*lm_change)(struct file_lock___255 **, int);
};

struct fasync_struct___255 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___255 *fa_next;
	struct file___255 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___255 {
	const char *name;
	int fs_flags;
	struct dentry___255 * (*mount)(struct file_system_type___255 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___255 *);
	struct module___157 *owner;
	struct file_system_type___255 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___255 {
	struct inode___255 * (*alloc_inode)(struct super_block___255 *);
	void (*destroy_inode)(struct inode___255 *);
	void (*dirty_inode)(struct inode___255 *, int);
	int (*write_inode)(struct inode___255 *, struct writeback_control *);
	int (*drop_inode)(struct inode___255 *);
	void (*evict_inode)(struct inode___255 *);
	void (*put_super)(struct super_block___255 *);
	int (*sync_fs)(struct super_block___255 *, int);
	int (*freeze_fs)(struct super_block___255 *);
	int (*unfreeze_fs)(struct super_block___255 *);
	int (*statfs)(struct dentry___255 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___255 *, int *, char *);
	void (*umount_begin)(struct super_block___255 *);
	int (*show_options)(struct seq_file___180 *, struct dentry___255 *);
	int (*show_devname)(struct seq_file___180 *, struct dentry___255 *);
	int (*show_path)(struct seq_file___180 *, struct dentry___255 *);
	int (*show_stats)(struct seq_file___180 *, struct dentry___255 *);
	ssize_t (*quota_read)(struct super_block___255 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___255 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___255 *);
	int (*bdev_try_to_free_page)(struct super_block___255 *, struct page___254 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___255 *);
	void (*free_cached_objects)(struct super_block___255 *, int);
};

struct xattr_handler___151 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___255 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___255 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___255 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___145)(struct file___255 *, wait_queue_head_t *, struct poll_table_struct___143 *);

struct poll_table_struct___143 {
	poll_queue_proc___145 _qproc;
	long unsigned int _key;
};

struct seq_operations___180;

struct seq_file___180 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___257 lock;
	const struct seq_operations___180 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___254 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___254 *page;
	long unsigned int vaddr;
};

struct vm_fault___225;

struct vm_operations_struct___229 {
	void (*open)(struct vm_area_struct___263 *);
	void (*close)(struct vm_area_struct___263 *);
	int (*fault)(struct vm_area_struct___263 *, struct vm_fault___225 *);
	int (*page_mkwrite)(struct vm_area_struct___263 *, struct vm_fault___225 *);
	int (*access)(struct vm_area_struct___263 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___263 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___263 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___263 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___263 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___256 {
	struct task_struct___256 *task;
	struct core_thread___256 *next;
};

struct core_state___256 {
	atomic_t nr_threads;
	struct core_thread___256 dumper;
	struct completion startup;
};

struct socket_wq___36 {
	wait_queue_head_t wait;
	struct fasync_struct___255 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___36;

struct socket___37 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___36 *wq;
	struct file___255 *file;
	struct sock___38 *sk;
	const struct proto_ops___36 *ops;
};

struct proto_ops___36 {
	int family;
	struct module___157 *owner;
	int (*release)(struct socket___37 *);
	int (*bind)(struct socket___37 *, struct sockaddr *, int);
	int (*connect)(struct socket___37 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___37 *, struct socket___37 *);
	int (*accept)(struct socket___37 *, struct socket___37 *, int);
	int (*getname)(struct socket___37 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___255 *, struct socket___37 *, struct poll_table_struct___143 *);
	int (*ioctl)(struct socket___37 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___37 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___37 *, int);
	int (*shutdown)(struct socket___37 *, int);
	int (*setsockopt)(struct socket___37 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___37 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___37 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___37 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___44 *, struct socket___37 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___44 *, struct socket___37 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___255 *, struct socket___37 *, struct vm_area_struct___263 *);
	ssize_t (*sendpage)(struct socket___37 *, struct page___254 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___37 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___38 *, int);
		struct {
			void (*set_peek_off)(struct sock___38 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct netns_nf___57 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___60 *nf_log_dir_header;
};

struct nf_proto_net___57 {
	struct ctl_table_header___60 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___57 {
	struct nf_proto_net___57 pn;
	unsigned int timeout;
};

struct nf_tcp_net___57 {
	struct nf_proto_net___57 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___57 {
	struct nf_proto_net___57 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___57 {
	struct nf_proto_net___57 pn;
	unsigned int timeout;
};

struct nf_ip_net___57 {
	struct nf_generic_net___57 generic;
	struct nf_tcp_net___57 tcp;
	struct nf_udp_net___57 udp;
	struct nf_icmp_net___57 icmp;
	struct nf_icmp_net___57 icmpv6;
};

struct netns_ct___58 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___60 *sysctl_header;
	struct ctl_table_header___60 *acct_sysctl_header;
	struct ctl_table_header___60 *tstamp_sysctl_header;
	struct ctl_table_header___60 *event_sysctl_header;
	struct ctl_table_header___60 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___238 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___57 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_xfrm___59 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___38 *nlsk;
	struct sock___38 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___60 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___59 xfrm4_dst_ops;
	struct dst_ops___59 xfrm6_dst_ops;
};

struct net___60 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___60 sysctls;
	struct sock___38 *rtnl;
	struct sock___38 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___46 *loopback_dev;
	struct netns_core___57 core;
	struct netns_mib mib;
	struct netns_packet___58 packet;
	struct netns_unix___57 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___57 ipv4;
	struct netns_ipv6___59 ipv6;
	struct netns_sctp___57 sctp;
	struct netns_dccp___36 dccp;
	struct netns_nf___57 nf;
	struct netns_xt xt;
	struct netns_ct___58 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___57 nf_frag;
	struct sock___38 *nfnl;
	struct sock___38 *nfnl_stash;
	struct sk_buff_head___46 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___59 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___38 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___38 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___257 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___257 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___118 {
	void * (*alloc)(struct device___253 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___253 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___253 *, struct vm_area_struct___263 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___253 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___253 *, struct page___254 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___253 *, dma_addr_t);
	int (*dma_supported)(struct device___253 *, u64);
	int (*set_dma_mask)(struct device___253 *, u64);
	int is_phys;
};

struct bus_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___253 *, char *);
	ssize_t (*store)(struct bus_type___253 *, const char *, size_t);
};

struct device_attribute___253;

struct driver_attribute___253;

struct bus_type___253 {
	const char *name;
	const char *dev_name;
	struct device___253 *dev_root;
	struct bus_attribute___253 *bus_attrs;
	struct device_attribute___253 *dev_attrs;
	struct driver_attribute___253 *drv_attrs;
	const struct attribute_group___215 **bus_groups;
	const struct attribute_group___215 **dev_groups;
	const struct attribute_group___215 **drv_groups;
	int (*match)(struct device___253 *, struct device_driver___253 *);
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	int (*probe)(struct device___253 *);
	int (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*online)(struct device___253 *);
	int (*offline)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct device___253 *, struct device_attribute___253 *, char *);
	ssize_t (*store)(struct device___253 *, struct device_attribute___253 *, const char *, size_t);
};

struct driver_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___253 *, char *);
	ssize_t (*store)(struct device_driver___253 *, const char *, size_t);
};

struct device_driver___253 {
	const char *name;
	struct bus_type___253 *bus;
	struct module___157 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___253 *);
	int (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	const struct attribute_group___215 **groups;
	const struct dev_pm_ops___253 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___253 {
	const char *name;
	const struct attribute_group___215 **groups;
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
};

struct class_attribute___253;

struct class___253 {
	const char *name;
	struct module___157 *owner;
	struct class_attribute___253 *class_attrs;
	struct device_attribute___253 *dev_attrs;
	const struct attribute_group___215 **dev_groups;
	struct bin_attribute___217 *dev_bin_attrs;
	struct kobject___39 *dev_kobj;
	int (*dev_uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *);
	void (*class_release)(struct class___253 *);
	void (*dev_release)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	const struct kobj_ns_type_operations___36 *ns_type;
	const void * (*namespace)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
	struct subsys_private *p;
};

struct class_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct class___253 *, struct class_attribute___253 *, char *);
	ssize_t (*store)(struct class___253 *, struct class_attribute___253 *, const char *, size_t);
	const void * (*namespace)(struct class___253 *, const struct class_attribute___253 *);
};

struct device_rh___253 {
	struct dev_pm_info_rh___253 power;
};

struct vm_fault___225 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___254 *page;
};

struct signal_struct___256 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___256 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___256 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___95 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___257 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___150 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___150 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___45 {
	atomic_t use;
	unsigned int mask;
	struct net_device___46 *physindev;
	struct net_device___46 *physoutdev;
	long unsigned int data[4];
};

struct nf_afinfo___59 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___49 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___49 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___60 *, struct dst_entry___36 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___49 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___49 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___179 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___179 *);
	void (*irq_shutdown)(struct irq_data___179 *);
	void (*irq_enable)(struct irq_data___179 *);
	void (*irq_disable)(struct irq_data___179 *);
	void (*irq_ack)(struct irq_data___179 *);
	void (*irq_mask)(struct irq_data___179 *);
	void (*irq_mask_ack)(struct irq_data___179 *);
	void (*irq_unmask)(struct irq_data___179 *);
	void (*irq_eoi)(struct irq_data___179 *);
	int (*irq_set_affinity)(struct irq_data___179 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___179 *);
	int (*irq_set_type)(struct irq_data___179 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___179 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___179 *);
	void (*irq_bus_sync_unlock)(struct irq_data___179 *);
	void (*irq_cpu_online)(struct irq_data___179 *);
	void (*irq_cpu_offline)(struct irq_data___179 *);
	void (*irq_suspend)(struct irq_data___179 *);
	void (*irq_resume)(struct irq_data___179 *);
	void (*irq_pm_shutdown)(struct irq_data___179 *);
	void (*irq_print_chip)(struct irq_data___179 *, struct seq_file___180 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___179 *, void *);
	long unsigned int flags;
};

struct seq_operations___180 {
	void * (*start)(struct seq_file___180 *, loff_t *);
	void (*stop)(struct seq_file___180 *, void *);
	void * (*next)(struct seq_file___180 *, void *, loff_t *);
	int (*show)(struct seq_file___180 *, void *);
};

struct pernet_operations___10 {
	struct list_head list;
	int (*init)(struct net___60 *);
	void (*exit)(struct net___60 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dev_pm_qos_request___57 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___253 *dev;
};

struct ethtool_ops___45 {
	int (*get_settings)(struct net_device___46 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___46 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___46 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___46 *);
	void (*get_regs)(struct net_device___46 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___46 *);
	void (*set_msglevel)(struct net_device___46 *, u32);
	int (*nway_reset)(struct net_device___46 *);
	u32 (*get_link)(struct net_device___46 *);
	int (*get_eeprom_len)(struct net_device___46 *);
	int (*get_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___46 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___46 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___46 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___46 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___46 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___46 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___46 *);
	void (*complete)(struct net_device___46 *);
	u32 (*get_priv_flags)(struct net_device___46 *);
	int (*set_priv_flags)(struct net_device___46 *, u32);
	int (*get_sset_count)(struct net_device___46 *, int);
	int (*get_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___46 *, struct ethtool_flash *);
	int (*reset)(struct net_device___46 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___46 *);
	int (*get_rxfh_indir)(struct net_device___46 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___46 *, const u32 *);
	void (*get_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___46 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___46 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___46 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___46 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___46 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___46 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___46 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___46 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dcbnl_rtnl_ops___45 {
	int (*ieee_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___46 *);
	u8 (*setstate)(struct net_device___46 *, u8);
	void (*getpermhwaddr)(struct net_device___46 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___46 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___46 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___46 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___46 *, int, u8 *);
	void (*setpfccfg)(struct net_device___46 *, int, u8);
	void (*getpfccfg)(struct net_device___46 *, int, u8 *);
	u8 (*setall)(struct net_device___46 *);
	u8 (*getcap)(struct net_device___46 *, int, u8 *);
	int (*getnumtcs)(struct net_device___46 *, int, u8 *);
	int (*setnumtcs)(struct net_device___46 *, int, u8);
	u8 (*getpfcstate)(struct net_device___46 *);
	void (*setpfcstate)(struct net_device___46 *, u8);
	void (*getbcncfg)(struct net_device___46 *, int, u32 *);
	void (*setbcncfg)(struct net_device___46 *, int, u32);
	void (*getbcnrp)(struct net_device___46 *, int, u8 *);
	void (*setbcnrp)(struct net_device___46 *, int, u8);
	u8 (*setapp)(struct net_device___46 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___46 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___46 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___46 *, int, u8);
	u8 (*getdcbx)(struct net_device___46 *);
	u8 (*setdcbx)(struct net_device___46 *, u8);
	int (*peer_getappinfo)(struct net_device___46 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___46 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___46 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___46 *, struct cee_pfc *);
};

struct cgroupfs_root___150;

struct cgroup___150 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___150 *parent;
	struct dentry___255 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___150 *subsys[11];
	struct cgroupfs_root___150 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___257 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___150 {
	struct super_block___255 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___150 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___88 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___255 *, struct file___255 *);
	ssize_t (*read)(struct cgroup___150 *, struct cftype___88 *, struct file___255 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___150 *, struct cftype___88 *);
	s64 (*read_s64)(struct cgroup___150 *, struct cftype___88 *);
	int (*read_map)(struct cgroup___150 *, struct cftype___88 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___150 *, struct cftype___88 *, struct seq_file___180 *);
	ssize_t (*write)(struct cgroup___150 *, struct cftype___88 *, struct file___255 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___150 *, struct cftype___88 *, u64);
	int (*write_s64)(struct cgroup___150 *, struct cftype___88 *, s64);
	int (*write_string)(struct cgroup___150 *, struct cftype___88 *, const char *);
	int (*trigger)(struct cgroup___150 *, unsigned int);
	int (*release)(struct inode___255 *, struct file___255 *);
	int (*register_event)(struct cgroup___150 *, struct cftype___88 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___150 *, struct cftype___88 *, struct eventfd_ctx *);
};

struct cftype_set___84 {
	struct list_head node;
	struct cftype___88 *cfts;
};

struct task_and_cgroup___84 {
	struct task_struct___256 *task;
	struct cgroup___150 *cgrp;
	struct css_set___150 *cg;
};

struct cgroup_taskset___84 {
	struct task_and_cgroup___84 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___150 *cur_cgrp;
};

struct cgroup_subsys___84 {
	struct cgroup_subsys_state___150 * (*css_alloc)(struct cgroup___150 *);
	int (*css_online)(struct cgroup___150 *);
	void (*css_offline)(struct cgroup___150 *);
	void (*css_free)(struct cgroup___150 *);
	int (*can_attach)(struct cgroup___150 *, struct cgroup_taskset___84 *);
	void (*cancel_attach)(struct cgroup___150 *, struct cgroup_taskset___84 *);
	void (*attach)(struct cgroup___150 *, struct cgroup_taskset___84 *);
	void (*fork)(struct task_struct___256 *);
	void (*exit)(struct cgroup___150 *, struct cgroup___150 *, struct task_struct___256 *);
	void (*bind)(struct cgroup___150 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___150 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___88 *base_cftypes;
	struct cftype_set___84 base_cftset;
	struct module___157 *module;
};

struct netlink_skb_parms___7 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___38 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___47 {
	struct sk_buff___49 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___49 *, struct netlink_callback___47 *);
	int (*done)(struct netlink_callback___47 *);
	void *data;
	struct module___157 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___45 {
	int (*create)(struct sk_buff___49 *, struct net_device___46 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___49 *, unsigned char *);
	int (*rebuild)(struct sk_buff___49 *);
	int (*cache)(const struct neighbour___36 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___46 *, const unsigned char *);
};

struct napi_struct___45 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___45 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___46 *dev;
	struct sk_buff___49 *gro_list;
	struct sk_buff___49 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___45 {
	struct net_device___46 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___39 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___45 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___39 kobj;
	struct net_device___46 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___45 {
	int (*ndo_init)(struct net_device___46 *);
	void (*ndo_uninit)(struct net_device___46 *);
	int (*ndo_open)(struct net_device___46 *);
	int (*ndo_stop)(struct net_device___46 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___49 *, struct net_device___46 *);
	u16 (*ndo_select_queue)(struct net_device___46 *, struct sk_buff___49 *);
	void (*ndo_change_rx_flags)(struct net_device___46 *, int);
	void (*ndo_set_rx_mode)(struct net_device___46 *);
	int (*ndo_set_mac_address)(struct net_device___46 *, void *);
	int (*ndo_validate_addr)(struct net_device___46 *);
	int (*ndo_do_ioctl)(struct net_device___46 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___46 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___46 *, int);
	int (*ndo_neigh_setup)(struct net_device___46 *, struct neigh_parms___36 *);
	void (*ndo_tx_timeout)(struct net_device___46 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___46 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___46 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___46 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___46 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___46 *);
	int (*ndo_netpoll_setup)(struct net_device___46 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___46 *);
	int (*ndo_busy_poll)(struct napi_struct___45 *);
	int (*ndo_set_vf_mac)(struct net_device___46 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___46 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___46 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___46 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___46 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___46 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___46 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___46 *, int, struct sk_buff___49 *);
	int (*ndo_setup_tc)(struct net_device___46 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___46 *);
	int (*ndo_fcoe_disable)(struct net_device___46 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___46 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___46 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___46 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___46 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___46 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___46 *, const struct sk_buff___49 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___46 *, struct net_device___46 *);
	int (*ndo_del_slave)(struct net_device___46 *, struct net_device___46 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___36 *);
	void (*ndo_neigh_destroy)(struct neighbour___36 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___49 *, struct netlink_callback___47 *, struct net_device___46 *, int);
	int (*ndo_bridge_setlink)(struct net_device___46 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___49 *, u32, u32, struct net_device___46 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___46 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___46 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___46 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___46 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___46 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___46 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___49 *, struct net_device___46 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___46 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___46 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___46 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___36 {
	struct net___60 *net;
	struct net_device___46 *dev;
	struct neigh_parms___36 *next;
	int (*neigh_setup)(struct neighbour___36 *);
	void (*neigh_cleanup)(struct neighbour___36 *);
	struct neigh_table___36 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___36 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___46 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___60 *, struct net_device___46 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___46 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___46 *, struct list_head *);
	size_t (*get_size)(const struct net_device___46 *);
	int (*fill_info)(struct sk_buff___49 *, const struct net_device___46 *);
	size_t (*get_xstats_size)(const struct net_device___46 *);
	int (*fill_xstats)(struct sk_buff___49 *, const struct net_device___46 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___60 * (*get_link_net)(const struct net_device___46 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___46 *, struct net_device___46 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___46 *, const struct net_device___46 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___49 *, const struct net_device___46 *, const struct net_device___46 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___37 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___49 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef int (*rtnl_doit_func___4)(struct sk_buff___49 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___4)(struct sk_buff___49 *, struct netlink_callback___47 *);

typedef u16 (*rtnl_calcit_func___4)(struct sk_buff___49 *, struct nlmsghdr *);

struct pneigh_entry___36;

struct neigh_hash_table___36;

struct neigh_table___36 {
	struct neigh_table___36 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___46 *, __u32 *);
	int (*constructor)(struct neighbour___36 *);
	int (*pconstructor)(struct pneigh_entry___36 *);
	void (*pdestructor)(struct pneigh_entry___36 *);
	void (*proxy_redo)(struct sk_buff___49 *);
	char *id;
	struct neigh_parms___36 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___46 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___36 *nht;
	struct pneigh_entry___36 **phash_buckets;
};

struct neigh_ops___36 {
	int family;
	void (*solicit)(struct neighbour___36 *, struct sk_buff___49 *);
	void (*error_report)(struct neighbour___36 *, struct sk_buff___49 *);
	int (*output)(struct neighbour___36 *, struct sk_buff___49 *);
	int (*connected_output)(struct neighbour___36 *, struct sk_buff___49 *);
};

struct pneigh_entry___36 {
	struct pneigh_entry___36 *next;
	struct net___60 *net;
	struct net_device___46 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___36 {
	struct neighbour___36 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___36 {
	void (*close)(struct sock___38 *, long int);
	int (*connect)(struct sock___38 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___38 *, int);
	struct sock___38 * (*accept)(struct sock___38 *, int, int *);
	int (*ioctl)(struct sock___38 *, int, long unsigned int);
	int (*init)(struct sock___38 *);
	void (*destroy)(struct sock___38 *);
	void (*shutdown)(struct sock___38 *, int);
	int (*setsockopt)(struct sock___38 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___38 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___38 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___38 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___38 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___44 *, struct sock___38 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___44 *, struct sock___38 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___38 *, struct page___254 *, int, size_t, int);
	int (*bind)(struct sock___38 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___38 *, struct sk_buff___49 *);
	void (*release_cb)(struct sock___38 *);
	void (*mtu_reduced)(struct sock___38 *);
	void (*hash)(struct sock___38 *);
	void (*unhash)(struct sock___38 *);
	void (*rehash)(struct sock___38 *);
	int (*get_port)(struct sock___38 *, short unsigned int);
	void (*clear_sk)(struct sock___38 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___38 *);
	void (*enter_memory_pressure)(struct sock___38 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___238 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___157 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___84 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___36 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___36 {
	void (*enter_memory_pressure)(struct sock___38 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

enum {
	FRA_UNSPEC = 0,
	FRA_DST = 1,
	FRA_SRC = 2,
	FRA_IIFNAME = 3,
	FRA_GOTO = 4,
	FRA_UNUSED2 = 5,
	FRA_PRIORITY = 6,
	FRA_UNUSED3 = 7,
	FRA_UNUSED4 = 8,
	FRA_UNUSED5 = 9,
	FRA_FWMARK = 10,
	FRA_FLOW = 11,
	FRA_UNUSED6 = 12,
	FRA_UNUSED7 = 13,
	FRA_UNUSED8 = 14,
	FRA_TABLE = 15,
	FRA_FWMASK = 16,
	FRA_OIFNAME = 17,
	__FRA_MAX = 18,
};

enum {
	FR_ACT_UNSPEC = 0,
	FR_ACT_TO_TBL = 1,
	FR_ACT_GOTO = 2,
	FR_ACT_NOP = 3,
	FR_ACT_RES3 = 4,
	FR_ACT_RES4 = 5,
	FR_ACT_BLACKHOLE = 6,
	FR_ACT_UNREACHABLE = 7,
	FR_ACT_PROHIBIT = 8,
	__FR_ACT_MAX = 9,
};

struct fib_rule___2 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___2 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___60 *fr_net;
};

struct fib_lookup_arg___2 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___2 *rule;
	int flags;
};

struct page___255;

typedef struct page___255 *pgtable_t___255;

struct address_space___256;

struct kmem_cache___239;

struct page___255 {
	long unsigned int flags;
	struct address_space___256 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___255 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___255 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___239 *slab_cache;
		struct page___255 *first_page;
	};
	long: 64;
};

struct thread_struct___85;

struct task_struct___257;

struct pv_cpu_ops___257 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___85 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___85 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___257 *);
	void (*end_context_switch)(struct task_struct___257 *);
};

struct perf_event___85;

struct thread_struct___85 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___85 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___96;

struct pid_link___96 {
	struct hlist_node node;
	struct pid___96 *pid;
};

struct mutex___258 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___257 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___250 {
	struct page___255 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___264;

struct nsproxy___136;

struct signal_struct___257;

struct css_set___151;

struct perf_event_context___85;

struct task_struct___257 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___257 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___264 *mm;
	struct mm_struct___264 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___257 *real_parent;
	struct task_struct___257 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___257 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___96 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___257 = 0,
		VTIME_USER___257 = 1,
		VTIME_SYS___257 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___85 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___136 *nsproxy;
	struct signal_struct___257 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___151 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___85 *perf_event_ctxp[2];
	struct mutex___258 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___250 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___264 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___264 *, struct mm_struct___264 *);
	void (*dup_mmap)(struct mm_struct___264 *, struct mm_struct___264 *);
	void (*exit_mmap)(struct mm_struct___264 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___264 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___264 *);
	void (*pgd_free)(struct mm_struct___264 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___264 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___264 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___264 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___264 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___264 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___264 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___264 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___264 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___264 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___264 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___264 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___258 lock;
	void *vdso;
} mm_context_t___258;

struct xol_area___255;

struct uprobes_state___255 {
	struct xol_area___255 *xol_area;
};

struct vm_area_struct___264;

struct file___256;

struct core_state___257;

struct mm_struct___264 {
	struct vm_area_struct___264 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___264 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___264 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___258 context;
	long unsigned int flags;
	struct core_state___257 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___257 *owner;
	struct file___256 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___255 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___85 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___257 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___257 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___257 *target;
};

typedef void (*perf_overflow_handler_t___85)(struct perf_event___85 *, struct perf_sample_data___8 *, struct pt_regs *);

struct ftrace_ops___85;

typedef void (*ftrace_func_t___85)(long unsigned int, long unsigned int, struct ftrace_ops___85 *, struct pt_regs *);

struct ftrace_ops___85 {
	ftrace_func_t___85 func;
	struct ftrace_ops___85 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___258 regex_lock;
};

struct pmu___85;

struct fasync_struct___256;

struct pid_namespace___96;

struct ftrace_event_call___74;

struct perf_cgroup___85;

struct perf_event___85 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___85 *group_leader;
	struct pmu___85 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___85 hw;
	struct perf_event_context___85 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___258 child_mutex;
	struct list_head child_list;
	struct perf_event___85 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___257 *owner;
	struct mutex___258 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___256 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___85 *);
	struct callback_head callback_head;
	struct pid_namespace___96 *ns;
	u64 id;
	perf_overflow_handler_t___85 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___74 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___85 ftrace_ops;
	struct perf_cgroup___85 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___117 {
	struct task_struct___257 *task;
	struct exec_domain___71 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct kiocb___45;

struct poll_table_struct___144;

struct inode___256;

struct file_lock___256;

struct seq_file___181;

struct file_operations___256 {
	struct module *owner;
	loff_t (*llseek)(struct file___256 *, loff_t, int);
	ssize_t (*read)(struct file___256 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___256 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___45 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___45 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___256 *, void *, filldir_t);
	unsigned int (*poll)(struct file___256 *, struct poll_table_struct___144 *);
	long int (*unlocked_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___256 *, struct vm_area_struct___264 *);
	int (*open)(struct inode___256 *, struct file___256 *);
	int (*flush)(struct file___256 *, fl_owner_t);
	int (*release)(struct inode___256 *, struct file___256 *);
	int (*fsync)(struct file___256 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___45 *, int);
	int (*fasync)(int, struct file___256 *, int);
	int (*lock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*sendpage)(struct file___256 *, struct page___255 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___256 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___256 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___256 *, long int, struct file_lock___256 **, void **);
		struct {
			int (*setlease)(struct file___256 *, long int, struct file_lock___256 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___256 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___181 *, struct file___256 *);
};

struct kset___40;

struct kobj_type___40;

struct kobject___40 {
	const char *name;
	struct list_head entry;
	struct kobject___40 *parent;
	struct kset___40 *kset;
	struct kobj_type___40 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___57;

struct dev_pm_info___57 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___57 *qos;
};

struct dma_map_ops___119;

struct dev_archdata___119 {
	struct dma_map_ops___119 *dma_ops;
	void *iommu;
};

struct device_type___254;

struct bus_type___254;

struct device_driver___254;

struct dev_pm_domain___254;

struct class___254;

struct attribute_group___216;

struct device_rh___254;

struct device___254 {
	struct device___254 *parent;
	struct device_private *p;
	struct kobject___40 kobj;
	const char *init_name;
	const struct device_type___254 *type;
	struct mutex___258 mutex;
	struct bus_type___254 *bus;
	struct device_driver___254 *driver;
	void *platform_data;
	struct dev_pm_info___57 power;
	struct dev_pm_domain___254 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___119 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___254 *class;
	const struct attribute_group___216 **groups;
	void (*release)(struct device___254 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___254 *device_rh;
};

struct sock___39;

struct kobj_ns_type_operations___37 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___39 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___37;

struct net___61;

struct sock_common___37 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___37 *skc_prot;
	struct net___61 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___50;

struct sk_buff_head___47 {
	struct sk_buff___50 *next;
	struct sk_buff___50 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___38;

struct socket_wq___37;

struct dst_entry___37;

struct socket___38;

struct cg_proto___37;

struct sock___39 {
	struct sock_common___37 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___47 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___50 *head;
		struct sk_buff___50 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___38 *sk_filter;
	struct socket_wq___37 *sk_wq;
	struct sk_buff_head___47 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___37 *sk_rx_dst;
	struct dst_entry___37 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___47 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___47 sk_error_queue;
	struct proto___37 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___96 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___38 *sk_socket;
	void *sk_user_data;
	struct page_frag___250 sk_frag;
	struct sk_buff___50 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___37 *sk_cgrp;
	void (*sk_state_change)(struct sock___39 *);
	void (*sk_data_ready)(struct sock___39 *, int);
	void (*sk_write_space)(struct sock___39 *);
	void (*sk_error_report)(struct sock___39 *);
	int (*sk_backlog_rcv)(struct sock___39 *, struct sk_buff___50 *);
	void (*sk_destruct)(struct sock___39 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___218;

struct attribute_group___216 {
	const char *name;
	umode_t (*is_visible)(struct kobject___40 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___218 **bin_attrs;
};

struct bin_attribute___218 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___256 *, struct kobject___40 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___256 *, struct kobject___40 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	int (*mmap)(struct file___256 *, struct kobject___40 *, struct bin_attribute___218 *, struct vm_area_struct___264 *);
};

struct dentry___256;

struct path___256 {
	struct vfsmount *mnt;
	struct dentry___256 *dentry;
};

struct fown_struct___96 {
	rwlock_t lock;
	struct pid___96 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___256 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___256 f_path;
	struct inode___256 *f_inode;
	const struct file_operations___256 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___96 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___256 *f_mapping;
	struct mutex___258 f_pos_lock;
};

struct vm_operations_struct___230;

struct vm_area_struct___264 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___264 *vm_next;
	struct vm_area_struct___264 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___264 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___230 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___256 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___40 {
	ssize_t (*show)(struct kobject___40 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___40 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___40 *, const struct attribute *);
};

struct kset_uevent_ops___40;

struct kset___40 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___40 kobj;
	const struct kset_uevent_ops___40 *uevent_ops;
};

struct kobj_type___40 {
	void (*release)(struct kobject___40 *);
	const struct sysfs_ops___40 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___37 * (*child_ns_type)(struct kobject___40 *);
	const void * (*namespace)(struct kobject___40 *);
};

struct kset_uevent_ops___40 {
	int (* const filter)(struct kset___40 *, struct kobject___40 *);
	const char * (* const name)(struct kset___40 *, struct kobject___40 *);
	int (* const uevent)(struct kset___40 *, struct kobject___40 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___254 {
	int (*prepare)(struct device___254 *);
	void (*complete)(struct device___254 *);
	int (*suspend)(struct device___254 *);
	int (*resume)(struct device___254 *);
	int (*freeze)(struct device___254 *);
	int (*thaw)(struct device___254 *);
	int (*poweroff)(struct device___254 *);
	int (*restore)(struct device___254 *);
	int (*suspend_late)(struct device___254 *);
	int (*resume_early)(struct device___254 *);
	int (*freeze_late)(struct device___254 *);
	int (*thaw_early)(struct device___254 *);
	int (*poweroff_late)(struct device___254 *);
	int (*restore_early)(struct device___254 *);
	int (*suspend_noirq)(struct device___254 *);
	int (*resume_noirq)(struct device___254 *);
	int (*freeze_noirq)(struct device___254 *);
	int (*thaw_noirq)(struct device___254 *);
	int (*poweroff_noirq)(struct device___254 *);
	int (*restore_noirq)(struct device___254 *);
	int (*runtime_suspend)(struct device___254 *);
	int (*runtime_resume)(struct device___254 *);
	int (*runtime_idle)(struct device___254 *);
};

struct dev_pm_qos_request___58;

struct dev_pm_qos___57 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___58 *latency_req;
	struct dev_pm_qos_request___58 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___58 *latency_tolerance_req;
};

struct dev_pm_info_rh___254 {
	void (*set_latency_tolerance)(struct device___254 *, s32);
};

struct dev_pm_domain___254 {
	struct dev_pm_ops___254 ops;
};

struct zone___257;

struct lruvec___257 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___257 *zone;
};

struct pglist_data___257;

struct zone___257 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___257 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___257 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___257 {
	struct zone___257 *zone;
	int zone_idx;
};

struct zonelist___257 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___257 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___257 {
	struct zone___257 node_zones[4];
	struct zonelist___257 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___257 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___180;

struct x86_io_apic_ops___180 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___180 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___180;

struct irq_data___180 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___180 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___257 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___257 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___119 {
	void * (*alloc)(struct device___254 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___254 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___254 *, struct vm_area_struct___264 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___254 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___254 *, struct page___255 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___254 *, dma_addr_t);
	int (*dma_supported)(struct device___254 *, u64);
	int (*set_dma_mask)(struct device___254 *, u64);
	int is_phys;
};

struct bus_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___254 *, char *);
	ssize_t (*store)(struct bus_type___254 *, const char *, size_t);
};

struct device_attribute___254;

struct driver_attribute___254;

struct bus_type___254 {
	const char *name;
	const char *dev_name;
	struct device___254 *dev_root;
	struct bus_attribute___254 *bus_attrs;
	struct device_attribute___254 *dev_attrs;
	struct driver_attribute___254 *drv_attrs;
	const struct attribute_group___216 **bus_groups;
	const struct attribute_group___216 **dev_groups;
	const struct attribute_group___216 **drv_groups;
	int (*match)(struct device___254 *, struct device_driver___254 *);
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	int (*probe)(struct device___254 *);
	int (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*online)(struct device___254 *);
	int (*offline)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct device___254 *, struct device_attribute___254 *, char *);
	ssize_t (*store)(struct device___254 *, struct device_attribute___254 *, const char *, size_t);
};

struct driver_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___254 *, char *);
	ssize_t (*store)(struct device_driver___254 *, const char *, size_t);
};

struct device_driver___254 {
	const char *name;
	struct bus_type___254 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___254 *);
	int (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	const struct attribute_group___216 **groups;
	const struct dev_pm_ops___254 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___254 {
	const char *name;
	const struct attribute_group___216 **groups;
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
};

struct class_attribute___254;

struct class___254 {
	const char *name;
	struct module *owner;
	struct class_attribute___254 *class_attrs;
	struct device_attribute___254 *dev_attrs;
	const struct attribute_group___216 **dev_groups;
	struct bin_attribute___218 *dev_bin_attrs;
	struct kobject___40 *dev_kobj;
	int (*dev_uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *);
	void (*class_release)(struct class___254 *);
	void (*dev_release)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	const struct kobj_ns_type_operations___37 *ns_type;
	const void * (*namespace)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
	struct subsys_private *p;
};

struct class_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct class___254 *, struct class_attribute___254 *, char *);
	ssize_t (*store)(struct class___254 *, struct class_attribute___254 *, const char *, size_t);
	const void * (*namespace)(struct class___254 *, const struct class_attribute___254 *);
};

struct device_rh___254 {
	struct dev_pm_info_rh___254 power;
};

struct dev_pm_qos_request___58 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___254 *dev;
};

struct xol_area___255 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___255 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___238;

struct memcg_cache_params___239;

struct kmem_cache___239 {
	struct kmem_cache_cpu___238 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___40 kobj;
	struct memcg_cache_params___239 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___256;

struct address_space___256 {
	struct inode___256 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___258 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___256 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___226;

struct vm_operations_struct___230 {
	void (*open)(struct vm_area_struct___264 *);
	void (*close)(struct vm_area_struct___264 *);
	int (*fault)(struct vm_area_struct___264 *, struct vm_fault___226 *);
	int (*page_mkwrite)(struct vm_area_struct___264 *, struct vm_fault___226 *);
	int (*access)(struct vm_area_struct___264 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___264 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___264 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___264 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___264 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___257 {
	struct task_struct___257 *task;
	struct core_thread___257 *next;
};

struct core_state___257 {
	atomic_t nr_threads;
	struct core_thread___257 dumper;
	struct completion startup;
};

struct vm_fault___226 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___255 *page;
};

struct dentry_operations___256;

struct super_block___256;

struct dentry___256 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___256 *d_parent;
	struct qstr d_name;
	struct inode___256 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___256 *d_op;
	struct super_block___256 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___256;

struct dquot___256;

struct block_device___256;

struct inode___256 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___256 *i_op;
	struct super_block___256 *i_sb;
	struct address_space___256 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___258 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___256 *i_fop;
	struct file_lock___256 *i_flock;
	struct address_space___256 i_data;
	struct dquot___256 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___256 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___256 {
	int (*d_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_hash)(const struct dentry___256 *, struct qstr *);
	int (*d_compare)(const struct dentry___256 *, const struct dentry___256 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___256 *);
	void (*d_release)(struct dentry___256 *);
	void (*d_prune)(struct dentry___256 *);
	void (*d_iput)(struct dentry___256 *, struct inode___256 *);
	char * (*d_dname)(struct dentry___256 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___256 *);
	int (*d_manage)(struct dentry___256 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___256;

struct mem_dqinfo___256 {
	struct quota_format_type___256 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___256;

struct quota_info___256 {
	unsigned int flags;
	struct mutex___258 dqio_mutex;
	struct mutex___258 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___256 *files[2];
	struct mem_dqinfo___256 info[2];
	const struct quota_format_ops___256 *ops[2];
};

struct file_system_type___256;

struct super_operations___256;

struct dquot_operations___256;

struct quotactl_ops___256;

struct xattr_handler___152;

struct super_block___256 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___256 *s_type;
	const struct super_operations___256 *s_op;
	const struct dquot_operations___256 *dq_op;
	const struct quotactl_ops___256 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___256 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___152 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___256 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___256 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___258 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___256 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct upid___96 {
	int nr;
	struct pid_namespace___96 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___96 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___257 *child_reaper;
	struct kmem_cache___239 *pid_cachep;
	unsigned int level;
	struct pid_namespace___96 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___256 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___96 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___96 numbers[1];
};

struct block_device___256 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___256 *bd_inode;
	struct super_block___256 *bd_super;
	struct mutex___258 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___256 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___258 bd_fsfreeze_mutex;
};

struct cgroup___151;

struct cgroup_subsys_state___151 {
	struct cgroup___151 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___45(struct kiocb___45 *, struct io_event *);

struct kiocb___45 {
	atomic_t ki_users;
	struct file___256 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___45 *ki_cancel;
	void (*ki_dtor)(struct kiocb___45 *);
	union {
		void *user;
		struct task_struct___257 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___256 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___256 *ia_file;
};

struct dquot___256 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___258 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___256 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___256 {
	int qf_fmt_id;
	const struct quota_format_ops___256 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___256 *qf_next;
};

struct quota_format_ops___256 {
	int (*check_quota_file)(struct super_block___256 *, int);
	int (*read_file_info)(struct super_block___256 *, int);
	int (*write_file_info)(struct super_block___256 *, int);
	int (*free_file_info)(struct super_block___256 *, int);
	int (*read_dqblk)(struct dquot___256 *);
	int (*commit_dqblk)(struct dquot___256 *);
	int (*release_dqblk)(struct dquot___256 *);
};

struct dquot_operations___256 {
	int (*write_dquot)(struct dquot___256 *);
	struct dquot___256 * (*alloc_dquot)(struct super_block___256 *, int);
	void (*destroy_dquot)(struct dquot___256 *);
	int (*acquire_dquot)(struct dquot___256 *);
	int (*release_dquot)(struct dquot___256 *);
	int (*mark_dirty)(struct dquot___256 *);
	int (*write_info)(struct super_block___256 *, int);
	qsize_t * (*get_reserved_space)(struct inode___256 *);
};

struct quotactl_ops___256 {
	int (*quota_on)(struct super_block___256 *, int, int, struct path___256 *);
	int (*quota_on_meta)(struct super_block___256 *, int, int);
	int (*quota_off)(struct super_block___256 *, int);
	int (*quota_sync)(struct super_block___256 *, int);
	int (*get_info)(struct super_block___256 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___256 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___256 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___256 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___256 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___256 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___256 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___256 *, unsigned int);
};

struct address_space_operations___256 {
	int (*writepage)(struct page___255 *, struct writeback_control *);
	int (*readpage)(struct file___256 *, struct page___255 *);
	int (*writepages)(struct address_space___256 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___255 *);
	int (*readpages)(struct file___256 *, struct address_space___256 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___256 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___255 **, void **);
	int (*write_end)(struct file___256 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___255 *, void *);
	sector_t (*bmap)(struct address_space___256 *, sector_t);
	void (*invalidatepage)(struct page___255 *, long unsigned int);
	int (*releasepage)(struct page___255 *, gfp_t);
	void (*freepage)(struct page___255 *);
	ssize_t (*direct_IO)(int, struct kiocb___45 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___256 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___256 *, struct page___255 *, struct page___255 *, enum migrate_mode);
	int (*launder_page)(struct page___255 *);
	int (*is_partially_uptodate)(struct page___255 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___255 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___256 *, struct page___255 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___256 *, sector_t *);
	void (*swap_deactivate)(struct file___256 *);
	void (*invalidatepage_range)(struct page___255 *, unsigned int, unsigned int);
};

struct inode_operations___256 {
	struct dentry___256 * (*lookup)(struct inode___256 *, struct dentry___256 *, unsigned int);
	void * (*follow_link)(struct dentry___256 *, struct nameidata *);
	int (*permission)(struct inode___256 *, int);
	struct posix_acl * (*get_acl)(struct inode___256 *, int);
	int (*readlink)(struct dentry___256 *, char *, int);
	void (*put_link)(struct dentry___256 *, struct nameidata *, void *);
	int (*create)(struct inode___256 *, struct dentry___256 *, umode_t, bool);
	int (*link)(struct dentry___256 *, struct inode___256 *, struct dentry___256 *);
	int (*unlink)(struct inode___256 *, struct dentry___256 *);
	int (*symlink)(struct inode___256 *, struct dentry___256 *, const char *);
	int (*mkdir)(struct inode___256 *, struct dentry___256 *, umode_t);
	int (*rmdir)(struct inode___256 *, struct dentry___256 *);
	int (*mknod)(struct inode___256 *, struct dentry___256 *, umode_t, dev_t);
	int (*rename)(struct inode___256 *, struct dentry___256 *, struct inode___256 *, struct dentry___256 *);
	int (*setattr)(struct dentry___256 *, struct iattr___256 *);
	int (*getattr)(struct vfsmount *, struct dentry___256 *, struct kstat *);
	int (*setxattr)(struct dentry___256 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___256 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___256 *, char *, size_t);
	int (*removexattr)(struct dentry___256 *, const char *);
	int (*fiemap)(struct inode___256 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___256 *, struct timespec *, int);
	int (*atomic_open)(struct inode___256 *, struct dentry___256 *, struct file___256 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___256;

struct lock_manager_operations___256;

struct file_lock___256 {
	struct file_lock___256 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___96 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___256 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___256 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___256 *fl_ops;
	const struct lock_manager_operations___256 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___256 {
	void (*fl_copy_lock)(struct file_lock___256 *, struct file_lock___256 *);
	void (*fl_release_private)(struct file_lock___256 *);
};

struct lock_manager_operations___256 {
	int (*lm_compare_owner)(struct file_lock___256 *, struct file_lock___256 *);
	long unsigned int (*lm_owner_key)(struct file_lock___256 *);
	void (*lm_notify)(struct file_lock___256 *);
	int (*lm_grant)(struct file_lock___256 *, struct file_lock___256 *, int);
	void (*lm_break)(struct file_lock___256 *);
	int (*lm_change)(struct file_lock___256 **, int);
};

struct fasync_struct___256 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___256 *fa_next;
	struct file___256 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___256 {
	const char *name;
	int fs_flags;
	struct dentry___256 * (*mount)(struct file_system_type___256 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___256 *);
	struct module *owner;
	struct file_system_type___256 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___256 {
	struct inode___256 * (*alloc_inode)(struct super_block___256 *);
	void (*destroy_inode)(struct inode___256 *);
	void (*dirty_inode)(struct inode___256 *, int);
	int (*write_inode)(struct inode___256 *, struct writeback_control *);
	int (*drop_inode)(struct inode___256 *);
	void (*evict_inode)(struct inode___256 *);
	void (*put_super)(struct super_block___256 *);
	int (*sync_fs)(struct super_block___256 *, int);
	int (*freeze_fs)(struct super_block___256 *);
	int (*unfreeze_fs)(struct super_block___256 *);
	int (*statfs)(struct dentry___256 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___256 *, int *, char *);
	void (*umount_begin)(struct super_block___256 *);
	int (*show_options)(struct seq_file___181 *, struct dentry___256 *);
	int (*show_devname)(struct seq_file___181 *, struct dentry___256 *);
	int (*show_path)(struct seq_file___181 *, struct dentry___256 *);
	int (*show_stats)(struct seq_file___181 *, struct dentry___256 *);
	ssize_t (*quota_read)(struct super_block___256 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___256 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___256 *);
	int (*bdev_try_to_free_page)(struct super_block___256 *, struct page___255 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___256 *);
	void (*free_cached_objects)(struct super_block___256 *, int);
};

struct xattr_handler___152 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___256 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___256 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___256 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___146)(struct file___256 *, wait_queue_head_t *, struct poll_table_struct___144 *);

struct poll_table_struct___144 {
	poll_queue_proc___146 _qproc;
	long unsigned int _key;
};

struct seq_operations___181;

struct seq_file___181 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___258 lock;
	const struct seq_operations___181 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_table_header___61;

struct ctl_node___61 {
	struct rb_node node;
	struct ctl_table_header___61 *header;
};

struct ctl_table_root___61;

struct ctl_table_set___61;

struct ctl_dir___61;

struct ctl_table_header___61 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___61 *root;
	struct ctl_table_set___61 *set;
	struct ctl_dir___61 *parent;
	struct ctl_node___61 *node;
};

struct ctl_dir___61 {
	struct ctl_table_header___61 header;
	struct rb_root root;
};

struct ctl_table_set___61 {
	int (*is_seen)(struct ctl_table_set___61 *);
	struct ctl_dir___61 dir;
};

struct ctl_table_root___61 {
	struct ctl_table_set___61 default_set;
	struct ctl_table_set___61 * (*lookup)(struct ctl_table_root___61 *, struct nsproxy___136 *);
	int (*permissions)(struct ctl_table_header___61 *, struct ctl_table *);
};

struct nsproxy___136 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___96 *pid_ns;
	struct net___61 *net_ns;
};

struct signal_struct___257 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___257 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___257 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___96 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___96 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___258 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___151 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___151 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___85 {
	struct pmu___85 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___258 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___257 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___85 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct socket_wq___37 {
	wait_queue_head_t wait;
	struct fasync_struct___256 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___37;

struct socket___38 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___37 *wq;
	struct file___256 *file;
	struct sock___39 *sk;
	const struct proto_ops___37 *ops;
};

struct proto_ops___37 {
	int family;
	struct module *owner;
	int (*release)(struct socket___38 *);
	int (*bind)(struct socket___38 *, struct sockaddr *, int);
	int (*connect)(struct socket___38 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___38 *, struct socket___38 *);
	int (*accept)(struct socket___38 *, struct socket___38 *, int);
	int (*getname)(struct socket___38 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___256 *, struct socket___38 *, struct poll_table_struct___144 *);
	int (*ioctl)(struct socket___38 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___38 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___38 *, int);
	int (*shutdown)(struct socket___38 *, int);
	int (*setsockopt)(struct socket___38 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___38 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___38 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___38 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___45 *, struct socket___38 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___45 *, struct socket___38 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___256 *, struct socket___38 *, struct vm_area_struct___264 *);
	ssize_t (*sendpage)(struct socket___38 *, struct page___255 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___38 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___39 *, int);
		struct {
			void (*set_peek_off)(struct sock___39 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___58 {
	struct ctl_table_header___61 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___59 {
	struct mutex___258 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___58 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___61 *ctl;
};

struct netns_ipv4___58 {
	struct ctl_table_header___61 *forw_hdr;
	struct ctl_table_header___61 *frags_hdr;
	struct ctl_table_header___61 *ipv4_hdr;
	struct ctl_table_header___61 *route_hdr;
	struct ctl_table_header___61 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___39 *fibnl;
	struct sock___39 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___58 {
	struct ctl_table_header___61 *hdr;
	struct ctl_table_header___61 *route_hdr;
	struct ctl_table_header___61 *icmp_hdr;
	struct ctl_table_header___61 *frags_hdr;
	struct ctl_table_header___61 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___47;

struct neighbour___37;

struct dst_ops___60 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___60 *);
	struct dst_entry___37 * (*check)(struct dst_entry___37 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___37 *);
	unsigned int (*mtu)(const struct dst_entry___37 *);
	u32 * (*cow_metrics)(struct dst_entry___37 *, long unsigned int);
	void (*destroy)(struct dst_entry___37 *);
	void (*ifdown)(struct dst_entry___37 *, struct net_device___47 *, int);
	struct dst_entry___37 * (*negative_advice)(struct dst_entry___37 *);
	void (*link_failure)(struct sk_buff___50 *);
	void (*update_pmtu)(struct dst_entry___37 *, struct sock___39 *, struct sk_buff___50 *, u32);
	void (*redirect)(struct dst_entry___37 *, struct sock___39 *, struct sk_buff___50 *);
	int (*local_out)(struct sk_buff___50 *);
	struct neighbour___37 * (*neigh_lookup)(const struct dst_entry___37 *, struct sk_buff___50 *, const void *);
	struct kmem_cache___239 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___60 {
	struct netns_sysctl_ipv6___58 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___60 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___39 **icmp_sk;
	struct sock___39 *ndisc_sk;
	struct sock___39 *tcp_sk;
	struct sock___39 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___58 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___61 *sysctl_header;
	struct sock___39 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___37 {
	struct sock___39 *v4_ctl_sk;
	struct sock___39 *v6_ctl_sk;
};

struct netns_nf___58 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___61 *nf_log_dir_header;
};

struct nf_proto_net___58 {
	struct ctl_table_header___61 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___58 {
	struct nf_proto_net___58 pn;
	unsigned int timeout;
};

struct nf_tcp_net___58 {
	struct nf_proto_net___58 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___58 {
	struct nf_proto_net___58 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___58 {
	struct nf_proto_net___58 pn;
	unsigned int timeout;
};

struct nf_ip_net___58 {
	struct nf_generic_net___58 generic;
	struct nf_tcp_net___58 tcp;
	struct nf_udp_net___58 udp;
	struct nf_icmp_net___58 icmp;
	struct nf_icmp_net___58 icmpv6;
};

struct netns_ct___59 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___61 *sysctl_header;
	struct ctl_table_header___61 *acct_sysctl_header;
	struct ctl_table_header___61 *tstamp_sysctl_header;
	struct ctl_table_header___61 *event_sysctl_header;
	struct ctl_table_header___61 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___239 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___58 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___58 {
	struct netns_sysctl_ipv6___58 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___60 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___39 *nlsk;
	struct sock___39 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___61 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___60 xfrm4_dst_ops;
	struct dst_ops___60 xfrm6_dst_ops;
};

struct net___61 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___61 sysctls;
	struct sock___39 *rtnl;
	struct sock___39 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___47 *loopback_dev;
	struct netns_core___58 core;
	struct netns_mib mib;
	struct netns_packet___59 packet;
	struct netns_unix___58 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___58 ipv4;
	struct netns_ipv6___60 ipv6;
	struct netns_sctp___58 sctp;
	struct netns_dccp___37 dccp;
	struct netns_nf___58 nf;
	struct netns_xt xt;
	struct netns_ct___59 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___58 nf_frag;
	struct sock___39 *nfnl;
	struct sock___39 *nfnl_stash;
	struct sk_buff_head___47 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___60 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___39 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___39 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___258 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___258 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___238 {
	void **freelist;
	long unsigned int tid;
	struct page___255 *page;
	struct page___255 *partial;
};

struct memcg_cache_params___239 {
	bool is_root_cache;
	union {
		struct kmem_cache___239 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___239 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___46 {
	atomic_t use;
	unsigned int mask;
	struct net_device___47 *physindev;
	struct net_device___47 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___46(struct sk_buff___50 **);

struct net_device_ops___46;

struct ethtool_ops___46;

struct header_ops___46;

struct in_device___4;

struct netdev_rx_queue___46;

struct netdev_queue___46;

struct netpoll_info___4;

struct rtnl_link_ops___37;

struct dcbnl_rtnl_ops___46;

struct net_device___47 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___46 *netdev_ops;
	const struct ethtool_ops___46 *ethtool_ops;
	const struct header_ops___46 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___40 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___4 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___46 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___46 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___46 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___46 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___46 = 0,
		NETREG_REGISTERED___46 = 1,
		NETREG_UNREGISTERING___46 = 2,
		NETREG_UNREGISTERED___46 = 3,
		NETREG_RELEASED___46 = 4,
		NETREG_DUMMY___46 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___46 = 0,
		RTNL_LINK_INITIALIZING___46 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___47 *);
	struct netpoll_info___4 *npinfo;
	struct net___61 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___254 dev;
	const struct attribute_group___216 *sysfs_groups[4];
	const struct rtnl_link_ops___37 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___46 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___50 {
	struct sk_buff___50 *next;
	struct sk_buff___50 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___39 *sk;
	struct net_device___47 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___50 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___46 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___46 {
	int (*get_settings)(struct net_device___47 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___47 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___47 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___47 *);
	void (*get_regs)(struct net_device___47 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___47 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___47 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___47 *);
	void (*set_msglevel)(struct net_device___47 *, u32);
	int (*nway_reset)(struct net_device___47 *);
	u32 (*get_link)(struct net_device___47 *);
	int (*get_eeprom_len)(struct net_device___47 *);
	int (*get_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___47 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___47 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___47 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___47 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___47 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___47 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___47 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___47 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___47 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___47 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___47 *);
	void (*complete)(struct net_device___47 *);
	u32 (*get_priv_flags)(struct net_device___47 *);
	int (*set_priv_flags)(struct net_device___47 *, u32);
	int (*get_sset_count)(struct net_device___47 *, int);
	int (*get_rxnfc)(struct net_device___47 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___47 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___47 *, struct ethtool_flash *);
	int (*reset)(struct net_device___47 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___47 *);
	int (*get_rxfh_indir)(struct net_device___47 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___47 *, const u32 *);
	void (*get_channels)(struct net_device___47 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___47 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___47 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___47 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___47 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___47 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___47 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___47 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___47 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___47 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___47 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___47 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___37 {
	struct callback_head callback_head;
	struct dst_entry___37 *child;
	struct net_device___47 *dev;
	struct dst_ops___60 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___37 *path;
	struct dst_entry___37 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___50 *);
	union {
		int (*output)(struct sock___39 *, struct sk_buff___50 *);
		struct {
			int (*output)(struct sk_buff___50 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___37 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___37;

struct neigh_parms___37;

struct neigh_ops___37;

struct neighbour___37 {
	struct neighbour___37 *next;
	struct neigh_table___37 *tbl;
	struct neigh_parms___37 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___47 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___37 *, struct sk_buff___50 *);
	const struct neigh_ops___37 *ops;
	struct callback_head rcu;
	struct net_device___47 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___60 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___50 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___50 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___61 *, struct dst_entry___37 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___50 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___50 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___180 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___180 *);
	void (*irq_shutdown)(struct irq_data___180 *);
	void (*irq_enable)(struct irq_data___180 *);
	void (*irq_disable)(struct irq_data___180 *);
	void (*irq_ack)(struct irq_data___180 *);
	void (*irq_mask)(struct irq_data___180 *);
	void (*irq_mask_ack)(struct irq_data___180 *);
	void (*irq_unmask)(struct irq_data___180 *);
	void (*irq_eoi)(struct irq_data___180 *);
	int (*irq_set_affinity)(struct irq_data___180 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___180 *);
	int (*irq_set_type)(struct irq_data___180 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___180 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___180 *);
	void (*irq_bus_sync_unlock)(struct irq_data___180 *);
	void (*irq_cpu_online)(struct irq_data___180 *);
	void (*irq_cpu_offline)(struct irq_data___180 *);
	void (*irq_suspend)(struct irq_data___180 *);
	void (*irq_resume)(struct irq_data___180 *);
	void (*irq_pm_shutdown)(struct irq_data___180 *);
	void (*irq_print_chip)(struct irq_data___180 *, struct seq_file___181 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___180 *, void *);
	long unsigned int flags;
};

struct seq_operations___181 {
	void * (*start)(struct seq_file___181 *, loff_t *);
	void (*stop)(struct seq_file___181 *, void *);
	void * (*next)(struct seq_file___181 *, void *, loff_t *);
	int (*show)(struct seq_file___181 *, void *);
};

struct dcbnl_rtnl_ops___46 {
	int (*ieee_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___47 *);
	u8 (*setstate)(struct net_device___47 *, u8);
	void (*getpermhwaddr)(struct net_device___47 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___47 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___47 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___47 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___47 *, int, u8 *);
	void (*setpfccfg)(struct net_device___47 *, int, u8);
	void (*getpfccfg)(struct net_device___47 *, int, u8 *);
	u8 (*setall)(struct net_device___47 *);
	u8 (*getcap)(struct net_device___47 *, int, u8 *);
	int (*getnumtcs)(struct net_device___47 *, int, u8 *);
	int (*setnumtcs)(struct net_device___47 *, int, u8);
	u8 (*getpfcstate)(struct net_device___47 *);
	void (*setpfcstate)(struct net_device___47 *, u8);
	void (*getbcncfg)(struct net_device___47 *, int, u32 *);
	void (*setbcncfg)(struct net_device___47 *, int, u32);
	void (*getbcnrp)(struct net_device___47 *, int, u8 *);
	void (*setbcnrp)(struct net_device___47 *, int, u8);
	u8 (*setapp)(struct net_device___47 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___47 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___47 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___47 *, int, u8);
	u8 (*getdcbx)(struct net_device___47 *);
	u8 (*setdcbx)(struct net_device___47 *, u8);
	int (*peer_getappinfo)(struct net_device___47 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___47 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___47 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___47 *, struct cee_pfc *);
};

struct cgroupfs_root___151;

struct cgroup___151 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___151 *parent;
	struct dentry___256 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___151 *subsys[11];
	struct cgroupfs_root___151 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___258 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___151 {
	struct super_block___256 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___151 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___89 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___256 *, struct file___256 *);
	ssize_t (*read)(struct cgroup___151 *, struct cftype___89 *, struct file___256 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___151 *, struct cftype___89 *);
	s64 (*read_s64)(struct cgroup___151 *, struct cftype___89 *);
	int (*read_map)(struct cgroup___151 *, struct cftype___89 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___151 *, struct cftype___89 *, struct seq_file___181 *);
	ssize_t (*write)(struct cgroup___151 *, struct cftype___89 *, struct file___256 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___151 *, struct cftype___89 *, u64);
	int (*write_s64)(struct cgroup___151 *, struct cftype___89 *, s64);
	int (*write_string)(struct cgroup___151 *, struct cftype___89 *, const char *);
	int (*trigger)(struct cgroup___151 *, unsigned int);
	int (*release)(struct inode___256 *, struct file___256 *);
	int (*register_event)(struct cgroup___151 *, struct cftype___89 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___151 *, struct cftype___89 *, struct eventfd_ctx *);
};

struct cftype_set___85 {
	struct list_head node;
	struct cftype___89 *cfts;
};

struct task_and_cgroup___85 {
	struct task_struct___257 *task;
	struct cgroup___151 *cgrp;
	struct css_set___151 *cg;
};

struct cgroup_taskset___85 {
	struct task_and_cgroup___85 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___151 *cur_cgrp;
};

struct cgroup_subsys___85 {
	struct cgroup_subsys_state___151 * (*css_alloc)(struct cgroup___151 *);
	int (*css_online)(struct cgroup___151 *);
	void (*css_offline)(struct cgroup___151 *);
	void (*css_free)(struct cgroup___151 *);
	int (*can_attach)(struct cgroup___151 *, struct cgroup_taskset___85 *);
	void (*cancel_attach)(struct cgroup___151 *, struct cgroup_taskset___85 *);
	void (*attach)(struct cgroup___151 *, struct cgroup_taskset___85 *);
	void (*fork)(struct task_struct___257 *);
	void (*exit)(struct cgroup___151 *, struct cgroup___151 *, struct task_struct___257 *);
	void (*bind)(struct cgroup___151 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___151 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___89 *base_cftypes;
	struct cftype_set___85 base_cftset;
	struct module *module;
};

struct request_sock_ops___25;

struct request_sock___26 {
	struct sock_common___37 __req_common;
	struct request_sock___26 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___25 *rsk_ops;
	struct sock___39 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___48 {
	struct sk_buff___50 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___50 *, struct netlink_callback___48 *);
	int (*done)(struct netlink_callback___48 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___46 {
	int (*create)(struct sk_buff___50 *, struct net_device___47 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___50 *, unsigned char *);
	int (*rebuild)(struct sk_buff___50 *);
	int (*cache)(const struct neighbour___37 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___47 *, const unsigned char *);
};

struct napi_struct___46 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___46 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___47 *dev;
	struct sk_buff___50 *gro_list;
	struct sk_buff___50 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___46 {
	struct net_device___47 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___40 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___46 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___40 kobj;
	struct net_device___47 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___46 {
	int (*ndo_init)(struct net_device___47 *);
	void (*ndo_uninit)(struct net_device___47 *);
	int (*ndo_open)(struct net_device___47 *);
	int (*ndo_stop)(struct net_device___47 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___50 *, struct net_device___47 *);
	u16 (*ndo_select_queue)(struct net_device___47 *, struct sk_buff___50 *);
	void (*ndo_change_rx_flags)(struct net_device___47 *, int);
	void (*ndo_set_rx_mode)(struct net_device___47 *);
	int (*ndo_set_mac_address)(struct net_device___47 *, void *);
	int (*ndo_validate_addr)(struct net_device___47 *);
	int (*ndo_do_ioctl)(struct net_device___47 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___47 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___47 *, int);
	int (*ndo_neigh_setup)(struct net_device___47 *, struct neigh_parms___37 *);
	void (*ndo_tx_timeout)(struct net_device___47 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___47 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___47 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___47 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___47 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___47 *);
	int (*ndo_netpoll_setup)(struct net_device___47 *, struct netpoll_info___4 *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___47 *);
	int (*ndo_busy_poll)(struct napi_struct___46 *);
	int (*ndo_set_vf_mac)(struct net_device___47 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___47 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___47 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___47 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___47 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___47 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___47 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___47 *, int, struct sk_buff___50 *);
	int (*ndo_setup_tc)(struct net_device___47 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___47 *);
	int (*ndo_fcoe_disable)(struct net_device___47 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___47 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___47 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___47 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___47 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___47 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___47 *, const struct sk_buff___50 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___47 *, struct net_device___47 *);
	int (*ndo_del_slave)(struct net_device___47 *, struct net_device___47 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___37 *);
	void (*ndo_neigh_destroy)(struct neighbour___37 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___50 *, struct netlink_callback___48 *, struct net_device___47 *, int);
	int (*ndo_bridge_setlink)(struct net_device___47 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___50 *, u32, u32, struct net_device___47 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___47 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___47 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___47 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___47 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___47 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___47 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___50 *, struct net_device___47 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___47 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___47 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___47 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___37 {
	struct net___61 *net;
	struct net_device___47 *dev;
	struct neigh_parms___37 *next;
	int (*neigh_setup)(struct neighbour___37 *);
	void (*neigh_cleanup)(struct neighbour___37 *);
	struct neigh_table___37 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct netpoll___3;

struct netpoll_info___4 {
	atomic_t refcnt;
	long unsigned int rx_flags;
	spinlock_t rx_lock;
	struct semaphore dev_lock;
	struct list_head rx_np;
	struct sk_buff_head___47 neigh_tx;
	struct sk_buff_head___47 txq;
	struct delayed_work tx_work;
	struct netpoll___3 *netpoll;
	struct callback_head rcu;
};

struct in_ifaddr___4;

struct in_device___4 {
	struct net_device___47 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___4 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___37 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct rtnl_link_ops___37 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___47 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___61 *, struct net_device___47 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___47 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___47 *, struct list_head *);
	size_t (*get_size)(const struct net_device___47 *);
	int (*fill_info)(struct sk_buff___50 *, const struct net_device___47 *);
	size_t (*get_xstats_size)(const struct net_device___47 *);
	int (*fill_xstats)(struct sk_buff___50 *, const struct net_device___47 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___61 * (*get_link_net)(const struct net_device___47 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___47 *, struct net_device___47 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___47 *, const struct net_device___47 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___50 *, const struct net_device___47 *, const struct net_device___47 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___4 {
	struct hlist_node hash;
	struct in_ifaddr___4 *ifa_next;
	struct in_device___4 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___3 {
	struct net_device___47 *dev;
	char dev_name[16];
	const char *name;
	void (*rx_hook)(struct netpoll___3 *, int, char *, int);
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct list_head rx;
	struct work_struct cleanup_work;
};

struct perf_cpu_context___85;

struct pmu___85 {
	struct list_head entry;
	struct device___254 *dev;
	const struct attribute_group___216 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___85 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___85 *);
	void (*pmu_disable)(struct pmu___85 *);
	int (*event_init)(struct perf_event___85 *);
	int (*add)(struct perf_event___85 *, int);
	void (*del)(struct perf_event___85 *, int);
	void (*start)(struct perf_event___85 *, int);
	void (*stop)(struct perf_event___85 *, int);
	void (*read)(struct perf_event___85 *);
	void (*start_txn)(struct pmu___85 *);
	int (*commit_txn)(struct pmu___85 *);
	void (*cancel_txn)(struct pmu___85 *);
	int (*event_idx)(struct perf_event___85 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___85 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___85 *);
};

struct perf_cpu_context___85 {
	struct perf_event_context___85 ctx;
	struct perf_event_context___85 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___85 *unique_pmu;
	struct perf_cgroup___85 *cgrp;
};

struct trace_event_functions___74;

struct trace_event___74 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___74 *funcs;
};

struct ftrace_event_class___74;

struct ftrace_event_call___74 {
	struct list_head list;
	struct ftrace_event_class___74 *class;
	char *name;
	struct trace_event___74 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___85 {
	struct cgroup_subsys_state___151 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___74 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___258 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___74)(struct trace_iterator___74 *, int, struct trace_event___74 *);

struct trace_event_functions___74 {
	trace_print_func___74 trace;
	trace_print_func___74 raw;
	trace_print_func___74 hex;
	trace_print_func___74 binary;
};

struct ftrace_event_class___74 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___74 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___74 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___74 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___74 *);
};

struct ftrace_event_file___28 {
	struct list_head list;
	struct ftrace_event_call___74 *event_call;
	struct dentry___256 *dir;
	struct trace_array *tr;
	struct ftrace_subsystem_dir *system;
	long unsigned int flags;
	atomic_t sm_ref;
};

struct ftrace_raw_kfree_skb {
	struct trace_entry ent;
	void *skbaddr;
	void *location;
	short unsigned int protocol;
	char __data[0];
};

struct ftrace_raw_consume_skb {
	struct trace_entry ent;
	void *skbaddr;
	char __data[0];
};

struct ftrace_raw_skb_copy_datagram_iovec {
	struct trace_entry ent;
	const void *skbaddr;
	int len;
	char __data[0];
};

struct ftrace_data_offsets_kfree_skb {};

struct ftrace_data_offsets_consume_skb {};

struct ftrace_data_offsets_skb_copy_datagram_iovec {};

struct ftrace_raw_net_dev_xmit {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	int rc;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_raw_net_dev_template {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	u32 __data_loc_name;
	char __data[0];
};

struct ftrace_data_offsets_net_dev_xmit {
	u32 name;
};

struct ftrace_data_offsets_net_dev_template {
	u32 name;
};

struct ftrace_raw_napi_poll {
	struct trace_entry ent;
	struct napi_struct___46 *napi;
	u32 __data_loc_dev_name;
	char __data[0];
};

struct ftrace_data_offsets_napi_poll {
	u32 dev_name;
};

struct sk_filter___38 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___50 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___37;

struct neigh_hash_table___37;

struct neigh_table___37 {
	struct neigh_table___37 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___47 *, __u32 *);
	int (*constructor)(struct neighbour___37 *);
	int (*pconstructor)(struct pneigh_entry___37 *);
	void (*pdestructor)(struct pneigh_entry___37 *);
	void (*proxy_redo)(struct sk_buff___50 *);
	char *id;
	struct neigh_parms___37 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___47 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___37 *nht;
	struct pneigh_entry___37 **phash_buckets;
};

struct neigh_ops___37 {
	int family;
	void (*solicit)(struct neighbour___37 *, struct sk_buff___50 *);
	void (*error_report)(struct neighbour___37 *, struct sk_buff___50 *);
	int (*output)(struct neighbour___37 *, struct sk_buff___50 *);
	int (*connected_output)(struct neighbour___37 *, struct sk_buff___50 *);
};

struct pneigh_entry___37 {
	struct pneigh_entry___37 *next;
	struct net___61 *net;
	struct net_device___47 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___37 {
	struct neighbour___37 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___37 {
	void (*close)(struct sock___39 *, long int);
	int (*connect)(struct sock___39 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___39 *, int);
	struct sock___39 * (*accept)(struct sock___39 *, int, int *);
	int (*ioctl)(struct sock___39 *, int, long unsigned int);
	int (*init)(struct sock___39 *);
	void (*destroy)(struct sock___39 *);
	void (*shutdown)(struct sock___39 *, int);
	int (*setsockopt)(struct sock___39 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___39 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___39 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___39 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___39 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___45 *, struct sock___39 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___45 *, struct sock___39 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___39 *, struct page___255 *, int, size_t, int);
	int (*bind)(struct sock___39 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___39 *, struct sk_buff___50 *);
	void (*release_cb)(struct sock___39 *);
	void (*mtu_reduced)(struct sock___39 *);
	void (*hash)(struct sock___39 *);
	void (*unhash)(struct sock___39 *);
	void (*rehash)(struct sock___39 *);
	int (*get_port)(struct sock___39 *, short unsigned int);
	void (*clear_sk)(struct sock___39 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___39 *);
	void (*enter_memory_pressure)(struct sock___39 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___239 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___25 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___85 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___37 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___37 {
	void (*enter_memory_pressure)(struct sock___39 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___25 {
	int family;
	int obj_size;
	struct kmem_cache___239 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___39 *, struct request_sock___26 *);
	void (*send_ack)(struct sock___39 *, struct sk_buff___50 *, struct request_sock___26 *);
	void (*send_reset)(struct sock___39 *, struct sk_buff___50 *);
	void (*destructor)(struct request_sock___26 *);
	void (*syn_ack_timeout)(struct sock___39 *, struct request_sock___26 *);
};

struct ftrace_raw_sock_rcvqueue_full {
	struct trace_entry ent;
	int rmem_alloc;
	unsigned int truesize;
	int sk_rcvbuf;
	char __data[0];
};

struct ftrace_raw_sock_exceed_buf_limit {
	struct trace_entry ent;
	char name[32];
	long int *sysctl_mem;
	long int allocated;
	int sysctl_rmem;
	int rmem_alloc;
	char __data[0];
};

struct ftrace_data_offsets_sock_rcvqueue_full {};

struct ftrace_data_offsets_sock_exceed_buf_limit {};

struct inet_cork___4 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___37 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___4 {
	struct inet_cork___4 base;
	struct flowi fl;
};

struct inet_sock___4 {
	struct sock___39 sk;
	struct ipv6_pinfo___3 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___4 cork;
};

struct ftrace_raw_udp_fail_queue_rcv_skb {
	struct trace_entry ent;
	int rc;
	__u16 lport;
	char __data[0];
};

struct ftrace_data_offsets_udp_fail_queue_rcv_skb {};

struct netpoll___4;

struct netpoll_info {
	atomic_t refcnt;
	long unsigned int rx_flags;
	spinlock_t rx_lock;
	struct semaphore dev_lock;
	struct list_head rx_np;
	struct sk_buff_head___22 neigh_tx;
	struct sk_buff_head___22 txq;
	struct delayed_work tx_work;
	struct netpoll___4 *netpoll;
	struct callback_head rcu;
};

struct netpoll___4 {
	struct net_device___3 *dev;
	char dev_name[16];
	const char *name;
	void (*rx_hook)(struct netpoll___4 *, int, char *, int);
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct list_head rx;
	struct work_struct cleanup_work;
};

struct net_dm_drop_point {
	__u8 pc[8];
	__u32 count;
};

struct net_dm_alert_msg {
	__u32 entries;
	struct net_dm_drop_point points[0];
};

enum {
	NET_DM_CMD_UNSPEC = 0,
	NET_DM_CMD_ALERT = 1,
	NET_DM_CMD_CONFIG = 2,
	NET_DM_CMD_START = 3,
	NET_DM_CMD_STOP = 4,
	_NET_DM_CMD_MAX = 5,
};

struct genl_ops___5;

struct genl_info___5;

struct genl_family___5 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___5 *, struct sk_buff___46 *, struct genl_info___5 *);
	void (*post_doit)(const struct genl_ops___5 *, struct sk_buff___46 *, struct genl_info___5 *);
	struct nlattr **attrbuf;
	const struct genl_ops___5 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module___154 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___5 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___46 *, struct genl_info___5 *);
	int (*dumpit)(struct sk_buff___46 *, struct netlink_callback___44 *);
	int (*done)(struct netlink_callback___44 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___5 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___56 *_net;
	void *user_ptr[2];
	struct sock *dst_sk;
};

struct per_cpu_dm_data {
	spinlock_t lock;
	struct sk_buff___46 *skb;
	struct work_struct dm_alert_work;
	struct timer_list send_timer;
};

struct dm_hw_stat_delta {
	struct net_device___3 *dev;
	long unsigned int last_rx;
	struct list_head list;
	struct callback_head rcu;
	long unsigned int last_drop_val;
};

struct page___256;

typedef struct page___256 *pgtable_t___256;

struct address_space___257;

struct kmem_cache___240;

struct page___256 {
	long unsigned int flags;
	struct address_space___257 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___256 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___256 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___240 *slab_cache;
		struct page___256 *first_page;
	};
	long: 64;
};

struct task_struct___258;

struct pv_cpu_ops___258 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___85 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___85 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___258 *);
	void (*end_context_switch)(struct task_struct___258 *);
};

struct mutex___259 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___258 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___251 {
	struct page___256 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___265;

struct nsproxy___137;

struct signal_struct___258;

struct css_set___152;

struct task_struct___258 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___258 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___265 *mm;
	struct mm_struct___265 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___258 *real_parent;
	struct task_struct___258 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___258 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___96 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___258 = 0,
		VTIME_USER___258 = 1,
		VTIME_SYS___258 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___85 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___137 *nsproxy;
	struct signal_struct___258 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___152 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___259 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___251 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___265 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___265 *, struct mm_struct___265 *);
	void (*dup_mmap)(struct mm_struct___265 *, struct mm_struct___265 *);
	void (*exit_mmap)(struct mm_struct___265 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___265 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___265 *);
	void (*pgd_free)(struct mm_struct___265 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___265 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___265 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___265 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___265 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___265 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___265 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___265 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___265 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___265 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___265 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___265 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___259 lock;
	void *vdso;
} mm_context_t___259;

struct xol_area___256;

struct uprobes_state___256 {
	struct xol_area___256 *xol_area;
};

struct vm_area_struct___265;

struct file___257;

struct core_state___258;

struct mm_struct___265 {
	struct vm_area_struct___265 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___265 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___265 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___259 context;
	long unsigned int flags;
	struct core_state___258 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___258 *owner;
	struct file___257 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___256 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___256 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___256 *page;
	long unsigned int vaddr;
};

struct kset___41;

struct kobj_type___41;

struct kobject___41 {
	const char *name;
	struct list_head entry;
	struct kobject___41 *parent;
	struct kset___41 *kset;
	struct kobj_type___41 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___239;

struct memcg_cache_params___240;

struct kmem_cache___240 {
	struct kmem_cache_cpu___239 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___41 kobj;
	struct memcg_cache_params___240 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___257;

struct address_space_operations___257;

struct address_space___257 {
	struct inode___257 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___259 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___257 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___257;

struct path___257 {
	struct vfsmount *mnt;
	struct dentry___257 *dentry;
};

struct file_operations___257;

struct file___257 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___257 f_path;
	struct inode___257 *f_inode;
	const struct file_operations___257 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___96 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___257 *f_mapping;
	struct mutex___259 f_pos_lock;
};

struct vm_operations_struct___231;

struct vm_area_struct___265 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___265 *vm_next;
	struct vm_area_struct___265 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___265 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___231 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___257 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___227;

struct vm_operations_struct___231 {
	void (*open)(struct vm_area_struct___265 *);
	void (*close)(struct vm_area_struct___265 *);
	int (*fault)(struct vm_area_struct___265 *, struct vm_fault___227 *);
	int (*page_mkwrite)(struct vm_area_struct___265 *, struct vm_fault___227 *);
	int (*access)(struct vm_area_struct___265 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___265 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___265 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___265 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___265 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___258 {
	struct task_struct___258 *task;
	struct core_thread___258 *next;
};

struct core_state___258 {
	atomic_t nr_threads;
	struct core_thread___258 dumper;
	struct completion startup;
};

struct fasync_struct___257;

struct socket_wq___38 {
	wait_queue_head_t wait;
	struct fasync_struct___257 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___257 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___257 *fa_next;
	struct file___257 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___40;

struct proto_ops___38;

struct socket___39 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___38 *wq;
	struct file___257 *file;
	struct sock___40 *sk;
	const struct proto_ops___38 *ops;
};

struct proto___38;

struct net___62;

struct sock_common___38 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___38 *skc_prot;
	struct net___62 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___51;

struct sk_buff_head___48 {
	struct sk_buff___51 *next;
	struct sk_buff___51 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___39;

struct dst_entry___38;

struct cg_proto___38;

struct sock___40 {
	struct sock_common___38 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___48 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___51 *head;
		struct sk_buff___51 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___39 *sk_filter;
	struct socket_wq___38 *sk_wq;
	struct sk_buff_head___48 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___38 *sk_rx_dst;
	struct dst_entry___38 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___48 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___48 sk_error_queue;
	struct proto___38 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___96 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___39 *sk_socket;
	void *sk_user_data;
	struct page_frag___251 sk_frag;
	struct sk_buff___51 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___38 *sk_cgrp;
	void (*sk_state_change)(struct sock___40 *);
	void (*sk_data_ready)(struct sock___40 *, int);
	void (*sk_write_space)(struct sock___40 *);
	void (*sk_error_report)(struct sock___40 *);
	int (*sk_backlog_rcv)(struct sock___40 *, struct sk_buff___51 *);
	void (*sk_destruct)(struct sock___40 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___145;

struct kiocb___46;

struct proto_ops___38 {
	int family;
	struct module *owner;
	int (*release)(struct socket___39 *);
	int (*bind)(struct socket___39 *, struct sockaddr *, int);
	int (*connect)(struct socket___39 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___39 *, struct socket___39 *);
	int (*accept)(struct socket___39 *, struct socket___39 *, int);
	int (*getname)(struct socket___39 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___257 *, struct socket___39 *, struct poll_table_struct___145 *);
	int (*ioctl)(struct socket___39 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___39 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___39 *, int);
	int (*shutdown)(struct socket___39 *, int);
	int (*setsockopt)(struct socket___39 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___39 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___39 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___39 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___46 *, struct socket___39 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___46 *, struct socket___39 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___257 *, struct socket___39 *, struct vm_area_struct___265 *);
	ssize_t (*sendpage)(struct socket___39 *, struct page___256 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___39 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___40 *, int);
		struct {
			void (*set_peek_off)(struct sock___40 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___147)(struct file___257 *, wait_queue_head_t *, struct poll_table_struct___145 *);

struct poll_table_struct___145 {
	poll_queue_proc___147 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___46(struct kiocb___46 *, struct io_event *);

struct kiocb___46 {
	atomic_t ki_users;
	struct file___257 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___46 *ki_cancel;
	void (*ki_dtor)(struct kiocb___46 *);
	union {
		void *user;
		struct task_struct___258 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___62;

struct ctl_table_set___62;

struct ctl_dir___62;

struct ctl_node___62;

struct ctl_table_header___62 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___62 *root;
	struct ctl_table_set___62 *set;
	struct ctl_dir___62 *parent;
	struct ctl_node___62 *node;
};

struct ctl_dir___62 {
	struct ctl_table_header___62 header;
	struct rb_root root;
};

struct ctl_table_set___62 {
	int (*is_seen)(struct ctl_table_set___62 *);
	struct ctl_dir___62 dir;
};

struct netns_core___59 {
	struct ctl_table_header___62 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___60 {
	struct mutex___259 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___59 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___62 *ctl;
};

struct netns_ipv4___59 {
	struct ctl_table_header___62 *forw_hdr;
	struct ctl_table_header___62 *frags_hdr;
	struct ctl_table_header___62 *ipv4_hdr;
	struct ctl_table_header___62 *route_hdr;
	struct ctl_table_header___62 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___40 *fibnl;
	struct sock___40 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___59 {
	struct ctl_table_header___62 *hdr;
	struct ctl_table_header___62 *route_hdr;
	struct ctl_table_header___62 *icmp_hdr;
	struct ctl_table_header___62 *frags_hdr;
	struct ctl_table_header___62 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___48;

struct neighbour___38;

struct dst_ops___61 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___61 *);
	struct dst_entry___38 * (*check)(struct dst_entry___38 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___38 *);
	unsigned int (*mtu)(const struct dst_entry___38 *);
	u32 * (*cow_metrics)(struct dst_entry___38 *, long unsigned int);
	void (*destroy)(struct dst_entry___38 *);
	void (*ifdown)(struct dst_entry___38 *, struct net_device___48 *, int);
	struct dst_entry___38 * (*negative_advice)(struct dst_entry___38 *);
	void (*link_failure)(struct sk_buff___51 *);
	void (*update_pmtu)(struct dst_entry___38 *, struct sock___40 *, struct sk_buff___51 *, u32);
	void (*redirect)(struct dst_entry___38 *, struct sock___40 *, struct sk_buff___51 *);
	int (*local_out)(struct sk_buff___51 *);
	struct neighbour___38 * (*neigh_lookup)(const struct dst_entry___38 *, struct sk_buff___51 *, const void *);
	struct kmem_cache___240 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___61 {
	struct netns_sysctl_ipv6___59 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___61 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___40 **icmp_sk;
	struct sock___40 *ndisc_sk;
	struct sock___40 *tcp_sk;
	struct sock___40 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___59 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___62 *sysctl_header;
	struct sock___40 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___38 {
	struct sock___40 *v4_ctl_sk;
	struct sock___40 *v6_ctl_sk;
};

struct netns_nf___59 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___62 *nf_log_dir_header;
};

struct nf_proto_net___59 {
	struct ctl_table_header___62 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___59 {
	struct nf_proto_net___59 pn;
	unsigned int timeout;
};

struct nf_tcp_net___59 {
	struct nf_proto_net___59 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___59 {
	struct nf_proto_net___59 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___59 {
	struct nf_proto_net___59 pn;
	unsigned int timeout;
};

struct nf_ip_net___59 {
	struct nf_generic_net___59 generic;
	struct nf_tcp_net___59 tcp;
	struct nf_udp_net___59 udp;
	struct nf_icmp_net___59 icmp;
	struct nf_icmp_net___59 icmpv6;
};

struct netns_ct___60 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___62 *sysctl_header;
	struct ctl_table_header___62 *acct_sysctl_header;
	struct ctl_table_header___62 *tstamp_sysctl_header;
	struct ctl_table_header___62 *event_sysctl_header;
	struct ctl_table_header___62 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___240 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___59 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___59 {
	struct netns_sysctl_ipv6___59 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___61 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___40 *nlsk;
	struct sock___40 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___62 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___61 xfrm4_dst_ops;
	struct dst_ops___61 xfrm6_dst_ops;
};

struct net___62 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___62 sysctls;
	struct sock___40 *rtnl;
	struct sock___40 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___48 *loopback_dev;
	struct netns_core___59 core;
	struct netns_mib mib;
	struct netns_packet___60 packet;
	struct netns_unix___59 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___59 ipv4;
	struct netns_ipv6___61 ipv6;
	struct netns_sctp___59 sctp;
	struct netns_dccp___38 dccp;
	struct netns_nf___59 nf;
	struct netns_xt xt;
	struct netns_ct___60 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___59 nf_frag;
	struct sock___40 *nfnl;
	struct sock___40 *nfnl_stash;
	struct sk_buff_head___48 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___61 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___40 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___40 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___259 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___259 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___258;

struct lruvec___258 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___258 *zone;
};

struct pglist_data___258;

struct zone___258 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___258 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___258 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___258 {
	struct zone___258 *zone;
	int zone_idx;
};

struct zonelist___258 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___258 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___258 {
	struct zone___258 node_zones[4];
	struct zonelist___258 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___258 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___181;

struct x86_io_apic_ops___181 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___181 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___181;

struct irq_data___181 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___181 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___255;

struct dev_pm_ops___255 {
	int (*prepare)(struct device___255 *);
	void (*complete)(struct device___255 *);
	int (*suspend)(struct device___255 *);
	int (*resume)(struct device___255 *);
	int (*freeze)(struct device___255 *);
	int (*thaw)(struct device___255 *);
	int (*poweroff)(struct device___255 *);
	int (*restore)(struct device___255 *);
	int (*suspend_late)(struct device___255 *);
	int (*resume_early)(struct device___255 *);
	int (*freeze_late)(struct device___255 *);
	int (*thaw_early)(struct device___255 *);
	int (*poweroff_late)(struct device___255 *);
	int (*restore_early)(struct device___255 *);
	int (*suspend_noirq)(struct device___255 *);
	int (*resume_noirq)(struct device___255 *);
	int (*freeze_noirq)(struct device___255 *);
	int (*thaw_noirq)(struct device___255 *);
	int (*poweroff_noirq)(struct device___255 *);
	int (*restore_noirq)(struct device___255 *);
	int (*runtime_suspend)(struct device___255 *);
	int (*runtime_resume)(struct device___255 *);
	int (*runtime_idle)(struct device___255 *);
};

struct dev_pm_qos___58;

struct dev_pm_info___58 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___58 *qos;
};

struct dma_map_ops___120;

struct dev_archdata___120 {
	struct dma_map_ops___120 *dma_ops;
	void *iommu;
};

struct device_type___255;

struct bus_type___255;

struct device_driver___255;

struct dev_pm_domain___255;

struct class___255;

struct attribute_group___217;

struct device_rh___255;

struct device___255 {
	struct device___255 *parent;
	struct device_private *p;
	struct kobject___41 kobj;
	const char *init_name;
	const struct device_type___255 *type;
	struct mutex___259 mutex;
	struct bus_type___255 *bus;
	struct device_driver___255 *driver;
	void *platform_data;
	struct dev_pm_info___58 power;
	struct dev_pm_domain___255 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___120 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___255 *class;
	const struct attribute_group___217 **groups;
	void (*release)(struct device___255 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___255 *device_rh;
};

struct dev_pm_qos_request___59;

struct dev_pm_qos___58 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___59 *latency_req;
	struct dev_pm_qos_request___59 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___59 *latency_tolerance_req;
};

struct dev_pm_info_rh___255 {
	void (*set_latency_tolerance)(struct device___255 *, s32);
};

struct dev_pm_domain___255 {
	struct dev_pm_ops___255 ops;
};

struct smp_ops___258 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___258 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___38 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___40 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___219;

struct attribute_group___217 {
	const char *name;
	umode_t (*is_visible)(struct kobject___41 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___219 **bin_attrs;
};

struct bin_attribute___219 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___257 *, struct kobject___41 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___257 *, struct kobject___41 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	int (*mmap)(struct file___257 *, struct kobject___41 *, struct bin_attribute___219 *, struct vm_area_struct___265 *);
};

struct sysfs_ops___41 {
	ssize_t (*show)(struct kobject___41 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___41 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___41 *, const struct attribute *);
};

struct kset_uevent_ops___41;

struct kset___41 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___41 kobj;
	const struct kset_uevent_ops___41 *uevent_ops;
};

struct kobj_type___41 {
	void (*release)(struct kobject___41 *);
	const struct sysfs_ops___41 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___38 * (*child_ns_type)(struct kobject___41 *);
	const void * (*namespace)(struct kobject___41 *);
};

struct kset_uevent_ops___41 {
	int (* const filter)(struct kset___41 *, struct kobject___41 *);
	const char * (* const name)(struct kset___41 *, struct kobject___41 *);
	int (* const uevent)(struct kset___41 *, struct kobject___41 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___239 {
	void **freelist;
	long unsigned int tid;
	struct page___256 *page;
	struct page___256 *partial;
};

struct memcg_cache_params___240 {
	bool is_root_cache;
	union {
		struct kmem_cache___240 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___240 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___120 {
	void * (*alloc)(struct device___255 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___255 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___255 *, struct vm_area_struct___265 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___255 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___255 *, struct page___256 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___255 *, dma_addr_t);
	int (*dma_supported)(struct device___255 *, u64);
	int (*set_dma_mask)(struct device___255 *, u64);
	int is_phys;
};

struct bus_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___255 *, char *);
	ssize_t (*store)(struct bus_type___255 *, const char *, size_t);
};

struct device_attribute___255;

struct driver_attribute___255;

struct bus_type___255 {
	const char *name;
	const char *dev_name;
	struct device___255 *dev_root;
	struct bus_attribute___255 *bus_attrs;
	struct device_attribute___255 *dev_attrs;
	struct driver_attribute___255 *drv_attrs;
	const struct attribute_group___217 **bus_groups;
	const struct attribute_group___217 **dev_groups;
	const struct attribute_group___217 **drv_groups;
	int (*match)(struct device___255 *, struct device_driver___255 *);
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	int (*probe)(struct device___255 *);
	int (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*online)(struct device___255 *);
	int (*offline)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct device___255 *, struct device_attribute___255 *, char *);
	ssize_t (*store)(struct device___255 *, struct device_attribute___255 *, const char *, size_t);
};

struct driver_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___255 *, char *);
	ssize_t (*store)(struct device_driver___255 *, const char *, size_t);
};

struct device_driver___255 {
	const char *name;
	struct bus_type___255 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___255 *);
	int (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	const struct attribute_group___217 **groups;
	const struct dev_pm_ops___255 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___255 {
	const char *name;
	const struct attribute_group___217 **groups;
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
};

struct class_attribute___255;

struct class___255 {
	const char *name;
	struct module *owner;
	struct class_attribute___255 *class_attrs;
	struct device_attribute___255 *dev_attrs;
	const struct attribute_group___217 **dev_groups;
	struct bin_attribute___219 *dev_bin_attrs;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *);
	void (*class_release)(struct class___255 *);
	void (*dev_release)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	const struct kobj_ns_type_operations___38 *ns_type;
	const void * (*namespace)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
	struct subsys_private *p;
};

struct class_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct class___255 *, struct class_attribute___255 *, char *);
	ssize_t (*store)(struct class___255 *, struct class_attribute___255 *, const char *, size_t);
	const void * (*namespace)(struct class___255 *, const struct class_attribute___255 *);
};

struct device_rh___255 {
	struct dev_pm_info_rh___255 power;
};

struct vm_fault___227 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___256 *page;
};

struct ctl_node___62 {
	struct rb_node node;
	struct ctl_table_header___62 *header;
};

struct ctl_table_root___62 {
	struct ctl_table_set___62 default_set;
	struct ctl_table_set___62 * (*lookup)(struct ctl_table_root___62 *, struct nsproxy___137 *);
	int (*permissions)(struct ctl_table_header___62 *, struct ctl_table *);
};

struct nsproxy___137 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___62 *net_ns;
};

struct signal_struct___258 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___258 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___258 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___96 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___96 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___259 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___152;

struct css_set___152 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___152 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___47 {
	atomic_t use;
	unsigned int mask;
	struct net_device___48 *physindev;
	struct net_device___48 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___47(struct sk_buff___51 **);

struct net_device_ops___47;

struct ethtool_ops___47;

struct header_ops___47;

struct inet6_dev___20;

struct netdev_rx_queue___47;

struct netdev_queue___47;

struct rtnl_link_ops___38;

struct dcbnl_rtnl_ops___47;

struct phy_device___5;

struct net_device___48 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___47 *netdev_ops;
	const struct ethtool_ops___47 *ethtool_ops;
	const struct header_ops___47 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___41 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___20 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___47 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___47 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___47 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___47 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___47 = 0,
		NETREG_REGISTERED___47 = 1,
		NETREG_UNREGISTERING___47 = 2,
		NETREG_UNREGISTERED___47 = 3,
		NETREG_RELEASED___47 = 4,
		NETREG_DUMMY___47 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___47 = 0,
		RTNL_LINK_INITIALIZING___47 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___48 *);
	struct netpoll_info *npinfo;
	struct net___62 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___255 dev;
	const struct attribute_group___217 *sysfs_groups[4];
	const struct rtnl_link_ops___38 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___47 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___5 *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___51 {
	struct sk_buff___51 *next;
	struct sk_buff___51 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___40 *sk;
	struct net_device___48 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___51 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___47 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___7 {
	struct {
		struct page___256 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___7 skb_frag_t___7;

struct skb_shared_info___7 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___51 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___7 frags[17];
};

struct file_lock___257;

struct seq_file___182;

struct file_operations___257 {
	struct module *owner;
	loff_t (*llseek)(struct file___257 *, loff_t, int);
	ssize_t (*read)(struct file___257 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___257 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___46 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___46 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___257 *, void *, filldir_t);
	unsigned int (*poll)(struct file___257 *, struct poll_table_struct___145 *);
	long int (*unlocked_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___257 *, struct vm_area_struct___265 *);
	int (*open)(struct inode___257 *, struct file___257 *);
	int (*flush)(struct file___257 *, fl_owner_t);
	int (*release)(struct inode___257 *, struct file___257 *);
	int (*fsync)(struct file___257 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___46 *, int);
	int (*fasync)(int, struct file___257 *, int);
	int (*lock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*sendpage)(struct file___257 *, struct page___256 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___257 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___257 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___257 *, long int, struct file_lock___257 **, void **);
		struct {
			int (*setlease)(struct file___257 *, long int, struct file_lock___257 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___257 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___182 *, struct file___257 *);
};

struct dev_pm_qos_request___59 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___255 *dev;
};

struct dentry_operations___257;

struct super_block___257;

struct dentry___257 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___257 *d_parent;
	struct qstr d_name;
	struct inode___257 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___257 *d_op;
	struct super_block___257 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___257;

struct dquot___257;

struct block_device___257;

struct inode___257 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___257 *i_op;
	struct super_block___257 *i_sb;
	struct address_space___257 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___259 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___257 *i_fop;
	struct file_lock___257 *i_flock;
	struct address_space___257 i_data;
	struct dquot___257 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___257 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___257 {
	int (*d_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_hash)(const struct dentry___257 *, struct qstr *);
	int (*d_compare)(const struct dentry___257 *, const struct dentry___257 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___257 *);
	void (*d_release)(struct dentry___257 *);
	void (*d_prune)(struct dentry___257 *);
	void (*d_iput)(struct dentry___257 *, struct inode___257 *);
	char * (*d_dname)(struct dentry___257 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___257 *);
	int (*d_manage)(struct dentry___257 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___257;

struct mem_dqinfo___257 {
	struct quota_format_type___257 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___257;

struct quota_info___257 {
	unsigned int flags;
	struct mutex___259 dqio_mutex;
	struct mutex___259 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___257 *files[2];
	struct mem_dqinfo___257 info[2];
	const struct quota_format_ops___257 *ops[2];
};

struct file_system_type___257;

struct super_operations___257;

struct dquot_operations___257;

struct quotactl_ops___257;

struct xattr_handler___153;

struct super_block___257 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___257 *s_type;
	const struct super_operations___257 *s_op;
	const struct dquot_operations___257 *dq_op;
	const struct quotactl_ops___257 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___257 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___153 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___257 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___257 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___259 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___257 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___257 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___257 *bd_inode;
	struct super_block___257 *bd_super;
	struct mutex___259 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___257 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___259 bd_fsfreeze_mutex;
};

struct cgroup___152;

struct cgroup_subsys_state___152 {
	struct cgroup___152 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___257 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___257 *ia_file;
};

struct dquot___257 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___259 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___257 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___257 {
	int qf_fmt_id;
	const struct quota_format_ops___257 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___257 *qf_next;
};

struct quota_format_ops___257 {
	int (*check_quota_file)(struct super_block___257 *, int);
	int (*read_file_info)(struct super_block___257 *, int);
	int (*write_file_info)(struct super_block___257 *, int);
	int (*free_file_info)(struct super_block___257 *, int);
	int (*read_dqblk)(struct dquot___257 *);
	int (*commit_dqblk)(struct dquot___257 *);
	int (*release_dqblk)(struct dquot___257 *);
};

struct dquot_operations___257 {
	int (*write_dquot)(struct dquot___257 *);
	struct dquot___257 * (*alloc_dquot)(struct super_block___257 *, int);
	void (*destroy_dquot)(struct dquot___257 *);
	int (*acquire_dquot)(struct dquot___257 *);
	int (*release_dquot)(struct dquot___257 *);
	int (*mark_dirty)(struct dquot___257 *);
	int (*write_info)(struct super_block___257 *, int);
	qsize_t * (*get_reserved_space)(struct inode___257 *);
};

struct quotactl_ops___257 {
	int (*quota_on)(struct super_block___257 *, int, int, struct path___257 *);
	int (*quota_on_meta)(struct super_block___257 *, int, int);
	int (*quota_off)(struct super_block___257 *, int);
	int (*quota_sync)(struct super_block___257 *, int);
	int (*get_info)(struct super_block___257 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___257 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___257 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___257 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___257 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___257 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___257 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___257 *, unsigned int);
};

struct address_space_operations___257 {
	int (*writepage)(struct page___256 *, struct writeback_control *);
	int (*readpage)(struct file___257 *, struct page___256 *);
	int (*writepages)(struct address_space___257 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___256 *);
	int (*readpages)(struct file___257 *, struct address_space___257 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___257 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___256 **, void **);
	int (*write_end)(struct file___257 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___256 *, void *);
	sector_t (*bmap)(struct address_space___257 *, sector_t);
	void (*invalidatepage)(struct page___256 *, long unsigned int);
	int (*releasepage)(struct page___256 *, gfp_t);
	void (*freepage)(struct page___256 *);
	ssize_t (*direct_IO)(int, struct kiocb___46 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___257 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___257 *, struct page___256 *, struct page___256 *, enum migrate_mode);
	int (*launder_page)(struct page___256 *);
	int (*is_partially_uptodate)(struct page___256 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___256 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___257 *, struct page___256 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___257 *, sector_t *);
	void (*swap_deactivate)(struct file___257 *);
	void (*invalidatepage_range)(struct page___256 *, unsigned int, unsigned int);
};

struct inode_operations___257 {
	struct dentry___257 * (*lookup)(struct inode___257 *, struct dentry___257 *, unsigned int);
	void * (*follow_link)(struct dentry___257 *, struct nameidata *);
	int (*permission)(struct inode___257 *, int);
	struct posix_acl * (*get_acl)(struct inode___257 *, int);
	int (*readlink)(struct dentry___257 *, char *, int);
	void (*put_link)(struct dentry___257 *, struct nameidata *, void *);
	int (*create)(struct inode___257 *, struct dentry___257 *, umode_t, bool);
	int (*link)(struct dentry___257 *, struct inode___257 *, struct dentry___257 *);
	int (*unlink)(struct inode___257 *, struct dentry___257 *);
	int (*symlink)(struct inode___257 *, struct dentry___257 *, const char *);
	int (*mkdir)(struct inode___257 *, struct dentry___257 *, umode_t);
	int (*rmdir)(struct inode___257 *, struct dentry___257 *);
	int (*mknod)(struct inode___257 *, struct dentry___257 *, umode_t, dev_t);
	int (*rename)(struct inode___257 *, struct dentry___257 *, struct inode___257 *, struct dentry___257 *);
	int (*setattr)(struct dentry___257 *, struct iattr___257 *);
	int (*getattr)(struct vfsmount *, struct dentry___257 *, struct kstat *);
	int (*setxattr)(struct dentry___257 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___257 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___257 *, char *, size_t);
	int (*removexattr)(struct dentry___257 *, const char *);
	int (*fiemap)(struct inode___257 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___257 *, struct timespec *, int);
	int (*atomic_open)(struct inode___257 *, struct dentry___257 *, struct file___257 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___257;

struct lock_manager_operations___257;

struct file_lock___257 {
	struct file_lock___257 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___96 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___257 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___257 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___257 *fl_ops;
	const struct lock_manager_operations___257 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___257 {
	void (*fl_copy_lock)(struct file_lock___257 *, struct file_lock___257 *);
	void (*fl_release_private)(struct file_lock___257 *);
};

struct lock_manager_operations___257 {
	int (*lm_compare_owner)(struct file_lock___257 *, struct file_lock___257 *);
	long unsigned int (*lm_owner_key)(struct file_lock___257 *);
	void (*lm_notify)(struct file_lock___257 *);
	int (*lm_grant)(struct file_lock___257 *, struct file_lock___257 *, int);
	void (*lm_break)(struct file_lock___257 *);
	int (*lm_change)(struct file_lock___257 **, int);
};

struct file_system_type___257 {
	const char *name;
	int fs_flags;
	struct dentry___257 * (*mount)(struct file_system_type___257 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___257 *);
	struct module *owner;
	struct file_system_type___257 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___257 {
	struct inode___257 * (*alloc_inode)(struct super_block___257 *);
	void (*destroy_inode)(struct inode___257 *);
	void (*dirty_inode)(struct inode___257 *, int);
	int (*write_inode)(struct inode___257 *, struct writeback_control *);
	int (*drop_inode)(struct inode___257 *);
	void (*evict_inode)(struct inode___257 *);
	void (*put_super)(struct super_block___257 *);
	int (*sync_fs)(struct super_block___257 *, int);
	int (*freeze_fs)(struct super_block___257 *);
	int (*unfreeze_fs)(struct super_block___257 *);
	int (*statfs)(struct dentry___257 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___257 *, int *, char *);
	void (*umount_begin)(struct super_block___257 *);
	int (*show_options)(struct seq_file___182 *, struct dentry___257 *);
	int (*show_devname)(struct seq_file___182 *, struct dentry___257 *);
	int (*show_path)(struct seq_file___182 *, struct dentry___257 *);
	int (*show_stats)(struct seq_file___182 *, struct dentry___257 *);
	ssize_t (*quota_read)(struct super_block___257 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___257 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___257 *);
	int (*bdev_try_to_free_page)(struct super_block___257 *, struct page___256 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___257 *);
	void (*free_cached_objects)(struct super_block___257 *, int);
};

struct xattr_handler___153 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___257 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___257 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___257 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___182;

struct seq_file___182 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___259 lock;
	const struct seq_operations___182 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___47 {
	int (*get_settings)(struct net_device___48 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___48 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___48 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___48 *);
	void (*get_regs)(struct net_device___48 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___48 *);
	void (*set_msglevel)(struct net_device___48 *, u32);
	int (*nway_reset)(struct net_device___48 *);
	u32 (*get_link)(struct net_device___48 *);
	int (*get_eeprom_len)(struct net_device___48 *);
	int (*get_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___48 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___48 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___48 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___48 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___48 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___48 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___48 *);
	void (*complete)(struct net_device___48 *);
	u32 (*get_priv_flags)(struct net_device___48 *);
	int (*set_priv_flags)(struct net_device___48 *, u32);
	int (*get_sset_count)(struct net_device___48 *, int);
	int (*get_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___48 *, struct ethtool_flash *);
	int (*reset)(struct net_device___48 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___48 *);
	int (*get_rxfh_indir)(struct net_device___48 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___48 *, const u32 *);
	void (*get_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___48 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___48 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___48 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___48 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___48 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___48 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___48 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___48 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___15;

struct dst_entry___38 {
	struct callback_head callback_head;
	struct dst_entry___38 *child;
	struct net_device___48 *dev;
	struct dst_ops___61 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___38 *path;
	struct dst_entry___38 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___51 *);
	union {
		int (*output)(struct sock___40 *, struct sk_buff___51 *);
		struct {
			int (*output)(struct sk_buff___51 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___38 *next;
		struct rtable___15 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___38;

struct neigh_parms___38;

struct neigh_ops___38;

struct neighbour___38 {
	struct neighbour___38 *next;
	struct neigh_table___38 *tbl;
	struct neigh_parms___38 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___48 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___38 *, struct sk_buff___51 *);
	const struct neigh_ops___38 *ops;
	struct callback_head rcu;
	struct net_device___48 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___61 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___51 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___51 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___62 *, struct dst_entry___38 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___51 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___51 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___181 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___181 *);
	void (*irq_shutdown)(struct irq_data___181 *);
	void (*irq_enable)(struct irq_data___181 *);
	void (*irq_disable)(struct irq_data___181 *);
	void (*irq_ack)(struct irq_data___181 *);
	void (*irq_mask)(struct irq_data___181 *);
	void (*irq_mask_ack)(struct irq_data___181 *);
	void (*irq_unmask)(struct irq_data___181 *);
	void (*irq_eoi)(struct irq_data___181 *);
	int (*irq_set_affinity)(struct irq_data___181 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___181 *);
	int (*irq_set_type)(struct irq_data___181 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___181 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___181 *);
	void (*irq_bus_sync_unlock)(struct irq_data___181 *);
	void (*irq_cpu_online)(struct irq_data___181 *);
	void (*irq_cpu_offline)(struct irq_data___181 *);
	void (*irq_suspend)(struct irq_data___181 *);
	void (*irq_resume)(struct irq_data___181 *);
	void (*irq_pm_shutdown)(struct irq_data___181 *);
	void (*irq_print_chip)(struct irq_data___181 *, struct seq_file___182 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___181 *, void *);
	long unsigned int flags;
};

struct seq_operations___182 {
	void * (*start)(struct seq_file___182 *, loff_t *);
	void (*stop)(struct seq_file___182 *, void *);
	void * (*next)(struct seq_file___182 *, void *, loff_t *);
	int (*show)(struct seq_file___182 *, void *);
};

struct mii_bus___5 {
	const char *name;
	char id[17];
	void *priv;
	int (*read)(struct mii_bus___5 *, int, int);
	int (*write)(struct mii_bus___5 *, int, int, u16);
	int (*reset)(struct mii_bus___5 *);
	struct mutex___259 mdio_lock;
	struct device___255 *parent;
	enum {
		MDIOBUS_ALLOCATED___5 = 1,
		MDIOBUS_REGISTERED___5 = 2,
		MDIOBUS_UNREGISTERED___5 = 3,
		MDIOBUS_RELEASED___5 = 4,
	} state;
	struct device___255 dev;
	struct phy_device___5 *phy_map[32];
	u32 phy_mask;
	int *irq;
};

struct dcbnl_rtnl_ops___47 {
	int (*ieee_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___48 *);
	u8 (*setstate)(struct net_device___48 *, u8);
	void (*getpermhwaddr)(struct net_device___48 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___48 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___48 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___48 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___48 *, int, u8 *);
	void (*setpfccfg)(struct net_device___48 *, int, u8);
	void (*getpfccfg)(struct net_device___48 *, int, u8 *);
	u8 (*setall)(struct net_device___48 *);
	u8 (*getcap)(struct net_device___48 *, int, u8 *);
	int (*getnumtcs)(struct net_device___48 *, int, u8 *);
	int (*setnumtcs)(struct net_device___48 *, int, u8);
	u8 (*getpfcstate)(struct net_device___48 *);
	void (*setpfcstate)(struct net_device___48 *, u8);
	void (*getbcncfg)(struct net_device___48 *, int, u32 *);
	void (*setbcncfg)(struct net_device___48 *, int, u32);
	void (*getbcnrp)(struct net_device___48 *, int, u8 *);
	void (*setbcnrp)(struct net_device___48 *, int, u8);
	u8 (*setapp)(struct net_device___48 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___48 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___48 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___48 *, int, u8);
	u8 (*getdcbx)(struct net_device___48 *);
	u8 (*setdcbx)(struct net_device___48 *, u8);
	int (*peer_getappinfo)(struct net_device___48 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___48 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___48 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___48 *, struct cee_pfc *);
};

struct cgroupfs_root___152;

struct cgroup___152 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___152 *parent;
	struct dentry___257 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___152 *subsys[11];
	struct cgroupfs_root___152 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___259 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___152 {
	struct super_block___257 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___152 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___90 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___257 *, struct file___257 *);
	ssize_t (*read)(struct cgroup___152 *, struct cftype___90 *, struct file___257 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___152 *, struct cftype___90 *);
	s64 (*read_s64)(struct cgroup___152 *, struct cftype___90 *);
	int (*read_map)(struct cgroup___152 *, struct cftype___90 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___152 *, struct cftype___90 *, struct seq_file___182 *);
	ssize_t (*write)(struct cgroup___152 *, struct cftype___90 *, struct file___257 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___152 *, struct cftype___90 *, u64);
	int (*write_s64)(struct cgroup___152 *, struct cftype___90 *, s64);
	int (*write_string)(struct cgroup___152 *, struct cftype___90 *, const char *);
	int (*trigger)(struct cgroup___152 *, unsigned int);
	int (*release)(struct inode___257 *, struct file___257 *);
	int (*register_event)(struct cgroup___152 *, struct cftype___90 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___152 *, struct cftype___90 *, struct eventfd_ctx *);
};

struct cftype_set___86 {
	struct list_head node;
	struct cftype___90 *cfts;
};

struct task_and_cgroup___86 {
	struct task_struct___258 *task;
	struct cgroup___152 *cgrp;
	struct css_set___152 *cg;
};

struct cgroup_taskset___86 {
	struct task_and_cgroup___86 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___152 *cur_cgrp;
};

struct cgroup_subsys___86 {
	struct cgroup_subsys_state___152 * (*css_alloc)(struct cgroup___152 *);
	int (*css_online)(struct cgroup___152 *);
	void (*css_offline)(struct cgroup___152 *);
	void (*css_free)(struct cgroup___152 *);
	int (*can_attach)(struct cgroup___152 *, struct cgroup_taskset___86 *);
	void (*cancel_attach)(struct cgroup___152 *, struct cgroup_taskset___86 *);
	void (*attach)(struct cgroup___152 *, struct cgroup_taskset___86 *);
	void (*fork)(struct task_struct___258 *);
	void (*exit)(struct cgroup___152 *, struct cgroup___152 *, struct task_struct___258 *);
	void (*bind)(struct cgroup___152 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___152 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___90 *base_cftypes;
	struct cftype_set___86 base_cftset;
	struct module *module;
};

struct request_sock_ops___26;

struct request_sock___27 {
	struct sock_common___38 __req_common;
	struct request_sock___27 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___26 *rsk_ops;
	struct sock___40 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___49 {
	struct sk_buff___51 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___51 *, struct netlink_callback___49 *);
	int (*done)(struct netlink_callback___49 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___47 {
	int (*create)(struct sk_buff___51 *, struct net_device___48 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___51 *, unsigned char *);
	int (*rebuild)(struct sk_buff___51 *);
	int (*cache)(const struct neighbour___38 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___48 *, const unsigned char *);
};

struct napi_struct___47 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___47 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___48 *dev;
	struct sk_buff___51 *gro_list;
	struct sk_buff___51 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___47 {
	struct net_device___48 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___41 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___47 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___41 kobj;
	struct net_device___48 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___47 {
	int (*ndo_init)(struct net_device___48 *);
	void (*ndo_uninit)(struct net_device___48 *);
	int (*ndo_open)(struct net_device___48 *);
	int (*ndo_stop)(struct net_device___48 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___51 *, struct net_device___48 *);
	u16 (*ndo_select_queue)(struct net_device___48 *, struct sk_buff___51 *);
	void (*ndo_change_rx_flags)(struct net_device___48 *, int);
	void (*ndo_set_rx_mode)(struct net_device___48 *);
	int (*ndo_set_mac_address)(struct net_device___48 *, void *);
	int (*ndo_validate_addr)(struct net_device___48 *);
	int (*ndo_do_ioctl)(struct net_device___48 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___48 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___48 *, int);
	int (*ndo_neigh_setup)(struct net_device___48 *, struct neigh_parms___38 *);
	void (*ndo_tx_timeout)(struct net_device___48 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___48 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___48 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___48 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___48 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___48 *);
	int (*ndo_netpoll_setup)(struct net_device___48 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___48 *);
	int (*ndo_busy_poll)(struct napi_struct___47 *);
	int (*ndo_set_vf_mac)(struct net_device___48 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___48 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___48 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___48 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___48 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___48 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___48 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___48 *, int, struct sk_buff___51 *);
	int (*ndo_setup_tc)(struct net_device___48 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___48 *);
	int (*ndo_fcoe_disable)(struct net_device___48 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___48 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___48 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___48 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___48 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___48 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___48 *, const struct sk_buff___51 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___48 *, struct net_device___48 *);
	int (*ndo_del_slave)(struct net_device___48 *, struct net_device___48 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___38 *);
	void (*ndo_neigh_destroy)(struct neighbour___38 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___51 *, struct netlink_callback___49 *, struct net_device___48 *, int);
	int (*ndo_bridge_setlink)(struct net_device___48 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___51 *, u32, u32, struct net_device___48 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___48 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___48 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___48 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___48 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___48 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___48 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___51 *, struct net_device___48 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___48 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___48 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___48 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___38 {
	struct net___62 *net;
	struct net_device___48 *dev;
	struct neigh_parms___38 *next;
	int (*neigh_setup)(struct neighbour___38 *);
	void (*neigh_cleanup)(struct neighbour___38 *);
	struct neigh_table___38 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___20;

struct ifacaddr6___20;

struct inet6_dev___20 {
	struct net_device___48 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___20 *mc_list;
	struct ifmcaddr6___20 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___20 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___38 *nd_parms;
	struct inet6_dev___20 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___38 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___48 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___62 *, struct net_device___48 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___48 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___48 *, struct list_head *);
	size_t (*get_size)(const struct net_device___48 *);
	int (*fill_info)(struct sk_buff___51 *, const struct net_device___48 *);
	size_t (*get_xstats_size)(const struct net_device___48 *);
	int (*fill_xstats)(struct sk_buff___51 *, const struct net_device___48 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___62 * (*get_link_net)(const struct net_device___48 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___48 *, struct net_device___48 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___48 *, const struct net_device___48 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___51 *, const struct net_device___48 *, const struct net_device___48 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct phy_driver___5;

struct phy_device___5 {
	struct phy_driver___5 *drv;
	struct mii_bus___5 *bus;
	struct device___255 dev;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	bool is_c45;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int addr;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	int link;
	u32 interrupts;
	u32 supported;
	u32 advertising;
	int autoneg;
	int link_timeout;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	atomic_t irq_disable;
	struct mutex___259 lock;
	struct net_device___48 *attached_dev;
	void (*adjust_link)(struct net_device___48 *);
	void (*adjust_state)(struct net_device___48 *);
};

struct sk_filter___39 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___51 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___38;

struct neigh_hash_table___38;

struct neigh_table___38 {
	struct neigh_table___38 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___48 *, __u32 *);
	int (*constructor)(struct neighbour___38 *);
	int (*pconstructor)(struct pneigh_entry___38 *);
	void (*pdestructor)(struct pneigh_entry___38 *);
	void (*proxy_redo)(struct sk_buff___51 *);
	char *id;
	struct neigh_parms___38 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___48 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___38 *nht;
	struct pneigh_entry___38 **phash_buckets;
};

struct neigh_ops___38 {
	int family;
	void (*solicit)(struct neighbour___38 *, struct sk_buff___51 *);
	void (*error_report)(struct neighbour___38 *, struct sk_buff___51 *);
	int (*output)(struct neighbour___38 *, struct sk_buff___51 *);
	int (*connected_output)(struct neighbour___38 *, struct sk_buff___51 *);
};

struct pneigh_entry___38 {
	struct pneigh_entry___38 *next;
	struct net___62 *net;
	struct net_device___48 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___38 {
	struct neighbour___38 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___15 {
	struct dst_entry___38 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___23;

struct proto___38 {
	void (*close)(struct sock___40 *, long int);
	int (*connect)(struct sock___40 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___40 *, int);
	struct sock___40 * (*accept)(struct sock___40 *, int, int *);
	int (*ioctl)(struct sock___40 *, int, long unsigned int);
	int (*init)(struct sock___40 *);
	void (*destroy)(struct sock___40 *);
	void (*shutdown)(struct sock___40 *, int);
	int (*setsockopt)(struct sock___40 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___40 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___40 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___40 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___40 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___46 *, struct sock___40 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___46 *, struct sock___40 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___40 *, struct page___256 *, int, size_t, int);
	int (*bind)(struct sock___40 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___40 *, struct sk_buff___51 *);
	void (*release_cb)(struct sock___40 *);
	void (*mtu_reduced)(struct sock___40 *);
	void (*hash)(struct sock___40 *);
	void (*unhash)(struct sock___40 *);
	void (*rehash)(struct sock___40 *);
	int (*get_port)(struct sock___40 *, short unsigned int);
	void (*clear_sk)(struct sock___40 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___40 *);
	void (*enter_memory_pressure)(struct sock___40 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___240 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___26 *rsk_prot;
	struct timewait_sock_ops___23 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___86 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___38 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___38 {
	void (*enter_memory_pressure)(struct sock___40 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___26 {
	int family;
	int obj_size;
	struct kmem_cache___240 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___40 *, struct request_sock___27 *);
	void (*send_ack)(struct sock___40 *, struct sk_buff___51 *, struct request_sock___27 *);
	void (*send_reset)(struct sock___40 *, struct sk_buff___51 *);
	void (*destructor)(struct request_sock___27 *);
	void (*syn_ack_timeout)(struct sock___40 *, struct request_sock___27 *);
};

struct timewait_sock_ops___23 {
	struct kmem_cache___240 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___40 *, struct sock___40 *, void *);
	void (*twsk_destructor)(struct sock___40 *);
};

struct ifmcaddr6___20 {
	struct in6_addr mca_addr;
	struct inet6_dev___20 *idev;
	struct ifmcaddr6___20 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___20 {
	struct in6_addr aca_addr;
	struct inet6_dev___20 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___20 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct phy_driver___5 {
	u32 phy_id;
	char *name;
	unsigned int phy_id_mask;
	u32 features;
	u32 flags;
	int (*config_init)(struct phy_device___5 *);
	int (*probe)(struct phy_device___5 *);
	int (*suspend)(struct phy_device___5 *);
	int (*resume)(struct phy_device___5 *);
	int (*config_aneg)(struct phy_device___5 *);
	int (*read_status)(struct phy_device___5 *);
	int (*ack_interrupt)(struct phy_device___5 *);
	int (*config_intr)(struct phy_device___5 *);
	int (*did_interrupt)(struct phy_device___5 *);
	void (*remove)(struct phy_device___5 *);
	int (*match_phy_device)(struct phy_device___5 *);
	int (*ts_info)(struct phy_device___5 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___5 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___5 *, struct sk_buff___51 *, int);
	void (*txtstamp)(struct phy_device___5 *, struct sk_buff___51 *, int);
	int (*set_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	struct device_driver___255 driver;
};

struct page___257;

typedef struct page___257 *pgtable_t___257;

struct address_space___258;

struct kmem_cache___241;

struct page___257 {
	long unsigned int flags;
	struct address_space___258 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___257 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___257 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___241 *slab_cache;
		struct page___257 *first_page;
	};
	long: 64;
};

struct thread_struct___86;

struct task_struct___259;

struct pv_cpu_ops___259 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___259 *);
	void (*end_context_switch)(struct task_struct___259 *);
};

struct perf_event___86;

struct thread_struct___86 {
	struct desc_struct tls_array[3];
	long unsigned int sp0;
	long unsigned int sp;
	long unsigned int usersp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fs;
	long unsigned int gs;
	struct perf_event___86 *ptrace_bps[4];
	long unsigned int debugreg6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct fpu fpu;
	long unsigned int *io_bitmap_ptr;
	long unsigned int iopl;
	unsigned int io_bitmap_max;
};

struct pid___97;

struct pid_link___97 {
	struct hlist_node node;
	struct pid___97 *pid;
};

struct mutex___260 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___259 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___252 {
	struct page___257 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___266;

struct nsproxy___138;

struct signal_struct___259;

struct css_set___153;

struct perf_event_context___86;

struct task_struct___259 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___259 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___266 *mm;
	struct mm_struct___266 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___259 *real_parent;
	struct task_struct___259 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___259 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___259 = 0,
		VTIME_USER___259 = 1,
		VTIME_SYS___259 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___138 *nsproxy;
	struct signal_struct___259 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___153 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___86 *perf_event_ctxp[2];
	struct mutex___260 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___252 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___266 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___266 *, struct mm_struct___266 *);
	void (*dup_mmap)(struct mm_struct___266 *, struct mm_struct___266 *);
	void (*exit_mmap)(struct mm_struct___266 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___266 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___266 *);
	void (*pgd_free)(struct mm_struct___266 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___266 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___266 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___266 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___266 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___266 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___266 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___266 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___266 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___266 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___266 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___266 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___260 lock;
	void *vdso;
} mm_context_t___260;

struct xol_area___257;

struct uprobes_state___257 {
	struct xol_area___257 *xol_area;
};

struct vm_area_struct___266;

struct file___258;

struct core_state___259;

struct mm_struct___266 {
	struct vm_area_struct___266 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___266 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___266 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___260 context;
	long unsigned int flags;
	struct core_state___259 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___259 *owner;
	struct file___258 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___257 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hw_perf_event___86 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct task_struct___259 *rh_reserved_tp_target;
			struct list_head tp_list;
		};
		struct {
			int cqm_state;
			u32 cqm_rmid;
			struct list_head cqm_events_entry;
			struct list_head cqm_groups_entry;
			struct list_head cqm_group_entry;
		};
		struct {
			struct task_struct___259 *rh_reserved_bp_target;
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
	};
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
	struct event_constraint *constraint;
	struct task_struct___259 *target;
};

typedef void (*perf_overflow_handler_t___86)(struct perf_event___86 *, struct perf_sample_data___8 *, struct pt_regs *);

struct ftrace_ops___86;

typedef void (*ftrace_func_t___86)(long unsigned int, long unsigned int, struct ftrace_ops___86 *, struct pt_regs *);

struct ftrace_ops___86 {
	ftrace_func_t___86 func;
	struct ftrace_ops___86 *next;
	long unsigned int flags;
	int *disabled;
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex___260 regex_lock;
};

struct pmu___86;

struct fasync_struct___258;

struct pid_namespace___97;

struct ftrace_event_call___75;

struct perf_cgroup___86;

struct perf_event___86 {
	struct list_head group_entry;
	struct list_head event_entry;
	struct list_head sibling_list;
	struct hlist_node hlist_entry;
	int nr_siblings;
	int group_flags;
	struct perf_event___86 *group_leader;
	struct pmu___86 *pmu;
	enum perf_event_active_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp_enabled;
	u64 tstamp_running;
	u64 tstamp_stopped;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___86 hw;
	struct perf_event_context___86 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex___260 child_mutex;
	struct list_head child_list;
	struct perf_event___86 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___259 *owner;
	struct mutex___260 mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	wait_queue_head_t waitq;
	struct fasync_struct___258 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	void (*destroy)(struct perf_event___86 *);
	struct callback_head callback_head;
	struct pid_namespace___97 *ns;
	u64 id;
	perf_overflow_handler_t___86 overflow_handler;
	void *overflow_handler_context;
	struct ftrace_event_call___75 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops___86 ftrace_ops;
	struct perf_cgroup___86 *cgrp;
	int cgrp_defer_enabled;
	struct list_head migrate_entry;
	struct list_head active_entry;
};

struct thread_info___118 {
	struct task_struct___259 *task;
	struct exec_domain___71 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___259;

struct lruvec___259 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___259 *zone;
};

struct pglist_data___259;

struct zone___259 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___259 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___259 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___259 {
	struct zone___259 *zone;
	int zone_idx;
};

struct zonelist___259 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___259 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___259 {
	struct zone___259 node_zones[4];
	struct zonelist___259 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___259 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___182;

struct x86_io_apic_ops___182 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___182 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___182;

struct irq_data___182 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___182 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___256;

struct dev_pm_ops___256 {
	int (*prepare)(struct device___256 *);
	void (*complete)(struct device___256 *);
	int (*suspend)(struct device___256 *);
	int (*resume)(struct device___256 *);
	int (*freeze)(struct device___256 *);
	int (*thaw)(struct device___256 *);
	int (*poweroff)(struct device___256 *);
	int (*restore)(struct device___256 *);
	int (*suspend_late)(struct device___256 *);
	int (*resume_early)(struct device___256 *);
	int (*freeze_late)(struct device___256 *);
	int (*thaw_early)(struct device___256 *);
	int (*poweroff_late)(struct device___256 *);
	int (*restore_early)(struct device___256 *);
	int (*suspend_noirq)(struct device___256 *);
	int (*resume_noirq)(struct device___256 *);
	int (*freeze_noirq)(struct device___256 *);
	int (*thaw_noirq)(struct device___256 *);
	int (*poweroff_noirq)(struct device___256 *);
	int (*restore_noirq)(struct device___256 *);
	int (*runtime_suspend)(struct device___256 *);
	int (*runtime_resume)(struct device___256 *);
	int (*runtime_idle)(struct device___256 *);
};

struct kset___42;

struct kobj_type___42;

struct kobject___42 {
	const char *name;
	struct list_head entry;
	struct kobject___42 *parent;
	struct kset___42 *kset;
	struct kobj_type___42 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___59;

struct dev_pm_info___59 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___59 *qos;
};

struct dma_map_ops___121;

struct dev_archdata___121 {
	struct dma_map_ops___121 *dma_ops;
	void *iommu;
};

struct device_type___256;

struct bus_type___256;

struct device_driver___256;

struct dev_pm_domain___256;

struct class___256;

struct attribute_group___218;

struct device_rh___256;

struct device___256 {
	struct device___256 *parent;
	struct device_private *p;
	struct kobject___42 kobj;
	const char *init_name;
	const struct device_type___256 *type;
	struct mutex___260 mutex;
	struct bus_type___256 *bus;
	struct device_driver___256 *driver;
	void *platform_data;
	struct dev_pm_info___59 power;
	struct dev_pm_domain___256 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___121 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___256 *class;
	const struct attribute_group___218 **groups;
	void (*release)(struct device___256 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___256 *device_rh;
};

struct dev_pm_qos_request___60;

struct dev_pm_qos___59 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___60 *latency_req;
	struct dev_pm_qos_request___60 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___60 *latency_tolerance_req;
};

struct dev_pm_info_rh___256 {
	void (*set_latency_tolerance)(struct device___256 *, s32);
};

struct dev_pm_domain___256 {
	struct dev_pm_ops___256 ops;
};

struct smp_ops___259 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___259 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct inode___258;

struct dentry_operations___258;

struct super_block___258;

struct dentry___258 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___258 *d_parent;
	struct qstr d_name;
	struct inode___258 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___258 *d_op;
	struct super_block___258 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___258;

struct address_space___258 {
	struct inode___258 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___260 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___258 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___258;

struct file_operations___258;

struct file_lock___258;

struct dquot___258;

struct block_device___258;

struct inode___258 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___258 *i_op;
	struct super_block___258 *i_sb;
	struct address_space___258 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___260 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___258 *i_fop;
	struct file_lock___258 *i_flock;
	struct address_space___258 i_data;
	struct dquot___258 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___258 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___258;

struct dentry_operations___258 {
	int (*d_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_hash)(const struct dentry___258 *, struct qstr *);
	int (*d_compare)(const struct dentry___258 *, const struct dentry___258 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___258 *);
	void (*d_release)(struct dentry___258 *);
	void (*d_prune)(struct dentry___258 *);
	void (*d_iput)(struct dentry___258 *, struct inode___258 *);
	char * (*d_dname)(struct dentry___258 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___258 *);
	int (*d_manage)(struct dentry___258 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___258;

struct mem_dqinfo___258 {
	struct quota_format_type___258 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___258;

struct quota_info___258 {
	unsigned int flags;
	struct mutex___260 dqio_mutex;
	struct mutex___260 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___258 *files[2];
	struct mem_dqinfo___258 info[2];
	const struct quota_format_ops___258 *ops[2];
};

struct file_system_type___258;

struct super_operations___258;

struct dquot_operations___258;

struct quotactl_ops___258;

struct xattr_handler___154;

struct super_block___258 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___258 *s_type;
	const struct super_operations___258 *s_op;
	const struct dquot_operations___258 *dq_op;
	const struct quotactl_ops___258 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___258 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___154 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___258 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___258 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___260 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___258 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___258 {
	struct vfsmount *mnt;
	struct dentry___258 *dentry;
};

struct upid___97 {
	int nr;
	struct pid_namespace___97 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___97 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___259 *child_reaper;
	struct kmem_cache___241 *pid_cachep;
	unsigned int level;
	struct pid_namespace___97 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___258 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___97 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___97 numbers[1];
};

struct block_device___258 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___258 *bd_inode;
	struct super_block___258 *bd_super;
	struct mutex___260 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___258 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___260 bd_fsfreeze_mutex;
};

struct cgroup___153;

struct cgroup_subsys_state___153 {
	struct cgroup___153 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___47;

typedef int kiocb_cancel_fn___47(struct kiocb___47 *, struct io_event *);

struct kiocb___47 {
	atomic_t ki_users;
	struct file___258 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___47 *ki_cancel;
	void (*ki_dtor)(struct kiocb___47 *);
	union {
		void *user;
		struct task_struct___259 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___258 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___258 *ia_file;
};

struct fown_struct___97 {
	rwlock_t lock;
	struct pid___97 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___258 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___258 f_path;
	struct inode___258 *f_inode;
	const struct file_operations___258 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___258 *f_mapping;
	struct mutex___260 f_pos_lock;
};

struct dquot___258 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___260 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___258 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___258 {
	int qf_fmt_id;
	const struct quota_format_ops___258 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___258 *qf_next;
};

struct quota_format_ops___258 {
	int (*check_quota_file)(struct super_block___258 *, int);
	int (*read_file_info)(struct super_block___258 *, int);
	int (*write_file_info)(struct super_block___258 *, int);
	int (*free_file_info)(struct super_block___258 *, int);
	int (*read_dqblk)(struct dquot___258 *);
	int (*commit_dqblk)(struct dquot___258 *);
	int (*release_dqblk)(struct dquot___258 *);
};

struct dquot_operations___258 {
	int (*write_dquot)(struct dquot___258 *);
	struct dquot___258 * (*alloc_dquot)(struct super_block___258 *, int);
	void (*destroy_dquot)(struct dquot___258 *);
	int (*acquire_dquot)(struct dquot___258 *);
	int (*release_dquot)(struct dquot___258 *);
	int (*mark_dirty)(struct dquot___258 *);
	int (*write_info)(struct super_block___258 *, int);
	qsize_t * (*get_reserved_space)(struct inode___258 *);
};

struct quotactl_ops___258 {
	int (*quota_on)(struct super_block___258 *, int, int, struct path___258 *);
	int (*quota_on_meta)(struct super_block___258 *, int, int);
	int (*quota_off)(struct super_block___258 *, int);
	int (*quota_sync)(struct super_block___258 *, int);
	int (*get_info)(struct super_block___258 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___258 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___258 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___258 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___258 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___258 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___258 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___258 *, unsigned int);
};

struct address_space_operations___258 {
	int (*writepage)(struct page___257 *, struct writeback_control *);
	int (*readpage)(struct file___258 *, struct page___257 *);
	int (*writepages)(struct address_space___258 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___257 *);
	int (*readpages)(struct file___258 *, struct address_space___258 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___258 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___257 **, void **);
	int (*write_end)(struct file___258 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___257 *, void *);
	sector_t (*bmap)(struct address_space___258 *, sector_t);
	void (*invalidatepage)(struct page___257 *, long unsigned int);
	int (*releasepage)(struct page___257 *, gfp_t);
	void (*freepage)(struct page___257 *);
	ssize_t (*direct_IO)(int, struct kiocb___47 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___258 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___258 *, struct page___257 *, struct page___257 *, enum migrate_mode);
	int (*launder_page)(struct page___257 *);
	int (*is_partially_uptodate)(struct page___257 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___257 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___258 *, struct page___257 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___258 *, sector_t *);
	void (*swap_deactivate)(struct file___258 *);
	void (*invalidatepage_range)(struct page___257 *, unsigned int, unsigned int);
};

struct inode_operations___258 {
	struct dentry___258 * (*lookup)(struct inode___258 *, struct dentry___258 *, unsigned int);
	void * (*follow_link)(struct dentry___258 *, struct nameidata *);
	int (*permission)(struct inode___258 *, int);
	struct posix_acl * (*get_acl)(struct inode___258 *, int);
	int (*readlink)(struct dentry___258 *, char *, int);
	void (*put_link)(struct dentry___258 *, struct nameidata *, void *);
	int (*create)(struct inode___258 *, struct dentry___258 *, umode_t, bool);
	int (*link)(struct dentry___258 *, struct inode___258 *, struct dentry___258 *);
	int (*unlink)(struct inode___258 *, struct dentry___258 *);
	int (*symlink)(struct inode___258 *, struct dentry___258 *, const char *);
	int (*mkdir)(struct inode___258 *, struct dentry___258 *, umode_t);
	int (*rmdir)(struct inode___258 *, struct dentry___258 *);
	int (*mknod)(struct inode___258 *, struct dentry___258 *, umode_t, dev_t);
	int (*rename)(struct inode___258 *, struct dentry___258 *, struct inode___258 *, struct dentry___258 *);
	int (*setattr)(struct dentry___258 *, struct iattr___258 *);
	int (*getattr)(struct vfsmount *, struct dentry___258 *, struct kstat *);
	int (*setxattr)(struct dentry___258 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___258 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___258 *, char *, size_t);
	int (*removexattr)(struct dentry___258 *, const char *);
	int (*fiemap)(struct inode___258 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___258 *, struct timespec *, int);
	int (*atomic_open)(struct inode___258 *, struct dentry___258 *, struct file___258 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___146;

struct seq_file___183;

struct file_operations___258 {
	struct module *owner;
	loff_t (*llseek)(struct file___258 *, loff_t, int);
	ssize_t (*read)(struct file___258 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___258 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___47 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___47 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___258 *, void *, filldir_t);
	unsigned int (*poll)(struct file___258 *, struct poll_table_struct___146 *);
	long int (*unlocked_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___258 *, struct vm_area_struct___266 *);
	int (*open)(struct inode___258 *, struct file___258 *);
	int (*flush)(struct file___258 *, fl_owner_t);
	int (*release)(struct inode___258 *, struct file___258 *);
	int (*fsync)(struct file___258 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___47 *, int);
	int (*fasync)(int, struct file___258 *, int);
	int (*lock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*sendpage)(struct file___258 *, struct page___257 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___258 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___258 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___258 *, long int, struct file_lock___258 **, void **);
		struct {
			int (*setlease)(struct file___258 *, long int, struct file_lock___258 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___258 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___183 *, struct file___258 *);
};

struct file_lock_operations___258;

struct lock_manager_operations___258;

struct file_lock___258 {
	struct file_lock___258 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___258 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___258 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___258 *fl_ops;
	const struct lock_manager_operations___258 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___258 {
	void (*fl_copy_lock)(struct file_lock___258 *, struct file_lock___258 *);
	void (*fl_release_private)(struct file_lock___258 *);
};

struct lock_manager_operations___258 {
	int (*lm_compare_owner)(struct file_lock___258 *, struct file_lock___258 *);
	long unsigned int (*lm_owner_key)(struct file_lock___258 *);
	void (*lm_notify)(struct file_lock___258 *);
	int (*lm_grant)(struct file_lock___258 *, struct file_lock___258 *, int);
	void (*lm_break)(struct file_lock___258 *);
	int (*lm_change)(struct file_lock___258 **, int);
};

struct fasync_struct___258 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___258 *fa_next;
	struct file___258 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___258 {
	const char *name;
	int fs_flags;
	struct dentry___258 * (*mount)(struct file_system_type___258 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___258 *);
	struct module *owner;
	struct file_system_type___258 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___258 {
	struct inode___258 * (*alloc_inode)(struct super_block___258 *);
	void (*destroy_inode)(struct inode___258 *);
	void (*dirty_inode)(struct inode___258 *, int);
	int (*write_inode)(struct inode___258 *, struct writeback_control *);
	int (*drop_inode)(struct inode___258 *);
	void (*evict_inode)(struct inode___258 *);
	void (*put_super)(struct super_block___258 *);
	int (*sync_fs)(struct super_block___258 *, int);
	int (*freeze_fs)(struct super_block___258 *);
	int (*unfreeze_fs)(struct super_block___258 *);
	int (*statfs)(struct dentry___258 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___258 *, int *, char *);
	void (*umount_begin)(struct super_block___258 *);
	int (*show_options)(struct seq_file___183 *, struct dentry___258 *);
	int (*show_devname)(struct seq_file___183 *, struct dentry___258 *);
	int (*show_path)(struct seq_file___183 *, struct dentry___258 *);
	int (*show_stats)(struct seq_file___183 *, struct dentry___258 *);
	ssize_t (*quota_read)(struct super_block___258 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___258 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___258 *);
	int (*bdev_try_to_free_page)(struct super_block___258 *, struct page___257 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___258 *);
	void (*free_cached_objects)(struct super_block___258 *, int);
};

struct xattr_handler___154 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___258 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___258 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___258 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___148)(struct file___258 *, wait_queue_head_t *, struct poll_table_struct___146 *);

struct poll_table_struct___146 {
	poll_queue_proc___148 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___232;

struct vm_area_struct___266 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___266 *vm_next;
	struct vm_area_struct___266 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___266 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___232 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___258 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___183;

struct seq_file___183 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___260 lock;
	const struct seq_operations___183 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___257 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___257 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___240;

struct memcg_cache_params___241;

struct kmem_cache___241 {
	struct kmem_cache_cpu___240 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___42 kobj;
	struct memcg_cache_params___241 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___228;

struct vm_operations_struct___232 {
	void (*open)(struct vm_area_struct___266 *);
	void (*close)(struct vm_area_struct___266 *);
	int (*fault)(struct vm_area_struct___266 *, struct vm_fault___228 *);
	int (*page_mkwrite)(struct vm_area_struct___266 *, struct vm_fault___228 *);
	int (*access)(struct vm_area_struct___266 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___266 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___266 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___266 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___266 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___259 {
	struct task_struct___259 *task;
	struct core_thread___259 *next;
};

struct core_state___259 {
	atomic_t nr_threads;
	struct core_thread___259 dumper;
	struct completion startup;
};

struct socket_wq___39 {
	wait_queue_head_t wait;
	struct fasync_struct___258 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct sock___41;

struct proto_ops___39;

struct socket___40 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___39 *wq;
	struct file___258 *file;
	struct sock___41 *sk;
	const struct proto_ops___39 *ops;
};

struct proto___39;

struct net___63;

struct sock_common___39 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___39 *skc_prot;
	struct net___63 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___52;

struct sk_buff_head___49 {
	struct sk_buff___52 *next;
	struct sk_buff___52 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___40;

struct dst_entry___39;

struct cg_proto___39;

struct sock___41 {
	struct sock_common___39 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___49 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___52 *head;
		struct sk_buff___52 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___40 *sk_filter;
	struct socket_wq___39 *sk_wq;
	struct sk_buff_head___49 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___39 *sk_rx_dst;
	struct dst_entry___39 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___49 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___49 sk_error_queue;
	struct proto___39 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___40 *sk_socket;
	void *sk_user_data;
	struct page_frag___252 sk_frag;
	struct sk_buff___52 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___39 *sk_cgrp;
	void (*sk_state_change)(struct sock___41 *);
	void (*sk_data_ready)(struct sock___41 *, int);
	void (*sk_write_space)(struct sock___41 *);
	void (*sk_error_report)(struct sock___41 *);
	int (*sk_backlog_rcv)(struct sock___41 *, struct sk_buff___52 *);
	void (*sk_destruct)(struct sock___41 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct proto_ops___39 {
	int family;
	struct module *owner;
	int (*release)(struct socket___40 *);
	int (*bind)(struct socket___40 *, struct sockaddr *, int);
	int (*connect)(struct socket___40 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___40 *, struct socket___40 *);
	int (*accept)(struct socket___40 *, struct socket___40 *, int);
	int (*getname)(struct socket___40 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___258 *, struct socket___40 *, struct poll_table_struct___146 *);
	int (*ioctl)(struct socket___40 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___40 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___40 *, int);
	int (*shutdown)(struct socket___40 *, int);
	int (*setsockopt)(struct socket___40 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___40 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___40 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___40 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___47 *, struct socket___40 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___47 *, struct socket___40 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___258 *, struct socket___40 *, struct vm_area_struct___266 *);
	ssize_t (*sendpage)(struct socket___40 *, struct page___257 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___40 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___41 *, int);
		struct {
			void (*set_peek_off)(struct sock___41 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct ctl_table_root___63;

struct ctl_table_set___63;

struct ctl_dir___63;

struct ctl_node___63;

struct ctl_table_header___63 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___63 *root;
	struct ctl_table_set___63 *set;
	struct ctl_dir___63 *parent;
	struct ctl_node___63 *node;
};

struct ctl_dir___63 {
	struct ctl_table_header___63 header;
	struct rb_root root;
};

struct ctl_table_set___63 {
	int (*is_seen)(struct ctl_table_set___63 *);
	struct ctl_dir___63 dir;
};

struct netns_core___60 {
	struct ctl_table_header___63 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___61 {
	struct mutex___260 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___60 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___63 *ctl;
};

struct netns_ipv4___60 {
	struct ctl_table_header___63 *forw_hdr;
	struct ctl_table_header___63 *frags_hdr;
	struct ctl_table_header___63 *ipv4_hdr;
	struct ctl_table_header___63 *route_hdr;
	struct ctl_table_header___63 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___41 *fibnl;
	struct sock___41 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___60 {
	struct ctl_table_header___63 *hdr;
	struct ctl_table_header___63 *route_hdr;
	struct ctl_table_header___63 *icmp_hdr;
	struct ctl_table_header___63 *frags_hdr;
	struct ctl_table_header___63 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___49;

struct neighbour___39;

struct dst_ops___62 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___62 *);
	struct dst_entry___39 * (*check)(struct dst_entry___39 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___39 *);
	unsigned int (*mtu)(const struct dst_entry___39 *);
	u32 * (*cow_metrics)(struct dst_entry___39 *, long unsigned int);
	void (*destroy)(struct dst_entry___39 *);
	void (*ifdown)(struct dst_entry___39 *, struct net_device___49 *, int);
	struct dst_entry___39 * (*negative_advice)(struct dst_entry___39 *);
	void (*link_failure)(struct sk_buff___52 *);
	void (*update_pmtu)(struct dst_entry___39 *, struct sock___41 *, struct sk_buff___52 *, u32);
	void (*redirect)(struct dst_entry___39 *, struct sock___41 *, struct sk_buff___52 *);
	int (*local_out)(struct sk_buff___52 *);
	struct neighbour___39 * (*neigh_lookup)(const struct dst_entry___39 *, struct sk_buff___52 *, const void *);
	struct kmem_cache___241 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___62 {
	struct netns_sysctl_ipv6___60 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___62 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___41 **icmp_sk;
	struct sock___41 *ndisc_sk;
	struct sock___41 *tcp_sk;
	struct sock___41 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___60 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___63 *sysctl_header;
	struct sock___41 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___39 {
	struct sock___41 *v4_ctl_sk;
	struct sock___41 *v6_ctl_sk;
};

struct netns_nf___60 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___63 *nf_log_dir_header;
};

struct nf_proto_net___60 {
	struct ctl_table_header___63 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___60 {
	struct nf_proto_net___60 pn;
	unsigned int timeout;
};

struct nf_tcp_net___60 {
	struct nf_proto_net___60 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___60 {
	struct nf_proto_net___60 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___60 {
	struct nf_proto_net___60 pn;
	unsigned int timeout;
};

struct nf_ip_net___60 {
	struct nf_generic_net___60 generic;
	struct nf_tcp_net___60 tcp;
	struct nf_udp_net___60 udp;
	struct nf_icmp_net___60 icmp;
	struct nf_icmp_net___60 icmpv6;
};

struct netns_ct___61 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___63 *sysctl_header;
	struct ctl_table_header___63 *acct_sysctl_header;
	struct ctl_table_header___63 *tstamp_sysctl_header;
	struct ctl_table_header___63 *event_sysctl_header;
	struct ctl_table_header___63 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___241 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___60 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___60 {
	struct netns_sysctl_ipv6___60 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___62 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___41 *nlsk;
	struct sock___41 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___63 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___62 xfrm4_dst_ops;
	struct dst_ops___62 xfrm6_dst_ops;
};

struct net___63 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___63 sysctls;
	struct sock___41 *rtnl;
	struct sock___41 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___49 *loopback_dev;
	struct netns_core___60 core;
	struct netns_mib mib;
	struct netns_packet___61 packet;
	struct netns_unix___60 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___60 ipv4;
	struct netns_ipv6___62 ipv6;
	struct netns_sctp___60 sctp;
	struct netns_dccp___39 dccp;
	struct netns_nf___60 nf;
	struct netns_xt xt;
	struct netns_ct___61 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___60 nf_frag;
	struct sock___41 *nfnl;
	struct sock___41 *nfnl_stash;
	struct sk_buff_head___49 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___62 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___41 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___41 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___260 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___260 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___39 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___41 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___220;

struct attribute_group___218 {
	const char *name;
	umode_t (*is_visible)(struct kobject___42 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___220 **bin_attrs;
};

struct bin_attribute___220 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___258 *, struct kobject___42 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___258 *, struct kobject___42 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	int (*mmap)(struct file___258 *, struct kobject___42 *, struct bin_attribute___220 *, struct vm_area_struct___266 *);
};

struct sysfs_ops___42 {
	ssize_t (*show)(struct kobject___42 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___42 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___42 *, const struct attribute *);
};

struct kset_uevent_ops___42;

struct kset___42 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___42 kobj;
	const struct kset_uevent_ops___42 *uevent_ops;
};

struct kobj_type___42 {
	void (*release)(struct kobject___42 *);
	const struct sysfs_ops___42 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___39 * (*child_ns_type)(struct kobject___42 *);
	const void * (*namespace)(struct kobject___42 *);
};

struct kset_uevent_ops___42 {
	int (* const filter)(struct kset___42 *, struct kobject___42 *);
	const char * (* const name)(struct kset___42 *, struct kobject___42 *);
	int (* const uevent)(struct kset___42 *, struct kobject___42 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___240 {
	void **freelist;
	long unsigned int tid;
	struct page___257 *page;
	struct page___257 *partial;
};

struct memcg_cache_params___241 {
	bool is_root_cache;
	union {
		struct kmem_cache___241 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___241 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___121 {
	void * (*alloc)(struct device___256 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___256 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___256 *, struct vm_area_struct___266 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___256 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___256 *, struct page___257 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___256 *, dma_addr_t);
	int (*dma_supported)(struct device___256 *, u64);
	int (*set_dma_mask)(struct device___256 *, u64);
	int is_phys;
};

struct bus_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___256 *, char *);
	ssize_t (*store)(struct bus_type___256 *, const char *, size_t);
};

struct device_attribute___256;

struct driver_attribute___256;

struct bus_type___256 {
	const char *name;
	const char *dev_name;
	struct device___256 *dev_root;
	struct bus_attribute___256 *bus_attrs;
	struct device_attribute___256 *dev_attrs;
	struct driver_attribute___256 *drv_attrs;
	const struct attribute_group___218 **bus_groups;
	const struct attribute_group___218 **dev_groups;
	const struct attribute_group___218 **drv_groups;
	int (*match)(struct device___256 *, struct device_driver___256 *);
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	int (*probe)(struct device___256 *);
	int (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*online)(struct device___256 *);
	int (*offline)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct device___256 *, struct device_attribute___256 *, char *);
	ssize_t (*store)(struct device___256 *, struct device_attribute___256 *, const char *, size_t);
};

struct driver_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___256 *, char *);
	ssize_t (*store)(struct device_driver___256 *, const char *, size_t);
};

struct device_driver___256 {
	const char *name;
	struct bus_type___256 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___256 *);
	int (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	const struct attribute_group___218 **groups;
	const struct dev_pm_ops___256 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___256 {
	const char *name;
	const struct attribute_group___218 **groups;
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
};

struct class_attribute___256;

struct class___256 {
	const char *name;
	struct module *owner;
	struct class_attribute___256 *class_attrs;
	struct device_attribute___256 *dev_attrs;
	const struct attribute_group___218 **dev_groups;
	struct bin_attribute___220 *dev_bin_attrs;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *);
	void (*class_release)(struct class___256 *);
	void (*dev_release)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	const struct kobj_ns_type_operations___39 *ns_type;
	const void * (*namespace)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
	struct subsys_private *p;
};

struct class_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct class___256 *, struct class_attribute___256 *, char *);
	ssize_t (*store)(struct class___256 *, struct class_attribute___256 *, const char *, size_t);
	const void * (*namespace)(struct class___256 *, const struct class_attribute___256 *);
};

struct device_rh___256 {
	struct dev_pm_info_rh___256 power;
};

struct vm_fault___228 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___257 *page;
};

struct ctl_node___63 {
	struct rb_node node;
	struct ctl_table_header___63 *header;
};

struct ctl_table_root___63 {
	struct ctl_table_set___63 default_set;
	struct ctl_table_set___63 * (*lookup)(struct ctl_table_root___63 *, struct nsproxy___138 *);
	int (*permissions)(struct ctl_table_header___63 *, struct ctl_table *);
};

struct nsproxy___138 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___97 *pid_ns;
	struct net___63 *net_ns;
};

struct signal_struct___259 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___259 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___259 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___260 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___153 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___153 *subsys[11];
	struct callback_head callback_head;
};

struct perf_event_context___86 {
	struct pmu___86 *pmu;
	enum perf_event_context_type rh_reserved_type;
	raw_spinlock_t lock;
	struct mutex___260 mutex;
	struct list_head pinned_groups;
	struct list_head flexible_groups;
	struct list_head event_list;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___259 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___86 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	int rh_reserved_nr_branch_stack;
	struct callback_head callback_head;
	struct delayed_work orphans_remove;
	bool orphans_remove_sched;
	struct list_head active_ctx_list;
	void *task_ctx_data;
};

struct nf_bridge_info___48 {
	atomic_t use;
	unsigned int mask;
	struct net_device___49 *physindev;
	struct net_device___49 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___48(struct sk_buff___52 **);

struct net_device_ops___48;

struct ethtool_ops___48;

struct header_ops___48;

struct inet6_dev___21;

struct netdev_rx_queue___48;

struct netdev_queue___48;

struct rtnl_link_ops___39;

struct dcbnl_rtnl_ops___48;

struct net_device___49 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___48 *netdev_ops;
	const struct ethtool_ops___48 *ethtool_ops;
	const struct header_ops___48 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___42 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___21 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___48 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___48 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___48 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___48 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___48 = 0,
		NETREG_REGISTERED___48 = 1,
		NETREG_UNREGISTERING___48 = 2,
		NETREG_UNREGISTERED___48 = 3,
		NETREG_RELEASED___48 = 4,
		NETREG_DUMMY___48 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___48 = 0,
		RTNL_LINK_INITIALIZING___48 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___49 *);
	struct netpoll_info *npinfo;
	struct net___63 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___256 dev;
	const struct attribute_group___218 *sysfs_groups[4];
	const struct rtnl_link_ops___39 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___48 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___52 {
	struct sk_buff___52 *next;
	struct sk_buff___52 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___41 *sk;
	struct net_device___49 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___52 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___48 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct dev_pm_qos_request___60 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___256 *dev;
};

struct ethtool_ops___48 {
	int (*get_settings)(struct net_device___49 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___49 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___49 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___49 *);
	void (*get_regs)(struct net_device___49 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___49 *);
	void (*set_msglevel)(struct net_device___49 *, u32);
	int (*nway_reset)(struct net_device___49 *);
	u32 (*get_link)(struct net_device___49 *);
	int (*get_eeprom_len)(struct net_device___49 *);
	int (*get_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___49 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___49 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___49 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___49 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___49 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___49 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___49 *);
	void (*complete)(struct net_device___49 *);
	u32 (*get_priv_flags)(struct net_device___49 *);
	int (*set_priv_flags)(struct net_device___49 *, u32);
	int (*get_sset_count)(struct net_device___49 *, int);
	int (*get_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___49 *, struct ethtool_flash *);
	int (*reset)(struct net_device___49 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___49 *);
	int (*get_rxfh_indir)(struct net_device___49 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___49 *, const u32 *);
	void (*get_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___49 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___49 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___49 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___49 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___49 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___49 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___49 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___49 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___16;

struct dst_entry___39 {
	struct callback_head callback_head;
	struct dst_entry___39 *child;
	struct net_device___49 *dev;
	struct dst_ops___62 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___39 *path;
	struct dst_entry___39 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___52 *);
	union {
		int (*output)(struct sock___41 *, struct sk_buff___52 *);
		struct {
			int (*output)(struct sk_buff___52 *);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___39 *next;
		struct rtable___16 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___39;

struct neigh_parms___39;

struct neigh_ops___39;

struct neighbour___39 {
	struct neighbour___39 *next;
	struct neigh_table___39 *tbl;
	struct neigh_parms___39 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___49 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___39 *, struct sk_buff___52 *);
	const struct neigh_ops___39 *ops;
	struct callback_head rcu;
	struct net_device___49 *dev;
	u8 primary_key[0];
};

struct group_req {
	__u32 gr_interface;
	int: 32;
	struct __kernel_sockaddr_storage gr_group;
};

struct group_source_req {
	__u32 gsr_interface;
	int: 32;
	struct __kernel_sockaddr_storage gsr_group;
	struct __kernel_sockaddr_storage gsr_source;
};

struct group_filter {
	__u32 gf_interface;
	int: 32;
	struct __kernel_sockaddr_storage gf_group;
	__u32 gf_fmode;
	__u32 gf_numsrc;
	struct __kernel_sockaddr_storage gf_slist[1];
};

struct nf_afinfo___62 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___52 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___52 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___63 *, struct dst_entry___39 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___52 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___52 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___182 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___182 *);
	void (*irq_shutdown)(struct irq_data___182 *);
	void (*irq_enable)(struct irq_data___182 *);
	void (*irq_disable)(struct irq_data___182 *);
	void (*irq_ack)(struct irq_data___182 *);
	void (*irq_mask)(struct irq_data___182 *);
	void (*irq_mask_ack)(struct irq_data___182 *);
	void (*irq_unmask)(struct irq_data___182 *);
	void (*irq_eoi)(struct irq_data___182 *);
	int (*irq_set_affinity)(struct irq_data___182 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___182 *);
	int (*irq_set_type)(struct irq_data___182 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___182 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___182 *);
	void (*irq_bus_sync_unlock)(struct irq_data___182 *);
	void (*irq_cpu_online)(struct irq_data___182 *);
	void (*irq_cpu_offline)(struct irq_data___182 *);
	void (*irq_suspend)(struct irq_data___182 *);
	void (*irq_resume)(struct irq_data___182 *);
	void (*irq_pm_shutdown)(struct irq_data___182 *);
	void (*irq_print_chip)(struct irq_data___182 *, struct seq_file___183 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___182 *, void *);
	long unsigned int flags;
};

struct seq_operations___183 {
	void * (*start)(struct seq_file___183 *, loff_t *);
	void (*stop)(struct seq_file___183 *, void *);
	void * (*next)(struct seq_file___183 *, void *, loff_t *);
	int (*show)(struct seq_file___183 *, void *);
};

struct dcbnl_rtnl_ops___48 {
	int (*ieee_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___49 *);
	u8 (*setstate)(struct net_device___49 *, u8);
	void (*getpermhwaddr)(struct net_device___49 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___49 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___49 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___49 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___49 *, int, u8 *);
	void (*setpfccfg)(struct net_device___49 *, int, u8);
	void (*getpfccfg)(struct net_device___49 *, int, u8 *);
	u8 (*setall)(struct net_device___49 *);
	u8 (*getcap)(struct net_device___49 *, int, u8 *);
	int (*getnumtcs)(struct net_device___49 *, int, u8 *);
	int (*setnumtcs)(struct net_device___49 *, int, u8);
	u8 (*getpfcstate)(struct net_device___49 *);
	void (*setpfcstate)(struct net_device___49 *, u8);
	void (*getbcncfg)(struct net_device___49 *, int, u32 *);
	void (*setbcncfg)(struct net_device___49 *, int, u32);
	void (*getbcnrp)(struct net_device___49 *, int, u8 *);
	void (*setbcnrp)(struct net_device___49 *, int, u8);
	u8 (*setapp)(struct net_device___49 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___49 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___49 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___49 *, int, u8);
	u8 (*getdcbx)(struct net_device___49 *);
	u8 (*setdcbx)(struct net_device___49 *, u8);
	int (*peer_getappinfo)(struct net_device___49 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___49 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___49 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___49 *, struct cee_pfc *);
};

struct cgroupfs_root___153;

struct cgroup___153 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___153 *parent;
	struct dentry___258 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___153 *subsys[11];
	struct cgroupfs_root___153 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___260 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___153 {
	struct super_block___258 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___153 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___91 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___258 *, struct file___258 *);
	ssize_t (*read)(struct cgroup___153 *, struct cftype___91 *, struct file___258 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___153 *, struct cftype___91 *);
	s64 (*read_s64)(struct cgroup___153 *, struct cftype___91 *);
	int (*read_map)(struct cgroup___153 *, struct cftype___91 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___153 *, struct cftype___91 *, struct seq_file___183 *);
	ssize_t (*write)(struct cgroup___153 *, struct cftype___91 *, struct file___258 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___153 *, struct cftype___91 *, u64);
	int (*write_s64)(struct cgroup___153 *, struct cftype___91 *, s64);
	int (*write_string)(struct cgroup___153 *, struct cftype___91 *, const char *);
	int (*trigger)(struct cgroup___153 *, unsigned int);
	int (*release)(struct inode___258 *, struct file___258 *);
	int (*register_event)(struct cgroup___153 *, struct cftype___91 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___153 *, struct cftype___91 *, struct eventfd_ctx *);
};

struct cftype_set___87 {
	struct list_head node;
	struct cftype___91 *cfts;
};

struct task_and_cgroup___87 {
	struct task_struct___259 *task;
	struct cgroup___153 *cgrp;
	struct css_set___153 *cg;
};

struct cgroup_taskset___87 {
	struct task_and_cgroup___87 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___153 *cur_cgrp;
};

struct cgroup_subsys___87 {
	struct cgroup_subsys_state___153 * (*css_alloc)(struct cgroup___153 *);
	int (*css_online)(struct cgroup___153 *);
	void (*css_offline)(struct cgroup___153 *);
	void (*css_free)(struct cgroup___153 *);
	int (*can_attach)(struct cgroup___153 *, struct cgroup_taskset___87 *);
	void (*cancel_attach)(struct cgroup___153 *, struct cgroup_taskset___87 *);
	void (*attach)(struct cgroup___153 *, struct cgroup_taskset___87 *);
	void (*fork)(struct task_struct___259 *);
	void (*exit)(struct cgroup___153 *, struct cgroup___153 *, struct task_struct___259 *);
	void (*bind)(struct cgroup___153 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___153 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___91 *base_cftypes;
	struct cftype_set___87 base_cftset;
	struct module *module;
};

struct request_sock_ops___27;

struct request_sock___28 {
	struct sock_common___39 __req_common;
	struct request_sock___28 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___27 *rsk_ops;
	struct sock___41 *sk;
	u32 secid;
	u32 peer_secid;
};

struct scm_fp_list___3 {
	short int count;
	short int max;
	struct file___258 *fp[253];
};

struct scm_cookie___3 {
	struct pid___97 *pid;
	struct scm_fp_list___3 *fp;
	struct scm_creds creds;
	u32 secid;
};

struct netlink_callback___50 {
	struct sk_buff___52 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___52 *, struct netlink_callback___50 *);
	int (*done)(struct netlink_callback___50 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___48 {
	int (*create)(struct sk_buff___52 *, struct net_device___49 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___52 *, unsigned char *);
	int (*rebuild)(struct sk_buff___52 *);
	int (*cache)(const struct neighbour___39 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___49 *, const unsigned char *);
};

struct napi_struct___48 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___48 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___49 *dev;
	struct sk_buff___52 *gro_list;
	struct sk_buff___52 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___48 {
	struct net_device___49 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___42 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___48 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___42 kobj;
	struct net_device___49 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___48 {
	int (*ndo_init)(struct net_device___49 *);
	void (*ndo_uninit)(struct net_device___49 *);
	int (*ndo_open)(struct net_device___49 *);
	int (*ndo_stop)(struct net_device___49 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___52 *, struct net_device___49 *);
	u16 (*ndo_select_queue)(struct net_device___49 *, struct sk_buff___52 *);
	void (*ndo_change_rx_flags)(struct net_device___49 *, int);
	void (*ndo_set_rx_mode)(struct net_device___49 *);
	int (*ndo_set_mac_address)(struct net_device___49 *, void *);
	int (*ndo_validate_addr)(struct net_device___49 *);
	int (*ndo_do_ioctl)(struct net_device___49 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___49 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___49 *, int);
	int (*ndo_neigh_setup)(struct net_device___49 *, struct neigh_parms___39 *);
	void (*ndo_tx_timeout)(struct net_device___49 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___49 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___49 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___49 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___49 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___49 *);
	int (*ndo_netpoll_setup)(struct net_device___49 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___49 *);
	int (*ndo_busy_poll)(struct napi_struct___48 *);
	int (*ndo_set_vf_mac)(struct net_device___49 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___49 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___49 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___49 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___49 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___49 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___49 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___49 *, int, struct sk_buff___52 *);
	int (*ndo_setup_tc)(struct net_device___49 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___49 *);
	int (*ndo_fcoe_disable)(struct net_device___49 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___49 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___49 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___49 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___49 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___49 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___49 *, const struct sk_buff___52 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___49 *, struct net_device___49 *);
	int (*ndo_del_slave)(struct net_device___49 *, struct net_device___49 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___39 *);
	void (*ndo_neigh_destroy)(struct neighbour___39 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___52 *, struct netlink_callback___50 *, struct net_device___49 *, int);
	int (*ndo_bridge_setlink)(struct net_device___49 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___52 *, u32, u32, struct net_device___49 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___49 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___49 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___49 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___49 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___49 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___49 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___52 *, struct net_device___49 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___49 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___49 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___49 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___39 {
	struct net___63 *net;
	struct net_device___49 *dev;
	struct neigh_parms___39 *next;
	int (*neigh_setup)(struct neighbour___39 *);
	void (*neigh_cleanup)(struct neighbour___39 *);
	struct neigh_table___39 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___21;

struct ifacaddr6___21;

struct inet6_dev___21 {
	struct net_device___49 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___21 *mc_list;
	struct ifmcaddr6___21 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___21 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___39 *nd_parms;
	struct inet6_dev___21 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___39 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___49 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___63 *, struct net_device___49 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___49 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___49 *, struct list_head *);
	size_t (*get_size)(const struct net_device___49 *);
	int (*fill_info)(struct sk_buff___52 *, const struct net_device___49 *);
	size_t (*get_xstats_size)(const struct net_device___49 *);
	int (*fill_xstats)(struct sk_buff___52 *, const struct net_device___49 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___63 * (*get_link_net)(const struct net_device___49 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___49 *, struct net_device___49 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___49 *, const struct net_device___49 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___52 *, const struct net_device___49 *, const struct net_device___49 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct perf_cpu_context___86;

struct pmu___86 {
	struct list_head entry;
	struct device___256 *dev;
	const struct attribute_group___218 **attr_groups;
	const char *name;
	int type;
	int *pmu_disable_count;
	struct perf_cpu_context___86 *pmu_cpu_context;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	void (*pmu_enable)(struct pmu___86 *);
	void (*pmu_disable)(struct pmu___86 *);
	int (*event_init)(struct perf_event___86 *);
	int (*add)(struct perf_event___86 *, int);
	void (*del)(struct perf_event___86 *, int);
	void (*start)(struct perf_event___86 *, int);
	void (*stop)(struct perf_event___86 *, int);
	void (*read)(struct perf_event___86 *);
	void (*start_txn)(struct pmu___86 *);
	int (*commit_txn)(struct pmu___86 *);
	void (*cancel_txn)(struct pmu___86 *);
	int (*event_idx)(struct perf_event___86 *);
	void (*rh_reserved_flush_branch_stack)();
	struct module *module;
	int capabilities;
	void (*sched_task)(struct perf_event_context___86 *, bool);
	size_t task_ctx_size;
	u64 (*count)(struct perf_event___86 *);
};

struct perf_cpu_context___86 {
	struct perf_event_context___86 ctx;
	struct perf_event_context___86 *task_ctx;
	int active_oncpu;
	int exclusive;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	struct list_head rh_reserved_rotation_list;
	struct pmu___86 *unique_pmu;
	struct perf_cgroup___86 *cgrp;
};

struct trace_event_functions___75;

struct trace_event___75 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___75 *funcs;
};

struct ftrace_event_class___75;

struct ftrace_event_call___75 {
	struct list_head list;
	struct ftrace_event_class___75 *class;
	char *name;
	struct trace_event___75 event;
	const char *print_fmt;
	struct event_filter *filter;
	struct list_head *files;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
};

struct perf_cgroup___86 {
	struct cgroup_subsys_state___153 css;
	struct perf_cgroup_info *info;
};

struct trace_iterator___75 {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex___260 mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

typedef enum print_line_t (*trace_print_func___75)(struct trace_iterator___75 *, int, struct trace_event___75 *);

struct trace_event_functions___75 {
	trace_print_func___75 trace;
	trace_print_func___75 raw;
	trace_print_func___75 hex;
	trace_print_func___75 binary;
};

struct ftrace_event_class___75 {
	char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct ftrace_event_call___75 *, enum trace_reg, void *);
	int (*define_fields)(struct ftrace_event_call___75 *);
	struct list_head * (*get_fields)(struct ftrace_event_call___75 *);
	struct list_head fields;
	int (*raw_init)(struct ftrace_event_call___75 *);
};

struct sk_filter___40 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___52 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___39;

struct neigh_hash_table___39;

struct neigh_table___39 {
	struct neigh_table___39 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___49 *, __u32 *);
	int (*constructor)(struct neighbour___39 *);
	int (*pconstructor)(struct pneigh_entry___39 *);
	void (*pdestructor)(struct pneigh_entry___39 *);
	void (*proxy_redo)(struct sk_buff___52 *);
	char *id;
	struct neigh_parms___39 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___49 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___39 *nht;
	struct pneigh_entry___39 **phash_buckets;
};

struct neigh_ops___39 {
	int family;
	void (*solicit)(struct neighbour___39 *, struct sk_buff___52 *);
	void (*error_report)(struct neighbour___39 *, struct sk_buff___52 *);
	int (*output)(struct neighbour___39 *, struct sk_buff___52 *);
	int (*connected_output)(struct neighbour___39 *, struct sk_buff___52 *);
};

struct pneigh_entry___39 {
	struct pneigh_entry___39 *next;
	struct net___63 *net;
	struct net_device___49 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___39 {
	struct neighbour___39 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___16 {
	struct dst_entry___39 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___24;

struct proto___39 {
	void (*close)(struct sock___41 *, long int);
	int (*connect)(struct sock___41 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___41 *, int);
	struct sock___41 * (*accept)(struct sock___41 *, int, int *);
	int (*ioctl)(struct sock___41 *, int, long unsigned int);
	int (*init)(struct sock___41 *);
	void (*destroy)(struct sock___41 *);
	void (*shutdown)(struct sock___41 *, int);
	int (*setsockopt)(struct sock___41 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___41 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___41 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___41 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___41 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___47 *, struct sock___41 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___47 *, struct sock___41 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___41 *, struct page___257 *, int, size_t, int);
	int (*bind)(struct sock___41 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___41 *, struct sk_buff___52 *);
	void (*release_cb)(struct sock___41 *);
	void (*mtu_reduced)(struct sock___41 *);
	void (*hash)(struct sock___41 *);
	void (*unhash)(struct sock___41 *);
	void (*rehash)(struct sock___41 *);
	int (*get_port)(struct sock___41 *, short unsigned int);
	void (*clear_sk)(struct sock___41 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___41 *);
	void (*enter_memory_pressure)(struct sock___41 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___241 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___27 *rsk_prot;
	struct timewait_sock_ops___24 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___87 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___39 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___39 {
	void (*enter_memory_pressure)(struct sock___41 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___27 {
	int family;
	int obj_size;
	struct kmem_cache___241 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___41 *, struct request_sock___28 *);
	void (*send_ack)(struct sock___41 *, struct sk_buff___52 *, struct request_sock___28 *);
	void (*send_reset)(struct sock___41 *, struct sk_buff___52 *);
	void (*destructor)(struct request_sock___28 *);
	void (*syn_ack_timeout)(struct sock___41 *, struct request_sock___28 *);
};

struct timewait_sock_ops___24 {
	struct kmem_cache___241 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___41 *, struct sock___41 *, void *);
	void (*twsk_destructor)(struct sock___41 *);
};

struct ifmcaddr6___21 {
	struct in6_addr mca_addr;
	struct inet6_dev___21 *idev;
	struct ifmcaddr6___21 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___21 {
	struct in6_addr aca_addr;
	struct inet6_dev___21 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___21 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct compat_cmsghdr {
	compat_size_t cmsg_len;
	compat_int_t cmsg_level;
	compat_int_t cmsg_type;
};

struct compat_group_req {
	__u32 gr_interface;
	struct __kernel_sockaddr_storage gr_group;
};

struct compat_group_source_req {
	__u32 gsr_interface;
	struct __kernel_sockaddr_storage gsr_group;
	struct __kernel_sockaddr_storage gsr_source;
};

struct compat_group_filter {
	__u32 gf_interface;
	struct __kernel_sockaddr_storage gf_group;
	__u32 gf_fmode;
	__u32 gf_numsrc;
	struct __kernel_sockaddr_storage gf_slist[1];
};

struct offload_callbacks___2 {
	struct sk_buff___45 * (*gso_segment)(struct sk_buff___45 *, netdev_features_t);
	struct sk_buff___45 ** (*gro_receive)(struct sk_buff___45 **, struct sk_buff___45 *);
	int (*gro_complete)(struct sk_buff___45 *, int);
};

struct packet_offload___2 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___2 callbacks;
	struct list_head list;
};

struct fch_hdr {
	__u8 daddr[6];
	__u8 saddr[6];
};

struct fcllc {
	__u8 dsap;
	__u8 ssap;
	__u8 llc;
	__u8 protid[3];
	__be16 ethertype;
};

struct page___258;

typedef struct page___258 *pgtable_t___258;

struct address_space___259;

struct kmem_cache___242;

struct page___258 {
	long unsigned int flags;
	struct address_space___259 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___258 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___258 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___242 *slab_cache;
		struct page___258 *first_page;
	};
	long: 64;
};

struct task_struct___260;

struct pv_cpu_ops___260 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___260 *);
	void (*end_context_switch)(struct task_struct___260 *);
};

struct mutex___261 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___260 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___253 {
	struct page___258 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___267;

struct nsproxy___139;

struct signal_struct___260;

struct css_set___154;

struct task_struct___260 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___260 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___267 *mm;
	struct mm_struct___267 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___260 *real_parent;
	struct task_struct___260 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___260 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___260 = 0,
		VTIME_USER___260 = 1,
		VTIME_SYS___260 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___139 *nsproxy;
	struct signal_struct___260 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___154 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___261 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___253 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___267 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___267 *, struct mm_struct___267 *);
	void (*dup_mmap)(struct mm_struct___267 *, struct mm_struct___267 *);
	void (*exit_mmap)(struct mm_struct___267 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___267 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___267 *);
	void (*pgd_free)(struct mm_struct___267 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___267 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___267 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___267 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___267 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___267 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___267 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___267 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___267 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___267 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___267 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___267 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___261 lock;
	void *vdso;
} mm_context_t___261;

struct xol_area___258;

struct uprobes_state___258 {
	struct xol_area___258 *xol_area;
};

struct vm_area_struct___267;

struct file___259;

struct core_state___260;

struct mm_struct___267 {
	struct vm_area_struct___267 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___267 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___267 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___261 context;
	long unsigned int flags;
	struct core_state___260 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___260 *owner;
	struct file___259 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___258 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___158;

struct exec_domain___72 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___158 *module;
	struct exec_domain___72 *next;
};

struct module_kobject___156 {
	struct kobject___42 kobj;
	struct module___158 *mod;
	struct kobject___42 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___156;

struct module___158 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___156 mkobj;
	struct module_attribute___156 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___42 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___260 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___119 {
	struct task_struct___260 *task;
	struct exec_domain___72 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___260;

struct lruvec___260 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___260 *zone;
};

struct pglist_data___260;

struct zone___260 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___260 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___260 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___260 {
	struct zone___260 *zone;
	int zone_idx;
};

struct zonelist___260 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___260 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___260 {
	struct zone___260 node_zones[4];
	struct zonelist___260 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___260 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___183;

struct x86_io_apic_ops___183 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___183 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___183;

struct irq_data___183 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___183 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___257;

struct dev_pm_ops___257 {
	int (*prepare)(struct device___257 *);
	void (*complete)(struct device___257 *);
	int (*suspend)(struct device___257 *);
	int (*resume)(struct device___257 *);
	int (*freeze)(struct device___257 *);
	int (*thaw)(struct device___257 *);
	int (*poweroff)(struct device___257 *);
	int (*restore)(struct device___257 *);
	int (*suspend_late)(struct device___257 *);
	int (*resume_early)(struct device___257 *);
	int (*freeze_late)(struct device___257 *);
	int (*thaw_early)(struct device___257 *);
	int (*poweroff_late)(struct device___257 *);
	int (*restore_early)(struct device___257 *);
	int (*suspend_noirq)(struct device___257 *);
	int (*resume_noirq)(struct device___257 *);
	int (*freeze_noirq)(struct device___257 *);
	int (*thaw_noirq)(struct device___257 *);
	int (*poweroff_noirq)(struct device___257 *);
	int (*restore_noirq)(struct device___257 *);
	int (*runtime_suspend)(struct device___257 *);
	int (*runtime_resume)(struct device___257 *);
	int (*runtime_idle)(struct device___257 *);
};

struct dev_pm_qos___60;

struct dev_pm_info___60 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___60 *qos;
};

struct dma_map_ops___122;

struct dev_archdata___122 {
	struct dma_map_ops___122 *dma_ops;
	void *iommu;
};

struct device_type___257;

struct bus_type___257;

struct device_driver___257;

struct dev_pm_domain___257;

struct class___257;

struct attribute_group___219;

struct device_rh___257;

struct device___257 {
	struct device___257 *parent;
	struct device_private *p;
	struct kobject___42 kobj;
	const char *init_name;
	const struct device_type___257 *type;
	struct mutex___261 mutex;
	struct bus_type___257 *bus;
	struct device_driver___257 *driver;
	void *platform_data;
	struct dev_pm_info___60 power;
	struct dev_pm_domain___257 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___122 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___257 *class;
	const struct attribute_group___219 **groups;
	void (*release)(struct device___257 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___257 *device_rh;
};

struct dev_pm_qos_request___61;

struct dev_pm_qos___60 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___61 *latency_req;
	struct dev_pm_qos_request___61 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___61 *latency_tolerance_req;
};

struct dev_pm_info_rh___257 {
	void (*set_latency_tolerance)(struct device___257 *, s32);
};

struct dev_pm_domain___257 {
	struct dev_pm_ops___257 ops;
};

struct smp_ops___260 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___260 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___64;

struct ctl_node___64 {
	struct rb_node node;
	struct ctl_table_header___64 *header;
};

struct ctl_table_root___64;

struct ctl_table_set___64;

struct ctl_dir___64;

struct ctl_table_header___64 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___64 *root;
	struct ctl_table_set___64 *set;
	struct ctl_dir___64 *parent;
	struct ctl_node___64 *node;
};

struct ctl_dir___64 {
	struct ctl_table_header___64 header;
	struct rb_root root;
};

struct ctl_table_set___64 {
	int (*is_seen)(struct ctl_table_set___64 *);
	struct ctl_dir___64 dir;
};

struct ctl_table_root___64 {
	struct ctl_table_set___64 default_set;
	struct ctl_table_set___64 * (*lookup)(struct ctl_table_root___64 *, struct nsproxy___139 *);
	int (*permissions)(struct ctl_table_header___64 *, struct ctl_table *);
};

struct net___64;

struct nsproxy___139 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___64 *net_ns;
};

struct bin_attribute___221;

struct attribute_group___219 {
	const char *name;
	umode_t (*is_visible)(struct kobject___42 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___221 **bin_attrs;
};

struct bin_attribute___221 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___259 *, struct kobject___42 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___259 *, struct kobject___42 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	int (*mmap)(struct file___259 *, struct kobject___42 *, struct bin_attribute___221 *, struct vm_area_struct___267 *);
};

struct dentry___259;

struct path___259 {
	struct vfsmount *mnt;
	struct dentry___259 *dentry;
};

struct inode___259;

struct file_operations___259;

struct file___259 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___259 f_path;
	struct inode___259 *f_inode;
	const struct file_operations___259 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___259 *f_mapping;
	struct mutex___261 f_pos_lock;
};

struct vm_operations_struct___233;

struct vm_area_struct___267 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___267 *vm_next;
	struct vm_area_struct___267 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___267 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___233 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___259 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___156 *, struct module_kobject___156 *, char *);
	ssize_t (*store)(struct module_attribute___156 *, struct module_kobject___156 *, const char *, size_t);
	void (*setup)(struct module___158 *, const char *);
	int (*test)(struct module___158 *);
	void (*free)(struct module___158 *);
};

struct xol_area___258 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___258 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___241;

struct memcg_cache_params___242;

struct kmem_cache___242 {
	struct kmem_cache_cpu___241 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___42 kobj;
	struct memcg_cache_params___242 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___259;

struct address_space___259 {
	struct inode___259 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___261 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___259 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___229;

struct vm_operations_struct___233 {
	void (*open)(struct vm_area_struct___267 *);
	void (*close)(struct vm_area_struct___267 *);
	int (*fault)(struct vm_area_struct___267 *, struct vm_fault___229 *);
	int (*page_mkwrite)(struct vm_area_struct___267 *, struct vm_fault___229 *);
	int (*access)(struct vm_area_struct___267 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___267 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___267 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___267 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___267 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___260 {
	struct task_struct___260 *task;
	struct core_thread___260 *next;
};

struct core_state___260 {
	atomic_t nr_threads;
	struct core_thread___260 dumper;
	struct completion startup;
};

struct signal_struct___260 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___260 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___260 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___261 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___154;

struct css_set___154 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___154 *subsys[11];
	struct callback_head callback_head;
};

struct file_lock___259;

struct seq_file___184;

struct file_operations___259 {
	struct module___158 *owner;
	loff_t (*llseek)(struct file___259 *, loff_t, int);
	ssize_t (*read)(struct file___259 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___259 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___259 *, void *, filldir_t);
	unsigned int (*poll)(struct file___259 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___259 *, struct vm_area_struct___267 *);
	int (*open)(struct inode___259 *, struct file___259 *);
	int (*flush)(struct file___259 *, fl_owner_t);
	int (*release)(struct inode___259 *, struct file___259 *);
	int (*fsync)(struct file___259 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___259 *, int);
	int (*lock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*sendpage)(struct file___259 *, struct page___258 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___259 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___259 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___259 *, long int, struct file_lock___259 **, void **);
		struct {
			int (*setlease)(struct file___259 *, long int, struct file_lock___259 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___259 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___184 *, struct file___259 *);
};

struct dma_map_ops___122 {
	void * (*alloc)(struct device___257 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___257 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___257 *, struct vm_area_struct___267 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___257 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___257 *, struct page___258 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___257 *, dma_addr_t);
	int (*dma_supported)(struct device___257 *, u64);
	int (*set_dma_mask)(struct device___257 *, u64);
	int is_phys;
};

struct bus_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___257 *, char *);
	ssize_t (*store)(struct bus_type___257 *, const char *, size_t);
};

struct device_attribute___257;

struct driver_attribute___257;

struct bus_type___257 {
	const char *name;
	const char *dev_name;
	struct device___257 *dev_root;
	struct bus_attribute___257 *bus_attrs;
	struct device_attribute___257 *dev_attrs;
	struct driver_attribute___257 *drv_attrs;
	const struct attribute_group___219 **bus_groups;
	const struct attribute_group___219 **dev_groups;
	const struct attribute_group___219 **drv_groups;
	int (*match)(struct device___257 *, struct device_driver___257 *);
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	int (*probe)(struct device___257 *);
	int (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*online)(struct device___257 *);
	int (*offline)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct device___257 *, struct device_attribute___257 *, char *);
	ssize_t (*store)(struct device___257 *, struct device_attribute___257 *, const char *, size_t);
};

struct driver_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___257 *, char *);
	ssize_t (*store)(struct device_driver___257 *, const char *, size_t);
};

struct device_driver___257 {
	const char *name;
	struct bus_type___257 *bus;
	struct module___158 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___257 *);
	int (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	const struct attribute_group___219 **groups;
	const struct dev_pm_ops___257 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___257 {
	const char *name;
	const struct attribute_group___219 **groups;
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
};

struct class_attribute___257;

struct class___257 {
	const char *name;
	struct module___158 *owner;
	struct class_attribute___257 *class_attrs;
	struct device_attribute___257 *dev_attrs;
	const struct attribute_group___219 **dev_groups;
	struct bin_attribute___221 *dev_bin_attrs;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *);
	void (*class_release)(struct class___257 *);
	void (*dev_release)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	const struct kobj_ns_type_operations___39 *ns_type;
	const void * (*namespace)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
	struct subsys_private *p;
};

struct class_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct class___257 *, struct class_attribute___257 *, char *);
	ssize_t (*store)(struct class___257 *, struct class_attribute___257 *, const char *, size_t);
	const void * (*namespace)(struct class___257 *, const struct class_attribute___257 *);
};

struct device_rh___257 {
	struct dev_pm_info_rh___257 power;
};

struct dev_pm_qos_request___61 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___257 *dev;
};

struct vm_fault___229 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___258 *page;
};

struct dentry_operations___259;

struct super_block___259;

struct dentry___259 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___259 *d_parent;
	struct qstr d_name;
	struct inode___259 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___259 *d_op;
	struct super_block___259 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___259;

struct dquot___259;

struct block_device___259;

struct inode___259 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___259 *i_op;
	struct super_block___259 *i_sb;
	struct address_space___259 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___261 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___259 *i_fop;
	struct file_lock___259 *i_flock;
	struct address_space___259 i_data;
	struct dquot___259 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___259 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___259 {
	int (*d_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_hash)(const struct dentry___259 *, struct qstr *);
	int (*d_compare)(const struct dentry___259 *, const struct dentry___259 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___259 *);
	void (*d_release)(struct dentry___259 *);
	void (*d_prune)(struct dentry___259 *);
	void (*d_iput)(struct dentry___259 *, struct inode___259 *);
	char * (*d_dname)(struct dentry___259 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___259 *);
	int (*d_manage)(struct dentry___259 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___259;

struct mem_dqinfo___259 {
	struct quota_format_type___259 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___259;

struct quota_info___259 {
	unsigned int flags;
	struct mutex___261 dqio_mutex;
	struct mutex___261 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___259 *files[2];
	struct mem_dqinfo___259 info[2];
	const struct quota_format_ops___259 *ops[2];
};

struct file_system_type___259;

struct super_operations___259;

struct dquot_operations___259;

struct quotactl_ops___259;

struct xattr_handler___155;

struct super_block___259 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___259 *s_type;
	const struct super_operations___259 *s_op;
	const struct dquot_operations___259 *dq_op;
	const struct quotactl_ops___259 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___259 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___155 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___259 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___259 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___261 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___259 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___259 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___259 *bd_inode;
	struct super_block___259 *bd_super;
	struct mutex___261 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___259 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___261 bd_fsfreeze_mutex;
};

struct cgroup___154;

struct cgroup_subsys_state___154 {
	struct cgroup___154 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___259 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___259 *ia_file;
};

struct dquot___259 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___261 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___259 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___259 {
	int qf_fmt_id;
	const struct quota_format_ops___259 *qf_ops;
	struct module___158 *qf_owner;
	struct quota_format_type___259 *qf_next;
};

struct quota_format_ops___259 {
	int (*check_quota_file)(struct super_block___259 *, int);
	int (*read_file_info)(struct super_block___259 *, int);
	int (*write_file_info)(struct super_block___259 *, int);
	int (*free_file_info)(struct super_block___259 *, int);
	int (*read_dqblk)(struct dquot___259 *);
	int (*commit_dqblk)(struct dquot___259 *);
	int (*release_dqblk)(struct dquot___259 *);
};

struct dquot_operations___259 {
	int (*write_dquot)(struct dquot___259 *);
	struct dquot___259 * (*alloc_dquot)(struct super_block___259 *, int);
	void (*destroy_dquot)(struct dquot___259 *);
	int (*acquire_dquot)(struct dquot___259 *);
	int (*release_dquot)(struct dquot___259 *);
	int (*mark_dirty)(struct dquot___259 *);
	int (*write_info)(struct super_block___259 *, int);
	qsize_t * (*get_reserved_space)(struct inode___259 *);
};

struct quotactl_ops___259 {
	int (*quota_on)(struct super_block___259 *, int, int, struct path___259 *);
	int (*quota_on_meta)(struct super_block___259 *, int, int);
	int (*quota_off)(struct super_block___259 *, int);
	int (*quota_sync)(struct super_block___259 *, int);
	int (*get_info)(struct super_block___259 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___259 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___259 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___259 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___259 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___259 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___259 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___259 *, unsigned int);
};

struct address_space_operations___259 {
	int (*writepage)(struct page___258 *, struct writeback_control *);
	int (*readpage)(struct file___259 *, struct page___258 *);
	int (*writepages)(struct address_space___259 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___258 *);
	int (*readpages)(struct file___259 *, struct address_space___259 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___259 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___258 **, void **);
	int (*write_end)(struct file___259 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___258 *, void *);
	sector_t (*bmap)(struct address_space___259 *, sector_t);
	void (*invalidatepage)(struct page___258 *, long unsigned int);
	int (*releasepage)(struct page___258 *, gfp_t);
	void (*freepage)(struct page___258 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___259 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___259 *, struct page___258 *, struct page___258 *, enum migrate_mode);
	int (*launder_page)(struct page___258 *);
	int (*is_partially_uptodate)(struct page___258 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___258 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___259 *, struct page___258 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___259 *, sector_t *);
	void (*swap_deactivate)(struct file___259 *);
	void (*invalidatepage_range)(struct page___258 *, unsigned int, unsigned int);
};

struct inode_operations___259 {
	struct dentry___259 * (*lookup)(struct inode___259 *, struct dentry___259 *, unsigned int);
	void * (*follow_link)(struct dentry___259 *, struct nameidata *);
	int (*permission)(struct inode___259 *, int);
	struct posix_acl * (*get_acl)(struct inode___259 *, int);
	int (*readlink)(struct dentry___259 *, char *, int);
	void (*put_link)(struct dentry___259 *, struct nameidata *, void *);
	int (*create)(struct inode___259 *, struct dentry___259 *, umode_t, bool);
	int (*link)(struct dentry___259 *, struct inode___259 *, struct dentry___259 *);
	int (*unlink)(struct inode___259 *, struct dentry___259 *);
	int (*symlink)(struct inode___259 *, struct dentry___259 *, const char *);
	int (*mkdir)(struct inode___259 *, struct dentry___259 *, umode_t);
	int (*rmdir)(struct inode___259 *, struct dentry___259 *);
	int (*mknod)(struct inode___259 *, struct dentry___259 *, umode_t, dev_t);
	int (*rename)(struct inode___259 *, struct dentry___259 *, struct inode___259 *, struct dentry___259 *);
	int (*setattr)(struct dentry___259 *, struct iattr___259 *);
	int (*getattr)(struct vfsmount *, struct dentry___259 *, struct kstat *);
	int (*setxattr)(struct dentry___259 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___259 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___259 *, char *, size_t);
	int (*removexattr)(struct dentry___259 *, const char *);
	int (*fiemap)(struct inode___259 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___259 *, struct timespec *, int);
	int (*atomic_open)(struct inode___259 *, struct dentry___259 *, struct file___259 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___259;

struct file_lock_operations___259;

struct lock_manager_operations___259;

struct file_lock___259 {
	struct file_lock___259 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___259 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___259 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___259 *fl_ops;
	const struct lock_manager_operations___259 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___259 {
	void (*fl_copy_lock)(struct file_lock___259 *, struct file_lock___259 *);
	void (*fl_release_private)(struct file_lock___259 *);
};

struct lock_manager_operations___259 {
	int (*lm_compare_owner)(struct file_lock___259 *, struct file_lock___259 *);
	long unsigned int (*lm_owner_key)(struct file_lock___259 *);
	void (*lm_notify)(struct file_lock___259 *);
	int (*lm_grant)(struct file_lock___259 *, struct file_lock___259 *, int);
	void (*lm_break)(struct file_lock___259 *);
	int (*lm_change)(struct file_lock___259 **, int);
};

struct fasync_struct___259 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___259 *fa_next;
	struct file___259 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___259 {
	const char *name;
	int fs_flags;
	struct dentry___259 * (*mount)(struct file_system_type___259 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___259 *);
	struct module___158 *owner;
	struct file_system_type___259 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___259 {
	struct inode___259 * (*alloc_inode)(struct super_block___259 *);
	void (*destroy_inode)(struct inode___259 *);
	void (*dirty_inode)(struct inode___259 *, int);
	int (*write_inode)(struct inode___259 *, struct writeback_control *);
	int (*drop_inode)(struct inode___259 *);
	void (*evict_inode)(struct inode___259 *);
	void (*put_super)(struct super_block___259 *);
	int (*sync_fs)(struct super_block___259 *, int);
	int (*freeze_fs)(struct super_block___259 *);
	int (*unfreeze_fs)(struct super_block___259 *);
	int (*statfs)(struct dentry___259 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___259 *, int *, char *);
	void (*umount_begin)(struct super_block___259 *);
	int (*show_options)(struct seq_file___184 *, struct dentry___259 *);
	int (*show_devname)(struct seq_file___184 *, struct dentry___259 *);
	int (*show_path)(struct seq_file___184 *, struct dentry___259 *);
	int (*show_stats)(struct seq_file___184 *, struct dentry___259 *);
	ssize_t (*quota_read)(struct super_block___259 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___259 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___259 *);
	int (*bdev_try_to_free_page)(struct super_block___259 *, struct page___258 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___259 *);
	void (*free_cached_objects)(struct super_block___259 *, int);
};

struct xattr_handler___155 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___259 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___259 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___259 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___184;

struct seq_file___184 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___261 lock;
	const struct seq_operations___184 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct netns_core___61 {
	struct ctl_table_header___64 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___62 {
	struct mutex___261 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___61 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___64 *ctl;
};

struct netns_ipv4___61 {
	struct ctl_table_header___64 *forw_hdr;
	struct ctl_table_header___64 *frags_hdr;
	struct ctl_table_header___64 *ipv4_hdr;
	struct ctl_table_header___64 *route_hdr;
	struct ctl_table_header___64 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___61 {
	struct ctl_table_header___64 *hdr;
	struct ctl_table_header___64 *route_hdr;
	struct ctl_table_header___64 *icmp_hdr;
	struct ctl_table_header___64 *frags_hdr;
	struct ctl_table_header___64 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct dst_entry___40;

struct net_device___50;

struct sk_buff___53;

struct neighbour___40;

struct dst_ops___63 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___63 *);
	struct dst_entry___40 * (*check)(struct dst_entry___40 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___40 *);
	unsigned int (*mtu)(const struct dst_entry___40 *);
	u32 * (*cow_metrics)(struct dst_entry___40 *, long unsigned int);
	void (*destroy)(struct dst_entry___40 *);
	void (*ifdown)(struct dst_entry___40 *, struct net_device___50 *, int);
	struct dst_entry___40 * (*negative_advice)(struct dst_entry___40 *);
	void (*link_failure)(struct sk_buff___53 *);
	void (*update_pmtu)(struct dst_entry___40 *, struct sock *, struct sk_buff___53 *, u32);
	void (*redirect)(struct dst_entry___40 *, struct sock *, struct sk_buff___53 *);
	int (*local_out)(struct sk_buff___53 *);
	struct neighbour___40 * (*neigh_lookup)(const struct dst_entry___40 *, struct sk_buff___53 *, const void *);
	struct kmem_cache___242 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___63 {
	struct netns_sysctl_ipv6___61 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___63 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___61 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___64 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___61 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___64 *nf_log_dir_header;
};

struct nf_proto_net___61 {
	struct ctl_table_header___64 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___61 {
	struct nf_proto_net___61 pn;
	unsigned int timeout;
};

struct nf_tcp_net___61 {
	struct nf_proto_net___61 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___61 {
	struct nf_proto_net___61 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___61 {
	struct nf_proto_net___61 pn;
	unsigned int timeout;
};

struct nf_ip_net___61 {
	struct nf_generic_net___61 generic;
	struct nf_tcp_net___61 tcp;
	struct nf_udp_net___61 udp;
	struct nf_icmp_net___61 icmp;
	struct nf_icmp_net___61 icmpv6;
};

struct netns_ct___62 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___64 *sysctl_header;
	struct ctl_table_header___64 *acct_sysctl_header;
	struct ctl_table_header___64 *tstamp_sysctl_header;
	struct ctl_table_header___64 *event_sysctl_header;
	struct ctl_table_header___64 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___242 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___61 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___61 {
	struct netns_sysctl_ipv6___61 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___50 {
	struct sk_buff___53 *next;
	struct sk_buff___53 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___63 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___64 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___63 xfrm4_dst_ops;
	struct dst_ops___63 xfrm6_dst_ops;
};

struct net___64 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___64 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___50 *loopback_dev;
	struct netns_core___61 core;
	struct netns_mib mib;
	struct netns_packet___62 packet;
	struct netns_unix___61 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___61 ipv4;
	struct netns_ipv6___63 ipv6;
	struct netns_sctp___61 sctp;
	struct netns_dccp___39 dccp;
	struct netns_nf___61 nf;
	struct netns_xt xt;
	struct netns_ct___62 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___61 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___50 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___63 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___261 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___261 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___241 {
	void **freelist;
	long unsigned int tid;
	struct page___258 *page;
	struct page___258 *partial;
};

struct memcg_cache_params___242 {
	bool is_root_cache;
	union {
		struct kmem_cache___242 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___242 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___49 {
	atomic_t use;
	unsigned int mask;
	struct net_device___50 *physindev;
	struct net_device___50 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___49(struct sk_buff___53 **);

struct net_device_ops___49;

struct ethtool_ops___49;

struct header_ops___49;

struct netdev_rx_queue___49;

struct netdev_queue___49;

struct Qdisc___6;

struct rtnl_link_ops___40;

struct dcbnl_rtnl_ops___49;

struct net_device___50 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___49 *netdev_ops;
	const struct ethtool_ops___49 *ethtool_ops;
	const struct header_ops___49 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___42 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___49 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___49 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___49 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___49 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___6 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___49 = 0,
		NETREG_REGISTERED___49 = 1,
		NETREG_UNREGISTERING___49 = 2,
		NETREG_UNREGISTERED___49 = 3,
		NETREG_RELEASED___49 = 4,
		NETREG_DUMMY___49 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___49 = 0,
		RTNL_LINK_INITIALIZING___49 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___50 *);
	struct netpoll_info *npinfo;
	struct net___64 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___257 dev;
	const struct attribute_group___219 *sysfs_groups[4];
	const struct rtnl_link_ops___40 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___49 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___53 {
	struct sk_buff___53 *next;
	struct sk_buff___53 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___50 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___53 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___49 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___8 {
	struct {
		struct page___258 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___8 skb_frag_t___8;

struct skb_shared_info___8 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___53 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___8 frags[17];
};

struct ethtool_ops___49 {
	int (*get_settings)(struct net_device___50 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___50 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___50 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___50 *);
	void (*get_regs)(struct net_device___50 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___50 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___50 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___50 *);
	void (*set_msglevel)(struct net_device___50 *, u32);
	int (*nway_reset)(struct net_device___50 *);
	u32 (*get_link)(struct net_device___50 *);
	int (*get_eeprom_len)(struct net_device___50 *);
	int (*get_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___50 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___50 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___50 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___50 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___50 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___50 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___50 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___50 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___50 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___50 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___50 *);
	void (*complete)(struct net_device___50 *);
	u32 (*get_priv_flags)(struct net_device___50 *);
	int (*set_priv_flags)(struct net_device___50 *, u32);
	int (*get_sset_count)(struct net_device___50 *, int);
	int (*get_rxnfc)(struct net_device___50 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___50 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___50 *, struct ethtool_flash *);
	int (*reset)(struct net_device___50 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___50 *);
	int (*get_rxfh_indir)(struct net_device___50 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___50 *, const u32 *);
	void (*get_channels)(struct net_device___50 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___50 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___50 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___50 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___50 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___50 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___50 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___50 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___50 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___50 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___50 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___50 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___40 {
	struct callback_head callback_head;
	struct dst_entry___40 *child;
	struct net_device___50 *dev;
	struct dst_ops___63 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___40 *path;
	struct dst_entry___40 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___53 *);
	union {
		int (*output)(struct sock *, struct sk_buff___53 *);
		struct {
			int (*output)(struct sk_buff___53 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___40 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___40;

struct neigh_parms___40;

struct neigh_ops___40;

struct neighbour___40 {
	struct neighbour___40 *next;
	struct neigh_table___40 *tbl;
	struct neigh_parms___40 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___50 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___40 *, struct sk_buff___53 *);
	const struct neigh_ops___40 *ops;
	struct callback_head rcu;
	struct net_device___50 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___63 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___53 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___53 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___64 *, struct dst_entry___40 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___53 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___53 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___183 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___183 *);
	void (*irq_shutdown)(struct irq_data___183 *);
	void (*irq_enable)(struct irq_data___183 *);
	void (*irq_disable)(struct irq_data___183 *);
	void (*irq_ack)(struct irq_data___183 *);
	void (*irq_mask)(struct irq_data___183 *);
	void (*irq_mask_ack)(struct irq_data___183 *);
	void (*irq_unmask)(struct irq_data___183 *);
	void (*irq_eoi)(struct irq_data___183 *);
	int (*irq_set_affinity)(struct irq_data___183 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___183 *);
	int (*irq_set_type)(struct irq_data___183 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___183 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___183 *);
	void (*irq_bus_sync_unlock)(struct irq_data___183 *);
	void (*irq_cpu_online)(struct irq_data___183 *);
	void (*irq_cpu_offline)(struct irq_data___183 *);
	void (*irq_suspend)(struct irq_data___183 *);
	void (*irq_resume)(struct irq_data___183 *);
	void (*irq_pm_shutdown)(struct irq_data___183 *);
	void (*irq_print_chip)(struct irq_data___183 *, struct seq_file___184 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___183 *, void *);
	long unsigned int flags;
};

struct seq_operations___184 {
	void * (*start)(struct seq_file___184 *, loff_t *);
	void (*stop)(struct seq_file___184 *, void *);
	void * (*next)(struct seq_file___184 *, void *, loff_t *);
	int (*show)(struct seq_file___184 *, void *);
};

struct dcbnl_rtnl_ops___49 {
	int (*ieee_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___50 *);
	u8 (*setstate)(struct net_device___50 *, u8);
	void (*getpermhwaddr)(struct net_device___50 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___50 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___50 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___50 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___50 *, int, u8 *);
	void (*setpfccfg)(struct net_device___50 *, int, u8);
	void (*getpfccfg)(struct net_device___50 *, int, u8 *);
	u8 (*setall)(struct net_device___50 *);
	u8 (*getcap)(struct net_device___50 *, int, u8 *);
	int (*getnumtcs)(struct net_device___50 *, int, u8 *);
	int (*setnumtcs)(struct net_device___50 *, int, u8);
	u8 (*getpfcstate)(struct net_device___50 *);
	void (*setpfcstate)(struct net_device___50 *, u8);
	void (*getbcncfg)(struct net_device___50 *, int, u32 *);
	void (*setbcncfg)(struct net_device___50 *, int, u32);
	void (*getbcnrp)(struct net_device___50 *, int, u8 *);
	void (*setbcnrp)(struct net_device___50 *, int, u8);
	u8 (*setapp)(struct net_device___50 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___50 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___50 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___50 *, int, u8);
	u8 (*getdcbx)(struct net_device___50 *);
	u8 (*setdcbx)(struct net_device___50 *, u8);
	int (*peer_getappinfo)(struct net_device___50 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___50 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___50 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___50 *, struct cee_pfc *);
};

struct cgroupfs_root___154;

struct cgroup___154 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___154 *parent;
	struct dentry___259 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___154 *subsys[11];
	struct cgroupfs_root___154 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___261 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___154 {
	struct super_block___259 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___154 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___51 {
	struct sk_buff___53 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___53 *, struct netlink_callback___51 *);
	int (*done)(struct netlink_callback___51 *);
	void *data;
	struct module___158 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___49 {
	int (*create)(struct sk_buff___53 *, struct net_device___50 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___53 *, unsigned char *);
	int (*rebuild)(struct sk_buff___53 *);
	int (*cache)(const struct neighbour___40 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___50 *, const unsigned char *);
};

struct napi_struct___49 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___49 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___50 *dev;
	struct sk_buff___53 *gro_list;
	struct sk_buff___53 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___49 {
	struct net_device___50 *dev;
	struct Qdisc___6 *qdisc;
	struct Qdisc___6 *qdisc_sleeping;
	struct kobject___42 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___6;

struct Qdisc___6 {
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___6 *);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___6 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___6 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___53 *, struct Qdisc___6 *);
	void *u32_node;
	struct Qdisc___6 *__parent;
	struct netdev_queue___49 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___6 *next_sched;
	struct sk_buff___53 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___50 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___49 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___42 kobj;
	struct net_device___50 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___49 {
	int (*ndo_init)(struct net_device___50 *);
	void (*ndo_uninit)(struct net_device___50 *);
	int (*ndo_open)(struct net_device___50 *);
	int (*ndo_stop)(struct net_device___50 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___53 *, struct net_device___50 *);
	u16 (*ndo_select_queue)(struct net_device___50 *, struct sk_buff___53 *);
	void (*ndo_change_rx_flags)(struct net_device___50 *, int);
	void (*ndo_set_rx_mode)(struct net_device___50 *);
	int (*ndo_set_mac_address)(struct net_device___50 *, void *);
	int (*ndo_validate_addr)(struct net_device___50 *);
	int (*ndo_do_ioctl)(struct net_device___50 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___50 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___50 *, int);
	int (*ndo_neigh_setup)(struct net_device___50 *, struct neigh_parms___40 *);
	void (*ndo_tx_timeout)(struct net_device___50 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___50 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___50 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___50 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___50 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___50 *);
	int (*ndo_netpoll_setup)(struct net_device___50 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___50 *);
	int (*ndo_busy_poll)(struct napi_struct___49 *);
	int (*ndo_set_vf_mac)(struct net_device___50 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___50 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___50 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___50 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___50 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___50 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___50 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___50 *, int, struct sk_buff___53 *);
	int (*ndo_setup_tc)(struct net_device___50 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___50 *);
	int (*ndo_fcoe_disable)(struct net_device___50 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___50 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___50 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___50 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___50 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___50 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___50 *, const struct sk_buff___53 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___50 *, struct net_device___50 *);
	int (*ndo_del_slave)(struct net_device___50 *, struct net_device___50 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___40 *);
	void (*ndo_neigh_destroy)(struct neighbour___40 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___53 *, struct netlink_callback___51 *, struct net_device___50 *, int);
	int (*ndo_bridge_setlink)(struct net_device___50 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___53 *, u32, u32, struct net_device___50 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___50 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___50 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___50 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___50 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___50 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___50 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___53 *, struct net_device___50 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___50 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___50 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___50 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___40 {
	struct net___64 *net;
	struct net_device___50 *dev;
	struct neigh_parms___40 *next;
	int (*neigh_setup)(struct neighbour___40 *);
	void (*neigh_cleanup)(struct neighbour___40 *);
	struct neigh_table___40 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___40 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___50 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___64 *, struct net_device___50 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___50 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___50 *, struct list_head *);
	size_t (*get_size)(const struct net_device___50 *);
	int (*fill_info)(struct sk_buff___53 *, const struct net_device___50 *);
	size_t (*get_xstats_size)(const struct net_device___50 *);
	int (*fill_xstats)(struct sk_buff___53 *, const struct net_device___50 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___64 * (*get_link_net)(const struct net_device___50 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___50 *, struct net_device___50 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___50 *, const struct net_device___50 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___53 *, const struct net_device___50 *, const struct net_device___50 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct softnet_data___4 {
	struct Qdisc___6 *output_queue;
	struct Qdisc___6 **output_queue_tailp;
	struct list_head poll_list;
	struct sk_buff___53 *completion_queue;
	struct sk_buff_head___50 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int cpu_collision;
	unsigned int received_rps;
	struct softnet_data___4 *rps_ipi_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct call_single_data csd;
	struct softnet_data___4 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_head;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___50 input_pkt_queue;
	struct napi_struct___49 backlog;
	long: 64;
	long: 64;
};

enum {
	TCA_UNSPEC = 0,
	TCA_KIND = 1,
	TCA_OPTIONS = 2,
	TCA_STATS = 3,
	TCA_XSTATS = 4,
	TCA_RATE = 5,
	TCA_FCNT = 6,
	TCA_STATS2 = 7,
	TCA_STAB = 8,
	__TCA_MAX = 9,
};

struct tc_ratespec {
	unsigned char cell_log;
	__u8 linklayer;
	short unsigned int overhead;
	short int cell_align;
	short unsigned int mpu;
	__u32 rate;
};

struct tc_prio_qopt {
	int bands;
	__u8 priomap[16];
};

struct gnet_dump___7 {
	spinlock_t *lock;
	struct sk_buff___53 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___6;

struct Qdisc_ops___6 {
	struct Qdisc_ops___6 *next;
	const struct Qdisc_class_ops___6 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___6 *);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___6 *);
	struct sk_buff___53 * (*peek)(struct Qdisc___6 *);
	unsigned int (*drop)(struct Qdisc___6 *);
	int (*init)(struct Qdisc___6 *, struct nlattr *);
	void (*reset)(struct Qdisc___6 *);
	void (*destroy)(struct Qdisc___6 *);
	int (*change)(struct Qdisc___6 *, struct nlattr *);
	void (*attach)(struct Qdisc___6 *);
	int (*dump)(struct Qdisc___6 *, struct sk_buff___53 *);
	int (*dump_stats)(struct Qdisc___6 *, struct gnet_dump___7 *);
	struct module___158 *owner;
};

struct qdisc_walker___6;

struct tcf_proto___6;

struct Qdisc_class_ops___6 {
	struct netdev_queue___49 * (*select_queue)(struct Qdisc___6 *, struct tcmsg *);
	int (*graft)(struct Qdisc___6 *, long unsigned int, struct Qdisc___6 *, struct Qdisc___6 **);
	struct Qdisc___6 * (*leaf)(struct Qdisc___6 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___6 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___6 *, u32);
	void (*put)(struct Qdisc___6 *, long unsigned int);
	int (*change)(struct Qdisc___6 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___6 *, long unsigned int);
	void (*walk)(struct Qdisc___6 *, struct qdisc_walker___6 *);
	struct tcf_proto___6 ** (*tcf_chain)(struct Qdisc___6 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___6 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___6 *, long unsigned int);
	int (*dump)(struct Qdisc___6 *, long unsigned int, struct sk_buff___53 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___6 *, long unsigned int, struct gnet_dump___7 *);
};

struct qdisc_walker___6 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___6 *, long unsigned int, struct qdisc_walker___6 *);
};

struct tcf_proto_ops___6;

struct tcf_proto___6 {
	struct tcf_proto___6 *next;
	void *root;
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___6 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___6 *q;
	void *data;
	const struct tcf_proto_ops___6 *ops;
};

struct tcf_proto_ops___6 {
	struct tcf_proto_ops___6 *next;
	char kind[16];
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___6 *, struct tcf_result *);
	int (*init)(struct tcf_proto___6 *);
	void (*destroy)(struct tcf_proto___6 *);
	long unsigned int (*get)(struct tcf_proto___6 *, u32);
	void (*put)(struct tcf_proto___6 *, long unsigned int);
	int (*change)(struct net___64 *, struct sk_buff___53 *, struct tcf_proto___6 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___6 *, long unsigned int);
	void (*walk)(struct tcf_proto___6 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___6 *, long unsigned int, struct sk_buff___53 *, struct tcmsg *);
	struct module___158 *owner;
};

struct psched_ratecfg {
	u64 rate_bytes_ps;
	u32 mult;
	u16 overhead;
	u8 linklayer;
	u8 shift;
};

struct pneigh_entry___40;

struct neigh_hash_table___40;

struct neigh_table___40 {
	struct neigh_table___40 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___50 *, __u32 *);
	int (*constructor)(struct neighbour___40 *);
	int (*pconstructor)(struct pneigh_entry___40 *);
	void (*pdestructor)(struct pneigh_entry___40 *);
	void (*proxy_redo)(struct sk_buff___53 *);
	char *id;
	struct neigh_parms___40 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___50 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___40 *nht;
	struct pneigh_entry___40 **phash_buckets;
};

struct neigh_ops___40 {
	int family;
	void (*solicit)(struct neighbour___40 *, struct sk_buff___53 *);
	void (*error_report)(struct neighbour___40 *, struct sk_buff___53 *);
	int (*output)(struct neighbour___40 *, struct sk_buff___53 *);
	int (*connected_output)(struct neighbour___40 *, struct sk_buff___53 *);
};

struct pneigh_entry___40 {
	struct pneigh_entry___40 *next;
	struct net___64 *net;
	struct net_device___50 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___40 {
	struct neighbour___40 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct pfifo_fast_priv {
	u32 bitmap;
	struct sk_buff_head___50 q[3];
};

struct mq_sched {
	struct Qdisc___4 **qdiscs;
};

enum tc_link_layer {
	TC_LINKLAYER_UNAWARE = 0,
	TC_LINKLAYER_ETHERNET = 1,
	TC_LINKLAYER_ATM = 2,
};

enum {
	TCA_STAB_UNSPEC = 0,
	TCA_STAB_BASE = 1,
	TCA_STAB_DATA = 2,
	__TCA_STAB_MAX = 3,
};

struct qdisc_rate_table {
	struct tc_ratespec rate;
	u32 data[256];
	struct qdisc_rate_table *next;
	int refcnt;
};

struct Qdisc_class_common {
	u32 classid;
	struct hlist_node hnode;
};

struct Qdisc_class_hash {
	struct hlist_head *hash;
	unsigned int hashsize;
	unsigned int hashmask;
	unsigned int hashelems;
};

struct qdisc_watchdog {
	struct hrtimer timer;
	struct Qdisc___4 *qdisc;
};

struct check_loop_arg {
	struct qdisc_walker___4 w;
	struct Qdisc___4 *p;
	int depth;
};

struct qdisc_dump_args {
	struct qdisc_walker___4 w;
	struct sk_buff___45 *skb;
	struct netlink_callback___43 *cb;
};

enum {
	TCA_ACT_UNSPEC = 0,
	TCA_ACT_KIND = 1,
	TCA_ACT_OPTIONS = 2,
	TCA_ACT_INDEX = 3,
	TCA_ACT_STATS = 4,
	__TCA_ACT_MAX = 5,
};

struct tcf_t {
	__u64 install;
	__u64 lastuse;
	__u64 expires;
};

struct tcf_walker {
	int stop;
	int skip;
	int count;
	int (*fn)(struct tcf_proto___4 *, long unsigned int, struct tcf_walker *);
};

struct tcf_common {
	struct tcf_common *tcfc_next;
	u32 tcfc_index;
	int tcfc_refcnt;
	int tcfc_bindcnt;
	u32 tcfc_capab;
	int tcfc_action;
	struct tcf_t tcfc_tm;
	struct gnet_stats_basic_packed tcfc_bstats;
	struct gnet_stats_queue tcfc_qstats;
	struct gnet_stats_rate_est64 tcfc_rate_est;
	spinlock_t tcfc_lock;
	struct callback_head tcfc_rcu;
};

struct tcf_hashinfo {
	struct tcf_common **htab;
	unsigned int hmask;
	rwlock_t *lock;
};

struct tc_action_ops;

struct tc_action {
	void *priv;
	const struct tc_action_ops *ops;
	__u32 type;
	__u32 order;
	struct tc_action *next;
};

struct tc_action_ops {
	struct tc_action_ops *next;
	struct tcf_hashinfo *hinfo;
	char kind[16];
	__u32 type;
	__u32 capab;
	struct module___153 *owner;
	int (*act)(struct sk_buff___45 *, const struct tc_action *, struct tcf_result *);
	int (*get_stats)(struct sk_buff___45 *, struct tc_action *);
	int (*dump)(struct sk_buff___45 *, struct tc_action *, int, int);
	int (*cleanup)(struct tc_action *, int);
	int (*lookup)(struct tc_action *, u32);
	int (*init)(struct net___55 *, struct nlattr *, struct nlattr *, struct tc_action *, int, int);
	int (*walk)(struct sk_buff___45 *, struct netlink_callback___43 *, int, struct tc_action *);
};

struct tcf_exts {
	struct tc_action *action;
};

struct tcf_ext_map {
	int action;
	int police;
};

struct tcf_dump_args {
	struct tcf_walker w;
	struct sk_buff___45 *skb;
	struct netlink_callback___43 *cb;
};

struct tcamsg {
	unsigned char tca_family;
	unsigned char tca__pad1;
	short unsigned int tca__pad2;
};

struct tcf_act_hdr {
	struct tcf_common common;
};

struct tc_fifo_qopt {
	__u32 limit;
};

struct page___259;

typedef struct page___259 *pgtable_t___259;

struct address_space___260;

struct kmem_cache___243;

struct page___259 {
	long unsigned int flags;
	struct address_space___260 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___259 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___259 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___243 *slab_cache;
		struct page___259 *first_page;
	};
	long: 64;
};

struct task_struct___261;

struct pv_cpu_ops___261 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___261 *);
	void (*end_context_switch)(struct task_struct___261 *);
};

struct mutex___262 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___261 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___254 {
	struct page___259 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___268;

struct files_struct___15;

struct nsproxy___140;

struct signal_struct___261;

struct css_set___155;

struct task_struct___261 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___261 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___268 *mm;
	struct mm_struct___268 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___261 *real_parent;
	struct task_struct___261 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___261 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___261 = 0,
		VTIME_USER___261 = 1,
		VTIME_SYS___261 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct___15 *files;
	struct nsproxy___140 *nsproxy;
	struct signal_struct___261 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___155 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___262 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___254 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___268 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___268 *, struct mm_struct___268 *);
	void (*dup_mmap)(struct mm_struct___268 *, struct mm_struct___268 *);
	void (*exit_mmap)(struct mm_struct___268 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___268 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___268 *);
	void (*pgd_free)(struct mm_struct___268 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___268 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___268 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___268 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___268 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___268 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___268 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___268 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___268 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___268 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___268 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___268 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___262 lock;
	void *vdso;
} mm_context_t___262;

struct xol_area___259;

struct uprobes_state___259 {
	struct xol_area___259 *xol_area;
};

struct vm_area_struct___268;

struct file___260;

struct core_state___261;

struct mm_struct___268 {
	struct vm_area_struct___268 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___268 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___268 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___262 context;
	long unsigned int flags;
	struct core_state___261 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___261 *owner;
	struct file___260 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___259 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___159;

struct exec_domain___73 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___159 *module;
	struct exec_domain___73 *next;
};

struct kset___43;

struct kobj_type___43;

struct kobject___43 {
	const char *name;
	struct list_head entry;
	struct kobject___43 *parent;
	struct kset___43 *kset;
	struct kobj_type___43 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___157 {
	struct kobject___43 kobj;
	struct module___159 *mod;
	struct kobject___43 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___157;

struct module___159 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___157 mkobj;
	struct module_attribute___157 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___43 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___261 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___120 {
	struct task_struct___261 *task;
	struct exec_domain___73 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___261;

struct lruvec___261 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___261 *zone;
};

struct pglist_data___261;

struct zone___261 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___261 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___261 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___261 {
	struct zone___261 *zone;
	int zone_idx;
};

struct zonelist___261 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___261 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___261 {
	struct zone___261 node_zones[4];
	struct zonelist___261 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___261 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___184;

struct x86_io_apic_ops___184 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___184 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___184;

struct irq_data___184 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___184 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___258;

struct dev_pm_ops___258 {
	int (*prepare)(struct device___258 *);
	void (*complete)(struct device___258 *);
	int (*suspend)(struct device___258 *);
	int (*resume)(struct device___258 *);
	int (*freeze)(struct device___258 *);
	int (*thaw)(struct device___258 *);
	int (*poweroff)(struct device___258 *);
	int (*restore)(struct device___258 *);
	int (*suspend_late)(struct device___258 *);
	int (*resume_early)(struct device___258 *);
	int (*freeze_late)(struct device___258 *);
	int (*thaw_early)(struct device___258 *);
	int (*poweroff_late)(struct device___258 *);
	int (*restore_early)(struct device___258 *);
	int (*suspend_noirq)(struct device___258 *);
	int (*resume_noirq)(struct device___258 *);
	int (*freeze_noirq)(struct device___258 *);
	int (*thaw_noirq)(struct device___258 *);
	int (*poweroff_noirq)(struct device___258 *);
	int (*restore_noirq)(struct device___258 *);
	int (*runtime_suspend)(struct device___258 *);
	int (*runtime_resume)(struct device___258 *);
	int (*runtime_idle)(struct device___258 *);
};

struct dev_pm_qos___61;

struct dev_pm_info___61 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___61 *qos;
};

struct dma_map_ops___123;

struct dev_archdata___123 {
	struct dma_map_ops___123 *dma_ops;
	void *iommu;
};

struct device_type___258;

struct bus_type___258;

struct device_driver___258;

struct dev_pm_domain___258;

struct class___258;

struct attribute_group___220;

struct device_rh___258;

struct device___258 {
	struct device___258 *parent;
	struct device_private *p;
	struct kobject___43 kobj;
	const char *init_name;
	const struct device_type___258 *type;
	struct mutex___262 mutex;
	struct bus_type___258 *bus;
	struct device_driver___258 *driver;
	void *platform_data;
	struct dev_pm_info___61 power;
	struct dev_pm_domain___258 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___123 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___258 *class;
	const struct attribute_group___220 **groups;
	void (*release)(struct device___258 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___258 *device_rh;
};

struct dev_pm_qos_request___62;

struct dev_pm_qos___61 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___62 *latency_req;
	struct dev_pm_qos_request___62 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___62 *latency_tolerance_req;
};

struct dev_pm_info_rh___258 {
	void (*set_latency_tolerance)(struct device___258 *, s32);
};

struct dev_pm_domain___258 {
	struct dev_pm_ops___258 ops;
};

struct smp_ops___261 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___261 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___65;

struct ctl_node___65 {
	struct rb_node node;
	struct ctl_table_header___65 *header;
};

struct ctl_table_root___65;

struct ctl_table_set___65;

struct ctl_dir___65;

struct ctl_table_header___65 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___65 *root;
	struct ctl_table_set___65 *set;
	struct ctl_dir___65 *parent;
	struct ctl_node___65 *node;
};

struct ctl_dir___65 {
	struct ctl_table_header___65 header;
	struct rb_root root;
};

struct ctl_table_set___65 {
	int (*is_seen)(struct ctl_table_set___65 *);
	struct ctl_dir___65 dir;
};

struct ctl_table_root___65 {
	struct ctl_table_set___65 default_set;
	struct ctl_table_set___65 * (*lookup)(struct ctl_table_root___65 *, struct nsproxy___140 *);
	int (*permissions)(struct ctl_table_header___65 *, struct ctl_table *);
};

struct net___65;

struct nsproxy___140 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___65 *net_ns;
};

struct sock___42;

struct kobj_ns_type_operations___40 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___42 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___40;

struct sock_common___40 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___40 *skc_prot;
	struct net___65 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___54;

struct sk_buff_head___51 {
	struct sk_buff___54 *next;
	struct sk_buff___54 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___41;

struct socket_wq___40;

struct dst_entry___41;

struct socket___41;

struct cg_proto___40;

struct sock___42 {
	struct sock_common___40 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___51 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___54 *head;
		struct sk_buff___54 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___41 *sk_filter;
	struct socket_wq___40 *sk_wq;
	struct sk_buff_head___51 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___41 *sk_rx_dst;
	struct dst_entry___41 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___51 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___51 sk_error_queue;
	struct proto___40 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___41 *sk_socket;
	void *sk_user_data;
	struct page_frag___254 sk_frag;
	struct sk_buff___54 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___40 *sk_cgrp;
	void (*sk_state_change)(struct sock___42 *);
	void (*sk_data_ready)(struct sock___42 *, int);
	void (*sk_write_space)(struct sock___42 *);
	void (*sk_error_report)(struct sock___42 *);
	int (*sk_backlog_rcv)(struct sock___42 *, struct sk_buff___54 *);
	void (*sk_destruct)(struct sock___42 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___222;

struct attribute_group___220 {
	const char *name;
	umode_t (*is_visible)(struct kobject___43 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___222 **bin_attrs;
};

struct bin_attribute___222 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___260 *, struct kobject___43 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___260 *, struct kobject___43 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	int (*mmap)(struct file___260 *, struct kobject___43 *, struct bin_attribute___222 *, struct vm_area_struct___268 *);
};

struct dentry___260;

struct path___260 {
	struct vfsmount *mnt;
	struct dentry___260 *dentry;
};

struct inode___260;

struct file_operations___260;

struct file___260 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___260 f_path;
	struct inode___260 *f_inode;
	const struct file_operations___260 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___260 *f_mapping;
	struct mutex___262 f_pos_lock;
};

struct vm_operations_struct___234;

struct vm_area_struct___268 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___268 *vm_next;
	struct vm_area_struct___268 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___268 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___234 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___260 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___43 {
	ssize_t (*show)(struct kobject___43 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___43 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___43 *, const struct attribute *);
};

struct kset_uevent_ops___43;

struct kset___43 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___43 kobj;
	const struct kset_uevent_ops___43 *uevent_ops;
};

struct kobj_type___43 {
	void (*release)(struct kobject___43 *);
	const struct sysfs_ops___43 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___40 * (*child_ns_type)(struct kobject___43 *);
	const void * (*namespace)(struct kobject___43 *);
};

struct kset_uevent_ops___43 {
	int (* const filter)(struct kset___43 *, struct kobject___43 *);
	const char * (* const name)(struct kset___43 *, struct kobject___43 *);
	int (* const uevent)(struct kset___43 *, struct kobject___43 *, struct kobj_uevent_env *);
};

struct module_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___157 *, struct module_kobject___157 *, char *);
	ssize_t (*store)(struct module_attribute___157 *, struct module_kobject___157 *, const char *, size_t);
	void (*setup)(struct module___159 *, const char *);
	int (*test)(struct module___159 *);
	void (*free)(struct module___159 *);
};

struct kmem_cache_cpu___242 {
	void **freelist;
	long unsigned int tid;
	struct page___259 *page;
	struct page___259 *partial;
};

struct memcg_cache_params___243;

struct kmem_cache___243 {
	struct kmem_cache_cpu___242 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___43 kobj;
	struct memcg_cache_params___243 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___243 {
	bool is_root_cache;
	union {
		struct kmem_cache___243 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___243 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___259 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___259 *page;
	long unsigned int vaddr;
};

struct address_space_operations___260;

struct address_space___260 {
	struct inode___260 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___262 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___260 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___230;

struct vm_operations_struct___234 {
	void (*open)(struct vm_area_struct___268 *);
	void (*close)(struct vm_area_struct___268 *);
	int (*fault)(struct vm_area_struct___268 *, struct vm_fault___230 *);
	int (*page_mkwrite)(struct vm_area_struct___268 *, struct vm_fault___230 *);
	int (*access)(struct vm_area_struct___268 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___268 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___268 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___268 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___268 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___261 {
	struct task_struct___261 *task;
	struct core_thread___261 *next;
};

struct core_state___261 {
	atomic_t nr_threads;
	struct core_thread___261 dumper;
	struct completion startup;
};

struct fasync_struct___260;

struct socket_wq___40 {
	wait_queue_head_t wait;
	struct fasync_struct___260 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___260 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___260 *fa_next;
	struct file___260 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___40;

struct socket___41 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___40 *wq;
	struct file___260 *file;
	struct sock___42 *sk;
	const struct proto_ops___40 *ops;
};

struct poll_table_struct___147;

struct kiocb___48;

struct proto_ops___40 {
	int family;
	struct module___159 *owner;
	int (*release)(struct socket___41 *);
	int (*bind)(struct socket___41 *, struct sockaddr *, int);
	int (*connect)(struct socket___41 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___41 *, struct socket___41 *);
	int (*accept)(struct socket___41 *, struct socket___41 *, int);
	int (*getname)(struct socket___41 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___260 *, struct socket___41 *, struct poll_table_struct___147 *);
	int (*ioctl)(struct socket___41 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___41 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___41 *, int);
	int (*shutdown)(struct socket___41 *, int);
	int (*setsockopt)(struct socket___41 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___41 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___41 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___41 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___48 *, struct socket___41 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___48 *, struct socket___41 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___260 *, struct socket___41 *, struct vm_area_struct___268 *);
	ssize_t (*sendpage)(struct socket___41 *, struct page___259 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___41 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___42 *, int);
		struct {
			void (*set_peek_off)(struct sock___42 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___149)(struct file___260 *, wait_queue_head_t *, struct poll_table_struct___147 *);

struct poll_table_struct___147 {
	poll_queue_proc___149 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___48(struct kiocb___48 *, struct io_event *);

struct kiocb___48 {
	atomic_t ki_users;
	struct file___260 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___48 *ki_cancel;
	void (*ki_dtor)(struct kiocb___48 *);
	union {
		void *user;
		struct task_struct___261 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___62 {
	struct ctl_table_header___65 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___63 {
	struct mutex___262 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___62 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___65 *ctl;
};

struct netns_ipv4___62 {
	struct ctl_table_header___65 *forw_hdr;
	struct ctl_table_header___65 *frags_hdr;
	struct ctl_table_header___65 *ipv4_hdr;
	struct ctl_table_header___65 *route_hdr;
	struct ctl_table_header___65 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___42 *fibnl;
	struct sock___42 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___62 {
	struct ctl_table_header___65 *hdr;
	struct ctl_table_header___65 *route_hdr;
	struct ctl_table_header___65 *icmp_hdr;
	struct ctl_table_header___65 *frags_hdr;
	struct ctl_table_header___65 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___51;

struct neighbour___41;

struct dst_ops___64 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___64 *);
	struct dst_entry___41 * (*check)(struct dst_entry___41 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___41 *);
	unsigned int (*mtu)(const struct dst_entry___41 *);
	u32 * (*cow_metrics)(struct dst_entry___41 *, long unsigned int);
	void (*destroy)(struct dst_entry___41 *);
	void (*ifdown)(struct dst_entry___41 *, struct net_device___51 *, int);
	struct dst_entry___41 * (*negative_advice)(struct dst_entry___41 *);
	void (*link_failure)(struct sk_buff___54 *);
	void (*update_pmtu)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___54 *, u32);
	void (*redirect)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___54 *);
	int (*local_out)(struct sk_buff___54 *);
	struct neighbour___41 * (*neigh_lookup)(const struct dst_entry___41 *, struct sk_buff___54 *, const void *);
	struct kmem_cache___243 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___64 {
	struct netns_sysctl_ipv6___62 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___64 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___42 **icmp_sk;
	struct sock___42 *ndisc_sk;
	struct sock___42 *tcp_sk;
	struct sock___42 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___62 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___65 *sysctl_header;
	struct sock___42 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___40 {
	struct sock___42 *v4_ctl_sk;
	struct sock___42 *v6_ctl_sk;
};

struct netns_nf___62 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___65 *nf_log_dir_header;
};

struct nf_proto_net___62 {
	struct ctl_table_header___65 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___62 {
	struct nf_proto_net___62 pn;
	unsigned int timeout;
};

struct nf_tcp_net___62 {
	struct nf_proto_net___62 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___62 {
	struct nf_proto_net___62 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___62 {
	struct nf_proto_net___62 pn;
	unsigned int timeout;
};

struct nf_ip_net___62 {
	struct nf_generic_net___62 generic;
	struct nf_tcp_net___62 tcp;
	struct nf_udp_net___62 udp;
	struct nf_icmp_net___62 icmp;
	struct nf_icmp_net___62 icmpv6;
};

struct netns_ct___63 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___65 *sysctl_header;
	struct ctl_table_header___65 *acct_sysctl_header;
	struct ctl_table_header___65 *tstamp_sysctl_header;
	struct ctl_table_header___65 *event_sysctl_header;
	struct ctl_table_header___65 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___243 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___62 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___62 {
	struct netns_sysctl_ipv6___62 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___64 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___42 *nlsk;
	struct sock___42 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___65 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___64 xfrm4_dst_ops;
	struct dst_ops___64 xfrm6_dst_ops;
};

struct net___65 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___65 sysctls;
	struct sock___42 *rtnl;
	struct sock___42 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___51 *loopback_dev;
	struct netns_core___62 core;
	struct netns_mib mib;
	struct netns_packet___63 packet;
	struct netns_unix___62 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___62 ipv4;
	struct netns_ipv6___64 ipv6;
	struct netns_sctp___62 sctp;
	struct netns_dccp___40 dccp;
	struct netns_nf___62 nf;
	struct netns_xt xt;
	struct netns_ct___63 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___62 nf_frag;
	struct sock___42 *nfnl;
	struct sock___42 *nfnl_stash;
	struct sk_buff_head___51 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___64 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___42 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___42 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___262 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___262 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___123 {
	void * (*alloc)(struct device___258 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___258 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___258 *, struct vm_area_struct___268 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___258 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___258 *, struct page___259 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___258 *, dma_addr_t);
	int (*dma_supported)(struct device___258 *, u64);
	int (*set_dma_mask)(struct device___258 *, u64);
	int is_phys;
};

struct bus_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___258 *, char *);
	ssize_t (*store)(struct bus_type___258 *, const char *, size_t);
};

struct device_attribute___258;

struct driver_attribute___258;

struct bus_type___258 {
	const char *name;
	const char *dev_name;
	struct device___258 *dev_root;
	struct bus_attribute___258 *bus_attrs;
	struct device_attribute___258 *dev_attrs;
	struct driver_attribute___258 *drv_attrs;
	const struct attribute_group___220 **bus_groups;
	const struct attribute_group___220 **dev_groups;
	const struct attribute_group___220 **drv_groups;
	int (*match)(struct device___258 *, struct device_driver___258 *);
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	int (*probe)(struct device___258 *);
	int (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*online)(struct device___258 *);
	int (*offline)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct device___258 *, struct device_attribute___258 *, char *);
	ssize_t (*store)(struct device___258 *, struct device_attribute___258 *, const char *, size_t);
};

struct driver_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___258 *, char *);
	ssize_t (*store)(struct device_driver___258 *, const char *, size_t);
};

struct device_driver___258 {
	const char *name;
	struct bus_type___258 *bus;
	struct module___159 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___258 *);
	int (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	const struct attribute_group___220 **groups;
	const struct dev_pm_ops___258 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___258 {
	const char *name;
	const struct attribute_group___220 **groups;
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
};

struct class_attribute___258;

struct class___258 {
	const char *name;
	struct module___159 *owner;
	struct class_attribute___258 *class_attrs;
	struct device_attribute___258 *dev_attrs;
	const struct attribute_group___220 **dev_groups;
	struct bin_attribute___222 *dev_bin_attrs;
	struct kobject___43 *dev_kobj;
	int (*dev_uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *);
	void (*class_release)(struct class___258 *);
	void (*dev_release)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	const struct kobj_ns_type_operations___40 *ns_type;
	const void * (*namespace)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
	struct subsys_private *p;
};

struct class_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct class___258 *, struct class_attribute___258 *, char *);
	ssize_t (*store)(struct class___258 *, struct class_attribute___258 *, const char *, size_t);
	const void * (*namespace)(struct class___258 *, const struct class_attribute___258 *);
};

struct device_rh___258 {
	struct dev_pm_info_rh___258 power;
};

struct vm_fault___230 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___259 *page;
};

struct signal_struct___261 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___261 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___261 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___262 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fdtable___15 {
	unsigned int max_fds;
	struct file___260 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	struct callback_head rcu;
};

struct files_struct___15 {
	atomic_t count;
	struct fdtable___15 *fdt;
	struct fdtable___15 fdtab;
	spinlock_t file_lock;
	int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	struct file___260 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_subsys_state___155;

struct css_set___155 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___155 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___50 {
	atomic_t use;
	unsigned int mask;
	struct net_device___51 *physindev;
	struct net_device___51 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___50(struct sk_buff___54 **);

struct net_device_ops___50;

struct ethtool_ops___50;

struct header_ops___50;

struct netdev_rx_queue___50;

struct netdev_queue___50;

struct Qdisc___7;

struct rtnl_link_ops___41;

struct dcbnl_rtnl_ops___50;

struct net_device___51 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___50 *netdev_ops;
	const struct ethtool_ops___50 *ethtool_ops;
	const struct header_ops___50 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___43 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___50 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___50 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___50 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___50 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___7 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___50 = 0,
		NETREG_REGISTERED___50 = 1,
		NETREG_UNREGISTERING___50 = 2,
		NETREG_UNREGISTERED___50 = 3,
		NETREG_RELEASED___50 = 4,
		NETREG_DUMMY___50 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___50 = 0,
		RTNL_LINK_INITIALIZING___50 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___51 *);
	struct netpoll_info *npinfo;
	struct net___65 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___258 dev;
	const struct attribute_group___220 *sysfs_groups[4];
	const struct rtnl_link_ops___41 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___50 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___54 {
	struct sk_buff___54 *next;
	struct sk_buff___54 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___42 *sk;
	struct net_device___51 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___54 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___50 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xattr_handler___156 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___260 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___260 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___260 *, const char *, const void *, size_t, int, int);
};

struct dentry_operations___260;

struct super_block___260;

struct dentry___260 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___260 *d_parent;
	struct qstr d_name;
	struct inode___260 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___260 *d_op;
	struct super_block___260 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___260;

struct file_lock___260;

struct dquot___260;

struct block_device___260;

struct inode___260 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___260 *i_op;
	struct super_block___260 *i_sb;
	struct address_space___260 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___262 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___260 *i_fop;
	struct file_lock___260 *i_flock;
	struct address_space___260 i_data;
	struct dquot___260 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___260 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___260 {
	int (*d_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_hash)(const struct dentry___260 *, struct qstr *);
	int (*d_compare)(const struct dentry___260 *, const struct dentry___260 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___260 *);
	void (*d_release)(struct dentry___260 *);
	void (*d_prune)(struct dentry___260 *);
	void (*d_iput)(struct dentry___260 *, struct inode___260 *);
	char * (*d_dname)(struct dentry___260 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___260 *);
	int (*d_manage)(struct dentry___260 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___260;

struct mem_dqinfo___260 {
	struct quota_format_type___260 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___260;

struct quota_info___260 {
	unsigned int flags;
	struct mutex___262 dqio_mutex;
	struct mutex___262 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___260 *files[2];
	struct mem_dqinfo___260 info[2];
	const struct quota_format_ops___260 *ops[2];
};

struct file_system_type___260;

struct super_operations___260;

struct dquot_operations___260;

struct quotactl_ops___260;

struct super_block___260 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___260 *s_type;
	const struct super_operations___260 *s_op;
	const struct dquot_operations___260 *dq_op;
	const struct quotactl_ops___260 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___260 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___156 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___260 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___260 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___262 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___260 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___260 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___260 *bd_inode;
	struct super_block___260 *bd_super;
	struct mutex___262 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___260 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___262 bd_fsfreeze_mutex;
};

struct cgroup___155;

struct cgroup_subsys_state___155 {
	struct cgroup___155 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___260 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___260 *ia_file;
};

struct dquot___260 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___262 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___260 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___260 {
	int qf_fmt_id;
	const struct quota_format_ops___260 *qf_ops;
	struct module___159 *qf_owner;
	struct quota_format_type___260 *qf_next;
};

struct quota_format_ops___260 {
	int (*check_quota_file)(struct super_block___260 *, int);
	int (*read_file_info)(struct super_block___260 *, int);
	int (*write_file_info)(struct super_block___260 *, int);
	int (*free_file_info)(struct super_block___260 *, int);
	int (*read_dqblk)(struct dquot___260 *);
	int (*commit_dqblk)(struct dquot___260 *);
	int (*release_dqblk)(struct dquot___260 *);
};

struct dquot_operations___260 {
	int (*write_dquot)(struct dquot___260 *);
	struct dquot___260 * (*alloc_dquot)(struct super_block___260 *, int);
	void (*destroy_dquot)(struct dquot___260 *);
	int (*acquire_dquot)(struct dquot___260 *);
	int (*release_dquot)(struct dquot___260 *);
	int (*mark_dirty)(struct dquot___260 *);
	int (*write_info)(struct super_block___260 *, int);
	qsize_t * (*get_reserved_space)(struct inode___260 *);
};

struct quotactl_ops___260 {
	int (*quota_on)(struct super_block___260 *, int, int, struct path___260 *);
	int (*quota_on_meta)(struct super_block___260 *, int, int);
	int (*quota_off)(struct super_block___260 *, int);
	int (*quota_sync)(struct super_block___260 *, int);
	int (*get_info)(struct super_block___260 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___260 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___260 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___260 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___260 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___260 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___260 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___260 *, unsigned int);
};

struct address_space_operations___260 {
	int (*writepage)(struct page___259 *, struct writeback_control *);
	int (*readpage)(struct file___260 *, struct page___259 *);
	int (*writepages)(struct address_space___260 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___259 *);
	int (*readpages)(struct file___260 *, struct address_space___260 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___260 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___259 **, void **);
	int (*write_end)(struct file___260 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___259 *, void *);
	sector_t (*bmap)(struct address_space___260 *, sector_t);
	void (*invalidatepage)(struct page___259 *, long unsigned int);
	int (*releasepage)(struct page___259 *, gfp_t);
	void (*freepage)(struct page___259 *);
	ssize_t (*direct_IO)(int, struct kiocb___48 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___260 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___260 *, struct page___259 *, struct page___259 *, enum migrate_mode);
	int (*launder_page)(struct page___259 *);
	int (*is_partially_uptodate)(struct page___259 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___259 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___260 *, struct page___259 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___260 *, sector_t *);
	void (*swap_deactivate)(struct file___260 *);
	void (*invalidatepage_range)(struct page___259 *, unsigned int, unsigned int);
};

struct inode_operations___260 {
	struct dentry___260 * (*lookup)(struct inode___260 *, struct dentry___260 *, unsigned int);
	void * (*follow_link)(struct dentry___260 *, struct nameidata *);
	int (*permission)(struct inode___260 *, int);
	struct posix_acl * (*get_acl)(struct inode___260 *, int);
	int (*readlink)(struct dentry___260 *, char *, int);
	void (*put_link)(struct dentry___260 *, struct nameidata *, void *);
	int (*create)(struct inode___260 *, struct dentry___260 *, umode_t, bool);
	int (*link)(struct dentry___260 *, struct inode___260 *, struct dentry___260 *);
	int (*unlink)(struct inode___260 *, struct dentry___260 *);
	int (*symlink)(struct inode___260 *, struct dentry___260 *, const char *);
	int (*mkdir)(struct inode___260 *, struct dentry___260 *, umode_t);
	int (*rmdir)(struct inode___260 *, struct dentry___260 *);
	int (*mknod)(struct inode___260 *, struct dentry___260 *, umode_t, dev_t);
	int (*rename)(struct inode___260 *, struct dentry___260 *, struct inode___260 *, struct dentry___260 *);
	int (*setattr)(struct dentry___260 *, struct iattr___260 *);
	int (*getattr)(struct vfsmount *, struct dentry___260 *, struct kstat *);
	int (*setxattr)(struct dentry___260 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___260 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___260 *, char *, size_t);
	int (*removexattr)(struct dentry___260 *, const char *);
	int (*fiemap)(struct inode___260 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___260 *, struct timespec *, int);
	int (*atomic_open)(struct inode___260 *, struct dentry___260 *, struct file___260 *, unsigned int, umode_t, int *);
	long: 64;
};

typedef struct files_struct___15 *fl_owner_t___15;

struct seq_file___185;

struct file_operations___260 {
	struct module___159 *owner;
	loff_t (*llseek)(struct file___260 *, loff_t, int);
	ssize_t (*read)(struct file___260 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___260 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___48 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___48 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___260 *, void *, filldir_t);
	unsigned int (*poll)(struct file___260 *, struct poll_table_struct___147 *);
	long int (*unlocked_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___260 *, struct vm_area_struct___268 *);
	int (*open)(struct inode___260 *, struct file___260 *);
	int (*flush)(struct file___260 *, fl_owner_t___15);
	int (*release)(struct inode___260 *, struct file___260 *);
	int (*fsync)(struct file___260 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___48 *, int);
	int (*fasync)(int, struct file___260 *, int);
	int (*lock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*sendpage)(struct file___260 *, struct page___259 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___260 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___260 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___260 *, long int, struct file_lock___260 **, void **);
		struct {
			int (*setlease)(struct file___260 *, long int, struct file_lock___260 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___260 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___185 *, struct file___260 *);
};

struct file_lock_operations___260;

struct lock_manager_operations___260;

struct file_lock___260 {
	struct file_lock___260 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t___15 fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___260 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___260 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___260 *fl_ops;
	const struct lock_manager_operations___260 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___260 {
	void (*fl_copy_lock)(struct file_lock___260 *, struct file_lock___260 *);
	void (*fl_release_private)(struct file_lock___260 *);
};

struct lock_manager_operations___260 {
	int (*lm_compare_owner)(struct file_lock___260 *, struct file_lock___260 *);
	long unsigned int (*lm_owner_key)(struct file_lock___260 *);
	void (*lm_notify)(struct file_lock___260 *);
	int (*lm_grant)(struct file_lock___260 *, struct file_lock___260 *, int);
	void (*lm_break)(struct file_lock___260 *);
	int (*lm_change)(struct file_lock___260 **, int);
};

struct file_system_type___260 {
	const char *name;
	int fs_flags;
	struct dentry___260 * (*mount)(struct file_system_type___260 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___260 *);
	struct module___159 *owner;
	struct file_system_type___260 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___260 {
	struct inode___260 * (*alloc_inode)(struct super_block___260 *);
	void (*destroy_inode)(struct inode___260 *);
	void (*dirty_inode)(struct inode___260 *, int);
	int (*write_inode)(struct inode___260 *, struct writeback_control *);
	int (*drop_inode)(struct inode___260 *);
	void (*evict_inode)(struct inode___260 *);
	void (*put_super)(struct super_block___260 *);
	int (*sync_fs)(struct super_block___260 *, int);
	int (*freeze_fs)(struct super_block___260 *);
	int (*unfreeze_fs)(struct super_block___260 *);
	int (*statfs)(struct dentry___260 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___260 *, int *, char *);
	void (*umount_begin)(struct super_block___260 *);
	int (*show_options)(struct seq_file___185 *, struct dentry___260 *);
	int (*show_devname)(struct seq_file___185 *, struct dentry___260 *);
	int (*show_path)(struct seq_file___185 *, struct dentry___260 *);
	int (*show_stats)(struct seq_file___185 *, struct dentry___260 *);
	ssize_t (*quota_read)(struct super_block___260 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___260 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___260 *);
	int (*bdev_try_to_free_page)(struct super_block___260 *, struct page___259 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___260 *);
	void (*free_cached_objects)(struct super_block___260 *, int);
};

struct seq_operations___185;

struct seq_file___185 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___262 lock;
	const struct seq_operations___185 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct cgroupfs_root___155;

struct cgroup___155 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___155 *parent;
	struct dentry___260 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___155 *subsys[11];
	struct cgroupfs_root___155 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___262 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___155 {
	struct super_block___260 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___155 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___92 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___260 *, struct file___260 *);
	ssize_t (*read)(struct cgroup___155 *, struct cftype___92 *, struct file___260 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___155 *, struct cftype___92 *);
	s64 (*read_s64)(struct cgroup___155 *, struct cftype___92 *);
	int (*read_map)(struct cgroup___155 *, struct cftype___92 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___155 *, struct cftype___92 *, struct seq_file___185 *);
	ssize_t (*write)(struct cgroup___155 *, struct cftype___92 *, struct file___260 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___155 *, struct cftype___92 *, u64);
	int (*write_s64)(struct cgroup___155 *, struct cftype___92 *, s64);
	int (*write_string)(struct cgroup___155 *, struct cftype___92 *, const char *);
	int (*trigger)(struct cgroup___155 *, unsigned int);
	int (*release)(struct inode___260 *, struct file___260 *);
	int (*register_event)(struct cgroup___155 *, struct cftype___92 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___155 *, struct cftype___92 *, struct eventfd_ctx *);
};

struct cftype_set___88 {
	struct list_head node;
	struct cftype___92 *cfts;
};

struct task_and_cgroup___88 {
	struct task_struct___261 *task;
	struct cgroup___155 *cgrp;
	struct css_set___155 *cg;
};

struct cgroup_taskset___88 {
	struct task_and_cgroup___88 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___155 *cur_cgrp;
};

struct cgroup_subsys___88 {
	struct cgroup_subsys_state___155 * (*css_alloc)(struct cgroup___155 *);
	int (*css_online)(struct cgroup___155 *);
	void (*css_offline)(struct cgroup___155 *);
	void (*css_free)(struct cgroup___155 *);
	int (*can_attach)(struct cgroup___155 *, struct cgroup_taskset___88 *);
	void (*cancel_attach)(struct cgroup___155 *, struct cgroup_taskset___88 *);
	void (*attach)(struct cgroup___155 *, struct cgroup_taskset___88 *);
	void (*fork)(struct task_struct___261 *);
	void (*exit)(struct cgroup___155 *, struct cgroup___155 *, struct task_struct___261 *);
	void (*bind)(struct cgroup___155 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___155 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___92 *base_cftypes;
	struct cftype_set___88 base_cftset;
	struct module___159 *module;
};

struct dev_pm_qos_request___62 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___258 *dev;
};

struct ethtool_ops___50 {
	int (*get_settings)(struct net_device___51 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___51 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___51 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___51 *);
	void (*get_regs)(struct net_device___51 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___51 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___51 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___51 *);
	void (*set_msglevel)(struct net_device___51 *, u32);
	int (*nway_reset)(struct net_device___51 *);
	u32 (*get_link)(struct net_device___51 *);
	int (*get_eeprom_len)(struct net_device___51 *);
	int (*get_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___51 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___51 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___51 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___51 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___51 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___51 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___51 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___51 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___51 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___51 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___51 *);
	void (*complete)(struct net_device___51 *);
	u32 (*get_priv_flags)(struct net_device___51 *);
	int (*set_priv_flags)(struct net_device___51 *, u32);
	int (*get_sset_count)(struct net_device___51 *, int);
	int (*get_rxnfc)(struct net_device___51 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___51 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___51 *, struct ethtool_flash *);
	int (*reset)(struct net_device___51 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___51 *);
	int (*get_rxfh_indir)(struct net_device___51 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___51 *, const u32 *);
	void (*get_channels)(struct net_device___51 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___51 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___51 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___51 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___51 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___51 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___51 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___51 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___51 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___51 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___51 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___51 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___41 {
	struct callback_head callback_head;
	struct dst_entry___41 *child;
	struct net_device___51 *dev;
	struct dst_ops___64 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___41 *path;
	struct dst_entry___41 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___54 *);
	union {
		int (*output)(struct sock___42 *, struct sk_buff___54 *);
		struct {
			int (*output)(struct sk_buff___54 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___41 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___41;

struct neigh_parms___41;

struct neigh_ops___41;

struct neighbour___41 {
	struct neighbour___41 *next;
	struct neigh_table___41 *tbl;
	struct neigh_parms___41 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___51 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___41 *, struct sk_buff___54 *);
	const struct neigh_ops___41 *ops;
	struct callback_head rcu;
	struct net_device___51 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___64 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___54 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___54 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___65 *, struct dst_entry___41 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___54 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___54 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___184 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___184 *);
	void (*irq_shutdown)(struct irq_data___184 *);
	void (*irq_enable)(struct irq_data___184 *);
	void (*irq_disable)(struct irq_data___184 *);
	void (*irq_ack)(struct irq_data___184 *);
	void (*irq_mask)(struct irq_data___184 *);
	void (*irq_mask_ack)(struct irq_data___184 *);
	void (*irq_unmask)(struct irq_data___184 *);
	void (*irq_eoi)(struct irq_data___184 *);
	int (*irq_set_affinity)(struct irq_data___184 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___184 *);
	int (*irq_set_type)(struct irq_data___184 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___184 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___184 *);
	void (*irq_bus_sync_unlock)(struct irq_data___184 *);
	void (*irq_cpu_online)(struct irq_data___184 *);
	void (*irq_cpu_offline)(struct irq_data___184 *);
	void (*irq_suspend)(struct irq_data___184 *);
	void (*irq_resume)(struct irq_data___184 *);
	void (*irq_pm_shutdown)(struct irq_data___184 *);
	void (*irq_print_chip)(struct irq_data___184 *, struct seq_file___185 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___184 *, void *);
	long unsigned int flags;
};

struct seq_operations___185 {
	void * (*start)(struct seq_file___185 *, loff_t *);
	void (*stop)(struct seq_file___185 *, void *);
	void * (*next)(struct seq_file___185 *, void *, loff_t *);
	int (*show)(struct seq_file___185 *, void *);
};

struct dcbnl_rtnl_ops___50 {
	int (*ieee_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___51 *);
	u8 (*setstate)(struct net_device___51 *, u8);
	void (*getpermhwaddr)(struct net_device___51 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___51 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___51 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___51 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___51 *, int, u8 *);
	void (*setpfccfg)(struct net_device___51 *, int, u8);
	void (*getpfccfg)(struct net_device___51 *, int, u8 *);
	u8 (*setall)(struct net_device___51 *);
	u8 (*getcap)(struct net_device___51 *, int, u8 *);
	int (*getnumtcs)(struct net_device___51 *, int, u8 *);
	int (*setnumtcs)(struct net_device___51 *, int, u8);
	u8 (*getpfcstate)(struct net_device___51 *);
	void (*setpfcstate)(struct net_device___51 *, u8);
	void (*getbcncfg)(struct net_device___51 *, int, u32 *);
	void (*setbcncfg)(struct net_device___51 *, int, u32);
	void (*getbcnrp)(struct net_device___51 *, int, u8 *);
	void (*setbcnrp)(struct net_device___51 *, int, u8);
	u8 (*setapp)(struct net_device___51 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___51 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___51 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___51 *, int, u8);
	u8 (*getdcbx)(struct net_device___51 *);
	u8 (*setdcbx)(struct net_device___51 *, u8);
	int (*peer_getappinfo)(struct net_device___51 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___51 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___51 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___51 *, struct cee_pfc *);
};

struct netlink_callback___52 {
	struct sk_buff___54 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___54 *, struct netlink_callback___52 *);
	int (*done)(struct netlink_callback___52 *);
	void *data;
	struct module___159 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___50 {
	int (*create)(struct sk_buff___54 *, struct net_device___51 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___54 *, unsigned char *);
	int (*rebuild)(struct sk_buff___54 *);
	int (*cache)(const struct neighbour___41 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___51 *, const unsigned char *);
};

struct napi_struct___50 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___50 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___51 *dev;
	struct sk_buff___54 *gro_list;
	struct sk_buff___54 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___50 {
	struct net_device___51 *dev;
	struct Qdisc___7 *qdisc;
	struct Qdisc___7 *qdisc_sleeping;
	struct kobject___43 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___7;

struct Qdisc___7 {
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___7 *);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___7 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___7 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___54 *, struct Qdisc___7 *);
	void *u32_node;
	struct Qdisc___7 *__parent;
	struct netdev_queue___50 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___7 *next_sched;
	struct sk_buff___54 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___51 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___50 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___43 kobj;
	struct net_device___51 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___50 {
	int (*ndo_init)(struct net_device___51 *);
	void (*ndo_uninit)(struct net_device___51 *);
	int (*ndo_open)(struct net_device___51 *);
	int (*ndo_stop)(struct net_device___51 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___54 *, struct net_device___51 *);
	u16 (*ndo_select_queue)(struct net_device___51 *, struct sk_buff___54 *);
	void (*ndo_change_rx_flags)(struct net_device___51 *, int);
	void (*ndo_set_rx_mode)(struct net_device___51 *);
	int (*ndo_set_mac_address)(struct net_device___51 *, void *);
	int (*ndo_validate_addr)(struct net_device___51 *);
	int (*ndo_do_ioctl)(struct net_device___51 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___51 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___51 *, int);
	int (*ndo_neigh_setup)(struct net_device___51 *, struct neigh_parms___41 *);
	void (*ndo_tx_timeout)(struct net_device___51 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___51 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___51 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___51 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___51 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___51 *);
	int (*ndo_netpoll_setup)(struct net_device___51 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___51 *);
	int (*ndo_busy_poll)(struct napi_struct___50 *);
	int (*ndo_set_vf_mac)(struct net_device___51 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___51 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___51 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___51 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___51 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___51 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___51 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___51 *, int, struct sk_buff___54 *);
	int (*ndo_setup_tc)(struct net_device___51 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___51 *);
	int (*ndo_fcoe_disable)(struct net_device___51 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___51 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___51 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___51 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___51 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___51 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___51 *, const struct sk_buff___54 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___51 *, struct net_device___51 *);
	int (*ndo_del_slave)(struct net_device___51 *, struct net_device___51 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___41 *);
	void (*ndo_neigh_destroy)(struct neighbour___41 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___54 *, struct netlink_callback___52 *, struct net_device___51 *, int);
	int (*ndo_bridge_setlink)(struct net_device___51 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___54 *, u32, u32, struct net_device___51 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___51 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___51 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___51 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___51 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___51 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___51 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___54 *, struct net_device___51 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___51 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___51 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___51 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___41 {
	struct net___65 *net;
	struct net_device___51 *dev;
	struct neigh_parms___41 *next;
	int (*neigh_setup)(struct neighbour___41 *);
	void (*neigh_cleanup)(struct neighbour___41 *);
	struct neigh_table___41 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___41 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___51 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___65 *, struct net_device___51 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___51 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___51 *, struct list_head *);
	size_t (*get_size)(const struct net_device___51 *);
	int (*fill_info)(struct sk_buff___54 *, const struct net_device___51 *);
	size_t (*get_xstats_size)(const struct net_device___51 *);
	int (*fill_xstats)(struct sk_buff___54 *, const struct net_device___51 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___65 * (*get_link_net)(const struct net_device___51 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___51 *, struct net_device___51 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___51 *, const struct net_device___51 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___54 *, const struct net_device___51 *, const struct net_device___51 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	TCA_CGROUP_UNSPEC = 0,
	TCA_CGROUP_ACT = 1,
	TCA_CGROUP_POLICE = 2,
	TCA_CGROUP_EMATCHES = 3,
	__TCA_CGROUP_MAX = 4,
};

struct tcf_ematch_tree_hdr {
	__u16 nmatches;
	__u16 progid;
};

struct gnet_dump___8 {
	spinlock_t *lock;
	struct sk_buff___54 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___7;

struct Qdisc_ops___7 {
	struct Qdisc_ops___7 *next;
	const struct Qdisc_class_ops___7 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___7 *);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___7 *);
	struct sk_buff___54 * (*peek)(struct Qdisc___7 *);
	unsigned int (*drop)(struct Qdisc___7 *);
	int (*init)(struct Qdisc___7 *, struct nlattr *);
	void (*reset)(struct Qdisc___7 *);
	void (*destroy)(struct Qdisc___7 *);
	int (*change)(struct Qdisc___7 *, struct nlattr *);
	void (*attach)(struct Qdisc___7 *);
	int (*dump)(struct Qdisc___7 *, struct sk_buff___54 *);
	int (*dump_stats)(struct Qdisc___7 *, struct gnet_dump___8 *);
	struct module___159 *owner;
};

struct qdisc_walker___7;

struct tcf_proto___7;

struct Qdisc_class_ops___7 {
	struct netdev_queue___50 * (*select_queue)(struct Qdisc___7 *, struct tcmsg *);
	int (*graft)(struct Qdisc___7 *, long unsigned int, struct Qdisc___7 *, struct Qdisc___7 **);
	struct Qdisc___7 * (*leaf)(struct Qdisc___7 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___7 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___7 *, u32);
	void (*put)(struct Qdisc___7 *, long unsigned int);
	int (*change)(struct Qdisc___7 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___7 *, long unsigned int);
	void (*walk)(struct Qdisc___7 *, struct qdisc_walker___7 *);
	struct tcf_proto___7 ** (*tcf_chain)(struct Qdisc___7 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___7 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___7 *, long unsigned int);
	int (*dump)(struct Qdisc___7 *, long unsigned int, struct sk_buff___54 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___7 *, long unsigned int, struct gnet_dump___8 *);
};

struct qdisc_walker___7 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___7 *, long unsigned int, struct qdisc_walker___7 *);
};

struct tcf_proto_ops___7;

struct tcf_proto___7 {
	struct tcf_proto___7 *next;
	void *root;
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___7 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___7 *q;
	void *data;
	const struct tcf_proto_ops___7 *ops;
};

struct tcf_walker___2;

struct tcf_proto_ops___7 {
	struct tcf_proto_ops___7 *next;
	char kind[16];
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___7 *, struct tcf_result *);
	int (*init)(struct tcf_proto___7 *);
	void (*destroy)(struct tcf_proto___7 *);
	long unsigned int (*get)(struct tcf_proto___7 *, u32);
	void (*put)(struct tcf_proto___7 *, long unsigned int);
	int (*change)(struct net___65 *, struct sk_buff___54 *, struct tcf_proto___7 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___7 *, long unsigned int);
	void (*walk)(struct tcf_proto___7 *, struct tcf_walker___2 *);
	int (*dump)(struct tcf_proto___7 *, long unsigned int, struct sk_buff___54 *, struct tcmsg *);
	struct module___159 *owner;
};

struct tcf_walker___2 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct tcf_proto___7 *, long unsigned int, struct tcf_walker___2 *);
};

struct tc_action_ops___2;

struct tc_action___2 {
	void *priv;
	const struct tc_action_ops___2 *ops;
	__u32 type;
	__u32 order;
	struct tc_action___2 *next;
};

struct tc_action_ops___2 {
	struct tc_action_ops___2 *next;
	struct tcf_hashinfo *hinfo;
	char kind[16];
	__u32 type;
	__u32 capab;
	struct module___159 *owner;
	int (*act)(struct sk_buff___54 *, const struct tc_action___2 *, struct tcf_result *);
	int (*get_stats)(struct sk_buff___54 *, struct tc_action___2 *);
	int (*dump)(struct sk_buff___54 *, struct tc_action___2 *, int, int);
	int (*cleanup)(struct tc_action___2 *, int);
	int (*lookup)(struct tc_action___2 *, u32);
	int (*init)(struct net___65 *, struct nlattr *, struct nlattr *, struct tc_action___2 *, int, int);
	int (*walk)(struct sk_buff___54 *, struct netlink_callback___52 *, int, struct tc_action___2 *);
};

struct tcf_exts___2 {
	struct tc_action___2 *action;
};

struct tcf_pkt_info {
	unsigned char *ptr;
	int nexthdr;
};

struct tcf_ematch_ops;

struct tcf_ematch {
	struct tcf_ematch_ops *ops;
	long unsigned int data;
	unsigned int datalen;
	u16 matchid;
	u16 flags;
};

struct tcf_ematch_ops {
	int kind;
	int datalen;
	int (*change)(struct tcf_proto___7 *, void *, int, struct tcf_ematch *);
	int (*match)(struct sk_buff___54 *, struct tcf_ematch *, struct tcf_pkt_info *);
	void (*destroy)(struct tcf_proto___7 *, struct tcf_ematch *);
	int (*dump)(struct sk_buff___54 *, struct tcf_ematch *);
	struct module___159 *owner;
	struct list_head link;
};

struct tcf_ematch_tree {
	struct tcf_ematch_tree_hdr hdr;
	struct tcf_ematch *matches;
};

struct sk_filter___41 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___54 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___41;

struct neigh_hash_table___41;

struct neigh_table___41 {
	struct neigh_table___41 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___51 *, __u32 *);
	int (*constructor)(struct neighbour___41 *);
	int (*pconstructor)(struct pneigh_entry___41 *);
	void (*pdestructor)(struct pneigh_entry___41 *);
	void (*proxy_redo)(struct sk_buff___54 *);
	char *id;
	struct neigh_parms___41 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___51 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___41 *nht;
	struct pneigh_entry___41 **phash_buckets;
};

struct neigh_ops___41 {
	int family;
	void (*solicit)(struct neighbour___41 *, struct sk_buff___54 *);
	void (*error_report)(struct neighbour___41 *, struct sk_buff___54 *);
	int (*output)(struct neighbour___41 *, struct sk_buff___54 *);
	int (*connected_output)(struct neighbour___41 *, struct sk_buff___54 *);
};

struct pneigh_entry___41 {
	struct pneigh_entry___41 *next;
	struct net___65 *net;
	struct net_device___51 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___41 {
	struct neighbour___41 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___40 {
	void (*close)(struct sock___42 *, long int);
	int (*connect)(struct sock___42 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___42 *, int);
	struct sock___42 * (*accept)(struct sock___42 *, int, int *);
	int (*ioctl)(struct sock___42 *, int, long unsigned int);
	int (*init)(struct sock___42 *);
	void (*destroy)(struct sock___42 *);
	void (*shutdown)(struct sock___42 *, int);
	int (*setsockopt)(struct sock___42 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___42 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___42 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___42 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___42 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___48 *, struct sock___42 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___48 *, struct sock___42 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___42 *, struct page___259 *, int, size_t, int);
	int (*bind)(struct sock___42 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___42 *, struct sk_buff___54 *);
	void (*release_cb)(struct sock___42 *);
	void (*mtu_reduced)(struct sock___42 *);
	void (*hash)(struct sock___42 *);
	void (*unhash)(struct sock___42 *);
	void (*rehash)(struct sock___42 *);
	int (*get_port)(struct sock___42 *, short unsigned int);
	void (*clear_sk)(struct sock___42 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___42 *);
	void (*enter_memory_pressure)(struct sock___42 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___243 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___159 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___88 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___40 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___40 {
	void (*enter_memory_pressure)(struct sock___42 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct cgroup_cls_state___2 {
	struct cgroup_subsys_state___155 css;
	u32 classid;
};

struct cls_cgroup_head {
	u32 handle;
	struct tcf_exts___2 exts;
	struct tcf_ematch_tree ematches;
};

struct page___260;

typedef struct page___260 *pgtable_t___260;

struct address_space___261;

struct kmem_cache___244;

struct page___260 {
	long unsigned int flags;
	struct address_space___261 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___260 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___260 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___244 *slab_cache;
		struct page___260 *first_page;
	};
	long: 64;
};

struct task_struct___262;

struct pv_cpu_ops___262 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___262 *);
	void (*end_context_switch)(struct task_struct___262 *);
};

struct mutex___263 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___262 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___255 {
	struct page___260 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___269;

struct nsproxy___141;

struct signal_struct___262;

struct css_set___156;

struct task_struct___262 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___262 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___269 *mm;
	struct mm_struct___269 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___262 *real_parent;
	struct task_struct___262 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___262 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___262 = 0,
		VTIME_USER___262 = 1,
		VTIME_SYS___262 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___141 *nsproxy;
	struct signal_struct___262 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___156 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___263 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___255 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___269 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___269 *, struct mm_struct___269 *);
	void (*dup_mmap)(struct mm_struct___269 *, struct mm_struct___269 *);
	void (*exit_mmap)(struct mm_struct___269 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___269 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___269 *);
	void (*pgd_free)(struct mm_struct___269 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___269 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___269 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___269 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___269 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___269 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___269 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___269 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___269 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___269 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___269 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___269 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___263 lock;
	void *vdso;
} mm_context_t___263;

struct xol_area___260;

struct uprobes_state___260 {
	struct xol_area___260 *xol_area;
};

struct vm_area_struct___269;

struct file___261;

struct core_state___262;

struct mm_struct___269 {
	struct vm_area_struct___269 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___269 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___269 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___263 context;
	long unsigned int flags;
	struct core_state___262 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___262 *owner;
	struct file___261 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___260 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___160;

struct module_kobject___158 {
	struct kobject___43 kobj;
	struct module___160 *mod;
	struct kobject___43 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___158;

struct module___160 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___158 mkobj;
	struct module_attribute___158 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___43 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___262 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___262;

struct lruvec___262 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___262 *zone;
};

struct pglist_data___262;

struct zone___262 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___262 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___262 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___262 {
	struct zone___262 *zone;
	int zone_idx;
};

struct zonelist___262 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___262 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___262 {
	struct zone___262 node_zones[4];
	struct zonelist___262 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___262 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___185;

struct x86_io_apic_ops___185 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___185 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___185;

struct irq_data___185 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___185 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___259;

struct dev_pm_ops___259 {
	int (*prepare)(struct device___259 *);
	void (*complete)(struct device___259 *);
	int (*suspend)(struct device___259 *);
	int (*resume)(struct device___259 *);
	int (*freeze)(struct device___259 *);
	int (*thaw)(struct device___259 *);
	int (*poweroff)(struct device___259 *);
	int (*restore)(struct device___259 *);
	int (*suspend_late)(struct device___259 *);
	int (*resume_early)(struct device___259 *);
	int (*freeze_late)(struct device___259 *);
	int (*thaw_early)(struct device___259 *);
	int (*poweroff_late)(struct device___259 *);
	int (*restore_early)(struct device___259 *);
	int (*suspend_noirq)(struct device___259 *);
	int (*resume_noirq)(struct device___259 *);
	int (*freeze_noirq)(struct device___259 *);
	int (*thaw_noirq)(struct device___259 *);
	int (*poweroff_noirq)(struct device___259 *);
	int (*restore_noirq)(struct device___259 *);
	int (*runtime_suspend)(struct device___259 *);
	int (*runtime_resume)(struct device___259 *);
	int (*runtime_idle)(struct device___259 *);
};

struct dev_pm_qos___62;

struct dev_pm_info___62 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___62 *qos;
};

struct dma_map_ops___124;

struct dev_archdata___124 {
	struct dma_map_ops___124 *dma_ops;
	void *iommu;
};

struct device_type___259;

struct bus_type___259;

struct device_driver___259;

struct dev_pm_domain___259;

struct class___259;

struct attribute_group___221;

struct device_rh___259;

struct device___259 {
	struct device___259 *parent;
	struct device_private *p;
	struct kobject___43 kobj;
	const char *init_name;
	const struct device_type___259 *type;
	struct mutex___263 mutex;
	struct bus_type___259 *bus;
	struct device_driver___259 *driver;
	void *platform_data;
	struct dev_pm_info___62 power;
	struct dev_pm_domain___259 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___124 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___259 *class;
	const struct attribute_group___221 **groups;
	void (*release)(struct device___259 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___259 *device_rh;
};

struct dev_pm_qos_request___63;

struct dev_pm_qos___62 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___63 *latency_req;
	struct dev_pm_qos_request___63 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___63 *latency_tolerance_req;
};

struct dev_pm_info_rh___259 {
	void (*set_latency_tolerance)(struct device___259 *, s32);
};

struct dev_pm_domain___259 {
	struct dev_pm_ops___259 ops;
};

struct smp_ops___262 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___262 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___66;

struct ctl_node___66 {
	struct rb_node node;
	struct ctl_table_header___66 *header;
};

struct ctl_table_root___66;

struct ctl_table_set___66;

struct ctl_dir___66;

struct ctl_table_header___66 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___66 *root;
	struct ctl_table_set___66 *set;
	struct ctl_dir___66 *parent;
	struct ctl_node___66 *node;
};

struct ctl_dir___66 {
	struct ctl_table_header___66 header;
	struct rb_root root;
};

struct ctl_table_set___66 {
	int (*is_seen)(struct ctl_table_set___66 *);
	struct ctl_dir___66 dir;
};

struct ctl_table_root___66 {
	struct ctl_table_set___66 default_set;
	struct ctl_table_set___66 * (*lookup)(struct ctl_table_root___66 *, struct nsproxy___141 *);
	int (*permissions)(struct ctl_table_header___66 *, struct ctl_table *);
};

struct net___66;

struct nsproxy___141 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___66 *net_ns;
};

struct bin_attribute___223;

struct attribute_group___221 {
	const char *name;
	umode_t (*is_visible)(struct kobject___43 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___223 **bin_attrs;
};

struct bin_attribute___223 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___261 *, struct kobject___43 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___261 *, struct kobject___43 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	int (*mmap)(struct file___261 *, struct kobject___43 *, struct bin_attribute___223 *, struct vm_area_struct___269 *);
};

struct dentry___261;

struct path___261 {
	struct vfsmount *mnt;
	struct dentry___261 *dentry;
};

struct inode___261;

struct file_operations___261;

struct file___261 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___261 f_path;
	struct inode___261 *f_inode;
	const struct file_operations___261 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___261 *f_mapping;
	struct mutex___263 f_pos_lock;
};

struct vm_operations_struct___235;

struct vm_area_struct___269 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___269 *vm_next;
	struct vm_area_struct___269 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___269 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___235 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___261 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___158 *, struct module_kobject___158 *, char *);
	ssize_t (*store)(struct module_attribute___158 *, struct module_kobject___158 *, const char *, size_t);
	void (*setup)(struct module___160 *, const char *);
	int (*test)(struct module___160 *);
	void (*free)(struct module___160 *);
};

struct kmem_cache_cpu___243 {
	void **freelist;
	long unsigned int tid;
	struct page___260 *page;
	struct page___260 *partial;
};

struct memcg_cache_params___244;

struct kmem_cache___244 {
	struct kmem_cache_cpu___243 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___43 kobj;
	struct memcg_cache_params___244 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___244 {
	bool is_root_cache;
	union {
		struct kmem_cache___244 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___244 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct file_lock___261;

struct seq_file___186;

struct file_operations___261 {
	struct module___160 *owner;
	loff_t (*llseek)(struct file___261 *, loff_t, int);
	ssize_t (*read)(struct file___261 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___261 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___261 *, void *, filldir_t);
	unsigned int (*poll)(struct file___261 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___261 *, struct vm_area_struct___269 *);
	int (*open)(struct inode___261 *, struct file___261 *);
	int (*flush)(struct file___261 *, fl_owner_t);
	int (*release)(struct inode___261 *, struct file___261 *);
	int (*fsync)(struct file___261 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___261 *, int);
	int (*lock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*sendpage)(struct file___261 *, struct page___260 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___261 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___261 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___261 *, long int, struct file_lock___261 **, void **);
		struct {
			int (*setlease)(struct file___261 *, long int, struct file_lock___261 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___261 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___186 *, struct file___261 *);
};

struct dma_map_ops___124 {
	void * (*alloc)(struct device___259 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___259 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___259 *, struct vm_area_struct___269 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___259 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___259 *, struct page___260 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___259 *, dma_addr_t);
	int (*dma_supported)(struct device___259 *, u64);
	int (*set_dma_mask)(struct device___259 *, u64);
	int is_phys;
};

struct bus_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___259 *, char *);
	ssize_t (*store)(struct bus_type___259 *, const char *, size_t);
};

struct device_attribute___259;

struct driver_attribute___259;

struct bus_type___259 {
	const char *name;
	const char *dev_name;
	struct device___259 *dev_root;
	struct bus_attribute___259 *bus_attrs;
	struct device_attribute___259 *dev_attrs;
	struct driver_attribute___259 *drv_attrs;
	const struct attribute_group___221 **bus_groups;
	const struct attribute_group___221 **dev_groups;
	const struct attribute_group___221 **drv_groups;
	int (*match)(struct device___259 *, struct device_driver___259 *);
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	int (*probe)(struct device___259 *);
	int (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*online)(struct device___259 *);
	int (*offline)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct device___259 *, struct device_attribute___259 *, char *);
	ssize_t (*store)(struct device___259 *, struct device_attribute___259 *, const char *, size_t);
};

struct driver_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___259 *, char *);
	ssize_t (*store)(struct device_driver___259 *, const char *, size_t);
};

struct device_driver___259 {
	const char *name;
	struct bus_type___259 *bus;
	struct module___160 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___259 *);
	int (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	const struct attribute_group___221 **groups;
	const struct dev_pm_ops___259 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___259 {
	const char *name;
	const struct attribute_group___221 **groups;
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
};

struct class_attribute___259;

struct class___259 {
	const char *name;
	struct module___160 *owner;
	struct class_attribute___259 *class_attrs;
	struct device_attribute___259 *dev_attrs;
	const struct attribute_group___221 **dev_groups;
	struct bin_attribute___223 *dev_bin_attrs;
	struct kobject___43 *dev_kobj;
	int (*dev_uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *);
	void (*class_release)(struct class___259 *);
	void (*dev_release)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	const struct kobj_ns_type_operations___40 *ns_type;
	const void * (*namespace)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
	struct subsys_private *p;
};

struct class_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct class___259 *, struct class_attribute___259 *, char *);
	ssize_t (*store)(struct class___259 *, struct class_attribute___259 *, const char *, size_t);
	const void * (*namespace)(struct class___259 *, const struct class_attribute___259 *);
};

struct device_rh___259 {
	struct dev_pm_info_rh___259 power;
};

struct dev_pm_qos_request___63 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___259 *dev;
};

struct xol_area___260 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___260 *page;
	long unsigned int vaddr;
};

struct address_space_operations___261;

struct address_space___261 {
	struct inode___261 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___263 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___261 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___231;

struct vm_operations_struct___235 {
	void (*open)(struct vm_area_struct___269 *);
	void (*close)(struct vm_area_struct___269 *);
	int (*fault)(struct vm_area_struct___269 *, struct vm_fault___231 *);
	int (*page_mkwrite)(struct vm_area_struct___269 *, struct vm_fault___231 *);
	int (*access)(struct vm_area_struct___269 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___269 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___269 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___269 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___269 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___262 {
	struct task_struct___262 *task;
	struct core_thread___262 *next;
};

struct core_state___262 {
	atomic_t nr_threads;
	struct core_thread___262 dumper;
	struct completion startup;
};

struct vm_fault___231 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___260 *page;
};

struct dentry_operations___261;

struct super_block___261;

struct dentry___261 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___261 *d_parent;
	struct qstr d_name;
	struct inode___261 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___261 *d_op;
	struct super_block___261 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___261;

struct dquot___261;

struct block_device___261;

struct inode___261 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___261 *i_op;
	struct super_block___261 *i_sb;
	struct address_space___261 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___263 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___261 *i_fop;
	struct file_lock___261 *i_flock;
	struct address_space___261 i_data;
	struct dquot___261 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___261 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___261 {
	int (*d_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_hash)(const struct dentry___261 *, struct qstr *);
	int (*d_compare)(const struct dentry___261 *, const struct dentry___261 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___261 *);
	void (*d_release)(struct dentry___261 *);
	void (*d_prune)(struct dentry___261 *);
	void (*d_iput)(struct dentry___261 *, struct inode___261 *);
	char * (*d_dname)(struct dentry___261 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___261 *);
	int (*d_manage)(struct dentry___261 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___261;

struct mem_dqinfo___261 {
	struct quota_format_type___261 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___261;

struct quota_info___261 {
	unsigned int flags;
	struct mutex___263 dqio_mutex;
	struct mutex___263 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___261 *files[2];
	struct mem_dqinfo___261 info[2];
	const struct quota_format_ops___261 *ops[2];
};

struct file_system_type___261;

struct super_operations___261;

struct dquot_operations___261;

struct quotactl_ops___261;

struct xattr_handler___157;

struct super_block___261 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___261 *s_type;
	const struct super_operations___261 *s_op;
	const struct dquot_operations___261 *dq_op;
	const struct quotactl_ops___261 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___261 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___157 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___261 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___261 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___263 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___261 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___261 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___261 *bd_inode;
	struct super_block___261 *bd_super;
	struct mutex___263 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___261 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___263 bd_fsfreeze_mutex;
};

struct cgroup___156;

struct cgroup_subsys_state___156 {
	struct cgroup___156 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___261 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___261 *ia_file;
};

struct dquot___261 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___263 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___261 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___261 {
	int qf_fmt_id;
	const struct quota_format_ops___261 *qf_ops;
	struct module___160 *qf_owner;
	struct quota_format_type___261 *qf_next;
};

struct quota_format_ops___261 {
	int (*check_quota_file)(struct super_block___261 *, int);
	int (*read_file_info)(struct super_block___261 *, int);
	int (*write_file_info)(struct super_block___261 *, int);
	int (*free_file_info)(struct super_block___261 *, int);
	int (*read_dqblk)(struct dquot___261 *);
	int (*commit_dqblk)(struct dquot___261 *);
	int (*release_dqblk)(struct dquot___261 *);
};

struct dquot_operations___261 {
	int (*write_dquot)(struct dquot___261 *);
	struct dquot___261 * (*alloc_dquot)(struct super_block___261 *, int);
	void (*destroy_dquot)(struct dquot___261 *);
	int (*acquire_dquot)(struct dquot___261 *);
	int (*release_dquot)(struct dquot___261 *);
	int (*mark_dirty)(struct dquot___261 *);
	int (*write_info)(struct super_block___261 *, int);
	qsize_t * (*get_reserved_space)(struct inode___261 *);
};

struct quotactl_ops___261 {
	int (*quota_on)(struct super_block___261 *, int, int, struct path___261 *);
	int (*quota_on_meta)(struct super_block___261 *, int, int);
	int (*quota_off)(struct super_block___261 *, int);
	int (*quota_sync)(struct super_block___261 *, int);
	int (*get_info)(struct super_block___261 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___261 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___261 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___261 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___261 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___261 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___261 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___261 *, unsigned int);
};

struct address_space_operations___261 {
	int (*writepage)(struct page___260 *, struct writeback_control *);
	int (*readpage)(struct file___261 *, struct page___260 *);
	int (*writepages)(struct address_space___261 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___260 *);
	int (*readpages)(struct file___261 *, struct address_space___261 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___261 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___260 **, void **);
	int (*write_end)(struct file___261 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___260 *, void *);
	sector_t (*bmap)(struct address_space___261 *, sector_t);
	void (*invalidatepage)(struct page___260 *, long unsigned int);
	int (*releasepage)(struct page___260 *, gfp_t);
	void (*freepage)(struct page___260 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___261 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___261 *, struct page___260 *, struct page___260 *, enum migrate_mode);
	int (*launder_page)(struct page___260 *);
	int (*is_partially_uptodate)(struct page___260 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___260 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___261 *, struct page___260 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___261 *, sector_t *);
	void (*swap_deactivate)(struct file___261 *);
	void (*invalidatepage_range)(struct page___260 *, unsigned int, unsigned int);
};

struct inode_operations___261 {
	struct dentry___261 * (*lookup)(struct inode___261 *, struct dentry___261 *, unsigned int);
	void * (*follow_link)(struct dentry___261 *, struct nameidata *);
	int (*permission)(struct inode___261 *, int);
	struct posix_acl * (*get_acl)(struct inode___261 *, int);
	int (*readlink)(struct dentry___261 *, char *, int);
	void (*put_link)(struct dentry___261 *, struct nameidata *, void *);
	int (*create)(struct inode___261 *, struct dentry___261 *, umode_t, bool);
	int (*link)(struct dentry___261 *, struct inode___261 *, struct dentry___261 *);
	int (*unlink)(struct inode___261 *, struct dentry___261 *);
	int (*symlink)(struct inode___261 *, struct dentry___261 *, const char *);
	int (*mkdir)(struct inode___261 *, struct dentry___261 *, umode_t);
	int (*rmdir)(struct inode___261 *, struct dentry___261 *);
	int (*mknod)(struct inode___261 *, struct dentry___261 *, umode_t, dev_t);
	int (*rename)(struct inode___261 *, struct dentry___261 *, struct inode___261 *, struct dentry___261 *);
	int (*setattr)(struct dentry___261 *, struct iattr___261 *);
	int (*getattr)(struct vfsmount *, struct dentry___261 *, struct kstat *);
	int (*setxattr)(struct dentry___261 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___261 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___261 *, char *, size_t);
	int (*removexattr)(struct dentry___261 *, const char *);
	int (*fiemap)(struct inode___261 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___261 *, struct timespec *, int);
	int (*atomic_open)(struct inode___261 *, struct dentry___261 *, struct file___261 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___261;

struct file_lock_operations___261;

struct lock_manager_operations___261;

struct file_lock___261 {
	struct file_lock___261 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___261 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___261 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___261 *fl_ops;
	const struct lock_manager_operations___261 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___261 {
	void (*fl_copy_lock)(struct file_lock___261 *, struct file_lock___261 *);
	void (*fl_release_private)(struct file_lock___261 *);
};

struct lock_manager_operations___261 {
	int (*lm_compare_owner)(struct file_lock___261 *, struct file_lock___261 *);
	long unsigned int (*lm_owner_key)(struct file_lock___261 *);
	void (*lm_notify)(struct file_lock___261 *);
	int (*lm_grant)(struct file_lock___261 *, struct file_lock___261 *, int);
	void (*lm_break)(struct file_lock___261 *);
	int (*lm_change)(struct file_lock___261 **, int);
};

struct fasync_struct___261 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___261 *fa_next;
	struct file___261 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___261 {
	const char *name;
	int fs_flags;
	struct dentry___261 * (*mount)(struct file_system_type___261 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___261 *);
	struct module___160 *owner;
	struct file_system_type___261 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___261 {
	struct inode___261 * (*alloc_inode)(struct super_block___261 *);
	void (*destroy_inode)(struct inode___261 *);
	void (*dirty_inode)(struct inode___261 *, int);
	int (*write_inode)(struct inode___261 *, struct writeback_control *);
	int (*drop_inode)(struct inode___261 *);
	void (*evict_inode)(struct inode___261 *);
	void (*put_super)(struct super_block___261 *);
	int (*sync_fs)(struct super_block___261 *, int);
	int (*freeze_fs)(struct super_block___261 *);
	int (*unfreeze_fs)(struct super_block___261 *);
	int (*statfs)(struct dentry___261 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___261 *, int *, char *);
	void (*umount_begin)(struct super_block___261 *);
	int (*show_options)(struct seq_file___186 *, struct dentry___261 *);
	int (*show_devname)(struct seq_file___186 *, struct dentry___261 *);
	int (*show_path)(struct seq_file___186 *, struct dentry___261 *);
	int (*show_stats)(struct seq_file___186 *, struct dentry___261 *);
	ssize_t (*quota_read)(struct super_block___261 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___261 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___261 *);
	int (*bdev_try_to_free_page)(struct super_block___261 *, struct page___260 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___261 *);
	void (*free_cached_objects)(struct super_block___261 *, int);
};

struct xattr_handler___157 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___261 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___261 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___261 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___186;

struct seq_file___186 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___263 lock;
	const struct seq_operations___186 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___262 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___262 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___262 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___263 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___156 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___156 *subsys[11];
	struct callback_head callback_head;
};

struct netns_core___63 {
	struct ctl_table_header___66 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___64 {
	struct mutex___263 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___63 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___66 *ctl;
};

struct netns_ipv4___63 {
	struct ctl_table_header___66 *forw_hdr;
	struct ctl_table_header___66 *frags_hdr;
	struct ctl_table_header___66 *ipv4_hdr;
	struct ctl_table_header___66 *route_hdr;
	struct ctl_table_header___66 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___63 {
	struct ctl_table_header___66 *hdr;
	struct ctl_table_header___66 *route_hdr;
	struct ctl_table_header___66 *icmp_hdr;
	struct ctl_table_header___66 *frags_hdr;
	struct ctl_table_header___66 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___52;

struct sk_buff___55;

struct dst_ops___65 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___65 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___52 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___55 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___55 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___55 *);
	int (*local_out)(struct sk_buff___55 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___55 *, const void *);
	struct kmem_cache___244 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___65 {
	struct netns_sysctl_ipv6___63 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___65 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___63 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___66 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___63 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___66 *nf_log_dir_header;
};

struct nf_proto_net___63 {
	struct ctl_table_header___66 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___63 {
	struct nf_proto_net___63 pn;
	unsigned int timeout;
};

struct nf_tcp_net___63 {
	struct nf_proto_net___63 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___63 {
	struct nf_proto_net___63 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___63 {
	struct nf_proto_net___63 pn;
	unsigned int timeout;
};

struct nf_ip_net___63 {
	struct nf_generic_net___63 generic;
	struct nf_tcp_net___63 tcp;
	struct nf_udp_net___63 udp;
	struct nf_icmp_net___63 icmp;
	struct nf_icmp_net___63 icmpv6;
};

struct netns_ct___64 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___66 *sysctl_header;
	struct ctl_table_header___66 *acct_sysctl_header;
	struct ctl_table_header___66 *tstamp_sysctl_header;
	struct ctl_table_header___66 *event_sysctl_header;
	struct ctl_table_header___66 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___244 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___63 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___63 {
	struct netns_sysctl_ipv6___63 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___52 {
	struct sk_buff___55 *next;
	struct sk_buff___55 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___65 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___66 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___65 xfrm4_dst_ops;
	struct dst_ops___65 xfrm6_dst_ops;
};

struct net___66 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___66 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___52 *loopback_dev;
	struct netns_core___63 core;
	struct netns_mib mib;
	struct netns_packet___64 packet;
	struct netns_unix___63 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___63 ipv4;
	struct netns_ipv6___65 ipv6;
	struct netns_sctp___63 sctp;
	struct netns_dccp___40 dccp;
	struct netns_nf___63 nf;
	struct netns_xt xt;
	struct netns_ct___64 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___63 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___52 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___65 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___263 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___263 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___51 {
	atomic_t use;
	unsigned int mask;
	struct net_device___52 *physindev;
	struct net_device___52 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___51(struct sk_buff___55 **);

struct net_device_ops___51;

struct ethtool_ops___51;

struct header_ops___51;

struct netdev_rx_queue___51;

struct netdev_queue___51;

struct Qdisc___8;

struct rtnl_link_ops___42;

struct dcbnl_rtnl_ops___51;

struct net_device___52 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___51 *netdev_ops;
	const struct ethtool_ops___51 *ethtool_ops;
	const struct header_ops___51 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___43 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___51 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___51 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___51 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___51 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___8 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___51 = 0,
		NETREG_REGISTERED___51 = 1,
		NETREG_UNREGISTERING___51 = 2,
		NETREG_UNREGISTERED___51 = 3,
		NETREG_RELEASED___51 = 4,
		NETREG_DUMMY___51 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___51 = 0,
		RTNL_LINK_INITIALIZING___51 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___52 *);
	struct netpoll_info *npinfo;
	struct net___66 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___259 dev;
	const struct attribute_group___221 *sysfs_groups[4];
	const struct rtnl_link_ops___42 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___51 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___55 {
	struct sk_buff___55 *next;
	struct sk_buff___55 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___52 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___55 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___51 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___51 {
	int (*get_settings)(struct net_device___52 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___52 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___52 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___52 *);
	void (*get_regs)(struct net_device___52 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___52 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___52 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___52 *);
	void (*set_msglevel)(struct net_device___52 *, u32);
	int (*nway_reset)(struct net_device___52 *);
	u32 (*get_link)(struct net_device___52 *);
	int (*get_eeprom_len)(struct net_device___52 *);
	int (*get_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___52 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___52 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___52 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___52 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___52 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___52 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___52 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___52 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___52 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___52 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___52 *);
	void (*complete)(struct net_device___52 *);
	u32 (*get_priv_flags)(struct net_device___52 *);
	int (*set_priv_flags)(struct net_device___52 *, u32);
	int (*get_sset_count)(struct net_device___52 *, int);
	int (*get_rxnfc)(struct net_device___52 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___52 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___52 *, struct ethtool_flash *);
	int (*reset)(struct net_device___52 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___52 *);
	int (*get_rxfh_indir)(struct net_device___52 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___52 *, const u32 *);
	void (*get_channels)(struct net_device___52 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___52 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___52 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___52 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___52 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___52 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___52 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___52 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___52 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___52 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___52 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___52 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___65 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___55 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___55 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___66 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___55 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___55 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___185 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___185 *);
	void (*irq_shutdown)(struct irq_data___185 *);
	void (*irq_enable)(struct irq_data___185 *);
	void (*irq_disable)(struct irq_data___185 *);
	void (*irq_ack)(struct irq_data___185 *);
	void (*irq_mask)(struct irq_data___185 *);
	void (*irq_mask_ack)(struct irq_data___185 *);
	void (*irq_unmask)(struct irq_data___185 *);
	void (*irq_eoi)(struct irq_data___185 *);
	int (*irq_set_affinity)(struct irq_data___185 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___185 *);
	int (*irq_set_type)(struct irq_data___185 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___185 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___185 *);
	void (*irq_bus_sync_unlock)(struct irq_data___185 *);
	void (*irq_cpu_online)(struct irq_data___185 *);
	void (*irq_cpu_offline)(struct irq_data___185 *);
	void (*irq_suspend)(struct irq_data___185 *);
	void (*irq_resume)(struct irq_data___185 *);
	void (*irq_pm_shutdown)(struct irq_data___185 *);
	void (*irq_print_chip)(struct irq_data___185 *, struct seq_file___186 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___185 *, void *);
	long unsigned int flags;
};

struct seq_operations___186 {
	void * (*start)(struct seq_file___186 *, loff_t *);
	void (*stop)(struct seq_file___186 *, void *);
	void * (*next)(struct seq_file___186 *, void *, loff_t *);
	int (*show)(struct seq_file___186 *, void *);
};

struct dcbnl_rtnl_ops___51 {
	int (*ieee_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___52 *);
	u8 (*setstate)(struct net_device___52 *, u8);
	void (*getpermhwaddr)(struct net_device___52 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___52 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___52 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___52 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___52 *, int, u8 *);
	void (*setpfccfg)(struct net_device___52 *, int, u8);
	void (*getpfccfg)(struct net_device___52 *, int, u8 *);
	u8 (*setall)(struct net_device___52 *);
	u8 (*getcap)(struct net_device___52 *, int, u8 *);
	int (*getnumtcs)(struct net_device___52 *, int, u8 *);
	int (*setnumtcs)(struct net_device___52 *, int, u8);
	u8 (*getpfcstate)(struct net_device___52 *);
	void (*setpfcstate)(struct net_device___52 *, u8);
	void (*getbcncfg)(struct net_device___52 *, int, u32 *);
	void (*setbcncfg)(struct net_device___52 *, int, u32);
	void (*getbcnrp)(struct net_device___52 *, int, u8 *);
	void (*setbcnrp)(struct net_device___52 *, int, u8);
	u8 (*setapp)(struct net_device___52 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___52 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___52 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___52 *, int, u8);
	u8 (*getdcbx)(struct net_device___52 *);
	u8 (*setdcbx)(struct net_device___52 *, u8);
	int (*peer_getappinfo)(struct net_device___52 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___52 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___52 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___52 *, struct cee_pfc *);
};

struct cgroupfs_root___156;

struct cgroup___156 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___156 *parent;
	struct dentry___261 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___156 *subsys[11];
	struct cgroupfs_root___156 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___263 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___156 {
	struct super_block___261 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___156 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___53 {
	struct sk_buff___55 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___55 *, struct netlink_callback___53 *);
	int (*done)(struct netlink_callback___53 *);
	void *data;
	struct module___160 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___51 {
	int (*create)(struct sk_buff___55 *, struct net_device___52 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___55 *, unsigned char *);
	int (*rebuild)(struct sk_buff___55 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___52 *, const unsigned char *);
};

struct napi_struct___51 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___51 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___52 *dev;
	struct sk_buff___55 *gro_list;
	struct sk_buff___55 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___51 {
	struct net_device___52 *dev;
	struct Qdisc___8 *qdisc;
	struct Qdisc___8 *qdisc_sleeping;
	struct kobject___43 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___8;

struct Qdisc___8 {
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___8 *);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___8 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___8 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___55 *, struct Qdisc___8 *);
	void *u32_node;
	struct Qdisc___8 *__parent;
	struct netdev_queue___51 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___8 *next_sched;
	struct sk_buff___55 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___52 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___51 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___43 kobj;
	struct net_device___52 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___51 {
	int (*ndo_init)(struct net_device___52 *);
	void (*ndo_uninit)(struct net_device___52 *);
	int (*ndo_open)(struct net_device___52 *);
	int (*ndo_stop)(struct net_device___52 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___55 *, struct net_device___52 *);
	u16 (*ndo_select_queue)(struct net_device___52 *, struct sk_buff___55 *);
	void (*ndo_change_rx_flags)(struct net_device___52 *, int);
	void (*ndo_set_rx_mode)(struct net_device___52 *);
	int (*ndo_set_mac_address)(struct net_device___52 *, void *);
	int (*ndo_validate_addr)(struct net_device___52 *);
	int (*ndo_do_ioctl)(struct net_device___52 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___52 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___52 *, int);
	int (*ndo_neigh_setup)(struct net_device___52 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___52 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___52 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___52 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___52 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___52 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___52 *);
	int (*ndo_netpoll_setup)(struct net_device___52 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___52 *);
	int (*ndo_busy_poll)(struct napi_struct___51 *);
	int (*ndo_set_vf_mac)(struct net_device___52 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___52 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___52 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___52 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___52 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___52 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___52 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___52 *, int, struct sk_buff___55 *);
	int (*ndo_setup_tc)(struct net_device___52 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___52 *);
	int (*ndo_fcoe_disable)(struct net_device___52 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___52 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___52 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___52 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___52 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___52 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___52 *, const struct sk_buff___55 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___52 *, struct net_device___52 *);
	int (*ndo_del_slave)(struct net_device___52 *, struct net_device___52 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___55 *, struct netlink_callback___53 *, struct net_device___52 *, int);
	int (*ndo_bridge_setlink)(struct net_device___52 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___55 *, u32, u32, struct net_device___52 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___52 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___52 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___52 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___52 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___52 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___52 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___55 *, struct net_device___52 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___52 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___52 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___52 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtnl_link_ops___42 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___52 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___66 *, struct net_device___52 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___52 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___52 *, struct list_head *);
	size_t (*get_size)(const struct net_device___52 *);
	int (*fill_info)(struct sk_buff___55 *, const struct net_device___52 *);
	size_t (*get_xstats_size)(const struct net_device___52 *);
	int (*fill_xstats)(struct sk_buff___55 *, const struct net_device___52 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___66 * (*get_link_net)(const struct net_device___52 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___52 *, struct net_device___52 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___52 *, const struct net_device___52 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___55 *, const struct net_device___52 *, const struct net_device___52 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	TCA_EMATCH_TREE_UNSPEC = 0,
	TCA_EMATCH_TREE_HDR = 1,
	TCA_EMATCH_TREE_LIST = 2,
	__TCA_EMATCH_TREE_MAX = 3,
};

struct tcf_ematch_hdr {
	__u16 matchid;
	__u16 kind;
	__u16 flags;
	__u16 pad;
};

struct gnet_dump___9 {
	spinlock_t *lock;
	struct sk_buff___55 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___8;

struct Qdisc_ops___8 {
	struct Qdisc_ops___8 *next;
	const struct Qdisc_class_ops___8 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___8 *);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___8 *);
	struct sk_buff___55 * (*peek)(struct Qdisc___8 *);
	unsigned int (*drop)(struct Qdisc___8 *);
	int (*init)(struct Qdisc___8 *, struct nlattr *);
	void (*reset)(struct Qdisc___8 *);
	void (*destroy)(struct Qdisc___8 *);
	int (*change)(struct Qdisc___8 *, struct nlattr *);
	void (*attach)(struct Qdisc___8 *);
	int (*dump)(struct Qdisc___8 *, struct sk_buff___55 *);
	int (*dump_stats)(struct Qdisc___8 *, struct gnet_dump___9 *);
	struct module___160 *owner;
};

struct qdisc_walker___8;

struct tcf_proto___8;

struct Qdisc_class_ops___8 {
	struct netdev_queue___51 * (*select_queue)(struct Qdisc___8 *, struct tcmsg *);
	int (*graft)(struct Qdisc___8 *, long unsigned int, struct Qdisc___8 *, struct Qdisc___8 **);
	struct Qdisc___8 * (*leaf)(struct Qdisc___8 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___8 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___8 *, u32);
	void (*put)(struct Qdisc___8 *, long unsigned int);
	int (*change)(struct Qdisc___8 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___8 *, long unsigned int);
	void (*walk)(struct Qdisc___8 *, struct qdisc_walker___8 *);
	struct tcf_proto___8 ** (*tcf_chain)(struct Qdisc___8 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___8 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___8 *, long unsigned int);
	int (*dump)(struct Qdisc___8 *, long unsigned int, struct sk_buff___55 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___8 *, long unsigned int, struct gnet_dump___9 *);
};

struct qdisc_walker___8 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___8 *, long unsigned int, struct qdisc_walker___8 *);
};

struct tcf_proto_ops___8;

struct tcf_proto___8 {
	struct tcf_proto___8 *next;
	void *root;
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___8 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___8 *q;
	void *data;
	const struct tcf_proto_ops___8 *ops;
};

struct tcf_walker___3;

struct tcf_proto_ops___8 {
	struct tcf_proto_ops___8 *next;
	char kind[16];
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___8 *, struct tcf_result *);
	int (*init)(struct tcf_proto___8 *);
	void (*destroy)(struct tcf_proto___8 *);
	long unsigned int (*get)(struct tcf_proto___8 *, u32);
	void (*put)(struct tcf_proto___8 *, long unsigned int);
	int (*change)(struct net___66 *, struct sk_buff___55 *, struct tcf_proto___8 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___8 *, long unsigned int);
	void (*walk)(struct tcf_proto___8 *, struct tcf_walker___3 *);
	int (*dump)(struct tcf_proto___8 *, long unsigned int, struct sk_buff___55 *, struct tcmsg *);
	struct module___160 *owner;
};

struct tcf_walker___3 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct tcf_proto___8 *, long unsigned int, struct tcf_walker___3 *);
};

struct tcf_ematch_ops___2;

struct tcf_ematch___2 {
	struct tcf_ematch_ops___2 *ops;
	long unsigned int data;
	unsigned int datalen;
	u16 matchid;
	u16 flags;
};

struct tcf_ematch_ops___2 {
	int kind;
	int datalen;
	int (*change)(struct tcf_proto___8 *, void *, int, struct tcf_ematch___2 *);
	int (*match)(struct sk_buff___55 *, struct tcf_ematch___2 *, struct tcf_pkt_info *);
	void (*destroy)(struct tcf_proto___8 *, struct tcf_ematch___2 *);
	int (*dump)(struct sk_buff___55 *, struct tcf_ematch___2 *);
	struct module___160 *owner;
	struct list_head link;
};

struct tcf_ematch_tree___2 {
	struct tcf_ematch_tree_hdr hdr;
	struct tcf_ematch___2 *matches;
};

struct page___261;

typedef struct page___261 *pgtable_t___261;

struct address_space___262;

struct kmem_cache___245;

struct page___261 {
	long unsigned int flags;
	struct address_space___262 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___261 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___261 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___245 *slab_cache;
		struct page___261 *first_page;
	};
	long: 64;
};

struct task_struct___263;

struct pv_cpu_ops___263 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___263 *);
	void (*end_context_switch)(struct task_struct___263 *);
};

struct mutex___264 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___263 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___256 {
	struct page___261 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___270;

struct nsproxy___142;

struct signal_struct___263;

struct css_set___157;

struct task_struct___263 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___263 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___270 *mm;
	struct mm_struct___270 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___263 *real_parent;
	struct task_struct___263 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___263 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___263 = 0,
		VTIME_USER___263 = 1,
		VTIME_SYS___263 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___142 *nsproxy;
	struct signal_struct___263 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___157 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___264 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___256 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___270 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___270 *, struct mm_struct___270 *);
	void (*dup_mmap)(struct mm_struct___270 *, struct mm_struct___270 *);
	void (*exit_mmap)(struct mm_struct___270 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___270 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___270 *);
	void (*pgd_free)(struct mm_struct___270 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___270 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___270 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___270 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___270 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___270 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___270 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___270 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___270 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___270 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___270 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___270 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___264 lock;
	void *vdso;
} mm_context_t___264;

struct xol_area___261;

struct uprobes_state___261 {
	struct xol_area___261 *xol_area;
};

struct vm_area_struct___270;

struct file___262;

struct core_state___263;

struct mm_struct___270 {
	struct vm_area_struct___270 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___270 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___270 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___264 context;
	long unsigned int flags;
	struct core_state___263 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___263 *owner;
	struct file___262 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___261 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___161;

struct exec_domain___74 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___161 *module;
	struct exec_domain___74 *next;
};

struct kset___44;

struct kobj_type___44;

struct kobject___44 {
	const char *name;
	struct list_head entry;
	struct kobject___44 *parent;
	struct kset___44 *kset;
	struct kobj_type___44 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___159 {
	struct kobject___44 kobj;
	struct module___161 *mod;
	struct kobject___44 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___159;

struct module___161 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___159 mkobj;
	struct module_attribute___159 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___44 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___263 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___121 {
	struct task_struct___263 *task;
	struct exec_domain___74 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___263;

struct lruvec___263 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___263 *zone;
};

struct pglist_data___263;

struct zone___263 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___263 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___263 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___263 {
	struct zone___263 *zone;
	int zone_idx;
};

struct zonelist___263 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___263 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___263 {
	struct zone___263 node_zones[4];
	struct zonelist___263 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___263 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___186;

struct x86_io_apic_ops___186 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___186 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___186;

struct irq_data___186 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___186 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___260;

struct dev_pm_ops___260 {
	int (*prepare)(struct device___260 *);
	void (*complete)(struct device___260 *);
	int (*suspend)(struct device___260 *);
	int (*resume)(struct device___260 *);
	int (*freeze)(struct device___260 *);
	int (*thaw)(struct device___260 *);
	int (*poweroff)(struct device___260 *);
	int (*restore)(struct device___260 *);
	int (*suspend_late)(struct device___260 *);
	int (*resume_early)(struct device___260 *);
	int (*freeze_late)(struct device___260 *);
	int (*thaw_early)(struct device___260 *);
	int (*poweroff_late)(struct device___260 *);
	int (*restore_early)(struct device___260 *);
	int (*suspend_noirq)(struct device___260 *);
	int (*resume_noirq)(struct device___260 *);
	int (*freeze_noirq)(struct device___260 *);
	int (*thaw_noirq)(struct device___260 *);
	int (*poweroff_noirq)(struct device___260 *);
	int (*restore_noirq)(struct device___260 *);
	int (*runtime_suspend)(struct device___260 *);
	int (*runtime_resume)(struct device___260 *);
	int (*runtime_idle)(struct device___260 *);
};

struct dev_pm_qos___63;

struct dev_pm_info___63 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___63 *qos;
};

struct dma_map_ops___125;

struct dev_archdata___125 {
	struct dma_map_ops___125 *dma_ops;
	void *iommu;
};

struct device_type___260;

struct bus_type___260;

struct device_driver___260;

struct dev_pm_domain___260;

struct class___260;

struct attribute_group___222;

struct device_rh___260;

struct device___260 {
	struct device___260 *parent;
	struct device_private *p;
	struct kobject___44 kobj;
	const char *init_name;
	const struct device_type___260 *type;
	struct mutex___264 mutex;
	struct bus_type___260 *bus;
	struct device_driver___260 *driver;
	void *platform_data;
	struct dev_pm_info___63 power;
	struct dev_pm_domain___260 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___125 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___260 *class;
	const struct attribute_group___222 **groups;
	void (*release)(struct device___260 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___260 *device_rh;
};

struct dev_pm_qos_request___64;

struct dev_pm_qos___63 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___64 *latency_req;
	struct dev_pm_qos_request___64 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___64 *latency_tolerance_req;
};

struct dev_pm_info_rh___260 {
	void (*set_latency_tolerance)(struct device___260 *, s32);
};

struct dev_pm_domain___260 {
	struct dev_pm_ops___260 ops;
};

struct smp_ops___263 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___263 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___67;

struct ctl_node___67 {
	struct rb_node node;
	struct ctl_table_header___67 *header;
};

struct ctl_table_root___67;

struct ctl_table_set___67;

struct ctl_dir___67;

struct ctl_table_header___67 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___67 *root;
	struct ctl_table_set___67 *set;
	struct ctl_dir___67 *parent;
	struct ctl_node___67 *node;
};

struct ctl_dir___67 {
	struct ctl_table_header___67 header;
	struct rb_root root;
};

struct ctl_table_set___67 {
	int (*is_seen)(struct ctl_table_set___67 *);
	struct ctl_dir___67 dir;
};

struct ctl_table_root___67 {
	struct ctl_table_set___67 default_set;
	struct ctl_table_set___67 * (*lookup)(struct ctl_table_root___67 *, struct nsproxy___142 *);
	int (*permissions)(struct ctl_table_header___67 *, struct ctl_table *);
};

struct net___67;

struct nsproxy___142 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___67 *net_ns;
};

struct sock___43;

struct kobj_ns_type_operations___41 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___43 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___41;

struct sock_common___41 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___41 *skc_prot;
	struct net___67 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___56;

struct sk_buff_head___53 {
	struct sk_buff___56 *next;
	struct sk_buff___56 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___42;

struct socket_wq___41;

struct dst_entry___42;

struct socket___42;

struct cg_proto___41;

struct sock___43 {
	struct sock_common___41 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___53 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___56 *head;
		struct sk_buff___56 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___42 *sk_filter;
	struct socket_wq___41 *sk_wq;
	struct sk_buff_head___53 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___42 *sk_rx_dst;
	struct dst_entry___42 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___53 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___53 sk_error_queue;
	struct proto___41 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___42 *sk_socket;
	void *sk_user_data;
	struct page_frag___256 sk_frag;
	struct sk_buff___56 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___41 *sk_cgrp;
	void (*sk_state_change)(struct sock___43 *);
	void (*sk_data_ready)(struct sock___43 *, int);
	void (*sk_write_space)(struct sock___43 *);
	void (*sk_error_report)(struct sock___43 *);
	int (*sk_backlog_rcv)(struct sock___43 *, struct sk_buff___56 *);
	void (*sk_destruct)(struct sock___43 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___224;

struct attribute_group___222 {
	const char *name;
	umode_t (*is_visible)(struct kobject___44 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___224 **bin_attrs;
};

struct bin_attribute___224 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___262 *, struct kobject___44 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___262 *, struct kobject___44 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	int (*mmap)(struct file___262 *, struct kobject___44 *, struct bin_attribute___224 *, struct vm_area_struct___270 *);
};

struct dentry___262;

struct path___262 {
	struct vfsmount *mnt;
	struct dentry___262 *dentry;
};

struct inode___262;

struct file_operations___262;

struct file___262 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___262 f_path;
	struct inode___262 *f_inode;
	const struct file_operations___262 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___262 *f_mapping;
	struct mutex___264 f_pos_lock;
};

struct vm_operations_struct___236;

struct vm_area_struct___270 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___270 *vm_next;
	struct vm_area_struct___270 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___270 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___236 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___262 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___44 {
	ssize_t (*show)(struct kobject___44 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___44 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___44 *, const struct attribute *);
};

struct kset_uevent_ops___44;

struct kset___44 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___44 kobj;
	const struct kset_uevent_ops___44 *uevent_ops;
};

struct kobj_type___44 {
	void (*release)(struct kobject___44 *);
	const struct sysfs_ops___44 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___41 * (*child_ns_type)(struct kobject___44 *);
	const void * (*namespace)(struct kobject___44 *);
};

struct kset_uevent_ops___44 {
	int (* const filter)(struct kset___44 *, struct kobject___44 *);
	const char * (* const name)(struct kset___44 *, struct kobject___44 *);
	int (* const uevent)(struct kset___44 *, struct kobject___44 *, struct kobj_uevent_env *);
};

struct module_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___159 *, struct module_kobject___159 *, char *);
	ssize_t (*store)(struct module_attribute___159 *, struct module_kobject___159 *, const char *, size_t);
	void (*setup)(struct module___161 *, const char *);
	int (*test)(struct module___161 *);
	void (*free)(struct module___161 *);
};

struct xol_area___261 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___261 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___244;

struct memcg_cache_params___245;

struct kmem_cache___245 {
	struct kmem_cache_cpu___244 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___44 kobj;
	struct memcg_cache_params___245 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___262;

struct address_space___262 {
	struct inode___262 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___264 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___262 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___232;

struct vm_operations_struct___236 {
	void (*open)(struct vm_area_struct___270 *);
	void (*close)(struct vm_area_struct___270 *);
	int (*fault)(struct vm_area_struct___270 *, struct vm_fault___232 *);
	int (*page_mkwrite)(struct vm_area_struct___270 *, struct vm_fault___232 *);
	int (*access)(struct vm_area_struct___270 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___270 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___270 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___270 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___270 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___263 {
	struct task_struct___263 *task;
	struct core_thread___263 *next;
};

struct core_state___263 {
	atomic_t nr_threads;
	struct core_thread___263 dumper;
	struct completion startup;
};

struct signal_struct___263 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___263 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___263 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___264 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___157;

struct css_set___157 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___157 *subsys[11];
	struct callback_head callback_head;
};

struct fasync_struct___262;

struct socket_wq___41 {
	wait_queue_head_t wait;
	struct fasync_struct___262 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___262 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___262 *fa_next;
	struct file___262 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___41;

struct socket___42 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___41 *wq;
	struct file___262 *file;
	struct sock___43 *sk;
	const struct proto_ops___41 *ops;
};

struct poll_table_struct___148;

struct kiocb___49;

struct proto_ops___41 {
	int family;
	struct module___161 *owner;
	int (*release)(struct socket___42 *);
	int (*bind)(struct socket___42 *, struct sockaddr *, int);
	int (*connect)(struct socket___42 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___42 *, struct socket___42 *);
	int (*accept)(struct socket___42 *, struct socket___42 *, int);
	int (*getname)(struct socket___42 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___262 *, struct socket___42 *, struct poll_table_struct___148 *);
	int (*ioctl)(struct socket___42 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___42 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___42 *, int);
	int (*shutdown)(struct socket___42 *, int);
	int (*setsockopt)(struct socket___42 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___42 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___42 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___42 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___49 *, struct socket___42 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___49 *, struct socket___42 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___262 *, struct socket___42 *, struct vm_area_struct___270 *);
	ssize_t (*sendpage)(struct socket___42 *, struct page___261 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___42 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___43 *, int);
		struct {
			void (*set_peek_off)(struct sock___43 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___150)(struct file___262 *, wait_queue_head_t *, struct poll_table_struct___148 *);

struct poll_table_struct___148 {
	poll_queue_proc___150 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___49(struct kiocb___49 *, struct io_event *);

struct kiocb___49 {
	atomic_t ki_users;
	struct file___262 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___49 *ki_cancel;
	void (*ki_dtor)(struct kiocb___49 *);
	union {
		void *user;
		struct task_struct___263 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct net_proto_family___3 {
	int family;
	int (*create)(struct net___67 *, struct socket___42 *, int, int);
	struct module___161 *owner;
};

struct netns_core___64 {
	struct ctl_table_header___67 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___65 {
	struct mutex___264 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___64 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___67 *ctl;
};

struct netns_ipv4___64 {
	struct ctl_table_header___67 *forw_hdr;
	struct ctl_table_header___67 *frags_hdr;
	struct ctl_table_header___67 *ipv4_hdr;
	struct ctl_table_header___67 *route_hdr;
	struct ctl_table_header___67 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___43 *fibnl;
	struct sock___43 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___64 {
	struct ctl_table_header___67 *hdr;
	struct ctl_table_header___67 *route_hdr;
	struct ctl_table_header___67 *icmp_hdr;
	struct ctl_table_header___67 *frags_hdr;
	struct ctl_table_header___67 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___53;

struct neighbour___42;

struct dst_ops___66 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___66 *);
	struct dst_entry___42 * (*check)(struct dst_entry___42 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___42 *);
	unsigned int (*mtu)(const struct dst_entry___42 *);
	u32 * (*cow_metrics)(struct dst_entry___42 *, long unsigned int);
	void (*destroy)(struct dst_entry___42 *);
	void (*ifdown)(struct dst_entry___42 *, struct net_device___53 *, int);
	struct dst_entry___42 * (*negative_advice)(struct dst_entry___42 *);
	void (*link_failure)(struct sk_buff___56 *);
	void (*update_pmtu)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___56 *, u32);
	void (*redirect)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___56 *);
	int (*local_out)(struct sk_buff___56 *);
	struct neighbour___42 * (*neigh_lookup)(const struct dst_entry___42 *, struct sk_buff___56 *, const void *);
	struct kmem_cache___245 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___66 {
	struct netns_sysctl_ipv6___64 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___66 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___43 **icmp_sk;
	struct sock___43 *ndisc_sk;
	struct sock___43 *tcp_sk;
	struct sock___43 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___64 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___67 *sysctl_header;
	struct sock___43 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___41 {
	struct sock___43 *v4_ctl_sk;
	struct sock___43 *v6_ctl_sk;
};

struct netns_nf___64 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___67 *nf_log_dir_header;
};

struct nf_proto_net___64 {
	struct ctl_table_header___67 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___64 {
	struct nf_proto_net___64 pn;
	unsigned int timeout;
};

struct nf_tcp_net___64 {
	struct nf_proto_net___64 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___64 {
	struct nf_proto_net___64 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___64 {
	struct nf_proto_net___64 pn;
	unsigned int timeout;
};

struct nf_ip_net___64 {
	struct nf_generic_net___64 generic;
	struct nf_tcp_net___64 tcp;
	struct nf_udp_net___64 udp;
	struct nf_icmp_net___64 icmp;
	struct nf_icmp_net___64 icmpv6;
};

struct netns_ct___65 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___67 *sysctl_header;
	struct ctl_table_header___67 *acct_sysctl_header;
	struct ctl_table_header___67 *tstamp_sysctl_header;
	struct ctl_table_header___67 *event_sysctl_header;
	struct ctl_table_header___67 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___245 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___64 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___64 {
	struct netns_sysctl_ipv6___64 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___66 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___43 *nlsk;
	struct sock___43 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___67 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___66 xfrm4_dst_ops;
	struct dst_ops___66 xfrm6_dst_ops;
};

struct net___67 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___67 sysctls;
	struct sock___43 *rtnl;
	struct sock___43 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___53 *loopback_dev;
	struct netns_core___64 core;
	struct netns_mib mib;
	struct netns_packet___65 packet;
	struct netns_unix___64 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___64 ipv4;
	struct netns_ipv6___66 ipv6;
	struct netns_sctp___64 sctp;
	struct netns_dccp___41 dccp;
	struct netns_nf___64 nf;
	struct netns_xt xt;
	struct netns_ct___65 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___64 nf_frag;
	struct sock___43 *nfnl;
	struct sock___43 *nfnl_stash;
	struct sk_buff_head___53 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___66 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___43 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___43 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___264 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___264 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___262;

struct super_block___262;

struct dentry___262 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___262 *d_parent;
	struct qstr d_name;
	struct inode___262 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___262 *d_op;
	struct super_block___262 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___262;

struct file_lock___262;

struct dquot___262;

struct block_device___262;

struct inode___262 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___262 *i_op;
	struct super_block___262 *i_sb;
	struct address_space___262 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___264 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___262 *i_fop;
	struct file_lock___262 *i_flock;
	struct address_space___262 i_data;
	struct dquot___262 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___262 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___262 {
	int (*d_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_hash)(const struct dentry___262 *, struct qstr *);
	int (*d_compare)(const struct dentry___262 *, const struct dentry___262 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___262 *);
	void (*d_release)(struct dentry___262 *);
	void (*d_prune)(struct dentry___262 *);
	void (*d_iput)(struct dentry___262 *, struct inode___262 *);
	char * (*d_dname)(struct dentry___262 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___262 *);
	int (*d_manage)(struct dentry___262 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___262;

struct mem_dqinfo___262 {
	struct quota_format_type___262 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___262;

struct quota_info___262 {
	unsigned int flags;
	struct mutex___264 dqio_mutex;
	struct mutex___264 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___262 *files[2];
	struct mem_dqinfo___262 info[2];
	const struct quota_format_ops___262 *ops[2];
};

struct file_system_type___262;

struct super_operations___262;

struct dquot_operations___262;

struct quotactl_ops___262;

struct xattr_handler___158;

struct super_block___262 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___262 *s_type;
	const struct super_operations___262 *s_op;
	const struct dquot_operations___262 *dq_op;
	const struct quotactl_ops___262 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___262 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___158 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___262 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___262 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___264 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___262 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___262 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___262 *bd_inode;
	struct super_block___262 *bd_super;
	struct mutex___264 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___262 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___264 bd_fsfreeze_mutex;
};

struct cgroup___157;

struct cgroup_subsys_state___157 {
	struct cgroup___157 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___262 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___262 *ia_file;
};

struct dquot___262 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___264 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___262 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___262 {
	int qf_fmt_id;
	const struct quota_format_ops___262 *qf_ops;
	struct module___161 *qf_owner;
	struct quota_format_type___262 *qf_next;
};

struct quota_format_ops___262 {
	int (*check_quota_file)(struct super_block___262 *, int);
	int (*read_file_info)(struct super_block___262 *, int);
	int (*write_file_info)(struct super_block___262 *, int);
	int (*free_file_info)(struct super_block___262 *, int);
	int (*read_dqblk)(struct dquot___262 *);
	int (*commit_dqblk)(struct dquot___262 *);
	int (*release_dqblk)(struct dquot___262 *);
};

struct dquot_operations___262 {
	int (*write_dquot)(struct dquot___262 *);
	struct dquot___262 * (*alloc_dquot)(struct super_block___262 *, int);
	void (*destroy_dquot)(struct dquot___262 *);
	int (*acquire_dquot)(struct dquot___262 *);
	int (*release_dquot)(struct dquot___262 *);
	int (*mark_dirty)(struct dquot___262 *);
	int (*write_info)(struct super_block___262 *, int);
	qsize_t * (*get_reserved_space)(struct inode___262 *);
};

struct quotactl_ops___262 {
	int (*quota_on)(struct super_block___262 *, int, int, struct path___262 *);
	int (*quota_on_meta)(struct super_block___262 *, int, int);
	int (*quota_off)(struct super_block___262 *, int);
	int (*quota_sync)(struct super_block___262 *, int);
	int (*get_info)(struct super_block___262 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___262 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___262 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___262 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___262 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___262 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___262 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___262 *, unsigned int);
};

struct address_space_operations___262 {
	int (*writepage)(struct page___261 *, struct writeback_control *);
	int (*readpage)(struct file___262 *, struct page___261 *);
	int (*writepages)(struct address_space___262 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___261 *);
	int (*readpages)(struct file___262 *, struct address_space___262 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___262 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___261 **, void **);
	int (*write_end)(struct file___262 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___261 *, void *);
	sector_t (*bmap)(struct address_space___262 *, sector_t);
	void (*invalidatepage)(struct page___261 *, long unsigned int);
	int (*releasepage)(struct page___261 *, gfp_t);
	void (*freepage)(struct page___261 *);
	ssize_t (*direct_IO)(int, struct kiocb___49 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___262 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___262 *, struct page___261 *, struct page___261 *, enum migrate_mode);
	int (*launder_page)(struct page___261 *);
	int (*is_partially_uptodate)(struct page___261 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___261 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___262 *, struct page___261 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___262 *, sector_t *);
	void (*swap_deactivate)(struct file___262 *);
	void (*invalidatepage_range)(struct page___261 *, unsigned int, unsigned int);
};

struct inode_operations___262 {
	struct dentry___262 * (*lookup)(struct inode___262 *, struct dentry___262 *, unsigned int);
	void * (*follow_link)(struct dentry___262 *, struct nameidata *);
	int (*permission)(struct inode___262 *, int);
	struct posix_acl * (*get_acl)(struct inode___262 *, int);
	int (*readlink)(struct dentry___262 *, char *, int);
	void (*put_link)(struct dentry___262 *, struct nameidata *, void *);
	int (*create)(struct inode___262 *, struct dentry___262 *, umode_t, bool);
	int (*link)(struct dentry___262 *, struct inode___262 *, struct dentry___262 *);
	int (*unlink)(struct inode___262 *, struct dentry___262 *);
	int (*symlink)(struct inode___262 *, struct dentry___262 *, const char *);
	int (*mkdir)(struct inode___262 *, struct dentry___262 *, umode_t);
	int (*rmdir)(struct inode___262 *, struct dentry___262 *);
	int (*mknod)(struct inode___262 *, struct dentry___262 *, umode_t, dev_t);
	int (*rename)(struct inode___262 *, struct dentry___262 *, struct inode___262 *, struct dentry___262 *);
	int (*setattr)(struct dentry___262 *, struct iattr___262 *);
	int (*getattr)(struct vfsmount *, struct dentry___262 *, struct kstat *);
	int (*setxattr)(struct dentry___262 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___262 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___262 *, char *, size_t);
	int (*removexattr)(struct dentry___262 *, const char *);
	int (*fiemap)(struct inode___262 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___262 *, struct timespec *, int);
	int (*atomic_open)(struct inode___262 *, struct dentry___262 *, struct file___262 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___187;

struct file_operations___262 {
	struct module___161 *owner;
	loff_t (*llseek)(struct file___262 *, loff_t, int);
	ssize_t (*read)(struct file___262 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___262 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___49 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___49 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___262 *, void *, filldir_t);
	unsigned int (*poll)(struct file___262 *, struct poll_table_struct___148 *);
	long int (*unlocked_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___262 *, struct vm_area_struct___270 *);
	int (*open)(struct inode___262 *, struct file___262 *);
	int (*flush)(struct file___262 *, fl_owner_t);
	int (*release)(struct inode___262 *, struct file___262 *);
	int (*fsync)(struct file___262 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___49 *, int);
	int (*fasync)(int, struct file___262 *, int);
	int (*lock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*sendpage)(struct file___262 *, struct page___261 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___262 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___262 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___262 *, long int, struct file_lock___262 **, void **);
		struct {
			int (*setlease)(struct file___262 *, long int, struct file_lock___262 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___262 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___187 *, struct file___262 *);
};

struct file_lock_operations___262;

struct lock_manager_operations___262;

struct file_lock___262 {
	struct file_lock___262 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___262 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___262 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___262 *fl_ops;
	const struct lock_manager_operations___262 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___262 {
	void (*fl_copy_lock)(struct file_lock___262 *, struct file_lock___262 *);
	void (*fl_release_private)(struct file_lock___262 *);
};

struct lock_manager_operations___262 {
	int (*lm_compare_owner)(struct file_lock___262 *, struct file_lock___262 *);
	long unsigned int (*lm_owner_key)(struct file_lock___262 *);
	void (*lm_notify)(struct file_lock___262 *);
	int (*lm_grant)(struct file_lock___262 *, struct file_lock___262 *, int);
	void (*lm_break)(struct file_lock___262 *);
	int (*lm_change)(struct file_lock___262 **, int);
};

struct file_system_type___262 {
	const char *name;
	int fs_flags;
	struct dentry___262 * (*mount)(struct file_system_type___262 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___262 *);
	struct module___161 *owner;
	struct file_system_type___262 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___262 {
	struct inode___262 * (*alloc_inode)(struct super_block___262 *);
	void (*destroy_inode)(struct inode___262 *);
	void (*dirty_inode)(struct inode___262 *, int);
	int (*write_inode)(struct inode___262 *, struct writeback_control *);
	int (*drop_inode)(struct inode___262 *);
	void (*evict_inode)(struct inode___262 *);
	void (*put_super)(struct super_block___262 *);
	int (*sync_fs)(struct super_block___262 *, int);
	int (*freeze_fs)(struct super_block___262 *);
	int (*unfreeze_fs)(struct super_block___262 *);
	int (*statfs)(struct dentry___262 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___262 *, int *, char *);
	void (*umount_begin)(struct super_block___262 *);
	int (*show_options)(struct seq_file___187 *, struct dentry___262 *);
	int (*show_devname)(struct seq_file___187 *, struct dentry___262 *);
	int (*show_path)(struct seq_file___187 *, struct dentry___262 *);
	int (*show_stats)(struct seq_file___187 *, struct dentry___262 *);
	ssize_t (*quota_read)(struct super_block___262 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___262 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___262 *);
	int (*bdev_try_to_free_page)(struct super_block___262 *, struct page___261 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___262 *);
	void (*free_cached_objects)(struct super_block___262 *, int);
};

struct xattr_handler___158 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___262 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___262 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___262 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___187;

struct seq_file___187 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___264 lock;
	const struct seq_operations___187 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kmem_cache_cpu___244 {
	void **freelist;
	long unsigned int tid;
	struct page___261 *page;
	struct page___261 *partial;
};

struct memcg_cache_params___245 {
	bool is_root_cache;
	union {
		struct kmem_cache___245 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___245 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___125 {
	void * (*alloc)(struct device___260 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___260 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___260 *, struct vm_area_struct___270 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___260 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___260 *, struct page___261 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___260 *, dma_addr_t);
	int (*dma_supported)(struct device___260 *, u64);
	int (*set_dma_mask)(struct device___260 *, u64);
	int is_phys;
};

struct bus_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___260 *, char *);
	ssize_t (*store)(struct bus_type___260 *, const char *, size_t);
};

struct device_attribute___260;

struct driver_attribute___260;

struct bus_type___260 {
	const char *name;
	const char *dev_name;
	struct device___260 *dev_root;
	struct bus_attribute___260 *bus_attrs;
	struct device_attribute___260 *dev_attrs;
	struct driver_attribute___260 *drv_attrs;
	const struct attribute_group___222 **bus_groups;
	const struct attribute_group___222 **dev_groups;
	const struct attribute_group___222 **drv_groups;
	int (*match)(struct device___260 *, struct device_driver___260 *);
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	int (*probe)(struct device___260 *);
	int (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*online)(struct device___260 *);
	int (*offline)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct device___260 *, struct device_attribute___260 *, char *);
	ssize_t (*store)(struct device___260 *, struct device_attribute___260 *, const char *, size_t);
};

struct driver_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___260 *, char *);
	ssize_t (*store)(struct device_driver___260 *, const char *, size_t);
};

struct device_driver___260 {
	const char *name;
	struct bus_type___260 *bus;
	struct module___161 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___260 *);
	int (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	const struct attribute_group___222 **groups;
	const struct dev_pm_ops___260 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___260 {
	const char *name;
	const struct attribute_group___222 **groups;
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
};

struct class_attribute___260;

struct class___260 {
	const char *name;
	struct module___161 *owner;
	struct class_attribute___260 *class_attrs;
	struct device_attribute___260 *dev_attrs;
	const struct attribute_group___222 **dev_groups;
	struct bin_attribute___224 *dev_bin_attrs;
	struct kobject___44 *dev_kobj;
	int (*dev_uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *);
	void (*class_release)(struct class___260 *);
	void (*dev_release)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	const struct kobj_ns_type_operations___41 *ns_type;
	const void * (*namespace)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
	struct subsys_private *p;
};

struct class_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct class___260 *, struct class_attribute___260 *, char *);
	ssize_t (*store)(struct class___260 *, struct class_attribute___260 *, const char *, size_t);
	const void * (*namespace)(struct class___260 *, const struct class_attribute___260 *);
};

struct device_rh___260 {
	struct dev_pm_info_rh___260 power;
};

struct vm_fault___232 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___261 *page;
};

struct nf_bridge_info___52 {
	atomic_t use;
	unsigned int mask;
	struct net_device___53 *physindev;
	struct net_device___53 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___52(struct sk_buff___56 **);

struct net_device_ops___52;

struct ethtool_ops___52;

struct header_ops___52;

struct netdev_rx_queue___52;

struct netdev_queue___52;

struct rtnl_link_ops___43;

struct dcbnl_rtnl_ops___52;

struct net_device___53 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___52 *netdev_ops;
	const struct ethtool_ops___52 *ethtool_ops;
	const struct header_ops___52 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___44 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___52 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___52 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___52 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___52 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___52 = 0,
		NETREG_REGISTERED___52 = 1,
		NETREG_UNREGISTERING___52 = 2,
		NETREG_UNREGISTERED___52 = 3,
		NETREG_RELEASED___52 = 4,
		NETREG_DUMMY___52 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___52 = 0,
		RTNL_LINK_INITIALIZING___52 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___53 *);
	struct netpoll_info *npinfo;
	struct net___67 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___260 dev;
	const struct attribute_group___222 *sysfs_groups[4];
	const struct rtnl_link_ops___43 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___52 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___56 {
	struct sk_buff___56 *next;
	struct sk_buff___56 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___43 *sk;
	struct net_device___53 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___56 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___52 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___9 {
	struct {
		struct page___261 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___9 skb_frag_t___9;

struct skb_shared_info___9 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___56 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___9 frags[17];
};

struct dev_pm_qos_request___64 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___260 *dev;
};

struct ethtool_ops___52 {
	int (*get_settings)(struct net_device___53 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___53 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___53 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___53 *);
	void (*get_regs)(struct net_device___53 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___53 *);
	void (*set_msglevel)(struct net_device___53 *, u32);
	int (*nway_reset)(struct net_device___53 *);
	u32 (*get_link)(struct net_device___53 *);
	int (*get_eeprom_len)(struct net_device___53 *);
	int (*get_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___53 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___53 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___53 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___53 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___53 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___53 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___53 *);
	void (*complete)(struct net_device___53 *);
	u32 (*get_priv_flags)(struct net_device___53 *);
	int (*set_priv_flags)(struct net_device___53 *, u32);
	int (*get_sset_count)(struct net_device___53 *, int);
	int (*get_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___53 *, struct ethtool_flash *);
	int (*reset)(struct net_device___53 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___53 *);
	int (*get_rxfh_indir)(struct net_device___53 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___53 *, const u32 *);
	void (*get_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___53 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___53 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___53 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___53 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___53 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___53 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___53 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___53 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___42 {
	struct callback_head callback_head;
	struct dst_entry___42 *child;
	struct net_device___53 *dev;
	struct dst_ops___66 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___42 *path;
	struct dst_entry___42 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___56 *);
	union {
		int (*output)(struct sock___43 *, struct sk_buff___56 *);
		struct {
			int (*output)(struct sk_buff___56 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___42 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___42;

struct neigh_parms___42;

struct neigh_ops___42;

struct neighbour___42 {
	struct neighbour___42 *next;
	struct neigh_table___42 *tbl;
	struct neigh_parms___42 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___53 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___42 *, struct sk_buff___56 *);
	const struct neigh_ops___42 *ops;
	struct callback_head rcu;
	struct net_device___53 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___66 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___56 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___56 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___67 *, struct dst_entry___42 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___56 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___56 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___186 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___186 *);
	void (*irq_shutdown)(struct irq_data___186 *);
	void (*irq_enable)(struct irq_data___186 *);
	void (*irq_disable)(struct irq_data___186 *);
	void (*irq_ack)(struct irq_data___186 *);
	void (*irq_mask)(struct irq_data___186 *);
	void (*irq_mask_ack)(struct irq_data___186 *);
	void (*irq_unmask)(struct irq_data___186 *);
	void (*irq_eoi)(struct irq_data___186 *);
	int (*irq_set_affinity)(struct irq_data___186 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___186 *);
	int (*irq_set_type)(struct irq_data___186 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___186 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___186 *);
	void (*irq_bus_sync_unlock)(struct irq_data___186 *);
	void (*irq_cpu_online)(struct irq_data___186 *);
	void (*irq_cpu_offline)(struct irq_data___186 *);
	void (*irq_suspend)(struct irq_data___186 *);
	void (*irq_resume)(struct irq_data___186 *);
	void (*irq_pm_shutdown)(struct irq_data___186 *);
	void (*irq_print_chip)(struct irq_data___186 *, struct seq_file___187 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___186 *, void *);
	long unsigned int flags;
};

struct seq_operations___187 {
	void * (*start)(struct seq_file___187 *, loff_t *);
	void (*stop)(struct seq_file___187 *, void *);
	void * (*next)(struct seq_file___187 *, void *, loff_t *);
	int (*show)(struct seq_file___187 *, void *);
};

struct seq_net_private___4 {
	struct net___67 *net;
};

struct pernet_operations___11 {
	struct list_head list;
	int (*init)(struct net___67 *);
	void (*exit)(struct net___67 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___52 {
	int (*ieee_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___53 *);
	u8 (*setstate)(struct net_device___53 *, u8);
	void (*getpermhwaddr)(struct net_device___53 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___53 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___53 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___53 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___53 *, int, u8 *);
	void (*setpfccfg)(struct net_device___53 *, int, u8);
	void (*getpfccfg)(struct net_device___53 *, int, u8 *);
	u8 (*setall)(struct net_device___53 *);
	u8 (*getcap)(struct net_device___53 *, int, u8 *);
	int (*getnumtcs)(struct net_device___53 *, int, u8 *);
	int (*setnumtcs)(struct net_device___53 *, int, u8);
	u8 (*getpfcstate)(struct net_device___53 *);
	void (*setpfcstate)(struct net_device___53 *, u8);
	void (*getbcncfg)(struct net_device___53 *, int, u32 *);
	void (*setbcncfg)(struct net_device___53 *, int, u32);
	void (*getbcnrp)(struct net_device___53 *, int, u8 *);
	void (*setbcnrp)(struct net_device___53 *, int, u8);
	u8 (*setapp)(struct net_device___53 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___53 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___53 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___53 *, int, u8);
	u8 (*getdcbx)(struct net_device___53 *);
	u8 (*setdcbx)(struct net_device___53 *, u8);
	int (*peer_getappinfo)(struct net_device___53 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___53 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___53 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___53 *, struct cee_pfc *);
};

struct cgroupfs_root___157;

struct cgroup___157 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___157 *parent;
	struct dentry___262 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___157 *subsys[11];
	struct cgroupfs_root___157 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___264 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___157 {
	struct super_block___262 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___157 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___93 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___262 *, struct file___262 *);
	ssize_t (*read)(struct cgroup___157 *, struct cftype___93 *, struct file___262 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___157 *, struct cftype___93 *);
	s64 (*read_s64)(struct cgroup___157 *, struct cftype___93 *);
	int (*read_map)(struct cgroup___157 *, struct cftype___93 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___157 *, struct cftype___93 *, struct seq_file___187 *);
	ssize_t (*write)(struct cgroup___157 *, struct cftype___93 *, struct file___262 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___157 *, struct cftype___93 *, u64);
	int (*write_s64)(struct cgroup___157 *, struct cftype___93 *, s64);
	int (*write_string)(struct cgroup___157 *, struct cftype___93 *, const char *);
	int (*trigger)(struct cgroup___157 *, unsigned int);
	int (*release)(struct inode___262 *, struct file___262 *);
	int (*register_event)(struct cgroup___157 *, struct cftype___93 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___157 *, struct cftype___93 *, struct eventfd_ctx *);
};

struct cftype_set___89 {
	struct list_head node;
	struct cftype___93 *cfts;
};

struct task_and_cgroup___89 {
	struct task_struct___263 *task;
	struct cgroup___157 *cgrp;
	struct css_set___157 *cg;
};

struct cgroup_taskset___89 {
	struct task_and_cgroup___89 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___157 *cur_cgrp;
};

struct cgroup_subsys___89 {
	struct cgroup_subsys_state___157 * (*css_alloc)(struct cgroup___157 *);
	int (*css_online)(struct cgroup___157 *);
	void (*css_offline)(struct cgroup___157 *);
	void (*css_free)(struct cgroup___157 *);
	int (*can_attach)(struct cgroup___157 *, struct cgroup_taskset___89 *);
	void (*cancel_attach)(struct cgroup___157 *, struct cgroup_taskset___89 *);
	void (*attach)(struct cgroup___157 *, struct cgroup_taskset___89 *);
	void (*fork)(struct task_struct___263 *);
	void (*exit)(struct cgroup___157 *, struct cgroup___157 *, struct task_struct___263 *);
	void (*bind)(struct cgroup___157 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___157 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___93 *base_cftypes;
	struct cftype_set___89 base_cftset;
	struct module___161 *module;
};

struct scm_fp_list___4 {
	short int count;
	short int max;
	struct file___262 *fp[253];
};

struct scm_cookie___4 {
	struct pid___97 *pid;
	struct scm_fp_list___4 *fp;
	struct scm_creds creds;
	u32 secid;
};

struct sockaddr_nl {
	__kernel_sa_family_t nl_family;
	short unsigned int nl_pad;
	__u32 nl_pid;
	__u32 nl_groups;
};

struct nlmsgerr {
	int error;
	struct nlmsghdr msg;
};

struct nl_pktinfo {
	__u32 group;
};

struct nl_mmap_req {
	unsigned int nm_block_size;
	unsigned int nm_block_nr;
	unsigned int nm_frame_size;
	unsigned int nm_frame_nr;
};

struct nl_mmap_hdr {
	unsigned int nm_status;
	unsigned int nm_len;
	__u32 nm_group;
	__u32 nm_pid;
	__u32 nm_uid;
	__u32 nm_gid;
};

enum nl_mmap_status {
	NL_MMAP_STATUS_UNUSED = 0,
	NL_MMAP_STATUS_RESERVED = 1,
	NL_MMAP_STATUS_VALID = 2,
	NL_MMAP_STATUS_COPY = 3,
	NL_MMAP_STATUS_SKIP = 4,
};

enum {
	NETLINK_UNCONNECTED = 0,
	NETLINK_CONNECTED = 1,
};

enum netlink_skb_flags {
	NETLINK_SKB_MMAPED = 1,
	NETLINK_SKB_TX = 2,
	NETLINK_SKB_DELIVERED = 4,
	NETLINK_SKB_DST = 8,
};

struct netlink_skb_parms___8 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___43 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___8 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___56 *);
	struct mutex___264 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___67 *, struct sock___43 *);
};

struct netlink_callback___54 {
	struct sk_buff___56 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___56 *, struct netlink_callback___54 *);
	int (*done)(struct netlink_callback___54 *);
	void *data;
	struct module___161 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct netlink_notify {
	struct net___67 *net;
	int portid;
	int protocol;
};

struct netlink_dump_control___2 {
	int (*dump)(struct sk_buff___56 *, struct netlink_callback___54 *);
	int (*done)(struct netlink_callback___54 *);
	void *data;
	struct module___161 *module;
	u16 min_dump_alloc;
};

struct netlink_tap {
	struct net_device___53 *dev;
	struct module___161 *module;
	struct list_head list;
};

struct header_ops___52 {
	int (*create)(struct sk_buff___56 *, struct net_device___53 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___56 *, unsigned char *);
	int (*rebuild)(struct sk_buff___56 *);
	int (*cache)(const struct neighbour___42 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___53 *, const unsigned char *);
};

struct napi_struct___52 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___52 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___53 *dev;
	struct sk_buff___56 *gro_list;
	struct sk_buff___56 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___52 {
	struct net_device___53 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___44 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___52 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___44 kobj;
	struct net_device___53 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___52 {
	int (*ndo_init)(struct net_device___53 *);
	void (*ndo_uninit)(struct net_device___53 *);
	int (*ndo_open)(struct net_device___53 *);
	int (*ndo_stop)(struct net_device___53 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___56 *, struct net_device___53 *);
	u16 (*ndo_select_queue)(struct net_device___53 *, struct sk_buff___56 *);
	void (*ndo_change_rx_flags)(struct net_device___53 *, int);
	void (*ndo_set_rx_mode)(struct net_device___53 *);
	int (*ndo_set_mac_address)(struct net_device___53 *, void *);
	int (*ndo_validate_addr)(struct net_device___53 *);
	int (*ndo_do_ioctl)(struct net_device___53 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___53 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___53 *, int);
	int (*ndo_neigh_setup)(struct net_device___53 *, struct neigh_parms___42 *);
	void (*ndo_tx_timeout)(struct net_device___53 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___53 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___53 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___53 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___53 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___53 *);
	int (*ndo_netpoll_setup)(struct net_device___53 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___53 *);
	int (*ndo_busy_poll)(struct napi_struct___52 *);
	int (*ndo_set_vf_mac)(struct net_device___53 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___53 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___53 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___53 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___53 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___53 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___53 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___53 *, int, struct sk_buff___56 *);
	int (*ndo_setup_tc)(struct net_device___53 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___53 *);
	int (*ndo_fcoe_disable)(struct net_device___53 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___53 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___53 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___53 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___53 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___53 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___53 *, const struct sk_buff___56 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___53 *, struct net_device___53 *);
	int (*ndo_del_slave)(struct net_device___53 *, struct net_device___53 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___42 *);
	void (*ndo_neigh_destroy)(struct neighbour___42 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___56 *, struct netlink_callback___54 *, struct net_device___53 *, int);
	int (*ndo_bridge_setlink)(struct net_device___53 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___56 *, u32, u32, struct net_device___53 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___53 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___53 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___53 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___53 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___53 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___53 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___56 *, struct net_device___53 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___53 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___53 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___53 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___42 {
	struct net___67 *net;
	struct net_device___53 *dev;
	struct neigh_parms___42 *next;
	int (*neigh_setup)(struct neighbour___42 *);
	void (*neigh_cleanup)(struct neighbour___42 *);
	struct neigh_table___42 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___43 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___53 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___67 *, struct net_device___53 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___53 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___53 *, struct list_head *);
	size_t (*get_size)(const struct net_device___53 *);
	int (*fill_info)(struct sk_buff___56 *, const struct net_device___53 *);
	size_t (*get_xstats_size)(const struct net_device___53 *);
	int (*fill_xstats)(struct sk_buff___56 *, const struct net_device___53 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___67 * (*get_link_net)(const struct net_device___53 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___53 *, struct net_device___53 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___53 *, const struct net_device___53 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___56 *, const struct net_device___53 *, const struct net_device___53 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___42 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___56 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef struct poll_table_struct___148 poll_table___40;

struct pneigh_entry___42;

struct neigh_hash_table___42;

struct neigh_table___42 {
	struct neigh_table___42 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___53 *, __u32 *);
	int (*constructor)(struct neighbour___42 *);
	int (*pconstructor)(struct pneigh_entry___42 *);
	void (*pdestructor)(struct pneigh_entry___42 *);
	void (*proxy_redo)(struct sk_buff___56 *);
	char *id;
	struct neigh_parms___42 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___53 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___42 *nht;
	struct pneigh_entry___42 **phash_buckets;
};

struct neigh_ops___42 {
	int family;
	void (*solicit)(struct neighbour___42 *, struct sk_buff___56 *);
	void (*error_report)(struct neighbour___42 *, struct sk_buff___56 *);
	int (*output)(struct neighbour___42 *, struct sk_buff___56 *);
	int (*connected_output)(struct neighbour___42 *, struct sk_buff___56 *);
};

struct pneigh_entry___42 {
	struct pneigh_entry___42 *next;
	struct net___67 *net;
	struct net_device___53 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___42 {
	struct neighbour___42 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___41 {
	void (*close)(struct sock___43 *, long int);
	int (*connect)(struct sock___43 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___43 *, int);
	struct sock___43 * (*accept)(struct sock___43 *, int, int *);
	int (*ioctl)(struct sock___43 *, int, long unsigned int);
	int (*init)(struct sock___43 *);
	void (*destroy)(struct sock___43 *);
	void (*shutdown)(struct sock___43 *, int);
	int (*setsockopt)(struct sock___43 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___43 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___43 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___43 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___43 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___49 *, struct sock___43 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___49 *, struct sock___43 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___43 *, struct page___261 *, int, size_t, int);
	int (*bind)(struct sock___43 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___43 *, struct sk_buff___56 *);
	void (*release_cb)(struct sock___43 *);
	void (*mtu_reduced)(struct sock___43 *);
	void (*hash)(struct sock___43 *);
	void (*unhash)(struct sock___43 *);
	void (*rehash)(struct sock___43 *);
	int (*get_port)(struct sock___43 *, short unsigned int);
	void (*clear_sk)(struct sock___43 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___43 *);
	void (*enter_memory_pressure)(struct sock___43 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___245 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___161 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___89 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___41 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___41 {
	void (*enter_memory_pressure)(struct sock___43 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct sock_iocb___2 {
	struct list_head list;
	int flags;
	int size;
	struct socket___42 *sock;
	struct sock___43 *sk;
	struct scm_cookie___4 *scm;
	struct msghdr *msg;
	struct msghdr async_msg;
	struct kiocb___49 *kiocb;
};

struct socket_alloc___4 {
	struct socket___42 socket;
	struct inode___262 vfs_inode;
};

struct netlink_ring {
	void **pg_vec;
	unsigned int head;
	unsigned int frames_per_block;
	unsigned int frame_size;
	unsigned int frame_max;
	unsigned int pg_vec_order;
	unsigned int pg_vec_pages;
	unsigned int pg_vec_len;
	atomic_t pending;
};

struct netlink_sock {
	struct sock___43 sk;
	u32 portid;
	u32 dst_portid;
	u32 dst_group;
	u32 flags;
	u32 subscriptions;
	u32 ngroups;
	long unsigned int *groups;
	long unsigned int state;
	size_t max_recvmsg_len;
	wait_queue_head_t wait;
	bool cb_running;
	struct netlink_callback___54 cb;
	struct mutex___264 *cb_mutex;
	struct mutex___264 cb_def_mutex;
	void (*netlink_rcv)(struct sk_buff___56 *);
	void (*netlink_bind)(int);
	struct module___161 *module;
	struct mutex___264 pg_vec_lock;
	struct netlink_ring rx_ring;
	struct netlink_ring tx_ring;
	atomic_t mapped;
	struct rhash_head node;
};

struct listeners;

struct netlink_table {
	struct rhashtable hash;
	struct hlist_head mc_list;
	struct listeners *listeners;
	unsigned int flags;
	unsigned int groups;
	struct mutex___264 *cb_mutex;
	struct module___161 *module;
	void (*bind)(int);
	bool (*compare)(struct net___67 *, struct sock___43 *);
	int registered;
};

struct listeners {
	struct callback_head rcu;
	long unsigned int masks[0];
};

struct netlink_compare_arg {
	struct net___67 *net;
	u32 portid;
};

struct netlink_broadcast_data {
	struct sock___43 *exclude_sk;
	struct net___67 *net;
	u32 portid;
	u32 group;
	int failure;
	int delivery_failure;
	int congested;
	int delivered;
	gfp_t allocation;
	struct sk_buff___56 *skb;
	struct sk_buff___56 *skb2;
	int (*tx_filter)(struct sock___43 *, struct sk_buff___56 *, void *);
	void *tx_data;
};

struct netlink_set_err_data {
	struct sock___43 *exclude_sk;
	u32 portid;
	u32 group;
	int code;
};

struct nl_seq_iter {
	struct seq_net_private___4 p;
	int link;
	int hash_idx;
};

enum {
	CTRL_CMD_UNSPEC = 0,
	CTRL_CMD_NEWFAMILY = 1,
	CTRL_CMD_DELFAMILY = 2,
	CTRL_CMD_GETFAMILY = 3,
	CTRL_CMD_NEWOPS = 4,
	CTRL_CMD_DELOPS = 5,
	CTRL_CMD_GETOPS = 6,
	CTRL_CMD_NEWMCAST_GRP = 7,
	CTRL_CMD_DELMCAST_GRP = 8,
	CTRL_CMD_GETMCAST_GRP = 9,
	__CTRL_CMD_MAX = 10,
};

enum {
	CTRL_ATTR_UNSPEC = 0,
	CTRL_ATTR_FAMILY_ID = 1,
	CTRL_ATTR_FAMILY_NAME = 2,
	CTRL_ATTR_VERSION = 3,
	CTRL_ATTR_HDRSIZE = 4,
	CTRL_ATTR_MAXATTR = 5,
	CTRL_ATTR_OPS = 6,
	CTRL_ATTR_MCAST_GROUPS = 7,
	__CTRL_ATTR_MAX = 8,
};

enum {
	CTRL_ATTR_OP_UNSPEC = 0,
	CTRL_ATTR_OP_ID = 1,
	CTRL_ATTR_OP_FLAGS = 2,
	__CTRL_ATTR_OP_MAX = 3,
};

enum {
	CTRL_ATTR_MCAST_GRP_UNSPEC = 0,
	CTRL_ATTR_MCAST_GRP_NAME = 1,
	CTRL_ATTR_MCAST_GRP_ID = 2,
	__CTRL_ATTR_MCAST_GRP_MAX = 3,
};

struct genl_ops___6;

struct genl_info___6;

struct genl_family___6 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___6 *, struct sk_buff___54 *, struct genl_info___6 *);
	void (*post_doit)(const struct genl_ops___6 *, struct sk_buff___54 *, struct genl_info___6 *);
	struct nlattr **attrbuf;
	const struct genl_ops___6 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module___159 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___6 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___54 *, struct genl_info___6 *);
	int (*dumpit)(struct sk_buff___54 *, struct netlink_callback___52 *);
	int (*done)(struct netlink_callback___52 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___6 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___65 *_net;
	void *user_ptr[2];
	struct sock___42 *dst_sk;
};

struct page___262;

typedef struct page___262 *pgtable_t___262;

struct address_space___263;

struct kmem_cache___246;

struct page___262 {
	long unsigned int flags;
	struct address_space___263 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___262 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___262 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___246 *slab_cache;
		struct page___262 *first_page;
	};
	long: 64;
};

struct task_struct___264;

struct pv_cpu_ops___264 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___264 *);
	void (*end_context_switch)(struct task_struct___264 *);
};

struct mutex___265 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___264 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___257 {
	struct page___262 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___271;

struct nsproxy___143;

struct signal_struct___264;

struct css_set___158;

struct task_struct___264 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___264 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___271 *mm;
	struct mm_struct___271 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___264 *real_parent;
	struct task_struct___264 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___264 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___264 = 0,
		VTIME_USER___264 = 1,
		VTIME_SYS___264 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___143 *nsproxy;
	struct signal_struct___264 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___158 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___265 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___257 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___271 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___271 *, struct mm_struct___271 *);
	void (*dup_mmap)(struct mm_struct___271 *, struct mm_struct___271 *);
	void (*exit_mmap)(struct mm_struct___271 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___271 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___271 *);
	void (*pgd_free)(struct mm_struct___271 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___271 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___271 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___271 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___271 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___271 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___271 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___271 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___271 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___271 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___271 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___271 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___265 lock;
	void *vdso;
} mm_context_t___265;

struct xol_area___262;

struct uprobes_state___262 {
	struct xol_area___262 *xol_area;
};

struct vm_area_struct___271;

struct file___263;

struct core_state___264;

struct mm_struct___271 {
	struct vm_area_struct___271 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___271 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___271 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___265 context;
	long unsigned int flags;
	struct core_state___264 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___264 *owner;
	struct file___263 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___262 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___45;

struct kobj_type___45;

struct kobject___45 {
	const char *name;
	struct list_head entry;
	struct kobject___45 *parent;
	struct kset___45 *kset;
	struct kobj_type___45 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___162;

struct module_kobject___160 {
	struct kobject___45 kobj;
	struct module___162 *mod;
	struct kobject___45 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___160;

struct module___162 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___160 mkobj;
	struct module_attribute___160 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___45 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___264 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___262 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___262 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___245;

struct memcg_cache_params___246;

struct kmem_cache___246 {
	struct kmem_cache_cpu___245 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___45 kobj;
	struct memcg_cache_params___246 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___263;

struct address_space_operations___263;

struct address_space___263 {
	struct inode___263 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___265 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___263 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___263;

struct path___263 {
	struct vfsmount *mnt;
	struct dentry___263 *dentry;
};

struct file_operations___263;

struct file___263 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___263 f_path;
	struct inode___263 *f_inode;
	const struct file_operations___263 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___263 *f_mapping;
	struct mutex___265 f_pos_lock;
};

struct vm_operations_struct___237;

struct vm_area_struct___271 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___271 *vm_next;
	struct vm_area_struct___271 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___271 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___237 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___263 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___233;

struct vm_operations_struct___237 {
	void (*open)(struct vm_area_struct___271 *);
	void (*close)(struct vm_area_struct___271 *);
	int (*fault)(struct vm_area_struct___271 *, struct vm_fault___233 *);
	int (*page_mkwrite)(struct vm_area_struct___271 *, struct vm_fault___233 *);
	int (*access)(struct vm_area_struct___271 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___271 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___271 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___271 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___271 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___264 {
	struct task_struct___264 *task;
	struct core_thread___264 *next;
};

struct core_state___264 {
	atomic_t nr_threads;
	struct core_thread___264 dumper;
	struct completion startup;
};

struct fasync_struct___263;

struct socket_wq___42 {
	wait_queue_head_t wait;
	struct fasync_struct___263 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___263 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___263 *fa_next;
	struct file___263 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___44;

struct proto_ops___42;

struct socket___43 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___42 *wq;
	struct file___263 *file;
	struct sock___44 *sk;
	const struct proto_ops___42 *ops;
};

struct proto___42;

struct net___68;

struct sock_common___42 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___42 *skc_prot;
	struct net___68 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___57;

struct sk_buff_head___54 {
	struct sk_buff___57 *next;
	struct sk_buff___57 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___43;

struct dst_entry___43;

struct cg_proto___42;

struct sock___44 {
	struct sock_common___42 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___54 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___57 *head;
		struct sk_buff___57 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___43 *sk_filter;
	struct socket_wq___42 *sk_wq;
	struct sk_buff_head___54 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___43 *sk_rx_dst;
	struct dst_entry___43 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___54 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___54 sk_error_queue;
	struct proto___42 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___43 *sk_socket;
	void *sk_user_data;
	struct page_frag___257 sk_frag;
	struct sk_buff___57 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___42 *sk_cgrp;
	void (*sk_state_change)(struct sock___44 *);
	void (*sk_data_ready)(struct sock___44 *, int);
	void (*sk_write_space)(struct sock___44 *);
	void (*sk_error_report)(struct sock___44 *);
	int (*sk_backlog_rcv)(struct sock___44 *, struct sk_buff___57 *);
	void (*sk_destruct)(struct sock___44 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___149;

struct kiocb___50;

struct proto_ops___42 {
	int family;
	struct module___162 *owner;
	int (*release)(struct socket___43 *);
	int (*bind)(struct socket___43 *, struct sockaddr *, int);
	int (*connect)(struct socket___43 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___43 *, struct socket___43 *);
	int (*accept)(struct socket___43 *, struct socket___43 *, int);
	int (*getname)(struct socket___43 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___263 *, struct socket___43 *, struct poll_table_struct___149 *);
	int (*ioctl)(struct socket___43 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___43 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___43 *, int);
	int (*shutdown)(struct socket___43 *, int);
	int (*setsockopt)(struct socket___43 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___43 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___43 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___43 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___50 *, struct socket___43 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___50 *, struct socket___43 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___263 *, struct socket___43 *, struct vm_area_struct___271 *);
	ssize_t (*sendpage)(struct socket___43 *, struct page___262 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___43 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___44 *, int);
		struct {
			void (*set_peek_off)(struct sock___44 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___151)(struct file___263 *, wait_queue_head_t *, struct poll_table_struct___149 *);

struct poll_table_struct___149 {
	poll_queue_proc___151 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___50(struct kiocb___50 *, struct io_event *);

struct kiocb___50 {
	atomic_t ki_users;
	struct file___263 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___50 *ki_cancel;
	void (*ki_dtor)(struct kiocb___50 *);
	union {
		void *user;
		struct task_struct___264 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___68;

struct ctl_table_set___68;

struct ctl_dir___68;

struct ctl_node___68;

struct ctl_table_header___68 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___68 *root;
	struct ctl_table_set___68 *set;
	struct ctl_dir___68 *parent;
	struct ctl_node___68 *node;
};

struct ctl_dir___68 {
	struct ctl_table_header___68 header;
	struct rb_root root;
};

struct ctl_table_set___68 {
	int (*is_seen)(struct ctl_table_set___68 *);
	struct ctl_dir___68 dir;
};

struct netns_core___65 {
	struct ctl_table_header___68 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___66 {
	struct mutex___265 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___65 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___68 *ctl;
};

struct netns_ipv4___65 {
	struct ctl_table_header___68 *forw_hdr;
	struct ctl_table_header___68 *frags_hdr;
	struct ctl_table_header___68 *ipv4_hdr;
	struct ctl_table_header___68 *route_hdr;
	struct ctl_table_header___68 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___44 *fibnl;
	struct sock___44 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___65 {
	struct ctl_table_header___68 *hdr;
	struct ctl_table_header___68 *route_hdr;
	struct ctl_table_header___68 *icmp_hdr;
	struct ctl_table_header___68 *frags_hdr;
	struct ctl_table_header___68 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___54;

struct neighbour___43;

struct dst_ops___67 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___67 *);
	struct dst_entry___43 * (*check)(struct dst_entry___43 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___43 *);
	unsigned int (*mtu)(const struct dst_entry___43 *);
	u32 * (*cow_metrics)(struct dst_entry___43 *, long unsigned int);
	void (*destroy)(struct dst_entry___43 *);
	void (*ifdown)(struct dst_entry___43 *, struct net_device___54 *, int);
	struct dst_entry___43 * (*negative_advice)(struct dst_entry___43 *);
	void (*link_failure)(struct sk_buff___57 *);
	void (*update_pmtu)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___57 *, u32);
	void (*redirect)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___57 *);
	int (*local_out)(struct sk_buff___57 *);
	struct neighbour___43 * (*neigh_lookup)(const struct dst_entry___43 *, struct sk_buff___57 *, const void *);
	struct kmem_cache___246 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___67 {
	struct netns_sysctl_ipv6___65 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___67 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___44 **icmp_sk;
	struct sock___44 *ndisc_sk;
	struct sock___44 *tcp_sk;
	struct sock___44 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___65 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___68 *sysctl_header;
	struct sock___44 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___42 {
	struct sock___44 *v4_ctl_sk;
	struct sock___44 *v6_ctl_sk;
};

struct netns_nf___65 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___68 *nf_log_dir_header;
};

struct nf_proto_net___65 {
	struct ctl_table_header___68 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___65 {
	struct nf_proto_net___65 pn;
	unsigned int timeout;
};

struct nf_tcp_net___65 {
	struct nf_proto_net___65 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___65 {
	struct nf_proto_net___65 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___65 {
	struct nf_proto_net___65 pn;
	unsigned int timeout;
};

struct nf_ip_net___65 {
	struct nf_generic_net___65 generic;
	struct nf_tcp_net___65 tcp;
	struct nf_udp_net___65 udp;
	struct nf_icmp_net___65 icmp;
	struct nf_icmp_net___65 icmpv6;
};

struct netns_ct___66 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___68 *sysctl_header;
	struct ctl_table_header___68 *acct_sysctl_header;
	struct ctl_table_header___68 *tstamp_sysctl_header;
	struct ctl_table_header___68 *event_sysctl_header;
	struct ctl_table_header___68 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___246 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___65 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___65 {
	struct netns_sysctl_ipv6___65 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___67 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___44 *nlsk;
	struct sock___44 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___68 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___67 xfrm4_dst_ops;
	struct dst_ops___67 xfrm6_dst_ops;
};

struct net___68 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___68 sysctls;
	struct sock___44 *rtnl;
	struct sock___44 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___54 *loopback_dev;
	struct netns_core___65 core;
	struct netns_mib mib;
	struct netns_packet___66 packet;
	struct netns_unix___65 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___65 ipv4;
	struct netns_ipv6___67 ipv6;
	struct netns_sctp___65 sctp;
	struct netns_dccp___42 dccp;
	struct netns_nf___65 nf;
	struct netns_xt xt;
	struct netns_ct___66 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___65 nf_frag;
	struct sock___44 *nfnl;
	struct sock___44 *nfnl_stash;
	struct sk_buff_head___54 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___67 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___44 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___44 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___265 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___265 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___264;

struct lruvec___264 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___264 *zone;
};

struct pglist_data___264;

struct zone___264 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___264 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___264 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___264 {
	struct zone___264 *zone;
	int zone_idx;
};

struct zonelist___264 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___264 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___264 {
	struct zone___264 node_zones[4];
	struct zonelist___264 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___264 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___187;

struct x86_io_apic_ops___187 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___187 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___187;

struct irq_data___187 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___187 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___261;

struct dev_pm_ops___261 {
	int (*prepare)(struct device___261 *);
	void (*complete)(struct device___261 *);
	int (*suspend)(struct device___261 *);
	int (*resume)(struct device___261 *);
	int (*freeze)(struct device___261 *);
	int (*thaw)(struct device___261 *);
	int (*poweroff)(struct device___261 *);
	int (*restore)(struct device___261 *);
	int (*suspend_late)(struct device___261 *);
	int (*resume_early)(struct device___261 *);
	int (*freeze_late)(struct device___261 *);
	int (*thaw_early)(struct device___261 *);
	int (*poweroff_late)(struct device___261 *);
	int (*restore_early)(struct device___261 *);
	int (*suspend_noirq)(struct device___261 *);
	int (*resume_noirq)(struct device___261 *);
	int (*freeze_noirq)(struct device___261 *);
	int (*thaw_noirq)(struct device___261 *);
	int (*poweroff_noirq)(struct device___261 *);
	int (*restore_noirq)(struct device___261 *);
	int (*runtime_suspend)(struct device___261 *);
	int (*runtime_resume)(struct device___261 *);
	int (*runtime_idle)(struct device___261 *);
};

struct dev_pm_qos___64;

struct dev_pm_info___64 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___64 *qos;
};

struct dma_map_ops___126;

struct dev_archdata___126 {
	struct dma_map_ops___126 *dma_ops;
	void *iommu;
};

struct device_type___261;

struct bus_type___261;

struct device_driver___261;

struct dev_pm_domain___261;

struct class___261;

struct attribute_group___223;

struct device_rh___261;

struct device___261 {
	struct device___261 *parent;
	struct device_private *p;
	struct kobject___45 kobj;
	const char *init_name;
	const struct device_type___261 *type;
	struct mutex___265 mutex;
	struct bus_type___261 *bus;
	struct device_driver___261 *driver;
	void *platform_data;
	struct dev_pm_info___64 power;
	struct dev_pm_domain___261 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___126 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___261 *class;
	const struct attribute_group___223 **groups;
	void (*release)(struct device___261 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___261 *device_rh;
};

struct dev_pm_qos_request___65;

struct dev_pm_qos___64 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___65 *latency_req;
	struct dev_pm_qos_request___65 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___65 *latency_tolerance_req;
};

struct dev_pm_info_rh___261 {
	void (*set_latency_tolerance)(struct device___261 *, s32);
};

struct dev_pm_domain___261 {
	struct dev_pm_ops___261 ops;
};

struct smp_ops___264 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___264 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___42 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___44 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___225;

struct attribute_group___223 {
	const char *name;
	umode_t (*is_visible)(struct kobject___45 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___225 **bin_attrs;
};

struct bin_attribute___225 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___263 *, struct kobject___45 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___263 *, struct kobject___45 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	int (*mmap)(struct file___263 *, struct kobject___45 *, struct bin_attribute___225 *, struct vm_area_struct___271 *);
};

struct sysfs_ops___45 {
	ssize_t (*show)(struct kobject___45 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___45 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___45 *, const struct attribute *);
};

struct kset_uevent_ops___45;

struct kset___45 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___45 kobj;
	const struct kset_uevent_ops___45 *uevent_ops;
};

struct kobj_type___45 {
	void (*release)(struct kobject___45 *);
	const struct sysfs_ops___45 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___42 * (*child_ns_type)(struct kobject___45 *);
	const void * (*namespace)(struct kobject___45 *);
};

struct kset_uevent_ops___45 {
	int (* const filter)(struct kset___45 *, struct kobject___45 *);
	const char * (* const name)(struct kset___45 *, struct kobject___45 *);
	int (* const uevent)(struct kset___45 *, struct kobject___45 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___245 {
	void **freelist;
	long unsigned int tid;
	struct page___262 *page;
	struct page___262 *partial;
};

struct memcg_cache_params___246 {
	bool is_root_cache;
	union {
		struct kmem_cache___246 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___246 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___126 {
	void * (*alloc)(struct device___261 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___261 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___261 *, struct vm_area_struct___271 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___261 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___261 *, struct page___262 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___261 *, dma_addr_t);
	int (*dma_supported)(struct device___261 *, u64);
	int (*set_dma_mask)(struct device___261 *, u64);
	int is_phys;
};

struct bus_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___261 *, char *);
	ssize_t (*store)(struct bus_type___261 *, const char *, size_t);
};

struct device_attribute___261;

struct driver_attribute___261;

struct bus_type___261 {
	const char *name;
	const char *dev_name;
	struct device___261 *dev_root;
	struct bus_attribute___261 *bus_attrs;
	struct device_attribute___261 *dev_attrs;
	struct driver_attribute___261 *drv_attrs;
	const struct attribute_group___223 **bus_groups;
	const struct attribute_group___223 **dev_groups;
	const struct attribute_group___223 **drv_groups;
	int (*match)(struct device___261 *, struct device_driver___261 *);
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	int (*probe)(struct device___261 *);
	int (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*online)(struct device___261 *);
	int (*offline)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct device___261 *, struct device_attribute___261 *, char *);
	ssize_t (*store)(struct device___261 *, struct device_attribute___261 *, const char *, size_t);
};

struct driver_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___261 *, char *);
	ssize_t (*store)(struct device_driver___261 *, const char *, size_t);
};

struct device_driver___261 {
	const char *name;
	struct bus_type___261 *bus;
	struct module___162 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___261 *);
	int (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	const struct attribute_group___223 **groups;
	const struct dev_pm_ops___261 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___261 {
	const char *name;
	const struct attribute_group___223 **groups;
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
};

struct class_attribute___261;

struct class___261 {
	const char *name;
	struct module___162 *owner;
	struct class_attribute___261 *class_attrs;
	struct device_attribute___261 *dev_attrs;
	const struct attribute_group___223 **dev_groups;
	struct bin_attribute___225 *dev_bin_attrs;
	struct kobject___45 *dev_kobj;
	int (*dev_uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *);
	void (*class_release)(struct class___261 *);
	void (*dev_release)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	const struct kobj_ns_type_operations___42 *ns_type;
	const void * (*namespace)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
	struct subsys_private *p;
};

struct class_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct class___261 *, struct class_attribute___261 *, char *);
	ssize_t (*store)(struct class___261 *, struct class_attribute___261 *, const char *, size_t);
	const void * (*namespace)(struct class___261 *, const struct class_attribute___261 *);
};

struct device_rh___261 {
	struct dev_pm_info_rh___261 power;
};

struct vm_fault___233 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___262 *page;
};

struct ctl_node___68 {
	struct rb_node node;
	struct ctl_table_header___68 *header;
};

struct ctl_table_root___68 {
	struct ctl_table_set___68 default_set;
	struct ctl_table_set___68 * (*lookup)(struct ctl_table_root___68 *, struct nsproxy___143 *);
	int (*permissions)(struct ctl_table_header___68 *, struct ctl_table *);
};

struct nsproxy___143 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___68 *net_ns;
};

struct signal_struct___264 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___264 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___264 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___265 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___158;

struct css_set___158 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___158 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___53 {
	atomic_t use;
	unsigned int mask;
	struct net_device___54 *physindev;
	struct net_device___54 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___53(struct sk_buff___57 **);

struct net_device_ops___53;

struct ethtool_ops___53;

struct header_ops___53;

struct in_device___5;

struct netdev_rx_queue___53;

struct netdev_queue___53;

struct rtnl_link_ops___44;

struct dcbnl_rtnl_ops___53;

struct net_device___54 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___53 *netdev_ops;
	const struct ethtool_ops___53 *ethtool_ops;
	const struct header_ops___53 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___45 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___5 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___53 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___53 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___53 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___53 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___53 = 0,
		NETREG_REGISTERED___53 = 1,
		NETREG_UNREGISTERING___53 = 2,
		NETREG_UNREGISTERED___53 = 3,
		NETREG_RELEASED___53 = 4,
		NETREG_DUMMY___53 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___53 = 0,
		RTNL_LINK_INITIALIZING___53 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___54 *);
	struct netpoll_info *npinfo;
	struct net___68 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___261 dev;
	const struct attribute_group___223 *sysfs_groups[4];
	const struct rtnl_link_ops___44 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___53 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___57 {
	struct sk_buff___57 *next;
	struct sk_buff___57 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___44 *sk;
	struct net_device___54 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___57 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___53 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___10 {
	struct {
		struct page___262 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___10 skb_frag_t___10;

struct skb_shared_info___10 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___57 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___10 frags[17];
};

struct nf_hook_state___4 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___54 *in;
	struct net_device___54 *out;
	struct sock___44 *sk;
	int (*okfn)(struct sock___44 *, struct sk_buff___57 *);
};

struct nf_hook_ops___3;

typedef unsigned int nf_hookfn___2(const struct nf_hook_ops___3 *, struct sk_buff___57 *, const struct net_device___54 *, const struct net_device___54 *, const struct nf_hook_state___4 *);

struct nf_hook_ops___3 {
	struct list_head list;
	nf_hookfn___2 *hook;
	struct module___162 *owner;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
	long unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct nf_afinfo___67 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___57 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___57 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___68 *, struct dst_entry___43 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___57 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___57 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dst_entry___43 {
	struct callback_head callback_head;
	struct dst_entry___43 *child;
	struct net_device___54 *dev;
	struct dst_ops___67 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___43 *path;
	struct dst_entry___43 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___57 *);
	union {
		int (*output)(struct sock___44 *, struct sk_buff___57 *);
		struct {
			int (*output)(struct sk_buff___57 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___43 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct nf_conn___2;

enum ip_conntrack_info;

struct nfq_ct_hook {
	size_t (*build_size)(const struct nf_conn___2 *);
	int (*build)(struct sk_buff___57 *, struct nf_conn___2 *);
	int (*parse)(const struct nlattr *, struct nf_conn___2 *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn___2 *, u32, u32);
	void (*seq_adjust)(struct sk_buff___57 *, struct nf_conn___2 *, enum ip_conntrack_info, s32);
};

struct file_lock___263;

struct seq_file___188;

struct file_operations___263 {
	struct module___162 *owner;
	loff_t (*llseek)(struct file___263 *, loff_t, int);
	ssize_t (*read)(struct file___263 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___263 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___50 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___50 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___263 *, void *, filldir_t);
	unsigned int (*poll)(struct file___263 *, struct poll_table_struct___149 *);
	long int (*unlocked_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___263 *, struct vm_area_struct___271 *);
	int (*open)(struct inode___263 *, struct file___263 *);
	int (*flush)(struct file___263 *, fl_owner_t);
	int (*release)(struct inode___263 *, struct file___263 *);
	int (*fsync)(struct file___263 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___50 *, int);
	int (*fasync)(int, struct file___263 *, int);
	int (*lock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*sendpage)(struct file___263 *, struct page___262 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___263 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___263 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___263 *, long int, struct file_lock___263 **, void **);
		struct {
			int (*setlease)(struct file___263 *, long int, struct file_lock___263 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___263 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___188 *, struct file___263 *);
};

struct dev_pm_qos_request___65 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___261 *dev;
};

struct dentry_operations___263;

struct super_block___263;

struct dentry___263 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___263 *d_parent;
	struct qstr d_name;
	struct inode___263 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___263 *d_op;
	struct super_block___263 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___263;

struct dquot___263;

struct block_device___263;

struct inode___263 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___263 *i_op;
	struct super_block___263 *i_sb;
	struct address_space___263 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___265 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___263 *i_fop;
	struct file_lock___263 *i_flock;
	struct address_space___263 i_data;
	struct dquot___263 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___263 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___263 {
	int (*d_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_hash)(const struct dentry___263 *, struct qstr *);
	int (*d_compare)(const struct dentry___263 *, const struct dentry___263 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___263 *);
	void (*d_release)(struct dentry___263 *);
	void (*d_prune)(struct dentry___263 *);
	void (*d_iput)(struct dentry___263 *, struct inode___263 *);
	char * (*d_dname)(struct dentry___263 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___263 *);
	int (*d_manage)(struct dentry___263 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___263;

struct mem_dqinfo___263 {
	struct quota_format_type___263 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___263;

struct quota_info___263 {
	unsigned int flags;
	struct mutex___265 dqio_mutex;
	struct mutex___265 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___263 *files[2];
	struct mem_dqinfo___263 info[2];
	const struct quota_format_ops___263 *ops[2];
};

struct file_system_type___263;

struct super_operations___263;

struct dquot_operations___263;

struct quotactl_ops___263;

struct xattr_handler___159;

struct super_block___263 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___263 *s_type;
	const struct super_operations___263 *s_op;
	const struct dquot_operations___263 *dq_op;
	const struct quotactl_ops___263 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___263 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___159 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___263 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___263 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___265 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___263 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___263 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___263 *bd_inode;
	struct super_block___263 *bd_super;
	struct mutex___265 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___263 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___265 bd_fsfreeze_mutex;
};

struct cgroup___158;

struct cgroup_subsys_state___158 {
	struct cgroup___158 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___263 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___263 *ia_file;
};

struct dquot___263 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___265 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___263 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___263 {
	int qf_fmt_id;
	const struct quota_format_ops___263 *qf_ops;
	struct module___162 *qf_owner;
	struct quota_format_type___263 *qf_next;
};

struct quota_format_ops___263 {
	int (*check_quota_file)(struct super_block___263 *, int);
	int (*read_file_info)(struct super_block___263 *, int);
	int (*write_file_info)(struct super_block___263 *, int);
	int (*free_file_info)(struct super_block___263 *, int);
	int (*read_dqblk)(struct dquot___263 *);
	int (*commit_dqblk)(struct dquot___263 *);
	int (*release_dqblk)(struct dquot___263 *);
};

struct dquot_operations___263 {
	int (*write_dquot)(struct dquot___263 *);
	struct dquot___263 * (*alloc_dquot)(struct super_block___263 *, int);
	void (*destroy_dquot)(struct dquot___263 *);
	int (*acquire_dquot)(struct dquot___263 *);
	int (*release_dquot)(struct dquot___263 *);
	int (*mark_dirty)(struct dquot___263 *);
	int (*write_info)(struct super_block___263 *, int);
	qsize_t * (*get_reserved_space)(struct inode___263 *);
};

struct quotactl_ops___263 {
	int (*quota_on)(struct super_block___263 *, int, int, struct path___263 *);
	int (*quota_on_meta)(struct super_block___263 *, int, int);
	int (*quota_off)(struct super_block___263 *, int);
	int (*quota_sync)(struct super_block___263 *, int);
	int (*get_info)(struct super_block___263 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___263 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___263 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___263 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___263 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___263 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___263 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___263 *, unsigned int);
};

struct address_space_operations___263 {
	int (*writepage)(struct page___262 *, struct writeback_control *);
	int (*readpage)(struct file___263 *, struct page___262 *);
	int (*writepages)(struct address_space___263 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___262 *);
	int (*readpages)(struct file___263 *, struct address_space___263 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___263 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___262 **, void **);
	int (*write_end)(struct file___263 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___262 *, void *);
	sector_t (*bmap)(struct address_space___263 *, sector_t);
	void (*invalidatepage)(struct page___262 *, long unsigned int);
	int (*releasepage)(struct page___262 *, gfp_t);
	void (*freepage)(struct page___262 *);
	ssize_t (*direct_IO)(int, struct kiocb___50 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___263 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___263 *, struct page___262 *, struct page___262 *, enum migrate_mode);
	int (*launder_page)(struct page___262 *);
	int (*is_partially_uptodate)(struct page___262 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___262 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___263 *, struct page___262 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___263 *, sector_t *);
	void (*swap_deactivate)(struct file___263 *);
	void (*invalidatepage_range)(struct page___262 *, unsigned int, unsigned int);
};

struct inode_operations___263 {
	struct dentry___263 * (*lookup)(struct inode___263 *, struct dentry___263 *, unsigned int);
	void * (*follow_link)(struct dentry___263 *, struct nameidata *);
	int (*permission)(struct inode___263 *, int);
	struct posix_acl * (*get_acl)(struct inode___263 *, int);
	int (*readlink)(struct dentry___263 *, char *, int);
	void (*put_link)(struct dentry___263 *, struct nameidata *, void *);
	int (*create)(struct inode___263 *, struct dentry___263 *, umode_t, bool);
	int (*link)(struct dentry___263 *, struct inode___263 *, struct dentry___263 *);
	int (*unlink)(struct inode___263 *, struct dentry___263 *);
	int (*symlink)(struct inode___263 *, struct dentry___263 *, const char *);
	int (*mkdir)(struct inode___263 *, struct dentry___263 *, umode_t);
	int (*rmdir)(struct inode___263 *, struct dentry___263 *);
	int (*mknod)(struct inode___263 *, struct dentry___263 *, umode_t, dev_t);
	int (*rename)(struct inode___263 *, struct dentry___263 *, struct inode___263 *, struct dentry___263 *);
	int (*setattr)(struct dentry___263 *, struct iattr___263 *);
	int (*getattr)(struct vfsmount *, struct dentry___263 *, struct kstat *);
	int (*setxattr)(struct dentry___263 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___263 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___263 *, char *, size_t);
	int (*removexattr)(struct dentry___263 *, const char *);
	int (*fiemap)(struct inode___263 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___263 *, struct timespec *, int);
	int (*atomic_open)(struct inode___263 *, struct dentry___263 *, struct file___263 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___263;

struct lock_manager_operations___263;

struct file_lock___263 {
	struct file_lock___263 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___263 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___263 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___263 *fl_ops;
	const struct lock_manager_operations___263 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___263 {
	void (*fl_copy_lock)(struct file_lock___263 *, struct file_lock___263 *);
	void (*fl_release_private)(struct file_lock___263 *);
};

struct lock_manager_operations___263 {
	int (*lm_compare_owner)(struct file_lock___263 *, struct file_lock___263 *);
	long unsigned int (*lm_owner_key)(struct file_lock___263 *);
	void (*lm_notify)(struct file_lock___263 *);
	int (*lm_grant)(struct file_lock___263 *, struct file_lock___263 *, int);
	void (*lm_break)(struct file_lock___263 *);
	int (*lm_change)(struct file_lock___263 **, int);
};

struct file_system_type___263 {
	const char *name;
	int fs_flags;
	struct dentry___263 * (*mount)(struct file_system_type___263 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___263 *);
	struct module___162 *owner;
	struct file_system_type___263 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___263 {
	struct inode___263 * (*alloc_inode)(struct super_block___263 *);
	void (*destroy_inode)(struct inode___263 *);
	void (*dirty_inode)(struct inode___263 *, int);
	int (*write_inode)(struct inode___263 *, struct writeback_control *);
	int (*drop_inode)(struct inode___263 *);
	void (*evict_inode)(struct inode___263 *);
	void (*put_super)(struct super_block___263 *);
	int (*sync_fs)(struct super_block___263 *, int);
	int (*freeze_fs)(struct super_block___263 *);
	int (*unfreeze_fs)(struct super_block___263 *);
	int (*statfs)(struct dentry___263 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___263 *, int *, char *);
	void (*umount_begin)(struct super_block___263 *);
	int (*show_options)(struct seq_file___188 *, struct dentry___263 *);
	int (*show_devname)(struct seq_file___188 *, struct dentry___263 *);
	int (*show_path)(struct seq_file___188 *, struct dentry___263 *);
	int (*show_stats)(struct seq_file___188 *, struct dentry___263 *);
	ssize_t (*quota_read)(struct super_block___263 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___263 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___263 *);
	int (*bdev_try_to_free_page)(struct super_block___263 *, struct page___262 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___263 *);
	void (*free_cached_objects)(struct super_block___263 *, int);
};

struct xattr_handler___159 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___263 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___263 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___263 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___188;

struct seq_file___188 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___265 lock;
	const struct seq_operations___188 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___53 {
	int (*get_settings)(struct net_device___54 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___54 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___54 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___54 *);
	void (*get_regs)(struct net_device___54 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___54 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___54 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___54 *);
	void (*set_msglevel)(struct net_device___54 *, u32);
	int (*nway_reset)(struct net_device___54 *);
	u32 (*get_link)(struct net_device___54 *);
	int (*get_eeprom_len)(struct net_device___54 *);
	int (*get_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___54 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___54 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___54 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___54 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___54 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___54 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___54 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___54 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___54 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___54 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___54 *);
	void (*complete)(struct net_device___54 *);
	u32 (*get_priv_flags)(struct net_device___54 *);
	int (*set_priv_flags)(struct net_device___54 *, u32);
	int (*get_sset_count)(struct net_device___54 *, int);
	int (*get_rxnfc)(struct net_device___54 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___54 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___54 *, struct ethtool_flash *);
	int (*reset)(struct net_device___54 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___54 *);
	int (*get_rxfh_indir)(struct net_device___54 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___54 *, const u32 *);
	void (*get_channels)(struct net_device___54 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___54 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___54 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___54 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___54 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___54 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___54 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___54 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___54 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___54 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___54 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___54 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_table___43;

struct neigh_parms___43;

struct neigh_ops___43;

struct neighbour___43 {
	struct neighbour___43 *next;
	struct neigh_table___43 *tbl;
	struct neigh_parms___43 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___54 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___43 *, struct sk_buff___57 *);
	const struct neigh_ops___43 *ops;
	struct callback_head rcu;
	struct net_device___54 *dev;
	u8 primary_key[0];
};

struct irq_chip___187 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___187 *);
	void (*irq_shutdown)(struct irq_data___187 *);
	void (*irq_enable)(struct irq_data___187 *);
	void (*irq_disable)(struct irq_data___187 *);
	void (*irq_ack)(struct irq_data___187 *);
	void (*irq_mask)(struct irq_data___187 *);
	void (*irq_mask_ack)(struct irq_data___187 *);
	void (*irq_unmask)(struct irq_data___187 *);
	void (*irq_eoi)(struct irq_data___187 *);
	int (*irq_set_affinity)(struct irq_data___187 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___187 *);
	int (*irq_set_type)(struct irq_data___187 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___187 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___187 *);
	void (*irq_bus_sync_unlock)(struct irq_data___187 *);
	void (*irq_cpu_online)(struct irq_data___187 *);
	void (*irq_cpu_offline)(struct irq_data___187 *);
	void (*irq_suspend)(struct irq_data___187 *);
	void (*irq_resume)(struct irq_data___187 *);
	void (*irq_pm_shutdown)(struct irq_data___187 *);
	void (*irq_print_chip)(struct irq_data___187 *, struct seq_file___188 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___187 *, void *);
	long unsigned int flags;
};

struct seq_operations___188 {
	void * (*start)(struct seq_file___188 *, loff_t *);
	void (*stop)(struct seq_file___188 *, void *);
	void * (*next)(struct seq_file___188 *, void *, loff_t *);
	int (*show)(struct seq_file___188 *, void *);
};

struct pernet_operations___12 {
	struct list_head list;
	int (*init)(struct net___68 *);
	void (*exit)(struct net___68 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___53 {
	int (*ieee_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___54 *);
	u8 (*setstate)(struct net_device___54 *, u8);
	void (*getpermhwaddr)(struct net_device___54 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___54 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___54 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___54 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___54 *, int, u8 *);
	void (*setpfccfg)(struct net_device___54 *, int, u8);
	void (*getpfccfg)(struct net_device___54 *, int, u8 *);
	u8 (*setall)(struct net_device___54 *);
	u8 (*getcap)(struct net_device___54 *, int, u8 *);
	int (*getnumtcs)(struct net_device___54 *, int, u8 *);
	int (*setnumtcs)(struct net_device___54 *, int, u8);
	u8 (*getpfcstate)(struct net_device___54 *);
	void (*setpfcstate)(struct net_device___54 *, u8);
	void (*getbcncfg)(struct net_device___54 *, int, u32 *);
	void (*setbcncfg)(struct net_device___54 *, int, u32);
	void (*getbcnrp)(struct net_device___54 *, int, u8 *);
	void (*setbcnrp)(struct net_device___54 *, int, u8);
	u8 (*setapp)(struct net_device___54 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___54 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___54 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___54 *, int, u8);
	u8 (*getdcbx)(struct net_device___54 *);
	u8 (*setdcbx)(struct net_device___54 *, u8);
	int (*peer_getappinfo)(struct net_device___54 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___54 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___54 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___54 *, struct cee_pfc *);
};

struct cgroupfs_root___158;

struct cgroup___158 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___158 *parent;
	struct dentry___263 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___158 *subsys[11];
	struct cgroupfs_root___158 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___265 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___158 {
	struct super_block___263 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___158 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___94 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___263 *, struct file___263 *);
	ssize_t (*read)(struct cgroup___158 *, struct cftype___94 *, struct file___263 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___158 *, struct cftype___94 *);
	s64 (*read_s64)(struct cgroup___158 *, struct cftype___94 *);
	int (*read_map)(struct cgroup___158 *, struct cftype___94 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___158 *, struct cftype___94 *, struct seq_file___188 *);
	ssize_t (*write)(struct cgroup___158 *, struct cftype___94 *, struct file___263 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___158 *, struct cftype___94 *, u64);
	int (*write_s64)(struct cgroup___158 *, struct cftype___94 *, s64);
	int (*write_string)(struct cgroup___158 *, struct cftype___94 *, const char *);
	int (*trigger)(struct cgroup___158 *, unsigned int);
	int (*release)(struct inode___263 *, struct file___263 *);
	int (*register_event)(struct cgroup___158 *, struct cftype___94 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___158 *, struct cftype___94 *, struct eventfd_ctx *);
};

struct cftype_set___90 {
	struct list_head node;
	struct cftype___94 *cfts;
};

struct task_and_cgroup___90 {
	struct task_struct___264 *task;
	struct cgroup___158 *cgrp;
	struct css_set___158 *cg;
};

struct cgroup_taskset___90 {
	struct task_and_cgroup___90 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___158 *cur_cgrp;
};

struct cgroup_subsys___90 {
	struct cgroup_subsys_state___158 * (*css_alloc)(struct cgroup___158 *);
	int (*css_online)(struct cgroup___158 *);
	void (*css_offline)(struct cgroup___158 *);
	void (*css_free)(struct cgroup___158 *);
	int (*can_attach)(struct cgroup___158 *, struct cgroup_taskset___90 *);
	void (*cancel_attach)(struct cgroup___158 *, struct cgroup_taskset___90 *);
	void (*attach)(struct cgroup___158 *, struct cgroup_taskset___90 *);
	void (*fork)(struct task_struct___264 *);
	void (*exit)(struct cgroup___158 *, struct cgroup___158 *, struct task_struct___264 *);
	void (*bind)(struct cgroup___158 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___158 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___94 *base_cftypes;
	struct cftype_set___90 base_cftset;
	struct module___162 *module;
};

struct request_sock_ops___28;

struct request_sock___29 {
	struct sock_common___42 __req_common;
	struct request_sock___29 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___28 *rsk_ops;
	struct sock___44 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___55 {
	struct sk_buff___57 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___57 *, struct netlink_callback___55 *);
	int (*done)(struct netlink_callback___55 *);
	void *data;
	struct module___162 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___53 {
	int (*create)(struct sk_buff___57 *, struct net_device___54 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___57 *, unsigned char *);
	int (*rebuild)(struct sk_buff___57 *);
	int (*cache)(const struct neighbour___43 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___54 *, const unsigned char *);
};

struct napi_struct___53 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___53 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___54 *dev;
	struct sk_buff___57 *gro_list;
	struct sk_buff___57 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___53 {
	struct net_device___54 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___45 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___53 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___45 kobj;
	struct net_device___54 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___53 {
	int (*ndo_init)(struct net_device___54 *);
	void (*ndo_uninit)(struct net_device___54 *);
	int (*ndo_open)(struct net_device___54 *);
	int (*ndo_stop)(struct net_device___54 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___57 *, struct net_device___54 *);
	u16 (*ndo_select_queue)(struct net_device___54 *, struct sk_buff___57 *);
	void (*ndo_change_rx_flags)(struct net_device___54 *, int);
	void (*ndo_set_rx_mode)(struct net_device___54 *);
	int (*ndo_set_mac_address)(struct net_device___54 *, void *);
	int (*ndo_validate_addr)(struct net_device___54 *);
	int (*ndo_do_ioctl)(struct net_device___54 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___54 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___54 *, int);
	int (*ndo_neigh_setup)(struct net_device___54 *, struct neigh_parms___43 *);
	void (*ndo_tx_timeout)(struct net_device___54 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___54 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___54 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___54 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___54 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___54 *);
	int (*ndo_netpoll_setup)(struct net_device___54 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___54 *);
	int (*ndo_busy_poll)(struct napi_struct___53 *);
	int (*ndo_set_vf_mac)(struct net_device___54 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___54 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___54 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___54 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___54 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___54 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___54 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___54 *, int, struct sk_buff___57 *);
	int (*ndo_setup_tc)(struct net_device___54 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___54 *);
	int (*ndo_fcoe_disable)(struct net_device___54 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___54 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___54 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___54 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___54 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___54 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___54 *, const struct sk_buff___57 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___54 *, struct net_device___54 *);
	int (*ndo_del_slave)(struct net_device___54 *, struct net_device___54 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___43 *);
	void (*ndo_neigh_destroy)(struct neighbour___43 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___57 *, struct netlink_callback___55 *, struct net_device___54 *, int);
	int (*ndo_bridge_setlink)(struct net_device___54 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___57 *, u32, u32, struct net_device___54 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___54 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___54 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___54 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___54 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___54 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___54 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___57 *, struct net_device___54 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___54 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___54 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___54 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___43 {
	struct net___68 *net;
	struct net_device___54 *dev;
	struct neigh_parms___43 *next;
	int (*neigh_setup)(struct neighbour___43 *);
	void (*neigh_cleanup)(struct neighbour___43 *);
	struct neigh_table___43 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___5;

struct in_device___5 {
	struct net_device___54 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___5 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___43 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct rtnl_link_ops___44 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___54 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___68 *, struct net_device___54 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___54 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___54 *, struct list_head *);
	size_t (*get_size)(const struct net_device___54 *);
	int (*fill_info)(struct sk_buff___57 *, const struct net_device___54 *);
	size_t (*get_xstats_size)(const struct net_device___54 *);
	int (*fill_xstats)(struct sk_buff___57 *, const struct net_device___54 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___68 * (*get_link_net)(const struct net_device___54 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___54 *, struct net_device___54 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___54 *, const struct net_device___54 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___57 *, const struct net_device___54 *, const struct net_device___54 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___43 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___57 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___43;

struct neigh_hash_table___43;

struct neigh_table___43 {
	struct neigh_table___43 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___54 *, __u32 *);
	int (*constructor)(struct neighbour___43 *);
	int (*pconstructor)(struct pneigh_entry___43 *);
	void (*pdestructor)(struct pneigh_entry___43 *);
	void (*proxy_redo)(struct sk_buff___57 *);
	char *id;
	struct neigh_parms___43 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___54 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___43 *nht;
	struct pneigh_entry___43 **phash_buckets;
};

struct neigh_ops___43 {
	int family;
	void (*solicit)(struct neighbour___43 *, struct sk_buff___57 *);
	void (*error_report)(struct neighbour___43 *, struct sk_buff___57 *);
	int (*output)(struct neighbour___43 *, struct sk_buff___57 *);
	int (*connected_output)(struct neighbour___43 *, struct sk_buff___57 *);
};

struct pneigh_entry___43 {
	struct pneigh_entry___43 *next;
	struct net___68 *net;
	struct net_device___54 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___43 {
	struct neighbour___43 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___25;

struct proto___42 {
	void (*close)(struct sock___44 *, long int);
	int (*connect)(struct sock___44 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___44 *, int);
	struct sock___44 * (*accept)(struct sock___44 *, int, int *);
	int (*ioctl)(struct sock___44 *, int, long unsigned int);
	int (*init)(struct sock___44 *);
	void (*destroy)(struct sock___44 *);
	void (*shutdown)(struct sock___44 *, int);
	int (*setsockopt)(struct sock___44 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___44 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___44 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___44 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___44 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___50 *, struct sock___44 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___50 *, struct sock___44 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___44 *, struct page___262 *, int, size_t, int);
	int (*bind)(struct sock___44 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___44 *, struct sk_buff___57 *);
	void (*release_cb)(struct sock___44 *);
	void (*mtu_reduced)(struct sock___44 *);
	void (*hash)(struct sock___44 *);
	void (*unhash)(struct sock___44 *);
	void (*rehash)(struct sock___44 *);
	int (*get_port)(struct sock___44 *, short unsigned int);
	void (*clear_sk)(struct sock___44 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___44 *);
	void (*enter_memory_pressure)(struct sock___44 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___246 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___28 *rsk_prot;
	struct timewait_sock_ops___25 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___162 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___90 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___42 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___42 {
	void (*enter_memory_pressure)(struct sock___44 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___28 {
	int family;
	int obj_size;
	struct kmem_cache___246 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___44 *, struct request_sock___29 *);
	void (*send_ack)(struct sock___44 *, struct sk_buff___57 *, struct request_sock___29 *);
	void (*send_reset)(struct sock___44 *, struct sk_buff___57 *);
	void (*destructor)(struct request_sock___29 *);
	void (*syn_ack_timeout)(struct sock___44 *, struct request_sock___29 *);
};

struct timewait_sock_ops___25 {
	struct kmem_cache___246 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___44 *, struct sock___44 *, void *);
	void (*twsk_destructor)(struct sock___44 *);
};

struct module_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___160 *, struct module_kobject___160 *, char *);
	ssize_t (*store)(struct module_attribute___160 *, struct module_kobject___160 *, const char *, size_t);
	void (*setup)(struct module___162 *, const char *);
	int (*test)(struct module___162 *);
	void (*free)(struct module___162 *);
};

struct in_ifaddr___5 {
	struct hlist_node hash;
	struct in_ifaddr___5 *ifa_next;
	struct in_device___5 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_ipv6_ops___4;

struct nfq_ct_nat_hook;

struct page___263;

typedef struct page___263 *pgtable_t___263;

struct address_space___264;

struct kmem_cache___247;

struct page___263 {
	long unsigned int flags;
	struct address_space___264 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___263 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___263 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___247 *slab_cache;
		struct page___263 *first_page;
	};
	long: 64;
};

struct task_struct___265;

struct pv_cpu_ops___265 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___265 *);
	void (*end_context_switch)(struct task_struct___265 *);
};

struct mutex___266 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___265 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___258 {
	struct page___263 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___272;

struct nsproxy___144;

struct signal_struct___265;

struct css_set___159;

struct task_struct___265 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___265 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___272 *mm;
	struct mm_struct___272 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___265 *real_parent;
	struct task_struct___265 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___265 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___265 = 0,
		VTIME_USER___265 = 1,
		VTIME_SYS___265 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___144 *nsproxy;
	struct signal_struct___265 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___159 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___266 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___258 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___272 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___272 *, struct mm_struct___272 *);
	void (*dup_mmap)(struct mm_struct___272 *, struct mm_struct___272 *);
	void (*exit_mmap)(struct mm_struct___272 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___272 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___272 *);
	void (*pgd_free)(struct mm_struct___272 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___272 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___272 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___272 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___272 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___272 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___272 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___272 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___272 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___272 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___272 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___272 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___266 lock;
	void *vdso;
} mm_context_t___266;

struct xol_area___263;

struct uprobes_state___263 {
	struct xol_area___263 *xol_area;
};

struct vm_area_struct___272;

struct file___264;

struct core_state___265;

struct mm_struct___272 {
	struct vm_area_struct___272 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___272 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___272 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___266 context;
	long unsigned int flags;
	struct core_state___265 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___265 *owner;
	struct file___264 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___263 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___46;

struct kobj_type___46;

struct kobject___46 {
	const char *name;
	struct list_head entry;
	struct kobject___46 *parent;
	struct kset___46 *kset;
	struct kobj_type___46 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___161 {
	struct kobject___46 kobj;
	struct module___3 *mod;
	struct kobject___46 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___161;

struct module___3 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___161 mkobj;
	struct module_attribute___161 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___46 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___265 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___265;

struct lruvec___265 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___265 *zone;
};

struct pglist_data___265;

struct zone___265 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___265 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___265 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___265 {
	struct zone___265 *zone;
	int zone_idx;
};

struct zonelist___265 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___265 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___265 {
	struct zone___265 node_zones[4];
	struct zonelist___265 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___265 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___188;

struct x86_io_apic_ops___188 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___188 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___188;

struct irq_data___188 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___188 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___262;

struct dev_pm_ops___262 {
	int (*prepare)(struct device___262 *);
	void (*complete)(struct device___262 *);
	int (*suspend)(struct device___262 *);
	int (*resume)(struct device___262 *);
	int (*freeze)(struct device___262 *);
	int (*thaw)(struct device___262 *);
	int (*poweroff)(struct device___262 *);
	int (*restore)(struct device___262 *);
	int (*suspend_late)(struct device___262 *);
	int (*resume_early)(struct device___262 *);
	int (*freeze_late)(struct device___262 *);
	int (*thaw_early)(struct device___262 *);
	int (*poweroff_late)(struct device___262 *);
	int (*restore_early)(struct device___262 *);
	int (*suspend_noirq)(struct device___262 *);
	int (*resume_noirq)(struct device___262 *);
	int (*freeze_noirq)(struct device___262 *);
	int (*thaw_noirq)(struct device___262 *);
	int (*poweroff_noirq)(struct device___262 *);
	int (*restore_noirq)(struct device___262 *);
	int (*runtime_suspend)(struct device___262 *);
	int (*runtime_resume)(struct device___262 *);
	int (*runtime_idle)(struct device___262 *);
};

struct dev_pm_qos___65;

struct dev_pm_info___65 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___65 *qos;
};

struct dma_map_ops___127;

struct dev_archdata___127 {
	struct dma_map_ops___127 *dma_ops;
	void *iommu;
};

struct device_type___262;

struct bus_type___262;

struct device_driver___262;

struct dev_pm_domain___262;

struct class___262;

struct attribute_group___224;

struct device_rh___262;

struct device___262 {
	struct device___262 *parent;
	struct device_private *p;
	struct kobject___46 kobj;
	const char *init_name;
	const struct device_type___262 *type;
	struct mutex___266 mutex;
	struct bus_type___262 *bus;
	struct device_driver___262 *driver;
	void *platform_data;
	struct dev_pm_info___65 power;
	struct dev_pm_domain___262 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___127 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___262 *class;
	const struct attribute_group___224 **groups;
	void (*release)(struct device___262 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___262 *device_rh;
};

struct dev_pm_qos_request___66;

struct dev_pm_qos___65 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___66 *latency_req;
	struct dev_pm_qos_request___66 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___66 *latency_tolerance_req;
};

struct dev_pm_info_rh___262 {
	void (*set_latency_tolerance)(struct device___262 *, s32);
};

struct dev_pm_domain___262 {
	struct dev_pm_ops___262 ops;
};

struct smp_ops___265 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___265 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___69;

struct ctl_node___69 {
	struct rb_node node;
	struct ctl_table_header___69 *header;
};

struct ctl_table_root___69;

struct ctl_table_set___69;

struct ctl_dir___69;

struct ctl_table_header___69 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___69 *root;
	struct ctl_table_set___69 *set;
	struct ctl_dir___69 *parent;
	struct ctl_node___69 *node;
};

struct ctl_dir___69 {
	struct ctl_table_header___69 header;
	struct rb_root root;
};

struct ctl_table_set___69 {
	int (*is_seen)(struct ctl_table_set___69 *);
	struct ctl_dir___69 dir;
};

struct ctl_table_root___69 {
	struct ctl_table_set___69 default_set;
	struct ctl_table_set___69 * (*lookup)(struct ctl_table_root___69 *, struct nsproxy___144 *);
	int (*permissions)(struct ctl_table_header___69 *, struct ctl_table *);
};

struct nsproxy___144 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___2 *net_ns;
};

struct kobj_ns_type_operations___43 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___2 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___43;

struct sock_common___43 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___43 *skc_prot;
	struct net___2 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff_head___55 {
	struct sk_buff___2 *next;
	struct sk_buff___2 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___44;

struct socket_wq___43;

struct dst_entry___44;

struct socket___44;

struct cg_proto___43;

struct sock___2 {
	struct sock_common___43 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___55 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___2 *head;
		struct sk_buff___2 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___44 *sk_filter;
	struct socket_wq___43 *sk_wq;
	struct sk_buff_head___55 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___44 *sk_rx_dst;
	struct dst_entry___44 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___55 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___55 sk_error_queue;
	struct proto___43 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___44 *sk_socket;
	void *sk_user_data;
	struct page_frag___258 sk_frag;
	struct sk_buff___2 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___43 *sk_cgrp;
	void (*sk_state_change)(struct sock___2 *);
	void (*sk_data_ready)(struct sock___2 *, int);
	void (*sk_write_space)(struct sock___2 *);
	void (*sk_error_report)(struct sock___2 *);
	int (*sk_backlog_rcv)(struct sock___2 *, struct sk_buff___2 *);
	void (*sk_destruct)(struct sock___2 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___226;

struct attribute_group___224 {
	const char *name;
	umode_t (*is_visible)(struct kobject___46 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___226 **bin_attrs;
};

struct bin_attribute___226 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___264 *, struct kobject___46 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___264 *, struct kobject___46 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	int (*mmap)(struct file___264 *, struct kobject___46 *, struct bin_attribute___226 *, struct vm_area_struct___272 *);
};

struct dentry___264;

struct path___264 {
	struct vfsmount *mnt;
	struct dentry___264 *dentry;
};

struct inode___264;

struct file_operations___264;

struct file___264 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___264 f_path;
	struct inode___264 *f_inode;
	const struct file_operations___264 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___264 *f_mapping;
	struct mutex___266 f_pos_lock;
};

struct vm_operations_struct___238;

struct vm_area_struct___272 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___272 *vm_next;
	struct vm_area_struct___272 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___272 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___238 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___264 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___46 {
	ssize_t (*show)(struct kobject___46 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___46 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___46 *, const struct attribute *);
};

struct kset_uevent_ops___46;

struct kset___46 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___46 kobj;
	const struct kset_uevent_ops___46 *uevent_ops;
};

struct kobj_type___46 {
	void (*release)(struct kobject___46 *);
	const struct sysfs_ops___46 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___43 * (*child_ns_type)(struct kobject___46 *);
	const void * (*namespace)(struct kobject___46 *);
};

struct kset_uevent_ops___46 {
	int (* const filter)(struct kset___46 *, struct kobject___46 *);
	const char * (* const name)(struct kset___46 *, struct kobject___46 *);
	int (* const uevent)(struct kset___46 *, struct kobject___46 *, struct kobj_uevent_env *);
};

struct module_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___161 *, struct module_kobject___161 *, char *);
	ssize_t (*store)(struct module_attribute___161 *, struct module_kobject___161 *, const char *, size_t);
	void (*setup)(struct module___3 *, const char *);
	int (*test)(struct module___3 *);
	void (*free)(struct module___3 *);
};

struct dentry_operations___264;

struct super_block___264;

struct dentry___264 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___264 *d_parent;
	struct qstr d_name;
	struct inode___264 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___264 *d_op;
	struct super_block___264 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___264;

struct address_space___264 {
	struct inode___264 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___266 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___264 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___264;

struct file_lock___264;

struct dquot___264;

struct block_device___264;

struct inode___264 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___264 *i_op;
	struct super_block___264 *i_sb;
	struct address_space___264 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___266 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___264 *i_fop;
	struct file_lock___264 *i_flock;
	struct address_space___264 i_data;
	struct dquot___264 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___264 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___264 {
	int (*d_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_hash)(const struct dentry___264 *, struct qstr *);
	int (*d_compare)(const struct dentry___264 *, const struct dentry___264 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___264 *);
	void (*d_release)(struct dentry___264 *);
	void (*d_prune)(struct dentry___264 *);
	void (*d_iput)(struct dentry___264 *, struct inode___264 *);
	char * (*d_dname)(struct dentry___264 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___264 *);
	int (*d_manage)(struct dentry___264 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___264;

struct mem_dqinfo___264 {
	struct quota_format_type___264 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___264;

struct quota_info___264 {
	unsigned int flags;
	struct mutex___266 dqio_mutex;
	struct mutex___266 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___264 *files[2];
	struct mem_dqinfo___264 info[2];
	const struct quota_format_ops___264 *ops[2];
};

struct file_system_type___264;

struct super_operations___264;

struct dquot_operations___264;

struct quotactl_ops___264;

struct xattr_handler___160;

struct super_block___264 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___264 *s_type;
	const struct super_operations___264 *s_op;
	const struct dquot_operations___264 *dq_op;
	const struct quotactl_ops___264 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___264 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___160 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___264 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___264 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___266 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___264 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___264 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___264 *bd_inode;
	struct super_block___264 *bd_super;
	struct mutex___266 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___264 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___266 bd_fsfreeze_mutex;
};

struct cgroup___159;

struct cgroup_subsys_state___159 {
	struct cgroup___159 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___51;

typedef int kiocb_cancel_fn___51(struct kiocb___51 *, struct io_event *);

struct kiocb___51 {
	atomic_t ki_users;
	struct file___264 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___51 *ki_cancel;
	void (*ki_dtor)(struct kiocb___51 *);
	union {
		void *user;
		struct task_struct___265 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___264 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___264 *ia_file;
};

struct dquot___264 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___266 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___264 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___264 {
	int qf_fmt_id;
	const struct quota_format_ops___264 *qf_ops;
	struct module___3 *qf_owner;
	struct quota_format_type___264 *qf_next;
};

struct quota_format_ops___264 {
	int (*check_quota_file)(struct super_block___264 *, int);
	int (*read_file_info)(struct super_block___264 *, int);
	int (*write_file_info)(struct super_block___264 *, int);
	int (*free_file_info)(struct super_block___264 *, int);
	int (*read_dqblk)(struct dquot___264 *);
	int (*commit_dqblk)(struct dquot___264 *);
	int (*release_dqblk)(struct dquot___264 *);
};

struct dquot_operations___264 {
	int (*write_dquot)(struct dquot___264 *);
	struct dquot___264 * (*alloc_dquot)(struct super_block___264 *, int);
	void (*destroy_dquot)(struct dquot___264 *);
	int (*acquire_dquot)(struct dquot___264 *);
	int (*release_dquot)(struct dquot___264 *);
	int (*mark_dirty)(struct dquot___264 *);
	int (*write_info)(struct super_block___264 *, int);
	qsize_t * (*get_reserved_space)(struct inode___264 *);
};

struct quotactl_ops___264 {
	int (*quota_on)(struct super_block___264 *, int, int, struct path___264 *);
	int (*quota_on_meta)(struct super_block___264 *, int, int);
	int (*quota_off)(struct super_block___264 *, int);
	int (*quota_sync)(struct super_block___264 *, int);
	int (*get_info)(struct super_block___264 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___264 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___264 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___264 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___264 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___264 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___264 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___264 *, unsigned int);
};

struct address_space_operations___264 {
	int (*writepage)(struct page___263 *, struct writeback_control *);
	int (*readpage)(struct file___264 *, struct page___263 *);
	int (*writepages)(struct address_space___264 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___263 *);
	int (*readpages)(struct file___264 *, struct address_space___264 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___264 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___263 **, void **);
	int (*write_end)(struct file___264 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___263 *, void *);
	sector_t (*bmap)(struct address_space___264 *, sector_t);
	void (*invalidatepage)(struct page___263 *, long unsigned int);
	int (*releasepage)(struct page___263 *, gfp_t);
	void (*freepage)(struct page___263 *);
	ssize_t (*direct_IO)(int, struct kiocb___51 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___264 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___264 *, struct page___263 *, struct page___263 *, enum migrate_mode);
	int (*launder_page)(struct page___263 *);
	int (*is_partially_uptodate)(struct page___263 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___263 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___264 *, struct page___263 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___264 *, sector_t *);
	void (*swap_deactivate)(struct file___264 *);
	void (*invalidatepage_range)(struct page___263 *, unsigned int, unsigned int);
};

struct inode_operations___264 {
	struct dentry___264 * (*lookup)(struct inode___264 *, struct dentry___264 *, unsigned int);
	void * (*follow_link)(struct dentry___264 *, struct nameidata *);
	int (*permission)(struct inode___264 *, int);
	struct posix_acl * (*get_acl)(struct inode___264 *, int);
	int (*readlink)(struct dentry___264 *, char *, int);
	void (*put_link)(struct dentry___264 *, struct nameidata *, void *);
	int (*create)(struct inode___264 *, struct dentry___264 *, umode_t, bool);
	int (*link)(struct dentry___264 *, struct inode___264 *, struct dentry___264 *);
	int (*unlink)(struct inode___264 *, struct dentry___264 *);
	int (*symlink)(struct inode___264 *, struct dentry___264 *, const char *);
	int (*mkdir)(struct inode___264 *, struct dentry___264 *, umode_t);
	int (*rmdir)(struct inode___264 *, struct dentry___264 *);
	int (*mknod)(struct inode___264 *, struct dentry___264 *, umode_t, dev_t);
	int (*rename)(struct inode___264 *, struct dentry___264 *, struct inode___264 *, struct dentry___264 *);
	int (*setattr)(struct dentry___264 *, struct iattr___264 *);
	int (*getattr)(struct vfsmount *, struct dentry___264 *, struct kstat *);
	int (*setxattr)(struct dentry___264 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___264 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___264 *, char *, size_t);
	int (*removexattr)(struct dentry___264 *, const char *);
	int (*fiemap)(struct inode___264 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___264 *, struct timespec *, int);
	int (*atomic_open)(struct inode___264 *, struct dentry___264 *, struct file___264 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___150;

struct seq_file___189;

struct file_operations___264 {
	struct module___3 *owner;
	loff_t (*llseek)(struct file___264 *, loff_t, int);
	ssize_t (*read)(struct file___264 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___264 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___51 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___51 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___264 *, void *, filldir_t);
	unsigned int (*poll)(struct file___264 *, struct poll_table_struct___150 *);
	long int (*unlocked_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___264 *, struct vm_area_struct___272 *);
	int (*open)(struct inode___264 *, struct file___264 *);
	int (*flush)(struct file___264 *, fl_owner_t);
	int (*release)(struct inode___264 *, struct file___264 *);
	int (*fsync)(struct file___264 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___51 *, int);
	int (*fasync)(int, struct file___264 *, int);
	int (*lock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*sendpage)(struct file___264 *, struct page___263 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___264 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___264 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___264 *, long int, struct file_lock___264 **, void **);
		struct {
			int (*setlease)(struct file___264 *, long int, struct file_lock___264 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___264 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___189 *, struct file___264 *);
};

struct fasync_struct___264;

struct file_lock_operations___264;

struct lock_manager_operations___264;

struct file_lock___264 {
	struct file_lock___264 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___264 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___264 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___264 *fl_ops;
	const struct lock_manager_operations___264 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___264 {
	void (*fl_copy_lock)(struct file_lock___264 *, struct file_lock___264 *);
	void (*fl_release_private)(struct file_lock___264 *);
};

struct lock_manager_operations___264 {
	int (*lm_compare_owner)(struct file_lock___264 *, struct file_lock___264 *);
	long unsigned int (*lm_owner_key)(struct file_lock___264 *);
	void (*lm_notify)(struct file_lock___264 *);
	int (*lm_grant)(struct file_lock___264 *, struct file_lock___264 *, int);
	void (*lm_break)(struct file_lock___264 *);
	int (*lm_change)(struct file_lock___264 **, int);
};

struct fasync_struct___264 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___264 *fa_next;
	struct file___264 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___264 {
	const char *name;
	int fs_flags;
	struct dentry___264 * (*mount)(struct file_system_type___264 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___264 *);
	struct module___3 *owner;
	struct file_system_type___264 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___264 {
	struct inode___264 * (*alloc_inode)(struct super_block___264 *);
	void (*destroy_inode)(struct inode___264 *);
	void (*dirty_inode)(struct inode___264 *, int);
	int (*write_inode)(struct inode___264 *, struct writeback_control *);
	int (*drop_inode)(struct inode___264 *);
	void (*evict_inode)(struct inode___264 *);
	void (*put_super)(struct super_block___264 *);
	int (*sync_fs)(struct super_block___264 *, int);
	int (*freeze_fs)(struct super_block___264 *);
	int (*unfreeze_fs)(struct super_block___264 *);
	int (*statfs)(struct dentry___264 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___264 *, int *, char *);
	void (*umount_begin)(struct super_block___264 *);
	int (*show_options)(struct seq_file___189 *, struct dentry___264 *);
	int (*show_devname)(struct seq_file___189 *, struct dentry___264 *);
	int (*show_path)(struct seq_file___189 *, struct dentry___264 *);
	int (*show_stats)(struct seq_file___189 *, struct dentry___264 *);
	ssize_t (*quota_read)(struct super_block___264 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___264 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___264 *);
	int (*bdev_try_to_free_page)(struct super_block___264 *, struct page___263 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___264 *);
	void (*free_cached_objects)(struct super_block___264 *, int);
};

struct xattr_handler___160 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___264 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___264 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___264 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___152)(struct file___264 *, wait_queue_head_t *, struct poll_table_struct___150 *);

struct poll_table_struct___150 {
	poll_queue_proc___152 _qproc;
	long unsigned int _key;
};

struct seq_operations___189;

struct seq_file___189 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___266 lock;
	const struct seq_operations___189 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___263 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___263 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___246;

struct memcg_cache_params___247;

struct kmem_cache___247 {
	struct kmem_cache_cpu___246 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___46 kobj;
	struct memcg_cache_params___247 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___234;

struct vm_operations_struct___238 {
	void (*open)(struct vm_area_struct___272 *);
	void (*close)(struct vm_area_struct___272 *);
	int (*fault)(struct vm_area_struct___272 *, struct vm_fault___234 *);
	int (*page_mkwrite)(struct vm_area_struct___272 *, struct vm_fault___234 *);
	int (*access)(struct vm_area_struct___272 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___272 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___272 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___272 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___272 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___265 {
	struct task_struct___265 *task;
	struct core_thread___265 *next;
};

struct core_state___265 {
	atomic_t nr_threads;
	struct core_thread___265 dumper;
	struct completion startup;
};

struct socket_wq___43 {
	wait_queue_head_t wait;
	struct fasync_struct___264 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___43;

struct socket___44 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___43 *wq;
	struct file___264 *file;
	struct sock___2 *sk;
	const struct proto_ops___43 *ops;
};

struct proto_ops___43 {
	int family;
	struct module___3 *owner;
	int (*release)(struct socket___44 *);
	int (*bind)(struct socket___44 *, struct sockaddr *, int);
	int (*connect)(struct socket___44 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___44 *, struct socket___44 *);
	int (*accept)(struct socket___44 *, struct socket___44 *, int);
	int (*getname)(struct socket___44 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___264 *, struct socket___44 *, struct poll_table_struct___150 *);
	int (*ioctl)(struct socket___44 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___44 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___44 *, int);
	int (*shutdown)(struct socket___44 *, int);
	int (*setsockopt)(struct socket___44 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___44 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___44 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___44 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___51 *, struct socket___44 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___51 *, struct socket___44 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___264 *, struct socket___44 *, struct vm_area_struct___272 *);
	ssize_t (*sendpage)(struct socket___44 *, struct page___263 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___44 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___2 *, int);
		struct {
			void (*set_peek_off)(struct sock___2 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct netns_core___66 {
	struct ctl_table_header___69 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___67 {
	struct mutex___266 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___66 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___69 *ctl;
};

struct netns_ipv4___66 {
	struct ctl_table_header___69 *forw_hdr;
	struct ctl_table_header___69 *frags_hdr;
	struct ctl_table_header___69 *ipv4_hdr;
	struct ctl_table_header___69 *route_hdr;
	struct ctl_table_header___69 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___2 *fibnl;
	struct sock___2 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___66 {
	struct ctl_table_header___69 *hdr;
	struct ctl_table_header___69 *route_hdr;
	struct ctl_table_header___69 *icmp_hdr;
	struct ctl_table_header___69 *frags_hdr;
	struct ctl_table_header___69 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___44;

struct dst_ops___68 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___68 *);
	struct dst_entry___44 * (*check)(struct dst_entry___44 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___44 *);
	unsigned int (*mtu)(const struct dst_entry___44 *);
	u32 * (*cow_metrics)(struct dst_entry___44 *, long unsigned int);
	void (*destroy)(struct dst_entry___44 *);
	void (*ifdown)(struct dst_entry___44 *, struct net_device___2 *, int);
	struct dst_entry___44 * (*negative_advice)(struct dst_entry___44 *);
	void (*link_failure)(struct sk_buff___2 *);
	void (*update_pmtu)(struct dst_entry___44 *, struct sock___2 *, struct sk_buff___2 *, u32);
	void (*redirect)(struct dst_entry___44 *, struct sock___2 *, struct sk_buff___2 *);
	int (*local_out)(struct sk_buff___2 *);
	struct neighbour___44 * (*neigh_lookup)(const struct dst_entry___44 *, struct sk_buff___2 *, const void *);
	struct kmem_cache___247 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___68 {
	struct netns_sysctl_ipv6___66 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___68 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___2 **icmp_sk;
	struct sock___2 *ndisc_sk;
	struct sock___2 *tcp_sk;
	struct sock___2 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___66 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___69 *sysctl_header;
	struct sock___2 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___43 {
	struct sock___2 *v4_ctl_sk;
	struct sock___2 *v6_ctl_sk;
};

struct netns_nf___66 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___69 *nf_log_dir_header;
};

struct nf_proto_net___66 {
	struct ctl_table_header___69 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___66 {
	struct nf_proto_net___66 pn;
	unsigned int timeout;
};

struct nf_tcp_net___66 {
	struct nf_proto_net___66 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___66 {
	struct nf_proto_net___66 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___66 {
	struct nf_proto_net___66 pn;
	unsigned int timeout;
};

struct nf_ip_net___66 {
	struct nf_generic_net___66 generic;
	struct nf_tcp_net___66 tcp;
	struct nf_udp_net___66 udp;
	struct nf_icmp_net___66 icmp;
	struct nf_icmp_net___66 icmpv6;
};

struct netns_ct___67 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___69 *sysctl_header;
	struct ctl_table_header___69 *acct_sysctl_header;
	struct ctl_table_header___69 *tstamp_sysctl_header;
	struct ctl_table_header___69 *event_sysctl_header;
	struct ctl_table_header___69 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___247 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___66 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___66 {
	struct netns_sysctl_ipv6___66 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___68 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___2 *nlsk;
	struct sock___2 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___69 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___68 xfrm4_dst_ops;
	struct dst_ops___68 xfrm6_dst_ops;
};

struct net___2 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___69 sysctls;
	struct sock___2 *rtnl;
	struct sock___2 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___2 *loopback_dev;
	struct netns_core___66 core;
	struct netns_mib mib;
	struct netns_packet___67 packet;
	struct netns_unix___66 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___66 ipv4;
	struct netns_ipv6___68 ipv6;
	struct netns_sctp___66 sctp;
	struct netns_dccp___43 dccp;
	struct netns_nf___66 nf;
	struct netns_xt xt;
	struct netns_ct___67 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___66 nf_frag;
	struct sock___2 *nfnl;
	struct sock___2 *nfnl_stash;
	struct sk_buff_head___55 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___68 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___2 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___2 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___266 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___266 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___246 {
	void **freelist;
	long unsigned int tid;
	struct page___263 *page;
	struct page___263 *partial;
};

struct memcg_cache_params___247 {
	bool is_root_cache;
	union {
		struct kmem_cache___247 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___247 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___127 {
	void * (*alloc)(struct device___262 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___262 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___262 *, struct vm_area_struct___272 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___262 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___262 *, struct page___263 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___262 *, dma_addr_t);
	int (*dma_supported)(struct device___262 *, u64);
	int (*set_dma_mask)(struct device___262 *, u64);
	int is_phys;
};

struct bus_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___262 *, char *);
	ssize_t (*store)(struct bus_type___262 *, const char *, size_t);
};

struct device_attribute___262;

struct driver_attribute___262;

struct bus_type___262 {
	const char *name;
	const char *dev_name;
	struct device___262 *dev_root;
	struct bus_attribute___262 *bus_attrs;
	struct device_attribute___262 *dev_attrs;
	struct driver_attribute___262 *drv_attrs;
	const struct attribute_group___224 **bus_groups;
	const struct attribute_group___224 **dev_groups;
	const struct attribute_group___224 **drv_groups;
	int (*match)(struct device___262 *, struct device_driver___262 *);
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	int (*probe)(struct device___262 *);
	int (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*online)(struct device___262 *);
	int (*offline)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct device___262 *, struct device_attribute___262 *, char *);
	ssize_t (*store)(struct device___262 *, struct device_attribute___262 *, const char *, size_t);
};

struct driver_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___262 *, char *);
	ssize_t (*store)(struct device_driver___262 *, const char *, size_t);
};

struct device_driver___262 {
	const char *name;
	struct bus_type___262 *bus;
	struct module___3 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___262 *);
	int (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	const struct attribute_group___224 **groups;
	const struct dev_pm_ops___262 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___262 {
	const char *name;
	const struct attribute_group___224 **groups;
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
};

struct class_attribute___262;

struct class___262 {
	const char *name;
	struct module___3 *owner;
	struct class_attribute___262 *class_attrs;
	struct device_attribute___262 *dev_attrs;
	const struct attribute_group___224 **dev_groups;
	struct bin_attribute___226 *dev_bin_attrs;
	struct kobject___46 *dev_kobj;
	int (*dev_uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *);
	void (*class_release)(struct class___262 *);
	void (*dev_release)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	const struct kobj_ns_type_operations___43 *ns_type;
	const void * (*namespace)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
	struct subsys_private *p;
};

struct class_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct class___262 *, struct class_attribute___262 *, char *);
	ssize_t (*store)(struct class___262 *, struct class_attribute___262 *, const char *, size_t);
	const void * (*namespace)(struct class___262 *, const struct class_attribute___262 *);
};

struct device_rh___262 {
	struct dev_pm_info_rh___262 power;
};

struct vm_fault___234 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___263 *page;
};

struct signal_struct___265 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___265 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___265 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___266 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___159 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___159 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___54 {
	atomic_t use;
	unsigned int mask;
	struct net_device___2 *physindev;
	struct net_device___2 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___54(struct sk_buff___2 **);

struct net_device_ops___54;

struct ethtool_ops___54;

struct header_ops___54;

struct netdev_rx_queue___54;

struct netdev_queue___54;

struct rtnl_link_ops___45;

struct dcbnl_rtnl_ops___54;

struct net_device___2 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___54 *netdev_ops;
	const struct ethtool_ops___54 *ethtool_ops;
	const struct header_ops___54 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___46 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___54 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___54 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___54 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___54 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___54 = 0,
		NETREG_REGISTERED___54 = 1,
		NETREG_UNREGISTERING___54 = 2,
		NETREG_UNREGISTERED___54 = 3,
		NETREG_RELEASED___54 = 4,
		NETREG_DUMMY___54 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___54 = 0,
		RTNL_LINK_INITIALIZING___54 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___2 *);
	struct netpoll_info *npinfo;
	struct net___2 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___262 dev;
	const struct attribute_group___224 *sysfs_groups[4];
	const struct rtnl_link_ops___45 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___54 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___2 {
	struct sk_buff___2 *next;
	struct sk_buff___2 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___2 *sk;
	struct net_device___2 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___2 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___54 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct nf_afinfo___68 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___2 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___2 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___2 *, struct dst_entry___44 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___2 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___2 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct dst_entry___44 {
	struct callback_head callback_head;
	struct dst_entry___44 *child;
	struct net_device___2 *dev;
	struct dst_ops___68 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___44 *path;
	struct dst_entry___44 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___2 *);
	union {
		int (*output)(struct sock___2 *, struct sk_buff___2 *);
		struct {
			int (*output)(struct sk_buff___2 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___44 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct seq_operations___189 {
	void * (*start)(struct seq_file___189 *, loff_t *);
	void (*stop)(struct seq_file___189 *, void *);
	void * (*next)(struct seq_file___189 *, void *, loff_t *);
	int (*show)(struct seq_file___189 *, void *);
};

struct dev_pm_qos_request___66 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___262 *dev;
};

struct ethtool_ops___54 {
	int (*get_settings)(struct net_device___2 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___2 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___2 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___2 *);
	void (*get_regs)(struct net_device___2 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___2 *);
	void (*set_msglevel)(struct net_device___2 *, u32);
	int (*nway_reset)(struct net_device___2 *);
	u32 (*get_link)(struct net_device___2 *);
	int (*get_eeprom_len)(struct net_device___2 *);
	int (*get_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___2 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___2 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___2 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___2 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___2 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___2 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___2 *);
	void (*complete)(struct net_device___2 *);
	u32 (*get_priv_flags)(struct net_device___2 *);
	int (*set_priv_flags)(struct net_device___2 *, u32);
	int (*get_sset_count)(struct net_device___2 *, int);
	int (*get_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___2 *, struct ethtool_flash *);
	int (*reset)(struct net_device___2 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___2 *);
	int (*get_rxfh_indir)(struct net_device___2 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___2 *, const u32 *);
	void (*get_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___2 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___2 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___2 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___2 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___2 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___2 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___2 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___2 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_table___44;

struct neigh_parms___44;

struct neigh_ops___44;

struct neighbour___44 {
	struct neighbour___44 *next;
	struct neigh_table___44 *tbl;
	struct neigh_parms___44 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___55 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___44 *, struct sk_buff___2 *);
	const struct neigh_ops___44 *ops;
	struct callback_head rcu;
	struct net_device___2 *dev;
	u8 primary_key[0];
};

struct irq_chip___188 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___188 *);
	void (*irq_shutdown)(struct irq_data___188 *);
	void (*irq_enable)(struct irq_data___188 *);
	void (*irq_disable)(struct irq_data___188 *);
	void (*irq_ack)(struct irq_data___188 *);
	void (*irq_mask)(struct irq_data___188 *);
	void (*irq_mask_ack)(struct irq_data___188 *);
	void (*irq_unmask)(struct irq_data___188 *);
	void (*irq_eoi)(struct irq_data___188 *);
	int (*irq_set_affinity)(struct irq_data___188 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___188 *);
	int (*irq_set_type)(struct irq_data___188 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___188 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___188 *);
	void (*irq_bus_sync_unlock)(struct irq_data___188 *);
	void (*irq_cpu_online)(struct irq_data___188 *);
	void (*irq_cpu_offline)(struct irq_data___188 *);
	void (*irq_suspend)(struct irq_data___188 *);
	void (*irq_resume)(struct irq_data___188 *);
	void (*irq_pm_shutdown)(struct irq_data___188 *);
	void (*irq_print_chip)(struct irq_data___188 *, struct seq_file___189 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___188 *, void *);
	long unsigned int flags;
};

struct seq_net_private___5 {
	struct net___2 *net;
};

struct pernet_operations___13 {
	struct list_head list;
	int (*init)(struct net___2 *);
	void (*exit)(struct net___2 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___54 {
	int (*ieee_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___2 *);
	u8 (*setstate)(struct net_device___2 *, u8);
	void (*getpermhwaddr)(struct net_device___2 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___2 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___2 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___2 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___2 *, int, u8 *);
	void (*setpfccfg)(struct net_device___2 *, int, u8);
	void (*getpfccfg)(struct net_device___2 *, int, u8 *);
	u8 (*setall)(struct net_device___2 *);
	u8 (*getcap)(struct net_device___2 *, int, u8 *);
	int (*getnumtcs)(struct net_device___2 *, int, u8 *);
	int (*setnumtcs)(struct net_device___2 *, int, u8);
	u8 (*getpfcstate)(struct net_device___2 *);
	void (*setpfcstate)(struct net_device___2 *, u8);
	void (*getbcncfg)(struct net_device___2 *, int, u32 *);
	void (*setbcncfg)(struct net_device___2 *, int, u32);
	void (*getbcnrp)(struct net_device___2 *, int, u8 *);
	void (*setbcnrp)(struct net_device___2 *, int, u8);
	u8 (*setapp)(struct net_device___2 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___2 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___2 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___2 *, int, u8);
	u8 (*getdcbx)(struct net_device___2 *);
	u8 (*setdcbx)(struct net_device___2 *, u8);
	int (*peer_getappinfo)(struct net_device___2 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___2 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___2 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___2 *, struct cee_pfc *);
};

struct cgroupfs_root___159;

struct cgroup___159 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___159 *parent;
	struct dentry___264 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___159 *subsys[11];
	struct cgroupfs_root___159 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___266 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___159 {
	struct super_block___264 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___159 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___95 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___264 *, struct file___264 *);
	ssize_t (*read)(struct cgroup___159 *, struct cftype___95 *, struct file___264 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___159 *, struct cftype___95 *);
	s64 (*read_s64)(struct cgroup___159 *, struct cftype___95 *);
	int (*read_map)(struct cgroup___159 *, struct cftype___95 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___159 *, struct cftype___95 *, struct seq_file___189 *);
	ssize_t (*write)(struct cgroup___159 *, struct cftype___95 *, struct file___264 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___159 *, struct cftype___95 *, u64);
	int (*write_s64)(struct cgroup___159 *, struct cftype___95 *, s64);
	int (*write_string)(struct cgroup___159 *, struct cftype___95 *, const char *);
	int (*trigger)(struct cgroup___159 *, unsigned int);
	int (*release)(struct inode___264 *, struct file___264 *);
	int (*register_event)(struct cgroup___159 *, struct cftype___95 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___159 *, struct cftype___95 *, struct eventfd_ctx *);
};

struct cftype_set___91 {
	struct list_head node;
	struct cftype___95 *cfts;
};

struct task_and_cgroup___91 {
	struct task_struct___265 *task;
	struct cgroup___159 *cgrp;
	struct css_set___159 *cg;
};

struct cgroup_taskset___91 {
	struct task_and_cgroup___91 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___159 *cur_cgrp;
};

struct cgroup_subsys___91 {
	struct cgroup_subsys_state___159 * (*css_alloc)(struct cgroup___159 *);
	int (*css_online)(struct cgroup___159 *);
	void (*css_offline)(struct cgroup___159 *);
	void (*css_free)(struct cgroup___159 *);
	int (*can_attach)(struct cgroup___159 *, struct cgroup_taskset___91 *);
	void (*cancel_attach)(struct cgroup___159 *, struct cgroup_taskset___91 *);
	void (*attach)(struct cgroup___159 *, struct cgroup_taskset___91 *);
	void (*fork)(struct task_struct___265 *);
	void (*exit)(struct cgroup___159 *, struct cgroup___159 *, struct task_struct___265 *);
	void (*bind)(struct cgroup___159 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___159 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___95 *base_cftypes;
	struct cftype_set___91 base_cftset;
	struct module___3 *module;
};

struct request_sock_ops___29;

struct request_sock___30 {
	struct sock_common___43 __req_common;
	struct request_sock___30 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___29 *rsk_ops;
	struct sock___2 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___56 {
	struct sk_buff___2 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___2 *, struct netlink_callback___56 *);
	int (*done)(struct netlink_callback___56 *);
	void *data;
	struct module___3 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___54 {
	int (*create)(struct sk_buff___2 *, struct net_device___2 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___2 *, unsigned char *);
	int (*rebuild)(struct sk_buff___2 *);
	int (*cache)(const struct neighbour___44 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___2 *, const unsigned char *);
};

struct napi_struct___54 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___54 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___2 *dev;
	struct sk_buff___2 *gro_list;
	struct sk_buff___2 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___54 {
	struct net_device___2 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___46 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___54 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___46 kobj;
	struct net_device___2 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___54 {
	int (*ndo_init)(struct net_device___2 *);
	void (*ndo_uninit)(struct net_device___2 *);
	int (*ndo_open)(struct net_device___2 *);
	int (*ndo_stop)(struct net_device___2 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___2 *, struct net_device___2 *);
	u16 (*ndo_select_queue)(struct net_device___2 *, struct sk_buff___2 *);
	void (*ndo_change_rx_flags)(struct net_device___2 *, int);
	void (*ndo_set_rx_mode)(struct net_device___2 *);
	int (*ndo_set_mac_address)(struct net_device___2 *, void *);
	int (*ndo_validate_addr)(struct net_device___2 *);
	int (*ndo_do_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___2 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___2 *, int);
	int (*ndo_neigh_setup)(struct net_device___2 *, struct neigh_parms___44 *);
	void (*ndo_tx_timeout)(struct net_device___2 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___2 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___2 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___2 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___2 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___2 *);
	int (*ndo_netpoll_setup)(struct net_device___2 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___2 *);
	int (*ndo_busy_poll)(struct napi_struct___54 *);
	int (*ndo_set_vf_mac)(struct net_device___2 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___2 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___2 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___2 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___2 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___2 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___2 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___2 *, int, struct sk_buff___2 *);
	int (*ndo_setup_tc)(struct net_device___2 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___2 *);
	int (*ndo_fcoe_disable)(struct net_device___2 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___2 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___2 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___2 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___2 *, const struct sk_buff___2 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___2 *, struct net_device___2 *);
	int (*ndo_del_slave)(struct net_device___2 *, struct net_device___2 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___44 *);
	void (*ndo_neigh_destroy)(struct neighbour___44 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___2 *, struct netlink_callback___56 *, struct net_device___2 *, int);
	int (*ndo_bridge_setlink)(struct net_device___2 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___2 *, u32, u32, struct net_device___2 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___2 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___2 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___2 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___2 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___2 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___2 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___2 *, struct net_device___2 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___2 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___2 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___2 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___44 {
	struct net___2 *net;
	struct net_device___2 *dev;
	struct neigh_parms___44 *next;
	int (*neigh_setup)(struct neighbour___44 *);
	void (*neigh_cleanup)(struct neighbour___44 *);
	struct neigh_table___44 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___45 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___2 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___2 *, struct net_device___2 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___2 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___2 *, struct list_head *);
	size_t (*get_size)(const struct net_device___2 *);
	int (*fill_info)(struct sk_buff___2 *, const struct net_device___2 *);
	size_t (*get_xstats_size)(const struct net_device___2 *);
	int (*fill_xstats)(struct sk_buff___2 *, const struct net_device___2 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___2 * (*get_link_net)(const struct net_device___2 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___2 *, struct net_device___2 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___2 *, const struct net_device___2 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___44 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___2 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___44;

struct neigh_hash_table___44;

struct neigh_table___44 {
	struct neigh_table___44 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___2 *, __u32 *);
	int (*constructor)(struct neighbour___44 *);
	int (*pconstructor)(struct pneigh_entry___44 *);
	void (*pdestructor)(struct pneigh_entry___44 *);
	void (*proxy_redo)(struct sk_buff___2 *);
	char *id;
	struct neigh_parms___44 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___55 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___44 *nht;
	struct pneigh_entry___44 **phash_buckets;
};

struct neigh_ops___44 {
	int family;
	void (*solicit)(struct neighbour___44 *, struct sk_buff___2 *);
	void (*error_report)(struct neighbour___44 *, struct sk_buff___2 *);
	int (*output)(struct neighbour___44 *, struct sk_buff___2 *);
	int (*connected_output)(struct neighbour___44 *, struct sk_buff___2 *);
};

struct pneigh_entry___44 {
	struct pneigh_entry___44 *next;
	struct net___2 *net;
	struct net_device___2 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___44 {
	struct neighbour___44 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___26;

struct proto___43 {
	void (*close)(struct sock___2 *, long int);
	int (*connect)(struct sock___2 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___2 *, int);
	struct sock___2 * (*accept)(struct sock___2 *, int, int *);
	int (*ioctl)(struct sock___2 *, int, long unsigned int);
	int (*init)(struct sock___2 *);
	void (*destroy)(struct sock___2 *);
	void (*shutdown)(struct sock___2 *, int);
	int (*setsockopt)(struct sock___2 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___2 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___2 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___2 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___2 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___51 *, struct sock___2 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___51 *, struct sock___2 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___2 *, struct page___263 *, int, size_t, int);
	int (*bind)(struct sock___2 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___2 *, struct sk_buff___2 *);
	void (*release_cb)(struct sock___2 *);
	void (*mtu_reduced)(struct sock___2 *);
	void (*hash)(struct sock___2 *);
	void (*unhash)(struct sock___2 *);
	void (*rehash)(struct sock___2 *);
	int (*get_port)(struct sock___2 *, short unsigned int);
	void (*clear_sk)(struct sock___2 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___2 *);
	void (*enter_memory_pressure)(struct sock___2 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___247 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___29 *rsk_prot;
	struct timewait_sock_ops___26 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___3 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___91 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___43 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___43 {
	void (*enter_memory_pressure)(struct sock___2 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___29 {
	int family;
	int obj_size;
	struct kmem_cache___247 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___2 *, struct request_sock___30 *);
	void (*send_ack)(struct sock___2 *, struct sk_buff___2 *, struct request_sock___30 *);
	void (*send_reset)(struct sock___2 *, struct sk_buff___2 *);
	void (*destructor)(struct request_sock___30 *);
	void (*syn_ack_timeout)(struct sock___2 *, struct request_sock___30 *);
};

struct timewait_sock_ops___26 {
	struct kmem_cache___247 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___2 *, struct sock___2 *, void *);
	void (*twsk_destructor)(struct sock___2 *);
};

struct nf_loginfo {
	u_int8_t type;
	union {
		struct {
			u_int32_t copy_len;
			u_int16_t group;
			u_int16_t qthreshold;
		} ulog;
		struct {
			u_int8_t level;
			u_int8_t logflags;
		} log;
	} u;
};

struct nf_log_buf {
	unsigned int count;
	char buf[1020];
};

typedef unsigned int nf_hookfn___3(const struct nf_hook_ops *, struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *, const struct nf_hook_state *);

struct nf_hook_ops {
	struct list_head list;
	nf_hookfn___3 *hook;
	struct module___3 *owner;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
	long unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct nf_queue_handler {
	int (*outfn)(struct nf_queue_entry *, unsigned int);
};

struct nf_sockopt_ops {
	struct list_head list;
	u_int8_t pf;
	int set_optmin;
	int set_optmax;
	int (*set)(struct sock___42 *, int, void *, unsigned int);
	int (*compat_set)(struct sock___42 *, int, void *, unsigned int);
	int get_optmin;
	int get_optmax;
	int (*get)(struct sock___42 *, int, void *, int *);
	int (*compat_get)(struct sock___42 *, int, void *, int *);
	struct module___159 *owner;
};

struct page___264;

typedef struct page___264 *pgtable_t___264;

struct address_space___265;

struct kmem_cache___248;

struct page___264 {
	long unsigned int flags;
	struct address_space___265 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___264 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___264 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___248 *slab_cache;
		struct page___264 *first_page;
	};
	long: 64;
};

struct task_struct___266;

struct pv_cpu_ops___266 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___266 *);
	void (*end_context_switch)(struct task_struct___266 *);
};

struct mutex___267 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___266 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___259 {
	struct page___264 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___273;

struct nsproxy___145;

struct signal_struct___266;

struct css_set___160;

struct task_struct___266 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___266 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___273 *mm;
	struct mm_struct___273 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___266 *real_parent;
	struct task_struct___266 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___266 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___266 = 0,
		VTIME_USER___266 = 1,
		VTIME_SYS___266 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___145 *nsproxy;
	struct signal_struct___266 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___160 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___267 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___259 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___273 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___273 *, struct mm_struct___273 *);
	void (*dup_mmap)(struct mm_struct___273 *, struct mm_struct___273 *);
	void (*exit_mmap)(struct mm_struct___273 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___273 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___273 *);
	void (*pgd_free)(struct mm_struct___273 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___273 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___273 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___273 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___273 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___273 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___273 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___273 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___273 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___273 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___273 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___273 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___267 lock;
	void *vdso;
} mm_context_t___267;

struct xol_area___264;

struct uprobes_state___264 {
	struct xol_area___264 *xol_area;
};

struct vm_area_struct___273;

struct file___265;

struct core_state___266;

struct mm_struct___273 {
	struct vm_area_struct___273 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___273 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___273 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___267 context;
	long unsigned int flags;
	struct core_state___266 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___266 *owner;
	struct file___265 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___264 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___47;

struct kobj_type___47;

struct kobject___47 {
	const char *name;
	struct list_head entry;
	struct kobject___47 *parent;
	struct kset___47 *kset;
	struct kobj_type___47 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___163;

struct module_kobject___162 {
	struct kobject___47 kobj;
	struct module___163 *mod;
	struct kobject___47 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___162;

struct module___163 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___162 mkobj;
	struct module_attribute___162 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___47 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___266 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___266;

struct lruvec___266 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___266 *zone;
};

struct pglist_data___266;

struct zone___266 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___266 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___266 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___266 {
	struct zone___266 *zone;
	int zone_idx;
};

struct zonelist___266 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___266 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___266 {
	struct zone___266 node_zones[4];
	struct zonelist___266 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___266 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___189;

struct x86_io_apic_ops___189 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___189 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___189;

struct irq_data___189 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___189 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___263;

struct dev_pm_ops___263 {
	int (*prepare)(struct device___263 *);
	void (*complete)(struct device___263 *);
	int (*suspend)(struct device___263 *);
	int (*resume)(struct device___263 *);
	int (*freeze)(struct device___263 *);
	int (*thaw)(struct device___263 *);
	int (*poweroff)(struct device___263 *);
	int (*restore)(struct device___263 *);
	int (*suspend_late)(struct device___263 *);
	int (*resume_early)(struct device___263 *);
	int (*freeze_late)(struct device___263 *);
	int (*thaw_early)(struct device___263 *);
	int (*poweroff_late)(struct device___263 *);
	int (*restore_early)(struct device___263 *);
	int (*suspend_noirq)(struct device___263 *);
	int (*resume_noirq)(struct device___263 *);
	int (*freeze_noirq)(struct device___263 *);
	int (*thaw_noirq)(struct device___263 *);
	int (*poweroff_noirq)(struct device___263 *);
	int (*restore_noirq)(struct device___263 *);
	int (*runtime_suspend)(struct device___263 *);
	int (*runtime_resume)(struct device___263 *);
	int (*runtime_idle)(struct device___263 *);
};

struct dev_pm_qos___66;

struct dev_pm_info___66 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___66 *qos;
};

struct dma_map_ops___128;

struct dev_archdata___128 {
	struct dma_map_ops___128 *dma_ops;
	void *iommu;
};

struct device_type___263;

struct bus_type___263;

struct device_driver___263;

struct dev_pm_domain___263;

struct class___263;

struct attribute_group___225;

struct device_rh___263;

struct device___263 {
	struct device___263 *parent;
	struct device_private *p;
	struct kobject___47 kobj;
	const char *init_name;
	const struct device_type___263 *type;
	struct mutex___267 mutex;
	struct bus_type___263 *bus;
	struct device_driver___263 *driver;
	void *platform_data;
	struct dev_pm_info___66 power;
	struct dev_pm_domain___263 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___128 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___263 *class;
	const struct attribute_group___225 **groups;
	void (*release)(struct device___263 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___263 *device_rh;
};

struct dev_pm_qos_request___67;

struct dev_pm_qos___66 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___67 *latency_req;
	struct dev_pm_qos_request___67 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___67 *latency_tolerance_req;
};

struct dev_pm_info_rh___263 {
	void (*set_latency_tolerance)(struct device___263 *, s32);
};

struct dev_pm_domain___263 {
	struct dev_pm_ops___263 ops;
};

struct smp_ops___266 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___266 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___70;

struct ctl_node___70 {
	struct rb_node node;
	struct ctl_table_header___70 *header;
};

struct ctl_table_root___70;

struct ctl_table_set___70;

struct ctl_dir___70;

struct ctl_table_header___70 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___70 *root;
	struct ctl_table_set___70 *set;
	struct ctl_dir___70 *parent;
	struct ctl_node___70 *node;
};

struct ctl_dir___70 {
	struct ctl_table_header___70 header;
	struct rb_root root;
};

struct ctl_table_set___70 {
	int (*is_seen)(struct ctl_table_set___70 *);
	struct ctl_dir___70 dir;
};

struct ctl_table_root___70 {
	struct ctl_table_set___70 default_set;
	struct ctl_table_set___70 * (*lookup)(struct ctl_table_root___70 *, struct nsproxy___145 *);
	int (*permissions)(struct ctl_table_header___70 *, struct ctl_table *);
};

struct net___69;

struct nsproxy___145 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___69 *net_ns;
};

struct sock___45;

struct kobj_ns_type_operations___44 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___45 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___44;

struct sock_common___44 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___44 *skc_prot;
	struct net___69 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___58;

struct sk_buff_head___56 {
	struct sk_buff___58 *next;
	struct sk_buff___58 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___45;

struct socket_wq___44;

struct dst_entry___45;

struct socket___45;

struct cg_proto___44;

struct sock___45 {
	struct sock_common___44 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___56 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___58 *head;
		struct sk_buff___58 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___45 *sk_filter;
	struct socket_wq___44 *sk_wq;
	struct sk_buff_head___56 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___45 *sk_rx_dst;
	struct dst_entry___45 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___56 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___56 sk_error_queue;
	struct proto___44 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___45 *sk_socket;
	void *sk_user_data;
	struct page_frag___259 sk_frag;
	struct sk_buff___58 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___44 *sk_cgrp;
	void (*sk_state_change)(struct sock___45 *);
	void (*sk_data_ready)(struct sock___45 *, int);
	void (*sk_write_space)(struct sock___45 *);
	void (*sk_error_report)(struct sock___45 *);
	int (*sk_backlog_rcv)(struct sock___45 *, struct sk_buff___58 *);
	void (*sk_destruct)(struct sock___45 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___227;

struct attribute_group___225 {
	const char *name;
	umode_t (*is_visible)(struct kobject___47 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___227 **bin_attrs;
};

struct bin_attribute___227 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___265 *, struct kobject___47 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___265 *, struct kobject___47 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	int (*mmap)(struct file___265 *, struct kobject___47 *, struct bin_attribute___227 *, struct vm_area_struct___273 *);
};

struct dentry___265;

struct path___265 {
	struct vfsmount *mnt;
	struct dentry___265 *dentry;
};

struct inode___265;

struct file_operations___265;

struct file___265 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___265 f_path;
	struct inode___265 *f_inode;
	const struct file_operations___265 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___265 *f_mapping;
	struct mutex___267 f_pos_lock;
};

struct vm_operations_struct___239;

struct vm_area_struct___273 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___273 *vm_next;
	struct vm_area_struct___273 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___273 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___239 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___265 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___47 {
	ssize_t (*show)(struct kobject___47 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___47 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___47 *, const struct attribute *);
};

struct kset_uevent_ops___47;

struct kset___47 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___47 kobj;
	const struct kset_uevent_ops___47 *uevent_ops;
};

struct kobj_type___47 {
	void (*release)(struct kobject___47 *);
	const struct sysfs_ops___47 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___44 * (*child_ns_type)(struct kobject___47 *);
	const void * (*namespace)(struct kobject___47 *);
};

struct kset_uevent_ops___47 {
	int (* const filter)(struct kset___47 *, struct kobject___47 *);
	const char * (* const name)(struct kset___47 *, struct kobject___47 *);
	int (* const uevent)(struct kset___47 *, struct kobject___47 *, struct kobj_uevent_env *);
};

struct module_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___162 *, struct module_kobject___162 *, char *);
	ssize_t (*store)(struct module_attribute___162 *, struct module_kobject___162 *, const char *, size_t);
	void (*setup)(struct module___163 *, const char *);
	int (*test)(struct module___163 *);
	void (*free)(struct module___163 *);
};

struct xol_area___264 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___264 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___247;

struct memcg_cache_params___248;

struct kmem_cache___248 {
	struct kmem_cache_cpu___247 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___47 kobj;
	struct memcg_cache_params___248 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___265;

struct address_space___265 {
	struct inode___265 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___267 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___265 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___235;

struct vm_operations_struct___239 {
	void (*open)(struct vm_area_struct___273 *);
	void (*close)(struct vm_area_struct___273 *);
	int (*fault)(struct vm_area_struct___273 *, struct vm_fault___235 *);
	int (*page_mkwrite)(struct vm_area_struct___273 *, struct vm_fault___235 *);
	int (*access)(struct vm_area_struct___273 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___273 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___273 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___273 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___273 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___266 {
	struct task_struct___266 *task;
	struct core_thread___266 *next;
};

struct core_state___266 {
	atomic_t nr_threads;
	struct core_thread___266 dumper;
	struct completion startup;
};

struct fasync_struct___265;

struct socket_wq___44 {
	wait_queue_head_t wait;
	struct fasync_struct___265 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___265 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___265 *fa_next;
	struct file___265 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___44;

struct socket___45 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___44 *wq;
	struct file___265 *file;
	struct sock___45 *sk;
	const struct proto_ops___44 *ops;
};

struct poll_table_struct___151;

struct kiocb___52;

struct proto_ops___44 {
	int family;
	struct module___163 *owner;
	int (*release)(struct socket___45 *);
	int (*bind)(struct socket___45 *, struct sockaddr *, int);
	int (*connect)(struct socket___45 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___45 *, struct socket___45 *);
	int (*accept)(struct socket___45 *, struct socket___45 *, int);
	int (*getname)(struct socket___45 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___265 *, struct socket___45 *, struct poll_table_struct___151 *);
	int (*ioctl)(struct socket___45 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___45 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___45 *, int);
	int (*shutdown)(struct socket___45 *, int);
	int (*setsockopt)(struct socket___45 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___45 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___45 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___45 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___52 *, struct socket___45 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___52 *, struct socket___45 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___265 *, struct socket___45 *, struct vm_area_struct___273 *);
	ssize_t (*sendpage)(struct socket___45 *, struct page___264 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___45 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___45 *, int);
		struct {
			void (*set_peek_off)(struct sock___45 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___153)(struct file___265 *, wait_queue_head_t *, struct poll_table_struct___151 *);

struct poll_table_struct___151 {
	poll_queue_proc___153 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___52(struct kiocb___52 *, struct io_event *);

struct kiocb___52 {
	atomic_t ki_users;
	struct file___265 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___52 *ki_cancel;
	void (*ki_dtor)(struct kiocb___52 *);
	union {
		void *user;
		struct task_struct___266 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___67 {
	struct ctl_table_header___70 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___68 {
	struct mutex___267 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___67 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___70 *ctl;
};

struct xt_table___2;

struct netns_ipv4___67 {
	struct ctl_table_header___70 *forw_hdr;
	struct ctl_table_header___70 *frags_hdr;
	struct ctl_table_header___70 *ipv4_hdr;
	struct ctl_table_header___70 *route_hdr;
	struct ctl_table_header___70 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___45 *fibnl;
	struct sock___45 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table___2 *iptable_filter;
	struct xt_table___2 *iptable_mangle;
	struct xt_table___2 *iptable_raw;
	struct xt_table___2 *arptable_filter;
	struct xt_table___2 *iptable_security;
	struct xt_table___2 *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___67 {
	struct ctl_table_header___70 *hdr;
	struct ctl_table_header___70 *route_hdr;
	struct ctl_table_header___70 *icmp_hdr;
	struct ctl_table_header___70 *frags_hdr;
	struct ctl_table_header___70 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___55;

struct neighbour___45;

struct dst_ops___69 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___69 *);
	struct dst_entry___45 * (*check)(struct dst_entry___45 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___45 *);
	unsigned int (*mtu)(const struct dst_entry___45 *);
	u32 * (*cow_metrics)(struct dst_entry___45 *, long unsigned int);
	void (*destroy)(struct dst_entry___45 *);
	void (*ifdown)(struct dst_entry___45 *, struct net_device___55 *, int);
	struct dst_entry___45 * (*negative_advice)(struct dst_entry___45 *);
	void (*link_failure)(struct sk_buff___58 *);
	void (*update_pmtu)(struct dst_entry___45 *, struct sock___45 *, struct sk_buff___58 *, u32);
	void (*redirect)(struct dst_entry___45 *, struct sock___45 *, struct sk_buff___58 *);
	int (*local_out)(struct sk_buff___58 *);
	struct neighbour___45 * (*neigh_lookup)(const struct dst_entry___45 *, struct sk_buff___58 *, const void *);
	struct kmem_cache___248 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___69 {
	struct netns_sysctl_ipv6___67 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table___2 *ip6table_filter;
	struct xt_table___2 *ip6table_mangle;
	struct xt_table___2 *ip6table_raw;
	struct xt_table___2 *ip6table_security;
	struct xt_table___2 *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___69 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___45 **icmp_sk;
	struct sock___45 *ndisc_sk;
	struct sock___45 *tcp_sk;
	struct sock___45 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___67 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___70 *sysctl_header;
	struct sock___45 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___44 {
	struct sock___45 *v4_ctl_sk;
	struct sock___45 *v6_ctl_sk;
};

struct netns_nf___67 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___70 *nf_log_dir_header;
};

struct nf_proto_net___67 {
	struct ctl_table_header___70 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___67 {
	struct nf_proto_net___67 pn;
	unsigned int timeout;
};

struct nf_tcp_net___67 {
	struct nf_proto_net___67 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___67 {
	struct nf_proto_net___67 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___67 {
	struct nf_proto_net___67 pn;
	unsigned int timeout;
};

struct nf_ip_net___67 {
	struct nf_generic_net___67 generic;
	struct nf_tcp_net___67 tcp;
	struct nf_udp_net___67 udp;
	struct nf_icmp_net___67 icmp;
	struct nf_icmp_net___67 icmpv6;
};

struct netns_ct___68 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___70 *sysctl_header;
	struct ctl_table_header___70 *acct_sysctl_header;
	struct ctl_table_header___70 *tstamp_sysctl_header;
	struct ctl_table_header___70 *event_sysctl_header;
	struct ctl_table_header___70 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___248 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___67 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___67 {
	struct netns_sysctl_ipv6___67 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___69 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___45 *nlsk;
	struct sock___45 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___70 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___69 xfrm4_dst_ops;
	struct dst_ops___69 xfrm6_dst_ops;
};

struct net___69 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___70 sysctls;
	struct sock___45 *rtnl;
	struct sock___45 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___55 *loopback_dev;
	struct netns_core___67 core;
	struct netns_mib mib;
	struct netns_packet___68 packet;
	struct netns_unix___67 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___67 ipv4;
	struct netns_ipv6___69 ipv6;
	struct netns_sctp___67 sctp;
	struct netns_dccp___44 dccp;
	struct netns_nf___67 nf;
	struct netns_xt xt;
	struct netns_ct___68 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___67 nf_frag;
	struct sock___45 *nfnl;
	struct sock___45 *nfnl_stash;
	struct sk_buff_head___56 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___69 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___45 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___45 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___267 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___267 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___265;

struct super_block___265;

struct dentry___265 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___265 *d_parent;
	struct qstr d_name;
	struct inode___265 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___265 *d_op;
	struct super_block___265 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___265;

struct file_lock___265;

struct dquot___265;

struct block_device___265;

struct inode___265 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___265 *i_op;
	struct super_block___265 *i_sb;
	struct address_space___265 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___267 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___265 *i_fop;
	struct file_lock___265 *i_flock;
	struct address_space___265 i_data;
	struct dquot___265 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___265 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___265 {
	int (*d_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_hash)(const struct dentry___265 *, struct qstr *);
	int (*d_compare)(const struct dentry___265 *, const struct dentry___265 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___265 *);
	void (*d_release)(struct dentry___265 *);
	void (*d_prune)(struct dentry___265 *);
	void (*d_iput)(struct dentry___265 *, struct inode___265 *);
	char * (*d_dname)(struct dentry___265 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___265 *);
	int (*d_manage)(struct dentry___265 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___265;

struct mem_dqinfo___265 {
	struct quota_format_type___265 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___265;

struct quota_info___265 {
	unsigned int flags;
	struct mutex___267 dqio_mutex;
	struct mutex___267 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___265 *files[2];
	struct mem_dqinfo___265 info[2];
	const struct quota_format_ops___265 *ops[2];
};

struct file_system_type___265;

struct super_operations___265;

struct dquot_operations___265;

struct quotactl_ops___265;

struct xattr_handler___161;

struct super_block___265 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___265 *s_type;
	const struct super_operations___265 *s_op;
	const struct dquot_operations___265 *dq_op;
	const struct quotactl_ops___265 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___265 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___161 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___265 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___265 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___267 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___265 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___265 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___265 *bd_inode;
	struct super_block___265 *bd_super;
	struct mutex___267 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___265 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___267 bd_fsfreeze_mutex;
};

struct cgroup___160;

struct cgroup_subsys_state___160 {
	struct cgroup___160 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___265 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___265 *ia_file;
};

struct dquot___265 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___267 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___265 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___265 {
	int qf_fmt_id;
	const struct quota_format_ops___265 *qf_ops;
	struct module___163 *qf_owner;
	struct quota_format_type___265 *qf_next;
};

struct quota_format_ops___265 {
	int (*check_quota_file)(struct super_block___265 *, int);
	int (*read_file_info)(struct super_block___265 *, int);
	int (*write_file_info)(struct super_block___265 *, int);
	int (*free_file_info)(struct super_block___265 *, int);
	int (*read_dqblk)(struct dquot___265 *);
	int (*commit_dqblk)(struct dquot___265 *);
	int (*release_dqblk)(struct dquot___265 *);
};

struct dquot_operations___265 {
	int (*write_dquot)(struct dquot___265 *);
	struct dquot___265 * (*alloc_dquot)(struct super_block___265 *, int);
	void (*destroy_dquot)(struct dquot___265 *);
	int (*acquire_dquot)(struct dquot___265 *);
	int (*release_dquot)(struct dquot___265 *);
	int (*mark_dirty)(struct dquot___265 *);
	int (*write_info)(struct super_block___265 *, int);
	qsize_t * (*get_reserved_space)(struct inode___265 *);
};

struct quotactl_ops___265 {
	int (*quota_on)(struct super_block___265 *, int, int, struct path___265 *);
	int (*quota_on_meta)(struct super_block___265 *, int, int);
	int (*quota_off)(struct super_block___265 *, int);
	int (*quota_sync)(struct super_block___265 *, int);
	int (*get_info)(struct super_block___265 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___265 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___265 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___265 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___265 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___265 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___265 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___265 *, unsigned int);
};

struct address_space_operations___265 {
	int (*writepage)(struct page___264 *, struct writeback_control *);
	int (*readpage)(struct file___265 *, struct page___264 *);
	int (*writepages)(struct address_space___265 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___264 *);
	int (*readpages)(struct file___265 *, struct address_space___265 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___265 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___264 **, void **);
	int (*write_end)(struct file___265 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___264 *, void *);
	sector_t (*bmap)(struct address_space___265 *, sector_t);
	void (*invalidatepage)(struct page___264 *, long unsigned int);
	int (*releasepage)(struct page___264 *, gfp_t);
	void (*freepage)(struct page___264 *);
	ssize_t (*direct_IO)(int, struct kiocb___52 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___265 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___265 *, struct page___264 *, struct page___264 *, enum migrate_mode);
	int (*launder_page)(struct page___264 *);
	int (*is_partially_uptodate)(struct page___264 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___264 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___265 *, struct page___264 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___265 *, sector_t *);
	void (*swap_deactivate)(struct file___265 *);
	void (*invalidatepage_range)(struct page___264 *, unsigned int, unsigned int);
};

struct inode_operations___265 {
	struct dentry___265 * (*lookup)(struct inode___265 *, struct dentry___265 *, unsigned int);
	void * (*follow_link)(struct dentry___265 *, struct nameidata *);
	int (*permission)(struct inode___265 *, int);
	struct posix_acl * (*get_acl)(struct inode___265 *, int);
	int (*readlink)(struct dentry___265 *, char *, int);
	void (*put_link)(struct dentry___265 *, struct nameidata *, void *);
	int (*create)(struct inode___265 *, struct dentry___265 *, umode_t, bool);
	int (*link)(struct dentry___265 *, struct inode___265 *, struct dentry___265 *);
	int (*unlink)(struct inode___265 *, struct dentry___265 *);
	int (*symlink)(struct inode___265 *, struct dentry___265 *, const char *);
	int (*mkdir)(struct inode___265 *, struct dentry___265 *, umode_t);
	int (*rmdir)(struct inode___265 *, struct dentry___265 *);
	int (*mknod)(struct inode___265 *, struct dentry___265 *, umode_t, dev_t);
	int (*rename)(struct inode___265 *, struct dentry___265 *, struct inode___265 *, struct dentry___265 *);
	int (*setattr)(struct dentry___265 *, struct iattr___265 *);
	int (*getattr)(struct vfsmount *, struct dentry___265 *, struct kstat *);
	int (*setxattr)(struct dentry___265 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___265 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___265 *, char *, size_t);
	int (*removexattr)(struct dentry___265 *, const char *);
	int (*fiemap)(struct inode___265 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___265 *, struct timespec *, int);
	int (*atomic_open)(struct inode___265 *, struct dentry___265 *, struct file___265 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___190;

struct file_operations___265 {
	struct module___163 *owner;
	loff_t (*llseek)(struct file___265 *, loff_t, int);
	ssize_t (*read)(struct file___265 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___265 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___52 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___52 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___265 *, void *, filldir_t);
	unsigned int (*poll)(struct file___265 *, struct poll_table_struct___151 *);
	long int (*unlocked_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___265 *, struct vm_area_struct___273 *);
	int (*open)(struct inode___265 *, struct file___265 *);
	int (*flush)(struct file___265 *, fl_owner_t);
	int (*release)(struct inode___265 *, struct file___265 *);
	int (*fsync)(struct file___265 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___52 *, int);
	int (*fasync)(int, struct file___265 *, int);
	int (*lock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*sendpage)(struct file___265 *, struct page___264 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___265 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___265 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___265 *, long int, struct file_lock___265 **, void **);
		struct {
			int (*setlease)(struct file___265 *, long int, struct file_lock___265 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___265 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___190 *, struct file___265 *);
};

struct file_lock_operations___265;

struct lock_manager_operations___265;

struct file_lock___265 {
	struct file_lock___265 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___265 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___265 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___265 *fl_ops;
	const struct lock_manager_operations___265 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___265 {
	void (*fl_copy_lock)(struct file_lock___265 *, struct file_lock___265 *);
	void (*fl_release_private)(struct file_lock___265 *);
};

struct lock_manager_operations___265 {
	int (*lm_compare_owner)(struct file_lock___265 *, struct file_lock___265 *);
	long unsigned int (*lm_owner_key)(struct file_lock___265 *);
	void (*lm_notify)(struct file_lock___265 *);
	int (*lm_grant)(struct file_lock___265 *, struct file_lock___265 *, int);
	void (*lm_break)(struct file_lock___265 *);
	int (*lm_change)(struct file_lock___265 **, int);
};

struct file_system_type___265 {
	const char *name;
	int fs_flags;
	struct dentry___265 * (*mount)(struct file_system_type___265 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___265 *);
	struct module___163 *owner;
	struct file_system_type___265 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___265 {
	struct inode___265 * (*alloc_inode)(struct super_block___265 *);
	void (*destroy_inode)(struct inode___265 *);
	void (*dirty_inode)(struct inode___265 *, int);
	int (*write_inode)(struct inode___265 *, struct writeback_control *);
	int (*drop_inode)(struct inode___265 *);
	void (*evict_inode)(struct inode___265 *);
	void (*put_super)(struct super_block___265 *);
	int (*sync_fs)(struct super_block___265 *, int);
	int (*freeze_fs)(struct super_block___265 *);
	int (*unfreeze_fs)(struct super_block___265 *);
	int (*statfs)(struct dentry___265 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___265 *, int *, char *);
	void (*umount_begin)(struct super_block___265 *);
	int (*show_options)(struct seq_file___190 *, struct dentry___265 *);
	int (*show_devname)(struct seq_file___190 *, struct dentry___265 *);
	int (*show_path)(struct seq_file___190 *, struct dentry___265 *);
	int (*show_stats)(struct seq_file___190 *, struct dentry___265 *);
	ssize_t (*quota_read)(struct super_block___265 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___265 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___265 *);
	int (*bdev_try_to_free_page)(struct super_block___265 *, struct page___264 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___265 *);
	void (*free_cached_objects)(struct super_block___265 *, int);
};

struct xattr_handler___161 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___265 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___265 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___265 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___190;

struct seq_file___190 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___267 lock;
	const struct seq_operations___190 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___190 {
	void * (*start)(struct seq_file___190 *, loff_t *);
	void (*stop)(struct seq_file___190 *, void *);
	void * (*next)(struct seq_file___190 *, void *, loff_t *);
	int (*show)(struct seq_file___190 *, void *);
};

struct vm_fault___235 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___264 *page;
};

struct kmem_cache_cpu___247 {
	void **freelist;
	long unsigned int tid;
	struct page___264 *page;
	struct page___264 *partial;
};

struct memcg_cache_params___248 {
	bool is_root_cache;
	union {
		struct kmem_cache___248 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___248 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct signal_struct___266 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___266 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___266 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___267 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___160 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___160 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___55;

struct sk_buff___58 {
	struct sk_buff___58 *next;
	struct sk_buff___58 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___45 *sk;
	struct net_device___55 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___58 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___55 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xt_table___2 {
	struct list_head list;
	unsigned int valid_hooks;
	struct xt_table_info *private;
	struct module___163 *me;
	u_int8_t af;
	int priority;
	char name[32];
};

struct dst_entry___45 {
	struct callback_head callback_head;
	struct dst_entry___45 *child;
	struct net_device___55 *dev;
	struct dst_ops___69 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___45 *path;
	struct dst_entry___45 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___58 *);
	union {
		int (*output)(struct sock___45 *, struct sk_buff___58 *);
		struct {
			int (*output)(struct sk_buff___58 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___45 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

typedef rx_handler_result_t rx_handler_func_t___55(struct sk_buff___58 **);

struct net_device_ops___55;

struct ethtool_ops___55;

struct header_ops___55;

struct netdev_rx_queue___55;

struct netdev_queue___55;

struct rtnl_link_ops___46;

struct dcbnl_rtnl_ops___55;

struct net_device___55 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___55 *netdev_ops;
	const struct ethtool_ops___55 *ethtool_ops;
	const struct header_ops___55 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___47 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___55 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___55 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___55 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___55 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___55 = 0,
		NETREG_REGISTERED___55 = 1,
		NETREG_UNREGISTERING___55 = 2,
		NETREG_UNREGISTERED___55 = 3,
		NETREG_RELEASED___55 = 4,
		NETREG_DUMMY___55 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___55 = 0,
		RTNL_LINK_INITIALIZING___55 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___55 *);
	struct netpoll_info *npinfo;
	struct net___69 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___263 dev;
	const struct attribute_group___225 *sysfs_groups[4];
	const struct rtnl_link_ops___46 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___55 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___45;

struct neigh_parms___45;

struct neigh_ops___45;

struct neighbour___45 {
	struct neighbour___45 *next;
	struct neigh_table___45 *tbl;
	struct neigh_parms___45 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___56 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___45 *, struct sk_buff___58 *);
	const struct neigh_ops___45 *ops;
	struct callback_head rcu;
	struct net_device___55 *dev;
	u8 primary_key[0];
};

struct dma_map_ops___128 {
	void * (*alloc)(struct device___263 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___263 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___263 *, struct vm_area_struct___273 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___263 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___263 *, struct page___264 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___263 *, dma_addr_t);
	int (*dma_supported)(struct device___263 *, u64);
	int (*set_dma_mask)(struct device___263 *, u64);
	int is_phys;
};

struct bus_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___263 *, char *);
	ssize_t (*store)(struct bus_type___263 *, const char *, size_t);
};

struct device_attribute___263;

struct driver_attribute___263;

struct bus_type___263 {
	const char *name;
	const char *dev_name;
	struct device___263 *dev_root;
	struct bus_attribute___263 *bus_attrs;
	struct device_attribute___263 *dev_attrs;
	struct driver_attribute___263 *drv_attrs;
	const struct attribute_group___225 **bus_groups;
	const struct attribute_group___225 **dev_groups;
	const struct attribute_group___225 **drv_groups;
	int (*match)(struct device___263 *, struct device_driver___263 *);
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	int (*probe)(struct device___263 *);
	int (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*online)(struct device___263 *);
	int (*offline)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct device___263 *, struct device_attribute___263 *, char *);
	ssize_t (*store)(struct device___263 *, struct device_attribute___263 *, const char *, size_t);
};

struct driver_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___263 *, char *);
	ssize_t (*store)(struct device_driver___263 *, const char *, size_t);
};

struct device_driver___263 {
	const char *name;
	struct bus_type___263 *bus;
	struct module___163 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___263 *);
	int (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	const struct attribute_group___225 **groups;
	const struct dev_pm_ops___263 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___263 {
	const char *name;
	const struct attribute_group___225 **groups;
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
};

struct class_attribute___263;

struct class___263 {
	const char *name;
	struct module___163 *owner;
	struct class_attribute___263 *class_attrs;
	struct device_attribute___263 *dev_attrs;
	const struct attribute_group___225 **dev_groups;
	struct bin_attribute___227 *dev_bin_attrs;
	struct kobject___47 *dev_kobj;
	int (*dev_uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *);
	void (*class_release)(struct class___263 *);
	void (*dev_release)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	const struct kobj_ns_type_operations___44 *ns_type;
	const void * (*namespace)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
	struct subsys_private *p;
};

struct class_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct class___263 *, struct class_attribute___263 *, char *);
	ssize_t (*store)(struct class___263 *, struct class_attribute___263 *, const char *, size_t);
	const void * (*namespace)(struct class___263 *, const struct class_attribute___263 *);
};

struct device_rh___263 {
	struct dev_pm_info_rh___263 power;
};

struct nf_bridge_info___55 {
	atomic_t use;
	unsigned int mask;
	struct net_device___55 *physindev;
	struct net_device___55 *physoutdev;
	long unsigned int data[4];
};

struct nf_hook_state___5 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___55 *in;
	struct net_device___55 *out;
	struct sock___45 *sk;
	int (*okfn)(struct sock___45 *, struct sk_buff___58 *);
};

struct nf_hook_ops___4;

typedef unsigned int nf_hookfn___4(const struct nf_hook_ops___4 *, struct sk_buff___58 *, const struct net_device___55 *, const struct net_device___55 *, const struct nf_hook_state___5 *);

struct nf_hook_ops___4 {
	struct list_head list;
	nf_hookfn___4 *hook;
	struct module___163 *owner;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
	long unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct nf_afinfo___69 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___58 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___58 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___69 *, struct dst_entry___45 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___58 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___58 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___189 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___189 *);
	void (*irq_shutdown)(struct irq_data___189 *);
	void (*irq_enable)(struct irq_data___189 *);
	void (*irq_disable)(struct irq_data___189 *);
	void (*irq_ack)(struct irq_data___189 *);
	void (*irq_mask)(struct irq_data___189 *);
	void (*irq_mask_ack)(struct irq_data___189 *);
	void (*irq_unmask)(struct irq_data___189 *);
	void (*irq_eoi)(struct irq_data___189 *);
	int (*irq_set_affinity)(struct irq_data___189 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___189 *);
	int (*irq_set_type)(struct irq_data___189 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___189 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___189 *);
	void (*irq_bus_sync_unlock)(struct irq_data___189 *);
	void (*irq_cpu_online)(struct irq_data___189 *);
	void (*irq_cpu_offline)(struct irq_data___189 *);
	void (*irq_suspend)(struct irq_data___189 *);
	void (*irq_resume)(struct irq_data___189 *);
	void (*irq_pm_shutdown)(struct irq_data___189 *);
	void (*irq_print_chip)(struct irq_data___189 *, struct seq_file___190 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___189 *, void *);
	long unsigned int flags;
};

struct seq_net_private___6 {
	struct net___69 *net;
};

struct pernet_operations___14 {
	struct list_head list;
	int (*init)(struct net___69 *);
	void (*exit)(struct net___69 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dev_pm_qos_request___67 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___263 *dev;
};

struct ethtool_ops___55 {
	int (*get_settings)(struct net_device___55 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___55 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___55 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___55 *);
	void (*get_regs)(struct net_device___55 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___55 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___55 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___55 *);
	void (*set_msglevel)(struct net_device___55 *, u32);
	int (*nway_reset)(struct net_device___55 *);
	u32 (*get_link)(struct net_device___55 *);
	int (*get_eeprom_len)(struct net_device___55 *);
	int (*get_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___55 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___55 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___55 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___55 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___55 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___55 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___55 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___55 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___55 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___55 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___55 *);
	void (*complete)(struct net_device___55 *);
	u32 (*get_priv_flags)(struct net_device___55 *);
	int (*set_priv_flags)(struct net_device___55 *, u32);
	int (*get_sset_count)(struct net_device___55 *, int);
	int (*get_rxnfc)(struct net_device___55 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___55 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___55 *, struct ethtool_flash *);
	int (*reset)(struct net_device___55 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___55 *);
	int (*get_rxfh_indir)(struct net_device___55 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___55 *, const u32 *);
	void (*get_channels)(struct net_device___55 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___55 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___55 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___55 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___55 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___55 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___55 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___55 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___55 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___55 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___55 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___55 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dcbnl_rtnl_ops___55 {
	int (*ieee_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___55 *);
	u8 (*setstate)(struct net_device___55 *, u8);
	void (*getpermhwaddr)(struct net_device___55 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___55 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___55 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___55 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___55 *, int, u8 *);
	void (*setpfccfg)(struct net_device___55 *, int, u8);
	void (*getpfccfg)(struct net_device___55 *, int, u8 *);
	u8 (*setall)(struct net_device___55 *);
	u8 (*getcap)(struct net_device___55 *, int, u8 *);
	int (*getnumtcs)(struct net_device___55 *, int, u8 *);
	int (*setnumtcs)(struct net_device___55 *, int, u8);
	u8 (*getpfcstate)(struct net_device___55 *);
	void (*setpfcstate)(struct net_device___55 *, u8);
	void (*getbcncfg)(struct net_device___55 *, int, u32 *);
	void (*setbcncfg)(struct net_device___55 *, int, u32);
	void (*getbcnrp)(struct net_device___55 *, int, u8 *);
	void (*setbcnrp)(struct net_device___55 *, int, u8);
	u8 (*setapp)(struct net_device___55 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___55 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___55 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___55 *, int, u8);
	u8 (*getdcbx)(struct net_device___55 *);
	u8 (*setdcbx)(struct net_device___55 *, u8);
	int (*peer_getappinfo)(struct net_device___55 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___55 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___55 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___55 *, struct cee_pfc *);
};

struct cgroupfs_root___160;

struct cgroup___160 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___160 *parent;
	struct dentry___265 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___160 *subsys[11];
	struct cgroupfs_root___160 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___267 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___160 {
	struct super_block___265 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___160 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___96 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___265 *, struct file___265 *);
	ssize_t (*read)(struct cgroup___160 *, struct cftype___96 *, struct file___265 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___160 *, struct cftype___96 *);
	s64 (*read_s64)(struct cgroup___160 *, struct cftype___96 *);
	int (*read_map)(struct cgroup___160 *, struct cftype___96 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___160 *, struct cftype___96 *, struct seq_file___190 *);
	ssize_t (*write)(struct cgroup___160 *, struct cftype___96 *, struct file___265 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___160 *, struct cftype___96 *, u64);
	int (*write_s64)(struct cgroup___160 *, struct cftype___96 *, s64);
	int (*write_string)(struct cgroup___160 *, struct cftype___96 *, const char *);
	int (*trigger)(struct cgroup___160 *, unsigned int);
	int (*release)(struct inode___265 *, struct file___265 *);
	int (*register_event)(struct cgroup___160 *, struct cftype___96 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___160 *, struct cftype___96 *, struct eventfd_ctx *);
};

struct cftype_set___92 {
	struct list_head node;
	struct cftype___96 *cfts;
};

struct task_and_cgroup___92 {
	struct task_struct___266 *task;
	struct cgroup___160 *cgrp;
	struct css_set___160 *cg;
};

struct cgroup_taskset___92 {
	struct task_and_cgroup___92 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___160 *cur_cgrp;
};

struct cgroup_subsys___92 {
	struct cgroup_subsys_state___160 * (*css_alloc)(struct cgroup___160 *);
	int (*css_online)(struct cgroup___160 *);
	void (*css_offline)(struct cgroup___160 *);
	void (*css_free)(struct cgroup___160 *);
	int (*can_attach)(struct cgroup___160 *, struct cgroup_taskset___92 *);
	void (*cancel_attach)(struct cgroup___160 *, struct cgroup_taskset___92 *);
	void (*attach)(struct cgroup___160 *, struct cgroup_taskset___92 *);
	void (*fork)(struct task_struct___266 *);
	void (*exit)(struct cgroup___160 *, struct cgroup___160 *, struct task_struct___266 *);
	void (*bind)(struct cgroup___160 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___160 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___96 *base_cftypes;
	struct cftype_set___92 base_cftset;
	struct module___163 *module;
};

struct request_sock_ops___30;

struct request_sock___31 {
	struct sock_common___44 __req_common;
	struct request_sock___31 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___30 *rsk_ops;
	struct sock___45 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___57 {
	struct sk_buff___58 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___58 *, struct netlink_callback___57 *);
	int (*done)(struct netlink_callback___57 *);
	void *data;
	struct module___163 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___55 {
	int (*create)(struct sk_buff___58 *, struct net_device___55 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___58 *, unsigned char *);
	int (*rebuild)(struct sk_buff___58 *);
	int (*cache)(const struct neighbour___45 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___55 *, const unsigned char *);
};

struct napi_struct___55 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___55 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___55 *dev;
	struct sk_buff___58 *gro_list;
	struct sk_buff___58 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___55 {
	struct net_device___55 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___47 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___55 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___47 kobj;
	struct net_device___55 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___55 {
	int (*ndo_init)(struct net_device___55 *);
	void (*ndo_uninit)(struct net_device___55 *);
	int (*ndo_open)(struct net_device___55 *);
	int (*ndo_stop)(struct net_device___55 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___58 *, struct net_device___55 *);
	u16 (*ndo_select_queue)(struct net_device___55 *, struct sk_buff___58 *);
	void (*ndo_change_rx_flags)(struct net_device___55 *, int);
	void (*ndo_set_rx_mode)(struct net_device___55 *);
	int (*ndo_set_mac_address)(struct net_device___55 *, void *);
	int (*ndo_validate_addr)(struct net_device___55 *);
	int (*ndo_do_ioctl)(struct net_device___55 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___55 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___55 *, int);
	int (*ndo_neigh_setup)(struct net_device___55 *, struct neigh_parms___45 *);
	void (*ndo_tx_timeout)(struct net_device___55 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___55 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___55 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___55 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___55 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___55 *);
	int (*ndo_netpoll_setup)(struct net_device___55 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___55 *);
	int (*ndo_busy_poll)(struct napi_struct___55 *);
	int (*ndo_set_vf_mac)(struct net_device___55 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___55 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___55 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___55 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___55 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___55 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___55 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___55 *, int, struct sk_buff___58 *);
	int (*ndo_setup_tc)(struct net_device___55 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___55 *);
	int (*ndo_fcoe_disable)(struct net_device___55 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___55 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___55 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___55 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___55 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___55 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___55 *, const struct sk_buff___58 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___55 *, struct net_device___55 *);
	int (*ndo_del_slave)(struct net_device___55 *, struct net_device___55 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___45 *);
	void (*ndo_neigh_destroy)(struct neighbour___45 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___58 *, struct netlink_callback___57 *, struct net_device___55 *, int);
	int (*ndo_bridge_setlink)(struct net_device___55 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___58 *, u32, u32, struct net_device___55 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___55 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___55 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___55 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___55 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___55 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___55 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___58 *, struct net_device___55 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___55 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___55 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___55 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___45 {
	struct net___69 *net;
	struct net_device___55 *dev;
	struct neigh_parms___45 *next;
	int (*neigh_setup)(struct neighbour___45 *);
	void (*neigh_cleanup)(struct neighbour___45 *);
	struct neigh_table___45 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___46 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___55 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___69 *, struct net_device___55 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___55 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___55 *, struct list_head *);
	size_t (*get_size)(const struct net_device___55 *);
	int (*fill_info)(struct sk_buff___58 *, const struct net_device___55 *);
	size_t (*get_xstats_size)(const struct net_device___55 *);
	int (*fill_xstats)(struct sk_buff___58 *, const struct net_device___55 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___69 * (*get_link_net)(const struct net_device___55 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___55 *, struct net_device___55 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___55 *, const struct net_device___55 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___58 *, const struct net_device___55 *, const struct net_device___55 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct xt_action_param;

struct xt_mtchk_param;

struct xt_mtdtor_param;

struct xt_match {
	struct list_head list;
	char name[29];
	u_int8_t revision;
	bool (*match)(const struct sk_buff___58 *, struct xt_action_param *);
	int (*checkentry)(const struct xt_mtchk_param *);
	void (*destroy)(const struct xt_mtdtor_param *);
	void (*compat_from_user)(void *, const void *);
	int (*compat_to_user)(void *, const void *);
	struct module___163 *me;
	const char *table;
	unsigned int matchsize;
	unsigned int compatsize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_entry_match {
	union {
		struct {
			__u16 match_size;
			char name[29];
			__u8 revision;
		} user;
		struct {
			__u16 match_size;
			struct xt_match *match;
		} kernel;
		__u16 match_size;
	} u;
	unsigned char data[0];
};

struct xt_tgchk_param;

struct xt_tgdtor_param;

struct xt_target {
	struct list_head list;
	char name[29];
	u_int8_t revision;
	unsigned int (*target)(struct sk_buff___58 *, const struct xt_action_param *);
	int (*checkentry)(const struct xt_tgchk_param *);
	void (*destroy)(const struct xt_tgdtor_param *);
	void (*compat_from_user)(void *, const void *);
	int (*compat_to_user)(void *, const void *);
	struct module___163 *me;
	const char *table;
	unsigned int targetsize;
	unsigned int compatsize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xt_entry_target {
	union {
		struct {
			__u16 target_size;
			char name[29];
			__u8 revision;
		} user;
		struct {
			__u16 target_size;
			struct xt_target *target;
		} kernel;
		__u16 target_size;
	} u;
	unsigned char data[0];
};

struct xt_action_param {
	union {
		const struct xt_match *match;
		const struct xt_target *target;
	};
	union {
		const void *matchinfo;
		const void *targinfo;
	};
	const struct net_device___55 *in;
	const struct net_device___55 *out;
	int fragoff;
	unsigned int thoff;
	unsigned int hooknum;
	u_int8_t family;
	bool hotdrop;
};

struct xt_mtchk_param {
	struct net___69 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_match *match;
	void *matchinfo;
	unsigned int hook_mask;
	u_int8_t family;
};

struct xt_mtdtor_param {
	struct net___69 *net;
	const struct xt_match *match;
	void *matchinfo;
	u_int8_t family;
};

struct xt_tgchk_param {
	struct net___69 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_target *target;
	void *targinfo;
	unsigned int hook_mask;
	u_int8_t family;
};

struct xt_tgdtor_param {
	struct net___69 *net;
	const struct xt_target *target;
	void *targinfo;
	u_int8_t family;
};

struct compat_xt_entry_match {
	union {
		struct {
			u_int16_t match_size;
			char name[29];
			u_int8_t revision;
		} user;
		struct {
			u_int16_t match_size;
			compat_uptr_t match;
		} kernel;
		u_int16_t match_size;
	} u;
	unsigned char data[0];
};

struct compat_xt_entry_target {
	union {
		struct {
			u_int16_t target_size;
			char name[29];
			u_int8_t revision;
		} user;
		struct {
			u_int16_t target_size;
			compat_uptr_t target;
		} kernel;
		u_int16_t target_size;
	} u;
	unsigned char data[0];
};

struct sk_filter___45 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___58 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___45;

struct neigh_hash_table___45;

struct neigh_table___45 {
	struct neigh_table___45 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___55 *, __u32 *);
	int (*constructor)(struct neighbour___45 *);
	int (*pconstructor)(struct pneigh_entry___45 *);
	void (*pdestructor)(struct pneigh_entry___45 *);
	void (*proxy_redo)(struct sk_buff___58 *);
	char *id;
	struct neigh_parms___45 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___56 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___45 *nht;
	struct pneigh_entry___45 **phash_buckets;
};

struct neigh_ops___45 {
	int family;
	void (*solicit)(struct neighbour___45 *, struct sk_buff___58 *);
	void (*error_report)(struct neighbour___45 *, struct sk_buff___58 *);
	int (*output)(struct neighbour___45 *, struct sk_buff___58 *);
	int (*connected_output)(struct neighbour___45 *, struct sk_buff___58 *);
};

struct pneigh_entry___45 {
	struct pneigh_entry___45 *next;
	struct net___69 *net;
	struct net_device___55 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___45 {
	struct neighbour___45 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___27;

struct proto___44 {
	void (*close)(struct sock___45 *, long int);
	int (*connect)(struct sock___45 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___45 *, int);
	struct sock___45 * (*accept)(struct sock___45 *, int, int *);
	int (*ioctl)(struct sock___45 *, int, long unsigned int);
	int (*init)(struct sock___45 *);
	void (*destroy)(struct sock___45 *);
	void (*shutdown)(struct sock___45 *, int);
	int (*setsockopt)(struct sock___45 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___45 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___45 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___45 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___45 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___52 *, struct sock___45 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___52 *, struct sock___45 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___45 *, struct page___264 *, int, size_t, int);
	int (*bind)(struct sock___45 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___45 *, struct sk_buff___58 *);
	void (*release_cb)(struct sock___45 *);
	void (*mtu_reduced)(struct sock___45 *);
	void (*hash)(struct sock___45 *);
	void (*unhash)(struct sock___45 *);
	void (*rehash)(struct sock___45 *);
	int (*get_port)(struct sock___45 *, short unsigned int);
	void (*clear_sk)(struct sock___45 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___45 *);
	void (*enter_memory_pressure)(struct sock___45 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___248 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___30 *rsk_prot;
	struct timewait_sock_ops___27 *twsk_prot;
	union {
		struct inet_hashinfo___4 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___163 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___92 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___44 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___44 {
	void (*enter_memory_pressure)(struct sock___45 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___30 {
	int family;
	int obj_size;
	struct kmem_cache___248 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___45 *, struct request_sock___31 *);
	void (*send_ack)(struct sock___45 *, struct sk_buff___58 *, struct request_sock___31 *);
	void (*send_reset)(struct sock___45 *, struct sk_buff___58 *);
	void (*destructor)(struct request_sock___31 *);
	void (*syn_ack_timeout)(struct sock___45 *, struct request_sock___31 *);
};

struct timewait_sock_ops___27 {
	struct kmem_cache___248 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___45 *, struct sock___45 *, void *);
	void (*twsk_destructor)(struct sock___45 *);
};

struct nf_ipv6_ops___5 {
	int (*chk_addr)(struct net___69 *, const struct in6_addr *, const struct net_device___55 *, int);
};

struct compat_delta {
	unsigned int offset;
	int delta;
};

struct xt_af {
	struct mutex___267 mutex;
	struct list_head match;
	struct list_head target;
	struct mutex___267 compat_mutex;
	struct compat_delta *compat_tab;
	unsigned int number;
	unsigned int cur;
};

struct xt_names_priv {
	struct seq_net_private___6 p;
	u_int8_t af;
};

struct nf_mttg_trav {
	struct list_head *head;
	struct list_head *curr;
	uint8_t class;
	uint8_t nfproto;
};

enum {
	MTTG_TRAV_INIT = 0,
	MTTG_TRAV_NFP_UNSPEC = 1,
	MTTG_TRAV_NFP_SPEC = 2,
	MTTG_TRAV_DONE = 3,
};

struct page___265;

typedef struct page___265 *pgtable_t___265;

struct address_space___266;

struct kmem_cache___249;

struct page___265 {
	long unsigned int flags;
	struct address_space___266 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___265 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___265 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___249 *slab_cache;
		struct page___265 *first_page;
	};
	long: 64;
};

struct task_struct___267;

struct pv_cpu_ops___267 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___267 *);
	void (*end_context_switch)(struct task_struct___267 *);
};

struct mutex___268 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___267 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___260 {
	struct page___265 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___274;

struct nsproxy___146;

struct signal_struct___267;

struct css_set___161;

struct task_struct___267 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___267 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___274 *mm;
	struct mm_struct___274 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___267 *real_parent;
	struct task_struct___267 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___267 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___267 = 0,
		VTIME_USER___267 = 1,
		VTIME_SYS___267 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___146 *nsproxy;
	struct signal_struct___267 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___161 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___268 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___260 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___274 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___274 *, struct mm_struct___274 *);
	void (*dup_mmap)(struct mm_struct___274 *, struct mm_struct___274 *);
	void (*exit_mmap)(struct mm_struct___274 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___274 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___274 *);
	void (*pgd_free)(struct mm_struct___274 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___274 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___274 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___274 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___274 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___274 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___274 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___274 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___274 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___274 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___274 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___274 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___268 lock;
	void *vdso;
} mm_context_t___268;

struct xol_area___265;

struct uprobes_state___265 {
	struct xol_area___265 *xol_area;
};

struct vm_area_struct___274;

struct file___266;

struct core_state___267;

struct mm_struct___274 {
	struct vm_area_struct___274 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___274 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___274 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___268 context;
	long unsigned int flags;
	struct core_state___267 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___267 *owner;
	struct file___266 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___265 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___48;

struct kobj_type___48;

struct kobject___48 {
	const char *name;
	struct list_head entry;
	struct kobject___48 *parent;
	struct kset___48 *kset;
	struct kobj_type___48 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___164;

struct module_kobject___163 {
	struct kobject___48 kobj;
	struct module___164 *mod;
	struct kobject___48 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___163;

struct module___164 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___163 mkobj;
	struct module_attribute___163 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___48 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___267 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___267;

struct lruvec___267 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___267 *zone;
};

struct pglist_data___267;

struct zone___267 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___267 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___267 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___267 {
	struct zone___267 *zone;
	int zone_idx;
};

struct zonelist___267 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___267 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___267 {
	struct zone___267 node_zones[4];
	struct zonelist___267 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___267 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___190;

struct x86_io_apic_ops___190 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___190 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___190;

struct irq_data___190 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___190 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___264;

struct dev_pm_ops___264 {
	int (*prepare)(struct device___264 *);
	void (*complete)(struct device___264 *);
	int (*suspend)(struct device___264 *);
	int (*resume)(struct device___264 *);
	int (*freeze)(struct device___264 *);
	int (*thaw)(struct device___264 *);
	int (*poweroff)(struct device___264 *);
	int (*restore)(struct device___264 *);
	int (*suspend_late)(struct device___264 *);
	int (*resume_early)(struct device___264 *);
	int (*freeze_late)(struct device___264 *);
	int (*thaw_early)(struct device___264 *);
	int (*poweroff_late)(struct device___264 *);
	int (*restore_early)(struct device___264 *);
	int (*suspend_noirq)(struct device___264 *);
	int (*resume_noirq)(struct device___264 *);
	int (*freeze_noirq)(struct device___264 *);
	int (*thaw_noirq)(struct device___264 *);
	int (*poweroff_noirq)(struct device___264 *);
	int (*restore_noirq)(struct device___264 *);
	int (*runtime_suspend)(struct device___264 *);
	int (*runtime_resume)(struct device___264 *);
	int (*runtime_idle)(struct device___264 *);
};

struct dev_pm_qos___67;

struct dev_pm_info___67 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___67 *qos;
};

struct dma_map_ops___129;

struct dev_archdata___129 {
	struct dma_map_ops___129 *dma_ops;
	void *iommu;
};

struct device_type___264;

struct bus_type___264;

struct device_driver___264;

struct dev_pm_domain___264;

struct class___264;

struct attribute_group___226;

struct device_rh___264;

struct device___264 {
	struct device___264 *parent;
	struct device_private *p;
	struct kobject___48 kobj;
	const char *init_name;
	const struct device_type___264 *type;
	struct mutex___268 mutex;
	struct bus_type___264 *bus;
	struct device_driver___264 *driver;
	void *platform_data;
	struct dev_pm_info___67 power;
	struct dev_pm_domain___264 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___129 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___264 *class;
	const struct attribute_group___226 **groups;
	void (*release)(struct device___264 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___264 *device_rh;
};

struct dev_pm_qos_request___68;

struct dev_pm_qos___67 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___68 *latency_req;
	struct dev_pm_qos_request___68 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___68 *latency_tolerance_req;
};

struct dev_pm_info_rh___264 {
	void (*set_latency_tolerance)(struct device___264 *, s32);
};

struct dev_pm_domain___264 {
	struct dev_pm_ops___264 ops;
};

struct smp_ops___267 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___267 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___71;

struct ctl_node___71 {
	struct rb_node node;
	struct ctl_table_header___71 *header;
};

struct ctl_table_root___71;

struct ctl_table_set___71;

struct ctl_dir___71;

struct ctl_table_header___71 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___71 *root;
	struct ctl_table_set___71 *set;
	struct ctl_dir___71 *parent;
	struct ctl_node___71 *node;
};

struct ctl_dir___71 {
	struct ctl_table_header___71 header;
	struct rb_root root;
};

struct ctl_table_set___71 {
	int (*is_seen)(struct ctl_table_set___71 *);
	struct ctl_dir___71 dir;
};

struct ctl_table_root___71 {
	struct ctl_table_set___71 default_set;
	struct ctl_table_set___71 * (*lookup)(struct ctl_table_root___71 *, struct nsproxy___146 *);
	int (*permissions)(struct ctl_table_header___71 *, struct ctl_table *);
};

struct net___70;

struct nsproxy___146 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___70 *net_ns;
};

struct sock___46;

struct kobj_ns_type_operations___45 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___46 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___45;

struct sock_common___45 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___45 *skc_prot;
	struct net___70 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___59;

struct sk_buff_head___57 {
	struct sk_buff___59 *next;
	struct sk_buff___59 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___46;

struct socket_wq___45;

struct dst_entry___46;

struct socket___46;

struct cg_proto___45;

struct sock___46 {
	struct sock_common___45 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___57 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___59 *head;
		struct sk_buff___59 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___46 *sk_filter;
	struct socket_wq___45 *sk_wq;
	struct sk_buff_head___57 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___46 *sk_rx_dst;
	struct dst_entry___46 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___57 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___57 sk_error_queue;
	struct proto___45 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___46 *sk_socket;
	void *sk_user_data;
	struct page_frag___260 sk_frag;
	struct sk_buff___59 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___45 *sk_cgrp;
	void (*sk_state_change)(struct sock___46 *);
	void (*sk_data_ready)(struct sock___46 *, int);
	void (*sk_write_space)(struct sock___46 *);
	void (*sk_error_report)(struct sock___46 *);
	int (*sk_backlog_rcv)(struct sock___46 *, struct sk_buff___59 *);
	void (*sk_destruct)(struct sock___46 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___228;

struct attribute_group___226 {
	const char *name;
	umode_t (*is_visible)(struct kobject___48 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___228 **bin_attrs;
};

struct bin_attribute___228 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___266 *, struct kobject___48 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___266 *, struct kobject___48 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	int (*mmap)(struct file___266 *, struct kobject___48 *, struct bin_attribute___228 *, struct vm_area_struct___274 *);
};

struct dentry___266;

struct path___266 {
	struct vfsmount *mnt;
	struct dentry___266 *dentry;
};

struct inode___266;

struct file_operations___266;

struct file___266 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___266 f_path;
	struct inode___266 *f_inode;
	const struct file_operations___266 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___266 *f_mapping;
	struct mutex___268 f_pos_lock;
};

struct vm_operations_struct___240;

struct vm_area_struct___274 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___274 *vm_next;
	struct vm_area_struct___274 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___274 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___240 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___266 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___48 {
	ssize_t (*show)(struct kobject___48 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___48 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___48 *, const struct attribute *);
};

struct kset_uevent_ops___48;

struct kset___48 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___48 kobj;
	const struct kset_uevent_ops___48 *uevent_ops;
};

struct kobj_type___48 {
	void (*release)(struct kobject___48 *);
	const struct sysfs_ops___48 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___45 * (*child_ns_type)(struct kobject___48 *);
	const void * (*namespace)(struct kobject___48 *);
};

struct kset_uevent_ops___48 {
	int (* const filter)(struct kset___48 *, struct kobject___48 *);
	const char * (* const name)(struct kset___48 *, struct kobject___48 *);
	int (* const uevent)(struct kset___48 *, struct kobject___48 *, struct kobj_uevent_env *);
};

struct module_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___163 *, struct module_kobject___163 *, char *);
	ssize_t (*store)(struct module_attribute___163 *, struct module_kobject___163 *, const char *, size_t);
	void (*setup)(struct module___164 *, const char *);
	int (*test)(struct module___164 *);
	void (*free)(struct module___164 *);
};

struct xol_area___265 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___265 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___248;

struct memcg_cache_params___249;

struct kmem_cache___249 {
	struct kmem_cache_cpu___248 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___48 kobj;
	struct memcg_cache_params___249 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___266;

struct address_space___266 {
	struct inode___266 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___268 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___266 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___236;

struct vm_operations_struct___240 {
	void (*open)(struct vm_area_struct___274 *);
	void (*close)(struct vm_area_struct___274 *);
	int (*fault)(struct vm_area_struct___274 *, struct vm_fault___236 *);
	int (*page_mkwrite)(struct vm_area_struct___274 *, struct vm_fault___236 *);
	int (*access)(struct vm_area_struct___274 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___274 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___274 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___274 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___274 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___267 {
	struct task_struct___267 *task;
	struct core_thread___267 *next;
};

struct core_state___267 {
	atomic_t nr_threads;
	struct core_thread___267 dumper;
	struct completion startup;
};

struct fasync_struct___266;

struct socket_wq___45 {
	wait_queue_head_t wait;
	struct fasync_struct___266 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___266 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___266 *fa_next;
	struct file___266 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___45;

struct socket___46 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___45 *wq;
	struct file___266 *file;
	struct sock___46 *sk;
	const struct proto_ops___45 *ops;
};

struct poll_table_struct___152;

struct kiocb___53;

struct proto_ops___45 {
	int family;
	struct module___164 *owner;
	int (*release)(struct socket___46 *);
	int (*bind)(struct socket___46 *, struct sockaddr *, int);
	int (*connect)(struct socket___46 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___46 *, struct socket___46 *);
	int (*accept)(struct socket___46 *, struct socket___46 *, int);
	int (*getname)(struct socket___46 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___266 *, struct socket___46 *, struct poll_table_struct___152 *);
	int (*ioctl)(struct socket___46 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___46 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___46 *, int);
	int (*shutdown)(struct socket___46 *, int);
	int (*setsockopt)(struct socket___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___46 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___46 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___46 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___53 *, struct socket___46 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___53 *, struct socket___46 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___266 *, struct socket___46 *, struct vm_area_struct___274 *);
	ssize_t (*sendpage)(struct socket___46 *, struct page___265 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___46 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___46 *, int);
		struct {
			void (*set_peek_off)(struct sock___46 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___154)(struct file___266 *, wait_queue_head_t *, struct poll_table_struct___152 *);

struct poll_table_struct___152 {
	poll_queue_proc___154 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___53(struct kiocb___53 *, struct io_event *);

struct kiocb___53 {
	atomic_t ki_users;
	struct file___266 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___53 *ki_cancel;
	void (*ki_dtor)(struct kiocb___53 *);
	union {
		void *user;
		struct task_struct___267 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___68 {
	struct ctl_table_header___71 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___69 {
	struct mutex___268 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___68 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___71 *ctl;
};

struct xt_table___3;

struct netns_ipv4___68 {
	struct ctl_table_header___71 *forw_hdr;
	struct ctl_table_header___71 *frags_hdr;
	struct ctl_table_header___71 *ipv4_hdr;
	struct ctl_table_header___71 *route_hdr;
	struct ctl_table_header___71 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___46 *fibnl;
	struct sock___46 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table___3 *iptable_filter;
	struct xt_table___3 *iptable_mangle;
	struct xt_table___3 *iptable_raw;
	struct xt_table___3 *arptable_filter;
	struct xt_table___3 *iptable_security;
	struct xt_table___3 *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___68 {
	struct ctl_table_header___71 *hdr;
	struct ctl_table_header___71 *route_hdr;
	struct ctl_table_header___71 *icmp_hdr;
	struct ctl_table_header___71 *frags_hdr;
	struct ctl_table_header___71 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___56;

struct neighbour___46;

struct dst_ops___70 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___70 *);
	struct dst_entry___46 * (*check)(struct dst_entry___46 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___46 *);
	unsigned int (*mtu)(const struct dst_entry___46 *);
	u32 * (*cow_metrics)(struct dst_entry___46 *, long unsigned int);
	void (*destroy)(struct dst_entry___46 *);
	void (*ifdown)(struct dst_entry___46 *, struct net_device___56 *, int);
	struct dst_entry___46 * (*negative_advice)(struct dst_entry___46 *);
	void (*link_failure)(struct sk_buff___59 *);
	void (*update_pmtu)(struct dst_entry___46 *, struct sock___46 *, struct sk_buff___59 *, u32);
	void (*redirect)(struct dst_entry___46 *, struct sock___46 *, struct sk_buff___59 *);
	int (*local_out)(struct sk_buff___59 *);
	struct neighbour___46 * (*neigh_lookup)(const struct dst_entry___46 *, struct sk_buff___59 *, const void *);
	struct kmem_cache___249 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___70 {
	struct netns_sysctl_ipv6___68 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table___3 *ip6table_filter;
	struct xt_table___3 *ip6table_mangle;
	struct xt_table___3 *ip6table_raw;
	struct xt_table___3 *ip6table_security;
	struct xt_table___3 *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___70 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___46 **icmp_sk;
	struct sock___46 *ndisc_sk;
	struct sock___46 *tcp_sk;
	struct sock___46 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___68 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___71 *sysctl_header;
	struct sock___46 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___45 {
	struct sock___46 *v4_ctl_sk;
	struct sock___46 *v6_ctl_sk;
};

struct netns_nf___68 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___71 *nf_log_dir_header;
};

struct nf_proto_net___68 {
	struct ctl_table_header___71 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___68 {
	struct nf_proto_net___68 pn;
	unsigned int timeout;
};

struct nf_tcp_net___68 {
	struct nf_proto_net___68 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___68 {
	struct nf_proto_net___68 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___68 {
	struct nf_proto_net___68 pn;
	unsigned int timeout;
};

struct nf_ip_net___68 {
	struct nf_generic_net___68 generic;
	struct nf_tcp_net___68 tcp;
	struct nf_udp_net___68 udp;
	struct nf_icmp_net___68 icmp;
	struct nf_icmp_net___68 icmpv6;
};

struct netns_ct___69 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___71 *sysctl_header;
	struct ctl_table_header___71 *acct_sysctl_header;
	struct ctl_table_header___71 *tstamp_sysctl_header;
	struct ctl_table_header___71 *event_sysctl_header;
	struct ctl_table_header___71 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___249 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___68 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___68 {
	struct netns_sysctl_ipv6___68 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___70 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___46 *nlsk;
	struct sock___46 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___71 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___70 xfrm4_dst_ops;
	struct dst_ops___70 xfrm6_dst_ops;
};

struct net___70 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___71 sysctls;
	struct sock___46 *rtnl;
	struct sock___46 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___56 *loopback_dev;
	struct netns_core___68 core;
	struct netns_mib mib;
	struct netns_packet___69 packet;
	struct netns_unix___68 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___68 ipv4;
	struct netns_ipv6___70 ipv6;
	struct netns_sctp___68 sctp;
	struct netns_dccp___45 dccp;
	struct netns_nf___68 nf;
	struct netns_xt xt;
	struct netns_ct___69 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___68 nf_frag;
	struct sock___46 *nfnl;
	struct sock___46 *nfnl_stash;
	struct sk_buff_head___57 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___70 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___46 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___46 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___268 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___268 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___248 {
	void **freelist;
	long unsigned int tid;
	struct page___265 *page;
	struct page___265 *partial;
};

struct memcg_cache_params___249 {
	bool is_root_cache;
	union {
		struct kmem_cache___249 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___249 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___129 {
	void * (*alloc)(struct device___264 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___264 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___264 *, struct vm_area_struct___274 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___264 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___264 *, struct page___265 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___264 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___264 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___264 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___264 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___264 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___264 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___264 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___264 *, dma_addr_t);
	int (*dma_supported)(struct device___264 *, u64);
	int (*set_dma_mask)(struct device___264 *, u64);
	int is_phys;
};

struct bus_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___264 *, char *);
	ssize_t (*store)(struct bus_type___264 *, const char *, size_t);
};

struct device_attribute___264;

struct driver_attribute___264;

struct bus_type___264 {
	const char *name;
	const char *dev_name;
	struct device___264 *dev_root;
	struct bus_attribute___264 *bus_attrs;
	struct device_attribute___264 *dev_attrs;
	struct driver_attribute___264 *drv_attrs;
	const struct attribute_group___226 **bus_groups;
	const struct attribute_group___226 **dev_groups;
	const struct attribute_group___226 **drv_groups;
	int (*match)(struct device___264 *, struct device_driver___264 *);
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	int (*probe)(struct device___264 *);
	int (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*online)(struct device___264 *);
	int (*offline)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct device___264 *, struct device_attribute___264 *, char *);
	ssize_t (*store)(struct device___264 *, struct device_attribute___264 *, const char *, size_t);
};

struct driver_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___264 *, char *);
	ssize_t (*store)(struct device_driver___264 *, const char *, size_t);
};

struct device_driver___264 {
	const char *name;
	struct bus_type___264 *bus;
	struct module___164 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___264 *);
	int (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	const struct attribute_group___226 **groups;
	const struct dev_pm_ops___264 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___264 {
	const char *name;
	const struct attribute_group___226 **groups;
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
};

struct class_attribute___264;

struct class___264 {
	const char *name;
	struct module___164 *owner;
	struct class_attribute___264 *class_attrs;
	struct device_attribute___264 *dev_attrs;
	const struct attribute_group___226 **dev_groups;
	struct bin_attribute___228 *dev_bin_attrs;
	struct kobject___48 *dev_kobj;
	int (*dev_uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *);
	void (*class_release)(struct class___264 *);
	void (*dev_release)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	const struct kobj_ns_type_operations___45 *ns_type;
	const void * (*namespace)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
	struct subsys_private *p;
};

struct class_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct class___264 *, struct class_attribute___264 *, char *);
	ssize_t (*store)(struct class___264 *, struct class_attribute___264 *, const char *, size_t);
	const void * (*namespace)(struct class___264 *, const struct class_attribute___264 *);
};

struct device_rh___264 {
	struct dev_pm_info_rh___264 power;
};

struct vm_fault___236 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___265 *page;
};

struct signal_struct___267 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___267 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___267 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___268 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___161;

struct css_set___161 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___161 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___56 {
	atomic_t use;
	unsigned int mask;
	struct net_device___56 *physindev;
	struct net_device___56 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___56(struct sk_buff___59 **);

struct net_device_ops___56;

struct ethtool_ops___56;

struct header_ops___56;

struct inet6_dev___22;

struct netdev_rx_queue___56;

struct netdev_queue___56;

struct rtnl_link_ops___47;

struct dcbnl_rtnl_ops___56;

struct net_device___56 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___56 *netdev_ops;
	const struct ethtool_ops___56 *ethtool_ops;
	const struct header_ops___56 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___48 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___22 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___56 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___56 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___56 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___56 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___56 = 0,
		NETREG_REGISTERED___56 = 1,
		NETREG_UNREGISTERING___56 = 2,
		NETREG_UNREGISTERED___56 = 3,
		NETREG_RELEASED___56 = 4,
		NETREG_DUMMY___56 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___56 = 0,
		RTNL_LINK_INITIALIZING___56 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___56 *);
	struct netpoll_info *npinfo;
	struct net___70 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___264 dev;
	const struct attribute_group___226 *sysfs_groups[4];
	const struct rtnl_link_ops___47 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___56 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___59 {
	struct sk_buff___59 *next;
	struct sk_buff___59 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___46 *sk;
	struct net_device___56 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___59 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___56 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct file_lock___266;

struct seq_file___191;

struct file_operations___266 {
	struct module___164 *owner;
	loff_t (*llseek)(struct file___266 *, loff_t, int);
	ssize_t (*read)(struct file___266 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___266 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___53 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___53 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___266 *, void *, filldir_t);
	unsigned int (*poll)(struct file___266 *, struct poll_table_struct___152 *);
	long int (*unlocked_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___266 *, struct vm_area_struct___274 *);
	int (*open)(struct inode___266 *, struct file___266 *);
	int (*flush)(struct file___266 *, fl_owner_t);
	int (*release)(struct inode___266 *, struct file___266 *);
	int (*fsync)(struct file___266 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___53 *, int);
	int (*fasync)(int, struct file___266 *, int);
	int (*lock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*sendpage)(struct file___266 *, struct page___265 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___266 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___266 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___266 *, long int, struct file_lock___266 **, void **);
		struct {
			int (*setlease)(struct file___266 *, long int, struct file_lock___266 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___266 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___191 *, struct file___266 *);
};

struct dev_pm_qos_request___68 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___264 *dev;
};

struct dentry_operations___266;

struct super_block___266;

struct dentry___266 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___266 *d_parent;
	struct qstr d_name;
	struct inode___266 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___266 *d_op;
	struct super_block___266 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___266;

struct dquot___266;

struct block_device___266;

struct inode___266 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___266 *i_op;
	struct super_block___266 *i_sb;
	struct address_space___266 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___268 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___266 *i_fop;
	struct file_lock___266 *i_flock;
	struct address_space___266 i_data;
	struct dquot___266 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___266 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___266 {
	int (*d_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_hash)(const struct dentry___266 *, struct qstr *);
	int (*d_compare)(const struct dentry___266 *, const struct dentry___266 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___266 *);
	void (*d_release)(struct dentry___266 *);
	void (*d_prune)(struct dentry___266 *);
	void (*d_iput)(struct dentry___266 *, struct inode___266 *);
	char * (*d_dname)(struct dentry___266 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___266 *);
	int (*d_manage)(struct dentry___266 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___266;

struct mem_dqinfo___266 {
	struct quota_format_type___266 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___266;

struct quota_info___266 {
	unsigned int flags;
	struct mutex___268 dqio_mutex;
	struct mutex___268 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___266 *files[2];
	struct mem_dqinfo___266 info[2];
	const struct quota_format_ops___266 *ops[2];
};

struct file_system_type___266;

struct super_operations___266;

struct dquot_operations___266;

struct quotactl_ops___266;

struct xattr_handler___162;

struct super_block___266 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___266 *s_type;
	const struct super_operations___266 *s_op;
	const struct dquot_operations___266 *dq_op;
	const struct quotactl_ops___266 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___266 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___162 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___266 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___266 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___268 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___266 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___266 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___266 *bd_inode;
	struct super_block___266 *bd_super;
	struct mutex___268 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___266 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___268 bd_fsfreeze_mutex;
};

struct cgroup___161;

struct cgroup_subsys_state___161 {
	struct cgroup___161 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___266 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___266 *ia_file;
};

struct dquot___266 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___268 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___266 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___266 {
	int qf_fmt_id;
	const struct quota_format_ops___266 *qf_ops;
	struct module___164 *qf_owner;
	struct quota_format_type___266 *qf_next;
};

struct quota_format_ops___266 {
	int (*check_quota_file)(struct super_block___266 *, int);
	int (*read_file_info)(struct super_block___266 *, int);
	int (*write_file_info)(struct super_block___266 *, int);
	int (*free_file_info)(struct super_block___266 *, int);
	int (*read_dqblk)(struct dquot___266 *);
	int (*commit_dqblk)(struct dquot___266 *);
	int (*release_dqblk)(struct dquot___266 *);
};

struct dquot_operations___266 {
	int (*write_dquot)(struct dquot___266 *);
	struct dquot___266 * (*alloc_dquot)(struct super_block___266 *, int);
	void (*destroy_dquot)(struct dquot___266 *);
	int (*acquire_dquot)(struct dquot___266 *);
	int (*release_dquot)(struct dquot___266 *);
	int (*mark_dirty)(struct dquot___266 *);
	int (*write_info)(struct super_block___266 *, int);
	qsize_t * (*get_reserved_space)(struct inode___266 *);
};

struct quotactl_ops___266 {
	int (*quota_on)(struct super_block___266 *, int, int, struct path___266 *);
	int (*quota_on_meta)(struct super_block___266 *, int, int);
	int (*quota_off)(struct super_block___266 *, int);
	int (*quota_sync)(struct super_block___266 *, int);
	int (*get_info)(struct super_block___266 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___266 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___266 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___266 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___266 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___266 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___266 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___266 *, unsigned int);
};

struct address_space_operations___266 {
	int (*writepage)(struct page___265 *, struct writeback_control *);
	int (*readpage)(struct file___266 *, struct page___265 *);
	int (*writepages)(struct address_space___266 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___265 *);
	int (*readpages)(struct file___266 *, struct address_space___266 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___266 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___265 **, void **);
	int (*write_end)(struct file___266 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___265 *, void *);
	sector_t (*bmap)(struct address_space___266 *, sector_t);
	void (*invalidatepage)(struct page___265 *, long unsigned int);
	int (*releasepage)(struct page___265 *, gfp_t);
	void (*freepage)(struct page___265 *);
	ssize_t (*direct_IO)(int, struct kiocb___53 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___266 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___266 *, struct page___265 *, struct page___265 *, enum migrate_mode);
	int (*launder_page)(struct page___265 *);
	int (*is_partially_uptodate)(struct page___265 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___265 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___266 *, struct page___265 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___266 *, sector_t *);
	void (*swap_deactivate)(struct file___266 *);
	void (*invalidatepage_range)(struct page___265 *, unsigned int, unsigned int);
};

struct inode_operations___266 {
	struct dentry___266 * (*lookup)(struct inode___266 *, struct dentry___266 *, unsigned int);
	void * (*follow_link)(struct dentry___266 *, struct nameidata *);
	int (*permission)(struct inode___266 *, int);
	struct posix_acl * (*get_acl)(struct inode___266 *, int);
	int (*readlink)(struct dentry___266 *, char *, int);
	void (*put_link)(struct dentry___266 *, struct nameidata *, void *);
	int (*create)(struct inode___266 *, struct dentry___266 *, umode_t, bool);
	int (*link)(struct dentry___266 *, struct inode___266 *, struct dentry___266 *);
	int (*unlink)(struct inode___266 *, struct dentry___266 *);
	int (*symlink)(struct inode___266 *, struct dentry___266 *, const char *);
	int (*mkdir)(struct inode___266 *, struct dentry___266 *, umode_t);
	int (*rmdir)(struct inode___266 *, struct dentry___266 *);
	int (*mknod)(struct inode___266 *, struct dentry___266 *, umode_t, dev_t);
	int (*rename)(struct inode___266 *, struct dentry___266 *, struct inode___266 *, struct dentry___266 *);
	int (*setattr)(struct dentry___266 *, struct iattr___266 *);
	int (*getattr)(struct vfsmount *, struct dentry___266 *, struct kstat *);
	int (*setxattr)(struct dentry___266 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___266 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___266 *, char *, size_t);
	int (*removexattr)(struct dentry___266 *, const char *);
	int (*fiemap)(struct inode___266 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___266 *, struct timespec *, int);
	int (*atomic_open)(struct inode___266 *, struct dentry___266 *, struct file___266 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___266;

struct lock_manager_operations___266;

struct file_lock___266 {
	struct file_lock___266 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___266 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___266 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___266 *fl_ops;
	const struct lock_manager_operations___266 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___266 {
	void (*fl_copy_lock)(struct file_lock___266 *, struct file_lock___266 *);
	void (*fl_release_private)(struct file_lock___266 *);
};

struct lock_manager_operations___266 {
	int (*lm_compare_owner)(struct file_lock___266 *, struct file_lock___266 *);
	long unsigned int (*lm_owner_key)(struct file_lock___266 *);
	void (*lm_notify)(struct file_lock___266 *);
	int (*lm_grant)(struct file_lock___266 *, struct file_lock___266 *, int);
	void (*lm_break)(struct file_lock___266 *);
	int (*lm_change)(struct file_lock___266 **, int);
};

struct file_system_type___266 {
	const char *name;
	int fs_flags;
	struct dentry___266 * (*mount)(struct file_system_type___266 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___266 *);
	struct module___164 *owner;
	struct file_system_type___266 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___266 {
	struct inode___266 * (*alloc_inode)(struct super_block___266 *);
	void (*destroy_inode)(struct inode___266 *);
	void (*dirty_inode)(struct inode___266 *, int);
	int (*write_inode)(struct inode___266 *, struct writeback_control *);
	int (*drop_inode)(struct inode___266 *);
	void (*evict_inode)(struct inode___266 *);
	void (*put_super)(struct super_block___266 *);
	int (*sync_fs)(struct super_block___266 *, int);
	int (*freeze_fs)(struct super_block___266 *);
	int (*unfreeze_fs)(struct super_block___266 *);
	int (*statfs)(struct dentry___266 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___266 *, int *, char *);
	void (*umount_begin)(struct super_block___266 *);
	int (*show_options)(struct seq_file___191 *, struct dentry___266 *);
	int (*show_devname)(struct seq_file___191 *, struct dentry___266 *);
	int (*show_path)(struct seq_file___191 *, struct dentry___266 *);
	int (*show_stats)(struct seq_file___191 *, struct dentry___266 *);
	ssize_t (*quota_read)(struct super_block___266 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___266 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___266 *);
	int (*bdev_try_to_free_page)(struct super_block___266 *, struct page___265 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___266 *);
	void (*free_cached_objects)(struct super_block___266 *, int);
};

struct xattr_handler___162 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___266 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___266 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___266 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___191;

struct seq_file___191 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___268 lock;
	const struct seq_operations___191 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___56 {
	int (*get_settings)(struct net_device___56 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___56 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___56 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___56 *);
	void (*get_regs)(struct net_device___56 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___56 *);
	void (*set_msglevel)(struct net_device___56 *, u32);
	int (*nway_reset)(struct net_device___56 *);
	u32 (*get_link)(struct net_device___56 *);
	int (*get_eeprom_len)(struct net_device___56 *);
	int (*get_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___56 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___56 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___56 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___56 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___56 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___56 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___56 *);
	void (*complete)(struct net_device___56 *);
	u32 (*get_priv_flags)(struct net_device___56 *);
	int (*set_priv_flags)(struct net_device___56 *, u32);
	int (*get_sset_count)(struct net_device___56 *, int);
	int (*get_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___56 *, struct ethtool_flash *);
	int (*reset)(struct net_device___56 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___56 *);
	int (*get_rxfh_indir)(struct net_device___56 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___56 *, const u32 *);
	void (*get_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___56 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___56 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___56 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___56 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___56 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___56 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___56 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___56 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct xt_table___3 {
	struct list_head list;
	unsigned int valid_hooks;
	struct xt_table_info *private;
	struct module___164 *me;
	u_int8_t af;
	int priority;
	char name[32];
};

struct rtable___17;

struct dst_entry___46 {
	struct callback_head callback_head;
	struct dst_entry___46 *child;
	struct net_device___56 *dev;
	struct dst_ops___70 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___46 *path;
	struct dst_entry___46 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___59 *);
	union {
		int (*output)(struct sock___46 *, struct sk_buff___59 *);
		struct {
			int (*output)(struct sk_buff___59 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___46 *next;
		struct rtable___17 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___46;

struct neigh_parms___46;

struct neigh_ops___46;

struct neighbour___46 {
	struct neighbour___46 *next;
	struct neigh_table___46 *tbl;
	struct neigh_parms___46 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___57 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___46 *, struct sk_buff___59 *);
	const struct neigh_ops___46 *ops;
	struct callback_head rcu;
	struct net_device___56 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___70 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___59 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___59 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___70 *, struct dst_entry___46 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___59 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___59 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___190 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___190 *);
	void (*irq_shutdown)(struct irq_data___190 *);
	void (*irq_enable)(struct irq_data___190 *);
	void (*irq_disable)(struct irq_data___190 *);
	void (*irq_ack)(struct irq_data___190 *);
	void (*irq_mask)(struct irq_data___190 *);
	void (*irq_mask_ack)(struct irq_data___190 *);
	void (*irq_unmask)(struct irq_data___190 *);
	void (*irq_eoi)(struct irq_data___190 *);
	int (*irq_set_affinity)(struct irq_data___190 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___190 *);
	int (*irq_set_type)(struct irq_data___190 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___190 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___190 *);
	void (*irq_bus_sync_unlock)(struct irq_data___190 *);
	void (*irq_cpu_online)(struct irq_data___190 *);
	void (*irq_cpu_offline)(struct irq_data___190 *);
	void (*irq_suspend)(struct irq_data___190 *);
	void (*irq_resume)(struct irq_data___190 *);
	void (*irq_pm_shutdown)(struct irq_data___190 *);
	void (*irq_print_chip)(struct irq_data___190 *, struct seq_file___191 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___190 *, void *);
	long unsigned int flags;
};

struct seq_operations___191 {
	void * (*start)(struct seq_file___191 *, loff_t *);
	void (*stop)(struct seq_file___191 *, void *);
	void * (*next)(struct seq_file___191 *, void *, loff_t *);
	int (*show)(struct seq_file___191 *, void *);
};

struct dcbnl_rtnl_ops___56 {
	int (*ieee_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___56 *);
	u8 (*setstate)(struct net_device___56 *, u8);
	void (*getpermhwaddr)(struct net_device___56 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___56 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___56 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___56 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___56 *, int, u8 *);
	void (*setpfccfg)(struct net_device___56 *, int, u8);
	void (*getpfccfg)(struct net_device___56 *, int, u8 *);
	u8 (*setall)(struct net_device___56 *);
	u8 (*getcap)(struct net_device___56 *, int, u8 *);
	int (*getnumtcs)(struct net_device___56 *, int, u8 *);
	int (*setnumtcs)(struct net_device___56 *, int, u8);
	u8 (*getpfcstate)(struct net_device___56 *);
	void (*setpfcstate)(struct net_device___56 *, u8);
	void (*getbcncfg)(struct net_device___56 *, int, u32 *);
	void (*setbcncfg)(struct net_device___56 *, int, u32);
	void (*getbcnrp)(struct net_device___56 *, int, u8 *);
	void (*setbcnrp)(struct net_device___56 *, int, u8);
	u8 (*setapp)(struct net_device___56 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___56 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___56 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___56 *, int, u8);
	u8 (*getdcbx)(struct net_device___56 *);
	u8 (*setdcbx)(struct net_device___56 *, u8);
	int (*peer_getappinfo)(struct net_device___56 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___56 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___56 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___56 *, struct cee_pfc *);
};

struct cgroupfs_root___161;

struct cgroup___161 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___161 *parent;
	struct dentry___266 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___161 *subsys[11];
	struct cgroupfs_root___161 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___268 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___161 {
	struct super_block___266 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___161 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___97 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___266 *, struct file___266 *);
	ssize_t (*read)(struct cgroup___161 *, struct cftype___97 *, struct file___266 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___161 *, struct cftype___97 *);
	s64 (*read_s64)(struct cgroup___161 *, struct cftype___97 *);
	int (*read_map)(struct cgroup___161 *, struct cftype___97 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___161 *, struct cftype___97 *, struct seq_file___191 *);
	ssize_t (*write)(struct cgroup___161 *, struct cftype___97 *, struct file___266 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___161 *, struct cftype___97 *, u64);
	int (*write_s64)(struct cgroup___161 *, struct cftype___97 *, s64);
	int (*write_string)(struct cgroup___161 *, struct cftype___97 *, const char *);
	int (*trigger)(struct cgroup___161 *, unsigned int);
	int (*release)(struct inode___266 *, struct file___266 *);
	int (*register_event)(struct cgroup___161 *, struct cftype___97 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___161 *, struct cftype___97 *, struct eventfd_ctx *);
};

struct cftype_set___93 {
	struct list_head node;
	struct cftype___97 *cfts;
};

struct task_and_cgroup___93 {
	struct task_struct___267 *task;
	struct cgroup___161 *cgrp;
	struct css_set___161 *cg;
};

struct cgroup_taskset___93 {
	struct task_and_cgroup___93 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___161 *cur_cgrp;
};

struct cgroup_subsys___93 {
	struct cgroup_subsys_state___161 * (*css_alloc)(struct cgroup___161 *);
	int (*css_online)(struct cgroup___161 *);
	void (*css_offline)(struct cgroup___161 *);
	void (*css_free)(struct cgroup___161 *);
	int (*can_attach)(struct cgroup___161 *, struct cgroup_taskset___93 *);
	void (*cancel_attach)(struct cgroup___161 *, struct cgroup_taskset___93 *);
	void (*attach)(struct cgroup___161 *, struct cgroup_taskset___93 *);
	void (*fork)(struct task_struct___267 *);
	void (*exit)(struct cgroup___161 *, struct cgroup___161 *, struct task_struct___267 *);
	void (*bind)(struct cgroup___161 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___161 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___97 *base_cftypes;
	struct cftype_set___93 base_cftset;
	struct module___164 *module;
};

struct request_sock_ops___31;

struct request_sock___32 {
	struct sock_common___45 __req_common;
	struct request_sock___32 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___31 *rsk_ops;
	struct sock___46 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___58 {
	struct sk_buff___59 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___59 *, struct netlink_callback___58 *);
	int (*done)(struct netlink_callback___58 *);
	void *data;
	struct module___164 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___56 {
	int (*create)(struct sk_buff___59 *, struct net_device___56 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___59 *, unsigned char *);
	int (*rebuild)(struct sk_buff___59 *);
	int (*cache)(const struct neighbour___46 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___56 *, const unsigned char *);
};

struct napi_struct___56 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___56 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___56 *dev;
	struct sk_buff___59 *gro_list;
	struct sk_buff___59 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___56 {
	struct net_device___56 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___48 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___56 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___48 kobj;
	struct net_device___56 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___56 {
	int (*ndo_init)(struct net_device___56 *);
	void (*ndo_uninit)(struct net_device___56 *);
	int (*ndo_open)(struct net_device___56 *);
	int (*ndo_stop)(struct net_device___56 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___59 *, struct net_device___56 *);
	u16 (*ndo_select_queue)(struct net_device___56 *, struct sk_buff___59 *);
	void (*ndo_change_rx_flags)(struct net_device___56 *, int);
	void (*ndo_set_rx_mode)(struct net_device___56 *);
	int (*ndo_set_mac_address)(struct net_device___56 *, void *);
	int (*ndo_validate_addr)(struct net_device___56 *);
	int (*ndo_do_ioctl)(struct net_device___56 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___56 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___56 *, int);
	int (*ndo_neigh_setup)(struct net_device___56 *, struct neigh_parms___46 *);
	void (*ndo_tx_timeout)(struct net_device___56 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___56 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___56 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___56 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___56 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___56 *);
	int (*ndo_netpoll_setup)(struct net_device___56 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___56 *);
	int (*ndo_busy_poll)(struct napi_struct___56 *);
	int (*ndo_set_vf_mac)(struct net_device___56 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___56 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___56 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___56 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___56 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___56 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___56 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___56 *, int, struct sk_buff___59 *);
	int (*ndo_setup_tc)(struct net_device___56 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___56 *);
	int (*ndo_fcoe_disable)(struct net_device___56 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___56 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___56 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___56 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___56 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___56 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___56 *, const struct sk_buff___59 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___56 *, struct net_device___56 *);
	int (*ndo_del_slave)(struct net_device___56 *, struct net_device___56 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___46 *);
	void (*ndo_neigh_destroy)(struct neighbour___46 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___59 *, struct netlink_callback___58 *, struct net_device___56 *, int);
	int (*ndo_bridge_setlink)(struct net_device___56 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___59 *, u32, u32, struct net_device___56 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___56 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___56 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___56 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___56 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___56 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___56 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___59 *, struct net_device___56 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___56 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___56 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___56 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___46 {
	struct net___70 *net;
	struct net_device___56 *dev;
	struct neigh_parms___46 *next;
	int (*neigh_setup)(struct neighbour___46 *);
	void (*neigh_cleanup)(struct neighbour___46 *);
	struct neigh_table___46 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___22;

struct ifacaddr6___22;

struct inet6_dev___22 {
	struct net_device___56 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___22 *mc_list;
	struct ifmcaddr6___22 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___22 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___46 *nd_parms;
	struct inet6_dev___22 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___47 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___56 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___70 *, struct net_device___56 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___56 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___56 *, struct list_head *);
	size_t (*get_size)(const struct net_device___56 *);
	int (*fill_info)(struct sk_buff___59 *, const struct net_device___56 *);
	size_t (*get_xstats_size)(const struct net_device___56 *);
	int (*fill_xstats)(struct sk_buff___59 *, const struct net_device___56 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___70 * (*get_link_net)(const struct net_device___56 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___56 *, struct net_device___56 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___56 *, const struct net_device___56 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___59 *, const struct net_device___56 *, const struct net_device___56 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___46 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___59 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___46;

struct neigh_hash_table___46;

struct neigh_table___46 {
	struct neigh_table___46 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___56 *, __u32 *);
	int (*constructor)(struct neighbour___46 *);
	int (*pconstructor)(struct pneigh_entry___46 *);
	void (*pdestructor)(struct pneigh_entry___46 *);
	void (*proxy_redo)(struct sk_buff___59 *);
	char *id;
	struct neigh_parms___46 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___57 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___46 *nht;
	struct pneigh_entry___46 **phash_buckets;
};

struct neigh_ops___46 {
	int family;
	void (*solicit)(struct neighbour___46 *, struct sk_buff___59 *);
	void (*error_report)(struct neighbour___46 *, struct sk_buff___59 *);
	int (*output)(struct neighbour___46 *, struct sk_buff___59 *);
	int (*connected_output)(struct neighbour___46 *, struct sk_buff___59 *);
};

struct pneigh_entry___46 {
	struct pneigh_entry___46 *next;
	struct net___70 *net;
	struct net_device___56 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___46 {
	struct neighbour___46 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___17 {
	struct dst_entry___46 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___28;

struct inet_hashinfo___5;

struct proto___45 {
	void (*close)(struct sock___46 *, long int);
	int (*connect)(struct sock___46 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___46 *, int);
	struct sock___46 * (*accept)(struct sock___46 *, int, int *);
	int (*ioctl)(struct sock___46 *, int, long unsigned int);
	int (*init)(struct sock___46 *);
	void (*destroy)(struct sock___46 *);
	void (*shutdown)(struct sock___46 *, int);
	int (*setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___46 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___46 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___53 *, struct sock___46 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___53 *, struct sock___46 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___46 *, struct page___265 *, int, size_t, int);
	int (*bind)(struct sock___46 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___46 *, struct sk_buff___59 *);
	void (*release_cb)(struct sock___46 *);
	void (*mtu_reduced)(struct sock___46 *);
	void (*hash)(struct sock___46 *);
	void (*unhash)(struct sock___46 *);
	void (*rehash)(struct sock___46 *);
	int (*get_port)(struct sock___46 *, short unsigned int);
	void (*clear_sk)(struct sock___46 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___46 *);
	void (*enter_memory_pressure)(struct sock___46 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___249 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___31 *rsk_prot;
	struct timewait_sock_ops___28 *twsk_prot;
	union {
		struct inet_hashinfo___5 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___164 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___93 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___45 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___45 {
	void (*enter_memory_pressure)(struct sock___46 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___5 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___249 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___31 {
	int family;
	int obj_size;
	struct kmem_cache___249 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___46 *, struct request_sock___32 *);
	void (*send_ack)(struct sock___46 *, struct sk_buff___59 *, struct request_sock___32 *);
	void (*send_reset)(struct sock___46 *, struct sk_buff___59 *);
	void (*destructor)(struct request_sock___32 *);
	void (*syn_ack_timeout)(struct sock___46 *, struct request_sock___32 *);
};

struct timewait_sock_ops___28 {
	struct kmem_cache___249 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___46 *, struct sock___46 *, void *);
	void (*twsk_destructor)(struct sock___46 *);
};

struct ifmcaddr6___22 {
	struct in6_addr mca_addr;
	struct inet6_dev___22 *idev;
	struct ifmcaddr6___22 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___22 {
	struct in6_addr aca_addr;
	struct inet6_dev___22 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___22 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct xt_action_param___2;

struct xt_mtchk_param___2;

struct xt_mtdtor_param___2;

struct xt_match___2 {
	struct list_head list;
	char name[29];
	u_int8_t revision;
	bool (*match)(const struct sk_buff___59 *, struct xt_action_param___2 *);
	int (*checkentry)(const struct xt_mtchk_param___2 *);
	void (*destroy)(const struct xt_mtdtor_param___2 *);
	void (*compat_from_user)(void *, const void *);
	int (*compat_to_user)(void *, const void *);
	struct module___164 *me;
	const char *table;
	unsigned int matchsize;
	unsigned int compatsize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_tgchk_param___2;

struct xt_tgdtor_param___2;

struct xt_target___2 {
	struct list_head list;
	char name[29];
	u_int8_t revision;
	unsigned int (*target)(struct sk_buff___59 *, const struct xt_action_param___2 *);
	int (*checkentry)(const struct xt_tgchk_param___2 *);
	void (*destroy)(const struct xt_tgdtor_param___2 *);
	void (*compat_from_user)(void *, const void *);
	int (*compat_to_user)(void *, const void *);
	struct module___164 *me;
	const char *table;
	unsigned int targetsize;
	unsigned int compatsize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xt_action_param___2 {
	union {
		const struct xt_match___2 *match;
		const struct xt_target___2 *target;
	};
	union {
		const void *matchinfo;
		const void *targinfo;
	};
	const struct net_device___56 *in;
	const struct net_device___56 *out;
	int fragoff;
	unsigned int thoff;
	unsigned int hooknum;
	u_int8_t family;
	bool hotdrop;
};

struct xt_mtchk_param___2 {
	struct net___70 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_match___2 *match;
	void *matchinfo;
	unsigned int hook_mask;
	u_int8_t family;
};

struct xt_mtdtor_param___2 {
	struct net___70 *net;
	const struct xt_match___2 *match;
	void *matchinfo;
	u_int8_t family;
};

struct xt_tgchk_param___2 {
	struct net___70 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_target___2 *target;
	void *targinfo;
	unsigned int hook_mask;
	u_int8_t family;
};

struct xt_tgdtor_param___2 {
	struct net___70 *net;
	const struct xt_target___2 *target;
	void *targinfo;
	u_int8_t family;
};

struct xt_tcp {
	__u16 spts[2];
	__u16 dpts[2];
	__u8 option;
	__u8 flg_mask;
	__u8 flg_cmp;
	__u8 invflags;
};

struct xt_udp {
	__u16 spts[2];
	__u16 dpts[2];
	__u8 invflags;
};

struct nf_ipv6_ops___6 {
	int (*chk_addr)(struct net___70 *, const struct in6_addr *, const struct net_device___56 *, int);
};

struct page___266;

typedef struct page___266 *pgtable_t___266;

struct address_space___267;

struct kmem_cache___250;

struct page___266 {
	long unsigned int flags;
	struct address_space___267 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___266 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___266 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___250 *slab_cache;
		struct page___266 *first_page;
	};
	long: 64;
};

struct task_struct___268;

struct pv_cpu_ops___268 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___268 *);
	void (*end_context_switch)(struct task_struct___268 *);
};

struct mutex___269 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___268 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___261 {
	struct page___266 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___275;

struct nsproxy___147;

struct signal_struct___268;

struct css_set___162;

struct task_struct___268 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___268 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___275 *mm;
	struct mm_struct___275 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___268 *real_parent;
	struct task_struct___268 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___268 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___268 = 0,
		VTIME_USER___268 = 1,
		VTIME_SYS___268 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___147 *nsproxy;
	struct signal_struct___268 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___162 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___269 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___261 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___275 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___275 *, struct mm_struct___275 *);
	void (*dup_mmap)(struct mm_struct___275 *, struct mm_struct___275 *);
	void (*exit_mmap)(struct mm_struct___275 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___275 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___275 *);
	void (*pgd_free)(struct mm_struct___275 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___275 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___275 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___275 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___275 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___275 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___275 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___275 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___275 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___275 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___275 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___275 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___269 lock;
	void *vdso;
} mm_context_t___269;

struct xol_area___266;

struct uprobes_state___266 {
	struct xol_area___266 *xol_area;
};

struct vm_area_struct___275;

struct file___267;

struct core_state___268;

struct mm_struct___275 {
	struct vm_area_struct___275 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___275 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___275 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___269 context;
	long unsigned int flags;
	struct core_state___268 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___268 *owner;
	struct file___267 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___266 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___49;

struct kobj_type___49;

struct kobject___49 {
	const char *name;
	struct list_head entry;
	struct kobject___49 *parent;
	struct kset___49 *kset;
	struct kobj_type___49 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___165;

struct module_kobject___164 {
	struct kobject___49 kobj;
	struct module___165 *mod;
	struct kobject___49 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___164;

struct module___165 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___164 mkobj;
	struct module_attribute___164 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___49 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___268 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___268;

struct lruvec___268 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___268 *zone;
};

struct pglist_data___268;

struct zone___268 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___268 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___268 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___268 {
	struct zone___268 *zone;
	int zone_idx;
};

struct zonelist___268 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___268 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___268 {
	struct zone___268 node_zones[4];
	struct zonelist___268 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___268 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___191;

struct x86_io_apic_ops___191 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___191 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___191;

struct irq_data___191 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___191 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___265;

struct dev_pm_ops___265 {
	int (*prepare)(struct device___265 *);
	void (*complete)(struct device___265 *);
	int (*suspend)(struct device___265 *);
	int (*resume)(struct device___265 *);
	int (*freeze)(struct device___265 *);
	int (*thaw)(struct device___265 *);
	int (*poweroff)(struct device___265 *);
	int (*restore)(struct device___265 *);
	int (*suspend_late)(struct device___265 *);
	int (*resume_early)(struct device___265 *);
	int (*freeze_late)(struct device___265 *);
	int (*thaw_early)(struct device___265 *);
	int (*poweroff_late)(struct device___265 *);
	int (*restore_early)(struct device___265 *);
	int (*suspend_noirq)(struct device___265 *);
	int (*resume_noirq)(struct device___265 *);
	int (*freeze_noirq)(struct device___265 *);
	int (*thaw_noirq)(struct device___265 *);
	int (*poweroff_noirq)(struct device___265 *);
	int (*restore_noirq)(struct device___265 *);
	int (*runtime_suspend)(struct device___265 *);
	int (*runtime_resume)(struct device___265 *);
	int (*runtime_idle)(struct device___265 *);
};

struct dev_pm_qos___68;

struct dev_pm_info___68 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___68 *qos;
};

struct dma_map_ops___130;

struct dev_archdata___130 {
	struct dma_map_ops___130 *dma_ops;
	void *iommu;
};

struct device_type___265;

struct bus_type___265;

struct device_driver___265;

struct dev_pm_domain___265;

struct class___265;

struct attribute_group___227;

struct device_rh___265;

struct device___265 {
	struct device___265 *parent;
	struct device_private *p;
	struct kobject___49 kobj;
	const char *init_name;
	const struct device_type___265 *type;
	struct mutex___269 mutex;
	struct bus_type___265 *bus;
	struct device_driver___265 *driver;
	void *platform_data;
	struct dev_pm_info___68 power;
	struct dev_pm_domain___265 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___130 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___42 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___265 *class;
	const struct attribute_group___227 **groups;
	void (*release)(struct device___265 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___265 *device_rh;
};

struct dev_pm_qos_request___69;

struct dev_pm_qos___68 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___69 *latency_req;
	struct dev_pm_qos_request___69 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___69 *latency_tolerance_req;
};

struct dev_pm_info_rh___265 {
	void (*set_latency_tolerance)(struct device___265 *, s32);
};

struct dev_pm_domain___265 {
	struct dev_pm_ops___265 ops;
};

struct smp_ops___268 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___268 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___72;

struct ctl_node___72 {
	struct rb_node node;
	struct ctl_table_header___72 *header;
};

struct ctl_table_root___72;

struct ctl_table_set___72;

struct ctl_dir___72;

struct ctl_table_header___72 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___72 *root;
	struct ctl_table_set___72 *set;
	struct ctl_dir___72 *parent;
	struct ctl_node___72 *node;
};

struct ctl_dir___72 {
	struct ctl_table_header___72 header;
	struct rb_root root;
};

struct ctl_table_set___72 {
	int (*is_seen)(struct ctl_table_set___72 *);
	struct ctl_dir___72 dir;
};

struct ctl_table_root___72 {
	struct ctl_table_set___72 default_set;
	struct ctl_table_set___72 * (*lookup)(struct ctl_table_root___72 *, struct nsproxy___147 *);
	int (*permissions)(struct ctl_table_header___72 *, struct ctl_table *);
};

struct net___71;

struct nsproxy___147 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___71 *net_ns;
};

struct sock___47;

struct kobj_ns_type_operations___46 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___47 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___46;

struct sock_common___46 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___46 *skc_prot;
	struct net___71 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___60;

struct sk_buff_head___58 {
	struct sk_buff___60 *next;
	struct sk_buff___60 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___47;

struct socket_wq___46;

struct xfrm_policy___5;

struct dst_entry___47;

struct socket___47;

struct cg_proto___46;

struct sock___47 {
	struct sock_common___46 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___58 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___60 *head;
		struct sk_buff___60 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___47 *sk_filter;
	struct socket_wq___46 *sk_wq;
	struct sk_buff_head___58 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___5 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___47 *sk_rx_dst;
	struct dst_entry___47 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___58 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___58 sk_error_queue;
	struct proto___46 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___47 *sk_socket;
	void *sk_user_data;
	struct page_frag___261 sk_frag;
	struct sk_buff___60 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___46 *sk_cgrp;
	void (*sk_state_change)(struct sock___47 *);
	void (*sk_data_ready)(struct sock___47 *, int);
	void (*sk_write_space)(struct sock___47 *);
	void (*sk_error_report)(struct sock___47 *);
	int (*sk_backlog_rcv)(struct sock___47 *, struct sk_buff___60 *);
	void (*sk_destruct)(struct sock___47 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___229;

struct attribute_group___227 {
	const char *name;
	umode_t (*is_visible)(struct kobject___49 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___229 **bin_attrs;
};

struct bin_attribute___229 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___267 *, struct kobject___49 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___267 *, struct kobject___49 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	int (*mmap)(struct file___267 *, struct kobject___49 *, struct bin_attribute___229 *, struct vm_area_struct___275 *);
};

struct dentry___267;

struct path___267 {
	struct vfsmount *mnt;
	struct dentry___267 *dentry;
};

struct inode___267;

struct file_operations___267;

struct file___267 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___267 f_path;
	struct inode___267 *f_inode;
	const struct file_operations___267 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___267 *f_mapping;
	struct mutex___269 f_pos_lock;
};

struct vm_operations_struct___241;

struct vm_area_struct___275 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___275 *vm_next;
	struct vm_area_struct___275 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___275 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___241 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___267 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___49 {
	ssize_t (*show)(struct kobject___49 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___49 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___49 *, const struct attribute *);
};

struct kset_uevent_ops___49;

struct kset___49 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___49 kobj;
	const struct kset_uevent_ops___49 *uevent_ops;
};

struct kobj_type___49 {
	void (*release)(struct kobject___49 *);
	const struct sysfs_ops___49 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___46 * (*child_ns_type)(struct kobject___49 *);
	const void * (*namespace)(struct kobject___49 *);
};

struct kset_uevent_ops___49 {
	int (* const filter)(struct kset___49 *, struct kobject___49 *);
	const char * (* const name)(struct kset___49 *, struct kobject___49 *);
	int (* const uevent)(struct kset___49 *, struct kobject___49 *, struct kobj_uevent_env *);
};

struct module_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___164 *, struct module_kobject___164 *, char *);
	ssize_t (*store)(struct module_attribute___164 *, struct module_kobject___164 *, const char *, size_t);
	void (*setup)(struct module___165 *, const char *);
	int (*test)(struct module___165 *);
	void (*free)(struct module___165 *);
};

struct xol_area___266 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___266 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___249;

struct memcg_cache_params___250;

struct kmem_cache___250 {
	struct kmem_cache_cpu___249 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___49 kobj;
	struct memcg_cache_params___250 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___267;

struct address_space___267 {
	struct inode___267 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___269 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___267 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___237;

struct vm_operations_struct___241 {
	void (*open)(struct vm_area_struct___275 *);
	void (*close)(struct vm_area_struct___275 *);
	int (*fault)(struct vm_area_struct___275 *, struct vm_fault___237 *);
	int (*page_mkwrite)(struct vm_area_struct___275 *, struct vm_fault___237 *);
	int (*access)(struct vm_area_struct___275 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___275 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___275 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___275 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___275 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___268 {
	struct task_struct___268 *task;
	struct core_thread___268 *next;
};

struct core_state___268 {
	atomic_t nr_threads;
	struct core_thread___268 dumper;
	struct completion startup;
};

struct vm_fault___237 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___266 *page;
};

struct ip_mreqn {
	struct in_addr imr_multiaddr;
	struct in_addr imr_address;
	int imr_ifindex;
};

struct kiocb___54;

struct poll_table_struct___153;

struct file_lock___267;

struct seq_file___192;

struct file_operations___267 {
	struct module___165 *owner;
	loff_t (*llseek)(struct file___267 *, loff_t, int);
	ssize_t (*read)(struct file___267 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___267 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___54 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___54 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___267 *, void *, filldir_t);
	unsigned int (*poll)(struct file___267 *, struct poll_table_struct___153 *);
	long int (*unlocked_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___267 *, struct vm_area_struct___275 *);
	int (*open)(struct inode___267 *, struct file___267 *);
	int (*flush)(struct file___267 *, fl_owner_t);
	int (*release)(struct inode___267 *, struct file___267 *);
	int (*fsync)(struct file___267 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___54 *, int);
	int (*fasync)(int, struct file___267 *, int);
	int (*lock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*sendpage)(struct file___267 *, struct page___266 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___267 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___267 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___267 *, long int, struct file_lock___267 **, void **);
		struct {
			int (*setlease)(struct file___267 *, long int, struct file_lock___267 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___267 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___192 *, struct file___267 *);
};

struct dma_map_ops___130 {
	void * (*alloc)(struct device___265 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___265 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___265 *, struct vm_area_struct___275 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___265 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___265 *, struct page___266 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___265 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___265 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___265 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___265 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___265 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___265 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___265 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___265 *, dma_addr_t);
	int (*dma_supported)(struct device___265 *, u64);
	int (*set_dma_mask)(struct device___265 *, u64);
	int is_phys;
};

struct bus_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___265 *, char *);
	ssize_t (*store)(struct bus_type___265 *, const char *, size_t);
};

struct device_attribute___265;

struct driver_attribute___265;

struct bus_type___265 {
	const char *name;
	const char *dev_name;
	struct device___265 *dev_root;
	struct bus_attribute___265 *bus_attrs;
	struct device_attribute___265 *dev_attrs;
	struct driver_attribute___265 *drv_attrs;
	const struct attribute_group___227 **bus_groups;
	const struct attribute_group___227 **dev_groups;
	const struct attribute_group___227 **drv_groups;
	int (*match)(struct device___265 *, struct device_driver___265 *);
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	int (*probe)(struct device___265 *);
	int (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*online)(struct device___265 *);
	int (*offline)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct device___265 *, struct device_attribute___265 *, char *);
	ssize_t (*store)(struct device___265 *, struct device_attribute___265 *, const char *, size_t);
};

struct driver_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___265 *, char *);
	ssize_t (*store)(struct device_driver___265 *, const char *, size_t);
};

struct device_driver___265 {
	const char *name;
	struct bus_type___265 *bus;
	struct module___165 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___265 *);
	int (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	const struct attribute_group___227 **groups;
	const struct dev_pm_ops___265 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___265 {
	const char *name;
	const struct attribute_group___227 **groups;
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
};

struct class_attribute___265;

struct class___265 {
	const char *name;
	struct module___165 *owner;
	struct class_attribute___265 *class_attrs;
	struct device_attribute___265 *dev_attrs;
	const struct attribute_group___227 **dev_groups;
	struct bin_attribute___229 *dev_bin_attrs;
	struct kobject___49 *dev_kobj;
	int (*dev_uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *);
	void (*class_release)(struct class___265 *);
	void (*dev_release)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	const struct kobj_ns_type_operations___46 *ns_type;
	const void * (*namespace)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
	struct subsys_private *p;
};

struct class_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct class___265 *, struct class_attribute___265 *, char *);
	ssize_t (*store)(struct class___265 *, struct class_attribute___265 *, const char *, size_t);
	const void * (*namespace)(struct class___265 *, const struct class_attribute___265 *);
};

struct device_rh___265 {
	struct dev_pm_info_rh___265 power;
};

struct dev_pm_qos_request___69 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___265 *dev;
};

struct dentry_operations___267;

struct super_block___267;

struct dentry___267 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___267 *d_parent;
	struct qstr d_name;
	struct inode___267 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___267 *d_op;
	struct super_block___267 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___267;

struct dquot___267;

struct block_device___267;

struct inode___267 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___267 *i_op;
	struct super_block___267 *i_sb;
	struct address_space___267 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___269 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___267 *i_fop;
	struct file_lock___267 *i_flock;
	struct address_space___267 i_data;
	struct dquot___267 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___267 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___267 {
	int (*d_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_hash)(const struct dentry___267 *, struct qstr *);
	int (*d_compare)(const struct dentry___267 *, const struct dentry___267 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___267 *);
	void (*d_release)(struct dentry___267 *);
	void (*d_prune)(struct dentry___267 *);
	void (*d_iput)(struct dentry___267 *, struct inode___267 *);
	char * (*d_dname)(struct dentry___267 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___267 *);
	int (*d_manage)(struct dentry___267 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___267;

struct mem_dqinfo___267 {
	struct quota_format_type___267 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___267;

struct quota_info___267 {
	unsigned int flags;
	struct mutex___269 dqio_mutex;
	struct mutex___269 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___267 *files[2];
	struct mem_dqinfo___267 info[2];
	const struct quota_format_ops___267 *ops[2];
};

struct file_system_type___267;

struct super_operations___267;

struct dquot_operations___267;

struct quotactl_ops___267;

struct xattr_handler___163;

struct super_block___267 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___267 *s_type;
	const struct super_operations___267 *s_op;
	const struct dquot_operations___267 *dq_op;
	const struct quotactl_ops___267 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___267 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___163 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___267 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___267 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___269 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___267 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___267 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___267 *bd_inode;
	struct super_block___267 *bd_super;
	struct mutex___269 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___267 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___269 bd_fsfreeze_mutex;
};

struct cgroup___162;

struct cgroup_subsys_state___162 {
	struct cgroup___162 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___54(struct kiocb___54 *, struct io_event *);

struct kiocb___54 {
	atomic_t ki_users;
	struct file___267 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___54 *ki_cancel;
	void (*ki_dtor)(struct kiocb___54 *);
	union {
		void *user;
		struct task_struct___268 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___267 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___267 *ia_file;
};

struct dquot___267 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___269 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___267 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___267 {
	int qf_fmt_id;
	const struct quota_format_ops___267 *qf_ops;
	struct module___165 *qf_owner;
	struct quota_format_type___267 *qf_next;
};

struct quota_format_ops___267 {
	int (*check_quota_file)(struct super_block___267 *, int);
	int (*read_file_info)(struct super_block___267 *, int);
	int (*write_file_info)(struct super_block___267 *, int);
	int (*free_file_info)(struct super_block___267 *, int);
	int (*read_dqblk)(struct dquot___267 *);
	int (*commit_dqblk)(struct dquot___267 *);
	int (*release_dqblk)(struct dquot___267 *);
};

struct dquot_operations___267 {
	int (*write_dquot)(struct dquot___267 *);
	struct dquot___267 * (*alloc_dquot)(struct super_block___267 *, int);
	void (*destroy_dquot)(struct dquot___267 *);
	int (*acquire_dquot)(struct dquot___267 *);
	int (*release_dquot)(struct dquot___267 *);
	int (*mark_dirty)(struct dquot___267 *);
	int (*write_info)(struct super_block___267 *, int);
	qsize_t * (*get_reserved_space)(struct inode___267 *);
};

struct quotactl_ops___267 {
	int (*quota_on)(struct super_block___267 *, int, int, struct path___267 *);
	int (*quota_on_meta)(struct super_block___267 *, int, int);
	int (*quota_off)(struct super_block___267 *, int);
	int (*quota_sync)(struct super_block___267 *, int);
	int (*get_info)(struct super_block___267 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___267 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___267 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___267 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___267 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___267 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___267 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___267 *, unsigned int);
};

struct address_space_operations___267 {
	int (*writepage)(struct page___266 *, struct writeback_control *);
	int (*readpage)(struct file___267 *, struct page___266 *);
	int (*writepages)(struct address_space___267 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___266 *);
	int (*readpages)(struct file___267 *, struct address_space___267 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___267 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___266 **, void **);
	int (*write_end)(struct file___267 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___266 *, void *);
	sector_t (*bmap)(struct address_space___267 *, sector_t);
	void (*invalidatepage)(struct page___266 *, long unsigned int);
	int (*releasepage)(struct page___266 *, gfp_t);
	void (*freepage)(struct page___266 *);
	ssize_t (*direct_IO)(int, struct kiocb___54 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___267 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___267 *, struct page___266 *, struct page___266 *, enum migrate_mode);
	int (*launder_page)(struct page___266 *);
	int (*is_partially_uptodate)(struct page___266 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___266 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___267 *, struct page___266 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___267 *, sector_t *);
	void (*swap_deactivate)(struct file___267 *);
	void (*invalidatepage_range)(struct page___266 *, unsigned int, unsigned int);
};

struct inode_operations___267 {
	struct dentry___267 * (*lookup)(struct inode___267 *, struct dentry___267 *, unsigned int);
	void * (*follow_link)(struct dentry___267 *, struct nameidata *);
	int (*permission)(struct inode___267 *, int);
	struct posix_acl * (*get_acl)(struct inode___267 *, int);
	int (*readlink)(struct dentry___267 *, char *, int);
	void (*put_link)(struct dentry___267 *, struct nameidata *, void *);
	int (*create)(struct inode___267 *, struct dentry___267 *, umode_t, bool);
	int (*link)(struct dentry___267 *, struct inode___267 *, struct dentry___267 *);
	int (*unlink)(struct inode___267 *, struct dentry___267 *);
	int (*symlink)(struct inode___267 *, struct dentry___267 *, const char *);
	int (*mkdir)(struct inode___267 *, struct dentry___267 *, umode_t);
	int (*rmdir)(struct inode___267 *, struct dentry___267 *);
	int (*mknod)(struct inode___267 *, struct dentry___267 *, umode_t, dev_t);
	int (*rename)(struct inode___267 *, struct dentry___267 *, struct inode___267 *, struct dentry___267 *);
	int (*setattr)(struct dentry___267 *, struct iattr___267 *);
	int (*getattr)(struct vfsmount *, struct dentry___267 *, struct kstat *);
	int (*setxattr)(struct dentry___267 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___267 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___267 *, char *, size_t);
	int (*removexattr)(struct dentry___267 *, const char *);
	int (*fiemap)(struct inode___267 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___267 *, struct timespec *, int);
	int (*atomic_open)(struct inode___267 *, struct dentry___267 *, struct file___267 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___267;

struct file_lock_operations___267;

struct lock_manager_operations___267;

struct file_lock___267 {
	struct file_lock___267 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___267 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___267 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___267 *fl_ops;
	const struct lock_manager_operations___267 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___267 {
	void (*fl_copy_lock)(struct file_lock___267 *, struct file_lock___267 *);
	void (*fl_release_private)(struct file_lock___267 *);
};

struct lock_manager_operations___267 {
	int (*lm_compare_owner)(struct file_lock___267 *, struct file_lock___267 *);
	long unsigned int (*lm_owner_key)(struct file_lock___267 *);
	void (*lm_notify)(struct file_lock___267 *);
	int (*lm_grant)(struct file_lock___267 *, struct file_lock___267 *, int);
	void (*lm_break)(struct file_lock___267 *);
	int (*lm_change)(struct file_lock___267 **, int);
};

struct fasync_struct___267 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___267 *fa_next;
	struct file___267 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___267 {
	const char *name;
	int fs_flags;
	struct dentry___267 * (*mount)(struct file_system_type___267 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___267 *);
	struct module___165 *owner;
	struct file_system_type___267 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___267 {
	struct inode___267 * (*alloc_inode)(struct super_block___267 *);
	void (*destroy_inode)(struct inode___267 *);
	void (*dirty_inode)(struct inode___267 *, int);
	int (*write_inode)(struct inode___267 *, struct writeback_control *);
	int (*drop_inode)(struct inode___267 *);
	void (*evict_inode)(struct inode___267 *);
	void (*put_super)(struct super_block___267 *);
	int (*sync_fs)(struct super_block___267 *, int);
	int (*freeze_fs)(struct super_block___267 *);
	int (*unfreeze_fs)(struct super_block___267 *);
	int (*statfs)(struct dentry___267 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___267 *, int *, char *);
	void (*umount_begin)(struct super_block___267 *);
	int (*show_options)(struct seq_file___192 *, struct dentry___267 *);
	int (*show_devname)(struct seq_file___192 *, struct dentry___267 *);
	int (*show_path)(struct seq_file___192 *, struct dentry___267 *);
	int (*show_stats)(struct seq_file___192 *, struct dentry___267 *);
	ssize_t (*quota_read)(struct super_block___267 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___267 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___267 *);
	int (*bdev_try_to_free_page)(struct super_block___267 *, struct page___266 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___267 *);
	void (*free_cached_objects)(struct super_block___267 *, int);
};

struct xattr_handler___163 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___267 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___267 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___267 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___155)(struct file___267 *, wait_queue_head_t *, struct poll_table_struct___153 *);

struct poll_table_struct___153 {
	poll_queue_proc___155 _qproc;
	long unsigned int _key;
};

struct seq_operations___192;

struct seq_file___192 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___269 lock;
	const struct seq_operations___192 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___268 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___268 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___268 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___269 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___162 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___162 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___46 {
	wait_queue_head_t wait;
	struct fasync_struct___267 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___46;

struct socket___47 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___46 *wq;
	struct file___267 *file;
	struct sock___47 *sk;
	const struct proto_ops___46 *ops;
};

struct proto_ops___46 {
	int family;
	struct module___165 *owner;
	int (*release)(struct socket___47 *);
	int (*bind)(struct socket___47 *, struct sockaddr *, int);
	int (*connect)(struct socket___47 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___47 *, struct socket___47 *);
	int (*accept)(struct socket___47 *, struct socket___47 *, int);
	int (*getname)(struct socket___47 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___267 *, struct socket___47 *, struct poll_table_struct___153 *);
	int (*ioctl)(struct socket___47 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___47 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___47 *, int);
	int (*shutdown)(struct socket___47 *, int);
	int (*setsockopt)(struct socket___47 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___47 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___47 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___47 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___54 *, struct socket___47 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___54 *, struct socket___47 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___267 *, struct socket___47 *, struct vm_area_struct___275 *);
	ssize_t (*sendpage)(struct socket___47 *, struct page___266 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___47 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___47 *, int);
		struct {
			void (*set_peek_off)(struct sock___47 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___69 {
	struct ctl_table_header___72 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___70 {
	struct mutex___269 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___69 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___72 *ctl;
};

struct fib_rules_ops___3;

struct netns_ipv4___69 {
	struct ctl_table_header___72 *forw_hdr;
	struct ctl_table_header___72 *frags_hdr;
	struct ctl_table_header___72 *ipv4_hdr;
	struct ctl_table_header___72 *route_hdr;
	struct ctl_table_header___72 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___3 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___47 *fibnl;
	struct sock___47 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___3 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___69 {
	struct ctl_table_header___72 *hdr;
	struct ctl_table_header___72 *route_hdr;
	struct ctl_table_header___72 *icmp_hdr;
	struct ctl_table_header___72 *frags_hdr;
	struct ctl_table_header___72 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___57;

struct neighbour___47;

struct dst_ops___71 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___71 *);
	struct dst_entry___47 * (*check)(struct dst_entry___47 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___47 *);
	unsigned int (*mtu)(const struct dst_entry___47 *);
	u32 * (*cow_metrics)(struct dst_entry___47 *, long unsigned int);
	void (*destroy)(struct dst_entry___47 *);
	void (*ifdown)(struct dst_entry___47 *, struct net_device___57 *, int);
	struct dst_entry___47 * (*negative_advice)(struct dst_entry___47 *);
	void (*link_failure)(struct sk_buff___60 *);
	void (*update_pmtu)(struct dst_entry___47 *, struct sock___47 *, struct sk_buff___60 *, u32);
	void (*redirect)(struct dst_entry___47 *, struct sock___47 *, struct sk_buff___60 *);
	int (*local_out)(struct sk_buff___60 *);
	struct neighbour___47 * (*neigh_lookup)(const struct dst_entry___47 *, struct sk_buff___60 *, const void *);
	struct kmem_cache___250 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___5;

struct fib6_table___5;

struct netns_ipv6___71 {
	struct netns_sysctl_ipv6___69 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___5 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___5 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___71 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___5 *ip6_prohibit_entry;
	struct rt6_info___5 *ip6_blk_hole_entry;
	struct fib6_table___5 *fib6_local_tbl;
	struct fib_rules_ops___3 *fib6_rules_ops;
	struct sock___47 **icmp_sk;
	struct sock___47 *ndisc_sk;
	struct sock___47 *tcp_sk;
	struct sock___47 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___3 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___69 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___72 *sysctl_header;
	struct sock___47 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___46 {
	struct sock___47 *v4_ctl_sk;
	struct sock___47 *v6_ctl_sk;
};

struct netns_nf___69 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___72 *nf_log_dir_header;
};

struct nf_proto_net___69 {
	struct ctl_table_header___72 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___69 {
	struct nf_proto_net___69 pn;
	unsigned int timeout;
};

struct nf_tcp_net___69 {
	struct nf_proto_net___69 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___69 {
	struct nf_proto_net___69 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___69 {
	struct nf_proto_net___69 pn;
	unsigned int timeout;
};

struct nf_ip_net___69 {
	struct nf_generic_net___69 generic;
	struct nf_tcp_net___69 tcp;
	struct nf_udp_net___69 udp;
	struct nf_icmp_net___69 icmp;
	struct nf_icmp_net___69 icmpv6;
};

struct netns_ct___70 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___72 *sysctl_header;
	struct ctl_table_header___72 *acct_sysctl_header;
	struct ctl_table_header___72 *tstamp_sysctl_header;
	struct ctl_table_header___72 *event_sysctl_header;
	struct ctl_table_header___72 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___250 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___69 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___69 {
	struct netns_sysctl_ipv6___69 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___71 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___47 *nlsk;
	struct sock___47 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___72 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___71 xfrm4_dst_ops;
	struct dst_ops___71 xfrm6_dst_ops;
};

struct net___71 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___72 sysctls;
	struct sock___47 *rtnl;
	struct sock___47 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___57 *loopback_dev;
	struct netns_core___69 core;
	struct netns_mib mib;
	struct netns_packet___70 packet;
	struct netns_unix___69 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___69 ipv4;
	struct netns_ipv6___71 ipv6;
	struct netns_sctp___69 sctp;
	struct netns_dccp___46 dccp;
	struct netns_nf___69 nf;
	struct netns_xt xt;
	struct netns_ct___70 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___69 nf_frag;
	struct sock___47 *nfnl;
	struct sock___47 *nfnl_stash;
	struct sk_buff_head___58 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___71 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___47 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___47 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___269 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___269 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___249 {
	void **freelist;
	long unsigned int tid;
	struct page___266 *page;
	struct page___266 *partial;
};

struct memcg_cache_params___250 {
	bool is_root_cache;
	union {
		struct kmem_cache___250 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___250 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___57 {
	atomic_t use;
	unsigned int mask;
	struct net_device___57 *physindev;
	struct net_device___57 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___57(struct sk_buff___60 **);

struct net_device_ops___57;

struct ethtool_ops___57;

struct header_ops___57;

struct in_device___6;

struct inet6_dev___23;

struct netdev_rx_queue___57;

struct netdev_queue___57;

struct rtnl_link_ops___48;

struct dcbnl_rtnl_ops___57;

struct net_device___57 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___57 *netdev_ops;
	const struct ethtool_ops___57 *ethtool_ops;
	const struct header_ops___57 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___49 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___6 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___23 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___57 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___57 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___57 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___57 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___57 = 0,
		NETREG_REGISTERED___57 = 1,
		NETREG_UNREGISTERING___57 = 2,
		NETREG_UNREGISTERED___57 = 3,
		NETREG_RELEASED___57 = 4,
		NETREG_DUMMY___57 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___57 = 0,
		RTNL_LINK_INITIALIZING___57 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___57 *);
	struct netpoll_info *npinfo;
	struct net___71 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___265 dev;
	const struct attribute_group___227 *sysfs_groups[4];
	const struct rtnl_link_ops___48 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___57 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___5;

struct sk_buff___60 {
	struct sk_buff___60 *next;
	struct sk_buff___60 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___47 *sk;
	struct net_device___57 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___5 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___60 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___57 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___5;

struct sec_path___5 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___5 *xvec[6];
};

struct ethtool_ops___57 {
	int (*get_settings)(struct net_device___57 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___57 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___57 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___57 *);
	void (*get_regs)(struct net_device___57 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___57 *);
	void (*set_msglevel)(struct net_device___57 *, u32);
	int (*nway_reset)(struct net_device___57 *);
	u32 (*get_link)(struct net_device___57 *);
	int (*get_eeprom_len)(struct net_device___57 *);
	int (*get_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___57 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___57 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___57 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___57 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___57 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___57 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___57 *);
	void (*complete)(struct net_device___57 *);
	u32 (*get_priv_flags)(struct net_device___57 *);
	int (*set_priv_flags)(struct net_device___57 *, u32);
	int (*get_sset_count)(struct net_device___57 *, int);
	int (*get_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___57 *, struct ethtool_flash *);
	int (*reset)(struct net_device___57 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___57 *);
	int (*get_rxfh_indir)(struct net_device___57 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___57 *, const u32 *);
	void (*get_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___57 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___57 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___57 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___57 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___57 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___57 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___57 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___57 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	IPSTATS_MIB_NUM = 0,
	IPSTATS_MIB_INPKTS = 1,
	IPSTATS_MIB_INOCTETS = 2,
	IPSTATS_MIB_INDELIVERS = 3,
	IPSTATS_MIB_OUTFORWDATAGRAMS = 4,
	IPSTATS_MIB_OUTPKTS = 5,
	IPSTATS_MIB_OUTOCTETS = 6,
	IPSTATS_MIB_INHDRERRORS = 7,
	IPSTATS_MIB_INTOOBIGERRORS = 8,
	IPSTATS_MIB_INNOROUTES = 9,
	IPSTATS_MIB_INADDRERRORS = 10,
	IPSTATS_MIB_INUNKNOWNPROTOS = 11,
	IPSTATS_MIB_INTRUNCATEDPKTS = 12,
	IPSTATS_MIB_INDISCARDS = 13,
	IPSTATS_MIB_OUTDISCARDS = 14,
	IPSTATS_MIB_OUTNOROUTES = 15,
	IPSTATS_MIB_REASMTIMEOUT = 16,
	IPSTATS_MIB_REASMREQDS = 17,
	IPSTATS_MIB_REASMOKS = 18,
	IPSTATS_MIB_REASMFAILS = 19,
	IPSTATS_MIB_FRAGOKS = 20,
	IPSTATS_MIB_FRAGFAILS = 21,
	IPSTATS_MIB_FRAGCREATES = 22,
	IPSTATS_MIB_INMCASTPKTS = 23,
	IPSTATS_MIB_OUTMCASTPKTS = 24,
	IPSTATS_MIB_INBCASTPKTS = 25,
	IPSTATS_MIB_OUTBCASTPKTS = 26,
	IPSTATS_MIB_INMCASTOCTETS = 27,
	IPSTATS_MIB_OUTMCASTOCTETS = 28,
	IPSTATS_MIB_INBCASTOCTETS = 29,
	IPSTATS_MIB_OUTBCASTOCTETS = 30,
	IPSTATS_MIB_CSUMERRORS = 31,
	IPSTATS_MIB_NOECTPKTS = 32,
	IPSTATS_MIB_ECT1PKTS = 33,
	IPSTATS_MIB_ECT0PKTS = 34,
	IPSTATS_MIB_CEPKTS = 35,
	__IPSTATS_MIB_MAX = 36,
};

struct fib_rule___3;

struct fib_lookup_arg___3;

struct fib_rules_ops___3 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___3 *, struct flowi *, int, struct fib_lookup_arg___3 *);
	int (*match)(struct fib_rule___3 *, struct flowi *, int);
	int (*configure)(struct fib_rule___3 *, struct sk_buff___60 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___3 *);
	int (*compare)(struct fib_rule___3 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___3 *, struct sk_buff___60 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___3 *);
	size_t (*nlmsg_payload)(struct fib_rule___3 *);
	void (*flush_cache)(struct fib_rules_ops___3 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___165 *owner;
	struct net___71 *fro_net;
	struct callback_head rcu;
};

struct fib_table {
	struct hlist_node tb_hlist;
	u32 tb_id;
	int tb_default;
	int tb_num_default;
	long unsigned int tb_data[0];
};

struct rtable___18;

struct dst_entry___47 {
	struct callback_head callback_head;
	struct dst_entry___47 *child;
	struct net_device___57 *dev;
	struct dst_ops___71 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___47 *path;
	struct dst_entry___47 *from;
	struct xfrm_state___5 *xfrm;
	int (*input)(struct sk_buff___60 *);
	union {
		int (*output)(struct sock___47 *, struct sk_buff___60 *);
		struct {
			int (*output)(struct sk_buff___60 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___47 *next;
		struct rtable___18 *rt_next;
		struct rt6_info___5 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___47;

struct neigh_parms___47;

struct neigh_ops___47;

struct neighbour___47 {
	struct neighbour___47 *next;
	struct neigh_table___47 *tbl;
	struct neigh_parms___47 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___58 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___47 *, struct sk_buff___60 *);
	const struct neigh_ops___47 *ops;
	struct callback_head rcu;
	struct net_device___57 *dev;
	u8 primary_key[0];
};

struct fib6_node___5;

struct rt6_info___5 {
	struct dst_entry___47 dst;
	struct fib6_table___5 *rt6i_table;
	struct fib6_node___5 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___23 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___5 {
	struct fib6_node___5 *parent;
	struct fib6_node___5 *left;
	struct fib6_node___5 *right;
	struct rt6_info___5 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___5 *rr_ptr;
};

struct fib6_table___5 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___5 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___71 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___60 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___60 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___71 *, struct dst_entry___47 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___60 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___60 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___191 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___191 *);
	void (*irq_shutdown)(struct irq_data___191 *);
	void (*irq_enable)(struct irq_data___191 *);
	void (*irq_disable)(struct irq_data___191 *);
	void (*irq_ack)(struct irq_data___191 *);
	void (*irq_mask)(struct irq_data___191 *);
	void (*irq_mask_ack)(struct irq_data___191 *);
	void (*irq_unmask)(struct irq_data___191 *);
	void (*irq_eoi)(struct irq_data___191 *);
	int (*irq_set_affinity)(struct irq_data___191 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___191 *);
	int (*irq_set_type)(struct irq_data___191 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___191 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___191 *);
	void (*irq_bus_sync_unlock)(struct irq_data___191 *);
	void (*irq_cpu_online)(struct irq_data___191 *);
	void (*irq_cpu_offline)(struct irq_data___191 *);
	void (*irq_suspend)(struct irq_data___191 *);
	void (*irq_resume)(struct irq_data___191 *);
	void (*irq_pm_shutdown)(struct irq_data___191 *);
	void (*irq_print_chip)(struct irq_data___191 *, struct seq_file___192 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___191 *, void *);
	long unsigned int flags;
};

struct seq_operations___192 {
	void * (*start)(struct seq_file___192 *, loff_t *);
	void (*stop)(struct seq_file___192 *, void *);
	void * (*next)(struct seq_file___192 *, void *, loff_t *);
	int (*show)(struct seq_file___192 *, void *);
};

struct pernet_operations___15 {
	struct list_head list;
	int (*init)(struct net___71 *);
	void (*exit)(struct net___71 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___57 {
	int (*ieee_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___57 *);
	u8 (*setstate)(struct net_device___57 *, u8);
	void (*getpermhwaddr)(struct net_device___57 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___57 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___57 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___57 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___57 *, int, u8 *);
	void (*setpfccfg)(struct net_device___57 *, int, u8);
	void (*getpfccfg)(struct net_device___57 *, int, u8 *);
	u8 (*setall)(struct net_device___57 *);
	u8 (*getcap)(struct net_device___57 *, int, u8 *);
	int (*getnumtcs)(struct net_device___57 *, int, u8 *);
	int (*setnumtcs)(struct net_device___57 *, int, u8);
	u8 (*getpfcstate)(struct net_device___57 *);
	void (*setpfcstate)(struct net_device___57 *, u8);
	void (*getbcncfg)(struct net_device___57 *, int, u32 *);
	void (*setbcncfg)(struct net_device___57 *, int, u32);
	void (*getbcnrp)(struct net_device___57 *, int, u8 *);
	void (*setbcnrp)(struct net_device___57 *, int, u8);
	u8 (*setapp)(struct net_device___57 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___57 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___57 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___57 *, int, u8);
	u8 (*getdcbx)(struct net_device___57 *);
	u8 (*setdcbx)(struct net_device___57 *, u8);
	int (*peer_getappinfo)(struct net_device___57 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___57 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___57 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___57 *, struct cee_pfc *);
};

struct cgroupfs_root___162;

struct cgroup___162 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___162 *parent;
	struct dentry___267 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___162 *subsys[11];
	struct cgroupfs_root___162 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___269 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___162 {
	struct super_block___267 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___162 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___98 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___267 *, struct file___267 *);
	ssize_t (*read)(struct cgroup___162 *, struct cftype___98 *, struct file___267 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___162 *, struct cftype___98 *);
	s64 (*read_s64)(struct cgroup___162 *, struct cftype___98 *);
	int (*read_map)(struct cgroup___162 *, struct cftype___98 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___162 *, struct cftype___98 *, struct seq_file___192 *);
	ssize_t (*write)(struct cgroup___162 *, struct cftype___98 *, struct file___267 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___162 *, struct cftype___98 *, u64);
	int (*write_s64)(struct cgroup___162 *, struct cftype___98 *, s64);
	int (*write_string)(struct cgroup___162 *, struct cftype___98 *, const char *);
	int (*trigger)(struct cgroup___162 *, unsigned int);
	int (*release)(struct inode___267 *, struct file___267 *);
	int (*register_event)(struct cgroup___162 *, struct cftype___98 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___162 *, struct cftype___98 *, struct eventfd_ctx *);
};

struct cftype_set___94 {
	struct list_head node;
	struct cftype___98 *cfts;
};

struct task_and_cgroup___94 {
	struct task_struct___268 *task;
	struct cgroup___162 *cgrp;
	struct css_set___162 *cg;
};

struct cgroup_taskset___94 {
	struct task_and_cgroup___94 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___162 *cur_cgrp;
};

struct cgroup_subsys___94 {
	struct cgroup_subsys_state___162 * (*css_alloc)(struct cgroup___162 *);
	int (*css_online)(struct cgroup___162 *);
	void (*css_offline)(struct cgroup___162 *);
	void (*css_free)(struct cgroup___162 *);
	int (*can_attach)(struct cgroup___162 *, struct cgroup_taskset___94 *);
	void (*cancel_attach)(struct cgroup___162 *, struct cgroup_taskset___94 *);
	void (*attach)(struct cgroup___162 *, struct cgroup_taskset___94 *);
	void (*fork)(struct task_struct___268 *);
	void (*exit)(struct cgroup___162 *, struct cgroup___162 *, struct task_struct___268 *);
	void (*bind)(struct cgroup___162 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___162 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___98 *base_cftypes;
	struct cftype_set___94 base_cftset;
	struct module___165 *module;
};

struct request_sock_ops___32;

struct request_sock___33 {
	struct sock_common___46 __req_common;
	struct request_sock___33 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___32 *rsk_ops;
	struct sock___47 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___5;

struct xfrm_type___5;

struct xfrm_mode___5;

struct xfrm_state___5 {
	struct net___71 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___5 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___5 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___5 *type;
	struct xfrm_mode___5 *inner_mode;
	struct xfrm_mode___5 *inner_mode_iaf;
	struct xfrm_mode___5 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___5 {
	struct sk_buff_head___58 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___5 {
	struct net___71 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___5 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_skb_parms___9 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___47 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___59 {
	struct sk_buff___60 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___60 *, struct netlink_callback___59 *);
	int (*done)(struct netlink_callback___59 *);
	void *data;
	struct module___165 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___57 {
	int (*create)(struct sk_buff___60 *, struct net_device___57 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___60 *, unsigned char *);
	int (*rebuild)(struct sk_buff___60 *);
	int (*cache)(const struct neighbour___47 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___57 *, const unsigned char *);
};

struct napi_struct___57 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___57 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___57 *dev;
	struct sk_buff___60 *gro_list;
	struct sk_buff___60 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___57 {
	struct net_device___57 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___49 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___57 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___49 kobj;
	struct net_device___57 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___57 {
	int (*ndo_init)(struct net_device___57 *);
	void (*ndo_uninit)(struct net_device___57 *);
	int (*ndo_open)(struct net_device___57 *);
	int (*ndo_stop)(struct net_device___57 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___60 *, struct net_device___57 *);
	u16 (*ndo_select_queue)(struct net_device___57 *, struct sk_buff___60 *);
	void (*ndo_change_rx_flags)(struct net_device___57 *, int);
	void (*ndo_set_rx_mode)(struct net_device___57 *);
	int (*ndo_set_mac_address)(struct net_device___57 *, void *);
	int (*ndo_validate_addr)(struct net_device___57 *);
	int (*ndo_do_ioctl)(struct net_device___57 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___57 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___57 *, int);
	int (*ndo_neigh_setup)(struct net_device___57 *, struct neigh_parms___47 *);
	void (*ndo_tx_timeout)(struct net_device___57 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___57 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___57 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___57 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___57 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___57 *);
	int (*ndo_netpoll_setup)(struct net_device___57 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___57 *);
	int (*ndo_busy_poll)(struct napi_struct___57 *);
	int (*ndo_set_vf_mac)(struct net_device___57 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___57 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___57 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___57 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___57 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___57 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___57 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___57 *, int, struct sk_buff___60 *);
	int (*ndo_setup_tc)(struct net_device___57 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___57 *);
	int (*ndo_fcoe_disable)(struct net_device___57 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___57 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___57 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___57 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___57 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___57 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___57 *, const struct sk_buff___60 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___57 *, struct net_device___57 *);
	int (*ndo_del_slave)(struct net_device___57 *, struct net_device___57 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___47 *);
	void (*ndo_neigh_destroy)(struct neighbour___47 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___60 *, struct netlink_callback___59 *, struct net_device___57 *, int);
	int (*ndo_bridge_setlink)(struct net_device___57 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___60 *, u32, u32, struct net_device___57 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___57 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___57 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___57 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___57 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___57 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___57 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___60 *, struct net_device___57 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___57 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___57 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___57 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___47 {
	struct net___71 *net;
	struct net_device___57 *dev;
	struct neigh_parms___47 *next;
	int (*neigh_setup)(struct neighbour___47 *);
	void (*neigh_cleanup)(struct neighbour___47 *);
	struct neigh_table___47 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___6;

struct in_device___6 {
	struct net_device___57 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___6 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___47 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___23;

struct ifacaddr6___23;

struct inet6_dev___23 {
	struct net_device___57 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___23 *mc_list;
	struct ifmcaddr6___23 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___23 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___47 *nd_parms;
	struct inet6_dev___23 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___48 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___57 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___71 *, struct net_device___57 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___57 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___57 *, struct list_head *);
	size_t (*get_size)(const struct net_device___57 *);
	int (*fill_info)(struct sk_buff___60 *, const struct net_device___57 *);
	size_t (*get_xstats_size)(const struct net_device___57 *);
	int (*fill_xstats)(struct sk_buff___60 *, const struct net_device___57 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___71 * (*get_link_net)(const struct net_device___57 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___57 *, struct net_device___57 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___57 *, const struct net_device___57 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___60 *, const struct net_device___57 *, const struct net_device___57 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtmsg {
	unsigned char rtm_family;
	unsigned char rtm_dst_len;
	unsigned char rtm_src_len;
	unsigned char rtm_tos;
	unsigned char rtm_table;
	unsigned char rtm_protocol;
	unsigned char rtm_scope;
	unsigned char rtm_type;
	unsigned int rtm_flags;
};

enum rt_scope_t {
	RT_SCOPE_UNIVERSE = 0,
	RT_SCOPE_SITE = 200,
	RT_SCOPE_LINK = 253,
	RT_SCOPE_HOST = 254,
	RT_SCOPE_NOWHERE = 255,
};

enum rt_class_t {
	RT_TABLE_UNSPEC = 0,
	RT_TABLE_COMPAT = 252,
	RT_TABLE_DEFAULT = 253,
	RT_TABLE_MAIN = 254,
	RT_TABLE_LOCAL = 255,
	RT_TABLE_MAX = 4294967295,
};

struct in_ifaddr___6 {
	struct hlist_node hash;
	struct in_ifaddr___6 *ifa_next;
	struct in_device___6 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_sf_list;

struct ip_mc_list {
	struct in_device___6 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list *next;
		struct ip_mc_list *next_rcu;
	};
	struct timer_list timer;
	int users;
	atomic_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct ip_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct callback_head rcu;
	__be32 sl_addr[0];
};

struct ip_mc_socklist {
	struct ip_mc_socklist *next_rcu;
	struct ip_mreqn multi;
	unsigned int sfmode;
	struct ip_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ip_sf_list {
	struct ip_sf_list *sf_next;
	__be32 sf_inaddr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
};

struct sk_filter___47 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___60 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef int (*rtnl_doit_func___5)(struct sk_buff___60 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___5)(struct sk_buff___60 *, struct netlink_callback___59 *);

typedef u16 (*rtnl_calcit_func___5)(struct sk_buff___60 *, struct nlmsghdr *);

struct pneigh_entry___47;

struct neigh_hash_table___47;

struct neigh_table___47 {
	struct neigh_table___47 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___57 *, __u32 *);
	int (*constructor)(struct neighbour___47 *);
	int (*pconstructor)(struct pneigh_entry___47 *);
	void (*pdestructor)(struct pneigh_entry___47 *);
	void (*proxy_redo)(struct sk_buff___60 *);
	char *id;
	struct neigh_parms___47 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___58 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___47 *nht;
	struct pneigh_entry___47 **phash_buckets;
};

struct neigh_ops___47 {
	int family;
	void (*solicit)(struct neighbour___47 *, struct sk_buff___60 *);
	void (*error_report)(struct neighbour___47 *, struct sk_buff___60 *);
	int (*output)(struct neighbour___47 *, struct sk_buff___60 *);
	int (*connected_output)(struct neighbour___47 *, struct sk_buff___60 *);
};

struct pneigh_entry___47 {
	struct pneigh_entry___47 *next;
	struct net___71 *net;
	struct net_device___57 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___47 {
	struct neighbour___47 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___18 {
	struct dst_entry___47 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___29;

struct inet_hashinfo___6;

struct proto___46 {
	void (*close)(struct sock___47 *, long int);
	int (*connect)(struct sock___47 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___47 *, int);
	struct sock___47 * (*accept)(struct sock___47 *, int, int *);
	int (*ioctl)(struct sock___47 *, int, long unsigned int);
	int (*init)(struct sock___47 *);
	void (*destroy)(struct sock___47 *);
	void (*shutdown)(struct sock___47 *, int);
	int (*setsockopt)(struct sock___47 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___47 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___47 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___47 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___47 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___54 *, struct sock___47 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___54 *, struct sock___47 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___47 *, struct page___266 *, int, size_t, int);
	int (*bind)(struct sock___47 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___47 *, struct sk_buff___60 *);
	void (*release_cb)(struct sock___47 *);
	void (*mtu_reduced)(struct sock___47 *);
	void (*hash)(struct sock___47 *);
	void (*unhash)(struct sock___47 *);
	void (*rehash)(struct sock___47 *);
	int (*get_port)(struct sock___47 *, short unsigned int);
	void (*clear_sk)(struct sock___47 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___47 *);
	void (*enter_memory_pressure)(struct sock___47 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___250 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___32 *rsk_prot;
	struct timewait_sock_ops___29 *twsk_prot;
	union {
		struct inet_hashinfo___6 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___165 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___94 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___46 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___46 {
	void (*enter_memory_pressure)(struct sock___47 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___6 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___250 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___32 {
	int family;
	int obj_size;
	struct kmem_cache___250 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___47 *, struct request_sock___33 *);
	void (*send_ack)(struct sock___47 *, struct sk_buff___60 *, struct request_sock___33 *);
	void (*send_reset)(struct sock___47 *, struct sk_buff___60 *);
	void (*destructor)(struct request_sock___33 *);
	void (*syn_ack_timeout)(struct sock___47 *, struct request_sock___33 *);
};

struct timewait_sock_ops___29 {
	struct kmem_cache___250 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___47 *, struct sock___47 *, void *);
	void (*twsk_destructor)(struct sock___47 *);
};

struct inet_cork___5 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___47 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___5 {
	struct inet_cork___5 base;
	struct flowi fl;
};

struct ipv6_pinfo___4;

struct inet_sock___5 {
	struct sock___47 sk;
	struct ipv6_pinfo___4 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___5 cork;
};

struct ipv6_fl_socklist___3;

struct ipv6_pinfo___4 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___3 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___60 *pktoptions;
	struct sk_buff___60 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___3;

struct ipv6_fl_socklist___3 {
	struct ipv6_fl_socklist___3 *next;
	struct ip6_flowlabel___3 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___23 {
	struct in6_addr mca_addr;
	struct inet6_dev___23 *idev;
	struct ifmcaddr6___23 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___23 {
	struct in6_addr aca_addr;
	struct inet6_dev___23 *aca_idev;
	struct rt6_info___5 *aca_rt;
	struct ifacaddr6___23 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___3 {
	struct ip6_flowlabel___3 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___71 *fl_net;
};

struct ip_rt_acct {
	__u32 o_bytes;
	__u32 o_packets;
	__u32 i_bytes;
	__u32 i_packets;
};

struct rt_cache_stat {
	unsigned int in_slow_tot;
	unsigned int in_slow_mc;
	unsigned int in_no_route;
	unsigned int in_brd;
	unsigned int in_martian_dst;
	unsigned int in_martian_src;
	unsigned int out_slow_tot;
	unsigned int out_slow_mc;
};

struct fib_rule___3 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___3 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___71 *fr_net;
};

struct fib_lookup_arg___3 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___3 *rule;
	int flags;
};

struct fib_nh_exception {
	struct fib_nh_exception *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___18 *fnhe_rth;
	long unsigned int fnhe_stamp;
};

struct fnhe_hash_bucket {
	struct fib_nh_exception *chain;
};

struct fib_info;

struct fib_nh {
	struct net_device___57 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	int nh_power;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___18 **nh_pcpu_rth_output;
	struct rtable___18 *nh_rth_input;
	struct fnhe_hash_bucket *nh_exceptions;
};

struct fib_info {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___71 *fib_net;
	int fib_treeref;
	atomic_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_priority;
	u32 *fib_metrics;
	int fib_nhs;
	int fib_power;
	struct callback_head rcu;
	struct fib_nh fib_nh[0];
};

struct fib_result {
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct icmphdr {
	__u8 type;
	__u8 code;
	__sum16 checksum;
	union {
		struct {
			__be16 id;
			__be16 sequence;
		} echo;
		__be32 gateway;
		struct {
			__be16 __unused;
			__be16 mtu;
		} frag;
	} un;
};

struct xfrm_replay___5 {
	void (*advance)(struct xfrm_state___5 *, __be32);
	int (*check)(struct xfrm_state___5 *, struct sk_buff___60 *, __be32);
	int (*recheck)(struct xfrm_state___5 *, struct sk_buff___60 *, __be32);
	void (*notify)(struct xfrm_state___5 *, int);
	int (*overflow)(struct xfrm_state___5 *, struct sk_buff___60 *);
};

struct xfrm_type___5 {
	char *description;
	struct module___165 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___5 *);
	void (*destructor)(struct xfrm_state___5 *);
	int (*input)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*output)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*reject)(struct xfrm_state___5 *, struct sk_buff___60 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___5 *, struct sk_buff___60 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___5 *, int);
};

struct xfrm_state_afinfo___5;

struct xfrm_mode___5 {
	int (*input2)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*input)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*output2)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*output)(struct xfrm_state___5 *, struct sk_buff___60 *);
	struct xfrm_state_afinfo___5 *afinfo;
	struct module___165 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___5 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___165 *owner;
	const struct xfrm_type___5 *type_map[256];
	struct xfrm_mode___5 *mode_map[5];
	int (*init_flags)(struct xfrm_state___5 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___5 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___5 **, struct xfrm_state___5 **, int);
	union {
		int (*output)(struct sock___47 *, struct sk_buff___60 *);
		struct {
			int (*output)(struct sk_buff___60 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___47 *, struct sk_buff___60 *);
		struct {
			int (*output_finish)(struct sk_buff___60 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*extract_output)(struct xfrm_state___5 *, struct sk_buff___60 *);
	int (*transport_finish)(struct sk_buff___60 *, int);
};

struct offload_callbacks___3 {
	struct sk_buff___24 * (*gso_segment)(struct sk_buff___24 *, netdev_features_t);
	struct sk_buff___24 ** (*gro_receive)(struct sk_buff___24 **, struct sk_buff___24 *);
	int (*gro_complete)(struct sk_buff___24 *, int);
};

struct net_protocol {
	void (*early_demux)(struct sk_buff___24 *);
	int (*handler)(struct sk_buff___24 *);
	void (*err_handler)(struct sk_buff___24 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct net_offload {
	struct offload_callbacks___3 callbacks;
	unsigned int flags;
};

struct page___267;

typedef struct page___267 *pgtable_t___267;

struct address_space___268;

struct kmem_cache___251;

struct page___267 {
	long unsigned int flags;
	struct address_space___268 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___267 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___267 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___251 *slab_cache;
		struct page___267 *first_page;
	};
	long: 64;
};

struct task_struct___269;

struct pv_cpu_ops___269 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___269 *);
	void (*end_context_switch)(struct task_struct___269 *);
};

struct mutex___270 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___269 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___262 {
	struct page___267 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___276;

struct nsproxy___148;

struct signal_struct___269;

struct css_set___163;

struct task_struct___269 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___269 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___276 *mm;
	struct mm_struct___276 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___269 *real_parent;
	struct task_struct___269 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___269 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___269 = 0,
		VTIME_USER___269 = 1,
		VTIME_SYS___269 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___148 *nsproxy;
	struct signal_struct___269 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___163 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___270 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___262 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___276 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___276 *, struct mm_struct___276 *);
	void (*dup_mmap)(struct mm_struct___276 *, struct mm_struct___276 *);
	void (*exit_mmap)(struct mm_struct___276 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___276 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___276 *);
	void (*pgd_free)(struct mm_struct___276 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___276 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___276 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___276 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___276 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___276 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___276 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___276 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___276 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___276 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___276 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___276 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___270 lock;
	void *vdso;
} mm_context_t___270;

struct xol_area___267;

struct uprobes_state___267 {
	struct xol_area___267 *xol_area;
};

struct vm_area_struct___276;

struct file___268;

struct core_state___269;

struct mm_struct___276 {
	struct vm_area_struct___276 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___276 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___276 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___270 context;
	long unsigned int flags;
	struct core_state___269 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___269 *owner;
	struct file___268 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___267 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___50;

struct kobj_type___50;

struct kobject___50 {
	const char *name;
	struct list_head entry;
	struct kobject___50 *parent;
	struct kset___50 *kset;
	struct kobj_type___50 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___166;

struct module_kobject___165 {
	struct kobject___50 kobj;
	struct module___166 *mod;
	struct kobject___50 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___165;

struct module___166 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___165 mkobj;
	struct module_attribute___165 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___50 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___269 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___269;

struct lruvec___269 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___269 *zone;
};

struct pglist_data___269;

struct zone___269 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___269 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___269 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___269 {
	struct zone___269 *zone;
	int zone_idx;
};

struct zonelist___269 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___269 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___269 {
	struct zone___269 node_zones[4];
	struct zonelist___269 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___269 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___192;

struct x86_io_apic_ops___192 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___192 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___192;

struct irq_data___192 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___192 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___266;

struct dev_pm_ops___266 {
	int (*prepare)(struct device___266 *);
	void (*complete)(struct device___266 *);
	int (*suspend)(struct device___266 *);
	int (*resume)(struct device___266 *);
	int (*freeze)(struct device___266 *);
	int (*thaw)(struct device___266 *);
	int (*poweroff)(struct device___266 *);
	int (*restore)(struct device___266 *);
	int (*suspend_late)(struct device___266 *);
	int (*resume_early)(struct device___266 *);
	int (*freeze_late)(struct device___266 *);
	int (*thaw_early)(struct device___266 *);
	int (*poweroff_late)(struct device___266 *);
	int (*restore_early)(struct device___266 *);
	int (*suspend_noirq)(struct device___266 *);
	int (*resume_noirq)(struct device___266 *);
	int (*freeze_noirq)(struct device___266 *);
	int (*thaw_noirq)(struct device___266 *);
	int (*poweroff_noirq)(struct device___266 *);
	int (*restore_noirq)(struct device___266 *);
	int (*runtime_suspend)(struct device___266 *);
	int (*runtime_resume)(struct device___266 *);
	int (*runtime_idle)(struct device___266 *);
};

struct dev_pm_qos___69;

struct dev_pm_info___69 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___69 *qos;
};

struct dma_map_ops___131;

struct dev_archdata___131 {
	struct dma_map_ops___131 *dma_ops;
	void *iommu;
};

struct device_type___266;

struct bus_type___266;

struct device_driver___266;

struct dev_pm_domain___266;

struct class___266;

struct attribute_group___228;

struct device_rh___266;

struct device___266 {
	struct device___266 *parent;
	struct device_private *p;
	struct kobject___50 kobj;
	const char *init_name;
	const struct device_type___266 *type;
	struct mutex___270 mutex;
	struct bus_type___266 *bus;
	struct device_driver___266 *driver;
	void *platform_data;
	struct dev_pm_info___69 power;
	struct dev_pm_domain___266 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___131 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___266 *class;
	const struct attribute_group___228 **groups;
	void (*release)(struct device___266 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___266 *device_rh;
};

struct dev_pm_qos_request___70;

struct dev_pm_qos___69 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___70 *latency_req;
	struct dev_pm_qos_request___70 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___70 *latency_tolerance_req;
};

struct dev_pm_info_rh___266 {
	void (*set_latency_tolerance)(struct device___266 *, s32);
};

struct dev_pm_domain___266 {
	struct dev_pm_ops___266 ops;
};

struct smp_ops___269 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___269 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___73;

struct ctl_node___73 {
	struct rb_node node;
	struct ctl_table_header___73 *header;
};

struct ctl_table_root___73;

struct ctl_table_set___73;

struct ctl_dir___73;

struct ctl_table_header___73 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___73 *root;
	struct ctl_table_set___73 *set;
	struct ctl_dir___73 *parent;
	struct ctl_node___73 *node;
};

struct ctl_dir___73 {
	struct ctl_table_header___73 header;
	struct rb_root root;
};

struct ctl_table_set___73 {
	int (*is_seen)(struct ctl_table_set___73 *);
	struct ctl_dir___73 dir;
};

struct ctl_table_root___73 {
	struct ctl_table_set___73 default_set;
	struct ctl_table_set___73 * (*lookup)(struct ctl_table_root___73 *, struct nsproxy___148 *);
	int (*permissions)(struct ctl_table_header___73 *, struct ctl_table *);
};

struct net___72;

struct nsproxy___148 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___72 *net_ns;
};

struct sock___48;

struct kobj_ns_type_operations___47 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___48 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___47;

struct sock_common___47 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___47 *skc_prot;
	struct net___72 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___61;

struct sk_buff_head___59 {
	struct sk_buff___61 *next;
	struct sk_buff___61 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___48;

struct socket_wq___47;

struct xfrm_policy___6;

struct dst_entry___48;

struct socket___48;

struct cg_proto___47;

struct sock___48 {
	struct sock_common___47 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___59 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___61 *head;
		struct sk_buff___61 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___48 *sk_filter;
	struct socket_wq___47 *sk_wq;
	struct sk_buff_head___59 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___6 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___48 *sk_rx_dst;
	struct dst_entry___48 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___59 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___59 sk_error_queue;
	struct proto___47 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___48 *sk_socket;
	void *sk_user_data;
	struct page_frag___262 sk_frag;
	struct sk_buff___61 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___47 *sk_cgrp;
	void (*sk_state_change)(struct sock___48 *);
	void (*sk_data_ready)(struct sock___48 *, int);
	void (*sk_write_space)(struct sock___48 *);
	void (*sk_error_report)(struct sock___48 *);
	int (*sk_backlog_rcv)(struct sock___48 *, struct sk_buff___61 *);
	void (*sk_destruct)(struct sock___48 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___230;

struct attribute_group___228 {
	const char *name;
	umode_t (*is_visible)(struct kobject___50 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___230 **bin_attrs;
};

struct bin_attribute___230 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___268 *, struct kobject___50 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___268 *, struct kobject___50 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	int (*mmap)(struct file___268 *, struct kobject___50 *, struct bin_attribute___230 *, struct vm_area_struct___276 *);
};

struct dentry___268;

struct path___268 {
	struct vfsmount *mnt;
	struct dentry___268 *dentry;
};

struct inode___268;

struct file_operations___268;

struct file___268 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___268 f_path;
	struct inode___268 *f_inode;
	const struct file_operations___268 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___268 *f_mapping;
	struct mutex___270 f_pos_lock;
};

struct vm_operations_struct___242;

struct vm_area_struct___276 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___276 *vm_next;
	struct vm_area_struct___276 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___276 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___242 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___268 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___50 {
	ssize_t (*show)(struct kobject___50 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___50 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___50 *, const struct attribute *);
};

struct kset_uevent_ops___50;

struct kset___50 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___50 kobj;
	const struct kset_uevent_ops___50 *uevent_ops;
};

struct kobj_type___50 {
	void (*release)(struct kobject___50 *);
	const struct sysfs_ops___50 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___47 * (*child_ns_type)(struct kobject___50 *);
	const void * (*namespace)(struct kobject___50 *);
};

struct kset_uevent_ops___50 {
	int (* const filter)(struct kset___50 *, struct kobject___50 *);
	const char * (* const name)(struct kset___50 *, struct kobject___50 *);
	int (* const uevent)(struct kset___50 *, struct kobject___50 *, struct kobj_uevent_env *);
};

struct module_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___165 *, struct module_kobject___165 *, char *);
	ssize_t (*store)(struct module_attribute___165 *, struct module_kobject___165 *, const char *, size_t);
	void (*setup)(struct module___166 *, const char *);
	int (*test)(struct module___166 *);
	void (*free)(struct module___166 *);
};

struct kmem_cache_cpu___250 {
	void **freelist;
	long unsigned int tid;
	struct page___267 *page;
	struct page___267 *partial;
};

struct memcg_cache_params___251;

struct kmem_cache___251 {
	struct kmem_cache_cpu___250 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___50 kobj;
	struct memcg_cache_params___251 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___251 {
	bool is_root_cache;
	union {
		struct kmem_cache___251 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___251 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct xol_area___267 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___267 *page;
	long unsigned int vaddr;
};

struct address_space_operations___268;

struct address_space___268 {
	struct inode___268 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___270 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___268 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___238;

struct vm_operations_struct___242 {
	void (*open)(struct vm_area_struct___276 *);
	void (*close)(struct vm_area_struct___276 *);
	int (*fault)(struct vm_area_struct___276 *, struct vm_fault___238 *);
	int (*page_mkwrite)(struct vm_area_struct___276 *, struct vm_fault___238 *);
	int (*access)(struct vm_area_struct___276 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___276 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___276 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___276 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___276 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___269 {
	struct task_struct___269 *task;
	struct core_thread___269 *next;
};

struct core_state___269 {
	atomic_t nr_threads;
	struct core_thread___269 dumper;
	struct completion startup;
};

struct fasync_struct___268;

struct socket_wq___47 {
	wait_queue_head_t wait;
	struct fasync_struct___268 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___268 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___268 *fa_next;
	struct file___268 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___47;

struct socket___48 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___47 *wq;
	struct file___268 *file;
	struct sock___48 *sk;
	const struct proto_ops___47 *ops;
};

struct poll_table_struct___154;

struct kiocb___55;

struct proto_ops___47 {
	int family;
	struct module___166 *owner;
	int (*release)(struct socket___48 *);
	int (*bind)(struct socket___48 *, struct sockaddr *, int);
	int (*connect)(struct socket___48 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___48 *, struct socket___48 *);
	int (*accept)(struct socket___48 *, struct socket___48 *, int);
	int (*getname)(struct socket___48 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___268 *, struct socket___48 *, struct poll_table_struct___154 *);
	int (*ioctl)(struct socket___48 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___48 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___48 *, int);
	int (*shutdown)(struct socket___48 *, int);
	int (*setsockopt)(struct socket___48 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___48 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___48 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___48 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___55 *, struct socket___48 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___55 *, struct socket___48 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___268 *, struct socket___48 *, struct vm_area_struct___276 *);
	ssize_t (*sendpage)(struct socket___48 *, struct page___267 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___48 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___48 *, int);
		struct {
			void (*set_peek_off)(struct sock___48 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___156)(struct file___268 *, wait_queue_head_t *, struct poll_table_struct___154 *);

struct poll_table_struct___154 {
	poll_queue_proc___156 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___55(struct kiocb___55 *, struct io_event *);

struct kiocb___55 {
	atomic_t ki_users;
	struct file___268 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___55 *ki_cancel;
	void (*ki_dtor)(struct kiocb___55 *);
	union {
		void *user;
		struct task_struct___269 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___70 {
	struct ctl_table_header___73 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___71 {
	struct mutex___270 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___70 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___73 *ctl;
};

struct netns_ipv4___70 {
	struct ctl_table_header___73 *forw_hdr;
	struct ctl_table_header___73 *frags_hdr;
	struct ctl_table_header___73 *ipv4_hdr;
	struct ctl_table_header___73 *route_hdr;
	struct ctl_table_header___73 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___48 *fibnl;
	struct sock___48 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___70 {
	struct ctl_table_header___73 *hdr;
	struct ctl_table_header___73 *route_hdr;
	struct ctl_table_header___73 *icmp_hdr;
	struct ctl_table_header___73 *frags_hdr;
	struct ctl_table_header___73 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___58;

struct neighbour___48;

struct dst_ops___72 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___72 *);
	struct dst_entry___48 * (*check)(struct dst_entry___48 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___48 *);
	unsigned int (*mtu)(const struct dst_entry___48 *);
	u32 * (*cow_metrics)(struct dst_entry___48 *, long unsigned int);
	void (*destroy)(struct dst_entry___48 *);
	void (*ifdown)(struct dst_entry___48 *, struct net_device___58 *, int);
	struct dst_entry___48 * (*negative_advice)(struct dst_entry___48 *);
	void (*link_failure)(struct sk_buff___61 *);
	void (*update_pmtu)(struct dst_entry___48 *, struct sock___48 *, struct sk_buff___61 *, u32);
	void (*redirect)(struct dst_entry___48 *, struct sock___48 *, struct sk_buff___61 *);
	int (*local_out)(struct sk_buff___61 *);
	struct neighbour___48 * (*neigh_lookup)(const struct dst_entry___48 *, struct sk_buff___61 *, const void *);
	struct kmem_cache___251 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___6;

struct fib6_table___6;

struct netns_ipv6___72 {
	struct netns_sysctl_ipv6___70 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___6 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___6 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___72 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___6 *ip6_prohibit_entry;
	struct rt6_info___6 *ip6_blk_hole_entry;
	struct fib6_table___6 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___48 **icmp_sk;
	struct sock___48 *ndisc_sk;
	struct sock___48 *tcp_sk;
	struct sock___48 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___70 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___73 *sysctl_header;
	struct sock___48 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___47 {
	struct sock___48 *v4_ctl_sk;
	struct sock___48 *v6_ctl_sk;
};

struct netns_nf___70 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___73 *nf_log_dir_header;
};

struct nf_proto_net___70 {
	struct ctl_table_header___73 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___70 {
	struct nf_proto_net___70 pn;
	unsigned int timeout;
};

struct nf_tcp_net___70 {
	struct nf_proto_net___70 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___70 {
	struct nf_proto_net___70 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___70 {
	struct nf_proto_net___70 pn;
	unsigned int timeout;
};

struct nf_ip_net___70 {
	struct nf_generic_net___70 generic;
	struct nf_tcp_net___70 tcp;
	struct nf_udp_net___70 udp;
	struct nf_icmp_net___70 icmp;
	struct nf_icmp_net___70 icmpv6;
};

struct netns_ct___71 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___73 *sysctl_header;
	struct ctl_table_header___73 *acct_sysctl_header;
	struct ctl_table_header___73 *tstamp_sysctl_header;
	struct ctl_table_header___73 *event_sysctl_header;
	struct ctl_table_header___73 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___251 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___70 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___70 {
	struct netns_sysctl_ipv6___70 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___72 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___48 *nlsk;
	struct sock___48 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___73 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___72 xfrm4_dst_ops;
	struct dst_ops___72 xfrm6_dst_ops;
};

struct net___72 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___73 sysctls;
	struct sock___48 *rtnl;
	struct sock___48 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___58 *loopback_dev;
	struct netns_core___70 core;
	struct netns_mib mib;
	struct netns_packet___71 packet;
	struct netns_unix___70 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___70 ipv4;
	struct netns_ipv6___72 ipv6;
	struct netns_sctp___70 sctp;
	struct netns_dccp___47 dccp;
	struct netns_nf___70 nf;
	struct netns_xt xt;
	struct netns_ct___71 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___70 nf_frag;
	struct sock___48 *nfnl;
	struct sock___48 *nfnl_stash;
	struct sk_buff_head___59 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___72 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___48 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___48 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___270 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___270 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___268;

struct seq_file___193;

struct file_operations___268 {
	struct module___166 *owner;
	loff_t (*llseek)(struct file___268 *, loff_t, int);
	ssize_t (*read)(struct file___268 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___268 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___55 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___55 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___268 *, void *, filldir_t);
	unsigned int (*poll)(struct file___268 *, struct poll_table_struct___154 *);
	long int (*unlocked_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___268 *, struct vm_area_struct___276 *);
	int (*open)(struct inode___268 *, struct file___268 *);
	int (*flush)(struct file___268 *, fl_owner_t);
	int (*release)(struct inode___268 *, struct file___268 *);
	int (*fsync)(struct file___268 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___55 *, int);
	int (*fasync)(int, struct file___268 *, int);
	int (*lock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*sendpage)(struct file___268 *, struct page___267 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___268 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___268 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___268 *, long int, struct file_lock___268 **, void **);
		struct {
			int (*setlease)(struct file___268 *, long int, struct file_lock___268 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___268 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___193 *, struct file___268 *);
};

struct dma_map_ops___131 {
	void * (*alloc)(struct device___266 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___266 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___266 *, struct vm_area_struct___276 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___266 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___266 *, struct page___267 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___266 *, dma_addr_t);
	int (*dma_supported)(struct device___266 *, u64);
	int (*set_dma_mask)(struct device___266 *, u64);
	int is_phys;
};

struct bus_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___266 *, char *);
	ssize_t (*store)(struct bus_type___266 *, const char *, size_t);
};

struct device_attribute___266;

struct driver_attribute___266;

struct bus_type___266 {
	const char *name;
	const char *dev_name;
	struct device___266 *dev_root;
	struct bus_attribute___266 *bus_attrs;
	struct device_attribute___266 *dev_attrs;
	struct driver_attribute___266 *drv_attrs;
	const struct attribute_group___228 **bus_groups;
	const struct attribute_group___228 **dev_groups;
	const struct attribute_group___228 **drv_groups;
	int (*match)(struct device___266 *, struct device_driver___266 *);
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	int (*probe)(struct device___266 *);
	int (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*online)(struct device___266 *);
	int (*offline)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct device___266 *, struct device_attribute___266 *, char *);
	ssize_t (*store)(struct device___266 *, struct device_attribute___266 *, const char *, size_t);
};

struct driver_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___266 *, char *);
	ssize_t (*store)(struct device_driver___266 *, const char *, size_t);
};

struct device_driver___266 {
	const char *name;
	struct bus_type___266 *bus;
	struct module___166 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___266 *);
	int (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	const struct attribute_group___228 **groups;
	const struct dev_pm_ops___266 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___266 {
	const char *name;
	const struct attribute_group___228 **groups;
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
};

struct class_attribute___266;

struct class___266 {
	const char *name;
	struct module___166 *owner;
	struct class_attribute___266 *class_attrs;
	struct device_attribute___266 *dev_attrs;
	const struct attribute_group___228 **dev_groups;
	struct bin_attribute___230 *dev_bin_attrs;
	struct kobject___50 *dev_kobj;
	int (*dev_uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *);
	void (*class_release)(struct class___266 *);
	void (*dev_release)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	const struct kobj_ns_type_operations___47 *ns_type;
	const void * (*namespace)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
	struct subsys_private *p;
};

struct class_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct class___266 *, struct class_attribute___266 *, char *);
	ssize_t (*store)(struct class___266 *, struct class_attribute___266 *, const char *, size_t);
	const void * (*namespace)(struct class___266 *, const struct class_attribute___266 *);
};

struct device_rh___266 {
	struct dev_pm_info_rh___266 power;
};

struct dev_pm_qos_request___70 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___266 *dev;
};

struct vm_fault___238 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___267 *page;
};

struct dentry_operations___268;

struct super_block___268;

struct dentry___268 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___268 *d_parent;
	struct qstr d_name;
	struct inode___268 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___268 *d_op;
	struct super_block___268 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___268;

struct dquot___268;

struct block_device___268;

struct inode___268 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___268 *i_op;
	struct super_block___268 *i_sb;
	struct address_space___268 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___270 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___268 *i_fop;
	struct file_lock___268 *i_flock;
	struct address_space___268 i_data;
	struct dquot___268 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___268 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___268 {
	int (*d_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_hash)(const struct dentry___268 *, struct qstr *);
	int (*d_compare)(const struct dentry___268 *, const struct dentry___268 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___268 *);
	void (*d_release)(struct dentry___268 *);
	void (*d_prune)(struct dentry___268 *);
	void (*d_iput)(struct dentry___268 *, struct inode___268 *);
	char * (*d_dname)(struct dentry___268 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___268 *);
	int (*d_manage)(struct dentry___268 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___268;

struct mem_dqinfo___268 {
	struct quota_format_type___268 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___268;

struct quota_info___268 {
	unsigned int flags;
	struct mutex___270 dqio_mutex;
	struct mutex___270 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___268 *files[2];
	struct mem_dqinfo___268 info[2];
	const struct quota_format_ops___268 *ops[2];
};

struct file_system_type___268;

struct super_operations___268;

struct dquot_operations___268;

struct quotactl_ops___268;

struct xattr_handler___164;

struct super_block___268 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___268 *s_type;
	const struct super_operations___268 *s_op;
	const struct dquot_operations___268 *dq_op;
	const struct quotactl_ops___268 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___268 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___164 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___268 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___268 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___270 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___268 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___268 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___268 *bd_inode;
	struct super_block___268 *bd_super;
	struct mutex___270 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___268 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___270 bd_fsfreeze_mutex;
};

struct cgroup___163;

struct cgroup_subsys_state___163 {
	struct cgroup___163 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___268 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___268 *ia_file;
};

struct dquot___268 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___270 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___268 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___268 {
	int qf_fmt_id;
	const struct quota_format_ops___268 *qf_ops;
	struct module___166 *qf_owner;
	struct quota_format_type___268 *qf_next;
};

struct quota_format_ops___268 {
	int (*check_quota_file)(struct super_block___268 *, int);
	int (*read_file_info)(struct super_block___268 *, int);
	int (*write_file_info)(struct super_block___268 *, int);
	int (*free_file_info)(struct super_block___268 *, int);
	int (*read_dqblk)(struct dquot___268 *);
	int (*commit_dqblk)(struct dquot___268 *);
	int (*release_dqblk)(struct dquot___268 *);
};

struct dquot_operations___268 {
	int (*write_dquot)(struct dquot___268 *);
	struct dquot___268 * (*alloc_dquot)(struct super_block___268 *, int);
	void (*destroy_dquot)(struct dquot___268 *);
	int (*acquire_dquot)(struct dquot___268 *);
	int (*release_dquot)(struct dquot___268 *);
	int (*mark_dirty)(struct dquot___268 *);
	int (*write_info)(struct super_block___268 *, int);
	qsize_t * (*get_reserved_space)(struct inode___268 *);
};

struct quotactl_ops___268 {
	int (*quota_on)(struct super_block___268 *, int, int, struct path___268 *);
	int (*quota_on_meta)(struct super_block___268 *, int, int);
	int (*quota_off)(struct super_block___268 *, int);
	int (*quota_sync)(struct super_block___268 *, int);
	int (*get_info)(struct super_block___268 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___268 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___268 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___268 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___268 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___268 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___268 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___268 *, unsigned int);
};

struct address_space_operations___268 {
	int (*writepage)(struct page___267 *, struct writeback_control *);
	int (*readpage)(struct file___268 *, struct page___267 *);
	int (*writepages)(struct address_space___268 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___267 *);
	int (*readpages)(struct file___268 *, struct address_space___268 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___268 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___267 **, void **);
	int (*write_end)(struct file___268 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___267 *, void *);
	sector_t (*bmap)(struct address_space___268 *, sector_t);
	void (*invalidatepage)(struct page___267 *, long unsigned int);
	int (*releasepage)(struct page___267 *, gfp_t);
	void (*freepage)(struct page___267 *);
	ssize_t (*direct_IO)(int, struct kiocb___55 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___268 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___268 *, struct page___267 *, struct page___267 *, enum migrate_mode);
	int (*launder_page)(struct page___267 *);
	int (*is_partially_uptodate)(struct page___267 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___267 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___268 *, struct page___267 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___268 *, sector_t *);
	void (*swap_deactivate)(struct file___268 *);
	void (*invalidatepage_range)(struct page___267 *, unsigned int, unsigned int);
};

struct inode_operations___268 {
	struct dentry___268 * (*lookup)(struct inode___268 *, struct dentry___268 *, unsigned int);
	void * (*follow_link)(struct dentry___268 *, struct nameidata *);
	int (*permission)(struct inode___268 *, int);
	struct posix_acl * (*get_acl)(struct inode___268 *, int);
	int (*readlink)(struct dentry___268 *, char *, int);
	void (*put_link)(struct dentry___268 *, struct nameidata *, void *);
	int (*create)(struct inode___268 *, struct dentry___268 *, umode_t, bool);
	int (*link)(struct dentry___268 *, struct inode___268 *, struct dentry___268 *);
	int (*unlink)(struct inode___268 *, struct dentry___268 *);
	int (*symlink)(struct inode___268 *, struct dentry___268 *, const char *);
	int (*mkdir)(struct inode___268 *, struct dentry___268 *, umode_t);
	int (*rmdir)(struct inode___268 *, struct dentry___268 *);
	int (*mknod)(struct inode___268 *, struct dentry___268 *, umode_t, dev_t);
	int (*rename)(struct inode___268 *, struct dentry___268 *, struct inode___268 *, struct dentry___268 *);
	int (*setattr)(struct dentry___268 *, struct iattr___268 *);
	int (*getattr)(struct vfsmount *, struct dentry___268 *, struct kstat *);
	int (*setxattr)(struct dentry___268 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___268 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___268 *, char *, size_t);
	int (*removexattr)(struct dentry___268 *, const char *);
	int (*fiemap)(struct inode___268 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___268 *, struct timespec *, int);
	int (*atomic_open)(struct inode___268 *, struct dentry___268 *, struct file___268 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___268;

struct lock_manager_operations___268;

struct file_lock___268 {
	struct file_lock___268 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___268 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___268 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___268 *fl_ops;
	const struct lock_manager_operations___268 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___268 {
	void (*fl_copy_lock)(struct file_lock___268 *, struct file_lock___268 *);
	void (*fl_release_private)(struct file_lock___268 *);
};

struct lock_manager_operations___268 {
	int (*lm_compare_owner)(struct file_lock___268 *, struct file_lock___268 *);
	long unsigned int (*lm_owner_key)(struct file_lock___268 *);
	void (*lm_notify)(struct file_lock___268 *);
	int (*lm_grant)(struct file_lock___268 *, struct file_lock___268 *, int);
	void (*lm_break)(struct file_lock___268 *);
	int (*lm_change)(struct file_lock___268 **, int);
};

struct file_system_type___268 {
	const char *name;
	int fs_flags;
	struct dentry___268 * (*mount)(struct file_system_type___268 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___268 *);
	struct module___166 *owner;
	struct file_system_type___268 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___268 {
	struct inode___268 * (*alloc_inode)(struct super_block___268 *);
	void (*destroy_inode)(struct inode___268 *);
	void (*dirty_inode)(struct inode___268 *, int);
	int (*write_inode)(struct inode___268 *, struct writeback_control *);
	int (*drop_inode)(struct inode___268 *);
	void (*evict_inode)(struct inode___268 *);
	void (*put_super)(struct super_block___268 *);
	int (*sync_fs)(struct super_block___268 *, int);
	int (*freeze_fs)(struct super_block___268 *);
	int (*unfreeze_fs)(struct super_block___268 *);
	int (*statfs)(struct dentry___268 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___268 *, int *, char *);
	void (*umount_begin)(struct super_block___268 *);
	int (*show_options)(struct seq_file___193 *, struct dentry___268 *);
	int (*show_devname)(struct seq_file___193 *, struct dentry___268 *);
	int (*show_path)(struct seq_file___193 *, struct dentry___268 *);
	int (*show_stats)(struct seq_file___193 *, struct dentry___268 *);
	ssize_t (*quota_read)(struct super_block___268 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___268 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___268 *);
	int (*bdev_try_to_free_page)(struct super_block___268 *, struct page___267 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___268 *);
	void (*free_cached_objects)(struct super_block___268 *, int);
};

struct xattr_handler___164 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___268 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___268 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___268 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___193;

struct seq_file___193 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___270 lock;
	const struct seq_operations___193 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___269 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___269 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___269 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___270 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___163 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___163 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___58 {
	atomic_t use;
	unsigned int mask;
	struct net_device___58 *physindev;
	struct net_device___58 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___58(struct sk_buff___61 **);

struct net_device_ops___58;

struct ethtool_ops___58;

struct header_ops___58;

struct in_device___7;

struct inet6_dev___24;

struct netdev_rx_queue___58;

struct netdev_queue___58;

struct rtnl_link_ops___49;

struct dcbnl_rtnl_ops___58;

struct net_device___58 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___58 *netdev_ops;
	const struct ethtool_ops___58 *ethtool_ops;
	const struct header_ops___58 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___50 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___7 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___24 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___58 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___58 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___58 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___58 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___58 = 0,
		NETREG_REGISTERED___58 = 1,
		NETREG_UNREGISTERING___58 = 2,
		NETREG_UNREGISTERED___58 = 3,
		NETREG_RELEASED___58 = 4,
		NETREG_DUMMY___58 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___58 = 0,
		RTNL_LINK_INITIALIZING___58 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___58 *);
	struct netpoll_info *npinfo;
	struct net___72 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___266 dev;
	const struct attribute_group___228 *sysfs_groups[4];
	const struct rtnl_link_ops___49 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___58 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___6;

struct sk_buff___61 {
	struct sk_buff___61 *next;
	struct sk_buff___61 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___48 *sk;
	struct net_device___58 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___6 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___61 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___58 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___11 {
	struct {
		struct page___267 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___11 skb_frag_t___11;

struct skb_shared_info___11 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___61 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___11 frags[17];
};

struct xfrm_state___6;

struct sec_path___6 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___6 *xvec[6];
};

struct ethtool_ops___58 {
	int (*get_settings)(struct net_device___58 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___58 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___58 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___58 *);
	void (*get_regs)(struct net_device___58 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___58 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___58 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___58 *);
	void (*set_msglevel)(struct net_device___58 *, u32);
	int (*nway_reset)(struct net_device___58 *);
	u32 (*get_link)(struct net_device___58 *);
	int (*get_eeprom_len)(struct net_device___58 *);
	int (*get_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___58 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___58 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___58 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___58 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___58 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___58 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___58 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___58 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___58 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___58 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___58 *);
	void (*complete)(struct net_device___58 *);
	u32 (*get_priv_flags)(struct net_device___58 *);
	int (*set_priv_flags)(struct net_device___58 *, u32);
	int (*get_sset_count)(struct net_device___58 *, int);
	int (*get_rxnfc)(struct net_device___58 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___58 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___58 *, struct ethtool_flash *);
	int (*reset)(struct net_device___58 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___58 *);
	int (*get_rxfh_indir)(struct net_device___58 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___58 *, const u32 *);
	void (*get_channels)(struct net_device___58 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___58 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___58 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___58 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___58 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___58 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___58 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___58 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___58 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___58 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___58 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___58 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___19;

struct dst_entry___48 {
	struct callback_head callback_head;
	struct dst_entry___48 *child;
	struct net_device___58 *dev;
	struct dst_ops___72 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___48 *path;
	struct dst_entry___48 *from;
	struct xfrm_state___6 *xfrm;
	int (*input)(struct sk_buff___61 *);
	union {
		int (*output)(struct sock___48 *, struct sk_buff___61 *);
		struct {
			int (*output)(struct sk_buff___61 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___48 *next;
		struct rtable___19 *rt_next;
		struct rt6_info___6 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___48;

struct neigh_parms___48;

struct neigh_ops___48;

struct neighbour___48 {
	struct neighbour___48 *next;
	struct neigh_table___48 *tbl;
	struct neigh_parms___48 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___59 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___48 *, struct sk_buff___61 *);
	const struct neigh_ops___48 *ops;
	struct callback_head rcu;
	struct net_device___58 *dev;
	u8 primary_key[0];
};

struct fib6_node___6;

struct rt6_info___6 {
	struct dst_entry___48 dst;
	struct fib6_table___6 *rt6i_table;
	struct fib6_node___6 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___24 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___6 {
	struct fib6_node___6 *parent;
	struct fib6_node___6 *left;
	struct fib6_node___6 *right;
	struct rt6_info___6 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___6 *rr_ptr;
};

struct fib6_table___6 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___6 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___6 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___58 *in;
	struct net_device___58 *out;
	struct sock___48 *sk;
	int (*okfn)(struct sock___48 *, struct sk_buff___61 *);
};

struct nf_afinfo___72 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___61 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___61 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___72 *, struct dst_entry___48 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___61 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___61 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___192 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___192 *);
	void (*irq_shutdown)(struct irq_data___192 *);
	void (*irq_enable)(struct irq_data___192 *);
	void (*irq_disable)(struct irq_data___192 *);
	void (*irq_ack)(struct irq_data___192 *);
	void (*irq_mask)(struct irq_data___192 *);
	void (*irq_mask_ack)(struct irq_data___192 *);
	void (*irq_unmask)(struct irq_data___192 *);
	void (*irq_eoi)(struct irq_data___192 *);
	int (*irq_set_affinity)(struct irq_data___192 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___192 *);
	int (*irq_set_type)(struct irq_data___192 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___192 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___192 *);
	void (*irq_bus_sync_unlock)(struct irq_data___192 *);
	void (*irq_cpu_online)(struct irq_data___192 *);
	void (*irq_cpu_offline)(struct irq_data___192 *);
	void (*irq_suspend)(struct irq_data___192 *);
	void (*irq_resume)(struct irq_data___192 *);
	void (*irq_pm_shutdown)(struct irq_data___192 *);
	void (*irq_print_chip)(struct irq_data___192 *, struct seq_file___193 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___192 *, void *);
	long unsigned int flags;
};

struct seq_operations___193 {
	void * (*start)(struct seq_file___193 *, loff_t *);
	void (*stop)(struct seq_file___193 *, void *);
	void * (*next)(struct seq_file___193 *, void *, loff_t *);
	int (*show)(struct seq_file___193 *, void *);
};

struct dcbnl_rtnl_ops___58 {
	int (*ieee_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___58 *);
	u8 (*setstate)(struct net_device___58 *, u8);
	void (*getpermhwaddr)(struct net_device___58 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___58 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___58 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___58 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___58 *, int, u8 *);
	void (*setpfccfg)(struct net_device___58 *, int, u8);
	void (*getpfccfg)(struct net_device___58 *, int, u8 *);
	u8 (*setall)(struct net_device___58 *);
	u8 (*getcap)(struct net_device___58 *, int, u8 *);
	int (*getnumtcs)(struct net_device___58 *, int, u8 *);
	int (*setnumtcs)(struct net_device___58 *, int, u8);
	u8 (*getpfcstate)(struct net_device___58 *);
	void (*setpfcstate)(struct net_device___58 *, u8);
	void (*getbcncfg)(struct net_device___58 *, int, u32 *);
	void (*setbcncfg)(struct net_device___58 *, int, u32);
	void (*getbcnrp)(struct net_device___58 *, int, u8 *);
	void (*setbcnrp)(struct net_device___58 *, int, u8);
	u8 (*setapp)(struct net_device___58 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___58 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___58 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___58 *, int, u8);
	u8 (*getdcbx)(struct net_device___58 *);
	u8 (*setdcbx)(struct net_device___58 *, u8);
	int (*peer_getappinfo)(struct net_device___58 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___58 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___58 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___58 *, struct cee_pfc *);
};

struct cgroupfs_root___163;

struct cgroup___163 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___163 *parent;
	struct dentry___268 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___163 *subsys[11];
	struct cgroupfs_root___163 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___270 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___163 {
	struct super_block___268 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___163 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___99 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___268 *, struct file___268 *);
	ssize_t (*read)(struct cgroup___163 *, struct cftype___99 *, struct file___268 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___163 *, struct cftype___99 *);
	s64 (*read_s64)(struct cgroup___163 *, struct cftype___99 *);
	int (*read_map)(struct cgroup___163 *, struct cftype___99 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___163 *, struct cftype___99 *, struct seq_file___193 *);
	ssize_t (*write)(struct cgroup___163 *, struct cftype___99 *, struct file___268 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___163 *, struct cftype___99 *, u64);
	int (*write_s64)(struct cgroup___163 *, struct cftype___99 *, s64);
	int (*write_string)(struct cgroup___163 *, struct cftype___99 *, const char *);
	int (*trigger)(struct cgroup___163 *, unsigned int);
	int (*release)(struct inode___268 *, struct file___268 *);
	int (*register_event)(struct cgroup___163 *, struct cftype___99 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___163 *, struct cftype___99 *, struct eventfd_ctx *);
};

struct cftype_set___95 {
	struct list_head node;
	struct cftype___99 *cfts;
};

struct task_and_cgroup___95 {
	struct task_struct___269 *task;
	struct cgroup___163 *cgrp;
	struct css_set___163 *cg;
};

struct cgroup_taskset___95 {
	struct task_and_cgroup___95 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___163 *cur_cgrp;
};

struct cgroup_subsys___95 {
	struct cgroup_subsys_state___163 * (*css_alloc)(struct cgroup___163 *);
	int (*css_online)(struct cgroup___163 *);
	void (*css_offline)(struct cgroup___163 *);
	void (*css_free)(struct cgroup___163 *);
	int (*can_attach)(struct cgroup___163 *, struct cgroup_taskset___95 *);
	void (*cancel_attach)(struct cgroup___163 *, struct cgroup_taskset___95 *);
	void (*attach)(struct cgroup___163 *, struct cgroup_taskset___95 *);
	void (*fork)(struct task_struct___269 *);
	void (*exit)(struct cgroup___163 *, struct cgroup___163 *, struct task_struct___269 *);
	void (*bind)(struct cgroup___163 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___163 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___99 *base_cftypes;
	struct cftype_set___95 base_cftset;
	struct module___166 *module;
};

struct request_sock_ops___33;

struct request_sock___34 {
	struct sock_common___47 __req_common;
	struct request_sock___34 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___33 *rsk_ops;
	struct sock___48 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___6;

struct xfrm_type___6;

struct xfrm_mode___6;

struct xfrm_state___6 {
	struct net___72 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___6 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___6 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___6 *type;
	struct xfrm_mode___6 *inner_mode;
	struct xfrm_mode___6 *inner_mode_iaf;
	struct xfrm_mode___6 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___6 {
	struct sk_buff_head___59 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___6 {
	struct net___72 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___6 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___60 {
	struct sk_buff___61 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___61 *, struct netlink_callback___60 *);
	int (*done)(struct netlink_callback___60 *);
	void *data;
	struct module___166 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___58 {
	int (*create)(struct sk_buff___61 *, struct net_device___58 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___61 *, unsigned char *);
	int (*rebuild)(struct sk_buff___61 *);
	int (*cache)(const struct neighbour___48 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___58 *, const unsigned char *);
};

struct napi_struct___58 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___58 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___58 *dev;
	struct sk_buff___61 *gro_list;
	struct sk_buff___61 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___58 {
	struct net_device___58 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___50 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___58 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___50 kobj;
	struct net_device___58 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___58 {
	int (*ndo_init)(struct net_device___58 *);
	void (*ndo_uninit)(struct net_device___58 *);
	int (*ndo_open)(struct net_device___58 *);
	int (*ndo_stop)(struct net_device___58 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___61 *, struct net_device___58 *);
	u16 (*ndo_select_queue)(struct net_device___58 *, struct sk_buff___61 *);
	void (*ndo_change_rx_flags)(struct net_device___58 *, int);
	void (*ndo_set_rx_mode)(struct net_device___58 *);
	int (*ndo_set_mac_address)(struct net_device___58 *, void *);
	int (*ndo_validate_addr)(struct net_device___58 *);
	int (*ndo_do_ioctl)(struct net_device___58 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___58 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___58 *, int);
	int (*ndo_neigh_setup)(struct net_device___58 *, struct neigh_parms___48 *);
	void (*ndo_tx_timeout)(struct net_device___58 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___58 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___58 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___58 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___58 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___58 *);
	int (*ndo_netpoll_setup)(struct net_device___58 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___58 *);
	int (*ndo_busy_poll)(struct napi_struct___58 *);
	int (*ndo_set_vf_mac)(struct net_device___58 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___58 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___58 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___58 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___58 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___58 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___58 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___58 *, int, struct sk_buff___61 *);
	int (*ndo_setup_tc)(struct net_device___58 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___58 *);
	int (*ndo_fcoe_disable)(struct net_device___58 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___58 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___58 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___58 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___58 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___58 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___58 *, const struct sk_buff___61 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___58 *, struct net_device___58 *);
	int (*ndo_del_slave)(struct net_device___58 *, struct net_device___58 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___48 *);
	void (*ndo_neigh_destroy)(struct neighbour___48 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___61 *, struct netlink_callback___60 *, struct net_device___58 *, int);
	int (*ndo_bridge_setlink)(struct net_device___58 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___61 *, u32, u32, struct net_device___58 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___58 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___58 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___58 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___58 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___58 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___58 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___61 *, struct net_device___58 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___58 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___58 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___58 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___48 {
	struct net___72 *net;
	struct net_device___58 *dev;
	struct neigh_parms___48 *next;
	int (*neigh_setup)(struct neighbour___48 *);
	void (*neigh_cleanup)(struct neighbour___48 *);
	struct neigh_table___48 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___7;

struct in_device___7 {
	struct net_device___58 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___7 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___48 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___24;

struct ifacaddr6___24;

struct inet6_dev___24 {
	struct net_device___58 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___24 *mc_list;
	struct ifmcaddr6___24 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___48 *nd_parms;
	struct inet6_dev___24 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___49 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___58 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___72 *, struct net_device___58 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___58 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___58 *, struct list_head *);
	size_t (*get_size)(const struct net_device___58 *);
	int (*fill_info)(struct sk_buff___61 *, const struct net_device___58 *);
	size_t (*get_xstats_size)(const struct net_device___58 *);
	int (*fill_xstats)(struct sk_buff___61 *, const struct net_device___58 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___72 * (*get_link_net)(const struct net_device___58 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___58 *, struct net_device___58 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___58 *, const struct net_device___58 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___61 *, const struct net_device___58 *, const struct net_device___58 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct packet_type___3 {
	__be16 type;
	struct net_device___58 *dev;
	int (*func)(struct sk_buff___61 *, struct net_device___58 *, struct packet_type___3 *, struct net_device___58 *);
	bool (*id_match)(struct packet_type___3 *, struct sock___48 *);
	void *af_packet_priv;
	struct list_head list;
};

struct in_ifaddr___7 {
	struct hlist_node hash;
	struct in_ifaddr___7 *ifa_next;
	struct in_device___7 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___48 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___61 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___48;

struct neigh_hash_table___48;

struct neigh_table___48 {
	struct neigh_table___48 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___58 *, __u32 *);
	int (*constructor)(struct neighbour___48 *);
	int (*pconstructor)(struct pneigh_entry___48 *);
	void (*pdestructor)(struct pneigh_entry___48 *);
	void (*proxy_redo)(struct sk_buff___61 *);
	char *id;
	struct neigh_parms___48 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___59 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___48 *nht;
	struct pneigh_entry___48 **phash_buckets;
};

struct neigh_ops___48 {
	int family;
	void (*solicit)(struct neighbour___48 *, struct sk_buff___61 *);
	void (*error_report)(struct neighbour___48 *, struct sk_buff___61 *);
	int (*output)(struct neighbour___48 *, struct sk_buff___61 *);
	int (*connected_output)(struct neighbour___48 *, struct sk_buff___61 *);
};

struct pneigh_entry___48 {
	struct pneigh_entry___48 *next;
	struct net___72 *net;
	struct net_device___58 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___48 {
	struct neighbour___48 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___19 {
	struct dst_entry___48 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___30;

struct proto___47 {
	void (*close)(struct sock___48 *, long int);
	int (*connect)(struct sock___48 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___48 *, int);
	struct sock___48 * (*accept)(struct sock___48 *, int, int *);
	int (*ioctl)(struct sock___48 *, int, long unsigned int);
	int (*init)(struct sock___48 *);
	void (*destroy)(struct sock___48 *);
	void (*shutdown)(struct sock___48 *, int);
	int (*setsockopt)(struct sock___48 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___48 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___48 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___48 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___48 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___55 *, struct sock___48 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___55 *, struct sock___48 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___48 *, struct page___267 *, int, size_t, int);
	int (*bind)(struct sock___48 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___48 *, struct sk_buff___61 *);
	void (*release_cb)(struct sock___48 *);
	void (*mtu_reduced)(struct sock___48 *);
	void (*hash)(struct sock___48 *);
	void (*unhash)(struct sock___48 *);
	void (*rehash)(struct sock___48 *);
	int (*get_port)(struct sock___48 *, short unsigned int);
	void (*clear_sk)(struct sock___48 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___48 *);
	void (*enter_memory_pressure)(struct sock___48 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___251 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___33 *rsk_prot;
	struct timewait_sock_ops___30 *twsk_prot;
	union {
		struct inet_hashinfo___6 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___166 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___95 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___47 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___47 {
	void (*enter_memory_pressure)(struct sock___48 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct raw_hashinfo {
	rwlock_t lock;
	struct hlist_head ht[256];
};

struct request_sock_ops___33 {
	int family;
	int obj_size;
	struct kmem_cache___251 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___48 *, struct request_sock___34 *);
	void (*send_ack)(struct sock___48 *, struct sk_buff___61 *, struct request_sock___34 *);
	void (*send_reset)(struct sock___48 *, struct sk_buff___61 *);
	void (*destructor)(struct request_sock___34 *);
	void (*syn_ack_timeout)(struct sock___48 *, struct request_sock___34 *);
};

struct timewait_sock_ops___30 {
	struct kmem_cache___251 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___48 *, struct sock___48 *, void *);
	void (*twsk_destructor)(struct sock___48 *);
};

struct inet_cork___6 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___48 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___6 {
	struct inet_cork___6 base;
	struct flowi fl;
};

struct ipv6_pinfo___5;

struct inet_sock___6 {
	struct sock___48 sk;
	struct ipv6_pinfo___5 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___6 cork;
};

struct ipv6_fl_socklist___4;

struct ipv6_pinfo___5 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___4 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___61 *pktoptions;
	struct sk_buff___61 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___4;

struct ipv6_fl_socklist___4 {
	struct ipv6_fl_socklist___4 *next;
	struct ip6_flowlabel___4 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___24 {
	struct in6_addr mca_addr;
	struct inet6_dev___24 *idev;
	struct ifmcaddr6___24 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___24 {
	struct in6_addr aca_addr;
	struct inet6_dev___24 *aca_idev;
	struct rt6_info___6 *aca_rt;
	struct ifacaddr6___24 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___4 {
	struct ip6_flowlabel___4 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___72 *fl_net;
};

struct ip_ra_chain {
	struct ip_ra_chain *next;
	struct sock___48 *sk;
	union {
		void (*destructor)(struct sock___48 *);
		struct sock___48 *saved_sk;
	};
	struct callback_head rcu;
};

enum ip_defrag_users {
	IP_DEFRAG_LOCAL_DELIVER = 0,
	IP_DEFRAG_CALL_RA_CHAIN = 1,
	IP_DEFRAG_CONNTRACK_IN = 2,
	__IP_DEFRAG_CONNTRACK_IN_END = 65537,
	IP_DEFRAG_CONNTRACK_OUT = 65538,
	__IP_DEFRAG_CONNTRACK_OUT_END = 131073,
	IP_DEFRAG_CONNTRACK_BRIDGE_IN = 131074,
	__IP_DEFRAG_CONNTRACK_BRIDGE_IN = 196609,
	IP_DEFRAG_VS_IN = 196610,
	IP_DEFRAG_VS_OUT = 196611,
	IP_DEFRAG_VS_FWD = 196612,
	IP_DEFRAG_AF_PACKET = 196613,
	IP_DEFRAG_MACVLAN = 196614,
};

struct net_protocol___2 {
	void (*early_demux)(struct sk_buff___61 *);
	int (*handler)(struct sk_buff___61 *);
	void (*err_handler)(struct sk_buff___61 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

enum {
	INET_ECN_NOT_ECT = 0,
	INET_ECN_ECT_1 = 1,
	INET_ECN_ECT_0 = 2,
	INET_ECN_CE = 3,
	INET_ECN_MASK = 3,
};

struct xfrm_replay___6 {
	void (*advance)(struct xfrm_state___6 *, __be32);
	int (*check)(struct xfrm_state___6 *, struct sk_buff___61 *, __be32);
	int (*recheck)(struct xfrm_state___6 *, struct sk_buff___61 *, __be32);
	void (*notify)(struct xfrm_state___6 *, int);
	int (*overflow)(struct xfrm_state___6 *, struct sk_buff___61 *);
};

struct xfrm_type___6 {
	char *description;
	struct module___166 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___6 *);
	void (*destructor)(struct xfrm_state___6 *);
	int (*input)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*output)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*reject)(struct xfrm_state___6 *, struct sk_buff___61 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___6 *, struct sk_buff___61 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___6 *, int);
};

struct xfrm_state_afinfo___6;

struct xfrm_mode___6 {
	int (*input2)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*input)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*output2)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*output)(struct xfrm_state___6 *, struct sk_buff___61 *);
	struct xfrm_state_afinfo___6 *afinfo;
	struct module___166 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___6 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___166 *owner;
	const struct xfrm_type___6 *type_map[256];
	struct xfrm_mode___6 *mode_map[5];
	int (*init_flags)(struct xfrm_state___6 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___6 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___6 **, struct xfrm_state___6 **, int);
	union {
		int (*output)(struct sock___48 *, struct sk_buff___61 *);
		struct {
			int (*output)(struct sk_buff___61 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___48 *, struct sk_buff___61 *);
		struct {
			int (*output_finish)(struct sk_buff___61 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*extract_output)(struct xfrm_state___6 *, struct sk_buff___61 *);
	int (*transport_finish)(struct sk_buff___61 *, int);
};

struct inet_frag_queue {
	spinlock_t lock;
	struct timer_list timer;
	struct list_head lru_list;
	struct hlist_node list;
	atomic_t refcnt;
	struct sk_buff___59 *fragments;
	struct sk_buff___59 *fragments_tail;
	ktime_t stamp;
	int len;
	int meat;
	__u8 last_in;
	u16 max_size;
	struct netns_frags *net;
};

struct inet_frag_bucket {
	struct hlist_head chain;
	spinlock_t chain_lock;
};

struct inet_frags {
	struct inet_frag_bucket hash[1024];
	rwlock_t lock;
	int secret_interval;
	struct timer_list secret_timer;
	u32 rnd;
	int qsize;
	unsigned int (*hashfn)(struct inet_frag_queue *);
	bool (*match)(struct inet_frag_queue *, void *);
	void (*constructor)(struct inet_frag_queue *, void *);
	void (*destructor)(struct inet_frag_queue *);
	void (*skb_free)(struct sk_buff___59 *);
	void (*frag_expire)(long unsigned int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ipfrag_skb_cb {
	struct inet_skb_parm h;
	int offset;
};

struct ipq {
	struct inet_frag_queue q;
	u32 user;
	__be32 saddr;
	__be32 daddr;
	__be16 id;
	u8 protocol;
	u8 ecn;
	int iif;
	unsigned int rid;
	struct inet_peer *peer;
};

struct ip4_create_arg {
	struct iphdr *iph;
	u32 user;
};

struct page___268;

typedef struct page___268 *pgtable_t___268;

struct address_space___269;

struct kmem_cache___252;

struct page___268 {
	long unsigned int flags;
	struct address_space___269 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___268 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___268 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___252 *slab_cache;
		struct page___268 *first_page;
	};
	long: 64;
};

struct task_struct___270;

struct pv_cpu_ops___270 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___270 *);
	void (*end_context_switch)(struct task_struct___270 *);
};

struct mutex___271 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___270 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___263 {
	struct page___268 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___277;

struct nsproxy___149;

struct signal_struct___270;

struct css_set___164;

struct task_struct___270 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___270 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___277 *mm;
	struct mm_struct___277 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___270 *real_parent;
	struct task_struct___270 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___270 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___270 = 0,
		VTIME_USER___270 = 1,
		VTIME_SYS___270 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___149 *nsproxy;
	struct signal_struct___270 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___164 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___271 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___263 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___277 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___277 *, struct mm_struct___277 *);
	void (*dup_mmap)(struct mm_struct___277 *, struct mm_struct___277 *);
	void (*exit_mmap)(struct mm_struct___277 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___277 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___277 *);
	void (*pgd_free)(struct mm_struct___277 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___277 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___277 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___277 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___277 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___277 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___277 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___277 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___277 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___277 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___277 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___277 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___271 lock;
	void *vdso;
} mm_context_t___271;

struct xol_area___268;

struct uprobes_state___268 {
	struct xol_area___268 *xol_area;
};

struct vm_area_struct___277;

struct file___269;

struct core_state___270;

struct mm_struct___277 {
	struct vm_area_struct___277 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___277 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___277 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___271 context;
	long unsigned int flags;
	struct core_state___270 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___270 *owner;
	struct file___269 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___268 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___270;

struct lruvec___270 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___270 *zone;
};

struct pglist_data___270;

struct zone___270 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___270 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___270 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___270 {
	struct zone___270 *zone;
	int zone_idx;
};

struct zonelist___270 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___270 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___270 {
	struct zone___270 node_zones[4];
	struct zonelist___270 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___270 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___193;

struct x86_io_apic_ops___193 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___193 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___193;

struct irq_data___193 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___193 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___267;

struct dev_pm_ops___267 {
	int (*prepare)(struct device___267 *);
	void (*complete)(struct device___267 *);
	int (*suspend)(struct device___267 *);
	int (*resume)(struct device___267 *);
	int (*freeze)(struct device___267 *);
	int (*thaw)(struct device___267 *);
	int (*poweroff)(struct device___267 *);
	int (*restore)(struct device___267 *);
	int (*suspend_late)(struct device___267 *);
	int (*resume_early)(struct device___267 *);
	int (*freeze_late)(struct device___267 *);
	int (*thaw_early)(struct device___267 *);
	int (*poweroff_late)(struct device___267 *);
	int (*restore_early)(struct device___267 *);
	int (*suspend_noirq)(struct device___267 *);
	int (*resume_noirq)(struct device___267 *);
	int (*freeze_noirq)(struct device___267 *);
	int (*thaw_noirq)(struct device___267 *);
	int (*poweroff_noirq)(struct device___267 *);
	int (*restore_noirq)(struct device___267 *);
	int (*runtime_suspend)(struct device___267 *);
	int (*runtime_resume)(struct device___267 *);
	int (*runtime_idle)(struct device___267 *);
};

struct kset___51;

struct kobj_type___51;

struct kobject___51 {
	const char *name;
	struct list_head entry;
	struct kobject___51 *parent;
	struct kset___51 *kset;
	struct kobj_type___51 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___70;

struct dev_pm_info___70 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___70 *qos;
};

struct dma_map_ops___132;

struct dev_archdata___132 {
	struct dma_map_ops___132 *dma_ops;
	void *iommu;
};

struct device_type___267;

struct bus_type___267;

struct device_driver___267;

struct dev_pm_domain___267;

struct class___267;

struct attribute_group___229;

struct device_rh___267;

struct device___267 {
	struct device___267 *parent;
	struct device_private *p;
	struct kobject___51 kobj;
	const char *init_name;
	const struct device_type___267 *type;
	struct mutex___271 mutex;
	struct bus_type___267 *bus;
	struct device_driver___267 *driver;
	void *platform_data;
	struct dev_pm_info___70 power;
	struct dev_pm_domain___267 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___132 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___267 *class;
	const struct attribute_group___229 **groups;
	void (*release)(struct device___267 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___267 *device_rh;
};

struct dev_pm_qos_request___71;

struct dev_pm_qos___70 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___71 *latency_req;
	struct dev_pm_qos_request___71 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___71 *latency_tolerance_req;
};

struct dev_pm_info_rh___267 {
	void (*set_latency_tolerance)(struct device___267 *, s32);
};

struct dev_pm_domain___267 {
	struct dev_pm_ops___267 ops;
};

struct smp_ops___270 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___270 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___268 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___268 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___251;

struct memcg_cache_params___252;

struct kmem_cache___252 {
	struct kmem_cache_cpu___251 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___51 kobj;
	struct memcg_cache_params___252 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___269;

struct address_space_operations___269;

struct address_space___269 {
	struct inode___269 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___271 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___269 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___269;

struct path___269 {
	struct vfsmount *mnt;
	struct dentry___269 *dentry;
};

struct file_operations___269;

struct file___269 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___269 f_path;
	struct inode___269 *f_inode;
	const struct file_operations___269 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___269 *f_mapping;
	struct mutex___271 f_pos_lock;
};

struct vm_operations_struct___243;

struct vm_area_struct___277 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___277 *vm_next;
	struct vm_area_struct___277 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___277 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___243 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___269 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___239;

struct vm_operations_struct___243 {
	void (*open)(struct vm_area_struct___277 *);
	void (*close)(struct vm_area_struct___277 *);
	int (*fault)(struct vm_area_struct___277 *, struct vm_fault___239 *);
	int (*page_mkwrite)(struct vm_area_struct___277 *, struct vm_fault___239 *);
	int (*access)(struct vm_area_struct___277 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___277 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___277 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___277 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___277 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___270 {
	struct task_struct___270 *task;
	struct core_thread___270 *next;
};

struct core_state___270 {
	atomic_t nr_threads;
	struct core_thread___270 dumper;
	struct completion startup;
};

struct vm_fault___239 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___268 *page;
};

struct fasync_struct___269;

struct socket_wq___48 {
	wait_queue_head_t wait;
	struct fasync_struct___269 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___269 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___269 *fa_next;
	struct file___269 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___49;

struct proto_ops___48;

struct socket___49 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___48 *wq;
	struct file___269 *file;
	struct sock___49 *sk;
	const struct proto_ops___48 *ops;
};

struct proto___48;

struct net___73;

struct sock_common___48 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___48 *skc_prot;
	struct net___73 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___62;

struct sk_buff_head___60 {
	struct sk_buff___62 *next;
	struct sk_buff___62 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___49;

struct xfrm_policy___7;

struct dst_entry___49;

struct cg_proto___48;

struct sock___49 {
	struct sock_common___48 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___60 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___62 *head;
		struct sk_buff___62 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___49 *sk_filter;
	struct socket_wq___48 *sk_wq;
	struct sk_buff_head___60 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___7 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___49 *sk_rx_dst;
	struct dst_entry___49 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___60 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___60 sk_error_queue;
	struct proto___48 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___49 *sk_socket;
	void *sk_user_data;
	struct page_frag___263 sk_frag;
	struct sk_buff___62 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___48 *sk_cgrp;
	void (*sk_state_change)(struct sock___49 *);
	void (*sk_data_ready)(struct sock___49 *, int);
	void (*sk_write_space)(struct sock___49 *);
	void (*sk_error_report)(struct sock___49 *);
	int (*sk_backlog_rcv)(struct sock___49 *, struct sk_buff___62 *);
	void (*sk_destruct)(struct sock___49 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___155;

struct kiocb___56;

struct proto_ops___48 {
	int family;
	struct module *owner;
	int (*release)(struct socket___49 *);
	int (*bind)(struct socket___49 *, struct sockaddr *, int);
	int (*connect)(struct socket___49 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___49 *, struct socket___49 *);
	int (*accept)(struct socket___49 *, struct socket___49 *, int);
	int (*getname)(struct socket___49 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___269 *, struct socket___49 *, struct poll_table_struct___155 *);
	int (*ioctl)(struct socket___49 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___49 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___49 *, int);
	int (*shutdown)(struct socket___49 *, int);
	int (*setsockopt)(struct socket___49 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___49 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___49 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___49 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___56 *, struct socket___49 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___56 *, struct socket___49 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___269 *, struct socket___49 *, struct vm_area_struct___277 *);
	ssize_t (*sendpage)(struct socket___49 *, struct page___268 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___49 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___49 *, int);
		struct {
			void (*set_peek_off)(struct sock___49 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___157)(struct file___269 *, wait_queue_head_t *, struct poll_table_struct___155 *);

struct poll_table_struct___155 {
	poll_queue_proc___157 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___56(struct kiocb___56 *, struct io_event *);

struct kiocb___56 {
	atomic_t ki_users;
	struct file___269 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___56 *ki_cancel;
	void (*ki_dtor)(struct kiocb___56 *);
	union {
		void *user;
		struct task_struct___270 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___74;

struct ctl_table_set___74;

struct ctl_dir___74;

struct ctl_node___74;

struct ctl_table_header___74 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___74 *root;
	struct ctl_table_set___74 *set;
	struct ctl_dir___74 *parent;
	struct ctl_node___74 *node;
};

struct ctl_dir___74 {
	struct ctl_table_header___74 header;
	struct rb_root root;
};

struct ctl_table_set___74 {
	int (*is_seen)(struct ctl_table_set___74 *);
	struct ctl_dir___74 dir;
};

struct netns_core___71 {
	struct ctl_table_header___74 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___72 {
	struct mutex___271 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___71 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___74 *ctl;
};

struct netns_ipv4___71 {
	struct ctl_table_header___74 *forw_hdr;
	struct ctl_table_header___74 *frags_hdr;
	struct ctl_table_header___74 *ipv4_hdr;
	struct ctl_table_header___74 *route_hdr;
	struct ctl_table_header___74 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___49 *fibnl;
	struct sock___49 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___71 {
	struct ctl_table_header___74 *hdr;
	struct ctl_table_header___74 *route_hdr;
	struct ctl_table_header___74 *icmp_hdr;
	struct ctl_table_header___74 *frags_hdr;
	struct ctl_table_header___74 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___59;

struct neighbour___49;

struct dst_ops___73 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___73 *);
	struct dst_entry___49 * (*check)(struct dst_entry___49 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___49 *);
	unsigned int (*mtu)(const struct dst_entry___49 *);
	u32 * (*cow_metrics)(struct dst_entry___49 *, long unsigned int);
	void (*destroy)(struct dst_entry___49 *);
	void (*ifdown)(struct dst_entry___49 *, struct net_device___59 *, int);
	struct dst_entry___49 * (*negative_advice)(struct dst_entry___49 *);
	void (*link_failure)(struct sk_buff___62 *);
	void (*update_pmtu)(struct dst_entry___49 *, struct sock___49 *, struct sk_buff___62 *, u32);
	void (*redirect)(struct dst_entry___49 *, struct sock___49 *, struct sk_buff___62 *);
	int (*local_out)(struct sk_buff___62 *);
	struct neighbour___49 * (*neigh_lookup)(const struct dst_entry___49 *, struct sk_buff___62 *, const void *);
	struct kmem_cache___252 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___7;

struct fib6_table___7;

struct netns_ipv6___73 {
	struct netns_sysctl_ipv6___71 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___7 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___7 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___73 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___7 *ip6_prohibit_entry;
	struct rt6_info___7 *ip6_blk_hole_entry;
	struct fib6_table___7 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___49 **icmp_sk;
	struct sock___49 *ndisc_sk;
	struct sock___49 *tcp_sk;
	struct sock___49 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___71 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___74 *sysctl_header;
	struct sock___49 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___48 {
	struct sock___49 *v4_ctl_sk;
	struct sock___49 *v6_ctl_sk;
};

struct netns_nf___71 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___74 *nf_log_dir_header;
};

struct nf_proto_net___71 {
	struct ctl_table_header___74 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___71 {
	struct nf_proto_net___71 pn;
	unsigned int timeout;
};

struct nf_tcp_net___71 {
	struct nf_proto_net___71 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___71 {
	struct nf_proto_net___71 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___71 {
	struct nf_proto_net___71 pn;
	unsigned int timeout;
};

struct nf_ip_net___71 {
	struct nf_generic_net___71 generic;
	struct nf_tcp_net___71 tcp;
	struct nf_udp_net___71 udp;
	struct nf_icmp_net___71 icmp;
	struct nf_icmp_net___71 icmpv6;
};

struct netns_ct___72 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___74 *sysctl_header;
	struct ctl_table_header___74 *acct_sysctl_header;
	struct ctl_table_header___74 *tstamp_sysctl_header;
	struct ctl_table_header___74 *event_sysctl_header;
	struct ctl_table_header___74 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___252 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___71 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___71 {
	struct netns_sysctl_ipv6___71 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___73 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___49 *nlsk;
	struct sock___49 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___74 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___73 xfrm4_dst_ops;
	struct dst_ops___73 xfrm6_dst_ops;
};

struct net___73 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___74 sysctls;
	struct sock___49 *rtnl;
	struct sock___49 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___59 *loopback_dev;
	struct netns_core___71 core;
	struct netns_mib mib;
	struct netns_packet___72 packet;
	struct netns_unix___71 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___71 ipv4;
	struct netns_ipv6___73 ipv6;
	struct netns_sctp___71 sctp;
	struct netns_dccp___48 dccp;
	struct netns_nf___71 nf;
	struct netns_xt xt;
	struct netns_ct___72 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___71 nf_frag;
	struct sock___49 *nfnl;
	struct sock___49 *nfnl_stash;
	struct sk_buff_head___60 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___73 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___49 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___49 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___271 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___271 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___48 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___49 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___231;

struct attribute_group___229 {
	const char *name;
	umode_t (*is_visible)(struct kobject___51 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___231 **bin_attrs;
};

struct bin_attribute___231 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___269 *, struct kobject___51 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___269 *, struct kobject___51 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	int (*mmap)(struct file___269 *, struct kobject___51 *, struct bin_attribute___231 *, struct vm_area_struct___277 *);
};

struct sysfs_ops___51 {
	ssize_t (*show)(struct kobject___51 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___51 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___51 *, const struct attribute *);
};

struct kset_uevent_ops___51;

struct kset___51 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___51 kobj;
	const struct kset_uevent_ops___51 *uevent_ops;
};

struct kobj_type___51 {
	void (*release)(struct kobject___51 *);
	const struct sysfs_ops___51 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___48 * (*child_ns_type)(struct kobject___51 *);
	const void * (*namespace)(struct kobject___51 *);
};

struct kset_uevent_ops___51 {
	int (* const filter)(struct kset___51 *, struct kobject___51 *);
	const char * (* const name)(struct kset___51 *, struct kobject___51 *);
	int (* const uevent)(struct kset___51 *, struct kobject___51 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___251 {
	void **freelist;
	long unsigned int tid;
	struct page___268 *page;
	struct page___268 *partial;
};

struct memcg_cache_params___252 {
	bool is_root_cache;
	union {
		struct kmem_cache___252 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___252 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___132 {
	void * (*alloc)(struct device___267 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___267 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___267 *, struct vm_area_struct___277 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___267 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___267 *, struct page___268 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___267 *, dma_addr_t);
	int (*dma_supported)(struct device___267 *, u64);
	int (*set_dma_mask)(struct device___267 *, u64);
	int is_phys;
};

struct bus_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___267 *, char *);
	ssize_t (*store)(struct bus_type___267 *, const char *, size_t);
};

struct device_attribute___267;

struct driver_attribute___267;

struct bus_type___267 {
	const char *name;
	const char *dev_name;
	struct device___267 *dev_root;
	struct bus_attribute___267 *bus_attrs;
	struct device_attribute___267 *dev_attrs;
	struct driver_attribute___267 *drv_attrs;
	const struct attribute_group___229 **bus_groups;
	const struct attribute_group___229 **dev_groups;
	const struct attribute_group___229 **drv_groups;
	int (*match)(struct device___267 *, struct device_driver___267 *);
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	int (*probe)(struct device___267 *);
	int (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*online)(struct device___267 *);
	int (*offline)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct device___267 *, struct device_attribute___267 *, char *);
	ssize_t (*store)(struct device___267 *, struct device_attribute___267 *, const char *, size_t);
};

struct driver_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___267 *, char *);
	ssize_t (*store)(struct device_driver___267 *, const char *, size_t);
};

struct device_driver___267 {
	const char *name;
	struct bus_type___267 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___267 *);
	int (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	const struct attribute_group___229 **groups;
	const struct dev_pm_ops___267 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___267 {
	const char *name;
	const struct attribute_group___229 **groups;
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
};

struct class_attribute___267;

struct class___267 {
	const char *name;
	struct module *owner;
	struct class_attribute___267 *class_attrs;
	struct device_attribute___267 *dev_attrs;
	const struct attribute_group___229 **dev_groups;
	struct bin_attribute___231 *dev_bin_attrs;
	struct kobject___51 *dev_kobj;
	int (*dev_uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *);
	void (*class_release)(struct class___267 *);
	void (*dev_release)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	const struct kobj_ns_type_operations___48 *ns_type;
	const void * (*namespace)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
	struct subsys_private *p;
};

struct class_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct class___267 *, struct class_attribute___267 *, char *);
	ssize_t (*store)(struct class___267 *, struct class_attribute___267 *, const char *, size_t);
	const void * (*namespace)(struct class___267 *, const struct class_attribute___267 *);
};

struct device_rh___267 {
	struct dev_pm_info_rh___267 power;
};

struct ctl_node___74 {
	struct rb_node node;
	struct ctl_table_header___74 *header;
};

struct ctl_table_root___74 {
	struct ctl_table_set___74 default_set;
	struct ctl_table_set___74 * (*lookup)(struct ctl_table_root___74 *, struct nsproxy___149 *);
	int (*permissions)(struct ctl_table_header___74 *, struct ctl_table *);
};

struct nsproxy___149 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___73 *net_ns;
};

struct signal_struct___270 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___270 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___270 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___271 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___164;

struct css_set___164 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___164 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___59 {
	atomic_t use;
	unsigned int mask;
	struct net_device___59 *physindev;
	struct net_device___59 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___59(struct sk_buff___62 **);

struct net_device_ops___59;

struct ethtool_ops___59;

struct header_ops___59;

struct inet6_dev___25;

struct netdev_rx_queue___59;

struct netdev_queue___59;

struct rtnl_link_ops___50;

struct dcbnl_rtnl_ops___59;

struct net_device___59 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___59 *netdev_ops;
	const struct ethtool_ops___59 *ethtool_ops;
	const struct header_ops___59 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___51 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___25 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___59 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___59 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___59 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___59 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___59 = 0,
		NETREG_REGISTERED___59 = 1,
		NETREG_UNREGISTERING___59 = 2,
		NETREG_UNREGISTERED___59 = 3,
		NETREG_RELEASED___59 = 4,
		NETREG_DUMMY___59 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___59 = 0,
		RTNL_LINK_INITIALIZING___59 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___59 *);
	struct netpoll_info *npinfo;
	struct net___73 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___267 dev;
	const struct attribute_group___229 *sysfs_groups[4];
	const struct rtnl_link_ops___50 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___59 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___7;

struct sk_buff___62 {
	struct sk_buff___62 *next;
	struct sk_buff___62 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___49 *sk;
	struct net_device___59 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___7 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___62 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___59 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___12 {
	struct {
		struct page___268 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___12 skb_frag_t___12;

struct skb_shared_info___12 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___62 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___12 frags[17];
};

struct xfrm_state___7;

struct sec_path___7 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___7 *xvec[6];
};

struct file_lock___269;

struct seq_file___194;

struct file_operations___269 {
	struct module *owner;
	loff_t (*llseek)(struct file___269 *, loff_t, int);
	ssize_t (*read)(struct file___269 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___269 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___56 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___56 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___269 *, void *, filldir_t);
	unsigned int (*poll)(struct file___269 *, struct poll_table_struct___155 *);
	long int (*unlocked_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___269 *, struct vm_area_struct___277 *);
	int (*open)(struct inode___269 *, struct file___269 *);
	int (*flush)(struct file___269 *, fl_owner_t);
	int (*release)(struct inode___269 *, struct file___269 *);
	int (*fsync)(struct file___269 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___56 *, int);
	int (*fasync)(int, struct file___269 *, int);
	int (*lock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*sendpage)(struct file___269 *, struct page___268 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___269 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___269 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___269 *, long int, struct file_lock___269 **, void **);
		struct {
			int (*setlease)(struct file___269 *, long int, struct file_lock___269 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___269 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___194 *, struct file___269 *);
};

struct dev_pm_qos_request___71 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___267 *dev;
};

struct dentry_operations___269;

struct super_block___269;

struct dentry___269 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___269 *d_parent;
	struct qstr d_name;
	struct inode___269 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___269 *d_op;
	struct super_block___269 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___269;

struct dquot___269;

struct block_device___269;

struct inode___269 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___269 *i_op;
	struct super_block___269 *i_sb;
	struct address_space___269 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___271 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___269 *i_fop;
	struct file_lock___269 *i_flock;
	struct address_space___269 i_data;
	struct dquot___269 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___269 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___269 {
	int (*d_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_hash)(const struct dentry___269 *, struct qstr *);
	int (*d_compare)(const struct dentry___269 *, const struct dentry___269 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___269 *);
	void (*d_release)(struct dentry___269 *);
	void (*d_prune)(struct dentry___269 *);
	void (*d_iput)(struct dentry___269 *, struct inode___269 *);
	char * (*d_dname)(struct dentry___269 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___269 *);
	int (*d_manage)(struct dentry___269 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___269;

struct mem_dqinfo___269 {
	struct quota_format_type___269 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___269;

struct quota_info___269 {
	unsigned int flags;
	struct mutex___271 dqio_mutex;
	struct mutex___271 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___269 *files[2];
	struct mem_dqinfo___269 info[2];
	const struct quota_format_ops___269 *ops[2];
};

struct file_system_type___269;

struct super_operations___269;

struct dquot_operations___269;

struct quotactl_ops___269;

struct xattr_handler___165;

struct super_block___269 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___269 *s_type;
	const struct super_operations___269 *s_op;
	const struct dquot_operations___269 *dq_op;
	const struct quotactl_ops___269 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___269 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___165 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___269 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___269 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___271 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___269 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___269 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___269 *bd_inode;
	struct super_block___269 *bd_super;
	struct mutex___271 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___269 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___271 bd_fsfreeze_mutex;
};

struct cgroup___164;

struct cgroup_subsys_state___164 {
	struct cgroup___164 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___269 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___269 *ia_file;
};

struct dquot___269 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___271 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___269 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___269 {
	int qf_fmt_id;
	const struct quota_format_ops___269 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___269 *qf_next;
};

struct quota_format_ops___269 {
	int (*check_quota_file)(struct super_block___269 *, int);
	int (*read_file_info)(struct super_block___269 *, int);
	int (*write_file_info)(struct super_block___269 *, int);
	int (*free_file_info)(struct super_block___269 *, int);
	int (*read_dqblk)(struct dquot___269 *);
	int (*commit_dqblk)(struct dquot___269 *);
	int (*release_dqblk)(struct dquot___269 *);
};

struct dquot_operations___269 {
	int (*write_dquot)(struct dquot___269 *);
	struct dquot___269 * (*alloc_dquot)(struct super_block___269 *, int);
	void (*destroy_dquot)(struct dquot___269 *);
	int (*acquire_dquot)(struct dquot___269 *);
	int (*release_dquot)(struct dquot___269 *);
	int (*mark_dirty)(struct dquot___269 *);
	int (*write_info)(struct super_block___269 *, int);
	qsize_t * (*get_reserved_space)(struct inode___269 *);
};

struct quotactl_ops___269 {
	int (*quota_on)(struct super_block___269 *, int, int, struct path___269 *);
	int (*quota_on_meta)(struct super_block___269 *, int, int);
	int (*quota_off)(struct super_block___269 *, int);
	int (*quota_sync)(struct super_block___269 *, int);
	int (*get_info)(struct super_block___269 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___269 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___269 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___269 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___269 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___269 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___269 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___269 *, unsigned int);
};

struct address_space_operations___269 {
	int (*writepage)(struct page___268 *, struct writeback_control *);
	int (*readpage)(struct file___269 *, struct page___268 *);
	int (*writepages)(struct address_space___269 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___268 *);
	int (*readpages)(struct file___269 *, struct address_space___269 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___269 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___268 **, void **);
	int (*write_end)(struct file___269 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___268 *, void *);
	sector_t (*bmap)(struct address_space___269 *, sector_t);
	void (*invalidatepage)(struct page___268 *, long unsigned int);
	int (*releasepage)(struct page___268 *, gfp_t);
	void (*freepage)(struct page___268 *);
	ssize_t (*direct_IO)(int, struct kiocb___56 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___269 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___269 *, struct page___268 *, struct page___268 *, enum migrate_mode);
	int (*launder_page)(struct page___268 *);
	int (*is_partially_uptodate)(struct page___268 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___268 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___269 *, struct page___268 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___269 *, sector_t *);
	void (*swap_deactivate)(struct file___269 *);
	void (*invalidatepage_range)(struct page___268 *, unsigned int, unsigned int);
};

struct inode_operations___269 {
	struct dentry___269 * (*lookup)(struct inode___269 *, struct dentry___269 *, unsigned int);
	void * (*follow_link)(struct dentry___269 *, struct nameidata *);
	int (*permission)(struct inode___269 *, int);
	struct posix_acl * (*get_acl)(struct inode___269 *, int);
	int (*readlink)(struct dentry___269 *, char *, int);
	void (*put_link)(struct dentry___269 *, struct nameidata *, void *);
	int (*create)(struct inode___269 *, struct dentry___269 *, umode_t, bool);
	int (*link)(struct dentry___269 *, struct inode___269 *, struct dentry___269 *);
	int (*unlink)(struct inode___269 *, struct dentry___269 *);
	int (*symlink)(struct inode___269 *, struct dentry___269 *, const char *);
	int (*mkdir)(struct inode___269 *, struct dentry___269 *, umode_t);
	int (*rmdir)(struct inode___269 *, struct dentry___269 *);
	int (*mknod)(struct inode___269 *, struct dentry___269 *, umode_t, dev_t);
	int (*rename)(struct inode___269 *, struct dentry___269 *, struct inode___269 *, struct dentry___269 *);
	int (*setattr)(struct dentry___269 *, struct iattr___269 *);
	int (*getattr)(struct vfsmount *, struct dentry___269 *, struct kstat *);
	int (*setxattr)(struct dentry___269 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___269 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___269 *, char *, size_t);
	int (*removexattr)(struct dentry___269 *, const char *);
	int (*fiemap)(struct inode___269 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___269 *, struct timespec *, int);
	int (*atomic_open)(struct inode___269 *, struct dentry___269 *, struct file___269 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___269;

struct lock_manager_operations___269;

struct file_lock___269 {
	struct file_lock___269 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___269 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___269 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___269 *fl_ops;
	const struct lock_manager_operations___269 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___269 {
	void (*fl_copy_lock)(struct file_lock___269 *, struct file_lock___269 *);
	void (*fl_release_private)(struct file_lock___269 *);
};

struct lock_manager_operations___269 {
	int (*lm_compare_owner)(struct file_lock___269 *, struct file_lock___269 *);
	long unsigned int (*lm_owner_key)(struct file_lock___269 *);
	void (*lm_notify)(struct file_lock___269 *);
	int (*lm_grant)(struct file_lock___269 *, struct file_lock___269 *, int);
	void (*lm_break)(struct file_lock___269 *);
	int (*lm_change)(struct file_lock___269 **, int);
};

struct file_system_type___269 {
	const char *name;
	int fs_flags;
	struct dentry___269 * (*mount)(struct file_system_type___269 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___269 *);
	struct module *owner;
	struct file_system_type___269 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___269 {
	struct inode___269 * (*alloc_inode)(struct super_block___269 *);
	void (*destroy_inode)(struct inode___269 *);
	void (*dirty_inode)(struct inode___269 *, int);
	int (*write_inode)(struct inode___269 *, struct writeback_control *);
	int (*drop_inode)(struct inode___269 *);
	void (*evict_inode)(struct inode___269 *);
	void (*put_super)(struct super_block___269 *);
	int (*sync_fs)(struct super_block___269 *, int);
	int (*freeze_fs)(struct super_block___269 *);
	int (*unfreeze_fs)(struct super_block___269 *);
	int (*statfs)(struct dentry___269 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___269 *, int *, char *);
	void (*umount_begin)(struct super_block___269 *);
	int (*show_options)(struct seq_file___194 *, struct dentry___269 *);
	int (*show_devname)(struct seq_file___194 *, struct dentry___269 *);
	int (*show_path)(struct seq_file___194 *, struct dentry___269 *);
	int (*show_stats)(struct seq_file___194 *, struct dentry___269 *);
	ssize_t (*quota_read)(struct super_block___269 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___269 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___269 *);
	int (*bdev_try_to_free_page)(struct super_block___269 *, struct page___268 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___269 *);
	void (*free_cached_objects)(struct super_block___269 *, int);
};

struct xattr_handler___165 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___269 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___269 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___269 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___194;

struct seq_file___194 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___271 lock;
	const struct seq_operations___194 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___59 {
	int (*get_settings)(struct net_device___59 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___59 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___59 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___59 *);
	void (*get_regs)(struct net_device___59 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___59 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___59 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___59 *);
	void (*set_msglevel)(struct net_device___59 *, u32);
	int (*nway_reset)(struct net_device___59 *);
	u32 (*get_link)(struct net_device___59 *);
	int (*get_eeprom_len)(struct net_device___59 *);
	int (*get_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___59 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___59 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___59 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___59 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___59 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___59 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___59 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___59 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___59 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___59 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___59 *);
	void (*complete)(struct net_device___59 *);
	u32 (*get_priv_flags)(struct net_device___59 *);
	int (*set_priv_flags)(struct net_device___59 *, u32);
	int (*get_sset_count)(struct net_device___59 *, int);
	int (*get_rxnfc)(struct net_device___59 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___59 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___59 *, struct ethtool_flash *);
	int (*reset)(struct net_device___59 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___59 *);
	int (*get_rxfh_indir)(struct net_device___59 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___59 *, const u32 *);
	void (*get_channels)(struct net_device___59 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___59 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___59 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___59 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___59 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___59 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___59 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___59 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___59 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___59 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___59 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___59 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___20;

struct dst_entry___49 {
	struct callback_head callback_head;
	struct dst_entry___49 *child;
	struct net_device___59 *dev;
	struct dst_ops___73 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___49 *path;
	struct dst_entry___49 *from;
	struct xfrm_state___7 *xfrm;
	int (*input)(struct sk_buff___62 *);
	union {
		int (*output)(struct sock___49 *, struct sk_buff___62 *);
		struct {
			int (*output)(struct sk_buff___62 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___49 *next;
		struct rtable___20 *rt_next;
		struct rt6_info___7 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___49;

struct neigh_parms___49;

struct neigh_ops___49;

struct neighbour___49 {
	struct neighbour___49 *next;
	struct neigh_table___49 *tbl;
	struct neigh_parms___49 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___60 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___49 *, struct sk_buff___62 *);
	const struct neigh_ops___49 *ops;
	struct callback_head rcu;
	struct net_device___59 *dev;
	u8 primary_key[0];
};

struct fib6_node___7;

struct rt6_info___7 {
	struct dst_entry___49 dst;
	struct fib6_table___7 *rt6i_table;
	struct fib6_node___7 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___25 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___7 {
	struct fib6_node___7 *parent;
	struct fib6_node___7 *left;
	struct fib6_node___7 *right;
	struct rt6_info___7 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___7 *rr_ptr;
};

struct fib6_table___7 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___7 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___7 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___59 *in;
	struct net_device___59 *out;
	struct sock___49 *sk;
	int (*okfn)(struct sock___49 *, struct sk_buff___62 *);
};

struct nf_afinfo___73 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___62 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___62 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___73 *, struct dst_entry___49 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___62 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___62 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___193 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___193 *);
	void (*irq_shutdown)(struct irq_data___193 *);
	void (*irq_enable)(struct irq_data___193 *);
	void (*irq_disable)(struct irq_data___193 *);
	void (*irq_ack)(struct irq_data___193 *);
	void (*irq_mask)(struct irq_data___193 *);
	void (*irq_mask_ack)(struct irq_data___193 *);
	void (*irq_unmask)(struct irq_data___193 *);
	void (*irq_eoi)(struct irq_data___193 *);
	int (*irq_set_affinity)(struct irq_data___193 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___193 *);
	int (*irq_set_type)(struct irq_data___193 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___193 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___193 *);
	void (*irq_bus_sync_unlock)(struct irq_data___193 *);
	void (*irq_cpu_online)(struct irq_data___193 *);
	void (*irq_cpu_offline)(struct irq_data___193 *);
	void (*irq_suspend)(struct irq_data___193 *);
	void (*irq_resume)(struct irq_data___193 *);
	void (*irq_pm_shutdown)(struct irq_data___193 *);
	void (*irq_print_chip)(struct irq_data___193 *, struct seq_file___194 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___193 *, void *);
	long unsigned int flags;
};

struct seq_operations___194 {
	void * (*start)(struct seq_file___194 *, loff_t *);
	void (*stop)(struct seq_file___194 *, void *);
	void * (*next)(struct seq_file___194 *, void *, loff_t *);
	int (*show)(struct seq_file___194 *, void *);
};

struct dcbnl_rtnl_ops___59 {
	int (*ieee_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___59 *);
	u8 (*setstate)(struct net_device___59 *, u8);
	void (*getpermhwaddr)(struct net_device___59 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___59 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___59 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___59 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___59 *, int, u8 *);
	void (*setpfccfg)(struct net_device___59 *, int, u8);
	void (*getpfccfg)(struct net_device___59 *, int, u8 *);
	u8 (*setall)(struct net_device___59 *);
	u8 (*getcap)(struct net_device___59 *, int, u8 *);
	int (*getnumtcs)(struct net_device___59 *, int, u8 *);
	int (*setnumtcs)(struct net_device___59 *, int, u8);
	u8 (*getpfcstate)(struct net_device___59 *);
	void (*setpfcstate)(struct net_device___59 *, u8);
	void (*getbcncfg)(struct net_device___59 *, int, u32 *);
	void (*setbcncfg)(struct net_device___59 *, int, u32);
	void (*getbcnrp)(struct net_device___59 *, int, u8 *);
	void (*setbcnrp)(struct net_device___59 *, int, u8);
	u8 (*setapp)(struct net_device___59 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___59 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___59 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___59 *, int, u8);
	u8 (*getdcbx)(struct net_device___59 *);
	u8 (*setdcbx)(struct net_device___59 *, u8);
	int (*peer_getappinfo)(struct net_device___59 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___59 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___59 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___59 *, struct cee_pfc *);
};

struct cgroupfs_root___164;

struct cgroup___164 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___164 *parent;
	struct dentry___269 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___164 *subsys[11];
	struct cgroupfs_root___164 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___271 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___164 {
	struct super_block___269 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___164 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___100 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___269 *, struct file___269 *);
	ssize_t (*read)(struct cgroup___164 *, struct cftype___100 *, struct file___269 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___164 *, struct cftype___100 *);
	s64 (*read_s64)(struct cgroup___164 *, struct cftype___100 *);
	int (*read_map)(struct cgroup___164 *, struct cftype___100 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___164 *, struct cftype___100 *, struct seq_file___194 *);
	ssize_t (*write)(struct cgroup___164 *, struct cftype___100 *, struct file___269 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___164 *, struct cftype___100 *, u64);
	int (*write_s64)(struct cgroup___164 *, struct cftype___100 *, s64);
	int (*write_string)(struct cgroup___164 *, struct cftype___100 *, const char *);
	int (*trigger)(struct cgroup___164 *, unsigned int);
	int (*release)(struct inode___269 *, struct file___269 *);
	int (*register_event)(struct cgroup___164 *, struct cftype___100 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___164 *, struct cftype___100 *, struct eventfd_ctx *);
};

struct cftype_set___96 {
	struct list_head node;
	struct cftype___100 *cfts;
};

struct task_and_cgroup___96 {
	struct task_struct___270 *task;
	struct cgroup___164 *cgrp;
	struct css_set___164 *cg;
};

struct cgroup_taskset___96 {
	struct task_and_cgroup___96 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___164 *cur_cgrp;
};

struct cgroup_subsys___96 {
	struct cgroup_subsys_state___164 * (*css_alloc)(struct cgroup___164 *);
	int (*css_online)(struct cgroup___164 *);
	void (*css_offline)(struct cgroup___164 *);
	void (*css_free)(struct cgroup___164 *);
	int (*can_attach)(struct cgroup___164 *, struct cgroup_taskset___96 *);
	void (*cancel_attach)(struct cgroup___164 *, struct cgroup_taskset___96 *);
	void (*attach)(struct cgroup___164 *, struct cgroup_taskset___96 *);
	void (*fork)(struct task_struct___270 *);
	void (*exit)(struct cgroup___164 *, struct cgroup___164 *, struct task_struct___270 *);
	void (*bind)(struct cgroup___164 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___164 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___100 *base_cftypes;
	struct cftype_set___96 base_cftset;
	struct module *module;
};

struct request_sock_ops___34;

struct request_sock___35 {
	struct sock_common___48 __req_common;
	struct request_sock___35 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___34 *rsk_ops;
	struct sock___49 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___7;

struct xfrm_type___7;

struct xfrm_mode___7;

struct xfrm_state___7 {
	struct net___73 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___7 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___7 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___7 *type;
	struct xfrm_mode___7 *inner_mode;
	struct xfrm_mode___7 *inner_mode_iaf;
	struct xfrm_mode___7 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___7 {
	struct sk_buff_head___60 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___7 {
	struct net___73 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___7 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___61 {
	struct sk_buff___62 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___62 *, struct netlink_callback___61 *);
	int (*done)(struct netlink_callback___61 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___59 {
	int (*create)(struct sk_buff___62 *, struct net_device___59 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___62 *, unsigned char *);
	int (*rebuild)(struct sk_buff___62 *);
	int (*cache)(const struct neighbour___49 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___59 *, const unsigned char *);
};

struct napi_struct___59 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___59 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___59 *dev;
	struct sk_buff___62 *gro_list;
	struct sk_buff___62 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___59 {
	struct net_device___59 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___51 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___59 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___51 kobj;
	struct net_device___59 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___59 {
	int (*ndo_init)(struct net_device___59 *);
	void (*ndo_uninit)(struct net_device___59 *);
	int (*ndo_open)(struct net_device___59 *);
	int (*ndo_stop)(struct net_device___59 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___62 *, struct net_device___59 *);
	u16 (*ndo_select_queue)(struct net_device___59 *, struct sk_buff___62 *);
	void (*ndo_change_rx_flags)(struct net_device___59 *, int);
	void (*ndo_set_rx_mode)(struct net_device___59 *);
	int (*ndo_set_mac_address)(struct net_device___59 *, void *);
	int (*ndo_validate_addr)(struct net_device___59 *);
	int (*ndo_do_ioctl)(struct net_device___59 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___59 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___59 *, int);
	int (*ndo_neigh_setup)(struct net_device___59 *, struct neigh_parms___49 *);
	void (*ndo_tx_timeout)(struct net_device___59 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___59 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___59 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___59 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___59 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___59 *);
	int (*ndo_netpoll_setup)(struct net_device___59 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___59 *);
	int (*ndo_busy_poll)(struct napi_struct___59 *);
	int (*ndo_set_vf_mac)(struct net_device___59 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___59 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___59 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___59 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___59 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___59 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___59 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___59 *, int, struct sk_buff___62 *);
	int (*ndo_setup_tc)(struct net_device___59 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___59 *);
	int (*ndo_fcoe_disable)(struct net_device___59 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___59 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___59 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___59 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___59 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___59 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___59 *, const struct sk_buff___62 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___59 *, struct net_device___59 *);
	int (*ndo_del_slave)(struct net_device___59 *, struct net_device___59 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___49 *);
	void (*ndo_neigh_destroy)(struct neighbour___49 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___62 *, struct netlink_callback___61 *, struct net_device___59 *, int);
	int (*ndo_bridge_setlink)(struct net_device___59 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___62 *, u32, u32, struct net_device___59 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___59 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___59 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___59 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___59 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___59 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___59 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___62 *, struct net_device___59 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___59 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___59 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___59 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___49 {
	struct net___73 *net;
	struct net_device___59 *dev;
	struct neigh_parms___49 *next;
	int (*neigh_setup)(struct neighbour___49 *);
	void (*neigh_cleanup)(struct neighbour___49 *);
	struct neigh_table___49 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___25;

struct ifacaddr6___25;

struct inet6_dev___25 {
	struct net_device___59 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___25 *mc_list;
	struct ifmcaddr6___25 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___25 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___49 *nd_parms;
	struct inet6_dev___25 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___50 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___59 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___73 *, struct net_device___59 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___59 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___59 *, struct list_head *);
	size_t (*get_size)(const struct net_device___59 *);
	int (*fill_info)(struct sk_buff___62 *, const struct net_device___59 *);
	size_t (*get_xstats_size)(const struct net_device___59 *);
	int (*fill_xstats)(struct sk_buff___62 *, const struct net_device___59 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___73 * (*get_link_net)(const struct net_device___59 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___59 *, struct net_device___59 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___59 *, const struct net_device___59 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___62 *, const struct net_device___59 *, const struct net_device___59 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___49 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___62 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___49;

struct neigh_hash_table___49;

struct neigh_table___49 {
	struct neigh_table___49 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___59 *, __u32 *);
	int (*constructor)(struct neighbour___49 *);
	int (*pconstructor)(struct pneigh_entry___49 *);
	void (*pdestructor)(struct pneigh_entry___49 *);
	void (*proxy_redo)(struct sk_buff___62 *);
	char *id;
	struct neigh_parms___49 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___60 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___49 *nht;
	struct pneigh_entry___49 **phash_buckets;
};

struct neigh_ops___49 {
	int family;
	void (*solicit)(struct neighbour___49 *, struct sk_buff___62 *);
	void (*error_report)(struct neighbour___49 *, struct sk_buff___62 *);
	int (*output)(struct neighbour___49 *, struct sk_buff___62 *);
	int (*connected_output)(struct neighbour___49 *, struct sk_buff___62 *);
};

struct pneigh_entry___49 {
	struct pneigh_entry___49 *next;
	struct net___73 *net;
	struct net_device___59 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___49 {
	struct neighbour___49 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___20 {
	struct dst_entry___49 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___31;

struct inet_hashinfo___7;

struct proto___48 {
	void (*close)(struct sock___49 *, long int);
	int (*connect)(struct sock___49 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___49 *, int);
	struct sock___49 * (*accept)(struct sock___49 *, int, int *);
	int (*ioctl)(struct sock___49 *, int, long unsigned int);
	int (*init)(struct sock___49 *);
	void (*destroy)(struct sock___49 *);
	void (*shutdown)(struct sock___49 *, int);
	int (*setsockopt)(struct sock___49 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___49 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___49 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___49 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___49 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___56 *, struct sock___49 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___56 *, struct sock___49 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___49 *, struct page___268 *, int, size_t, int);
	int (*bind)(struct sock___49 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___49 *, struct sk_buff___62 *);
	void (*release_cb)(struct sock___49 *);
	void (*mtu_reduced)(struct sock___49 *);
	void (*hash)(struct sock___49 *);
	void (*unhash)(struct sock___49 *);
	void (*rehash)(struct sock___49 *);
	int (*get_port)(struct sock___49 *, short unsigned int);
	void (*clear_sk)(struct sock___49 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___49 *);
	void (*enter_memory_pressure)(struct sock___49 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___252 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___34 *rsk_prot;
	struct timewait_sock_ops___31 *twsk_prot;
	union {
		struct inet_hashinfo___7 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___96 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___48 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___48 {
	void (*enter_memory_pressure)(struct sock___49 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___7 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___252 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___34 {
	int family;
	int obj_size;
	struct kmem_cache___252 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___49 *, struct request_sock___35 *);
	void (*send_ack)(struct sock___49 *, struct sk_buff___62 *, struct request_sock___35 *);
	void (*send_reset)(struct sock___49 *, struct sk_buff___62 *);
	void (*destructor)(struct request_sock___35 *);
	void (*syn_ack_timeout)(struct sock___49 *, struct request_sock___35 *);
};

struct timewait_sock_ops___31 {
	struct kmem_cache___252 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___49 *, struct sock___49 *, void *);
	void (*twsk_destructor)(struct sock___49 *);
};

struct ifmcaddr6___25 {
	struct in6_addr mca_addr;
	struct inet6_dev___25 *idev;
	struct ifmcaddr6___25 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___25 {
	struct in6_addr aca_addr;
	struct inet6_dev___25 *aca_idev;
	struct rt6_info___7 *aca_rt;
	struct ifacaddr6___25 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct xfrm_replay___7 {
	void (*advance)(struct xfrm_state___7 *, __be32);
	int (*check)(struct xfrm_state___7 *, struct sk_buff___62 *, __be32);
	int (*recheck)(struct xfrm_state___7 *, struct sk_buff___62 *, __be32);
	void (*notify)(struct xfrm_state___7 *, int);
	int (*overflow)(struct xfrm_state___7 *, struct sk_buff___62 *);
};

struct xfrm_type___7 {
	char *description;
	struct module *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___7 *);
	void (*destructor)(struct xfrm_state___7 *);
	int (*input)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*output)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*reject)(struct xfrm_state___7 *, struct sk_buff___62 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___7 *, struct sk_buff___62 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___7 *, int);
};

struct xfrm_state_afinfo___7;

struct xfrm_mode___7 {
	int (*input2)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*input)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*output2)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*output)(struct xfrm_state___7 *, struct sk_buff___62 *);
	struct xfrm_state_afinfo___7 *afinfo;
	struct module *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___7 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module *owner;
	const struct xfrm_type___7 *type_map[256];
	struct xfrm_mode___7 *mode_map[5];
	int (*init_flags)(struct xfrm_state___7 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___7 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___7 **, struct xfrm_state___7 **, int);
	union {
		int (*output)(struct sock___49 *, struct sk_buff___62 *);
		struct {
			int (*output)(struct sk_buff___62 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___49 *, struct sk_buff___62 *);
		struct {
			int (*output_finish)(struct sk_buff___62 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*extract_output)(struct xfrm_state___7 *, struct sk_buff___62 *);
	int (*transport_finish)(struct sk_buff___62 *, int);
};

struct page___269;

typedef struct page___269 *pgtable_t___269;

struct address_space___270;

struct kmem_cache___253;

struct page___269 {
	long unsigned int flags;
	struct address_space___270 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___269 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___269 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___253 *slab_cache;
		struct page___269 *first_page;
	};
	long: 64;
};

struct task_struct___271;

struct pv_cpu_ops___271 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___271 *);
	void (*end_context_switch)(struct task_struct___271 *);
};

struct mutex___272 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___271 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___264 {
	struct page___269 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___278;

struct nsproxy___150;

struct signal_struct___271;

struct css_set___165;

struct task_struct___271 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___271 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___278 *mm;
	struct mm_struct___278 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___271 *real_parent;
	struct task_struct___271 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___271 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___271 = 0,
		VTIME_USER___271 = 1,
		VTIME_SYS___271 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___150 *nsproxy;
	struct signal_struct___271 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___165 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___272 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___264 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___278 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___278 *, struct mm_struct___278 *);
	void (*dup_mmap)(struct mm_struct___278 *, struct mm_struct___278 *);
	void (*exit_mmap)(struct mm_struct___278 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___278 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___278 *);
	void (*pgd_free)(struct mm_struct___278 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___278 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___278 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___278 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___278 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___278 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___278 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___278 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___278 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___278 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___278 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___278 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___272 lock;
	void *vdso;
} mm_context_t___272;

struct xol_area___269;

struct uprobes_state___269 {
	struct xol_area___269 *xol_area;
};

struct vm_area_struct___278;

struct file___270;

struct core_state___271;

struct mm_struct___278 {
	struct vm_area_struct___278 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___278 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___278 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___272 context;
	long unsigned int flags;
	struct core_state___271 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___271 *owner;
	struct file___270 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___269 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___52;

struct kobj_type___52;

struct kobject___52 {
	const char *name;
	struct list_head entry;
	struct kobject___52 *parent;
	struct kset___52 *kset;
	struct kobj_type___52 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___167;

struct module_kobject___166 {
	struct kobject___52 kobj;
	struct module___167 *mod;
	struct kobject___52 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___166;

struct module___167 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___166 mkobj;
	struct module_attribute___166 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___52 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___271 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___271;

struct lruvec___271 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___271 *zone;
};

struct pglist_data___271;

struct zone___271 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___271 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___271 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___271 {
	struct zone___271 *zone;
	int zone_idx;
};

struct zonelist___271 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___271 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___271 {
	struct zone___271 node_zones[4];
	struct zonelist___271 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___271 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___194;

struct x86_io_apic_ops___194 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___194 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___194;

struct irq_data___194 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___194 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___268;

struct dev_pm_ops___268 {
	int (*prepare)(struct device___268 *);
	void (*complete)(struct device___268 *);
	int (*suspend)(struct device___268 *);
	int (*resume)(struct device___268 *);
	int (*freeze)(struct device___268 *);
	int (*thaw)(struct device___268 *);
	int (*poweroff)(struct device___268 *);
	int (*restore)(struct device___268 *);
	int (*suspend_late)(struct device___268 *);
	int (*resume_early)(struct device___268 *);
	int (*freeze_late)(struct device___268 *);
	int (*thaw_early)(struct device___268 *);
	int (*poweroff_late)(struct device___268 *);
	int (*restore_early)(struct device___268 *);
	int (*suspend_noirq)(struct device___268 *);
	int (*resume_noirq)(struct device___268 *);
	int (*freeze_noirq)(struct device___268 *);
	int (*thaw_noirq)(struct device___268 *);
	int (*poweroff_noirq)(struct device___268 *);
	int (*restore_noirq)(struct device___268 *);
	int (*runtime_suspend)(struct device___268 *);
	int (*runtime_resume)(struct device___268 *);
	int (*runtime_idle)(struct device___268 *);
};

struct dev_pm_qos___71;

struct dev_pm_info___71 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___71 *qos;
};

struct dma_map_ops___133;

struct dev_archdata___133 {
	struct dma_map_ops___133 *dma_ops;
	void *iommu;
};

struct device_type___268;

struct bus_type___268;

struct device_driver___268;

struct dev_pm_domain___268;

struct class___268;

struct attribute_group___230;

struct device_rh___268;

struct device___268 {
	struct device___268 *parent;
	struct device_private *p;
	struct kobject___52 kobj;
	const char *init_name;
	const struct device_type___268 *type;
	struct mutex___272 mutex;
	struct bus_type___268 *bus;
	struct device_driver___268 *driver;
	void *platform_data;
	struct dev_pm_info___71 power;
	struct dev_pm_domain___268 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___133 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___35 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___268 *class;
	const struct attribute_group___230 **groups;
	void (*release)(struct device___268 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___268 *device_rh;
};

struct dev_pm_qos_request___72;

struct dev_pm_qos___71 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___72 *latency_req;
	struct dev_pm_qos_request___72 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___72 *latency_tolerance_req;
};

struct dev_pm_info_rh___268 {
	void (*set_latency_tolerance)(struct device___268 *, s32);
};

struct dev_pm_domain___268 {
	struct dev_pm_ops___268 ops;
};

struct smp_ops___271 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___271 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___75;

struct ctl_node___75 {
	struct rb_node node;
	struct ctl_table_header___75 *header;
};

struct ctl_table_root___75;

struct ctl_table_set___75;

struct ctl_dir___75;

struct ctl_table_header___75 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___75 *root;
	struct ctl_table_set___75 *set;
	struct ctl_dir___75 *parent;
	struct ctl_node___75 *node;
};

struct ctl_dir___75 {
	struct ctl_table_header___75 header;
	struct rb_root root;
};

struct ctl_table_set___75 {
	int (*is_seen)(struct ctl_table_set___75 *);
	struct ctl_dir___75 dir;
};

struct ctl_table_root___75 {
	struct ctl_table_set___75 default_set;
	struct ctl_table_set___75 * (*lookup)(struct ctl_table_root___75 *, struct nsproxy___150 *);
	int (*permissions)(struct ctl_table_header___75 *, struct ctl_table *);
};

struct net___74;

struct nsproxy___150 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___74 *net_ns;
};

struct sock___50;

struct kobj_ns_type_operations___49 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___50 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___49;

struct sock_common___49 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___49 *skc_prot;
	struct net___74 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___63;

struct sk_buff_head___61 {
	struct sk_buff___63 *next;
	struct sk_buff___63 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___50;

struct socket_wq___49;

struct xfrm_policy___8;

struct dst_entry___50;

struct socket___50;

struct cg_proto___49;

struct sock___50 {
	struct sock_common___49 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___61 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___63 *head;
		struct sk_buff___63 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___50 *sk_filter;
	struct socket_wq___49 *sk_wq;
	struct sk_buff_head___61 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___8 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___50 *sk_rx_dst;
	struct dst_entry___50 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___61 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___61 sk_error_queue;
	struct proto___49 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___50 *sk_socket;
	void *sk_user_data;
	struct page_frag___264 sk_frag;
	struct sk_buff___63 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___49 *sk_cgrp;
	void (*sk_state_change)(struct sock___50 *);
	void (*sk_data_ready)(struct sock___50 *, int);
	void (*sk_write_space)(struct sock___50 *);
	void (*sk_error_report)(struct sock___50 *);
	int (*sk_backlog_rcv)(struct sock___50 *, struct sk_buff___63 *);
	void (*sk_destruct)(struct sock___50 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___232;

struct attribute_group___230 {
	const char *name;
	umode_t (*is_visible)(struct kobject___52 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___232 **bin_attrs;
};

struct bin_attribute___232 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___270 *, struct kobject___52 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___270 *, struct kobject___52 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	int (*mmap)(struct file___270 *, struct kobject___52 *, struct bin_attribute___232 *, struct vm_area_struct___278 *);
};

struct dentry___270;

struct path___270 {
	struct vfsmount *mnt;
	struct dentry___270 *dentry;
};

struct inode___270;

struct file_operations___270;

struct file___270 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___270 f_path;
	struct inode___270 *f_inode;
	const struct file_operations___270 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___270 *f_mapping;
	struct mutex___272 f_pos_lock;
};

struct vm_operations_struct___244;

struct vm_area_struct___278 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___278 *vm_next;
	struct vm_area_struct___278 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___278 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___244 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___270 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___52 {
	ssize_t (*show)(struct kobject___52 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___52 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___52 *, const struct attribute *);
};

struct kset_uevent_ops___52;

struct kset___52 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___52 kobj;
	const struct kset_uevent_ops___52 *uevent_ops;
};

struct kobj_type___52 {
	void (*release)(struct kobject___52 *);
	const struct sysfs_ops___52 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___49 * (*child_ns_type)(struct kobject___52 *);
	const void * (*namespace)(struct kobject___52 *);
};

struct kset_uevent_ops___52 {
	int (* const filter)(struct kset___52 *, struct kobject___52 *);
	const char * (* const name)(struct kset___52 *, struct kobject___52 *);
	int (* const uevent)(struct kset___52 *, struct kobject___52 *, struct kobj_uevent_env *);
};

struct module_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___166 *, struct module_kobject___166 *, char *);
	ssize_t (*store)(struct module_attribute___166 *, struct module_kobject___166 *, const char *, size_t);
	void (*setup)(struct module___167 *, const char *);
	int (*test)(struct module___167 *);
	void (*free)(struct module___167 *);
};

struct xol_area___269 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___269 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___252;

struct memcg_cache_params___253;

struct kmem_cache___253 {
	struct kmem_cache_cpu___252 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___52 kobj;
	struct memcg_cache_params___253 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___270;

struct address_space___270 {
	struct inode___270 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___272 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___270 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___240;

struct vm_operations_struct___244 {
	void (*open)(struct vm_area_struct___278 *);
	void (*close)(struct vm_area_struct___278 *);
	int (*fault)(struct vm_area_struct___278 *, struct vm_fault___240 *);
	int (*page_mkwrite)(struct vm_area_struct___278 *, struct vm_fault___240 *);
	int (*access)(struct vm_area_struct___278 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___278 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___278 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___278 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___278 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___271 {
	struct task_struct___271 *task;
	struct core_thread___271 *next;
};

struct core_state___271 {
	atomic_t nr_threads;
	struct core_thread___271 dumper;
	struct completion startup;
};

struct vm_fault___240 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___269 *page;
};

struct dentry_operations___270;

struct super_block___270;

struct dentry___270 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___270 *d_parent;
	struct qstr d_name;
	struct inode___270 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___270 *d_op;
	struct super_block___270 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___270;

struct file_lock___270;

struct dquot___270;

struct block_device___270;

struct inode___270 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___270 *i_op;
	struct super_block___270 *i_sb;
	struct address_space___270 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___272 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___270 *i_fop;
	struct file_lock___270 *i_flock;
	struct address_space___270 i_data;
	struct dquot___270 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___270 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___270 {
	int (*d_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_hash)(const struct dentry___270 *, struct qstr *);
	int (*d_compare)(const struct dentry___270 *, const struct dentry___270 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___270 *);
	void (*d_release)(struct dentry___270 *);
	void (*d_prune)(struct dentry___270 *);
	void (*d_iput)(struct dentry___270 *, struct inode___270 *);
	char * (*d_dname)(struct dentry___270 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___270 *);
	int (*d_manage)(struct dentry___270 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___270;

struct mem_dqinfo___270 {
	struct quota_format_type___270 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___270;

struct quota_info___270 {
	unsigned int flags;
	struct mutex___272 dqio_mutex;
	struct mutex___272 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___270 *files[2];
	struct mem_dqinfo___270 info[2];
	const struct quota_format_ops___270 *ops[2];
};

struct file_system_type___270;

struct super_operations___270;

struct dquot_operations___270;

struct quotactl_ops___270;

struct xattr_handler___166;

struct super_block___270 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___270 *s_type;
	const struct super_operations___270 *s_op;
	const struct dquot_operations___270 *dq_op;
	const struct quotactl_ops___270 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___270 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___166 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___270 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___270 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___272 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___270 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___270 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___270 *bd_inode;
	struct super_block___270 *bd_super;
	struct mutex___272 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___270 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___272 bd_fsfreeze_mutex;
};

struct cgroup___165;

struct cgroup_subsys_state___165 {
	struct cgroup___165 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___57;

typedef int kiocb_cancel_fn___57(struct kiocb___57 *, struct io_event *);

struct kiocb___57 {
	atomic_t ki_users;
	struct file___270 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___57 *ki_cancel;
	void (*ki_dtor)(struct kiocb___57 *);
	union {
		void *user;
		struct task_struct___271 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___270 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___270 *ia_file;
};

struct dquot___270 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___272 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___270 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___270 {
	int qf_fmt_id;
	const struct quota_format_ops___270 *qf_ops;
	struct module___167 *qf_owner;
	struct quota_format_type___270 *qf_next;
};

struct quota_format_ops___270 {
	int (*check_quota_file)(struct super_block___270 *, int);
	int (*read_file_info)(struct super_block___270 *, int);
	int (*write_file_info)(struct super_block___270 *, int);
	int (*free_file_info)(struct super_block___270 *, int);
	int (*read_dqblk)(struct dquot___270 *);
	int (*commit_dqblk)(struct dquot___270 *);
	int (*release_dqblk)(struct dquot___270 *);
};

struct dquot_operations___270 {
	int (*write_dquot)(struct dquot___270 *);
	struct dquot___270 * (*alloc_dquot)(struct super_block___270 *, int);
	void (*destroy_dquot)(struct dquot___270 *);
	int (*acquire_dquot)(struct dquot___270 *);
	int (*release_dquot)(struct dquot___270 *);
	int (*mark_dirty)(struct dquot___270 *);
	int (*write_info)(struct super_block___270 *, int);
	qsize_t * (*get_reserved_space)(struct inode___270 *);
};

struct quotactl_ops___270 {
	int (*quota_on)(struct super_block___270 *, int, int, struct path___270 *);
	int (*quota_on_meta)(struct super_block___270 *, int, int);
	int (*quota_off)(struct super_block___270 *, int);
	int (*quota_sync)(struct super_block___270 *, int);
	int (*get_info)(struct super_block___270 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___270 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___270 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___270 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___270 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___270 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___270 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___270 *, unsigned int);
};

struct address_space_operations___270 {
	int (*writepage)(struct page___269 *, struct writeback_control *);
	int (*readpage)(struct file___270 *, struct page___269 *);
	int (*writepages)(struct address_space___270 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___269 *);
	int (*readpages)(struct file___270 *, struct address_space___270 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___270 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___269 **, void **);
	int (*write_end)(struct file___270 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___269 *, void *);
	sector_t (*bmap)(struct address_space___270 *, sector_t);
	void (*invalidatepage)(struct page___269 *, long unsigned int);
	int (*releasepage)(struct page___269 *, gfp_t);
	void (*freepage)(struct page___269 *);
	ssize_t (*direct_IO)(int, struct kiocb___57 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___270 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___270 *, struct page___269 *, struct page___269 *, enum migrate_mode);
	int (*launder_page)(struct page___269 *);
	int (*is_partially_uptodate)(struct page___269 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___269 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___270 *, struct page___269 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___270 *, sector_t *);
	void (*swap_deactivate)(struct file___270 *);
	void (*invalidatepage_range)(struct page___269 *, unsigned int, unsigned int);
};

struct inode_operations___270 {
	struct dentry___270 * (*lookup)(struct inode___270 *, struct dentry___270 *, unsigned int);
	void * (*follow_link)(struct dentry___270 *, struct nameidata *);
	int (*permission)(struct inode___270 *, int);
	struct posix_acl * (*get_acl)(struct inode___270 *, int);
	int (*readlink)(struct dentry___270 *, char *, int);
	void (*put_link)(struct dentry___270 *, struct nameidata *, void *);
	int (*create)(struct inode___270 *, struct dentry___270 *, umode_t, bool);
	int (*link)(struct dentry___270 *, struct inode___270 *, struct dentry___270 *);
	int (*unlink)(struct inode___270 *, struct dentry___270 *);
	int (*symlink)(struct inode___270 *, struct dentry___270 *, const char *);
	int (*mkdir)(struct inode___270 *, struct dentry___270 *, umode_t);
	int (*rmdir)(struct inode___270 *, struct dentry___270 *);
	int (*mknod)(struct inode___270 *, struct dentry___270 *, umode_t, dev_t);
	int (*rename)(struct inode___270 *, struct dentry___270 *, struct inode___270 *, struct dentry___270 *);
	int (*setattr)(struct dentry___270 *, struct iattr___270 *);
	int (*getattr)(struct vfsmount *, struct dentry___270 *, struct kstat *);
	int (*setxattr)(struct dentry___270 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___270 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___270 *, char *, size_t);
	int (*removexattr)(struct dentry___270 *, const char *);
	int (*fiemap)(struct inode___270 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___270 *, struct timespec *, int);
	int (*atomic_open)(struct inode___270 *, struct dentry___270 *, struct file___270 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___156;

struct seq_file___195;

struct file_operations___270 {
	struct module___167 *owner;
	loff_t (*llseek)(struct file___270 *, loff_t, int);
	ssize_t (*read)(struct file___270 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___270 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___57 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___57 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___270 *, void *, filldir_t);
	unsigned int (*poll)(struct file___270 *, struct poll_table_struct___156 *);
	long int (*unlocked_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___270 *, struct vm_area_struct___278 *);
	int (*open)(struct inode___270 *, struct file___270 *);
	int (*flush)(struct file___270 *, fl_owner_t);
	int (*release)(struct inode___270 *, struct file___270 *);
	int (*fsync)(struct file___270 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___57 *, int);
	int (*fasync)(int, struct file___270 *, int);
	int (*lock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*sendpage)(struct file___270 *, struct page___269 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___270 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___270 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___270 *, long int, struct file_lock___270 **, void **);
		struct {
			int (*setlease)(struct file___270 *, long int, struct file_lock___270 **);
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long int (*fallocate)(struct file___270 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___195 *, struct file___270 *);
};

struct fasync_struct___270;

struct file_lock_operations___270;

struct lock_manager_operations___270;

struct file_lock___270 {
	struct file_lock___270 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___270 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___270 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___270 *fl_ops;
	const struct lock_manager_operations___270 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___270 {
	void (*fl_copy_lock)(struct file_lock___270 *, struct file_lock___270 *);
	void (*fl_release_private)(struct file_lock___270 *);
};

struct lock_manager_operations___270 {
	int (*lm_compare_owner)(struct file_lock___270 *, struct file_lock___270 *);
	long unsigned int (*lm_owner_key)(struct file_lock___270 *);
	void (*lm_notify)(struct file_lock___270 *);
	int (*lm_grant)(struct file_lock___270 *, struct file_lock___270 *, int);
	void (*lm_break)(struct file_lock___270 *);
	int (*lm_change)(struct file_lock___270 **, int);
};

struct fasync_struct___270 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___270 *fa_next;
	struct file___270 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___270 {
	const char *name;
	int fs_flags;
	struct dentry___270 * (*mount)(struct file_system_type___270 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___270 *);
	struct module___167 *owner;
	struct file_system_type___270 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___270 {
	struct inode___270 * (*alloc_inode)(struct super_block___270 *);
	void (*destroy_inode)(struct inode___270 *);
	void (*dirty_inode)(struct inode___270 *, int);
	int (*write_inode)(struct inode___270 *, struct writeback_control *);
	int (*drop_inode)(struct inode___270 *);
	void (*evict_inode)(struct inode___270 *);
	void (*put_super)(struct super_block___270 *);
	int (*sync_fs)(struct super_block___270 *, int);
	int (*freeze_fs)(struct super_block___270 *);
	int (*unfreeze_fs)(struct super_block___270 *);
	int (*statfs)(struct dentry___270 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___270 *, int *, char *);
	void (*umount_begin)(struct super_block___270 *);
	int (*show_options)(struct seq_file___195 *, struct dentry___270 *);
	int (*show_devname)(struct seq_file___195 *, struct dentry___270 *);
	int (*show_path)(struct seq_file___195 *, struct dentry___270 *);
	int (*show_stats)(struct seq_file___195 *, struct dentry___270 *);
	ssize_t (*quota_read)(struct super_block___270 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___270 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___270 *);
	int (*bdev_try_to_free_page)(struct super_block___270 *, struct page___269 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___270 *);
	void (*free_cached_objects)(struct super_block___270 *, int);
};

struct xattr_handler___166 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___270 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___270 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___270 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___158)(struct file___270 *, wait_queue_head_t *, struct poll_table_struct___156 *);

struct poll_table_struct___156 {
	poll_queue_proc___158 _qproc;
	long unsigned int _key;
};

struct seq_operations___195;

struct seq_file___195 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___272 lock;
	const struct seq_operations___195 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct irq_chip___194 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___194 *);
	void (*irq_shutdown)(struct irq_data___194 *);
	void (*irq_enable)(struct irq_data___194 *);
	void (*irq_disable)(struct irq_data___194 *);
	void (*irq_ack)(struct irq_data___194 *);
	void (*irq_mask)(struct irq_data___194 *);
	void (*irq_mask_ack)(struct irq_data___194 *);
	void (*irq_unmask)(struct irq_data___194 *);
	void (*irq_eoi)(struct irq_data___194 *);
	int (*irq_set_affinity)(struct irq_data___194 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___194 *);
	int (*irq_set_type)(struct irq_data___194 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___194 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___194 *);
	void (*irq_bus_sync_unlock)(struct irq_data___194 *);
	void (*irq_cpu_online)(struct irq_data___194 *);
	void (*irq_cpu_offline)(struct irq_data___194 *);
	void (*irq_suspend)(struct irq_data___194 *);
	void (*irq_resume)(struct irq_data___194 *);
	void (*irq_pm_shutdown)(struct irq_data___194 *);
	void (*irq_print_chip)(struct irq_data___194 *, struct seq_file___195 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___194 *, void *);
	long unsigned int flags;
};

struct kmem_cache_cpu___252 {
	void **freelist;
	long unsigned int tid;
	struct page___269 *page;
	struct page___269 *partial;
};

struct memcg_cache_params___253 {
	bool is_root_cache;
	union {
		struct kmem_cache___253 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___253 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___133 {
	void * (*alloc)(struct device___268 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___268 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___268 *, struct vm_area_struct___278 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___268 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___268 *, struct page___269 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___268 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___268 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___268 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___268 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___268 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___268 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___268 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___268 *, dma_addr_t);
	int (*dma_supported)(struct device___268 *, u64);
	int (*set_dma_mask)(struct device___268 *, u64);
	int is_phys;
};

struct bus_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___268 *, char *);
	ssize_t (*store)(struct bus_type___268 *, const char *, size_t);
};

struct device_attribute___268;

struct driver_attribute___268;

struct bus_type___268 {
	const char *name;
	const char *dev_name;
	struct device___268 *dev_root;
	struct bus_attribute___268 *bus_attrs;
	struct device_attribute___268 *dev_attrs;
	struct driver_attribute___268 *drv_attrs;
	const struct attribute_group___230 **bus_groups;
	const struct attribute_group___230 **dev_groups;
	const struct attribute_group___230 **drv_groups;
	int (*match)(struct device___268 *, struct device_driver___268 *);
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	int (*probe)(struct device___268 *);
	int (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*online)(struct device___268 *);
	int (*offline)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct device___268 *, struct device_attribute___268 *, char *);
	ssize_t (*store)(struct device___268 *, struct device_attribute___268 *, const char *, size_t);
};

struct driver_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___268 *, char *);
	ssize_t (*store)(struct device_driver___268 *, const char *, size_t);
};

struct device_driver___268 {
	const char *name;
	struct bus_type___268 *bus;
	struct module___167 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___268 *);
	int (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	const struct attribute_group___230 **groups;
	const struct dev_pm_ops___268 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___268 {
	const char *name;
	const struct attribute_group___230 **groups;
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
};

struct class_attribute___268;

struct class___268 {
	const char *name;
	struct module___167 *owner;
	struct class_attribute___268 *class_attrs;
	struct device_attribute___268 *dev_attrs;
	const struct attribute_group___230 **dev_groups;
	struct bin_attribute___232 *dev_bin_attrs;
	struct kobject___52 *dev_kobj;
	int (*dev_uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *);
	void (*class_release)(struct class___268 *);
	void (*dev_release)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	const struct kobj_ns_type_operations___49 *ns_type;
	const void * (*namespace)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
	struct subsys_private *p;
};

struct class_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct class___268 *, struct class_attribute___268 *, char *);
	ssize_t (*store)(struct class___268 *, struct class_attribute___268 *, const char *, size_t);
	const void * (*namespace)(struct class___268 *, const struct class_attribute___268 *);
};

struct device_rh___268 {
	struct dev_pm_info_rh___268 power;
};

struct dev_pm_qos_request___72 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___268 *dev;
};

struct signal_struct___271 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___271 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___271 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___272 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___165 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___165 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___49 {
	wait_queue_head_t wait;
	struct fasync_struct___270 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___49;

struct socket___50 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___49 *wq;
	struct file___270 *file;
	struct sock___50 *sk;
	const struct proto_ops___49 *ops;
};

struct proto_ops___49 {
	int family;
	struct module___167 *owner;
	int (*release)(struct socket___50 *);
	int (*bind)(struct socket___50 *, struct sockaddr *, int);
	int (*connect)(struct socket___50 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___50 *, struct socket___50 *);
	int (*accept)(struct socket___50 *, struct socket___50 *, int);
	int (*getname)(struct socket___50 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___270 *, struct socket___50 *, struct poll_table_struct___156 *);
	int (*ioctl)(struct socket___50 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___50 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___50 *, int);
	int (*shutdown)(struct socket___50 *, int);
	int (*setsockopt)(struct socket___50 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___50 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___50 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___50 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___57 *, struct socket___50 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___57 *, struct socket___50 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___270 *, struct socket___50 *, struct vm_area_struct___278 *);
	ssize_t (*sendpage)(struct socket___50 *, struct page___269 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___50 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___50 *, int);
		struct {
			void (*set_peek_off)(struct sock___50 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___72 {
	struct ctl_table_header___75 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___73 {
	struct mutex___272 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___72 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___75 *ctl;
};

struct netns_ipv4___72 {
	struct ctl_table_header___75 *forw_hdr;
	struct ctl_table_header___75 *frags_hdr;
	struct ctl_table_header___75 *ipv4_hdr;
	struct ctl_table_header___75 *route_hdr;
	struct ctl_table_header___75 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___50 *fibnl;
	struct sock___50 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___72 {
	struct ctl_table_header___75 *hdr;
	struct ctl_table_header___75 *route_hdr;
	struct ctl_table_header___75 *icmp_hdr;
	struct ctl_table_header___75 *frags_hdr;
	struct ctl_table_header___75 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___60;

struct neighbour___50;

struct dst_ops___74 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___74 *);
	struct dst_entry___50 * (*check)(struct dst_entry___50 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___50 *);
	unsigned int (*mtu)(const struct dst_entry___50 *);
	u32 * (*cow_metrics)(struct dst_entry___50 *, long unsigned int);
	void (*destroy)(struct dst_entry___50 *);
	void (*ifdown)(struct dst_entry___50 *, struct net_device___60 *, int);
	struct dst_entry___50 * (*negative_advice)(struct dst_entry___50 *);
	void (*link_failure)(struct sk_buff___63 *);
	void (*update_pmtu)(struct dst_entry___50 *, struct sock___50 *, struct sk_buff___63 *, u32);
	void (*redirect)(struct dst_entry___50 *, struct sock___50 *, struct sk_buff___63 *);
	int (*local_out)(struct sk_buff___63 *);
	struct neighbour___50 * (*neigh_lookup)(const struct dst_entry___50 *, struct sk_buff___63 *, const void *);
	struct kmem_cache___253 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___8;

struct fib6_table___8;

struct netns_ipv6___74 {
	struct netns_sysctl_ipv6___72 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___8 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___8 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___74 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___8 *ip6_prohibit_entry;
	struct rt6_info___8 *ip6_blk_hole_entry;
	struct fib6_table___8 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___50 **icmp_sk;
	struct sock___50 *ndisc_sk;
	struct sock___50 *tcp_sk;
	struct sock___50 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___72 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___75 *sysctl_header;
	struct sock___50 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___49 {
	struct sock___50 *v4_ctl_sk;
	struct sock___50 *v6_ctl_sk;
};

struct netns_nf___72 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___75 *nf_log_dir_header;
};

struct nf_proto_net___72 {
	struct ctl_table_header___75 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___72 {
	struct nf_proto_net___72 pn;
	unsigned int timeout;
};

struct nf_tcp_net___72 {
	struct nf_proto_net___72 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___72 {
	struct nf_proto_net___72 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___72 {
	struct nf_proto_net___72 pn;
	unsigned int timeout;
};

struct nf_ip_net___72 {
	struct nf_generic_net___72 generic;
	struct nf_tcp_net___72 tcp;
	struct nf_udp_net___72 udp;
	struct nf_icmp_net___72 icmp;
	struct nf_icmp_net___72 icmpv6;
};

struct netns_ct___73 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___75 *sysctl_header;
	struct ctl_table_header___75 *acct_sysctl_header;
	struct ctl_table_header___75 *tstamp_sysctl_header;
	struct ctl_table_header___75 *event_sysctl_header;
	struct ctl_table_header___75 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___253 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___72 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___72 {
	struct netns_sysctl_ipv6___72 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___74 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___50 *nlsk;
	struct sock___50 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___75 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___74 xfrm4_dst_ops;
	struct dst_ops___74 xfrm6_dst_ops;
};

struct net___74 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___75 sysctls;
	struct sock___50 *rtnl;
	struct sock___50 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___60 *loopback_dev;
	struct netns_core___72 core;
	struct netns_mib mib;
	struct netns_packet___73 packet;
	struct netns_unix___72 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___72 ipv4;
	struct netns_ipv6___74 ipv6;
	struct netns_sctp___72 sctp;
	struct netns_dccp___49 dccp;
	struct netns_nf___72 nf;
	struct netns_xt xt;
	struct netns_ct___73 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___72 nf_frag;
	struct sock___50 *nfnl;
	struct sock___50 *nfnl_stash;
	struct sk_buff_head___61 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___74 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___50 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___50 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___272 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___272 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___60 {
	atomic_t use;
	unsigned int mask;
	struct net_device___60 *physindev;
	struct net_device___60 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___60(struct sk_buff___63 **);

struct net_device_ops___60;

struct ethtool_ops___60;

struct header_ops___60;

struct inet6_dev___26;

struct netdev_rx_queue___60;

struct netdev_queue___60;

struct rtnl_link_ops___51;

struct dcbnl_rtnl_ops___60;

struct net_device___60 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___60 *netdev_ops;
	const struct ethtool_ops___60 *ethtool_ops;
	const struct header_ops___60 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___52 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___26 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___60 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___60 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___60 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___60 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___60 = 0,
		NETREG_REGISTERED___60 = 1,
		NETREG_UNREGISTERING___60 = 2,
		NETREG_UNREGISTERED___60 = 3,
		NETREG_RELEASED___60 = 4,
		NETREG_DUMMY___60 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___60 = 0,
		RTNL_LINK_INITIALIZING___60 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___60 *);
	struct netpoll_info *npinfo;
	struct net___74 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___268 dev;
	const struct attribute_group___230 *sysfs_groups[4];
	const struct rtnl_link_ops___51 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___60 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___8;

struct sk_buff___63 {
	struct sk_buff___63 *next;
	struct sk_buff___63 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___50 *sk;
	struct net_device___60 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___8 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___63 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___60 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___13 {
	struct {
		struct page___269 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___13 skb_frag_t___13;

struct skb_shared_info___13 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___63 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___13 frags[17];
};

struct xfrm_state___8;

struct sec_path___8 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___8 *xvec[6];
};

struct ethtool_ops___60 {
	int (*get_settings)(struct net_device___60 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___60 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___60 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___60 *);
	void (*get_regs)(struct net_device___60 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___60 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___60 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___60 *);
	void (*set_msglevel)(struct net_device___60 *, u32);
	int (*nway_reset)(struct net_device___60 *);
	u32 (*get_link)(struct net_device___60 *);
	int (*get_eeprom_len)(struct net_device___60 *);
	int (*get_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___60 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___60 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___60 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___60 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___60 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___60 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___60 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___60 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___60 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___60 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___60 *);
	void (*complete)(struct net_device___60 *);
	u32 (*get_priv_flags)(struct net_device___60 *);
	int (*set_priv_flags)(struct net_device___60 *, u32);
	int (*get_sset_count)(struct net_device___60 *, int);
	int (*get_rxnfc)(struct net_device___60 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___60 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___60 *, struct ethtool_flash *);
	int (*reset)(struct net_device___60 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___60 *);
	int (*get_rxfh_indir)(struct net_device___60 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___60 *, const u32 *);
	void (*get_channels)(struct net_device___60 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___60 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___60 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___60 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___60 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___60 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___60 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___60 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___60 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___60 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___60 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___60 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___21;

struct dst_entry___50 {
	struct callback_head callback_head;
	struct dst_entry___50 *child;
	struct net_device___60 *dev;
	struct dst_ops___74 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___50 *path;
	struct dst_entry___50 *from;
	struct xfrm_state___8 *xfrm;
	int (*input)(struct sk_buff___63 *);
	union {
		int (*output)(struct sock___50 *, struct sk_buff___63 *);
		struct {
			int (*output)(struct sk_buff___63 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___50 *next;
		struct rtable___21 *rt_next;
		struct rt6_info___8 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___50;

struct neigh_parms___50;

struct neigh_ops___50;

struct neighbour___50 {
	struct neighbour___50 *next;
	struct neigh_table___50 *tbl;
	struct neigh_parms___50 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___61 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___50 *, struct sk_buff___63 *);
	const struct neigh_ops___50 *ops;
	struct callback_head rcu;
	struct net_device___60 *dev;
	u8 primary_key[0];
};

struct fib6_node___8;

struct rt6_info___8 {
	struct dst_entry___50 dst;
	struct fib6_table___8 *rt6i_table;
	struct fib6_node___8 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___26 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___8 {
	struct fib6_node___8 *parent;
	struct fib6_node___8 *left;
	struct fib6_node___8 *right;
	struct rt6_info___8 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___8 *rr_ptr;
};

struct fib6_table___8 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___8 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___8 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___60 *in;
	struct net_device___60 *out;
	struct sock___50 *sk;
	int (*okfn)(struct sock___50 *, struct sk_buff___63 *);
};

struct nf_afinfo___74 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___63 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___63 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___74 *, struct dst_entry___50 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___63 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___63 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___195 {
	void * (*start)(struct seq_file___195 *, loff_t *);
	void (*stop)(struct seq_file___195 *, void *);
	void * (*next)(struct seq_file___195 *, void *, loff_t *);
	int (*show)(struct seq_file___195 *, void *);
};

struct dcbnl_rtnl_ops___60 {
	int (*ieee_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___60 *);
	u8 (*setstate)(struct net_device___60 *, u8);
	void (*getpermhwaddr)(struct net_device___60 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___60 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___60 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___60 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___60 *, int, u8 *);
	void (*setpfccfg)(struct net_device___60 *, int, u8);
	void (*getpfccfg)(struct net_device___60 *, int, u8 *);
	u8 (*setall)(struct net_device___60 *);
	u8 (*getcap)(struct net_device___60 *, int, u8 *);
	int (*getnumtcs)(struct net_device___60 *, int, u8 *);
	int (*setnumtcs)(struct net_device___60 *, int, u8);
	u8 (*getpfcstate)(struct net_device___60 *);
	void (*setpfcstate)(struct net_device___60 *, u8);
	void (*getbcncfg)(struct net_device___60 *, int, u32 *);
	void (*setbcncfg)(struct net_device___60 *, int, u32);
	void (*getbcnrp)(struct net_device___60 *, int, u8 *);
	void (*setbcnrp)(struct net_device___60 *, int, u8);
	u8 (*setapp)(struct net_device___60 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___60 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___60 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___60 *, int, u8);
	u8 (*getdcbx)(struct net_device___60 *);
	u8 (*setdcbx)(struct net_device___60 *, u8);
	int (*peer_getappinfo)(struct net_device___60 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___60 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___60 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___60 *, struct cee_pfc *);
};

struct cgroupfs_root___165;

struct cgroup___165 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___165 *parent;
	struct dentry___270 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___165 *subsys[11];
	struct cgroupfs_root___165 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___272 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___165 {
	struct super_block___270 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___165 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___101 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___270 *, struct file___270 *);
	ssize_t (*read)(struct cgroup___165 *, struct cftype___101 *, struct file___270 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___165 *, struct cftype___101 *);
	s64 (*read_s64)(struct cgroup___165 *, struct cftype___101 *);
	int (*read_map)(struct cgroup___165 *, struct cftype___101 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___165 *, struct cftype___101 *, struct seq_file___195 *);
	ssize_t (*write)(struct cgroup___165 *, struct cftype___101 *, struct file___270 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___165 *, struct cftype___101 *, u64);
	int (*write_s64)(struct cgroup___165 *, struct cftype___101 *, s64);
	int (*write_string)(struct cgroup___165 *, struct cftype___101 *, const char *);
	int (*trigger)(struct cgroup___165 *, unsigned int);
	int (*release)(struct inode___270 *, struct file___270 *);
	int (*register_event)(struct cgroup___165 *, struct cftype___101 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___165 *, struct cftype___101 *, struct eventfd_ctx *);
};

struct cftype_set___97 {
	struct list_head node;
	struct cftype___101 *cfts;
};

struct task_and_cgroup___97 {
	struct task_struct___271 *task;
	struct cgroup___165 *cgrp;
	struct css_set___165 *cg;
};

struct cgroup_taskset___97 {
	struct task_and_cgroup___97 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___165 *cur_cgrp;
};

struct cgroup_subsys___97 {
	struct cgroup_subsys_state___165 * (*css_alloc)(struct cgroup___165 *);
	int (*css_online)(struct cgroup___165 *);
	void (*css_offline)(struct cgroup___165 *);
	void (*css_free)(struct cgroup___165 *);
	int (*can_attach)(struct cgroup___165 *, struct cgroup_taskset___97 *);
	void (*cancel_attach)(struct cgroup___165 *, struct cgroup_taskset___97 *);
	void (*attach)(struct cgroup___165 *, struct cgroup_taskset___97 *);
	void (*fork)(struct task_struct___271 *);
	void (*exit)(struct cgroup___165 *, struct cgroup___165 *, struct task_struct___271 *);
	void (*bind)(struct cgroup___165 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___165 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___101 *base_cftypes;
	struct cftype_set___97 base_cftset;
	struct module___167 *module;
};

struct request_sock_ops___35;

struct request_sock___36 {
	struct sock_common___49 __req_common;
	struct request_sock___36 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___35 *rsk_ops;
	struct sock___50 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___8;

struct xfrm_type___8;

struct xfrm_mode___8;

struct xfrm_state___8 {
	struct net___74 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___8 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___8 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___8 *type;
	struct xfrm_mode___8 *inner_mode;
	struct xfrm_mode___8 *inner_mode_iaf;
	struct xfrm_mode___8 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___8 {
	struct sk_buff_head___61 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___8 {
	struct net___74 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___8 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___62 {
	struct sk_buff___63 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___63 *, struct netlink_callback___62 *);
	int (*done)(struct netlink_callback___62 *);
	void *data;
	struct module___167 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___60 {
	int (*create)(struct sk_buff___63 *, struct net_device___60 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___63 *, unsigned char *);
	int (*rebuild)(struct sk_buff___63 *);
	int (*cache)(const struct neighbour___50 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___60 *, const unsigned char *);
};

struct napi_struct___60 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___60 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___60 *dev;
	struct sk_buff___63 *gro_list;
	struct sk_buff___63 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___60 {
	struct net_device___60 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___52 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___60 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___52 kobj;
	struct net_device___60 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___60 {
	int (*ndo_init)(struct net_device___60 *);
	void (*ndo_uninit)(struct net_device___60 *);
	int (*ndo_open)(struct net_device___60 *);
	int (*ndo_stop)(struct net_device___60 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___63 *, struct net_device___60 *);
	u16 (*ndo_select_queue)(struct net_device___60 *, struct sk_buff___63 *);
	void (*ndo_change_rx_flags)(struct net_device___60 *, int);
	void (*ndo_set_rx_mode)(struct net_device___60 *);
	int (*ndo_set_mac_address)(struct net_device___60 *, void *);
	int (*ndo_validate_addr)(struct net_device___60 *);
	int (*ndo_do_ioctl)(struct net_device___60 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___60 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___60 *, int);
	int (*ndo_neigh_setup)(struct net_device___60 *, struct neigh_parms___50 *);
	void (*ndo_tx_timeout)(struct net_device___60 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___60 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___60 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___60 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___60 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___60 *);
	int (*ndo_netpoll_setup)(struct net_device___60 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___60 *);
	int (*ndo_busy_poll)(struct napi_struct___60 *);
	int (*ndo_set_vf_mac)(struct net_device___60 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___60 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___60 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___60 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___60 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___60 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___60 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___60 *, int, struct sk_buff___63 *);
	int (*ndo_setup_tc)(struct net_device___60 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___60 *);
	int (*ndo_fcoe_disable)(struct net_device___60 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___60 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___60 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___60 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___60 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___60 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___60 *, const struct sk_buff___63 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___60 *, struct net_device___60 *);
	int (*ndo_del_slave)(struct net_device___60 *, struct net_device___60 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___50 *);
	void (*ndo_neigh_destroy)(struct neighbour___50 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___63 *, struct netlink_callback___62 *, struct net_device___60 *, int);
	int (*ndo_bridge_setlink)(struct net_device___60 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___63 *, u32, u32, struct net_device___60 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___60 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___60 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___60 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___60 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___60 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___60 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___63 *, struct net_device___60 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___60 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___60 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___60 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___50 {
	struct net___74 *net;
	struct net_device___60 *dev;
	struct neigh_parms___50 *next;
	int (*neigh_setup)(struct neighbour___50 *);
	void (*neigh_cleanup)(struct neighbour___50 *);
	struct neigh_table___50 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___26;

struct ifacaddr6___26;

struct inet6_dev___26 {
	struct net_device___60 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___26 *mc_list;
	struct ifmcaddr6___26 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___26 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___50 *nd_parms;
	struct inet6_dev___26 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___51 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___60 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___74 *, struct net_device___60 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___60 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___60 *, struct list_head *);
	size_t (*get_size)(const struct net_device___60 *);
	int (*fill_info)(struct sk_buff___63 *, const struct net_device___60 *);
	size_t (*get_xstats_size)(const struct net_device___60 *);
	int (*fill_xstats)(struct sk_buff___63 *, const struct net_device___60 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___74 * (*get_link_net)(const struct net_device___60 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___60 *, struct net_device___60 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___60 *, const struct net_device___60 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___63 *, const struct net_device___60 *, const struct net_device___60 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___50 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___63 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___50;

struct neigh_hash_table___50;

struct neigh_table___50 {
	struct neigh_table___50 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___60 *, __u32 *);
	int (*constructor)(struct neighbour___50 *);
	int (*pconstructor)(struct pneigh_entry___50 *);
	void (*pdestructor)(struct pneigh_entry___50 *);
	void (*proxy_redo)(struct sk_buff___63 *);
	char *id;
	struct neigh_parms___50 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___61 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___50 *nht;
	struct pneigh_entry___50 **phash_buckets;
};

struct neigh_ops___50 {
	int family;
	void (*solicit)(struct neighbour___50 *, struct sk_buff___63 *);
	void (*error_report)(struct neighbour___50 *, struct sk_buff___63 *);
	int (*output)(struct neighbour___50 *, struct sk_buff___63 *);
	int (*connected_output)(struct neighbour___50 *, struct sk_buff___63 *);
};

struct pneigh_entry___50 {
	struct pneigh_entry___50 *next;
	struct net___74 *net;
	struct net_device___60 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___50 {
	struct neighbour___50 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___21 {
	struct dst_entry___50 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___32;

struct proto___49 {
	void (*close)(struct sock___50 *, long int);
	int (*connect)(struct sock___50 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___50 *, int);
	struct sock___50 * (*accept)(struct sock___50 *, int, int *);
	int (*ioctl)(struct sock___50 *, int, long unsigned int);
	int (*init)(struct sock___50 *);
	void (*destroy)(struct sock___50 *);
	void (*shutdown)(struct sock___50 *, int);
	int (*setsockopt)(struct sock___50 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___50 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___50 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___50 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___50 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___57 *, struct sock___50 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___57 *, struct sock___50 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___50 *, struct page___269 *, int, size_t, int);
	int (*bind)(struct sock___50 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___50 *, struct sk_buff___63 *);
	void (*release_cb)(struct sock___50 *);
	void (*mtu_reduced)(struct sock___50 *);
	void (*hash)(struct sock___50 *);
	void (*unhash)(struct sock___50 *);
	void (*rehash)(struct sock___50 *);
	int (*get_port)(struct sock___50 *, short unsigned int);
	void (*clear_sk)(struct sock___50 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___50 *);
	void (*enter_memory_pressure)(struct sock___50 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___253 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___35 *rsk_prot;
	struct timewait_sock_ops___32 *twsk_prot;
	union {
		struct inet_hashinfo___7 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___167 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___97 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___49 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___49 {
	void (*enter_memory_pressure)(struct sock___50 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___35 {
	int family;
	int obj_size;
	struct kmem_cache___253 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___50 *, struct request_sock___36 *);
	void (*send_ack)(struct sock___50 *, struct sk_buff___63 *, struct request_sock___36 *);
	void (*send_reset)(struct sock___50 *, struct sk_buff___63 *);
	void (*destructor)(struct request_sock___36 *);
	void (*syn_ack_timeout)(struct sock___50 *, struct request_sock___36 *);
};

struct timewait_sock_ops___32 {
	struct kmem_cache___253 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___50 *, struct sock___50 *, void *);
	void (*twsk_destructor)(struct sock___50 *);
};

struct ip_options_data {
	struct ip_options_rcu opt;
	char data[40];
};

struct inet_cork___7 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___50 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___7 {
	struct inet_cork___7 base;
	struct flowi fl;
};

struct ipv6_pinfo___6;

struct inet_sock___7 {
	struct sock___50 sk;
	struct ipv6_pinfo___6 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___7 cork;
};

struct ipv6_fl_socklist___5;

struct ipv6_pinfo___6 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___5 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___63 *pktoptions;
	struct sk_buff___63 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___5;

struct ipv6_fl_socklist___5 {
	struct ipv6_fl_socklist___5 *next;
	struct ip6_flowlabel___5 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___26 {
	struct in6_addr mca_addr;
	struct inet6_dev___26 *idev;
	struct ifmcaddr6___26 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___26 {
	struct in6_addr aca_addr;
	struct inet6_dev___26 *aca_idev;
	struct rt6_info___8 *aca_rt;
	struct ifacaddr6___26 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___5 {
	struct ip6_flowlabel___5 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___74 *fl_net;
};

struct ipcm_cookie {
	__be32 addr;
	int oif;
	struct ip_options_rcu *opt;
	__u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct ip_reply_arg {
	struct kvec iov[1];
	int flags;
	__wsum csum;
	int csumoffset;
	int bound_dev_if;
	u8 tos;
};

struct xfrm_replay___8 {
	void (*advance)(struct xfrm_state___8 *, __be32);
	int (*check)(struct xfrm_state___8 *, struct sk_buff___63 *, __be32);
	int (*recheck)(struct xfrm_state___8 *, struct sk_buff___63 *, __be32);
	void (*notify)(struct xfrm_state___8 *, int);
	int (*overflow)(struct xfrm_state___8 *, struct sk_buff___63 *);
};

struct xfrm_type___8 {
	char *description;
	struct module___167 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___8 *);
	void (*destructor)(struct xfrm_state___8 *);
	int (*input)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*output)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*reject)(struct xfrm_state___8 *, struct sk_buff___63 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___8 *, struct sk_buff___63 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___8 *, int);
};

struct xfrm_state_afinfo___8;

struct xfrm_mode___8 {
	int (*input2)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*input)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*output2)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*output)(struct xfrm_state___8 *, struct sk_buff___63 *);
	struct xfrm_state_afinfo___8 *afinfo;
	struct module___167 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___8 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___167 *owner;
	const struct xfrm_type___8 *type_map[256];
	struct xfrm_mode___8 *mode_map[5];
	int (*init_flags)(struct xfrm_state___8 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___8 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___8 **, struct xfrm_state___8 **, int);
	union {
		int (*output)(struct sock___50 *, struct sk_buff___63 *);
		struct {
			int (*output)(struct sk_buff___63 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___50 *, struct sk_buff___63 *);
		struct {
			int (*output_finish)(struct sk_buff___63 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*extract_output)(struct xfrm_state___8 *, struct sk_buff___63 *);
	int (*transport_finish)(struct sk_buff___63 *, int);
};

typedef u64 pao_T_____4;

struct page___270;

typedef struct page___270 *pgtable_t___270;

struct address_space___271;

struct kmem_cache___254;

struct page___270 {
	long unsigned int flags;
	struct address_space___271 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___270 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___270 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___254 *slab_cache;
		struct page___270 *first_page;
	};
	long: 64;
};

struct task_struct___272;

struct pv_cpu_ops___272 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___272 *);
	void (*end_context_switch)(struct task_struct___272 *);
};

struct mutex___273 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___272 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___265 {
	struct page___270 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___279;

struct nsproxy___151;

struct signal_struct___272;

struct css_set___166;

struct task_struct___272 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___272 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___279 *mm;
	struct mm_struct___279 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___272 *real_parent;
	struct task_struct___272 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___272 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___272 = 0,
		VTIME_USER___272 = 1,
		VTIME_SYS___272 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___151 *nsproxy;
	struct signal_struct___272 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___166 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___273 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___265 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___279 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___279 *, struct mm_struct___279 *);
	void (*dup_mmap)(struct mm_struct___279 *, struct mm_struct___279 *);
	void (*exit_mmap)(struct mm_struct___279 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___279 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___279 *);
	void (*pgd_free)(struct mm_struct___279 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___279 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___279 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___279 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___279 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___279 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___279 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___279 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___279 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___279 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___279 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___279 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___273 lock;
	void *vdso;
} mm_context_t___273;

struct xol_area___270;

struct uprobes_state___270 {
	struct xol_area___270 *xol_area;
};

struct vm_area_struct___279;

struct file___271;

struct core_state___272;

struct mm_struct___279 {
	struct vm_area_struct___279 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___279 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___279 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___273 context;
	long unsigned int flags;
	struct core_state___272 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___272 *owner;
	struct file___271 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___270 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___53;

struct kobj_type___53;

struct kobject___53 {
	const char *name;
	struct list_head entry;
	struct kobject___53 *parent;
	struct kset___53 *kset;
	struct kobj_type___53 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___168;

struct module_kobject___167 {
	struct kobject___53 kobj;
	struct module___168 *mod;
	struct kobject___53 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___167;

struct module___168 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___167 mkobj;
	struct module_attribute___167 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___53 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___272 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___272;

struct lruvec___272 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___272 *zone;
};

struct pglist_data___272;

struct zone___272 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___272 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___272 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___272 {
	struct zone___272 *zone;
	int zone_idx;
};

struct zonelist___272 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___272 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___272 {
	struct zone___272 node_zones[4];
	struct zonelist___272 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___272 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___195;

struct x86_io_apic_ops___195 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___195 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___195;

struct irq_data___195 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___195 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___269;

struct dev_pm_ops___269 {
	int (*prepare)(struct device___269 *);
	void (*complete)(struct device___269 *);
	int (*suspend)(struct device___269 *);
	int (*resume)(struct device___269 *);
	int (*freeze)(struct device___269 *);
	int (*thaw)(struct device___269 *);
	int (*poweroff)(struct device___269 *);
	int (*restore)(struct device___269 *);
	int (*suspend_late)(struct device___269 *);
	int (*resume_early)(struct device___269 *);
	int (*freeze_late)(struct device___269 *);
	int (*thaw_early)(struct device___269 *);
	int (*poweroff_late)(struct device___269 *);
	int (*restore_early)(struct device___269 *);
	int (*suspend_noirq)(struct device___269 *);
	int (*resume_noirq)(struct device___269 *);
	int (*freeze_noirq)(struct device___269 *);
	int (*thaw_noirq)(struct device___269 *);
	int (*poweroff_noirq)(struct device___269 *);
	int (*restore_noirq)(struct device___269 *);
	int (*runtime_suspend)(struct device___269 *);
	int (*runtime_resume)(struct device___269 *);
	int (*runtime_idle)(struct device___269 *);
};

struct dev_pm_qos___72;

struct dev_pm_info___72 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___72 *qos;
};

struct dma_map_ops___134;

struct dev_archdata___134 {
	struct dma_map_ops___134 *dma_ops;
	void *iommu;
};

struct device_type___269;

struct bus_type___269;

struct device_driver___269;

struct dev_pm_domain___269;

struct class___269;

struct attribute_group___231;

struct device_rh___269;

struct device___269 {
	struct device___269 *parent;
	struct device_private *p;
	struct kobject___53 kobj;
	const char *init_name;
	const struct device_type___269 *type;
	struct mutex___273 mutex;
	struct bus_type___269 *bus;
	struct device_driver___269 *driver;
	void *platform_data;
	struct dev_pm_info___72 power;
	struct dev_pm_domain___269 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___134 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___269 *class;
	const struct attribute_group___231 **groups;
	void (*release)(struct device___269 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___269 *device_rh;
};

struct dev_pm_qos_request___73;

struct dev_pm_qos___72 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___73 *latency_req;
	struct dev_pm_qos_request___73 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___73 *latency_tolerance_req;
};

struct dev_pm_info_rh___269 {
	void (*set_latency_tolerance)(struct device___269 *, s32);
};

struct dev_pm_domain___269 {
	struct dev_pm_ops___269 ops;
};

struct smp_ops___272 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___272 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___76;

struct ctl_node___76 {
	struct rb_node node;
	struct ctl_table_header___76 *header;
};

struct ctl_table_root___76;

struct ctl_table_set___76;

struct ctl_dir___76;

struct ctl_table_header___76 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___76 *root;
	struct ctl_table_set___76 *set;
	struct ctl_dir___76 *parent;
	struct ctl_node___76 *node;
};

struct ctl_dir___76 {
	struct ctl_table_header___76 header;
	struct rb_root root;
};

struct ctl_table_set___76 {
	int (*is_seen)(struct ctl_table_set___76 *);
	struct ctl_dir___76 dir;
};

struct ctl_table_root___76 {
	struct ctl_table_set___76 default_set;
	struct ctl_table_set___76 * (*lookup)(struct ctl_table_root___76 *, struct nsproxy___151 *);
	int (*permissions)(struct ctl_table_header___76 *, struct ctl_table *);
};

struct net___75;

struct nsproxy___151 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___75 *net_ns;
};

struct sock___51;

struct kobj_ns_type_operations___50 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___51 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___50;

struct sock_common___50 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___50 *skc_prot;
	struct net___75 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___64;

struct sk_buff_head___62 {
	struct sk_buff___64 *next;
	struct sk_buff___64 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___51;

struct socket_wq___50;

struct xfrm_policy___9;

struct dst_entry___51;

struct socket___51;

struct cg_proto___50;

struct sock___51 {
	struct sock_common___50 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___62 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___64 *head;
		struct sk_buff___64 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___51 *sk_filter;
	struct socket_wq___50 *sk_wq;
	struct sk_buff_head___62 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___9 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___51 *sk_rx_dst;
	struct dst_entry___51 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___62 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___62 sk_error_queue;
	struct proto___50 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___51 *sk_socket;
	void *sk_user_data;
	struct page_frag___265 sk_frag;
	struct sk_buff___64 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___50 *sk_cgrp;
	void (*sk_state_change)(struct sock___51 *);
	void (*sk_data_ready)(struct sock___51 *, int);
	void (*sk_write_space)(struct sock___51 *);
	void (*sk_error_report)(struct sock___51 *);
	int (*sk_backlog_rcv)(struct sock___51 *, struct sk_buff___64 *);
	void (*sk_destruct)(struct sock___51 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___233;

struct attribute_group___231 {
	const char *name;
	umode_t (*is_visible)(struct kobject___53 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___233 **bin_attrs;
};

struct bin_attribute___233 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___271 *, struct kobject___53 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___271 *, struct kobject___53 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	int (*mmap)(struct file___271 *, struct kobject___53 *, struct bin_attribute___233 *, struct vm_area_struct___279 *);
};

struct dentry___271;

struct path___271 {
	struct vfsmount *mnt;
	struct dentry___271 *dentry;
};

struct inode___271;

struct file_operations___271;

struct file___271 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___271 f_path;
	struct inode___271 *f_inode;
	const struct file_operations___271 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___271 *f_mapping;
	struct mutex___273 f_pos_lock;
};

struct vm_operations_struct___245;

struct vm_area_struct___279 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___279 *vm_next;
	struct vm_area_struct___279 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___279 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___245 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___271 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___53 {
	ssize_t (*show)(struct kobject___53 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___53 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___53 *, const struct attribute *);
};

struct kset_uevent_ops___53;

struct kset___53 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___53 kobj;
	const struct kset_uevent_ops___53 *uevent_ops;
};

struct kobj_type___53 {
	void (*release)(struct kobject___53 *);
	const struct sysfs_ops___53 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___50 * (*child_ns_type)(struct kobject___53 *);
	const void * (*namespace)(struct kobject___53 *);
};

struct kset_uevent_ops___53 {
	int (* const filter)(struct kset___53 *, struct kobject___53 *);
	const char * (* const name)(struct kset___53 *, struct kobject___53 *);
	int (* const uevent)(struct kset___53 *, struct kobject___53 *, struct kobj_uevent_env *);
};

struct module_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___167 *, struct module_kobject___167 *, char *);
	ssize_t (*store)(struct module_attribute___167 *, struct module_kobject___167 *, const char *, size_t);
	void (*setup)(struct module___168 *, const char *);
	int (*test)(struct module___168 *);
	void (*free)(struct module___168 *);
};

struct xol_area___270 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___270 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___253;

struct memcg_cache_params___254;

struct kmem_cache___254 {
	struct kmem_cache_cpu___253 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___53 kobj;
	struct memcg_cache_params___254 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___271;

struct address_space___271 {
	struct inode___271 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___273 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___271 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___241;

struct vm_operations_struct___245 {
	void (*open)(struct vm_area_struct___279 *);
	void (*close)(struct vm_area_struct___279 *);
	int (*fault)(struct vm_area_struct___279 *, struct vm_fault___241 *);
	int (*page_mkwrite)(struct vm_area_struct___279 *, struct vm_fault___241 *);
	int (*access)(struct vm_area_struct___279 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___279 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___279 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___279 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___279 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___272 {
	struct task_struct___272 *task;
	struct core_thread___272 *next;
};

struct core_state___272 {
	atomic_t nr_threads;
	struct core_thread___272 dumper;
	struct completion startup;
};

struct vm_fault___241 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___270 *page;
};

struct fasync_struct___271;

struct socket_wq___50 {
	wait_queue_head_t wait;
	struct fasync_struct___271 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___271 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___271 *fa_next;
	struct file___271 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___50;

struct socket___51 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___50 *wq;
	struct file___271 *file;
	struct sock___51 *sk;
	const struct proto_ops___50 *ops;
};

struct poll_table_struct___157;

struct kiocb___58;

struct proto_ops___50 {
	int family;
	struct module___168 *owner;
	int (*release)(struct socket___51 *);
	int (*bind)(struct socket___51 *, struct sockaddr *, int);
	int (*connect)(struct socket___51 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___51 *, struct socket___51 *);
	int (*accept)(struct socket___51 *, struct socket___51 *, int);
	int (*getname)(struct socket___51 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___271 *, struct socket___51 *, struct poll_table_struct___157 *);
	int (*ioctl)(struct socket___51 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___51 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___51 *, int);
	int (*shutdown)(struct socket___51 *, int);
	int (*setsockopt)(struct socket___51 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___51 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___51 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___51 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___58 *, struct socket___51 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___58 *, struct socket___51 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___271 *, struct socket___51 *, struct vm_area_struct___279 *);
	ssize_t (*sendpage)(struct socket___51 *, struct page___270 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___51 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___51 *, int);
		struct {
			void (*set_peek_off)(struct sock___51 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___159)(struct file___271 *, wait_queue_head_t *, struct poll_table_struct___157 *);

struct poll_table_struct___157 {
	poll_queue_proc___159 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___58(struct kiocb___58 *, struct io_event *);

struct kiocb___58 {
	atomic_t ki_users;
	struct file___271 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___58 *ki_cancel;
	void (*ki_dtor)(struct kiocb___58 *);
	union {
		void *user;
		struct task_struct___272 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___73 {
	struct ctl_table_header___76 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___74 {
	struct mutex___273 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___73 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___76 *ctl;
};

struct fib_rules_ops___4;

struct netns_ipv4___73 {
	struct ctl_table_header___76 *forw_hdr;
	struct ctl_table_header___76 *frags_hdr;
	struct ctl_table_header___76 *ipv4_hdr;
	struct ctl_table_header___76 *route_hdr;
	struct ctl_table_header___76 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___4 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___51 *fibnl;
	struct sock___51 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___4 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___73 {
	struct ctl_table_header___76 *hdr;
	struct ctl_table_header___76 *route_hdr;
	struct ctl_table_header___76 *icmp_hdr;
	struct ctl_table_header___76 *frags_hdr;
	struct ctl_table_header___76 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___61;

struct neighbour___51;

struct dst_ops___75 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___75 *);
	struct dst_entry___51 * (*check)(struct dst_entry___51 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___51 *);
	unsigned int (*mtu)(const struct dst_entry___51 *);
	u32 * (*cow_metrics)(struct dst_entry___51 *, long unsigned int);
	void (*destroy)(struct dst_entry___51 *);
	void (*ifdown)(struct dst_entry___51 *, struct net_device___61 *, int);
	struct dst_entry___51 * (*negative_advice)(struct dst_entry___51 *);
	void (*link_failure)(struct sk_buff___64 *);
	void (*update_pmtu)(struct dst_entry___51 *, struct sock___51 *, struct sk_buff___64 *, u32);
	void (*redirect)(struct dst_entry___51 *, struct sock___51 *, struct sk_buff___64 *);
	int (*local_out)(struct sk_buff___64 *);
	struct neighbour___51 * (*neigh_lookup)(const struct dst_entry___51 *, struct sk_buff___64 *, const void *);
	struct kmem_cache___254 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___9;

struct fib6_table___9;

struct netns_ipv6___75 {
	struct netns_sysctl_ipv6___73 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___9 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___9 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___75 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___9 *ip6_prohibit_entry;
	struct rt6_info___9 *ip6_blk_hole_entry;
	struct fib6_table___9 *fib6_local_tbl;
	struct fib_rules_ops___4 *fib6_rules_ops;
	struct sock___51 **icmp_sk;
	struct sock___51 *ndisc_sk;
	struct sock___51 *tcp_sk;
	struct sock___51 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___4 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___73 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___76 *sysctl_header;
	struct sock___51 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___50 {
	struct sock___51 *v4_ctl_sk;
	struct sock___51 *v6_ctl_sk;
};

struct netns_nf___73 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___76 *nf_log_dir_header;
};

struct nf_proto_net___73 {
	struct ctl_table_header___76 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___73 {
	struct nf_proto_net___73 pn;
	unsigned int timeout;
};

struct nf_tcp_net___73 {
	struct nf_proto_net___73 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___73 {
	struct nf_proto_net___73 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___73 {
	struct nf_proto_net___73 pn;
	unsigned int timeout;
};

struct nf_ip_net___73 {
	struct nf_generic_net___73 generic;
	struct nf_tcp_net___73 tcp;
	struct nf_udp_net___73 udp;
	struct nf_icmp_net___73 icmp;
	struct nf_icmp_net___73 icmpv6;
};

struct netns_ct___74 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___76 *sysctl_header;
	struct ctl_table_header___76 *acct_sysctl_header;
	struct ctl_table_header___76 *tstamp_sysctl_header;
	struct ctl_table_header___76 *event_sysctl_header;
	struct ctl_table_header___76 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___254 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___73 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___73 {
	struct netns_sysctl_ipv6___73 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___75 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___51 *nlsk;
	struct sock___51 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___76 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___75 xfrm4_dst_ops;
	struct dst_ops___75 xfrm6_dst_ops;
};

struct net___75 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___76 sysctls;
	struct sock___51 *rtnl;
	struct sock___51 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___61 *loopback_dev;
	struct netns_core___73 core;
	struct netns_mib mib;
	struct netns_packet___74 packet;
	struct netns_unix___73 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___73 ipv4;
	struct netns_ipv6___75 ipv6;
	struct netns_sctp___73 sctp;
	struct netns_dccp___50 dccp;
	struct netns_nf___73 nf;
	struct netns_xt xt;
	struct netns_ct___74 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___73 nf_frag;
	struct sock___51 *nfnl;
	struct sock___51 *nfnl_stash;
	struct sk_buff_head___62 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___75 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___51 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___51 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___273 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___273 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___253 {
	void **freelist;
	long unsigned int tid;
	struct page___270 *page;
	struct page___270 *partial;
};

struct memcg_cache_params___254 {
	bool is_root_cache;
	union {
		struct kmem_cache___254 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___254 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___134 {
	void * (*alloc)(struct device___269 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___269 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___269 *, struct vm_area_struct___279 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___269 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___269 *, struct page___270 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___269 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___269 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___269 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___269 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___269 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___269 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___269 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___269 *, dma_addr_t);
	int (*dma_supported)(struct device___269 *, u64);
	int (*set_dma_mask)(struct device___269 *, u64);
	int is_phys;
};

struct bus_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___269 *, char *);
	ssize_t (*store)(struct bus_type___269 *, const char *, size_t);
};

struct device_attribute___269;

struct driver_attribute___269;

struct bus_type___269 {
	const char *name;
	const char *dev_name;
	struct device___269 *dev_root;
	struct bus_attribute___269 *bus_attrs;
	struct device_attribute___269 *dev_attrs;
	struct driver_attribute___269 *drv_attrs;
	const struct attribute_group___231 **bus_groups;
	const struct attribute_group___231 **dev_groups;
	const struct attribute_group___231 **drv_groups;
	int (*match)(struct device___269 *, struct device_driver___269 *);
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	int (*probe)(struct device___269 *);
	int (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*online)(struct device___269 *);
	int (*offline)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct device___269 *, struct device_attribute___269 *, char *);
	ssize_t (*store)(struct device___269 *, struct device_attribute___269 *, const char *, size_t);
};

struct driver_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___269 *, char *);
	ssize_t (*store)(struct device_driver___269 *, const char *, size_t);
};

struct device_driver___269 {
	const char *name;
	struct bus_type___269 *bus;
	struct module___168 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___269 *);
	int (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	const struct attribute_group___231 **groups;
	const struct dev_pm_ops___269 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___269 {
	const char *name;
	const struct attribute_group___231 **groups;
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
};

struct class_attribute___269;

struct class___269 {
	const char *name;
	struct module___168 *owner;
	struct class_attribute___269 *class_attrs;
	struct device_attribute___269 *dev_attrs;
	const struct attribute_group___231 **dev_groups;
	struct bin_attribute___233 *dev_bin_attrs;
	struct kobject___53 *dev_kobj;
	int (*dev_uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *);
	void (*class_release)(struct class___269 *);
	void (*dev_release)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	const struct kobj_ns_type_operations___50 *ns_type;
	const void * (*namespace)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
	struct subsys_private *p;
};

struct class_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct class___269 *, struct class_attribute___269 *, char *);
	ssize_t (*store)(struct class___269 *, struct class_attribute___269 *, const char *, size_t);
	const void * (*namespace)(struct class___269 *, const struct class_attribute___269 *);
};

struct device_rh___269 {
	struct dev_pm_info_rh___269 power;
};

struct signal_struct___272 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___272 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___272 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___273 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___166;

struct css_set___166 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___166 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___61 {
	atomic_t use;
	unsigned int mask;
	struct net_device___61 *physindev;
	struct net_device___61 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___61(struct sk_buff___64 **);

struct net_device_ops___61;

struct ethtool_ops___61;

struct header_ops___61;

struct in_device___8;

struct inet6_dev___27;

struct netdev_rx_queue___61;

struct netdev_queue___61;

struct rtnl_link_ops___52;

struct dcbnl_rtnl_ops___61;

struct net_device___61 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___61 *netdev_ops;
	const struct ethtool_ops___61 *ethtool_ops;
	const struct header_ops___61 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___53 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___8 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___27 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___61 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___61 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___61 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___61 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___61 = 0,
		NETREG_REGISTERED___61 = 1,
		NETREG_UNREGISTERING___61 = 2,
		NETREG_UNREGISTERED___61 = 3,
		NETREG_RELEASED___61 = 4,
		NETREG_DUMMY___61 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___61 = 0,
		RTNL_LINK_INITIALIZING___61 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___61 *);
	struct netpoll_info *npinfo;
	struct net___75 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___269 dev;
	const struct attribute_group___231 *sysfs_groups[4];
	const struct rtnl_link_ops___52 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___61 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___9;

struct sk_buff___64 {
	struct sk_buff___64 *next;
	struct sk_buff___64 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___51 *sk;
	struct net_device___61 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___9 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___64 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___61 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___14 {
	struct {
		struct page___270 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___14 skb_frag_t___14;

struct skb_shared_info___14 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___64 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___14 frags[17];
};

struct xfrm_state___9;

struct sec_path___9 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___9 *xvec[6];
};

struct file_lock___271;

struct seq_file___196;

struct file_operations___271 {
	struct module___168 *owner;
	loff_t (*llseek)(struct file___271 *, loff_t, int);
	ssize_t (*read)(struct file___271 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___271 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___58 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___58 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___271 *, void *, filldir_t);
	unsigned int (*poll)(struct file___271 *, struct poll_table_struct___157 *);
	long int (*unlocked_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___271 *, struct vm_area_struct___279 *);
	int (*open)(struct inode___271 *, struct file___271 *);
	int (*flush)(struct file___271 *, fl_owner_t);
	int (*release)(struct inode___271 *, struct file___271 *);
	int (*fsync)(struct file___271 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___58 *, int);
	int (*fasync)(int, struct file___271 *, int);
	int (*lock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*sendpage)(struct file___271 *, struct page___270 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___271 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___271 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___271 *, long int, struct file_lock___271 **, void **);
		struct {
			int (*setlease)(struct file___271 *, long int, struct file_lock___271 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___271 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___196 *, struct file___271 *);
};

struct dev_pm_qos_request___73 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___269 *dev;
};

struct dentry_operations___271;

struct super_block___271;

struct dentry___271 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___271 *d_parent;
	struct qstr d_name;
	struct inode___271 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___271 *d_op;
	struct super_block___271 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___271;

struct dquot___271;

struct block_device___271;

struct inode___271 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___271 *i_op;
	struct super_block___271 *i_sb;
	struct address_space___271 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___273 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___271 *i_fop;
	struct file_lock___271 *i_flock;
	struct address_space___271 i_data;
	struct dquot___271 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___271 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___271 {
	int (*d_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_hash)(const struct dentry___271 *, struct qstr *);
	int (*d_compare)(const struct dentry___271 *, const struct dentry___271 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___271 *);
	void (*d_release)(struct dentry___271 *);
	void (*d_prune)(struct dentry___271 *);
	void (*d_iput)(struct dentry___271 *, struct inode___271 *);
	char * (*d_dname)(struct dentry___271 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___271 *);
	int (*d_manage)(struct dentry___271 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___271;

struct mem_dqinfo___271 {
	struct quota_format_type___271 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___271;

struct quota_info___271 {
	unsigned int flags;
	struct mutex___273 dqio_mutex;
	struct mutex___273 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___271 *files[2];
	struct mem_dqinfo___271 info[2];
	const struct quota_format_ops___271 *ops[2];
};

struct file_system_type___271;

struct super_operations___271;

struct dquot_operations___271;

struct quotactl_ops___271;

struct xattr_handler___167;

struct super_block___271 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___271 *s_type;
	const struct super_operations___271 *s_op;
	const struct dquot_operations___271 *dq_op;
	const struct quotactl_ops___271 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___271 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___167 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___271 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___271 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___273 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___271 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___271 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___271 *bd_inode;
	struct super_block___271 *bd_super;
	struct mutex___273 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___271 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___273 bd_fsfreeze_mutex;
};

struct cgroup___166;

struct cgroup_subsys_state___166 {
	struct cgroup___166 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___271 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___271 *ia_file;
};

struct dquot___271 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___273 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___271 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___271 {
	int qf_fmt_id;
	const struct quota_format_ops___271 *qf_ops;
	struct module___168 *qf_owner;
	struct quota_format_type___271 *qf_next;
};

struct quota_format_ops___271 {
	int (*check_quota_file)(struct super_block___271 *, int);
	int (*read_file_info)(struct super_block___271 *, int);
	int (*write_file_info)(struct super_block___271 *, int);
	int (*free_file_info)(struct super_block___271 *, int);
	int (*read_dqblk)(struct dquot___271 *);
	int (*commit_dqblk)(struct dquot___271 *);
	int (*release_dqblk)(struct dquot___271 *);
};

struct dquot_operations___271 {
	int (*write_dquot)(struct dquot___271 *);
	struct dquot___271 * (*alloc_dquot)(struct super_block___271 *, int);
	void (*destroy_dquot)(struct dquot___271 *);
	int (*acquire_dquot)(struct dquot___271 *);
	int (*release_dquot)(struct dquot___271 *);
	int (*mark_dirty)(struct dquot___271 *);
	int (*write_info)(struct super_block___271 *, int);
	qsize_t * (*get_reserved_space)(struct inode___271 *);
};

struct quotactl_ops___271 {
	int (*quota_on)(struct super_block___271 *, int, int, struct path___271 *);
	int (*quota_on_meta)(struct super_block___271 *, int, int);
	int (*quota_off)(struct super_block___271 *, int);
	int (*quota_sync)(struct super_block___271 *, int);
	int (*get_info)(struct super_block___271 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___271 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___271 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___271 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___271 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___271 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___271 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___271 *, unsigned int);
};

struct address_space_operations___271 {
	int (*writepage)(struct page___270 *, struct writeback_control *);
	int (*readpage)(struct file___271 *, struct page___270 *);
	int (*writepages)(struct address_space___271 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___270 *);
	int (*readpages)(struct file___271 *, struct address_space___271 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___271 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___270 **, void **);
	int (*write_end)(struct file___271 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___270 *, void *);
	sector_t (*bmap)(struct address_space___271 *, sector_t);
	void (*invalidatepage)(struct page___270 *, long unsigned int);
	int (*releasepage)(struct page___270 *, gfp_t);
	void (*freepage)(struct page___270 *);
	ssize_t (*direct_IO)(int, struct kiocb___58 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___271 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___271 *, struct page___270 *, struct page___270 *, enum migrate_mode);
	int (*launder_page)(struct page___270 *);
	int (*is_partially_uptodate)(struct page___270 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___270 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___271 *, struct page___270 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___271 *, sector_t *);
	void (*swap_deactivate)(struct file___271 *);
	void (*invalidatepage_range)(struct page___270 *, unsigned int, unsigned int);
};

struct inode_operations___271 {
	struct dentry___271 * (*lookup)(struct inode___271 *, struct dentry___271 *, unsigned int);
	void * (*follow_link)(struct dentry___271 *, struct nameidata *);
	int (*permission)(struct inode___271 *, int);
	struct posix_acl * (*get_acl)(struct inode___271 *, int);
	int (*readlink)(struct dentry___271 *, char *, int);
	void (*put_link)(struct dentry___271 *, struct nameidata *, void *);
	int (*create)(struct inode___271 *, struct dentry___271 *, umode_t, bool);
	int (*link)(struct dentry___271 *, struct inode___271 *, struct dentry___271 *);
	int (*unlink)(struct inode___271 *, struct dentry___271 *);
	int (*symlink)(struct inode___271 *, struct dentry___271 *, const char *);
	int (*mkdir)(struct inode___271 *, struct dentry___271 *, umode_t);
	int (*rmdir)(struct inode___271 *, struct dentry___271 *);
	int (*mknod)(struct inode___271 *, struct dentry___271 *, umode_t, dev_t);
	int (*rename)(struct inode___271 *, struct dentry___271 *, struct inode___271 *, struct dentry___271 *);
	int (*setattr)(struct dentry___271 *, struct iattr___271 *);
	int (*getattr)(struct vfsmount *, struct dentry___271 *, struct kstat *);
	int (*setxattr)(struct dentry___271 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___271 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___271 *, char *, size_t);
	int (*removexattr)(struct dentry___271 *, const char *);
	int (*fiemap)(struct inode___271 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___271 *, struct timespec *, int);
	int (*atomic_open)(struct inode___271 *, struct dentry___271 *, struct file___271 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___271;

struct lock_manager_operations___271;

struct file_lock___271 {
	struct file_lock___271 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___271 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___271 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___271 *fl_ops;
	const struct lock_manager_operations___271 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___271 {
	void (*fl_copy_lock)(struct file_lock___271 *, struct file_lock___271 *);
	void (*fl_release_private)(struct file_lock___271 *);
};

struct lock_manager_operations___271 {
	int (*lm_compare_owner)(struct file_lock___271 *, struct file_lock___271 *);
	long unsigned int (*lm_owner_key)(struct file_lock___271 *);
	void (*lm_notify)(struct file_lock___271 *);
	int (*lm_grant)(struct file_lock___271 *, struct file_lock___271 *, int);
	void (*lm_break)(struct file_lock___271 *);
	int (*lm_change)(struct file_lock___271 **, int);
};

struct file_system_type___271 {
	const char *name;
	int fs_flags;
	struct dentry___271 * (*mount)(struct file_system_type___271 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___271 *);
	struct module___168 *owner;
	struct file_system_type___271 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___271 {
	struct inode___271 * (*alloc_inode)(struct super_block___271 *);
	void (*destroy_inode)(struct inode___271 *);
	void (*dirty_inode)(struct inode___271 *, int);
	int (*write_inode)(struct inode___271 *, struct writeback_control *);
	int (*drop_inode)(struct inode___271 *);
	void (*evict_inode)(struct inode___271 *);
	void (*put_super)(struct super_block___271 *);
	int (*sync_fs)(struct super_block___271 *, int);
	int (*freeze_fs)(struct super_block___271 *);
	int (*unfreeze_fs)(struct super_block___271 *);
	int (*statfs)(struct dentry___271 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___271 *, int *, char *);
	void (*umount_begin)(struct super_block___271 *);
	int (*show_options)(struct seq_file___196 *, struct dentry___271 *);
	int (*show_devname)(struct seq_file___196 *, struct dentry___271 *);
	int (*show_path)(struct seq_file___196 *, struct dentry___271 *);
	int (*show_stats)(struct seq_file___196 *, struct dentry___271 *);
	ssize_t (*quota_read)(struct super_block___271 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___271 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___271 *);
	int (*bdev_try_to_free_page)(struct super_block___271 *, struct page___270 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___271 *);
	void (*free_cached_objects)(struct super_block___271 *, int);
};

struct xattr_handler___167 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___271 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___271 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___271 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___196;

struct seq_file___196 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___273 lock;
	const struct seq_operations___196 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___61 {
	int (*get_settings)(struct net_device___61 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___61 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___61 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___61 *);
	void (*get_regs)(struct net_device___61 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___61 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___61 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___61 *);
	void (*set_msglevel)(struct net_device___61 *, u32);
	int (*nway_reset)(struct net_device___61 *);
	u32 (*get_link)(struct net_device___61 *);
	int (*get_eeprom_len)(struct net_device___61 *);
	int (*get_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___61 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___61 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___61 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___61 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___61 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___61 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___61 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___61 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___61 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___61 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___61 *);
	void (*complete)(struct net_device___61 *);
	u32 (*get_priv_flags)(struct net_device___61 *);
	int (*set_priv_flags)(struct net_device___61 *, u32);
	int (*get_sset_count)(struct net_device___61 *, int);
	int (*get_rxnfc)(struct net_device___61 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___61 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___61 *, struct ethtool_flash *);
	int (*reset)(struct net_device___61 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___61 *);
	int (*get_rxfh_indir)(struct net_device___61 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___61 *, const u32 *);
	void (*get_channels)(struct net_device___61 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___61 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___61 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___61 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___61 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___61 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___61 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___61 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___61 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___61 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___61 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___61 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib_rule___4;

struct fib_lookup_arg___4;

struct fib_rules_ops___4 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___4 *, struct flowi *, int, struct fib_lookup_arg___4 *);
	int (*match)(struct fib_rule___4 *, struct flowi *, int);
	int (*configure)(struct fib_rule___4 *, struct sk_buff___64 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___4 *);
	int (*compare)(struct fib_rule___4 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___4 *, struct sk_buff___64 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___4 *);
	size_t (*nlmsg_payload)(struct fib_rule___4 *);
	void (*flush_cache)(struct fib_rules_ops___4 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___168 *owner;
	struct net___75 *fro_net;
	struct callback_head rcu;
};

struct rtable___22;

struct dst_entry___51 {
	struct callback_head callback_head;
	struct dst_entry___51 *child;
	struct net_device___61 *dev;
	struct dst_ops___75 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___51 *path;
	struct dst_entry___51 *from;
	struct xfrm_state___9 *xfrm;
	int (*input)(struct sk_buff___64 *);
	union {
		int (*output)(struct sock___51 *, struct sk_buff___64 *);
		struct {
			int (*output)(struct sk_buff___64 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___51 *next;
		struct rtable___22 *rt_next;
		struct rt6_info___9 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___51;

struct neigh_parms___51;

struct neigh_ops___51;

struct neighbour___51 {
	struct neighbour___51 *next;
	struct neigh_table___51 *tbl;
	struct neigh_parms___51 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___62 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___51 *, struct sk_buff___64 *);
	const struct neigh_ops___51 *ops;
	struct callback_head rcu;
	struct net_device___61 *dev;
	u8 primary_key[0];
};

struct fib6_node___9;

struct rt6_info___9 {
	struct dst_entry___51 dst;
	struct fib6_table___9 *rt6i_table;
	struct fib6_node___9 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___27 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___9 {
	struct fib6_node___9 *parent;
	struct fib6_node___9 *left;
	struct fib6_node___9 *right;
	struct rt6_info___9 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___9 *rr_ptr;
};

struct fib6_table___9 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___9 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct ip_mreq_source {
	__be32 imr_multiaddr;
	__be32 imr_interface;
	__be32 imr_sourceaddr;
};

struct ip_msfilter {
	__be32 imsf_multiaddr;
	__be32 imsf_interface;
	__u32 imsf_fmode;
	__u32 imsf_numsrc;
	__be32 imsf_slist[1];
};

struct in_pktinfo {
	int ipi_ifindex;
	struct in_addr ipi_spec_dst;
	struct in_addr ipi_addr;
};

struct nf_afinfo___75 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___64 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___64 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___75 *, struct dst_entry___51 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___64 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___64 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___195 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___195 *);
	void (*irq_shutdown)(struct irq_data___195 *);
	void (*irq_enable)(struct irq_data___195 *);
	void (*irq_disable)(struct irq_data___195 *);
	void (*irq_ack)(struct irq_data___195 *);
	void (*irq_mask)(struct irq_data___195 *);
	void (*irq_mask_ack)(struct irq_data___195 *);
	void (*irq_unmask)(struct irq_data___195 *);
	void (*irq_eoi)(struct irq_data___195 *);
	int (*irq_set_affinity)(struct irq_data___195 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___195 *);
	int (*irq_set_type)(struct irq_data___195 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___195 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___195 *);
	void (*irq_bus_sync_unlock)(struct irq_data___195 *);
	void (*irq_cpu_online)(struct irq_data___195 *);
	void (*irq_cpu_offline)(struct irq_data___195 *);
	void (*irq_suspend)(struct irq_data___195 *);
	void (*irq_resume)(struct irq_data___195 *);
	void (*irq_pm_shutdown)(struct irq_data___195 *);
	void (*irq_print_chip)(struct irq_data___195 *, struct seq_file___196 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___195 *, void *);
	long unsigned int flags;
};

struct seq_operations___196 {
	void * (*start)(struct seq_file___196 *, loff_t *);
	void (*stop)(struct seq_file___196 *, void *);
	void * (*next)(struct seq_file___196 *, void *, loff_t *);
	int (*show)(struct seq_file___196 *, void *);
};

struct dcbnl_rtnl_ops___61 {
	int (*ieee_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___61 *);
	u8 (*setstate)(struct net_device___61 *, u8);
	void (*getpermhwaddr)(struct net_device___61 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___61 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___61 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___61 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___61 *, int, u8 *);
	void (*setpfccfg)(struct net_device___61 *, int, u8);
	void (*getpfccfg)(struct net_device___61 *, int, u8 *);
	u8 (*setall)(struct net_device___61 *);
	u8 (*getcap)(struct net_device___61 *, int, u8 *);
	int (*getnumtcs)(struct net_device___61 *, int, u8 *);
	int (*setnumtcs)(struct net_device___61 *, int, u8);
	u8 (*getpfcstate)(struct net_device___61 *);
	void (*setpfcstate)(struct net_device___61 *, u8);
	void (*getbcncfg)(struct net_device___61 *, int, u32 *);
	void (*setbcncfg)(struct net_device___61 *, int, u32);
	void (*getbcnrp)(struct net_device___61 *, int, u8 *);
	void (*setbcnrp)(struct net_device___61 *, int, u8);
	u8 (*setapp)(struct net_device___61 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___61 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___61 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___61 *, int, u8);
	u8 (*getdcbx)(struct net_device___61 *);
	u8 (*setdcbx)(struct net_device___61 *, u8);
	int (*peer_getappinfo)(struct net_device___61 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___61 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___61 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___61 *, struct cee_pfc *);
};

struct cgroupfs_root___166;

struct cgroup___166 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___166 *parent;
	struct dentry___271 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___166 *subsys[11];
	struct cgroupfs_root___166 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___273 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___166 {
	struct super_block___271 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___166 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___102 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___271 *, struct file___271 *);
	ssize_t (*read)(struct cgroup___166 *, struct cftype___102 *, struct file___271 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___166 *, struct cftype___102 *);
	s64 (*read_s64)(struct cgroup___166 *, struct cftype___102 *);
	int (*read_map)(struct cgroup___166 *, struct cftype___102 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___166 *, struct cftype___102 *, struct seq_file___196 *);
	ssize_t (*write)(struct cgroup___166 *, struct cftype___102 *, struct file___271 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___166 *, struct cftype___102 *, u64);
	int (*write_s64)(struct cgroup___166 *, struct cftype___102 *, s64);
	int (*write_string)(struct cgroup___166 *, struct cftype___102 *, const char *);
	int (*trigger)(struct cgroup___166 *, unsigned int);
	int (*release)(struct inode___271 *, struct file___271 *);
	int (*register_event)(struct cgroup___166 *, struct cftype___102 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___166 *, struct cftype___102 *, struct eventfd_ctx *);
};

struct cftype_set___98 {
	struct list_head node;
	struct cftype___102 *cfts;
};

struct task_and_cgroup___98 {
	struct task_struct___272 *task;
	struct cgroup___166 *cgrp;
	struct css_set___166 *cg;
};

struct cgroup_taskset___98 {
	struct task_and_cgroup___98 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___166 *cur_cgrp;
};

struct cgroup_subsys___98 {
	struct cgroup_subsys_state___166 * (*css_alloc)(struct cgroup___166 *);
	int (*css_online)(struct cgroup___166 *);
	void (*css_offline)(struct cgroup___166 *);
	void (*css_free)(struct cgroup___166 *);
	int (*can_attach)(struct cgroup___166 *, struct cgroup_taskset___98 *);
	void (*cancel_attach)(struct cgroup___166 *, struct cgroup_taskset___98 *);
	void (*attach)(struct cgroup___166 *, struct cgroup_taskset___98 *);
	void (*fork)(struct task_struct___272 *);
	void (*exit)(struct cgroup___166 *, struct cgroup___166 *, struct task_struct___272 *);
	void (*bind)(struct cgroup___166 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___166 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___102 *base_cftypes;
	struct cftype_set___98 base_cftset;
	struct module___168 *module;
};

struct request_sock_ops___36;

struct request_sock___37 {
	struct sock_common___50 __req_common;
	struct request_sock___37 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___36 *rsk_ops;
	struct sock___51 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___9;

struct xfrm_type___9;

struct xfrm_mode___9;

struct xfrm_state___9 {
	struct net___75 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___9 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___9 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___9 *type;
	struct xfrm_mode___9 *inner_mode;
	struct xfrm_mode___9 *inner_mode_iaf;
	struct xfrm_mode___9 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___9 {
	struct sk_buff_head___62 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___9 {
	struct net___75 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___9 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___63 {
	struct sk_buff___64 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___64 *, struct netlink_callback___63 *);
	int (*done)(struct netlink_callback___63 *);
	void *data;
	struct module___168 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___61 {
	int (*create)(struct sk_buff___64 *, struct net_device___61 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___64 *, unsigned char *);
	int (*rebuild)(struct sk_buff___64 *);
	int (*cache)(const struct neighbour___51 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___61 *, const unsigned char *);
};

struct napi_struct___61 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___61 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___61 *dev;
	struct sk_buff___64 *gro_list;
	struct sk_buff___64 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___61 {
	struct net_device___61 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___53 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___61 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___53 kobj;
	struct net_device___61 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___61 {
	int (*ndo_init)(struct net_device___61 *);
	void (*ndo_uninit)(struct net_device___61 *);
	int (*ndo_open)(struct net_device___61 *);
	int (*ndo_stop)(struct net_device___61 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___64 *, struct net_device___61 *);
	u16 (*ndo_select_queue)(struct net_device___61 *, struct sk_buff___64 *);
	void (*ndo_change_rx_flags)(struct net_device___61 *, int);
	void (*ndo_set_rx_mode)(struct net_device___61 *);
	int (*ndo_set_mac_address)(struct net_device___61 *, void *);
	int (*ndo_validate_addr)(struct net_device___61 *);
	int (*ndo_do_ioctl)(struct net_device___61 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___61 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___61 *, int);
	int (*ndo_neigh_setup)(struct net_device___61 *, struct neigh_parms___51 *);
	void (*ndo_tx_timeout)(struct net_device___61 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___61 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___61 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___61 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___61 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___61 *);
	int (*ndo_netpoll_setup)(struct net_device___61 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___61 *);
	int (*ndo_busy_poll)(struct napi_struct___61 *);
	int (*ndo_set_vf_mac)(struct net_device___61 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___61 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___61 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___61 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___61 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___61 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___61 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___61 *, int, struct sk_buff___64 *);
	int (*ndo_setup_tc)(struct net_device___61 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___61 *);
	int (*ndo_fcoe_disable)(struct net_device___61 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___61 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___61 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___61 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___61 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___61 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___61 *, const struct sk_buff___64 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___61 *, struct net_device___61 *);
	int (*ndo_del_slave)(struct net_device___61 *, struct net_device___61 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___51 *);
	void (*ndo_neigh_destroy)(struct neighbour___51 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___64 *, struct netlink_callback___63 *, struct net_device___61 *, int);
	int (*ndo_bridge_setlink)(struct net_device___61 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___64 *, u32, u32, struct net_device___61 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___61 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___61 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___61 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___61 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___61 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___61 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___64 *, struct net_device___61 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___61 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___61 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___61 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___51 {
	struct net___75 *net;
	struct net_device___61 *dev;
	struct neigh_parms___51 *next;
	int (*neigh_setup)(struct neighbour___51 *);
	void (*neigh_cleanup)(struct neighbour___51 *);
	struct neigh_table___51 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___8;

struct ip_mc_list___2;

struct in_device___8 {
	struct net_device___61 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___8 *ifa_list;
	struct ip_mc_list___2 *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___2 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___51 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___27;

struct ifacaddr6___27;

struct inet6_dev___27 {
	struct net_device___61 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___27 *mc_list;
	struct ifmcaddr6___27 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___27 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___51 *nd_parms;
	struct inet6_dev___27 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___52 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___61 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___75 *, struct net_device___61 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___61 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___61 *, struct list_head *);
	size_t (*get_size)(const struct net_device___61 *);
	int (*fill_info)(struct sk_buff___64 *, const struct net_device___61 *);
	size_t (*get_xstats_size)(const struct net_device___61 *);
	int (*fill_xstats)(struct sk_buff___64 *, const struct net_device___61 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___75 * (*get_link_net)(const struct net_device___61 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___61 *, struct net_device___61 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___61 *, const struct net_device___61 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___64 *, const struct net_device___61 *, const struct net_device___61 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___8 {
	struct hlist_node hash;
	struct in_ifaddr___8 *ifa_next;
	struct in_device___8 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___2 {
	struct in_device___8 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___2 *next;
		struct ip_mc_list___2 *next_rcu;
	};
	struct timer_list timer;
	int users;
	atomic_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct sk_filter___51 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___64 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___51;

struct neigh_hash_table___51;

struct neigh_table___51 {
	struct neigh_table___51 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___61 *, __u32 *);
	int (*constructor)(struct neighbour___51 *);
	int (*pconstructor)(struct pneigh_entry___51 *);
	void (*pdestructor)(struct pneigh_entry___51 *);
	void (*proxy_redo)(struct sk_buff___64 *);
	char *id;
	struct neigh_parms___51 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___62 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___51 *nht;
	struct pneigh_entry___51 **phash_buckets;
};

struct neigh_ops___51 {
	int family;
	void (*solicit)(struct neighbour___51 *, struct sk_buff___64 *);
	void (*error_report)(struct neighbour___51 *, struct sk_buff___64 *);
	int (*output)(struct neighbour___51 *, struct sk_buff___64 *);
	int (*connected_output)(struct neighbour___51 *, struct sk_buff___64 *);
};

struct pneigh_entry___51 {
	struct pneigh_entry___51 *next;
	struct net___75 *net;
	struct net_device___61 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___51 {
	struct neighbour___51 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___22 {
	struct dst_entry___51 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___33;

struct proto___50 {
	void (*close)(struct sock___51 *, long int);
	int (*connect)(struct sock___51 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___51 *, int);
	struct sock___51 * (*accept)(struct sock___51 *, int, int *);
	int (*ioctl)(struct sock___51 *, int, long unsigned int);
	int (*init)(struct sock___51 *);
	void (*destroy)(struct sock___51 *);
	void (*shutdown)(struct sock___51 *, int);
	int (*setsockopt)(struct sock___51 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___51 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___51 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___51 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___51 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___58 *, struct sock___51 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___58 *, struct sock___51 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___51 *, struct page___270 *, int, size_t, int);
	int (*bind)(struct sock___51 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___51 *, struct sk_buff___64 *);
	void (*release_cb)(struct sock___51 *);
	void (*mtu_reduced)(struct sock___51 *);
	void (*hash)(struct sock___51 *);
	void (*unhash)(struct sock___51 *);
	void (*rehash)(struct sock___51 *);
	int (*get_port)(struct sock___51 *, short unsigned int);
	void (*clear_sk)(struct sock___51 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___51 *);
	void (*enter_memory_pressure)(struct sock___51 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___254 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___36 *rsk_prot;
	struct timewait_sock_ops___33 *twsk_prot;
	union {
		struct inet_hashinfo___7 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___168 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___98 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___50 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___50 {
	void (*enter_memory_pressure)(struct sock___51 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___36 {
	int family;
	int obj_size;
	struct kmem_cache___254 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___51 *, struct request_sock___37 *);
	void (*send_ack)(struct sock___51 *, struct sk_buff___64 *, struct request_sock___37 *);
	void (*send_reset)(struct sock___51 *, struct sk_buff___64 *);
	void (*destructor)(struct request_sock___37 *);
	void (*syn_ack_timeout)(struct sock___51 *, struct request_sock___37 *);
};

struct timewait_sock_ops___33 {
	struct kmem_cache___254 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___51 *, struct sock___51 *, void *);
	void (*twsk_destructor)(struct sock___51 *);
};

struct listen_sock___2 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___37 *syn_table[0];
};

struct fastopen_queue___2 {
	struct request_sock___37 *rskq_rst_head;
	struct request_sock___37 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___2 {
	struct request_sock___37 *rskq_accept_head;
	struct request_sock___37 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___2 *listen_opt;
	struct fastopen_queue___2 *fastopenq;
};

struct inet_cork___8 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___51 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___8 {
	struct inet_cork___8 base;
	struct flowi fl;
};

struct ipv6_pinfo___7;

struct inet_sock___8 {
	struct sock___51 sk;
	struct ipv6_pinfo___7 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___8 cork;
};

struct ipv6_fl_socklist___6;

struct ipv6_pinfo___7 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___6 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___64 *pktoptions;
	struct sk_buff___64 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___2 {
	int (*queue_xmit)(struct sk_buff___64 *, struct flowi *);
	void (*send_check)(struct sock___51 *, struct sk_buff___64 *);
	int (*rebuild_header)(struct sock___51 *);
	void (*sk_rx_dst_set)(struct sock___51 *, const struct sk_buff___64 *);
	int (*conn_request)(struct sock___51 *, struct sk_buff___64 *);
	struct sock___51 * (*syn_recv_sock)(struct sock___51 *, struct sk_buff___64 *, struct request_sock___37 *, struct dst_entry___51 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___51 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___51 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___51 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___51 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___51 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___51 *, const struct inet_bind_bucket___2 *, bool);
	void (*mtu_reduced)(struct sock___51 *);
};

struct inet_connection_sock___2 {
	struct inet_sock___8 icsk_inet;
	struct request_sock_queue___2 icsk_accept_queue;
	struct inet_bind_bucket___2 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___2 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___51 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct ip6_flowlabel___6;

struct ipv6_fl_socklist___6 {
	struct ipv6_fl_socklist___6 *next;
	struct ip6_flowlabel___6 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___27 {
	struct in6_addr mca_addr;
	struct inet6_dev___27 *idev;
	struct ifmcaddr6___27 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___27 {
	struct in6_addr aca_addr;
	struct inet6_dev___27 *aca_idev;
	struct rt6_info___9 *aca_rt;
	struct ifacaddr6___27 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___6 {
	struct ip6_flowlabel___6 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___75 *fl_net;
};

struct ip_ra_chain___2 {
	struct ip_ra_chain___2 *next;
	struct sock___51 *sk;
	union {
		void (*destructor)(struct sock___51 *);
		struct sock___51 *saved_sk;
	};
	struct callback_head rcu;
};

struct xfrm_replay___9 {
	void (*advance)(struct xfrm_state___9 *, __be32);
	int (*check)(struct xfrm_state___9 *, struct sk_buff___64 *, __be32);
	int (*recheck)(struct xfrm_state___9 *, struct sk_buff___64 *, __be32);
	void (*notify)(struct xfrm_state___9 *, int);
	int (*overflow)(struct xfrm_state___9 *, struct sk_buff___64 *);
};

struct xfrm_type___9 {
	char *description;
	struct module___168 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___9 *);
	void (*destructor)(struct xfrm_state___9 *);
	int (*input)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*output)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*reject)(struct xfrm_state___9 *, struct sk_buff___64 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___9 *, struct sk_buff___64 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___9 *, int);
};

struct xfrm_state_afinfo___9;

struct xfrm_mode___9 {
	int (*input2)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*input)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*output2)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*output)(struct xfrm_state___9 *, struct sk_buff___64 *);
	struct xfrm_state_afinfo___9 *afinfo;
	struct module___168 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___9 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___168 *owner;
	const struct xfrm_type___9 *type_map[256];
	struct xfrm_mode___9 *mode_map[5];
	int (*init_flags)(struct xfrm_state___9 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___9 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___9 **, struct xfrm_state___9 **, int);
	union {
		int (*output)(struct sock___51 *, struct sk_buff___64 *);
		struct {
			int (*output)(struct sk_buff___64 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___51 *, struct sk_buff___64 *);
		struct {
			int (*output_finish)(struct sk_buff___64 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*extract_output)(struct xfrm_state___9 *, struct sk_buff___64 *);
	int (*transport_finish)(struct sk_buff___64 *, int);
};

struct fib_rule___4 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___4 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___75 *fr_net;
};

struct fib_lookup_arg___4 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___4 *rule;
	int flags;
};

struct page___271;

typedef struct page___271 *pgtable_t___271;

struct address_space___272;

struct kmem_cache___255;

struct page___271 {
	long unsigned int flags;
	struct address_space___272 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___271 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___271 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___255 *slab_cache;
		struct page___271 *first_page;
	};
	long: 64;
};

struct task_struct___273;

struct pv_cpu_ops___273 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___273 *);
	void (*end_context_switch)(struct task_struct___273 *);
};

struct mutex___274 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___273 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___266 {
	struct page___271 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___280;

struct nsproxy___152;

struct signal_struct___273;

struct css_set___167;

struct task_struct___273 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___273 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___280 *mm;
	struct mm_struct___280 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___273 *real_parent;
	struct task_struct___273 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___273 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___273 = 0,
		VTIME_USER___273 = 1,
		VTIME_SYS___273 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___152 *nsproxy;
	struct signal_struct___273 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___167 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___274 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___266 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___280 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___280 *, struct mm_struct___280 *);
	void (*dup_mmap)(struct mm_struct___280 *, struct mm_struct___280 *);
	void (*exit_mmap)(struct mm_struct___280 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___280 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___280 *);
	void (*pgd_free)(struct mm_struct___280 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___280 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___280 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___280 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___280 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___280 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___280 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___280 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___280 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___280 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___280 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___280 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___274 lock;
	void *vdso;
} mm_context_t___274;

struct xol_area___271;

struct uprobes_state___271 {
	struct xol_area___271 *xol_area;
};

struct vm_area_struct___280;

struct file___272;

struct core_state___273;

struct mm_struct___280 {
	struct vm_area_struct___280 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___280 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___280 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___274 context;
	long unsigned int flags;
	struct core_state___273 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___273 *owner;
	struct file___272 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___271 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___54;

struct kobj_type___54;

struct kobject___54 {
	const char *name;
	struct list_head entry;
	struct kobject___54 *parent;
	struct kset___54 *kset;
	struct kobj_type___54 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___169;

struct module_kobject___168 {
	struct kobject___54 kobj;
	struct module___169 *mod;
	struct kobject___54 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___168;

struct module___169 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___168 mkobj;
	struct module_attribute___168 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___54 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___273 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___273;

struct lruvec___273 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___273 *zone;
};

struct pglist_data___273;

struct zone___273 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___273 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___273 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___273 {
	struct zone___273 *zone;
	int zone_idx;
};

struct zonelist___273 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___273 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___273 {
	struct zone___273 node_zones[4];
	struct zonelist___273 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___273 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___196;

struct x86_io_apic_ops___196 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___196 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___196;

struct irq_data___196 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___196 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___270;

struct dev_pm_ops___270 {
	int (*prepare)(struct device___270 *);
	void (*complete)(struct device___270 *);
	int (*suspend)(struct device___270 *);
	int (*resume)(struct device___270 *);
	int (*freeze)(struct device___270 *);
	int (*thaw)(struct device___270 *);
	int (*poweroff)(struct device___270 *);
	int (*restore)(struct device___270 *);
	int (*suspend_late)(struct device___270 *);
	int (*resume_early)(struct device___270 *);
	int (*freeze_late)(struct device___270 *);
	int (*thaw_early)(struct device___270 *);
	int (*poweroff_late)(struct device___270 *);
	int (*restore_early)(struct device___270 *);
	int (*suspend_noirq)(struct device___270 *);
	int (*resume_noirq)(struct device___270 *);
	int (*freeze_noirq)(struct device___270 *);
	int (*thaw_noirq)(struct device___270 *);
	int (*poweroff_noirq)(struct device___270 *);
	int (*restore_noirq)(struct device___270 *);
	int (*runtime_suspend)(struct device___270 *);
	int (*runtime_resume)(struct device___270 *);
	int (*runtime_idle)(struct device___270 *);
};

struct dev_pm_qos___73;

struct dev_pm_info___73 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___73 *qos;
};

struct dma_map_ops___135;

struct dev_archdata___135 {
	struct dma_map_ops___135 *dma_ops;
	void *iommu;
};

struct device_type___270;

struct bus_type___270;

struct device_driver___270;

struct dev_pm_domain___270;

struct class___270;

struct attribute_group___232;

struct device_rh___270;

struct device___270 {
	struct device___270 *parent;
	struct device_private *p;
	struct kobject___54 kobj;
	const char *init_name;
	const struct device_type___270 *type;
	struct mutex___274 mutex;
	struct bus_type___270 *bus;
	struct device_driver___270 *driver;
	void *platform_data;
	struct dev_pm_info___73 power;
	struct dev_pm_domain___270 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___135 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___270 *class;
	const struct attribute_group___232 **groups;
	void (*release)(struct device___270 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___270 *device_rh;
};

struct dev_pm_qos_request___74;

struct dev_pm_qos___73 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___74 *latency_req;
	struct dev_pm_qos_request___74 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___74 *latency_tolerance_req;
};

struct dev_pm_info_rh___270 {
	void (*set_latency_tolerance)(struct device___270 *, s32);
};

struct dev_pm_domain___270 {
	struct dev_pm_ops___270 ops;
};

struct smp_ops___273 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___273 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___77;

struct ctl_node___77 {
	struct rb_node node;
	struct ctl_table_header___77 *header;
};

struct ctl_table_root___77;

struct ctl_table_set___77;

struct ctl_dir___77;

struct ctl_table_header___77 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___77 *root;
	struct ctl_table_set___77 *set;
	struct ctl_dir___77 *parent;
	struct ctl_node___77 *node;
};

struct ctl_dir___77 {
	struct ctl_table_header___77 header;
	struct rb_root root;
};

struct ctl_table_set___77 {
	int (*is_seen)(struct ctl_table_set___77 *);
	struct ctl_dir___77 dir;
};

struct ctl_table_root___77 {
	struct ctl_table_set___77 default_set;
	struct ctl_table_set___77 * (*lookup)(struct ctl_table_root___77 *, struct nsproxy___152 *);
	int (*permissions)(struct ctl_table_header___77 *, struct ctl_table *);
};

struct net___76;

struct nsproxy___152 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___76 *net_ns;
};

struct sock___52;

struct kobj_ns_type_operations___51 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___52 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___51;

struct sock_common___51 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___51 *skc_prot;
	struct net___76 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___65;

struct sk_buff_head___63 {
	struct sk_buff___65 *next;
	struct sk_buff___65 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___52;

struct socket_wq___51;

struct dst_entry___52;

struct socket___52;

struct cg_proto___51;

struct sock___52 {
	struct sock_common___51 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___63 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___65 *head;
		struct sk_buff___65 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___52 *sk_filter;
	struct socket_wq___51 *sk_wq;
	struct sk_buff_head___63 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___52 *sk_rx_dst;
	struct dst_entry___52 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___63 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___63 sk_error_queue;
	struct proto___51 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___52 *sk_socket;
	void *sk_user_data;
	struct page_frag___266 sk_frag;
	struct sk_buff___65 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___51 *sk_cgrp;
	void (*sk_state_change)(struct sock___52 *);
	void (*sk_data_ready)(struct sock___52 *, int);
	void (*sk_write_space)(struct sock___52 *);
	void (*sk_error_report)(struct sock___52 *);
	int (*sk_backlog_rcv)(struct sock___52 *, struct sk_buff___65 *);
	void (*sk_destruct)(struct sock___52 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___234;

struct attribute_group___232 {
	const char *name;
	umode_t (*is_visible)(struct kobject___54 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___234 **bin_attrs;
};

struct bin_attribute___234 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___272 *, struct kobject___54 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___272 *, struct kobject___54 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	int (*mmap)(struct file___272 *, struct kobject___54 *, struct bin_attribute___234 *, struct vm_area_struct___280 *);
};

struct dentry___272;

struct path___272 {
	struct vfsmount *mnt;
	struct dentry___272 *dentry;
};

struct inode___272;

struct file_operations___272;

struct file___272 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___272 f_path;
	struct inode___272 *f_inode;
	const struct file_operations___272 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___272 *f_mapping;
	struct mutex___274 f_pos_lock;
};

struct vm_operations_struct___246;

struct vm_area_struct___280 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___280 *vm_next;
	struct vm_area_struct___280 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___280 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___246 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___272 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___54 {
	ssize_t (*show)(struct kobject___54 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___54 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___54 *, const struct attribute *);
};

struct kset_uevent_ops___54;

struct kset___54 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___54 kobj;
	const struct kset_uevent_ops___54 *uevent_ops;
};

struct kobj_type___54 {
	void (*release)(struct kobject___54 *);
	const struct sysfs_ops___54 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___51 * (*child_ns_type)(struct kobject___54 *);
	const void * (*namespace)(struct kobject___54 *);
};

struct kset_uevent_ops___54 {
	int (* const filter)(struct kset___54 *, struct kobject___54 *);
	const char * (* const name)(struct kset___54 *, struct kobject___54 *);
	int (* const uevent)(struct kset___54 *, struct kobject___54 *, struct kobj_uevent_env *);
};

struct module_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___168 *, struct module_kobject___168 *, char *);
	ssize_t (*store)(struct module_attribute___168 *, struct module_kobject___168 *, const char *, size_t);
	void (*setup)(struct module___169 *, const char *);
	int (*test)(struct module___169 *);
	void (*free)(struct module___169 *);
};

struct xol_area___271 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___271 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___254;

struct memcg_cache_params___255;

struct kmem_cache___255 {
	struct kmem_cache_cpu___254 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___54 kobj;
	struct memcg_cache_params___255 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___272;

struct address_space___272 {
	struct inode___272 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___274 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___272 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___242;

struct vm_operations_struct___246 {
	void (*open)(struct vm_area_struct___280 *);
	void (*close)(struct vm_area_struct___280 *);
	int (*fault)(struct vm_area_struct___280 *, struct vm_fault___242 *);
	int (*page_mkwrite)(struct vm_area_struct___280 *, struct vm_fault___242 *);
	int (*access)(struct vm_area_struct___280 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___280 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___280 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___280 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___280 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___273 {
	struct task_struct___273 *task;
	struct core_thread___273 *next;
};

struct core_state___273 {
	atomic_t nr_threads;
	struct core_thread___273 dumper;
	struct completion startup;
};

struct signal_struct___273 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___273 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___273 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___274 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___167;

struct css_set___167 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___167 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___254 {
	void **freelist;
	long unsigned int tid;
	struct page___271 *page;
	struct page___271 *partial;
};

struct memcg_cache_params___255 {
	bool is_root_cache;
	union {
		struct kmem_cache___255 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___255 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dentry_operations___272;

struct super_block___272;

struct dentry___272 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___272 *d_parent;
	struct qstr d_name;
	struct inode___272 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___272 *d_op;
	struct super_block___272 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___272;

struct file_lock___272;

struct dquot___272;

struct block_device___272;

struct inode___272 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___272 *i_op;
	struct super_block___272 *i_sb;
	struct address_space___272 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___274 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___272 *i_fop;
	struct file_lock___272 *i_flock;
	struct address_space___272 i_data;
	struct dquot___272 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___272 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___272 {
	int (*d_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_hash)(const struct dentry___272 *, struct qstr *);
	int (*d_compare)(const struct dentry___272 *, const struct dentry___272 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___272 *);
	void (*d_release)(struct dentry___272 *);
	void (*d_prune)(struct dentry___272 *);
	void (*d_iput)(struct dentry___272 *, struct inode___272 *);
	char * (*d_dname)(struct dentry___272 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___272 *);
	int (*d_manage)(struct dentry___272 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___272;

struct mem_dqinfo___272 {
	struct quota_format_type___272 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___272;

struct quota_info___272 {
	unsigned int flags;
	struct mutex___274 dqio_mutex;
	struct mutex___274 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___272 *files[2];
	struct mem_dqinfo___272 info[2];
	const struct quota_format_ops___272 *ops[2];
};

struct file_system_type___272;

struct super_operations___272;

struct dquot_operations___272;

struct quotactl_ops___272;

struct xattr_handler___168;

struct super_block___272 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___272 *s_type;
	const struct super_operations___272 *s_op;
	const struct dquot_operations___272 *dq_op;
	const struct quotactl_ops___272 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___272 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___168 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___272 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___272 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___274 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___272 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___272 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___272 *bd_inode;
	struct super_block___272 *bd_super;
	struct mutex___274 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___272 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___274 bd_fsfreeze_mutex;
};

struct cgroup___167;

struct cgroup_subsys_state___167 {
	struct cgroup___167 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___59;

typedef int kiocb_cancel_fn___59(struct kiocb___59 *, struct io_event *);

struct kiocb___59 {
	atomic_t ki_users;
	struct file___272 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___59 *ki_cancel;
	void (*ki_dtor)(struct kiocb___59 *);
	union {
		void *user;
		struct task_struct___273 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___272 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___272 *ia_file;
};

struct dquot___272 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___274 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___272 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___272 {
	int qf_fmt_id;
	const struct quota_format_ops___272 *qf_ops;
	struct module___169 *qf_owner;
	struct quota_format_type___272 *qf_next;
};

struct quota_format_ops___272 {
	int (*check_quota_file)(struct super_block___272 *, int);
	int (*read_file_info)(struct super_block___272 *, int);
	int (*write_file_info)(struct super_block___272 *, int);
	int (*free_file_info)(struct super_block___272 *, int);
	int (*read_dqblk)(struct dquot___272 *);
	int (*commit_dqblk)(struct dquot___272 *);
	int (*release_dqblk)(struct dquot___272 *);
};

struct dquot_operations___272 {
	int (*write_dquot)(struct dquot___272 *);
	struct dquot___272 * (*alloc_dquot)(struct super_block___272 *, int);
	void (*destroy_dquot)(struct dquot___272 *);
	int (*acquire_dquot)(struct dquot___272 *);
	int (*release_dquot)(struct dquot___272 *);
	int (*mark_dirty)(struct dquot___272 *);
	int (*write_info)(struct super_block___272 *, int);
	qsize_t * (*get_reserved_space)(struct inode___272 *);
};

struct quotactl_ops___272 {
	int (*quota_on)(struct super_block___272 *, int, int, struct path___272 *);
	int (*quota_on_meta)(struct super_block___272 *, int, int);
	int (*quota_off)(struct super_block___272 *, int);
	int (*quota_sync)(struct super_block___272 *, int);
	int (*get_info)(struct super_block___272 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___272 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___272 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___272 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___272 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___272 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___272 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___272 *, unsigned int);
};

struct address_space_operations___272 {
	int (*writepage)(struct page___271 *, struct writeback_control *);
	int (*readpage)(struct file___272 *, struct page___271 *);
	int (*writepages)(struct address_space___272 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___271 *);
	int (*readpages)(struct file___272 *, struct address_space___272 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___272 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___271 **, void **);
	int (*write_end)(struct file___272 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___271 *, void *);
	sector_t (*bmap)(struct address_space___272 *, sector_t);
	void (*invalidatepage)(struct page___271 *, long unsigned int);
	int (*releasepage)(struct page___271 *, gfp_t);
	void (*freepage)(struct page___271 *);
	ssize_t (*direct_IO)(int, struct kiocb___59 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___272 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___272 *, struct page___271 *, struct page___271 *, enum migrate_mode);
	int (*launder_page)(struct page___271 *);
	int (*is_partially_uptodate)(struct page___271 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___271 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___272 *, struct page___271 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___272 *, sector_t *);
	void (*swap_deactivate)(struct file___272 *);
	void (*invalidatepage_range)(struct page___271 *, unsigned int, unsigned int);
};

struct inode_operations___272 {
	struct dentry___272 * (*lookup)(struct inode___272 *, struct dentry___272 *, unsigned int);
	void * (*follow_link)(struct dentry___272 *, struct nameidata *);
	int (*permission)(struct inode___272 *, int);
	struct posix_acl * (*get_acl)(struct inode___272 *, int);
	int (*readlink)(struct dentry___272 *, char *, int);
	void (*put_link)(struct dentry___272 *, struct nameidata *, void *);
	int (*create)(struct inode___272 *, struct dentry___272 *, umode_t, bool);
	int (*link)(struct dentry___272 *, struct inode___272 *, struct dentry___272 *);
	int (*unlink)(struct inode___272 *, struct dentry___272 *);
	int (*symlink)(struct inode___272 *, struct dentry___272 *, const char *);
	int (*mkdir)(struct inode___272 *, struct dentry___272 *, umode_t);
	int (*rmdir)(struct inode___272 *, struct dentry___272 *);
	int (*mknod)(struct inode___272 *, struct dentry___272 *, umode_t, dev_t);
	int (*rename)(struct inode___272 *, struct dentry___272 *, struct inode___272 *, struct dentry___272 *);
	int (*setattr)(struct dentry___272 *, struct iattr___272 *);
	int (*getattr)(struct vfsmount *, struct dentry___272 *, struct kstat *);
	int (*setxattr)(struct dentry___272 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___272 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___272 *, char *, size_t);
	int (*removexattr)(struct dentry___272 *, const char *);
	int (*fiemap)(struct inode___272 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___272 *, struct timespec *, int);
	int (*atomic_open)(struct inode___272 *, struct dentry___272 *, struct file___272 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___158;

struct seq_file___197;

struct file_operations___272 {
	struct module___169 *owner;
	loff_t (*llseek)(struct file___272 *, loff_t, int);
	ssize_t (*read)(struct file___272 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___272 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___59 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___59 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___272 *, void *, filldir_t);
	unsigned int (*poll)(struct file___272 *, struct poll_table_struct___158 *);
	long int (*unlocked_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___272 *, struct vm_area_struct___280 *);
	int (*open)(struct inode___272 *, struct file___272 *);
	int (*flush)(struct file___272 *, fl_owner_t);
	int (*release)(struct inode___272 *, struct file___272 *);
	int (*fsync)(struct file___272 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___59 *, int);
	int (*fasync)(int, struct file___272 *, int);
	int (*lock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*sendpage)(struct file___272 *, struct page___271 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___272 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___272 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___272 *, long int, struct file_lock___272 **, void **);
		struct {
			int (*setlease)(struct file___272 *, long int, struct file_lock___272 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___272 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___197 *, struct file___272 *);
};

struct fasync_struct___272;

struct file_lock_operations___272;

struct lock_manager_operations___272;

struct file_lock___272 {
	struct file_lock___272 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___272 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___272 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___272 *fl_ops;
	const struct lock_manager_operations___272 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___272 {
	void (*fl_copy_lock)(struct file_lock___272 *, struct file_lock___272 *);
	void (*fl_release_private)(struct file_lock___272 *);
};

struct lock_manager_operations___272 {
	int (*lm_compare_owner)(struct file_lock___272 *, struct file_lock___272 *);
	long unsigned int (*lm_owner_key)(struct file_lock___272 *);
	void (*lm_notify)(struct file_lock___272 *);
	int (*lm_grant)(struct file_lock___272 *, struct file_lock___272 *, int);
	void (*lm_break)(struct file_lock___272 *);
	int (*lm_change)(struct file_lock___272 **, int);
};

struct fasync_struct___272 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___272 *fa_next;
	struct file___272 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___272 {
	const char *name;
	int fs_flags;
	struct dentry___272 * (*mount)(struct file_system_type___272 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___272 *);
	struct module___169 *owner;
	struct file_system_type___272 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___272 {
	struct inode___272 * (*alloc_inode)(struct super_block___272 *);
	void (*destroy_inode)(struct inode___272 *);
	void (*dirty_inode)(struct inode___272 *, int);
	int (*write_inode)(struct inode___272 *, struct writeback_control *);
	int (*drop_inode)(struct inode___272 *);
	void (*evict_inode)(struct inode___272 *);
	void (*put_super)(struct super_block___272 *);
	int (*sync_fs)(struct super_block___272 *, int);
	int (*freeze_fs)(struct super_block___272 *);
	int (*unfreeze_fs)(struct super_block___272 *);
	int (*statfs)(struct dentry___272 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___272 *, int *, char *);
	void (*umount_begin)(struct super_block___272 *);
	int (*show_options)(struct seq_file___197 *, struct dentry___272 *);
	int (*show_devname)(struct seq_file___197 *, struct dentry___272 *);
	int (*show_path)(struct seq_file___197 *, struct dentry___272 *);
	int (*show_stats)(struct seq_file___197 *, struct dentry___272 *);
	ssize_t (*quota_read)(struct super_block___272 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___272 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___272 *);
	int (*bdev_try_to_free_page)(struct super_block___272 *, struct page___271 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___272 *);
	void (*free_cached_objects)(struct super_block___272 *, int);
};

struct xattr_handler___168 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___272 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___272 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___272 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___160)(struct file___272 *, wait_queue_head_t *, struct poll_table_struct___158 *);

struct poll_table_struct___158 {
	poll_queue_proc___160 _qproc;
	long unsigned int _key;
};

struct seq_operations___197;

struct seq_file___197 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___274 lock;
	const struct seq_operations___197 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dma_map_ops___135 {
	void * (*alloc)(struct device___270 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___270 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___270 *, struct vm_area_struct___280 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___270 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___270 *, struct page___271 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___270 *, dma_addr_t);
	int (*dma_supported)(struct device___270 *, u64);
	int (*set_dma_mask)(struct device___270 *, u64);
	int is_phys;
};

struct bus_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___270 *, char *);
	ssize_t (*store)(struct bus_type___270 *, const char *, size_t);
};

struct device_attribute___270;

struct driver_attribute___270;

struct bus_type___270 {
	const char *name;
	const char *dev_name;
	struct device___270 *dev_root;
	struct bus_attribute___270 *bus_attrs;
	struct device_attribute___270 *dev_attrs;
	struct driver_attribute___270 *drv_attrs;
	const struct attribute_group___232 **bus_groups;
	const struct attribute_group___232 **dev_groups;
	const struct attribute_group___232 **drv_groups;
	int (*match)(struct device___270 *, struct device_driver___270 *);
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	int (*probe)(struct device___270 *);
	int (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*online)(struct device___270 *);
	int (*offline)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct device___270 *, struct device_attribute___270 *, char *);
	ssize_t (*store)(struct device___270 *, struct device_attribute___270 *, const char *, size_t);
};

struct driver_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___270 *, char *);
	ssize_t (*store)(struct device_driver___270 *, const char *, size_t);
};

struct device_driver___270 {
	const char *name;
	struct bus_type___270 *bus;
	struct module___169 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___270 *);
	int (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	const struct attribute_group___232 **groups;
	const struct dev_pm_ops___270 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___270 {
	const char *name;
	const struct attribute_group___232 **groups;
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
};

struct class_attribute___270;

struct class___270 {
	const char *name;
	struct module___169 *owner;
	struct class_attribute___270 *class_attrs;
	struct device_attribute___270 *dev_attrs;
	const struct attribute_group___232 **dev_groups;
	struct bin_attribute___234 *dev_bin_attrs;
	struct kobject___54 *dev_kobj;
	int (*dev_uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *);
	void (*class_release)(struct class___270 *);
	void (*dev_release)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	const struct kobj_ns_type_operations___51 *ns_type;
	const void * (*namespace)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
	struct subsys_private *p;
};

struct class_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct class___270 *, struct class_attribute___270 *, char *);
	ssize_t (*store)(struct class___270 *, struct class_attribute___270 *, const char *, size_t);
	const void * (*namespace)(struct class___270 *, const struct class_attribute___270 *);
};

struct device_rh___270 {
	struct dev_pm_info_rh___270 power;
};

struct dev_pm_qos_request___74 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___270 *dev;
};

struct vm_fault___242 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___271 *page;
};

struct socket_wq___51 {
	wait_queue_head_t wait;
	struct fasync_struct___272 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___51;

struct socket___52 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___51 *wq;
	struct file___272 *file;
	struct sock___52 *sk;
	const struct proto_ops___51 *ops;
};

struct proto_ops___51 {
	int family;
	struct module___169 *owner;
	int (*release)(struct socket___52 *);
	int (*bind)(struct socket___52 *, struct sockaddr *, int);
	int (*connect)(struct socket___52 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___52 *, struct socket___52 *);
	int (*accept)(struct socket___52 *, struct socket___52 *, int);
	int (*getname)(struct socket___52 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___272 *, struct socket___52 *, struct poll_table_struct___158 *);
	int (*ioctl)(struct socket___52 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___52 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___52 *, int);
	int (*shutdown)(struct socket___52 *, int);
	int (*setsockopt)(struct socket___52 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___52 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___52 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___52 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___59 *, struct socket___52 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___59 *, struct socket___52 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___272 *, struct socket___52 *, struct vm_area_struct___280 *);
	ssize_t (*sendpage)(struct socket___52 *, struct page___271 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___52 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___52 *, int);
		struct {
			void (*set_peek_off)(struct sock___52 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___74 {
	struct ctl_table_header___77 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___75 {
	struct mutex___274 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___74 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___77 *ctl;
};

struct netns_ipv4___74 {
	struct ctl_table_header___77 *forw_hdr;
	struct ctl_table_header___77 *frags_hdr;
	struct ctl_table_header___77 *ipv4_hdr;
	struct ctl_table_header___77 *route_hdr;
	struct ctl_table_header___77 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___52 *fibnl;
	struct sock___52 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___74 {
	struct ctl_table_header___77 *hdr;
	struct ctl_table_header___77 *route_hdr;
	struct ctl_table_header___77 *icmp_hdr;
	struct ctl_table_header___77 *frags_hdr;
	struct ctl_table_header___77 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___62;

struct neighbour___52;

struct dst_ops___76 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___76 *);
	struct dst_entry___52 * (*check)(struct dst_entry___52 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___52 *);
	unsigned int (*mtu)(const struct dst_entry___52 *);
	u32 * (*cow_metrics)(struct dst_entry___52 *, long unsigned int);
	void (*destroy)(struct dst_entry___52 *);
	void (*ifdown)(struct dst_entry___52 *, struct net_device___62 *, int);
	struct dst_entry___52 * (*negative_advice)(struct dst_entry___52 *);
	void (*link_failure)(struct sk_buff___65 *);
	void (*update_pmtu)(struct dst_entry___52 *, struct sock___52 *, struct sk_buff___65 *, u32);
	void (*redirect)(struct dst_entry___52 *, struct sock___52 *, struct sk_buff___65 *);
	int (*local_out)(struct sk_buff___65 *);
	struct neighbour___52 * (*neigh_lookup)(const struct dst_entry___52 *, struct sk_buff___65 *, const void *);
	struct kmem_cache___255 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___76 {
	struct netns_sysctl_ipv6___74 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___76 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___52 **icmp_sk;
	struct sock___52 *ndisc_sk;
	struct sock___52 *tcp_sk;
	struct sock___52 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___74 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___77 *sysctl_header;
	struct sock___52 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___51 {
	struct sock___52 *v4_ctl_sk;
	struct sock___52 *v6_ctl_sk;
};

struct netns_nf___74 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___77 *nf_log_dir_header;
};

struct nf_proto_net___74 {
	struct ctl_table_header___77 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___74 {
	struct nf_proto_net___74 pn;
	unsigned int timeout;
};

struct nf_tcp_net___74 {
	struct nf_proto_net___74 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___74 {
	struct nf_proto_net___74 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___74 {
	struct nf_proto_net___74 pn;
	unsigned int timeout;
};

struct nf_ip_net___74 {
	struct nf_generic_net___74 generic;
	struct nf_tcp_net___74 tcp;
	struct nf_udp_net___74 udp;
	struct nf_icmp_net___74 icmp;
	struct nf_icmp_net___74 icmpv6;
};

struct netns_ct___75 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___77 *sysctl_header;
	struct ctl_table_header___77 *acct_sysctl_header;
	struct ctl_table_header___77 *tstamp_sysctl_header;
	struct ctl_table_header___77 *event_sysctl_header;
	struct ctl_table_header___77 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___255 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___74 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___74 {
	struct netns_sysctl_ipv6___74 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___76 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___52 *nlsk;
	struct sock___52 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___77 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___76 xfrm4_dst_ops;
	struct dst_ops___76 xfrm6_dst_ops;
};

struct net___76 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___77 sysctls;
	struct sock___52 *rtnl;
	struct sock___52 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___62 *loopback_dev;
	struct netns_core___74 core;
	struct netns_mib mib;
	struct netns_packet___75 packet;
	struct netns_unix___74 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___74 ipv4;
	struct netns_ipv6___76 ipv6;
	struct netns_sctp___74 sctp;
	struct netns_dccp___51 dccp;
	struct netns_nf___74 nf;
	struct netns_xt xt;
	struct netns_ct___75 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___74 nf_frag;
	struct sock___52 *nfnl;
	struct sock___52 *nfnl_stash;
	struct sk_buff_head___63 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___76 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___52 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___52 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___274 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___274 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___62 {
	atomic_t use;
	unsigned int mask;
	struct net_device___62 *physindev;
	struct net_device___62 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___62(struct sk_buff___65 **);

struct net_device_ops___62;

struct ethtool_ops___62;

struct header_ops___62;

struct inet6_dev___28;

struct netdev_rx_queue___62;

struct netdev_queue___62;

struct rtnl_link_ops___53;

struct dcbnl_rtnl_ops___62;

struct net_device___62 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___62 *netdev_ops;
	const struct ethtool_ops___62 *ethtool_ops;
	const struct header_ops___62 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___54 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___28 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___62 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___62 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___62 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___62 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___62 = 0,
		NETREG_REGISTERED___62 = 1,
		NETREG_UNREGISTERING___62 = 2,
		NETREG_UNREGISTERED___62 = 3,
		NETREG_RELEASED___62 = 4,
		NETREG_DUMMY___62 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___62 = 0,
		RTNL_LINK_INITIALIZING___62 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___62 *);
	struct netpoll_info *npinfo;
	struct net___76 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___270 dev;
	const struct attribute_group___232 *sysfs_groups[4];
	const struct rtnl_link_ops___53 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___62 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___65 {
	struct sk_buff___65 *next;
	struct sk_buff___65 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___52 *sk;
	struct net_device___62 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___65 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___62 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___62 {
	int (*get_settings)(struct net_device___62 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___62 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___62 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___62 *);
	void (*get_regs)(struct net_device___62 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___62 *);
	void (*set_msglevel)(struct net_device___62 *, u32);
	int (*nway_reset)(struct net_device___62 *);
	u32 (*get_link)(struct net_device___62 *);
	int (*get_eeprom_len)(struct net_device___62 *);
	int (*get_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___62 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___62 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___62 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___62 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___62 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___62 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___62 *);
	void (*complete)(struct net_device___62 *);
	u32 (*get_priv_flags)(struct net_device___62 *);
	int (*set_priv_flags)(struct net_device___62 *, u32);
	int (*get_sset_count)(struct net_device___62 *, int);
	int (*get_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___62 *, struct ethtool_flash *);
	int (*reset)(struct net_device___62 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___62 *);
	int (*get_rxfh_indir)(struct net_device___62 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___62 *, const u32 *);
	void (*get_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___62 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___62 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___62 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___62 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___62 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___62 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___62 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___62 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___23;

struct dst_entry___52 {
	struct callback_head callback_head;
	struct dst_entry___52 *child;
	struct net_device___62 *dev;
	struct dst_ops___76 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___52 *path;
	struct dst_entry___52 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___65 *);
	union {
		int (*output)(struct sock___52 *, struct sk_buff___65 *);
		struct {
			int (*output)(struct sk_buff___65 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___52 *next;
		struct rtable___23 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___52;

struct neigh_parms___52;

struct neigh_ops___52;

struct neighbour___52 {
	struct neighbour___52 *next;
	struct neigh_table___52 *tbl;
	struct neigh_parms___52 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___63 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___52 *, struct sk_buff___65 *);
	const struct neigh_ops___52 *ops;
	struct callback_head rcu;
	struct net_device___62 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___76 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___65 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___65 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___76 *, struct dst_entry___52 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___65 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___65 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___196 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___196 *);
	void (*irq_shutdown)(struct irq_data___196 *);
	void (*irq_enable)(struct irq_data___196 *);
	void (*irq_disable)(struct irq_data___196 *);
	void (*irq_ack)(struct irq_data___196 *);
	void (*irq_mask)(struct irq_data___196 *);
	void (*irq_mask_ack)(struct irq_data___196 *);
	void (*irq_unmask)(struct irq_data___196 *);
	void (*irq_eoi)(struct irq_data___196 *);
	int (*irq_set_affinity)(struct irq_data___196 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___196 *);
	int (*irq_set_type)(struct irq_data___196 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___196 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___196 *);
	void (*irq_bus_sync_unlock)(struct irq_data___196 *);
	void (*irq_cpu_online)(struct irq_data___196 *);
	void (*irq_cpu_offline)(struct irq_data___196 *);
	void (*irq_suspend)(struct irq_data___196 *);
	void (*irq_resume)(struct irq_data___196 *);
	void (*irq_pm_shutdown)(struct irq_data___196 *);
	void (*irq_print_chip)(struct irq_data___196 *, struct seq_file___197 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___196 *, void *);
	long unsigned int flags;
};

struct seq_operations___197 {
	void * (*start)(struct seq_file___197 *, loff_t *);
	void (*stop)(struct seq_file___197 *, void *);
	void * (*next)(struct seq_file___197 *, void *, loff_t *);
	int (*show)(struct seq_file___197 *, void *);
};

struct dcbnl_rtnl_ops___62 {
	int (*ieee_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___62 *);
	u8 (*setstate)(struct net_device___62 *, u8);
	void (*getpermhwaddr)(struct net_device___62 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___62 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___62 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___62 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___62 *, int, u8 *);
	void (*setpfccfg)(struct net_device___62 *, int, u8);
	void (*getpfccfg)(struct net_device___62 *, int, u8 *);
	u8 (*setall)(struct net_device___62 *);
	u8 (*getcap)(struct net_device___62 *, int, u8 *);
	int (*getnumtcs)(struct net_device___62 *, int, u8 *);
	int (*setnumtcs)(struct net_device___62 *, int, u8);
	u8 (*getpfcstate)(struct net_device___62 *);
	void (*setpfcstate)(struct net_device___62 *, u8);
	void (*getbcncfg)(struct net_device___62 *, int, u32 *);
	void (*setbcncfg)(struct net_device___62 *, int, u32);
	void (*getbcnrp)(struct net_device___62 *, int, u8 *);
	void (*setbcnrp)(struct net_device___62 *, int, u8);
	u8 (*setapp)(struct net_device___62 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___62 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___62 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___62 *, int, u8);
	u8 (*getdcbx)(struct net_device___62 *);
	u8 (*setdcbx)(struct net_device___62 *, u8);
	int (*peer_getappinfo)(struct net_device___62 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___62 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___62 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___62 *, struct cee_pfc *);
};

struct cgroupfs_root___167;

struct cgroup___167 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___167 *parent;
	struct dentry___272 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___167 *subsys[11];
	struct cgroupfs_root___167 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___274 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___167 {
	struct super_block___272 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___167 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___103 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___272 *, struct file___272 *);
	ssize_t (*read)(struct cgroup___167 *, struct cftype___103 *, struct file___272 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___167 *, struct cftype___103 *);
	s64 (*read_s64)(struct cgroup___167 *, struct cftype___103 *);
	int (*read_map)(struct cgroup___167 *, struct cftype___103 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___167 *, struct cftype___103 *, struct seq_file___197 *);
	ssize_t (*write)(struct cgroup___167 *, struct cftype___103 *, struct file___272 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___167 *, struct cftype___103 *, u64);
	int (*write_s64)(struct cgroup___167 *, struct cftype___103 *, s64);
	int (*write_string)(struct cgroup___167 *, struct cftype___103 *, const char *);
	int (*trigger)(struct cgroup___167 *, unsigned int);
	int (*release)(struct inode___272 *, struct file___272 *);
	int (*register_event)(struct cgroup___167 *, struct cftype___103 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___167 *, struct cftype___103 *, struct eventfd_ctx *);
};

struct cftype_set___99 {
	struct list_head node;
	struct cftype___103 *cfts;
};

struct task_and_cgroup___99 {
	struct task_struct___273 *task;
	struct cgroup___167 *cgrp;
	struct css_set___167 *cg;
};

struct cgroup_taskset___99 {
	struct task_and_cgroup___99 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___167 *cur_cgrp;
};

struct cgroup_subsys___99 {
	struct cgroup_subsys_state___167 * (*css_alloc)(struct cgroup___167 *);
	int (*css_online)(struct cgroup___167 *);
	void (*css_offline)(struct cgroup___167 *);
	void (*css_free)(struct cgroup___167 *);
	int (*can_attach)(struct cgroup___167 *, struct cgroup_taskset___99 *);
	void (*cancel_attach)(struct cgroup___167 *, struct cgroup_taskset___99 *);
	void (*attach)(struct cgroup___167 *, struct cgroup_taskset___99 *);
	void (*fork)(struct task_struct___273 *);
	void (*exit)(struct cgroup___167 *, struct cgroup___167 *, struct task_struct___273 *);
	void (*bind)(struct cgroup___167 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___167 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___103 *base_cftypes;
	struct cftype_set___99 base_cftset;
	struct module___169 *module;
};

struct request_sock_ops___37;

struct request_sock___38 {
	struct sock_common___51 __req_common;
	struct request_sock___38 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___37 *rsk_ops;
	struct sock___52 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___64 {
	struct sk_buff___65 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___65 *, struct netlink_callback___64 *);
	int (*done)(struct netlink_callback___64 *);
	void *data;
	struct module___169 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___62 {
	int (*create)(struct sk_buff___65 *, struct net_device___62 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___65 *, unsigned char *);
	int (*rebuild)(struct sk_buff___65 *);
	int (*cache)(const struct neighbour___52 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___62 *, const unsigned char *);
};

struct napi_struct___62 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___62 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___62 *dev;
	struct sk_buff___65 *gro_list;
	struct sk_buff___65 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___62 {
	struct net_device___62 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___54 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___62 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___54 kobj;
	struct net_device___62 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___62 {
	int (*ndo_init)(struct net_device___62 *);
	void (*ndo_uninit)(struct net_device___62 *);
	int (*ndo_open)(struct net_device___62 *);
	int (*ndo_stop)(struct net_device___62 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___65 *, struct net_device___62 *);
	u16 (*ndo_select_queue)(struct net_device___62 *, struct sk_buff___65 *);
	void (*ndo_change_rx_flags)(struct net_device___62 *, int);
	void (*ndo_set_rx_mode)(struct net_device___62 *);
	int (*ndo_set_mac_address)(struct net_device___62 *, void *);
	int (*ndo_validate_addr)(struct net_device___62 *);
	int (*ndo_do_ioctl)(struct net_device___62 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___62 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___62 *, int);
	int (*ndo_neigh_setup)(struct net_device___62 *, struct neigh_parms___52 *);
	void (*ndo_tx_timeout)(struct net_device___62 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___62 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___62 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___62 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___62 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___62 *);
	int (*ndo_netpoll_setup)(struct net_device___62 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___62 *);
	int (*ndo_busy_poll)(struct napi_struct___62 *);
	int (*ndo_set_vf_mac)(struct net_device___62 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___62 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___62 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___62 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___62 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___62 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___62 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___62 *, int, struct sk_buff___65 *);
	int (*ndo_setup_tc)(struct net_device___62 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___62 *);
	int (*ndo_fcoe_disable)(struct net_device___62 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___62 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___62 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___62 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___62 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___62 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___62 *, const struct sk_buff___65 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___62 *, struct net_device___62 *);
	int (*ndo_del_slave)(struct net_device___62 *, struct net_device___62 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___52 *);
	void (*ndo_neigh_destroy)(struct neighbour___52 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___65 *, struct netlink_callback___64 *, struct net_device___62 *, int);
	int (*ndo_bridge_setlink)(struct net_device___62 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___65 *, u32, u32, struct net_device___62 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___62 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___62 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___62 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___62 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___62 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___62 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___65 *, struct net_device___62 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___62 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___62 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___62 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___52 {
	struct net___76 *net;
	struct net_device___62 *dev;
	struct neigh_parms___52 *next;
	int (*neigh_setup)(struct neighbour___52 *);
	void (*neigh_cleanup)(struct neighbour___52 *);
	struct neigh_table___52 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___28;

struct ifacaddr6___28;

struct inet6_dev___28 {
	struct net_device___62 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___28 *mc_list;
	struct ifmcaddr6___28 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___28 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___52 *nd_parms;
	struct inet6_dev___28 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___53 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___62 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___76 *, struct net_device___62 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___62 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___62 *, struct list_head *);
	size_t (*get_size)(const struct net_device___62 *);
	int (*fill_info)(struct sk_buff___65 *, const struct net_device___62 *);
	size_t (*get_xstats_size)(const struct net_device___62 *);
	int (*fill_xstats)(struct sk_buff___65 *, const struct net_device___62 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___76 * (*get_link_net)(const struct net_device___62 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___62 *, struct net_device___62 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___62 *, const struct net_device___62 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___65 *, const struct net_device___62 *, const struct net_device___62 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___52 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___65 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___52;

struct neigh_hash_table___52;

struct neigh_table___52 {
	struct neigh_table___52 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___62 *, __u32 *);
	int (*constructor)(struct neighbour___52 *);
	int (*pconstructor)(struct pneigh_entry___52 *);
	void (*pdestructor)(struct pneigh_entry___52 *);
	void (*proxy_redo)(struct sk_buff___65 *);
	char *id;
	struct neigh_parms___52 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___63 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___52 *nht;
	struct pneigh_entry___52 **phash_buckets;
};

struct neigh_ops___52 {
	int family;
	void (*solicit)(struct neighbour___52 *, struct sk_buff___65 *);
	void (*error_report)(struct neighbour___52 *, struct sk_buff___65 *);
	int (*output)(struct neighbour___52 *, struct sk_buff___65 *);
	int (*connected_output)(struct neighbour___52 *, struct sk_buff___65 *);
};

struct pneigh_entry___52 {
	struct pneigh_entry___52 *next;
	struct net___76 *net;
	struct net_device___62 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___52 {
	struct neighbour___52 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___23 {
	struct dst_entry___52 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___34;

struct inet_hashinfo___8;

struct proto___51 {
	void (*close)(struct sock___52 *, long int);
	int (*connect)(struct sock___52 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___52 *, int);
	struct sock___52 * (*accept)(struct sock___52 *, int, int *);
	int (*ioctl)(struct sock___52 *, int, long unsigned int);
	int (*init)(struct sock___52 *);
	void (*destroy)(struct sock___52 *);
	void (*shutdown)(struct sock___52 *, int);
	int (*setsockopt)(struct sock___52 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___52 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___52 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___52 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___52 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___59 *, struct sock___52 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___59 *, struct sock___52 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___52 *, struct page___271 *, int, size_t, int);
	int (*bind)(struct sock___52 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___52 *, struct sk_buff___65 *);
	void (*release_cb)(struct sock___52 *);
	void (*mtu_reduced)(struct sock___52 *);
	void (*hash)(struct sock___52 *);
	void (*unhash)(struct sock___52 *);
	void (*rehash)(struct sock___52 *);
	int (*get_port)(struct sock___52 *, short unsigned int);
	void (*clear_sk)(struct sock___52 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___52 *);
	void (*enter_memory_pressure)(struct sock___52 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___255 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___37 *rsk_prot;
	struct timewait_sock_ops___34 *twsk_prot;
	union {
		struct inet_hashinfo___8 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___169 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___99 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___51 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___51 {
	void (*enter_memory_pressure)(struct sock___52 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___8 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___255 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___37 {
	int family;
	int obj_size;
	struct kmem_cache___255 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___52 *, struct request_sock___38 *);
	void (*send_ack)(struct sock___52 *, struct sk_buff___65 *, struct request_sock___38 *);
	void (*send_reset)(struct sock___52 *, struct sk_buff___65 *);
	void (*destructor)(struct request_sock___38 *);
	void (*syn_ack_timeout)(struct sock___52 *, struct request_sock___38 *);
};

struct timewait_sock_ops___34 {
	struct kmem_cache___255 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___52 *, struct sock___52 *, void *);
	void (*twsk_destructor)(struct sock___52 *);
};

struct listen_sock___3 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___38 *syn_table[0];
};

struct fastopen_queue___3 {
	struct request_sock___38 *rskq_rst_head;
	struct request_sock___38 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___3 {
	struct request_sock___38 *rskq_accept_head;
	struct request_sock___38 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___3 *listen_opt;
	struct fastopen_queue___3 *fastopenq;
};

struct inet_cork___9 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___52 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___9 {
	struct inet_cork___9 base;
	struct flowi fl;
};

struct ipv6_pinfo___8;

struct inet_sock___9 {
	struct sock___52 sk;
	struct ipv6_pinfo___8 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___9 cork;
};

struct ipv6_fl_socklist___7;

struct ipv6_pinfo___8 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___7 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___65 *pktoptions;
	struct sk_buff___65 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___3;

struct inet_connection_sock_af_ops___3 {
	int (*queue_xmit)(struct sk_buff___65 *, struct flowi *);
	void (*send_check)(struct sock___52 *, struct sk_buff___65 *);
	int (*rebuild_header)(struct sock___52 *);
	void (*sk_rx_dst_set)(struct sock___52 *, const struct sk_buff___65 *);
	int (*conn_request)(struct sock___52 *, struct sk_buff___65 *);
	struct sock___52 * (*syn_recv_sock)(struct sock___52 *, struct sk_buff___65 *, struct request_sock___38 *, struct dst_entry___52 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___52 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___52 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___52 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___52 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___52 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___52 *, const struct inet_bind_bucket___3 *, bool);
	void (*mtu_reduced)(struct sock___52 *);
};

struct inet_bind_bucket___3 {
	struct net___76 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_connection_sock___3 {
	struct inet_sock___9 icsk_inet;
	struct request_sock_queue___3 icsk_accept_queue;
	struct inet_bind_bucket___3 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___3 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___52 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct inet_timewait_death_row {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___8 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct inet_timewait_sock___2 {
	struct sock_common___51 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___3 *tw_tb;
	struct hlist_node tw_death_node;
};

struct ip6_flowlabel___7;

struct ipv6_fl_socklist___7 {
	struct ipv6_fl_socklist___7 *next;
	struct ip6_flowlabel___7 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___28 {
	struct in6_addr mca_addr;
	struct inet6_dev___28 *idev;
	struct ifmcaddr6___28 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___28 {
	struct in6_addr aca_addr;
	struct inet6_dev___28 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___28 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___7 {
	struct ip6_flowlabel___7 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___76 *fl_net;
};

struct page___272;

typedef struct page___272 *pgtable_t___272;

struct address_space___273;

struct kmem_cache___256;

struct page___272 {
	long unsigned int flags;
	struct address_space___273 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___272 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___272 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___256 *slab_cache;
		struct page___272 *first_page;
	};
	long: 64;
};

struct task_struct___274;

struct pv_cpu_ops___274 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___274 *);
	void (*end_context_switch)(struct task_struct___274 *);
};

struct mutex___275 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___274 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___267 {
	struct page___272 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___281;

struct nsproxy___153;

struct signal_struct___274;

struct css_set___168;

struct task_struct___274 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___274 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___281 *mm;
	struct mm_struct___281 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___274 *real_parent;
	struct task_struct___274 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___274 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___274 = 0,
		VTIME_USER___274 = 1,
		VTIME_SYS___274 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___153 *nsproxy;
	struct signal_struct___274 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___168 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___275 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___267 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___281 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___281 *, struct mm_struct___281 *);
	void (*dup_mmap)(struct mm_struct___281 *, struct mm_struct___281 *);
	void (*exit_mmap)(struct mm_struct___281 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___281 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___281 *);
	void (*pgd_free)(struct mm_struct___281 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___281 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___281 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___281 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___281 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___281 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___281 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___281 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___281 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___281 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___281 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___281 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___275 lock;
	void *vdso;
} mm_context_t___275;

struct xol_area___272;

struct uprobes_state___272 {
	struct xol_area___272 *xol_area;
};

struct vm_area_struct___281;

struct file___273;

struct core_state___274;

struct mm_struct___281 {
	struct vm_area_struct___281 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___281 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___281 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___275 context;
	long unsigned int flags;
	struct core_state___274 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___274 *owner;
	struct file___273 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___272 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___170;

struct exec_domain___75 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___170 *module;
	struct exec_domain___75 *next;
};

struct kset___55;

struct kobj_type___55;

struct kobject___55 {
	const char *name;
	struct list_head entry;
	struct kobject___55 *parent;
	struct kset___55 *kset;
	struct kobj_type___55 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___169 {
	struct kobject___55 kobj;
	struct module___170 *mod;
	struct kobject___55 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___169;

struct module___170 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___169 mkobj;
	struct module_attribute___169 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___55 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___274 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___122 {
	struct task_struct___274 *task;
	struct exec_domain___75 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___272 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___272 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___255;

struct memcg_cache_params___256;

struct kmem_cache___256 {
	struct kmem_cache_cpu___255 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___55 kobj;
	struct memcg_cache_params___256 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___273;

struct address_space_operations___273;

struct address_space___273 {
	struct inode___273 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___275 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___273 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___273;

struct path___273 {
	struct vfsmount *mnt;
	struct dentry___273 *dentry;
};

struct file_operations___273;

struct file___273 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___273 f_path;
	struct inode___273 *f_inode;
	const struct file_operations___273 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___273 *f_mapping;
	struct mutex___275 f_pos_lock;
};

struct vm_operations_struct___247;

struct vm_area_struct___281 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___281 *vm_next;
	struct vm_area_struct___281 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___281 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___247 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___273 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___243;

struct vm_operations_struct___247 {
	void (*open)(struct vm_area_struct___281 *);
	void (*close)(struct vm_area_struct___281 *);
	int (*fault)(struct vm_area_struct___281 *, struct vm_fault___243 *);
	int (*page_mkwrite)(struct vm_area_struct___281 *, struct vm_fault___243 *);
	int (*access)(struct vm_area_struct___281 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___281 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___281 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___281 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___281 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___274 {
	struct task_struct___274 *task;
	struct core_thread___274 *next;
};

struct core_state___274 {
	atomic_t nr_threads;
	struct core_thread___274 dumper;
	struct completion startup;
};

struct zone___274;

struct lruvec___274 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___274 *zone;
};

struct pglist_data___274;

struct zone___274 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___274 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___274 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___274 {
	struct zone___274 *zone;
	int zone_idx;
};

struct zonelist___274 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___274 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___274 {
	struct zone___274 node_zones[4];
	struct zonelist___274 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___274 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___197;

struct x86_io_apic_ops___197 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___197 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___197;

struct irq_data___197 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___197 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___271;

struct dev_pm_ops___271 {
	int (*prepare)(struct device___271 *);
	void (*complete)(struct device___271 *);
	int (*suspend)(struct device___271 *);
	int (*resume)(struct device___271 *);
	int (*freeze)(struct device___271 *);
	int (*thaw)(struct device___271 *);
	int (*poweroff)(struct device___271 *);
	int (*restore)(struct device___271 *);
	int (*suspend_late)(struct device___271 *);
	int (*resume_early)(struct device___271 *);
	int (*freeze_late)(struct device___271 *);
	int (*thaw_early)(struct device___271 *);
	int (*poweroff_late)(struct device___271 *);
	int (*restore_early)(struct device___271 *);
	int (*suspend_noirq)(struct device___271 *);
	int (*resume_noirq)(struct device___271 *);
	int (*freeze_noirq)(struct device___271 *);
	int (*thaw_noirq)(struct device___271 *);
	int (*poweroff_noirq)(struct device___271 *);
	int (*restore_noirq)(struct device___271 *);
	int (*runtime_suspend)(struct device___271 *);
	int (*runtime_resume)(struct device___271 *);
	int (*runtime_idle)(struct device___271 *);
};

struct dev_pm_qos___74;

struct dev_pm_info___74 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___74 *qos;
};

struct dma_map_ops___136;

struct dev_archdata___136 {
	struct dma_map_ops___136 *dma_ops;
	void *iommu;
};

struct device_type___271;

struct bus_type___271;

struct device_driver___271;

struct dev_pm_domain___271;

struct class___271;

struct attribute_group___233;

struct device_rh___271;

struct device___271 {
	struct device___271 *parent;
	struct device_private *p;
	struct kobject___55 kobj;
	const char *init_name;
	const struct device_type___271 *type;
	struct mutex___275 mutex;
	struct bus_type___271 *bus;
	struct device_driver___271 *driver;
	void *platform_data;
	struct dev_pm_info___74 power;
	struct dev_pm_domain___271 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___136 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___271 *class;
	const struct attribute_group___233 **groups;
	void (*release)(struct device___271 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___271 *device_rh;
};

struct dev_pm_qos_request___75;

struct dev_pm_qos___74 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___75 *latency_req;
	struct dev_pm_qos_request___75 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___75 *latency_tolerance_req;
};

struct dev_pm_info_rh___271 {
	void (*set_latency_tolerance)(struct device___271 *, s32);
};

struct dev_pm_domain___271 {
	struct dev_pm_ops___271 ops;
};

struct smp_ops___274 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___274 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___53;

struct kobj_ns_type_operations___52 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___53 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___52;

struct net___77;

struct sock_common___52 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___52 *skc_prot;
	struct net___77 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___66;

struct sk_buff_head___64 {
	struct sk_buff___66 *next;
	struct sk_buff___66 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___53;

struct socket_wq___52;

struct dst_entry___53;

struct socket___53;

struct cg_proto___52;

struct sock___53 {
	struct sock_common___52 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___64 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___66 *head;
		struct sk_buff___66 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___53 *sk_filter;
	struct socket_wq___52 *sk_wq;
	struct sk_buff_head___64 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___53 *sk_rx_dst;
	struct dst_entry___53 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___64 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___64 sk_error_queue;
	struct proto___52 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___53 *sk_socket;
	void *sk_user_data;
	struct page_frag___267 sk_frag;
	struct sk_buff___66 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___52 *sk_cgrp;
	void (*sk_state_change)(struct sock___53 *);
	void (*sk_data_ready)(struct sock___53 *, int);
	void (*sk_write_space)(struct sock___53 *);
	void (*sk_error_report)(struct sock___53 *);
	int (*sk_backlog_rcv)(struct sock___53 *, struct sk_buff___66 *);
	void (*sk_destruct)(struct sock___53 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___235;

struct attribute_group___233 {
	const char *name;
	umode_t (*is_visible)(struct kobject___55 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___235 **bin_attrs;
};

struct bin_attribute___235 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___273 *, struct kobject___55 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___273 *, struct kobject___55 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	int (*mmap)(struct file___273 *, struct kobject___55 *, struct bin_attribute___235 *, struct vm_area_struct___281 *);
};

struct sysfs_ops___55 {
	ssize_t (*show)(struct kobject___55 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___55 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___55 *, const struct attribute *);
};

struct kset_uevent_ops___55;

struct kset___55 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___55 kobj;
	const struct kset_uevent_ops___55 *uevent_ops;
};

struct kobj_type___55 {
	void (*release)(struct kobject___55 *);
	const struct sysfs_ops___55 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___52 * (*child_ns_type)(struct kobject___55 *);
	const void * (*namespace)(struct kobject___55 *);
};

struct kset_uevent_ops___55 {
	int (* const filter)(struct kset___55 *, struct kobject___55 *);
	const char * (* const name)(struct kset___55 *, struct kobject___55 *);
	int (* const uevent)(struct kset___55 *, struct kobject___55 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___255 {
	void **freelist;
	long unsigned int tid;
	struct page___272 *page;
	struct page___272 *partial;
};

struct memcg_cache_params___256 {
	bool is_root_cache;
	union {
		struct kmem_cache___256 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___256 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct ctl_table_header___78;

struct ctl_node___78 {
	struct rb_node node;
	struct ctl_table_header___78 *header;
};

struct ctl_table_root___78;

struct ctl_table_set___78;

struct ctl_dir___78;

struct ctl_table_header___78 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___78 *root;
	struct ctl_table_set___78 *set;
	struct ctl_dir___78 *parent;
	struct ctl_node___78 *node;
};

struct ctl_dir___78 {
	struct ctl_table_header___78 header;
	struct rb_root root;
};

struct ctl_table_set___78 {
	int (*is_seen)(struct ctl_table_set___78 *);
	struct ctl_dir___78 dir;
};

struct ctl_table_root___78 {
	struct ctl_table_set___78 default_set;
	struct ctl_table_set___78 * (*lookup)(struct ctl_table_root___78 *, struct nsproxy___153 *);
	int (*permissions)(struct ctl_table_header___78 *, struct ctl_table *);
};

struct nsproxy___153 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___77 *net_ns;
};

struct module_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___169 *, struct module_kobject___169 *, char *);
	ssize_t (*store)(struct module_attribute___169 *, struct module_kobject___169 *, const char *, size_t);
	void (*setup)(struct module___170 *, const char *);
	int (*test)(struct module___170 *);
	void (*free)(struct module___170 *);
};

struct seq_file___198;

struct irq_chip___197 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___197 *);
	void (*irq_shutdown)(struct irq_data___197 *);
	void (*irq_enable)(struct irq_data___197 *);
	void (*irq_disable)(struct irq_data___197 *);
	void (*irq_ack)(struct irq_data___197 *);
	void (*irq_mask)(struct irq_data___197 *);
	void (*irq_mask_ack)(struct irq_data___197 *);
	void (*irq_unmask)(struct irq_data___197 *);
	void (*irq_eoi)(struct irq_data___197 *);
	int (*irq_set_affinity)(struct irq_data___197 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___197 *);
	int (*irq_set_type)(struct irq_data___197 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___197 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___197 *);
	void (*irq_bus_sync_unlock)(struct irq_data___197 *);
	void (*irq_cpu_online)(struct irq_data___197 *);
	void (*irq_cpu_offline)(struct irq_data___197 *);
	void (*irq_suspend)(struct irq_data___197 *);
	void (*irq_resume)(struct irq_data___197 *);
	void (*irq_pm_shutdown)(struct irq_data___197 *);
	void (*irq_print_chip)(struct irq_data___197 *, struct seq_file___198 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___197 *, void *);
	long unsigned int flags;
};

struct seq_operations___198;

struct seq_file___198 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___275 lock;
	const struct seq_operations___198 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct fasync_struct___273;

struct socket_wq___52 {
	wait_queue_head_t wait;
	struct fasync_struct___273 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___273 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___273 *fa_next;
	struct file___273 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___52;

struct socket___53 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___52 *wq;
	struct file___273 *file;
	struct sock___53 *sk;
	const struct proto_ops___52 *ops;
};

struct poll_table_struct___159;

struct kiocb___60;

struct proto_ops___52 {
	int family;
	struct module___170 *owner;
	int (*release)(struct socket___53 *);
	int (*bind)(struct socket___53 *, struct sockaddr *, int);
	int (*connect)(struct socket___53 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___53 *, struct socket___53 *);
	int (*accept)(struct socket___53 *, struct socket___53 *, int);
	int (*getname)(struct socket___53 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___273 *, struct socket___53 *, struct poll_table_struct___159 *);
	int (*ioctl)(struct socket___53 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___53 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___53 *, int);
	int (*shutdown)(struct socket___53 *, int);
	int (*setsockopt)(struct socket___53 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___53 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___53 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___53 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___60 *, struct socket___53 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___60 *, struct socket___53 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___273 *, struct socket___53 *, struct vm_area_struct___281 *);
	ssize_t (*sendpage)(struct socket___53 *, struct page___272 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___53 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___53 *, int);
		struct {
			void (*set_peek_off)(struct sock___53 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___161)(struct file___273 *, wait_queue_head_t *, struct poll_table_struct___159 *);

struct poll_table_struct___159 {
	poll_queue_proc___161 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___60(struct kiocb___60 *, struct io_event *);

struct kiocb___60 {
	atomic_t ki_users;
	struct file___273 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___60 *ki_cancel;
	void (*ki_dtor)(struct kiocb___60 *);
	union {
		void *user;
		struct task_struct___274 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___75 {
	struct ctl_table_header___78 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___76 {
	struct mutex___275 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___75 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___78 *ctl;
};

struct netns_ipv4___75 {
	struct ctl_table_header___78 *forw_hdr;
	struct ctl_table_header___78 *frags_hdr;
	struct ctl_table_header___78 *ipv4_hdr;
	struct ctl_table_header___78 *route_hdr;
	struct ctl_table_header___78 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___53 *fibnl;
	struct sock___53 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___75 {
	struct ctl_table_header___78 *hdr;
	struct ctl_table_header___78 *route_hdr;
	struct ctl_table_header___78 *icmp_hdr;
	struct ctl_table_header___78 *frags_hdr;
	struct ctl_table_header___78 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___63;

struct neighbour___53;

struct dst_ops___77 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___77 *);
	struct dst_entry___53 * (*check)(struct dst_entry___53 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___53 *);
	unsigned int (*mtu)(const struct dst_entry___53 *);
	u32 * (*cow_metrics)(struct dst_entry___53 *, long unsigned int);
	void (*destroy)(struct dst_entry___53 *);
	void (*ifdown)(struct dst_entry___53 *, struct net_device___63 *, int);
	struct dst_entry___53 * (*negative_advice)(struct dst_entry___53 *);
	void (*link_failure)(struct sk_buff___66 *);
	void (*update_pmtu)(struct dst_entry___53 *, struct sock___53 *, struct sk_buff___66 *, u32);
	void (*redirect)(struct dst_entry___53 *, struct sock___53 *, struct sk_buff___66 *);
	int (*local_out)(struct sk_buff___66 *);
	struct neighbour___53 * (*neigh_lookup)(const struct dst_entry___53 *, struct sk_buff___66 *, const void *);
	struct kmem_cache___256 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___77 {
	struct netns_sysctl_ipv6___75 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___77 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___53 **icmp_sk;
	struct sock___53 *ndisc_sk;
	struct sock___53 *tcp_sk;
	struct sock___53 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___75 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___78 *sysctl_header;
	struct sock___53 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___52 {
	struct sock___53 *v4_ctl_sk;
	struct sock___53 *v6_ctl_sk;
};

struct netns_nf___75 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___78 *nf_log_dir_header;
};

struct nf_proto_net___75 {
	struct ctl_table_header___78 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___75 {
	struct nf_proto_net___75 pn;
	unsigned int timeout;
};

struct nf_tcp_net___75 {
	struct nf_proto_net___75 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___75 {
	struct nf_proto_net___75 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___75 {
	struct nf_proto_net___75 pn;
	unsigned int timeout;
};

struct nf_ip_net___75 {
	struct nf_generic_net___75 generic;
	struct nf_tcp_net___75 tcp;
	struct nf_udp_net___75 udp;
	struct nf_icmp_net___75 icmp;
	struct nf_icmp_net___75 icmpv6;
};

struct netns_ct___76 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___78 *sysctl_header;
	struct ctl_table_header___78 *acct_sysctl_header;
	struct ctl_table_header___78 *tstamp_sysctl_header;
	struct ctl_table_header___78 *event_sysctl_header;
	struct ctl_table_header___78 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___256 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___75 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___75 {
	struct netns_sysctl_ipv6___75 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___77 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___53 *nlsk;
	struct sock___53 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___78 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___77 xfrm4_dst_ops;
	struct dst_ops___77 xfrm6_dst_ops;
};

struct net___77 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___78 sysctls;
	struct sock___53 *rtnl;
	struct sock___53 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___63 *loopback_dev;
	struct netns_core___75 core;
	struct netns_mib mib;
	struct netns_packet___76 packet;
	struct netns_unix___75 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___75 ipv4;
	struct netns_ipv6___77 ipv6;
	struct netns_sctp___75 sctp;
	struct netns_dccp___52 dccp;
	struct netns_nf___75 nf;
	struct netns_xt xt;
	struct netns_ct___76 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___75 nf_frag;
	struct sock___53 *nfnl;
	struct sock___53 *nfnl_stash;
	struct sk_buff_head___64 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___77 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___53 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___53 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___275 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___275 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___136 {
	void * (*alloc)(struct device___271 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___271 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___271 *, struct vm_area_struct___281 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___271 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___271 *, struct page___272 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___271 *, dma_addr_t);
	int (*dma_supported)(struct device___271 *, u64);
	int (*set_dma_mask)(struct device___271 *, u64);
	int is_phys;
};

struct bus_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___271 *, char *);
	ssize_t (*store)(struct bus_type___271 *, const char *, size_t);
};

struct device_attribute___271;

struct driver_attribute___271;

struct bus_type___271 {
	const char *name;
	const char *dev_name;
	struct device___271 *dev_root;
	struct bus_attribute___271 *bus_attrs;
	struct device_attribute___271 *dev_attrs;
	struct driver_attribute___271 *drv_attrs;
	const struct attribute_group___233 **bus_groups;
	const struct attribute_group___233 **dev_groups;
	const struct attribute_group___233 **drv_groups;
	int (*match)(struct device___271 *, struct device_driver___271 *);
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	int (*probe)(struct device___271 *);
	int (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*online)(struct device___271 *);
	int (*offline)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct device___271 *, struct device_attribute___271 *, char *);
	ssize_t (*store)(struct device___271 *, struct device_attribute___271 *, const char *, size_t);
};

struct driver_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___271 *, char *);
	ssize_t (*store)(struct device_driver___271 *, const char *, size_t);
};

struct device_driver___271 {
	const char *name;
	struct bus_type___271 *bus;
	struct module___170 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___271 *);
	int (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	const struct attribute_group___233 **groups;
	const struct dev_pm_ops___271 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___271 {
	const char *name;
	const struct attribute_group___233 **groups;
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
};

struct class_attribute___271;

struct class___271 {
	const char *name;
	struct module___170 *owner;
	struct class_attribute___271 *class_attrs;
	struct device_attribute___271 *dev_attrs;
	const struct attribute_group___233 **dev_groups;
	struct bin_attribute___235 *dev_bin_attrs;
	struct kobject___55 *dev_kobj;
	int (*dev_uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *);
	void (*class_release)(struct class___271 *);
	void (*dev_release)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	const struct kobj_ns_type_operations___52 *ns_type;
	const void * (*namespace)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
	struct subsys_private *p;
};

struct class_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct class___271 *, struct class_attribute___271 *, char *);
	ssize_t (*store)(struct class___271 *, struct class_attribute___271 *, const char *, size_t);
	const void * (*namespace)(struct class___271 *, const struct class_attribute___271 *);
};

struct device_rh___271 {
	struct dev_pm_info_rh___271 power;
};

struct vm_fault___243 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___272 *page;
};

struct signal_struct___274 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___274 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___274 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___275 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___168;

struct css_set___168 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___168 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___63 {
	atomic_t use;
	unsigned int mask;
	struct net_device___63 *physindev;
	struct net_device___63 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___63(struct sk_buff___66 **);

struct net_device_ops___63;

struct ethtool_ops___63;

struct header_ops___63;

struct inet6_dev___29;

struct netdev_rx_queue___63;

struct netdev_queue___63;

struct rtnl_link_ops___54;

struct dcbnl_rtnl_ops___63;

struct net_device___63 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___63 *netdev_ops;
	const struct ethtool_ops___63 *ethtool_ops;
	const struct header_ops___63 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___55 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___29 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___63 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___63 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___63 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___63 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___63 = 0,
		NETREG_REGISTERED___63 = 1,
		NETREG_UNREGISTERING___63 = 2,
		NETREG_UNREGISTERED___63 = 3,
		NETREG_RELEASED___63 = 4,
		NETREG_DUMMY___63 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___63 = 0,
		RTNL_LINK_INITIALIZING___63 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___63 *);
	struct netpoll_info *npinfo;
	struct net___77 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___271 dev;
	const struct attribute_group___233 *sysfs_groups[4];
	const struct rtnl_link_ops___54 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___63 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___66 {
	struct sk_buff___66 *next;
	struct sk_buff___66 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___53 *sk;
	struct net_device___63 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___66 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___63 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct file_lock___273;

struct file_operations___273 {
	struct module___170 *owner;
	loff_t (*llseek)(struct file___273 *, loff_t, int);
	ssize_t (*read)(struct file___273 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___273 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___60 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___60 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___273 *, void *, filldir_t);
	unsigned int (*poll)(struct file___273 *, struct poll_table_struct___159 *);
	long int (*unlocked_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___273 *, struct vm_area_struct___281 *);
	int (*open)(struct inode___273 *, struct file___273 *);
	int (*flush)(struct file___273 *, fl_owner_t);
	int (*release)(struct inode___273 *, struct file___273 *);
	int (*fsync)(struct file___273 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___60 *, int);
	int (*fasync)(int, struct file___273 *, int);
	int (*lock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*sendpage)(struct file___273 *, struct page___272 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___273 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___273 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___273 *, long int, struct file_lock___273 **, void **);
		struct {
			int (*setlease)(struct file___273 *, long int, struct file_lock___273 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___273 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___198 *, struct file___273 *);
};

struct dev_pm_qos_request___75 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___271 *dev;
};

struct dentry_operations___273;

struct super_block___273;

struct dentry___273 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___273 *d_parent;
	struct qstr d_name;
	struct inode___273 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___273 *d_op;
	struct super_block___273 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___273;

struct dquot___273;

struct block_device___273;

struct inode___273 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___273 *i_op;
	struct super_block___273 *i_sb;
	struct address_space___273 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___275 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___273 *i_fop;
	struct file_lock___273 *i_flock;
	struct address_space___273 i_data;
	struct dquot___273 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___273 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___273 {
	int (*d_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_hash)(const struct dentry___273 *, struct qstr *);
	int (*d_compare)(const struct dentry___273 *, const struct dentry___273 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___273 *);
	void (*d_release)(struct dentry___273 *);
	void (*d_prune)(struct dentry___273 *);
	void (*d_iput)(struct dentry___273 *, struct inode___273 *);
	char * (*d_dname)(struct dentry___273 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___273 *);
	int (*d_manage)(struct dentry___273 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___273;

struct mem_dqinfo___273 {
	struct quota_format_type___273 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___273;

struct quota_info___273 {
	unsigned int flags;
	struct mutex___275 dqio_mutex;
	struct mutex___275 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___273 *files[2];
	struct mem_dqinfo___273 info[2];
	const struct quota_format_ops___273 *ops[2];
};

struct file_system_type___273;

struct super_operations___273;

struct dquot_operations___273;

struct quotactl_ops___273;

struct xattr_handler___169;

struct super_block___273 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___273 *s_type;
	const struct super_operations___273 *s_op;
	const struct dquot_operations___273 *dq_op;
	const struct quotactl_ops___273 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___273 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___169 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___273 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___273 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___275 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___273 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___273 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___273 *bd_inode;
	struct super_block___273 *bd_super;
	struct mutex___275 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___273 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___275 bd_fsfreeze_mutex;
};

struct cgroup___168;

struct cgroup_subsys_state___168 {
	struct cgroup___168 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___273 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___273 *ia_file;
};

struct dquot___273 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___275 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___273 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___273 {
	int qf_fmt_id;
	const struct quota_format_ops___273 *qf_ops;
	struct module___170 *qf_owner;
	struct quota_format_type___273 *qf_next;
};

struct quota_format_ops___273 {
	int (*check_quota_file)(struct super_block___273 *, int);
	int (*read_file_info)(struct super_block___273 *, int);
	int (*write_file_info)(struct super_block___273 *, int);
	int (*free_file_info)(struct super_block___273 *, int);
	int (*read_dqblk)(struct dquot___273 *);
	int (*commit_dqblk)(struct dquot___273 *);
	int (*release_dqblk)(struct dquot___273 *);
};

struct dquot_operations___273 {
	int (*write_dquot)(struct dquot___273 *);
	struct dquot___273 * (*alloc_dquot)(struct super_block___273 *, int);
	void (*destroy_dquot)(struct dquot___273 *);
	int (*acquire_dquot)(struct dquot___273 *);
	int (*release_dquot)(struct dquot___273 *);
	int (*mark_dirty)(struct dquot___273 *);
	int (*write_info)(struct super_block___273 *, int);
	qsize_t * (*get_reserved_space)(struct inode___273 *);
};

struct quotactl_ops___273 {
	int (*quota_on)(struct super_block___273 *, int, int, struct path___273 *);
	int (*quota_on_meta)(struct super_block___273 *, int, int);
	int (*quota_off)(struct super_block___273 *, int);
	int (*quota_sync)(struct super_block___273 *, int);
	int (*get_info)(struct super_block___273 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___273 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___273 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___273 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___273 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___273 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___273 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___273 *, unsigned int);
};

struct address_space_operations___273 {
	int (*writepage)(struct page___272 *, struct writeback_control *);
	int (*readpage)(struct file___273 *, struct page___272 *);
	int (*writepages)(struct address_space___273 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___272 *);
	int (*readpages)(struct file___273 *, struct address_space___273 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___273 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___272 **, void **);
	int (*write_end)(struct file___273 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___272 *, void *);
	sector_t (*bmap)(struct address_space___273 *, sector_t);
	void (*invalidatepage)(struct page___272 *, long unsigned int);
	int (*releasepage)(struct page___272 *, gfp_t);
	void (*freepage)(struct page___272 *);
	ssize_t (*direct_IO)(int, struct kiocb___60 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___273 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___273 *, struct page___272 *, struct page___272 *, enum migrate_mode);
	int (*launder_page)(struct page___272 *);
	int (*is_partially_uptodate)(struct page___272 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___272 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___273 *, struct page___272 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___273 *, sector_t *);
	void (*swap_deactivate)(struct file___273 *);
	void (*invalidatepage_range)(struct page___272 *, unsigned int, unsigned int);
};

struct inode_operations___273 {
	struct dentry___273 * (*lookup)(struct inode___273 *, struct dentry___273 *, unsigned int);
	void * (*follow_link)(struct dentry___273 *, struct nameidata *);
	int (*permission)(struct inode___273 *, int);
	struct posix_acl * (*get_acl)(struct inode___273 *, int);
	int (*readlink)(struct dentry___273 *, char *, int);
	void (*put_link)(struct dentry___273 *, struct nameidata *, void *);
	int (*create)(struct inode___273 *, struct dentry___273 *, umode_t, bool);
	int (*link)(struct dentry___273 *, struct inode___273 *, struct dentry___273 *);
	int (*unlink)(struct inode___273 *, struct dentry___273 *);
	int (*symlink)(struct inode___273 *, struct dentry___273 *, const char *);
	int (*mkdir)(struct inode___273 *, struct dentry___273 *, umode_t);
	int (*rmdir)(struct inode___273 *, struct dentry___273 *);
	int (*mknod)(struct inode___273 *, struct dentry___273 *, umode_t, dev_t);
	int (*rename)(struct inode___273 *, struct dentry___273 *, struct inode___273 *, struct dentry___273 *);
	int (*setattr)(struct dentry___273 *, struct iattr___273 *);
	int (*getattr)(struct vfsmount *, struct dentry___273 *, struct kstat *);
	int (*setxattr)(struct dentry___273 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___273 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___273 *, char *, size_t);
	int (*removexattr)(struct dentry___273 *, const char *);
	int (*fiemap)(struct inode___273 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___273 *, struct timespec *, int);
	int (*atomic_open)(struct inode___273 *, struct dentry___273 *, struct file___273 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___273;

struct lock_manager_operations___273;

struct file_lock___273 {
	struct file_lock___273 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___273 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___273 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___273 *fl_ops;
	const struct lock_manager_operations___273 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___273 {
	void (*fl_copy_lock)(struct file_lock___273 *, struct file_lock___273 *);
	void (*fl_release_private)(struct file_lock___273 *);
};

struct lock_manager_operations___273 {
	int (*lm_compare_owner)(struct file_lock___273 *, struct file_lock___273 *);
	long unsigned int (*lm_owner_key)(struct file_lock___273 *);
	void (*lm_notify)(struct file_lock___273 *);
	int (*lm_grant)(struct file_lock___273 *, struct file_lock___273 *, int);
	void (*lm_break)(struct file_lock___273 *);
	int (*lm_change)(struct file_lock___273 **, int);
};

struct file_system_type___273 {
	const char *name;
	int fs_flags;
	struct dentry___273 * (*mount)(struct file_system_type___273 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___273 *);
	struct module___170 *owner;
	struct file_system_type___273 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___273 {
	struct inode___273 * (*alloc_inode)(struct super_block___273 *);
	void (*destroy_inode)(struct inode___273 *);
	void (*dirty_inode)(struct inode___273 *, int);
	int (*write_inode)(struct inode___273 *, struct writeback_control *);
	int (*drop_inode)(struct inode___273 *);
	void (*evict_inode)(struct inode___273 *);
	void (*put_super)(struct super_block___273 *);
	int (*sync_fs)(struct super_block___273 *, int);
	int (*freeze_fs)(struct super_block___273 *);
	int (*unfreeze_fs)(struct super_block___273 *);
	int (*statfs)(struct dentry___273 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___273 *, int *, char *);
	void (*umount_begin)(struct super_block___273 *);
	int (*show_options)(struct seq_file___198 *, struct dentry___273 *);
	int (*show_devname)(struct seq_file___198 *, struct dentry___273 *);
	int (*show_path)(struct seq_file___198 *, struct dentry___273 *);
	int (*show_stats)(struct seq_file___198 *, struct dentry___273 *);
	ssize_t (*quota_read)(struct super_block___273 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___273 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___273 *);
	int (*bdev_try_to_free_page)(struct super_block___273 *, struct page___272 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___273 *);
	void (*free_cached_objects)(struct super_block___273 *, int);
};

struct xattr_handler___169 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___273 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___273 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___273 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___63 {
	int (*get_settings)(struct net_device___63 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___63 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___63 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___63 *);
	void (*get_regs)(struct net_device___63 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___63 *);
	void (*set_msglevel)(struct net_device___63 *, u32);
	int (*nway_reset)(struct net_device___63 *);
	u32 (*get_link)(struct net_device___63 *);
	int (*get_eeprom_len)(struct net_device___63 *);
	int (*get_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___63 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___63 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___63 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___63 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___63 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___63 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___63 *);
	void (*complete)(struct net_device___63 *);
	u32 (*get_priv_flags)(struct net_device___63 *);
	int (*set_priv_flags)(struct net_device___63 *, u32);
	int (*get_sset_count)(struct net_device___63 *, int);
	int (*get_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___63 *, struct ethtool_flash *);
	int (*reset)(struct net_device___63 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___63 *);
	int (*get_rxfh_indir)(struct net_device___63 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___63 *, const u32 *);
	void (*get_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___63 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___63 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___63 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___63 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___63 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___63 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___63 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___63 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___24;

struct dst_entry___53 {
	struct callback_head callback_head;
	struct dst_entry___53 *child;
	struct net_device___63 *dev;
	struct dst_ops___77 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___53 *path;
	struct dst_entry___53 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___66 *);
	union {
		int (*output)(struct sock___53 *, struct sk_buff___66 *);
		struct {
			int (*output)(struct sk_buff___66 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___53 *next;
		struct rtable___24 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___53;

struct neigh_parms___53;

struct neigh_ops___53;

struct neighbour___53 {
	struct neighbour___53 *next;
	struct neigh_table___53 *tbl;
	struct neigh_parms___53 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___64 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___53 *, struct sk_buff___66 *);
	const struct neigh_ops___53 *ops;
	struct callback_head rcu;
	struct net_device___63 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___77 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___66 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___66 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___77 *, struct dst_entry___53 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___66 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___66 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___198 {
	void * (*start)(struct seq_file___198 *, loff_t *);
	void (*stop)(struct seq_file___198 *, void *);
	void * (*next)(struct seq_file___198 *, void *, loff_t *);
	int (*show)(struct seq_file___198 *, void *);
};

struct dcbnl_rtnl_ops___63 {
	int (*ieee_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___63 *);
	u8 (*setstate)(struct net_device___63 *, u8);
	void (*getpermhwaddr)(struct net_device___63 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___63 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___63 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___63 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___63 *, int, u8 *);
	void (*setpfccfg)(struct net_device___63 *, int, u8);
	void (*getpfccfg)(struct net_device___63 *, int, u8 *);
	u8 (*setall)(struct net_device___63 *);
	u8 (*getcap)(struct net_device___63 *, int, u8 *);
	int (*getnumtcs)(struct net_device___63 *, int, u8 *);
	int (*setnumtcs)(struct net_device___63 *, int, u8);
	u8 (*getpfcstate)(struct net_device___63 *);
	void (*setpfcstate)(struct net_device___63 *, u8);
	void (*getbcncfg)(struct net_device___63 *, int, u32 *);
	void (*setbcncfg)(struct net_device___63 *, int, u32);
	void (*getbcnrp)(struct net_device___63 *, int, u8 *);
	void (*setbcnrp)(struct net_device___63 *, int, u8);
	u8 (*setapp)(struct net_device___63 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___63 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___63 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___63 *, int, u8);
	u8 (*getdcbx)(struct net_device___63 *);
	u8 (*setdcbx)(struct net_device___63 *, u8);
	int (*peer_getappinfo)(struct net_device___63 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___63 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___63 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___63 *, struct cee_pfc *);
};

struct cgroupfs_root___168;

struct cgroup___168 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___168 *parent;
	struct dentry___273 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___168 *subsys[11];
	struct cgroupfs_root___168 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___275 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___168 {
	struct super_block___273 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___168 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___104 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___273 *, struct file___273 *);
	ssize_t (*read)(struct cgroup___168 *, struct cftype___104 *, struct file___273 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___168 *, struct cftype___104 *);
	s64 (*read_s64)(struct cgroup___168 *, struct cftype___104 *);
	int (*read_map)(struct cgroup___168 *, struct cftype___104 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___168 *, struct cftype___104 *, struct seq_file___198 *);
	ssize_t (*write)(struct cgroup___168 *, struct cftype___104 *, struct file___273 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___168 *, struct cftype___104 *, u64);
	int (*write_s64)(struct cgroup___168 *, struct cftype___104 *, s64);
	int (*write_string)(struct cgroup___168 *, struct cftype___104 *, const char *);
	int (*trigger)(struct cgroup___168 *, unsigned int);
	int (*release)(struct inode___273 *, struct file___273 *);
	int (*register_event)(struct cgroup___168 *, struct cftype___104 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___168 *, struct cftype___104 *, struct eventfd_ctx *);
};

struct cftype_set___100 {
	struct list_head node;
	struct cftype___104 *cfts;
};

struct task_and_cgroup___100 {
	struct task_struct___274 *task;
	struct cgroup___168 *cgrp;
	struct css_set___168 *cg;
};

struct cgroup_taskset___100 {
	struct task_and_cgroup___100 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___168 *cur_cgrp;
};

struct cgroup_subsys___100 {
	struct cgroup_subsys_state___168 * (*css_alloc)(struct cgroup___168 *);
	int (*css_online)(struct cgroup___168 *);
	void (*css_offline)(struct cgroup___168 *);
	void (*css_free)(struct cgroup___168 *);
	int (*can_attach)(struct cgroup___168 *, struct cgroup_taskset___100 *);
	void (*cancel_attach)(struct cgroup___168 *, struct cgroup_taskset___100 *);
	void (*attach)(struct cgroup___168 *, struct cgroup_taskset___100 *);
	void (*fork)(struct task_struct___274 *);
	void (*exit)(struct cgroup___168 *, struct cgroup___168 *, struct task_struct___274 *);
	void (*bind)(struct cgroup___168 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___168 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___104 *base_cftypes;
	struct cftype_set___100 base_cftset;
	struct module___170 *module;
};

struct request_sock_ops___38;

struct request_sock___39 {
	struct sock_common___52 __req_common;
	struct request_sock___39 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___38 *rsk_ops;
	struct sock___53 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___65 {
	struct sk_buff___66 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___66 *, struct netlink_callback___65 *);
	int (*done)(struct netlink_callback___65 *);
	void *data;
	struct module___170 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___63 {
	int (*create)(struct sk_buff___66 *, struct net_device___63 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___66 *, unsigned char *);
	int (*rebuild)(struct sk_buff___66 *);
	int (*cache)(const struct neighbour___53 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___63 *, const unsigned char *);
};

struct napi_struct___63 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___63 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___63 *dev;
	struct sk_buff___66 *gro_list;
	struct sk_buff___66 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___63 {
	struct net_device___63 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___55 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___63 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___55 kobj;
	struct net_device___63 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___63 {
	int (*ndo_init)(struct net_device___63 *);
	void (*ndo_uninit)(struct net_device___63 *);
	int (*ndo_open)(struct net_device___63 *);
	int (*ndo_stop)(struct net_device___63 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___66 *, struct net_device___63 *);
	u16 (*ndo_select_queue)(struct net_device___63 *, struct sk_buff___66 *);
	void (*ndo_change_rx_flags)(struct net_device___63 *, int);
	void (*ndo_set_rx_mode)(struct net_device___63 *);
	int (*ndo_set_mac_address)(struct net_device___63 *, void *);
	int (*ndo_validate_addr)(struct net_device___63 *);
	int (*ndo_do_ioctl)(struct net_device___63 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___63 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___63 *, int);
	int (*ndo_neigh_setup)(struct net_device___63 *, struct neigh_parms___53 *);
	void (*ndo_tx_timeout)(struct net_device___63 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___63 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___63 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___63 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___63 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___63 *);
	int (*ndo_netpoll_setup)(struct net_device___63 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___63 *);
	int (*ndo_busy_poll)(struct napi_struct___63 *);
	int (*ndo_set_vf_mac)(struct net_device___63 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___63 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___63 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___63 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___63 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___63 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___63 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___63 *, int, struct sk_buff___66 *);
	int (*ndo_setup_tc)(struct net_device___63 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___63 *);
	int (*ndo_fcoe_disable)(struct net_device___63 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___63 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___63 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___63 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___63 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___63 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___63 *, const struct sk_buff___66 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___63 *, struct net_device___63 *);
	int (*ndo_del_slave)(struct net_device___63 *, struct net_device___63 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___53 *);
	void (*ndo_neigh_destroy)(struct neighbour___53 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___66 *, struct netlink_callback___65 *, struct net_device___63 *, int);
	int (*ndo_bridge_setlink)(struct net_device___63 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___66 *, u32, u32, struct net_device___63 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___63 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___63 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___63 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___63 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___63 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___63 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___66 *, struct net_device___63 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___63 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___63 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___63 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___53 {
	struct net___77 *net;
	struct net_device___63 *dev;
	struct neigh_parms___53 *next;
	int (*neigh_setup)(struct neighbour___53 *);
	void (*neigh_cleanup)(struct neighbour___53 *);
	struct neigh_table___53 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___29;

struct ifacaddr6___29;

struct inet6_dev___29 {
	struct net_device___63 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___29 *mc_list;
	struct ifmcaddr6___29 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___29 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___53 *nd_parms;
	struct inet6_dev___29 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___54 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___63 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___77 *, struct net_device___63 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___63 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___63 *, struct list_head *);
	size_t (*get_size)(const struct net_device___63 *);
	int (*fill_info)(struct sk_buff___66 *, const struct net_device___63 *);
	size_t (*get_xstats_size)(const struct net_device___63 *);
	int (*fill_xstats)(struct sk_buff___66 *, const struct net_device___63 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___77 * (*get_link_net)(const struct net_device___63 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___63 *, struct net_device___63 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___63 *, const struct net_device___63 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___66 *, const struct net_device___63 *, const struct net_device___63 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___53 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___66 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___53;

struct neigh_hash_table___53;

struct neigh_table___53 {
	struct neigh_table___53 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___63 *, __u32 *);
	int (*constructor)(struct neighbour___53 *);
	int (*pconstructor)(struct pneigh_entry___53 *);
	void (*pdestructor)(struct pneigh_entry___53 *);
	void (*proxy_redo)(struct sk_buff___66 *);
	char *id;
	struct neigh_parms___53 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___64 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___53 *nht;
	struct pneigh_entry___53 **phash_buckets;
};

struct neigh_ops___53 {
	int family;
	void (*solicit)(struct neighbour___53 *, struct sk_buff___66 *);
	void (*error_report)(struct neighbour___53 *, struct sk_buff___66 *);
	int (*output)(struct neighbour___53 *, struct sk_buff___66 *);
	int (*connected_output)(struct neighbour___53 *, struct sk_buff___66 *);
};

struct pneigh_entry___53 {
	struct pneigh_entry___53 *next;
	struct net___77 *net;
	struct net_device___63 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___53 {
	struct neighbour___53 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___24 {
	struct dst_entry___53 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___35;

struct inet_hashinfo___9;

struct proto___52 {
	void (*close)(struct sock___53 *, long int);
	int (*connect)(struct sock___53 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___53 *, int);
	struct sock___53 * (*accept)(struct sock___53 *, int, int *);
	int (*ioctl)(struct sock___53 *, int, long unsigned int);
	int (*init)(struct sock___53 *);
	void (*destroy)(struct sock___53 *);
	void (*shutdown)(struct sock___53 *, int);
	int (*setsockopt)(struct sock___53 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___53 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___53 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___53 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___53 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___60 *, struct sock___53 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___60 *, struct sock___53 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___53 *, struct page___272 *, int, size_t, int);
	int (*bind)(struct sock___53 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___53 *, struct sk_buff___66 *);
	void (*release_cb)(struct sock___53 *);
	void (*mtu_reduced)(struct sock___53 *);
	void (*hash)(struct sock___53 *);
	void (*unhash)(struct sock___53 *);
	void (*rehash)(struct sock___53 *);
	int (*get_port)(struct sock___53 *, short unsigned int);
	void (*clear_sk)(struct sock___53 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___53 *);
	void (*enter_memory_pressure)(struct sock___53 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___256 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___38 *rsk_prot;
	struct timewait_sock_ops___35 *twsk_prot;
	union {
		struct inet_hashinfo___9 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___170 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___100 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___52 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___52 {
	void (*enter_memory_pressure)(struct sock___53 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___9 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___256 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___38 {
	int family;
	int obj_size;
	struct kmem_cache___256 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___53 *, struct request_sock___39 *);
	void (*send_ack)(struct sock___53 *, struct sk_buff___66 *, struct request_sock___39 *);
	void (*send_reset)(struct sock___53 *, struct sk_buff___66 *);
	void (*destructor)(struct request_sock___39 *);
	void (*syn_ack_timeout)(struct sock___53 *, struct request_sock___39 *);
};

struct timewait_sock_ops___35 {
	struct kmem_cache___256 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___53 *, struct sock___53 *, void *);
	void (*twsk_destructor)(struct sock___53 *);
};

struct listen_sock___4 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___39 *syn_table[0];
};

struct fastopen_queue___4 {
	struct request_sock___39 *rskq_rst_head;
	struct request_sock___39 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___4 {
	struct request_sock___39 *rskq_accept_head;
	struct request_sock___39 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___4 *listen_opt;
	struct fastopen_queue___4 *fastopenq;
};

struct inet_cork___10 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___53 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___10 {
	struct inet_cork___10 base;
	struct flowi fl;
};

struct ipv6_pinfo___9;

struct inet_sock___10 {
	struct sock___53 sk;
	struct ipv6_pinfo___9 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___10 cork;
};

struct ipv6_fl_socklist___8;

struct ipv6_pinfo___9 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___8 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___66 *pktoptions;
	struct sk_buff___66 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___4;

struct inet_connection_sock_af_ops___4 {
	int (*queue_xmit)(struct sk_buff___66 *, struct flowi *);
	void (*send_check)(struct sock___53 *, struct sk_buff___66 *);
	int (*rebuild_header)(struct sock___53 *);
	void (*sk_rx_dst_set)(struct sock___53 *, const struct sk_buff___66 *);
	int (*conn_request)(struct sock___53 *, struct sk_buff___66 *);
	struct sock___53 * (*syn_recv_sock)(struct sock___53 *, struct sk_buff___66 *, struct request_sock___39 *, struct dst_entry___53 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___53 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___53 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___53 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___53 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___53 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___53 *, const struct inet_bind_bucket___4 *, bool);
	void (*mtu_reduced)(struct sock___53 *);
};

struct inet_bind_bucket___4 {
	struct net___77 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_connection_sock___4 {
	struct inet_sock___10 icsk_inet;
	struct request_sock_queue___4 icsk_accept_queue;
	struct inet_bind_bucket___4 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___4 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___53 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct inet_timewait_death_row___2 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___9 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct inet_timewait_sock___3 {
	struct sock_common___52 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___4 *tw_tb;
	struct hlist_node tw_death_node;
};

struct ip6_flowlabel___8;

struct ipv6_fl_socklist___8 {
	struct ipv6_fl_socklist___8 *next;
	struct ip6_flowlabel___8 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___29 {
	struct in6_addr mca_addr;
	struct inet6_dev___29 *idev;
	struct ifmcaddr6___29 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___29 {
	struct in6_addr aca_addr;
	struct inet6_dev___29 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___29 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___8 {
	struct ip6_flowlabel___8 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___77 *fl_net;
};

struct page___273;

typedef struct page___273 *pgtable_t___273;

struct address_space___274;

struct kmem_cache___257;

struct page___273 {
	long unsigned int flags;
	struct address_space___274 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___273 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___273 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___257 *slab_cache;
		struct page___273 *first_page;
	};
	long: 64;
};

struct task_struct___275;

struct pv_cpu_ops___275 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___275 *);
	void (*end_context_switch)(struct task_struct___275 *);
};

struct mutex___276 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___275 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___268 {
	struct page___273 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___282;

struct nsproxy___154;

struct signal_struct___275;

struct css_set___169;

struct task_struct___275 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___275 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___282 *mm;
	struct mm_struct___282 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___275 *real_parent;
	struct task_struct___275 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___275 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___275 = 0,
		VTIME_USER___275 = 1,
		VTIME_SYS___275 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___154 *nsproxy;
	struct signal_struct___275 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___169 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___276 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___268 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___282 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___282 *, struct mm_struct___282 *);
	void (*dup_mmap)(struct mm_struct___282 *, struct mm_struct___282 *);
	void (*exit_mmap)(struct mm_struct___282 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___282 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___282 *);
	void (*pgd_free)(struct mm_struct___282 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___282 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___282 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___282 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___282 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___282 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___282 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___282 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___282 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___282 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___282 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___282 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___276 lock;
	void *vdso;
} mm_context_t___276;

struct xol_area___273;

struct uprobes_state___273 {
	struct xol_area___273 *xol_area;
};

struct vm_area_struct___282;

struct file___274;

struct core_state___275;

struct mm_struct___282 {
	struct vm_area_struct___282 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___282 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___282 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___276 context;
	long unsigned int flags;
	struct core_state___275 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___275 *owner;
	struct file___274 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___273 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___171;

struct exec_domain___76 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___171 *module;
	struct exec_domain___76 *next;
};

struct kset___56;

struct kobj_type___56;

struct kobject___56 {
	const char *name;
	struct list_head entry;
	struct kobject___56 *parent;
	struct kset___56 *kset;
	struct kobj_type___56 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___170 {
	struct kobject___56 kobj;
	struct module___171 *mod;
	struct kobject___56 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___170;

struct module___171 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___170 mkobj;
	struct module_attribute___170 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___56 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___275 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___123 {
	struct task_struct___275 *task;
	struct exec_domain___76 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___275;

struct lruvec___275 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___275 *zone;
};

struct pglist_data___275;

struct zone___275 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___275 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___275 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___275 {
	struct zone___275 *zone;
	int zone_idx;
};

struct zonelist___275 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___275 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___275 {
	struct zone___275 node_zones[4];
	struct zonelist___275 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___275 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___198;

struct x86_io_apic_ops___198 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___198 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___198;

struct irq_data___198 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___198 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___272;

struct dev_pm_ops___272 {
	int (*prepare)(struct device___272 *);
	void (*complete)(struct device___272 *);
	int (*suspend)(struct device___272 *);
	int (*resume)(struct device___272 *);
	int (*freeze)(struct device___272 *);
	int (*thaw)(struct device___272 *);
	int (*poweroff)(struct device___272 *);
	int (*restore)(struct device___272 *);
	int (*suspend_late)(struct device___272 *);
	int (*resume_early)(struct device___272 *);
	int (*freeze_late)(struct device___272 *);
	int (*thaw_early)(struct device___272 *);
	int (*poweroff_late)(struct device___272 *);
	int (*restore_early)(struct device___272 *);
	int (*suspend_noirq)(struct device___272 *);
	int (*resume_noirq)(struct device___272 *);
	int (*freeze_noirq)(struct device___272 *);
	int (*thaw_noirq)(struct device___272 *);
	int (*poweroff_noirq)(struct device___272 *);
	int (*restore_noirq)(struct device___272 *);
	int (*runtime_suspend)(struct device___272 *);
	int (*runtime_resume)(struct device___272 *);
	int (*runtime_idle)(struct device___272 *);
};

struct dev_pm_qos___75;

struct dev_pm_info___75 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___75 *qos;
};

struct dma_map_ops___137;

struct dev_archdata___137 {
	struct dma_map_ops___137 *dma_ops;
	void *iommu;
};

struct device_type___272;

struct bus_type___272;

struct device_driver___272;

struct dev_pm_domain___272;

struct class___272;

struct attribute_group___234;

struct device_rh___272;

struct device___272 {
	struct device___272 *parent;
	struct device_private *p;
	struct kobject___56 kobj;
	const char *init_name;
	const struct device_type___272 *type;
	struct mutex___276 mutex;
	struct bus_type___272 *bus;
	struct device_driver___272 *driver;
	void *platform_data;
	struct dev_pm_info___75 power;
	struct dev_pm_domain___272 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___137 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___35 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___272 *class;
	const struct attribute_group___234 **groups;
	void (*release)(struct device___272 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___272 *device_rh;
};

struct dev_pm_qos_request___76;

struct dev_pm_qos___75 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___76 *latency_req;
	struct dev_pm_qos_request___76 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___76 *latency_tolerance_req;
};

struct dev_pm_info_rh___272 {
	void (*set_latency_tolerance)(struct device___272 *, s32);
};

struct dev_pm_domain___272 {
	struct dev_pm_ops___272 ops;
};

struct smp_ops___275 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___275 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___79;

struct ctl_node___79 {
	struct rb_node node;
	struct ctl_table_header___79 *header;
};

struct ctl_table_root___79;

struct ctl_table_set___79;

struct ctl_dir___79;

struct ctl_table_header___79 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___79 *root;
	struct ctl_table_set___79 *set;
	struct ctl_dir___79 *parent;
	struct ctl_node___79 *node;
};

struct ctl_dir___79 {
	struct ctl_table_header___79 header;
	struct rb_root root;
};

struct ctl_table_set___79 {
	int (*is_seen)(struct ctl_table_set___79 *);
	struct ctl_dir___79 dir;
};

struct ctl_table_root___79 {
	struct ctl_table_set___79 default_set;
	struct ctl_table_set___79 * (*lookup)(struct ctl_table_root___79 *, struct nsproxy___154 *);
	int (*permissions)(struct ctl_table_header___79 *, struct ctl_table *);
};

struct net___78;

struct nsproxy___154 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___78 *net_ns;
};

struct sock___54;

struct kobj_ns_type_operations___53 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___54 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___53;

struct sock_common___53 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___53 *skc_prot;
	struct net___78 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___67;

struct sk_buff_head___65 {
	struct sk_buff___67 *next;
	struct sk_buff___67 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___54;

struct socket_wq___53;

struct xfrm_policy___10;

struct dst_entry___54;

struct socket___54;

struct cg_proto___53;

struct sock___54 {
	struct sock_common___53 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___65 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___67 *head;
		struct sk_buff___67 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___54 *sk_filter;
	struct socket_wq___53 *sk_wq;
	struct sk_buff_head___65 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___10 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___54 *sk_rx_dst;
	struct dst_entry___54 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___65 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___65 sk_error_queue;
	struct proto___53 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___54 *sk_socket;
	void *sk_user_data;
	struct page_frag___268 sk_frag;
	struct sk_buff___67 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___53 *sk_cgrp;
	void (*sk_state_change)(struct sock___54 *);
	void (*sk_data_ready)(struct sock___54 *, int);
	void (*sk_write_space)(struct sock___54 *);
	void (*sk_error_report)(struct sock___54 *);
	int (*sk_backlog_rcv)(struct sock___54 *, struct sk_buff___67 *);
	void (*sk_destruct)(struct sock___54 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___236;

struct attribute_group___234 {
	const char *name;
	umode_t (*is_visible)(struct kobject___56 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___236 **bin_attrs;
};

struct bin_attribute___236 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___274 *, struct kobject___56 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___274 *, struct kobject___56 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	int (*mmap)(struct file___274 *, struct kobject___56 *, struct bin_attribute___236 *, struct vm_area_struct___282 *);
};

struct dentry___274;

struct path___274 {
	struct vfsmount *mnt;
	struct dentry___274 *dentry;
};

struct inode___274;

struct file_operations___274;

struct file___274 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___274 f_path;
	struct inode___274 *f_inode;
	const struct file_operations___274 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___274 *f_mapping;
	struct mutex___276 f_pos_lock;
};

struct vm_operations_struct___248;

struct vm_area_struct___282 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___282 *vm_next;
	struct vm_area_struct___282 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___282 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___248 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___274 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___56 {
	ssize_t (*show)(struct kobject___56 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___56 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___56 *, const struct attribute *);
};

struct kset_uevent_ops___56;

struct kset___56 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___56 kobj;
	const struct kset_uevent_ops___56 *uevent_ops;
};

struct kobj_type___56 {
	void (*release)(struct kobject___56 *);
	const struct sysfs_ops___56 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___53 * (*child_ns_type)(struct kobject___56 *);
	const void * (*namespace)(struct kobject___56 *);
};

struct kset_uevent_ops___56 {
	int (* const filter)(struct kset___56 *, struct kobject___56 *);
	const char * (* const name)(struct kset___56 *, struct kobject___56 *);
	int (* const uevent)(struct kset___56 *, struct kobject___56 *, struct kobj_uevent_env *);
};

struct module_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___170 *, struct module_kobject___170 *, char *);
	ssize_t (*store)(struct module_attribute___170 *, struct module_kobject___170 *, const char *, size_t);
	void (*setup)(struct module___171 *, const char *);
	int (*test)(struct module___171 *);
	void (*free)(struct module___171 *);
};

struct dentry_operations___274;

struct super_block___274;

struct dentry___274 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___274 *d_parent;
	struct qstr d_name;
	struct inode___274 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___274 *d_op;
	struct super_block___274 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___274;

struct address_space___274 {
	struct inode___274 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___276 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___274 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___274;

struct file_lock___274;

struct dquot___274;

struct block_device___274;

struct inode___274 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___274 *i_op;
	struct super_block___274 *i_sb;
	struct address_space___274 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___276 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___274 *i_fop;
	struct file_lock___274 *i_flock;
	struct address_space___274 i_data;
	struct dquot___274 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___274 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___274 {
	int (*d_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_hash)(const struct dentry___274 *, struct qstr *);
	int (*d_compare)(const struct dentry___274 *, const struct dentry___274 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___274 *);
	void (*d_release)(struct dentry___274 *);
	void (*d_prune)(struct dentry___274 *);
	void (*d_iput)(struct dentry___274 *, struct inode___274 *);
	char * (*d_dname)(struct dentry___274 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___274 *);
	int (*d_manage)(struct dentry___274 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___274;

struct mem_dqinfo___274 {
	struct quota_format_type___274 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___274;

struct quota_info___274 {
	unsigned int flags;
	struct mutex___276 dqio_mutex;
	struct mutex___276 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___274 *files[2];
	struct mem_dqinfo___274 info[2];
	const struct quota_format_ops___274 *ops[2];
};

struct file_system_type___274;

struct super_operations___274;

struct dquot_operations___274;

struct quotactl_ops___274;

struct xattr_handler___170;

struct super_block___274 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___274 *s_type;
	const struct super_operations___274 *s_op;
	const struct dquot_operations___274 *dq_op;
	const struct quotactl_ops___274 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___274 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___170 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___274 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___274 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___276 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___274 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___274 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___274 *bd_inode;
	struct super_block___274 *bd_super;
	struct mutex___276 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___274 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___276 bd_fsfreeze_mutex;
};

struct cgroup___169;

struct cgroup_subsys_state___169 {
	struct cgroup___169 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___61;

typedef int kiocb_cancel_fn___61(struct kiocb___61 *, struct io_event *);

struct kiocb___61 {
	atomic_t ki_users;
	struct file___274 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___61 *ki_cancel;
	void (*ki_dtor)(struct kiocb___61 *);
	union {
		void *user;
		struct task_struct___275 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___274 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___274 *ia_file;
};

struct dquot___274 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___276 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___274 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___274 {
	int qf_fmt_id;
	const struct quota_format_ops___274 *qf_ops;
	struct module___171 *qf_owner;
	struct quota_format_type___274 *qf_next;
};

struct quota_format_ops___274 {
	int (*check_quota_file)(struct super_block___274 *, int);
	int (*read_file_info)(struct super_block___274 *, int);
	int (*write_file_info)(struct super_block___274 *, int);
	int (*free_file_info)(struct super_block___274 *, int);
	int (*read_dqblk)(struct dquot___274 *);
	int (*commit_dqblk)(struct dquot___274 *);
	int (*release_dqblk)(struct dquot___274 *);
};

struct dquot_operations___274 {
	int (*write_dquot)(struct dquot___274 *);
	struct dquot___274 * (*alloc_dquot)(struct super_block___274 *, int);
	void (*destroy_dquot)(struct dquot___274 *);
	int (*acquire_dquot)(struct dquot___274 *);
	int (*release_dquot)(struct dquot___274 *);
	int (*mark_dirty)(struct dquot___274 *);
	int (*write_info)(struct super_block___274 *, int);
	qsize_t * (*get_reserved_space)(struct inode___274 *);
};

struct quotactl_ops___274 {
	int (*quota_on)(struct super_block___274 *, int, int, struct path___274 *);
	int (*quota_on_meta)(struct super_block___274 *, int, int);
	int (*quota_off)(struct super_block___274 *, int);
	int (*quota_sync)(struct super_block___274 *, int);
	int (*get_info)(struct super_block___274 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___274 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___274 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___274 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___274 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___274 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___274 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___274 *, unsigned int);
};

struct address_space_operations___274 {
	int (*writepage)(struct page___273 *, struct writeback_control *);
	int (*readpage)(struct file___274 *, struct page___273 *);
	int (*writepages)(struct address_space___274 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___273 *);
	int (*readpages)(struct file___274 *, struct address_space___274 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___274 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___273 **, void **);
	int (*write_end)(struct file___274 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___273 *, void *);
	sector_t (*bmap)(struct address_space___274 *, sector_t);
	void (*invalidatepage)(struct page___273 *, long unsigned int);
	int (*releasepage)(struct page___273 *, gfp_t);
	void (*freepage)(struct page___273 *);
	ssize_t (*direct_IO)(int, struct kiocb___61 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___274 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___274 *, struct page___273 *, struct page___273 *, enum migrate_mode);
	int (*launder_page)(struct page___273 *);
	int (*is_partially_uptodate)(struct page___273 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___273 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___274 *, struct page___273 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___274 *, sector_t *);
	void (*swap_deactivate)(struct file___274 *);
	void (*invalidatepage_range)(struct page___273 *, unsigned int, unsigned int);
};

struct inode_operations___274 {
	struct dentry___274 * (*lookup)(struct inode___274 *, struct dentry___274 *, unsigned int);
	void * (*follow_link)(struct dentry___274 *, struct nameidata *);
	int (*permission)(struct inode___274 *, int);
	struct posix_acl * (*get_acl)(struct inode___274 *, int);
	int (*readlink)(struct dentry___274 *, char *, int);
	void (*put_link)(struct dentry___274 *, struct nameidata *, void *);
	int (*create)(struct inode___274 *, struct dentry___274 *, umode_t, bool);
	int (*link)(struct dentry___274 *, struct inode___274 *, struct dentry___274 *);
	int (*unlink)(struct inode___274 *, struct dentry___274 *);
	int (*symlink)(struct inode___274 *, struct dentry___274 *, const char *);
	int (*mkdir)(struct inode___274 *, struct dentry___274 *, umode_t);
	int (*rmdir)(struct inode___274 *, struct dentry___274 *);
	int (*mknod)(struct inode___274 *, struct dentry___274 *, umode_t, dev_t);
	int (*rename)(struct inode___274 *, struct dentry___274 *, struct inode___274 *, struct dentry___274 *);
	int (*setattr)(struct dentry___274 *, struct iattr___274 *);
	int (*getattr)(struct vfsmount *, struct dentry___274 *, struct kstat *);
	int (*setxattr)(struct dentry___274 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___274 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___274 *, char *, size_t);
	int (*removexattr)(struct dentry___274 *, const char *);
	int (*fiemap)(struct inode___274 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___274 *, struct timespec *, int);
	int (*atomic_open)(struct inode___274 *, struct dentry___274 *, struct file___274 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___160;

struct seq_file___199;

struct file_operations___274 {
	struct module___171 *owner;
	loff_t (*llseek)(struct file___274 *, loff_t, int);
	ssize_t (*read)(struct file___274 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___274 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___61 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___61 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___274 *, void *, filldir_t);
	unsigned int (*poll)(struct file___274 *, struct poll_table_struct___160 *);
	long int (*unlocked_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___274 *, struct vm_area_struct___282 *);
	int (*open)(struct inode___274 *, struct file___274 *);
	int (*flush)(struct file___274 *, fl_owner_t);
	int (*release)(struct inode___274 *, struct file___274 *);
	int (*fsync)(struct file___274 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___61 *, int);
	int (*fasync)(int, struct file___274 *, int);
	int (*lock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*sendpage)(struct file___274 *, struct page___273 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___274 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___274 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___274 *, long int, struct file_lock___274 **, void **);
		struct {
			int (*setlease)(struct file___274 *, long int, struct file_lock___274 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___274 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___199 *, struct file___274 *);
};

struct fasync_struct___274;

struct file_lock_operations___274;

struct lock_manager_operations___274;

struct file_lock___274 {
	struct file_lock___274 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___274 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___274 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___274 *fl_ops;
	const struct lock_manager_operations___274 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___274 {
	void (*fl_copy_lock)(struct file_lock___274 *, struct file_lock___274 *);
	void (*fl_release_private)(struct file_lock___274 *);
};

struct lock_manager_operations___274 {
	int (*lm_compare_owner)(struct file_lock___274 *, struct file_lock___274 *);
	long unsigned int (*lm_owner_key)(struct file_lock___274 *);
	void (*lm_notify)(struct file_lock___274 *);
	int (*lm_grant)(struct file_lock___274 *, struct file_lock___274 *, int);
	void (*lm_break)(struct file_lock___274 *);
	int (*lm_change)(struct file_lock___274 **, int);
};

struct fasync_struct___274 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___274 *fa_next;
	struct file___274 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___274 {
	const char *name;
	int fs_flags;
	struct dentry___274 * (*mount)(struct file_system_type___274 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___274 *);
	struct module___171 *owner;
	struct file_system_type___274 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___274 {
	struct inode___274 * (*alloc_inode)(struct super_block___274 *);
	void (*destroy_inode)(struct inode___274 *);
	void (*dirty_inode)(struct inode___274 *, int);
	int (*write_inode)(struct inode___274 *, struct writeback_control *);
	int (*drop_inode)(struct inode___274 *);
	void (*evict_inode)(struct inode___274 *);
	void (*put_super)(struct super_block___274 *);
	int (*sync_fs)(struct super_block___274 *, int);
	int (*freeze_fs)(struct super_block___274 *);
	int (*unfreeze_fs)(struct super_block___274 *);
	int (*statfs)(struct dentry___274 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___274 *, int *, char *);
	void (*umount_begin)(struct super_block___274 *);
	int (*show_options)(struct seq_file___199 *, struct dentry___274 *);
	int (*show_devname)(struct seq_file___199 *, struct dentry___274 *);
	int (*show_path)(struct seq_file___199 *, struct dentry___274 *);
	int (*show_stats)(struct seq_file___199 *, struct dentry___274 *);
	ssize_t (*quota_read)(struct super_block___274 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___274 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___274 *);
	int (*bdev_try_to_free_page)(struct super_block___274 *, struct page___273 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___274 *);
	void (*free_cached_objects)(struct super_block___274 *, int);
};

struct xattr_handler___170 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___274 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___274 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___274 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___162)(struct file___274 *, wait_queue_head_t *, struct poll_table_struct___160 *);

struct poll_table_struct___160 {
	poll_queue_proc___162 _qproc;
	long unsigned int _key;
};

struct seq_operations___199;

struct seq_file___199 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___276 lock;
	const struct seq_operations___199 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___273 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___273 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___256;

struct memcg_cache_params___257;

struct kmem_cache___257 {
	struct kmem_cache_cpu___256 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___56 kobj;
	struct memcg_cache_params___257 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___244;

struct vm_operations_struct___248 {
	void (*open)(struct vm_area_struct___282 *);
	void (*close)(struct vm_area_struct___282 *);
	int (*fault)(struct vm_area_struct___282 *, struct vm_fault___244 *);
	int (*page_mkwrite)(struct vm_area_struct___282 *, struct vm_fault___244 *);
	int (*access)(struct vm_area_struct___282 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___282 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___282 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___282 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___282 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___275 {
	struct task_struct___275 *task;
	struct core_thread___275 *next;
};

struct core_state___275 {
	atomic_t nr_threads;
	struct core_thread___275 dumper;
	struct completion startup;
};

struct dma_map_ops___137 {
	void * (*alloc)(struct device___272 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___272 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___272 *, struct vm_area_struct___282 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___272 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___272 *, struct page___273 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___272 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___272 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___272 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___272 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___272 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___272 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___272 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___272 *, dma_addr_t);
	int (*dma_supported)(struct device___272 *, u64);
	int (*set_dma_mask)(struct device___272 *, u64);
	int is_phys;
};

struct bus_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___272 *, char *);
	ssize_t (*store)(struct bus_type___272 *, const char *, size_t);
};

struct device_attribute___272;

struct driver_attribute___272;

struct bus_type___272 {
	const char *name;
	const char *dev_name;
	struct device___272 *dev_root;
	struct bus_attribute___272 *bus_attrs;
	struct device_attribute___272 *dev_attrs;
	struct driver_attribute___272 *drv_attrs;
	const struct attribute_group___234 **bus_groups;
	const struct attribute_group___234 **dev_groups;
	const struct attribute_group___234 **drv_groups;
	int (*match)(struct device___272 *, struct device_driver___272 *);
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	int (*probe)(struct device___272 *);
	int (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*online)(struct device___272 *);
	int (*offline)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct device___272 *, struct device_attribute___272 *, char *);
	ssize_t (*store)(struct device___272 *, struct device_attribute___272 *, const char *, size_t);
};

struct driver_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___272 *, char *);
	ssize_t (*store)(struct device_driver___272 *, const char *, size_t);
};

struct device_driver___272 {
	const char *name;
	struct bus_type___272 *bus;
	struct module___171 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___272 *);
	int (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	const struct attribute_group___234 **groups;
	const struct dev_pm_ops___272 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___272 {
	const char *name;
	const struct attribute_group___234 **groups;
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
};

struct class_attribute___272;

struct class___272 {
	const char *name;
	struct module___171 *owner;
	struct class_attribute___272 *class_attrs;
	struct device_attribute___272 *dev_attrs;
	const struct attribute_group___234 **dev_groups;
	struct bin_attribute___236 *dev_bin_attrs;
	struct kobject___56 *dev_kobj;
	int (*dev_uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *);
	void (*class_release)(struct class___272 *);
	void (*dev_release)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	const struct kobj_ns_type_operations___53 *ns_type;
	const void * (*namespace)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
	struct subsys_private *p;
};

struct class_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct class___272 *, struct class_attribute___272 *, char *);
	ssize_t (*store)(struct class___272 *, struct class_attribute___272 *, const char *, size_t);
	const void * (*namespace)(struct class___272 *, const struct class_attribute___272 *);
};

struct device_rh___272 {
	struct dev_pm_info_rh___272 power;
};

struct dev_pm_qos_request___76 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___272 *dev;
};

struct vm_fault___244 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___273 *page;
};

struct dma_device___7;

struct dma_chan_dev___7;

struct dma_chan___8 {
	struct dma_device___7 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___7 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___7;

struct dma_device___7 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___272 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___8 *);
	void (*device_free_chan_resources)(struct dma_chan___8 *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memcpy)(struct dma_chan___8 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor)(struct dma_chan___8 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor_val)(struct dma_chan___8 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq_val)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memset)(struct dma_chan___8 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_interrupt)(struct dma_chan___8 *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_slave_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_cyclic)(struct dma_chan___8 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___7 * (*device_prep_interleaved_dma)(struct dma_chan___8 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___8 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___8 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___8 *);
};

struct dma_chan_dev___7 {
	struct dma_chan___8 *chan;
	struct device___272 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___7 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___8 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___7 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___2 {
	char *base_address;
	int nr_pages;
	struct page___273 **pages;
};

struct dma_pinned_list___2 {
	int nr_iovecs;
	struct dma_page_list___2 page_list[0];
};

struct signal_struct___275 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___275 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___275 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___276 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___169 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___169 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___53 {
	wait_queue_head_t wait;
	struct fasync_struct___274 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___53;

struct socket___54 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___53 *wq;
	struct file___274 *file;
	struct sock___54 *sk;
	const struct proto_ops___53 *ops;
};

struct proto_ops___53 {
	int family;
	struct module___171 *owner;
	int (*release)(struct socket___54 *);
	int (*bind)(struct socket___54 *, struct sockaddr *, int);
	int (*connect)(struct socket___54 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___54 *, struct socket___54 *);
	int (*accept)(struct socket___54 *, struct socket___54 *, int);
	int (*getname)(struct socket___54 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___274 *, struct socket___54 *, struct poll_table_struct___160 *);
	int (*ioctl)(struct socket___54 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___54 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___54 *, int);
	int (*shutdown)(struct socket___54 *, int);
	int (*setsockopt)(struct socket___54 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___54 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___54 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___54 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___61 *, struct socket___54 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___61 *, struct socket___54 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___274 *, struct socket___54 *, struct vm_area_struct___282 *);
	ssize_t (*sendpage)(struct socket___54 *, struct page___273 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___54 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___54 *, int);
		struct {
			void (*set_peek_off)(struct sock___54 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___76 {
	struct ctl_table_header___79 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___77 {
	struct mutex___276 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___76 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___79 *ctl;
};

struct netns_ipv4___76 {
	struct ctl_table_header___79 *forw_hdr;
	struct ctl_table_header___79 *frags_hdr;
	struct ctl_table_header___79 *ipv4_hdr;
	struct ctl_table_header___79 *route_hdr;
	struct ctl_table_header___79 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___54 *fibnl;
	struct sock___54 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___76 {
	struct ctl_table_header___79 *hdr;
	struct ctl_table_header___79 *route_hdr;
	struct ctl_table_header___79 *icmp_hdr;
	struct ctl_table_header___79 *frags_hdr;
	struct ctl_table_header___79 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___64;

struct neighbour___54;

struct dst_ops___78 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___78 *);
	struct dst_entry___54 * (*check)(struct dst_entry___54 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___54 *);
	unsigned int (*mtu)(const struct dst_entry___54 *);
	u32 * (*cow_metrics)(struct dst_entry___54 *, long unsigned int);
	void (*destroy)(struct dst_entry___54 *);
	void (*ifdown)(struct dst_entry___54 *, struct net_device___64 *, int);
	struct dst_entry___54 * (*negative_advice)(struct dst_entry___54 *);
	void (*link_failure)(struct sk_buff___67 *);
	void (*update_pmtu)(struct dst_entry___54 *, struct sock___54 *, struct sk_buff___67 *, u32);
	void (*redirect)(struct dst_entry___54 *, struct sock___54 *, struct sk_buff___67 *);
	int (*local_out)(struct sk_buff___67 *);
	struct neighbour___54 * (*neigh_lookup)(const struct dst_entry___54 *, struct sk_buff___67 *, const void *);
	struct kmem_cache___257 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___10;

struct fib6_table___10;

struct netns_ipv6___78 {
	struct netns_sysctl_ipv6___76 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___10 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___10 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___78 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___10 *ip6_prohibit_entry;
	struct rt6_info___10 *ip6_blk_hole_entry;
	struct fib6_table___10 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___54 **icmp_sk;
	struct sock___54 *ndisc_sk;
	struct sock___54 *tcp_sk;
	struct sock___54 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___76 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___79 *sysctl_header;
	struct sock___54 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___53 {
	struct sock___54 *v4_ctl_sk;
	struct sock___54 *v6_ctl_sk;
};

struct netns_nf___76 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___79 *nf_log_dir_header;
};

struct nf_proto_net___76 {
	struct ctl_table_header___79 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___76 {
	struct nf_proto_net___76 pn;
	unsigned int timeout;
};

struct nf_tcp_net___76 {
	struct nf_proto_net___76 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___76 {
	struct nf_proto_net___76 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___76 {
	struct nf_proto_net___76 pn;
	unsigned int timeout;
};

struct nf_ip_net___76 {
	struct nf_generic_net___76 generic;
	struct nf_tcp_net___76 tcp;
	struct nf_udp_net___76 udp;
	struct nf_icmp_net___76 icmp;
	struct nf_icmp_net___76 icmpv6;
};

struct netns_ct___77 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___79 *sysctl_header;
	struct ctl_table_header___79 *acct_sysctl_header;
	struct ctl_table_header___79 *tstamp_sysctl_header;
	struct ctl_table_header___79 *event_sysctl_header;
	struct ctl_table_header___79 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___257 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___76 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___76 {
	struct netns_sysctl_ipv6___76 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___78 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___54 *nlsk;
	struct sock___54 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___79 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___78 xfrm4_dst_ops;
	struct dst_ops___78 xfrm6_dst_ops;
};

struct net___78 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___79 sysctls;
	struct sock___54 *rtnl;
	struct sock___54 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___64 *loopback_dev;
	struct netns_core___76 core;
	struct netns_mib mib;
	struct netns_packet___77 packet;
	struct netns_unix___76 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___76 ipv4;
	struct netns_ipv6___78 ipv6;
	struct netns_sctp___76 sctp;
	struct netns_dccp___53 dccp;
	struct netns_nf___76 nf;
	struct netns_xt xt;
	struct netns_ct___77 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___76 nf_frag;
	struct sock___54 *nfnl;
	struct sock___54 *nfnl_stash;
	struct sk_buff_head___65 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___78 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___54 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___54 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___276 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___276 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___256 {
	void **freelist;
	long unsigned int tid;
	struct page___273 *page;
	struct page___273 *partial;
};

struct memcg_cache_params___257 {
	bool is_root_cache;
	union {
		struct kmem_cache___257 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___257 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___64 {
	atomic_t use;
	unsigned int mask;
	struct net_device___64 *physindev;
	struct net_device___64 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___64(struct sk_buff___67 **);

struct net_device_ops___64;

struct ethtool_ops___64;

struct header_ops___64;

struct inet6_dev___30;

struct netdev_rx_queue___64;

struct netdev_queue___64;

struct rtnl_link_ops___55;

struct dcbnl_rtnl_ops___64;

struct net_device___64 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___64 *netdev_ops;
	const struct ethtool_ops___64 *ethtool_ops;
	const struct header_ops___64 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___56 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___30 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___64 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___64 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___64 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___64 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___64 = 0,
		NETREG_REGISTERED___64 = 1,
		NETREG_UNREGISTERING___64 = 2,
		NETREG_UNREGISTERED___64 = 3,
		NETREG_RELEASED___64 = 4,
		NETREG_DUMMY___64 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___64 = 0,
		RTNL_LINK_INITIALIZING___64 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___64 *);
	struct netpoll_info *npinfo;
	struct net___78 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___272 dev;
	const struct attribute_group___234 *sysfs_groups[4];
	const struct rtnl_link_ops___55 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___64 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___10;

struct sk_buff___67 {
	struct sk_buff___67 *next;
	struct sk_buff___67 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___54 *sk;
	struct net_device___64 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___10 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___67 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___64 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___10;

struct sec_path___10 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___10 *xvec[6];
};

struct ethtool_ops___64 {
	int (*get_settings)(struct net_device___64 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___64 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___64 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___64 *);
	void (*get_regs)(struct net_device___64 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___64 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___64 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___64 *);
	void (*set_msglevel)(struct net_device___64 *, u32);
	int (*nway_reset)(struct net_device___64 *);
	u32 (*get_link)(struct net_device___64 *);
	int (*get_eeprom_len)(struct net_device___64 *);
	int (*get_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___64 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___64 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___64 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___64 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___64 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___64 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___64 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___64 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___64 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___64 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___64 *);
	void (*complete)(struct net_device___64 *);
	u32 (*get_priv_flags)(struct net_device___64 *);
	int (*set_priv_flags)(struct net_device___64 *, u32);
	int (*get_sset_count)(struct net_device___64 *, int);
	int (*get_rxnfc)(struct net_device___64 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___64 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___64 *, struct ethtool_flash *);
	int (*reset)(struct net_device___64 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___64 *);
	int (*get_rxfh_indir)(struct net_device___64 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___64 *, const u32 *);
	void (*get_channels)(struct net_device___64 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___64 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___64 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___64 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___64 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___64 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___64 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___64 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___64 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___64 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___64 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___64 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___25;

struct dst_entry___54 {
	struct callback_head callback_head;
	struct dst_entry___54 *child;
	struct net_device___64 *dev;
	struct dst_ops___78 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___54 *path;
	struct dst_entry___54 *from;
	struct xfrm_state___10 *xfrm;
	int (*input)(struct sk_buff___67 *);
	union {
		int (*output)(struct sock___54 *, struct sk_buff___67 *);
		struct {
			int (*output)(struct sk_buff___67 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___54 *next;
		struct rtable___25 *rt_next;
		struct rt6_info___10 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___54;

struct neigh_parms___54;

struct neigh_ops___54;

struct neighbour___54 {
	struct neighbour___54 *next;
	struct neigh_table___54 *tbl;
	struct neigh_parms___54 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___65 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___54 *, struct sk_buff___67 *);
	const struct neigh_ops___54 *ops;
	struct callback_head rcu;
	struct net_device___64 *dev;
	u8 primary_key[0];
};

struct fib6_node___10;

struct rt6_info___10 {
	struct dst_entry___54 dst;
	struct fib6_table___10 *rt6i_table;
	struct fib6_node___10 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___30 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___10 {
	struct fib6_node___10 *parent;
	struct fib6_node___10 *left;
	struct fib6_node___10 *right;
	struct rt6_info___10 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___10 *rr_ptr;
};

struct fib6_table___10 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___10 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___78 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___67 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___67 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___78 *, struct dst_entry___54 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___67 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___67 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___198 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___198 *);
	void (*irq_shutdown)(struct irq_data___198 *);
	void (*irq_enable)(struct irq_data___198 *);
	void (*irq_disable)(struct irq_data___198 *);
	void (*irq_ack)(struct irq_data___198 *);
	void (*irq_mask)(struct irq_data___198 *);
	void (*irq_mask_ack)(struct irq_data___198 *);
	void (*irq_unmask)(struct irq_data___198 *);
	void (*irq_eoi)(struct irq_data___198 *);
	int (*irq_set_affinity)(struct irq_data___198 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___198 *);
	int (*irq_set_type)(struct irq_data___198 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___198 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___198 *);
	void (*irq_bus_sync_unlock)(struct irq_data___198 *);
	void (*irq_cpu_online)(struct irq_data___198 *);
	void (*irq_cpu_offline)(struct irq_data___198 *);
	void (*irq_suspend)(struct irq_data___198 *);
	void (*irq_resume)(struct irq_data___198 *);
	void (*irq_pm_shutdown)(struct irq_data___198 *);
	void (*irq_print_chip)(struct irq_data___198 *, struct seq_file___199 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___198 *, void *);
	long unsigned int flags;
};

struct seq_operations___199 {
	void * (*start)(struct seq_file___199 *, loff_t *);
	void (*stop)(struct seq_file___199 *, void *);
	void * (*next)(struct seq_file___199 *, void *, loff_t *);
	int (*show)(struct seq_file___199 *, void *);
};

struct dcbnl_rtnl_ops___64 {
	int (*ieee_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___64 *);
	u8 (*setstate)(struct net_device___64 *, u8);
	void (*getpermhwaddr)(struct net_device___64 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___64 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___64 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___64 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___64 *, int, u8 *);
	void (*setpfccfg)(struct net_device___64 *, int, u8);
	void (*getpfccfg)(struct net_device___64 *, int, u8 *);
	u8 (*setall)(struct net_device___64 *);
	u8 (*getcap)(struct net_device___64 *, int, u8 *);
	int (*getnumtcs)(struct net_device___64 *, int, u8 *);
	int (*setnumtcs)(struct net_device___64 *, int, u8);
	u8 (*getpfcstate)(struct net_device___64 *);
	void (*setpfcstate)(struct net_device___64 *, u8);
	void (*getbcncfg)(struct net_device___64 *, int, u32 *);
	void (*setbcncfg)(struct net_device___64 *, int, u32);
	void (*getbcnrp)(struct net_device___64 *, int, u8 *);
	void (*setbcnrp)(struct net_device___64 *, int, u8);
	u8 (*setapp)(struct net_device___64 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___64 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___64 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___64 *, int, u8);
	u8 (*getdcbx)(struct net_device___64 *);
	u8 (*setdcbx)(struct net_device___64 *, u8);
	int (*peer_getappinfo)(struct net_device___64 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___64 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___64 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___64 *, struct cee_pfc *);
};

struct cgroupfs_root___169;

struct cgroup___169 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___169 *parent;
	struct dentry___274 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___169 *subsys[11];
	struct cgroupfs_root___169 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___276 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___169 {
	struct super_block___274 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___169 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___105 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___274 *, struct file___274 *);
	ssize_t (*read)(struct cgroup___169 *, struct cftype___105 *, struct file___274 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___169 *, struct cftype___105 *);
	s64 (*read_s64)(struct cgroup___169 *, struct cftype___105 *);
	int (*read_map)(struct cgroup___169 *, struct cftype___105 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___169 *, struct cftype___105 *, struct seq_file___199 *);
	ssize_t (*write)(struct cgroup___169 *, struct cftype___105 *, struct file___274 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___169 *, struct cftype___105 *, u64);
	int (*write_s64)(struct cgroup___169 *, struct cftype___105 *, s64);
	int (*write_string)(struct cgroup___169 *, struct cftype___105 *, const char *);
	int (*trigger)(struct cgroup___169 *, unsigned int);
	int (*release)(struct inode___274 *, struct file___274 *);
	int (*register_event)(struct cgroup___169 *, struct cftype___105 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___169 *, struct cftype___105 *, struct eventfd_ctx *);
};

struct cftype_set___101 {
	struct list_head node;
	struct cftype___105 *cfts;
};

struct task_and_cgroup___101 {
	struct task_struct___275 *task;
	struct cgroup___169 *cgrp;
	struct css_set___169 *cg;
};

struct cgroup_taskset___101 {
	struct task_and_cgroup___101 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___169 *cur_cgrp;
};

struct cgroup_subsys___101 {
	struct cgroup_subsys_state___169 * (*css_alloc)(struct cgroup___169 *);
	int (*css_online)(struct cgroup___169 *);
	void (*css_offline)(struct cgroup___169 *);
	void (*css_free)(struct cgroup___169 *);
	int (*can_attach)(struct cgroup___169 *, struct cgroup_taskset___101 *);
	void (*cancel_attach)(struct cgroup___169 *, struct cgroup_taskset___101 *);
	void (*attach)(struct cgroup___169 *, struct cgroup_taskset___101 *);
	void (*fork)(struct task_struct___275 *);
	void (*exit)(struct cgroup___169 *, struct cgroup___169 *, struct task_struct___275 *);
	void (*bind)(struct cgroup___169 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___169 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___105 *base_cftypes;
	struct cftype_set___101 base_cftset;
	struct module___171 *module;
};

struct request_sock_ops___39;

struct request_sock___40 {
	struct sock_common___53 __req_common;
	struct request_sock___40 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___39 *rsk_ops;
	struct sock___54 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___10;

struct xfrm_type___10;

struct xfrm_mode___10;

struct xfrm_state___10 {
	struct net___78 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___10 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___10 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___10 *type;
	struct xfrm_mode___10 *inner_mode;
	struct xfrm_mode___10 *inner_mode_iaf;
	struct xfrm_mode___10 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___10 {
	struct sk_buff_head___65 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___10 {
	struct net___78 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___10 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___66 {
	struct sk_buff___67 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___67 *, struct netlink_callback___66 *);
	int (*done)(struct netlink_callback___66 *);
	void *data;
	struct module___171 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___64 {
	int (*create)(struct sk_buff___67 *, struct net_device___64 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___67 *, unsigned char *);
	int (*rebuild)(struct sk_buff___67 *);
	int (*cache)(const struct neighbour___54 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___64 *, const unsigned char *);
};

struct napi_struct___64 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___64 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___64 *dev;
	struct sk_buff___67 *gro_list;
	struct sk_buff___67 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___64 {
	struct net_device___64 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___56 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___64 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___56 kobj;
	struct net_device___64 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___64 {
	int (*ndo_init)(struct net_device___64 *);
	void (*ndo_uninit)(struct net_device___64 *);
	int (*ndo_open)(struct net_device___64 *);
	int (*ndo_stop)(struct net_device___64 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___67 *, struct net_device___64 *);
	u16 (*ndo_select_queue)(struct net_device___64 *, struct sk_buff___67 *);
	void (*ndo_change_rx_flags)(struct net_device___64 *, int);
	void (*ndo_set_rx_mode)(struct net_device___64 *);
	int (*ndo_set_mac_address)(struct net_device___64 *, void *);
	int (*ndo_validate_addr)(struct net_device___64 *);
	int (*ndo_do_ioctl)(struct net_device___64 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___64 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___64 *, int);
	int (*ndo_neigh_setup)(struct net_device___64 *, struct neigh_parms___54 *);
	void (*ndo_tx_timeout)(struct net_device___64 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___64 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___64 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___64 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___64 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___64 *);
	int (*ndo_netpoll_setup)(struct net_device___64 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___64 *);
	int (*ndo_busy_poll)(struct napi_struct___64 *);
	int (*ndo_set_vf_mac)(struct net_device___64 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___64 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___64 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___64 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___64 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___64 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___64 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___64 *, int, struct sk_buff___67 *);
	int (*ndo_setup_tc)(struct net_device___64 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___64 *);
	int (*ndo_fcoe_disable)(struct net_device___64 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___64 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___64 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___64 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___64 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___64 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___64 *, const struct sk_buff___67 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___64 *, struct net_device___64 *);
	int (*ndo_del_slave)(struct net_device___64 *, struct net_device___64 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___54 *);
	void (*ndo_neigh_destroy)(struct neighbour___54 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___67 *, struct netlink_callback___66 *, struct net_device___64 *, int);
	int (*ndo_bridge_setlink)(struct net_device___64 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___67 *, u32, u32, struct net_device___64 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___64 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___64 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___64 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___64 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___64 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___64 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___67 *, struct net_device___64 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___64 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___64 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___64 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___54 {
	struct net___78 *net;
	struct net_device___64 *dev;
	struct neigh_parms___54 *next;
	int (*neigh_setup)(struct neighbour___54 *);
	void (*neigh_cleanup)(struct neighbour___54 *);
	struct neigh_table___54 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___30;

struct ifacaddr6___30;

struct inet6_dev___30 {
	struct net_device___64 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___30 *mc_list;
	struct ifmcaddr6___30 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___30 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___54 *nd_parms;
	struct inet6_dev___30 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___55 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___64 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___78 *, struct net_device___64 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___64 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___64 *, struct list_head *);
	size_t (*get_size)(const struct net_device___64 *);
	int (*fill_info)(struct sk_buff___67 *, const struct net_device___64 *);
	size_t (*get_xstats_size)(const struct net_device___64 *);
	int (*fill_xstats)(struct sk_buff___67 *, const struct net_device___64 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___78 * (*get_link_net)(const struct net_device___64 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___64 *, struct net_device___64 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___64 *, const struct net_device___64 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___67 *, const struct net_device___64 *, const struct net_device___64 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___54 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___67 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___54;

struct neigh_hash_table___54;

struct neigh_table___54 {
	struct neigh_table___54 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___64 *, __u32 *);
	int (*constructor)(struct neighbour___54 *);
	int (*pconstructor)(struct pneigh_entry___54 *);
	void (*pdestructor)(struct pneigh_entry___54 *);
	void (*proxy_redo)(struct sk_buff___67 *);
	char *id;
	struct neigh_parms___54 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___65 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___54 *nht;
	struct pneigh_entry___54 **phash_buckets;
};

struct neigh_ops___54 {
	int family;
	void (*solicit)(struct neighbour___54 *, struct sk_buff___67 *);
	void (*error_report)(struct neighbour___54 *, struct sk_buff___67 *);
	int (*output)(struct neighbour___54 *, struct sk_buff___67 *);
	int (*connected_output)(struct neighbour___54 *, struct sk_buff___67 *);
};

struct pneigh_entry___54 {
	struct pneigh_entry___54 *next;
	struct net___78 *net;
	struct net_device___64 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___54 {
	struct neighbour___54 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___25 {
	struct dst_entry___54 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___36;

struct inet_hashinfo___10;

struct proto___53 {
	void (*close)(struct sock___54 *, long int);
	int (*connect)(struct sock___54 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___54 *, int);
	struct sock___54 * (*accept)(struct sock___54 *, int, int *);
	int (*ioctl)(struct sock___54 *, int, long unsigned int);
	int (*init)(struct sock___54 *);
	void (*destroy)(struct sock___54 *);
	void (*shutdown)(struct sock___54 *, int);
	int (*setsockopt)(struct sock___54 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___54 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___54 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___54 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___54 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___61 *, struct sock___54 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___61 *, struct sock___54 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___54 *, struct page___273 *, int, size_t, int);
	int (*bind)(struct sock___54 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___54 *, struct sk_buff___67 *);
	void (*release_cb)(struct sock___54 *);
	void (*mtu_reduced)(struct sock___54 *);
	void (*hash)(struct sock___54 *);
	void (*unhash)(struct sock___54 *);
	void (*rehash)(struct sock___54 *);
	int (*get_port)(struct sock___54 *, short unsigned int);
	void (*clear_sk)(struct sock___54 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___54 *);
	void (*enter_memory_pressure)(struct sock___54 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___257 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___39 *rsk_prot;
	struct timewait_sock_ops___36 *twsk_prot;
	union {
		struct inet_hashinfo___10 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___171 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___101 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___53 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___53 {
	void (*enter_memory_pressure)(struct sock___54 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___10 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___257 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___39 {
	int family;
	int obj_size;
	struct kmem_cache___257 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___54 *, struct request_sock___40 *);
	void (*send_ack)(struct sock___54 *, struct sk_buff___67 *, struct request_sock___40 *);
	void (*send_reset)(struct sock___54 *, struct sk_buff___67 *);
	void (*destructor)(struct request_sock___40 *);
	void (*syn_ack_timeout)(struct sock___54 *, struct request_sock___40 *);
};

struct timewait_sock_ops___36 {
	struct kmem_cache___257 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___54 *, struct sock___54 *, void *);
	void (*twsk_destructor)(struct sock___54 *);
};

struct listen_sock___5 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___40 *syn_table[0];
};

struct fastopen_queue___5 {
	struct request_sock___40 *rskq_rst_head;
	struct request_sock___40 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___5 {
	struct request_sock___40 *rskq_accept_head;
	struct request_sock___40 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___5 *listen_opt;
	struct fastopen_queue___5 *fastopenq;
};

struct inet_request_sock___2 {
	struct request_sock___40 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___67 *pktopts;
	};
};

struct inet_cork___11 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___54 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___11 {
	struct inet_cork___11 base;
	struct flowi fl;
};

struct ipv6_pinfo___10;

struct inet_sock___11 {
	struct sock___54 sk;
	struct ipv6_pinfo___10 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___11 cork;
};

struct ipv6_fl_socklist___9;

struct ipv6_pinfo___10 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___9 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___67 *pktoptions;
	struct sk_buff___67 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___5;

struct inet_connection_sock_af_ops___5 {
	int (*queue_xmit)(struct sk_buff___67 *, struct flowi *);
	void (*send_check)(struct sock___54 *, struct sk_buff___67 *);
	int (*rebuild_header)(struct sock___54 *);
	void (*sk_rx_dst_set)(struct sock___54 *, const struct sk_buff___67 *);
	int (*conn_request)(struct sock___54 *, struct sk_buff___67 *);
	struct sock___54 * (*syn_recv_sock)(struct sock___54 *, struct sk_buff___67 *, struct request_sock___40 *, struct dst_entry___54 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___54 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___54 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___54 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___54 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___54 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___54 *, const struct inet_bind_bucket___5 *, bool);
	void (*mtu_reduced)(struct sock___54 *);
};

struct inet_bind_bucket___5 {
	struct net___78 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_connection_sock___5 {
	struct inet_sock___11 icsk_inet;
	struct request_sock_queue___5 icsk_accept_queue;
	struct inet_bind_bucket___5 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___5 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___54 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct inet_timewait_sock___4 {
	struct sock_common___53 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___5 *tw_tb;
	struct hlist_node tw_death_node;
};

struct tcp_request_sock___2 {
	struct inet_request_sock___2 req;
	const struct tcp_request_sock_ops *af_specific;
	struct sock___54 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_sock___2 {
	struct inet_connection_sock___5 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___65 prequeue;
		struct task_struct___275 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___8 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___2 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___67 *lost_skb_hint;
	struct sk_buff___67 *retransmit_skb_hint;
	struct sk_buff_head___65 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___67 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request *fastopen_req;
	struct request_sock___40 *fastopen_rsk;
};

struct ip6_flowlabel___9;

struct ipv6_fl_socklist___9 {
	struct ipv6_fl_socklist___9 *next;
	struct ip6_flowlabel___9 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___30 {
	struct in6_addr mca_addr;
	struct inet6_dev___30 *idev;
	struct ifmcaddr6___30 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___30 {
	struct in6_addr aca_addr;
	struct inet6_dev___30 *aca_idev;
	struct rt6_info___10 *aca_rt;
	struct ifacaddr6___30 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___9 {
	struct ip6_flowlabel___9 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___78 *fl_net;
};

struct xfrm_replay___10 {
	void (*advance)(struct xfrm_state___10 *, __be32);
	int (*check)(struct xfrm_state___10 *, struct sk_buff___67 *, __be32);
	int (*recheck)(struct xfrm_state___10 *, struct sk_buff___67 *, __be32);
	void (*notify)(struct xfrm_state___10 *, int);
	int (*overflow)(struct xfrm_state___10 *, struct sk_buff___67 *);
};

struct xfrm_type___10 {
	char *description;
	struct module___171 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___10 *);
	void (*destructor)(struct xfrm_state___10 *);
	int (*input)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*output)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*reject)(struct xfrm_state___10 *, struct sk_buff___67 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___10 *, struct sk_buff___67 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___10 *, int);
};

struct xfrm_state_afinfo___10;

struct xfrm_mode___10 {
	int (*input2)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*input)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*output2)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*output)(struct xfrm_state___10 *, struct sk_buff___67 *);
	struct xfrm_state_afinfo___10 *afinfo;
	struct module___171 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___10 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___171 *owner;
	const struct xfrm_type___10 *type_map[256];
	struct xfrm_mode___10 *mode_map[5];
	int (*init_flags)(struct xfrm_state___10 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___10 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___10 **, struct xfrm_state___10 **, int);
	union {
		int (*output)(struct sock___54 *, struct sk_buff___67 *);
		struct {
			int (*output)(struct sk_buff___67 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___54 *, struct sk_buff___67 *);
		struct {
			int (*output_finish)(struct sk_buff___67 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*extract_output)(struct xfrm_state___10 *, struct sk_buff___67 *);
	int (*transport_finish)(struct sk_buff___67 *, int);
};

struct page___274;

typedef struct page___274 *pgtable_t___274;

struct address_space___275;

struct kmem_cache___258;

struct page___274 {
	long unsigned int flags;
	struct address_space___275 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___274 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___274 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___258 *slab_cache;
		struct page___274 *first_page;
	};
	long: 64;
};

struct task_struct___276;

struct pv_cpu_ops___276 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___276 *);
	void (*end_context_switch)(struct task_struct___276 *);
};

struct mutex___277 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___276 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___269 {
	struct page___274 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___283;

struct nsproxy___155;

struct signal_struct___276;

struct css_set___170;

struct pipe_inode_info___10;

struct task_struct___276 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___276 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___283 *mm;
	struct mm_struct___283 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___276 *real_parent;
	struct task_struct___276 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___276 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___276 = 0,
		VTIME_USER___276 = 1,
		VTIME_SYS___276 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___155 *nsproxy;
	struct signal_struct___276 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___170 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___277 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___10 *splice_pipe;
	struct page_frag___269 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___283 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___283 *, struct mm_struct___283 *);
	void (*dup_mmap)(struct mm_struct___283 *, struct mm_struct___283 *);
	void (*exit_mmap)(struct mm_struct___283 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___283 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___283 *);
	void (*pgd_free)(struct mm_struct___283 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___283 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___283 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___283 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___283 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___283 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___283 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___283 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___283 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___283 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___283 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___283 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___277 lock;
	void *vdso;
} mm_context_t___277;

struct xol_area___274;

struct uprobes_state___274 {
	struct xol_area___274 *xol_area;
};

struct vm_area_struct___283;

struct file___275;

struct core_state___276;

struct mm_struct___283 {
	struct vm_area_struct___283 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___283 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___283 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___277 context;
	long unsigned int flags;
	struct core_state___276 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___276 *owner;
	struct file___275 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___274 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___172;

struct exec_domain___77 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___172 *module;
	struct exec_domain___77 *next;
};

struct kset___57;

struct kobj_type___57;

struct kobject___57 {
	const char *name;
	struct list_head entry;
	struct kobject___57 *parent;
	struct kset___57 *kset;
	struct kobj_type___57 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___171 {
	struct kobject___57 kobj;
	struct module___172 *mod;
	struct kobject___57 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___171;

struct module___172 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___171 mkobj;
	struct module_attribute___171 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___57 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___276 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___124 {
	struct task_struct___276 *task;
	struct exec_domain___77 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___276;

struct lruvec___276 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___276 *zone;
};

struct pglist_data___276;

struct zone___276 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___276 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___276 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___276 {
	struct zone___276 *zone;
	int zone_idx;
};

struct zonelist___276 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___276 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___276 {
	struct zone___276 node_zones[4];
	struct zonelist___276 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___276 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___199;

struct x86_io_apic_ops___199 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___199 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___199;

struct irq_data___199 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___199 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___273;

struct dev_pm_ops___273 {
	int (*prepare)(struct device___273 *);
	void (*complete)(struct device___273 *);
	int (*suspend)(struct device___273 *);
	int (*resume)(struct device___273 *);
	int (*freeze)(struct device___273 *);
	int (*thaw)(struct device___273 *);
	int (*poweroff)(struct device___273 *);
	int (*restore)(struct device___273 *);
	int (*suspend_late)(struct device___273 *);
	int (*resume_early)(struct device___273 *);
	int (*freeze_late)(struct device___273 *);
	int (*thaw_early)(struct device___273 *);
	int (*poweroff_late)(struct device___273 *);
	int (*restore_early)(struct device___273 *);
	int (*suspend_noirq)(struct device___273 *);
	int (*resume_noirq)(struct device___273 *);
	int (*freeze_noirq)(struct device___273 *);
	int (*thaw_noirq)(struct device___273 *);
	int (*poweroff_noirq)(struct device___273 *);
	int (*restore_noirq)(struct device___273 *);
	int (*runtime_suspend)(struct device___273 *);
	int (*runtime_resume)(struct device___273 *);
	int (*runtime_idle)(struct device___273 *);
};

struct dev_pm_qos___76;

struct dev_pm_info___76 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___76 *qos;
};

struct dma_map_ops___138;

struct dev_archdata___138 {
	struct dma_map_ops___138 *dma_ops;
	void *iommu;
};

struct device_type___273;

struct bus_type___273;

struct device_driver___273;

struct dev_pm_domain___273;

struct class___273;

struct attribute_group___235;

struct device_rh___273;

struct device___273 {
	struct device___273 *parent;
	struct device_private *p;
	struct kobject___57 kobj;
	const char *init_name;
	const struct device_type___273 *type;
	struct mutex___277 mutex;
	struct bus_type___273 *bus;
	struct device_driver___273 *driver;
	void *platform_data;
	struct dev_pm_info___76 power;
	struct dev_pm_domain___273 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___138 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___273 *class;
	const struct attribute_group___235 **groups;
	void (*release)(struct device___273 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___273 *device_rh;
};

struct dev_pm_qos_request___77;

struct dev_pm_qos___76 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___77 *latency_req;
	struct dev_pm_qos_request___77 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___77 *latency_tolerance_req;
};

struct dev_pm_info_rh___273 {
	void (*set_latency_tolerance)(struct device___273 *, s32);
};

struct dev_pm_domain___273 {
	struct dev_pm_ops___273 ops;
};

struct smp_ops___276 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___276 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___80;

struct ctl_node___80 {
	struct rb_node node;
	struct ctl_table_header___80 *header;
};

struct ctl_table_root___80;

struct ctl_table_set___80;

struct ctl_dir___80;

struct ctl_table_header___80 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___80 *root;
	struct ctl_table_set___80 *set;
	struct ctl_dir___80 *parent;
	struct ctl_node___80 *node;
};

struct ctl_dir___80 {
	struct ctl_table_header___80 header;
	struct rb_root root;
};

struct ctl_table_set___80 {
	int (*is_seen)(struct ctl_table_set___80 *);
	struct ctl_dir___80 dir;
};

struct ctl_table_root___80 {
	struct ctl_table_set___80 default_set;
	struct ctl_table_set___80 * (*lookup)(struct ctl_table_root___80 *, struct nsproxy___155 *);
	int (*permissions)(struct ctl_table_header___80 *, struct ctl_table *);
};

struct net___79;

struct nsproxy___155 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___79 *net_ns;
};

struct sock___55;

struct kobj_ns_type_operations___54 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___55 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___54;

struct sock_common___54 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___54 *skc_prot;
	struct net___79 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___68;

struct sk_buff_head___66 {
	struct sk_buff___68 *next;
	struct sk_buff___68 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___55;

struct socket_wq___54;

struct xfrm_policy___11;

struct dst_entry___55;

struct socket___55;

struct cg_proto___54;

struct sock___55 {
	struct sock_common___54 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___66 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___68 *head;
		struct sk_buff___68 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___55 *sk_filter;
	struct socket_wq___54 *sk_wq;
	struct sk_buff_head___66 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___11 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___55 *sk_rx_dst;
	struct dst_entry___55 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___66 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___66 sk_error_queue;
	struct proto___54 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___55 *sk_socket;
	void *sk_user_data;
	struct page_frag___269 sk_frag;
	struct sk_buff___68 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___54 *sk_cgrp;
	void (*sk_state_change)(struct sock___55 *);
	void (*sk_data_ready)(struct sock___55 *, int);
	void (*sk_write_space)(struct sock___55 *);
	void (*sk_error_report)(struct sock___55 *);
	int (*sk_backlog_rcv)(struct sock___55 *, struct sk_buff___68 *);
	void (*sk_destruct)(struct sock___55 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___237;

struct attribute_group___235 {
	const char *name;
	umode_t (*is_visible)(struct kobject___57 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___237 **bin_attrs;
};

struct bin_attribute___237 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___275 *, struct kobject___57 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___275 *, struct kobject___57 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	int (*mmap)(struct file___275 *, struct kobject___57 *, struct bin_attribute___237 *, struct vm_area_struct___283 *);
};

struct dentry___275;

struct path___275 {
	struct vfsmount *mnt;
	struct dentry___275 *dentry;
};

struct inode___275;

struct file_operations___275;

struct file___275 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___275 f_path;
	struct inode___275 *f_inode;
	const struct file_operations___275 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___275 *f_mapping;
	struct mutex___277 f_pos_lock;
};

struct vm_operations_struct___249;

struct vm_area_struct___283 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___283 *vm_next;
	struct vm_area_struct___283 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___283 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___249 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___275 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___57 {
	ssize_t (*show)(struct kobject___57 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___57 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___57 *, const struct attribute *);
};

struct kset_uevent_ops___57;

struct kset___57 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___57 kobj;
	const struct kset_uevent_ops___57 *uevent_ops;
};

struct kobj_type___57 {
	void (*release)(struct kobject___57 *);
	const struct sysfs_ops___57 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___54 * (*child_ns_type)(struct kobject___57 *);
	const void * (*namespace)(struct kobject___57 *);
};

struct kset_uevent_ops___57 {
	int (* const filter)(struct kset___57 *, struct kobject___57 *);
	const char * (* const name)(struct kset___57 *, struct kobject___57 *);
	int (* const uevent)(struct kset___57 *, struct kobject___57 *, struct kobj_uevent_env *);
};

struct module_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___171 *, struct module_kobject___171 *, char *);
	ssize_t (*store)(struct module_attribute___171 *, struct module_kobject___171 *, const char *, size_t);
	void (*setup)(struct module___172 *, const char *);
	int (*test)(struct module___172 *);
	void (*free)(struct module___172 *);
};

struct dentry_operations___275;

struct super_block___275;

struct dentry___275 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___275 *d_parent;
	struct qstr d_name;
	struct inode___275 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___275 *d_op;
	struct super_block___275 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___275;

struct address_space___275 {
	struct inode___275 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___277 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___275 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___275;

struct file_lock___275;

struct dquot___275;

struct block_device___275;

struct inode___275 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___275 *i_op;
	struct super_block___275 *i_sb;
	struct address_space___275 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___277 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___275 *i_fop;
	struct file_lock___275 *i_flock;
	struct address_space___275 i_data;
	struct dquot___275 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___10 *i_pipe;
		struct block_device___275 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___275 {
	int (*d_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_hash)(const struct dentry___275 *, struct qstr *);
	int (*d_compare)(const struct dentry___275 *, const struct dentry___275 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___275 *);
	void (*d_release)(struct dentry___275 *);
	void (*d_prune)(struct dentry___275 *);
	void (*d_iput)(struct dentry___275 *, struct inode___275 *);
	char * (*d_dname)(struct dentry___275 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___275 *);
	int (*d_manage)(struct dentry___275 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___275;

struct mem_dqinfo___275 {
	struct quota_format_type___275 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___275;

struct quota_info___275 {
	unsigned int flags;
	struct mutex___277 dqio_mutex;
	struct mutex___277 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___275 *files[2];
	struct mem_dqinfo___275 info[2];
	const struct quota_format_ops___275 *ops[2];
};

struct file_system_type___275;

struct super_operations___275;

struct dquot_operations___275;

struct quotactl_ops___275;

struct xattr_handler___171;

struct super_block___275 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___275 *s_type;
	const struct super_operations___275 *s_op;
	const struct dquot_operations___275 *dq_op;
	const struct quotactl_ops___275 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___275 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___171 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___275 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___275 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___277 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___275 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___275 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___275 *bd_inode;
	struct super_block___275 *bd_super;
	struct mutex___277 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___275 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___277 bd_fsfreeze_mutex;
};

struct cgroup___170;

struct cgroup_subsys_state___170 {
	struct cgroup___170 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___62;

typedef int kiocb_cancel_fn___62(struct kiocb___62 *, struct io_event *);

struct kiocb___62 {
	atomic_t ki_users;
	struct file___275 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___62 *ki_cancel;
	void (*ki_dtor)(struct kiocb___62 *);
	union {
		void *user;
		struct task_struct___276 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___275 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___275 *ia_file;
};

struct dquot___275 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___277 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___275 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___275 {
	int qf_fmt_id;
	const struct quota_format_ops___275 *qf_ops;
	struct module___172 *qf_owner;
	struct quota_format_type___275 *qf_next;
};

struct quota_format_ops___275 {
	int (*check_quota_file)(struct super_block___275 *, int);
	int (*read_file_info)(struct super_block___275 *, int);
	int (*write_file_info)(struct super_block___275 *, int);
	int (*free_file_info)(struct super_block___275 *, int);
	int (*read_dqblk)(struct dquot___275 *);
	int (*commit_dqblk)(struct dquot___275 *);
	int (*release_dqblk)(struct dquot___275 *);
};

struct dquot_operations___275 {
	int (*write_dquot)(struct dquot___275 *);
	struct dquot___275 * (*alloc_dquot)(struct super_block___275 *, int);
	void (*destroy_dquot)(struct dquot___275 *);
	int (*acquire_dquot)(struct dquot___275 *);
	int (*release_dquot)(struct dquot___275 *);
	int (*mark_dirty)(struct dquot___275 *);
	int (*write_info)(struct super_block___275 *, int);
	qsize_t * (*get_reserved_space)(struct inode___275 *);
};

struct quotactl_ops___275 {
	int (*quota_on)(struct super_block___275 *, int, int, struct path___275 *);
	int (*quota_on_meta)(struct super_block___275 *, int, int);
	int (*quota_off)(struct super_block___275 *, int);
	int (*quota_sync)(struct super_block___275 *, int);
	int (*get_info)(struct super_block___275 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___275 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___275 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___275 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___275 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___275 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___275 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___275 *, unsigned int);
};

struct swap_info_struct___47;

struct address_space_operations___275 {
	int (*writepage)(struct page___274 *, struct writeback_control *);
	int (*readpage)(struct file___275 *, struct page___274 *);
	int (*writepages)(struct address_space___275 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___274 *);
	int (*readpages)(struct file___275 *, struct address_space___275 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___275 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___274 **, void **);
	int (*write_end)(struct file___275 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___274 *, void *);
	sector_t (*bmap)(struct address_space___275 *, sector_t);
	void (*invalidatepage)(struct page___274 *, long unsigned int);
	int (*releasepage)(struct page___274 *, gfp_t);
	void (*freepage)(struct page___274 *);
	ssize_t (*direct_IO)(int, struct kiocb___62 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___275 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___275 *, struct page___274 *, struct page___274 *, enum migrate_mode);
	int (*launder_page)(struct page___274 *);
	int (*is_partially_uptodate)(struct page___274 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___274 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___275 *, struct page___274 *);
	int (*swap_activate)(struct swap_info_struct___47 *, struct file___275 *, sector_t *);
	void (*swap_deactivate)(struct file___275 *);
	void (*invalidatepage_range)(struct page___274 *, unsigned int, unsigned int);
};

struct swap_info_struct___47 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___275 *bdev;
	struct file___275 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct fasync_struct___275;

struct pipe_buffer___10;

struct pipe_inode_info___10 {
	struct mutex___277 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___274 *tmp_page;
	struct fasync_struct___275 *fasync_readers;
	struct fasync_struct___275 *fasync_writers;
	struct pipe_buffer___10 *bufs;
};

struct inode_operations___275 {
	struct dentry___275 * (*lookup)(struct inode___275 *, struct dentry___275 *, unsigned int);
	void * (*follow_link)(struct dentry___275 *, struct nameidata *);
	int (*permission)(struct inode___275 *, int);
	struct posix_acl * (*get_acl)(struct inode___275 *, int);
	int (*readlink)(struct dentry___275 *, char *, int);
	void (*put_link)(struct dentry___275 *, struct nameidata *, void *);
	int (*create)(struct inode___275 *, struct dentry___275 *, umode_t, bool);
	int (*link)(struct dentry___275 *, struct inode___275 *, struct dentry___275 *);
	int (*unlink)(struct inode___275 *, struct dentry___275 *);
	int (*symlink)(struct inode___275 *, struct dentry___275 *, const char *);
	int (*mkdir)(struct inode___275 *, struct dentry___275 *, umode_t);
	int (*rmdir)(struct inode___275 *, struct dentry___275 *);
	int (*mknod)(struct inode___275 *, struct dentry___275 *, umode_t, dev_t);
	int (*rename)(struct inode___275 *, struct dentry___275 *, struct inode___275 *, struct dentry___275 *);
	int (*setattr)(struct dentry___275 *, struct iattr___275 *);
	int (*getattr)(struct vfsmount *, struct dentry___275 *, struct kstat *);
	int (*setxattr)(struct dentry___275 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___275 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___275 *, char *, size_t);
	int (*removexattr)(struct dentry___275 *, const char *);
	int (*fiemap)(struct inode___275 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___275 *, struct timespec *, int);
	int (*atomic_open)(struct inode___275 *, struct dentry___275 *, struct file___275 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___161;

struct seq_file___200;

struct file_operations___275 {
	struct module___172 *owner;
	loff_t (*llseek)(struct file___275 *, loff_t, int);
	ssize_t (*read)(struct file___275 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___275 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___62 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___62 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___275 *, void *, filldir_t);
	unsigned int (*poll)(struct file___275 *, struct poll_table_struct___161 *);
	long int (*unlocked_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___275 *, struct vm_area_struct___283 *);
	int (*open)(struct inode___275 *, struct file___275 *);
	int (*flush)(struct file___275 *, fl_owner_t);
	int (*release)(struct inode___275 *, struct file___275 *);
	int (*fsync)(struct file___275 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___62 *, int);
	int (*fasync)(int, struct file___275 *, int);
	int (*lock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*sendpage)(struct file___275 *, struct page___274 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*splice_write)(struct pipe_inode_info___10 *, struct file___275 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___275 *, loff_t *, struct pipe_inode_info___10 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___275 *, long int, struct file_lock___275 **, void **);
		struct {
			int (*setlease)(struct file___275 *, long int, struct file_lock___275 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___275 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___200 *, struct file___275 *);
};

struct file_lock_operations___275;

struct lock_manager_operations___275;

struct file_lock___275 {
	struct file_lock___275 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___275 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___275 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___275 *fl_ops;
	const struct lock_manager_operations___275 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___275 {
	void (*fl_copy_lock)(struct file_lock___275 *, struct file_lock___275 *);
	void (*fl_release_private)(struct file_lock___275 *);
};

struct lock_manager_operations___275 {
	int (*lm_compare_owner)(struct file_lock___275 *, struct file_lock___275 *);
	long unsigned int (*lm_owner_key)(struct file_lock___275 *);
	void (*lm_notify)(struct file_lock___275 *);
	int (*lm_grant)(struct file_lock___275 *, struct file_lock___275 *, int);
	void (*lm_break)(struct file_lock___275 *);
	int (*lm_change)(struct file_lock___275 **, int);
};

struct fasync_struct___275 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___275 *fa_next;
	struct file___275 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___275 {
	const char *name;
	int fs_flags;
	struct dentry___275 * (*mount)(struct file_system_type___275 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___275 *);
	struct module___172 *owner;
	struct file_system_type___275 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___275 {
	struct inode___275 * (*alloc_inode)(struct super_block___275 *);
	void (*destroy_inode)(struct inode___275 *);
	void (*dirty_inode)(struct inode___275 *, int);
	int (*write_inode)(struct inode___275 *, struct writeback_control *);
	int (*drop_inode)(struct inode___275 *);
	void (*evict_inode)(struct inode___275 *);
	void (*put_super)(struct super_block___275 *);
	int (*sync_fs)(struct super_block___275 *, int);
	int (*freeze_fs)(struct super_block___275 *);
	int (*unfreeze_fs)(struct super_block___275 *);
	int (*statfs)(struct dentry___275 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___275 *, int *, char *);
	void (*umount_begin)(struct super_block___275 *);
	int (*show_options)(struct seq_file___200 *, struct dentry___275 *);
	int (*show_devname)(struct seq_file___200 *, struct dentry___275 *);
	int (*show_path)(struct seq_file___200 *, struct dentry___275 *);
	int (*show_stats)(struct seq_file___200 *, struct dentry___275 *);
	ssize_t (*quota_read)(struct super_block___275 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___275 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___275 *);
	int (*bdev_try_to_free_page)(struct super_block___275 *, struct page___274 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___275 *);
	void (*free_cached_objects)(struct super_block___275 *, int);
};

struct xattr_handler___171 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___275 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___275 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___275 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___163)(struct file___275 *, wait_queue_head_t *, struct poll_table_struct___161 *);

struct poll_table_struct___161 {
	poll_queue_proc___163 _qproc;
	long unsigned int _key;
};

struct seq_operations___200;

struct seq_file___200 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___277 lock;
	const struct seq_operations___200 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

typedef struct poll_table_struct___161 poll_table___41;

struct xol_area___274 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___274 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___257;

struct memcg_cache_params___258;

struct kmem_cache___258 {
	struct kmem_cache_cpu___257 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___57 kobj;
	struct memcg_cache_params___258 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___245;

struct vm_operations_struct___249 {
	void (*open)(struct vm_area_struct___283 *);
	void (*close)(struct vm_area_struct___283 *);
	int (*fault)(struct vm_area_struct___283 *, struct vm_fault___245 *);
	int (*page_mkwrite)(struct vm_area_struct___283 *, struct vm_fault___245 *);
	int (*access)(struct vm_area_struct___283 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___283 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___283 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___283 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___283 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___276 {
	struct task_struct___276 *task;
	struct core_thread___276 *next;
};

struct core_state___276 {
	atomic_t nr_threads;
	struct core_thread___276 dumper;
	struct completion startup;
};

struct socket_wq___54 {
	wait_queue_head_t wait;
	struct fasync_struct___275 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___54;

struct socket___55 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___54 *wq;
	struct file___275 *file;
	struct sock___55 *sk;
	const struct proto_ops___54 *ops;
};

struct proto_ops___54 {
	int family;
	struct module___172 *owner;
	int (*release)(struct socket___55 *);
	int (*bind)(struct socket___55 *, struct sockaddr *, int);
	int (*connect)(struct socket___55 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___55 *, struct socket___55 *);
	int (*accept)(struct socket___55 *, struct socket___55 *, int);
	int (*getname)(struct socket___55 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___275 *, struct socket___55 *, struct poll_table_struct___161 *);
	int (*ioctl)(struct socket___55 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___55 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___55 *, int);
	int (*shutdown)(struct socket___55 *, int);
	int (*setsockopt)(struct socket___55 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___55 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___55 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___55 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___62 *, struct socket___55 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___62 *, struct socket___55 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___275 *, struct socket___55 *, struct vm_area_struct___283 *);
	ssize_t (*sendpage)(struct socket___55 *, struct page___274 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___55 *, loff_t *, struct pipe_inode_info___10 *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___55 *, int);
		struct {
			void (*set_peek_off)(struct sock___55 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct netns_core___77 {
	struct ctl_table_header___80 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___78 {
	struct mutex___277 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___77 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___80 *ctl;
};

struct netns_ipv4___77 {
	struct ctl_table_header___80 *forw_hdr;
	struct ctl_table_header___80 *frags_hdr;
	struct ctl_table_header___80 *ipv4_hdr;
	struct ctl_table_header___80 *route_hdr;
	struct ctl_table_header___80 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___55 *fibnl;
	struct sock___55 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___77 {
	struct ctl_table_header___80 *hdr;
	struct ctl_table_header___80 *route_hdr;
	struct ctl_table_header___80 *icmp_hdr;
	struct ctl_table_header___80 *frags_hdr;
	struct ctl_table_header___80 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___65;

struct neighbour___55;

struct dst_ops___79 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___79 *);
	struct dst_entry___55 * (*check)(struct dst_entry___55 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___55 *);
	unsigned int (*mtu)(const struct dst_entry___55 *);
	u32 * (*cow_metrics)(struct dst_entry___55 *, long unsigned int);
	void (*destroy)(struct dst_entry___55 *);
	void (*ifdown)(struct dst_entry___55 *, struct net_device___65 *, int);
	struct dst_entry___55 * (*negative_advice)(struct dst_entry___55 *);
	void (*link_failure)(struct sk_buff___68 *);
	void (*update_pmtu)(struct dst_entry___55 *, struct sock___55 *, struct sk_buff___68 *, u32);
	void (*redirect)(struct dst_entry___55 *, struct sock___55 *, struct sk_buff___68 *);
	int (*local_out)(struct sk_buff___68 *);
	struct neighbour___55 * (*neigh_lookup)(const struct dst_entry___55 *, struct sk_buff___68 *, const void *);
	struct kmem_cache___258 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___11;

struct fib6_table___11;

struct netns_ipv6___79 {
	struct netns_sysctl_ipv6___77 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___11 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___11 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___79 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___11 *ip6_prohibit_entry;
	struct rt6_info___11 *ip6_blk_hole_entry;
	struct fib6_table___11 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___55 **icmp_sk;
	struct sock___55 *ndisc_sk;
	struct sock___55 *tcp_sk;
	struct sock___55 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___77 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___80 *sysctl_header;
	struct sock___55 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___54 {
	struct sock___55 *v4_ctl_sk;
	struct sock___55 *v6_ctl_sk;
};

struct netns_nf___77 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___80 *nf_log_dir_header;
};

struct nf_proto_net___77 {
	struct ctl_table_header___80 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___77 {
	struct nf_proto_net___77 pn;
	unsigned int timeout;
};

struct nf_tcp_net___77 {
	struct nf_proto_net___77 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___77 {
	struct nf_proto_net___77 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___77 {
	struct nf_proto_net___77 pn;
	unsigned int timeout;
};

struct nf_ip_net___77 {
	struct nf_generic_net___77 generic;
	struct nf_tcp_net___77 tcp;
	struct nf_udp_net___77 udp;
	struct nf_icmp_net___77 icmp;
	struct nf_icmp_net___77 icmpv6;
};

struct netns_ct___78 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___80 *sysctl_header;
	struct ctl_table_header___80 *acct_sysctl_header;
	struct ctl_table_header___80 *tstamp_sysctl_header;
	struct ctl_table_header___80 *event_sysctl_header;
	struct ctl_table_header___80 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___258 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___77 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___77 {
	struct netns_sysctl_ipv6___77 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___79 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___55 *nlsk;
	struct sock___55 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___80 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___79 xfrm4_dst_ops;
	struct dst_ops___79 xfrm6_dst_ops;
};

struct net___79 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___80 sysctls;
	struct sock___55 *rtnl;
	struct sock___55 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___65 *loopback_dev;
	struct netns_core___77 core;
	struct netns_mib mib;
	struct netns_packet___78 packet;
	struct netns_unix___77 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___77 ipv4;
	struct netns_ipv6___79 ipv6;
	struct netns_sctp___77 sctp;
	struct netns_dccp___54 dccp;
	struct netns_nf___77 nf;
	struct netns_xt xt;
	struct netns_ct___78 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___77 nf_frag;
	struct sock___55 *nfnl;
	struct sock___55 *nfnl_stash;
	struct sk_buff_head___66 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___79 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___55 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___55 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___277 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___277 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___257 {
	void **freelist;
	long unsigned int tid;
	struct page___274 *page;
	struct page___274 *partial;
};

struct memcg_cache_params___258 {
	bool is_root_cache;
	union {
		struct kmem_cache___258 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___258 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___138 {
	void * (*alloc)(struct device___273 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___273 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___273 *, struct vm_area_struct___283 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___273 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___273 *, struct page___274 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___273 *, dma_addr_t);
	int (*dma_supported)(struct device___273 *, u64);
	int (*set_dma_mask)(struct device___273 *, u64);
	int is_phys;
};

struct bus_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___273 *, char *);
	ssize_t (*store)(struct bus_type___273 *, const char *, size_t);
};

struct device_attribute___273;

struct driver_attribute___273;

struct bus_type___273 {
	const char *name;
	const char *dev_name;
	struct device___273 *dev_root;
	struct bus_attribute___273 *bus_attrs;
	struct device_attribute___273 *dev_attrs;
	struct driver_attribute___273 *drv_attrs;
	const struct attribute_group___235 **bus_groups;
	const struct attribute_group___235 **dev_groups;
	const struct attribute_group___235 **drv_groups;
	int (*match)(struct device___273 *, struct device_driver___273 *);
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	int (*probe)(struct device___273 *);
	int (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*online)(struct device___273 *);
	int (*offline)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct device___273 *, struct device_attribute___273 *, char *);
	ssize_t (*store)(struct device___273 *, struct device_attribute___273 *, const char *, size_t);
};

struct driver_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___273 *, char *);
	ssize_t (*store)(struct device_driver___273 *, const char *, size_t);
};

struct device_driver___273 {
	const char *name;
	struct bus_type___273 *bus;
	struct module___172 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___273 *);
	int (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	const struct attribute_group___235 **groups;
	const struct dev_pm_ops___273 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___273 {
	const char *name;
	const struct attribute_group___235 **groups;
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
};

struct class_attribute___273;

struct class___273 {
	const char *name;
	struct module___172 *owner;
	struct class_attribute___273 *class_attrs;
	struct device_attribute___273 *dev_attrs;
	const struct attribute_group___235 **dev_groups;
	struct bin_attribute___237 *dev_bin_attrs;
	struct kobject___57 *dev_kobj;
	int (*dev_uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *);
	void (*class_release)(struct class___273 *);
	void (*dev_release)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	const struct kobj_ns_type_operations___54 *ns_type;
	const void * (*namespace)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
	struct subsys_private *p;
};

struct class_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct class___273 *, struct class_attribute___273 *, char *);
	ssize_t (*store)(struct class___273 *, struct class_attribute___273 *, const char *, size_t);
	const void * (*namespace)(struct class___273 *, const struct class_attribute___273 *);
};

struct device_rh___273 {
	struct dev_pm_info_rh___273 power;
};

struct vm_fault___245 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___274 *page;
};

struct dma_device___8;

struct dma_chan_dev___8;

struct dma_chan___9 {
	struct dma_device___8 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___8 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___8;

struct dma_device___8 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___273 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___9 *);
	void (*device_free_chan_resources)(struct dma_chan___9 *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memcpy)(struct dma_chan___9 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor)(struct dma_chan___9 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor_val)(struct dma_chan___9 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq_val)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memset)(struct dma_chan___9 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_interrupt)(struct dma_chan___9 *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_slave_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_cyclic)(struct dma_chan___9 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___8 * (*device_prep_interleaved_dma)(struct dma_chan___9 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___9 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___9 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___9 *);
};

struct dma_chan_dev___8 {
	struct dma_chan___9 *chan;
	struct device___273 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___8 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___9 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___8 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___3 {
	char *base_address;
	int nr_pages;
	struct page___274 **pages;
};

struct dma_pinned_list___3 {
	int nr_iovecs;
	struct dma_page_list___3 page_list[0];
};

struct signal_struct___276 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___276 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___276 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___277 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___170 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___170 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___65 {
	atomic_t use;
	unsigned int mask;
	struct net_device___65 *physindev;
	struct net_device___65 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___65(struct sk_buff___68 **);

struct net_device_ops___65;

struct ethtool_ops___65;

struct header_ops___65;

struct inet6_dev___31;

struct netdev_rx_queue___65;

struct netdev_queue___65;

struct rtnl_link_ops___56;

struct dcbnl_rtnl_ops___65;

struct net_device___65 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___65 *netdev_ops;
	const struct ethtool_ops___65 *ethtool_ops;
	const struct header_ops___65 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___57 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___31 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___65 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___65 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___65 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___65 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___65 = 0,
		NETREG_REGISTERED___65 = 1,
		NETREG_UNREGISTERING___65 = 2,
		NETREG_UNREGISTERED___65 = 3,
		NETREG_RELEASED___65 = 4,
		NETREG_DUMMY___65 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___65 = 0,
		RTNL_LINK_INITIALIZING___65 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___65 *);
	struct netpoll_info *npinfo;
	struct net___79 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___273 dev;
	const struct attribute_group___235 *sysfs_groups[4];
	const struct rtnl_link_ops___56 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___65 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___11;

struct sk_buff___68 {
	struct sk_buff___68 *next;
	struct sk_buff___68 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___55 *sk;
	struct net_device___65 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___11 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___68 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___65 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___15 {
	struct {
		struct page___274 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___15 skb_frag_t___15;

struct skb_shared_info___15 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___68 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___15 frags[17];
};

struct xfrm_state___11;

struct sec_path___11 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___11 *xvec[6];
};

struct pipe_buf_operations___10;

struct pipe_buffer___10 {
	struct page___274 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___10 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___10 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *, int);
	void (*unmap)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *, void *);
	int (*confirm)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	void (*release)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	int (*steal)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	void (*get)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
};

struct splice_pipe_desc___5 {
	struct page___274 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___10 *ops;
	void (*spd_release)(struct splice_pipe_desc___5 *, unsigned int);
};

struct irq_chip___199 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___199 *);
	void (*irq_shutdown)(struct irq_data___199 *);
	void (*irq_enable)(struct irq_data___199 *);
	void (*irq_disable)(struct irq_data___199 *);
	void (*irq_ack)(struct irq_data___199 *);
	void (*irq_mask)(struct irq_data___199 *);
	void (*irq_mask_ack)(struct irq_data___199 *);
	void (*irq_unmask)(struct irq_data___199 *);
	void (*irq_eoi)(struct irq_data___199 *);
	int (*irq_set_affinity)(struct irq_data___199 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___199 *);
	int (*irq_set_type)(struct irq_data___199 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___199 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___199 *);
	void (*irq_bus_sync_unlock)(struct irq_data___199 *);
	void (*irq_cpu_online)(struct irq_data___199 *);
	void (*irq_cpu_offline)(struct irq_data___199 *);
	void (*irq_suspend)(struct irq_data___199 *);
	void (*irq_resume)(struct irq_data___199 *);
	void (*irq_pm_shutdown)(struct irq_data___199 *);
	void (*irq_print_chip)(struct irq_data___199 *, struct seq_file___200 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___199 *, void *);
	long unsigned int flags;
};

struct cgroupfs_root___170;

struct cgroup___170 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___170 *parent;
	struct dentry___275 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___170 *subsys[11];
	struct cgroupfs_root___170 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___277 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___170 {
	struct super_block___275 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___170 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___106 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___275 *, struct file___275 *);
	ssize_t (*read)(struct cgroup___170 *, struct cftype___106 *, struct file___275 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___170 *, struct cftype___106 *);
	s64 (*read_s64)(struct cgroup___170 *, struct cftype___106 *);
	int (*read_map)(struct cgroup___170 *, struct cftype___106 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___170 *, struct cftype___106 *, struct seq_file___200 *);
	ssize_t (*write)(struct cgroup___170 *, struct cftype___106 *, struct file___275 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___170 *, struct cftype___106 *, u64);
	int (*write_s64)(struct cgroup___170 *, struct cftype___106 *, s64);
	int (*write_string)(struct cgroup___170 *, struct cftype___106 *, const char *);
	int (*trigger)(struct cgroup___170 *, unsigned int);
	int (*release)(struct inode___275 *, struct file___275 *);
	int (*register_event)(struct cgroup___170 *, struct cftype___106 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___170 *, struct cftype___106 *, struct eventfd_ctx *);
};

struct cftype_set___102 {
	struct list_head node;
	struct cftype___106 *cfts;
};

struct task_and_cgroup___102 {
	struct task_struct___276 *task;
	struct cgroup___170 *cgrp;
	struct css_set___170 *cg;
};

struct cgroup_taskset___102 {
	struct task_and_cgroup___102 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___170 *cur_cgrp;
};

struct cgroup_subsys___102 {
	struct cgroup_subsys_state___170 * (*css_alloc)(struct cgroup___170 *);
	int (*css_online)(struct cgroup___170 *);
	void (*css_offline)(struct cgroup___170 *);
	void (*css_free)(struct cgroup___170 *);
	int (*can_attach)(struct cgroup___170 *, struct cgroup_taskset___102 *);
	void (*cancel_attach)(struct cgroup___170 *, struct cgroup_taskset___102 *);
	void (*attach)(struct cgroup___170 *, struct cgroup_taskset___102 *);
	void (*fork)(struct task_struct___276 *);
	void (*exit)(struct cgroup___170 *, struct cgroup___170 *, struct task_struct___276 *);
	void (*bind)(struct cgroup___170 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___170 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___106 *base_cftypes;
	struct cftype_set___102 base_cftset;
	struct module___172 *module;
};

struct crypto_async_request___11;

typedef void (*crypto_completion_t___11)(struct crypto_async_request___11 *, int);

struct crypto_tfm___11;

struct crypto_async_request___11 {
	struct list_head list;
	crypto_completion_t___11 complete;
	void *data;
	struct crypto_tfm___11 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___11;

struct ablkcipher_request___11;

struct ablkcipher_tfm___11 {
	int (*setkey)(struct crypto_ablkcipher___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___11 *);
	int (*decrypt)(struct ablkcipher_request___11 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___11 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___11;

struct aead_request___11;

struct aead_tfm___11 {
	int (*setkey)(struct crypto_aead___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___11 *);
	int (*decrypt)(struct aead_request___11 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___11 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___11;

struct blkcipher_tfm___11 {
	void *iv;
	int (*setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___11 {
	int (*cit_setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___11 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___11 *, u8 *, const u8 *);
};

struct hash_desc___11;

struct crypto_hash___11;

struct hash_tfm___11 {
	int (*init)(struct hash_desc___11 *);
	int (*update)(struct hash_desc___11 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___11 *, u8 *);
	int (*digest)(struct hash_desc___11 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___11 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___11 {
	int (*cot_compress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___11;

struct rng_tfm___11 {
	int (*rng_gen_random)(struct crypto_rng___11 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___11 *, u8 *, unsigned int);
};

struct crypto_alg___11;

struct crypto_tfm___11 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___11 ablkcipher;
		struct aead_tfm___11 aead;
		struct blkcipher_tfm___11 blkcipher;
		struct cipher_tfm___11 cipher;
		struct hash_tfm___11 hash;
		struct compress_tfm___11 compress;
		struct rng_tfm___11 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___11 *);
	struct crypto_alg___11 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___11 {
	struct crypto_async_request___11 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___11 {
	struct crypto_async_request___11 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___11;

struct blkcipher_desc___11 {
	struct crypto_blkcipher___11 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___11 {
	struct crypto_tfm___11 base;
};

struct hash_desc___11 {
	struct crypto_hash___11 *tfm;
	u32 flags;
};

struct crypto_hash___11 {
	struct crypto_tfm___11 base;
};

struct ablkcipher_alg___11 {
	int (*setkey)(struct crypto_ablkcipher___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___11 *);
	int (*decrypt)(struct ablkcipher_request___11 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___11 {
	struct crypto_tfm___11 base;
};

struct aead_alg___11 {
	int (*setkey)(struct crypto_aead___11 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___11 *, unsigned int);
	int (*encrypt)(struct aead_request___11 *);
	int (*decrypt)(struct aead_request___11 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___11 {
	struct crypto_tfm___11 base;
};

struct blkcipher_alg___11 {
	int (*setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___11 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
};

struct compress_alg___11 {
	int (*coa_compress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___11 {
	int (*rng_make_random)(struct crypto_rng___11 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___11 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___11 {
	struct crypto_tfm___11 base;
};

struct crypto_alg___11 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___11 ablkcipher;
		struct aead_alg___11 aead;
		struct blkcipher_alg___11 blkcipher;
		struct cipher_alg___11 cipher;
		struct compress_alg___11 compress;
		struct rng_alg___11 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___11 *);
	void (*cra_exit)(struct crypto_tfm___11 *);
	void (*cra_destroy)(struct crypto_alg___11 *);
	struct module___172 *cra_module;
};

struct dev_pm_qos_request___77 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___273 *dev;
};

struct ethtool_ops___65 {
	int (*get_settings)(struct net_device___65 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___65 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___65 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___65 *);
	void (*get_regs)(struct net_device___65 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___65 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___65 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___65 *);
	void (*set_msglevel)(struct net_device___65 *, u32);
	int (*nway_reset)(struct net_device___65 *);
	u32 (*get_link)(struct net_device___65 *);
	int (*get_eeprom_len)(struct net_device___65 *);
	int (*get_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___65 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___65 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___65 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___65 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___65 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___65 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___65 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___65 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___65 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___65 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___65 *);
	void (*complete)(struct net_device___65 *);
	u32 (*get_priv_flags)(struct net_device___65 *);
	int (*set_priv_flags)(struct net_device___65 *, u32);
	int (*get_sset_count)(struct net_device___65 *, int);
	int (*get_rxnfc)(struct net_device___65 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___65 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___65 *, struct ethtool_flash *);
	int (*reset)(struct net_device___65 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___65 *);
	int (*get_rxfh_indir)(struct net_device___65 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___65 *, const u32 *);
	void (*get_channels)(struct net_device___65 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___65 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___65 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___65 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___65 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___65 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___65 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___65 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___65 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___65 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___65 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___65 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	TCP_MIB_NUM = 0,
	TCP_MIB_RTOALGORITHM = 1,
	TCP_MIB_RTOMIN = 2,
	TCP_MIB_RTOMAX = 3,
	TCP_MIB_MAXCONN = 4,
	TCP_MIB_ACTIVEOPENS = 5,
	TCP_MIB_PASSIVEOPENS = 6,
	TCP_MIB_ATTEMPTFAILS = 7,
	TCP_MIB_ESTABRESETS = 8,
	TCP_MIB_CURRESTAB = 9,
	TCP_MIB_INSEGS = 10,
	TCP_MIB_OUTSEGS = 11,
	TCP_MIB_RETRANSSEGS = 12,
	TCP_MIB_INERRS = 13,
	TCP_MIB_OUTRSTS = 14,
	TCP_MIB_CSUMERRORS = 15,
	__TCP_MIB_MAX = 16,
};

struct rtable___26;

struct dst_entry___55 {
	struct callback_head callback_head;
	struct dst_entry___55 *child;
	struct net_device___65 *dev;
	struct dst_ops___79 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___55 *path;
	struct dst_entry___55 *from;
	struct xfrm_state___11 *xfrm;
	int (*input)(struct sk_buff___68 *);
	union {
		int (*output)(struct sock___55 *, struct sk_buff___68 *);
		struct {
			int (*output)(struct sk_buff___68 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___55 *next;
		struct rtable___26 *rt_next;
		struct rt6_info___11 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___55;

struct neigh_parms___55;

struct neigh_ops___55;

struct neighbour___55 {
	struct neighbour___55 *next;
	struct neigh_table___55 *tbl;
	struct neigh_parms___55 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___66 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___55 *, struct sk_buff___68 *);
	const struct neigh_ops___55 *ops;
	struct callback_head rcu;
	struct net_device___65 *dev;
	u8 primary_key[0];
};

struct fib6_node___11;

struct rt6_info___11 {
	struct dst_entry___55 dst;
	struct fib6_table___11 *rt6i_table;
	struct fib6_node___11 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___31 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___11 {
	struct fib6_node___11 *parent;
	struct fib6_node___11 *left;
	struct fib6_node___11 *right;
	struct rt6_info___11 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___11 *rr_ptr;
};

struct fib6_table___11 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___11 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___79 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___68 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___68 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___79 *, struct dst_entry___55 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___68 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___68 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___200 {
	void * (*start)(struct seq_file___200 *, loff_t *);
	void (*stop)(struct seq_file___200 *, void *);
	void * (*next)(struct seq_file___200 *, void *, loff_t *);
	int (*show)(struct seq_file___200 *, void *);
};

struct dcbnl_rtnl_ops___65 {
	int (*ieee_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___65 *);
	u8 (*setstate)(struct net_device___65 *, u8);
	void (*getpermhwaddr)(struct net_device___65 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___65 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___65 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___65 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___65 *, int, u8 *);
	void (*setpfccfg)(struct net_device___65 *, int, u8);
	void (*getpfccfg)(struct net_device___65 *, int, u8 *);
	u8 (*setall)(struct net_device___65 *);
	u8 (*getcap)(struct net_device___65 *, int, u8 *);
	int (*getnumtcs)(struct net_device___65 *, int, u8 *);
	int (*setnumtcs)(struct net_device___65 *, int, u8);
	u8 (*getpfcstate)(struct net_device___65 *);
	void (*setpfcstate)(struct net_device___65 *, u8);
	void (*getbcncfg)(struct net_device___65 *, int, u32 *);
	void (*setbcncfg)(struct net_device___65 *, int, u32);
	void (*getbcnrp)(struct net_device___65 *, int, u8 *);
	void (*setbcnrp)(struct net_device___65 *, int, u8);
	u8 (*setapp)(struct net_device___65 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___65 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___65 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___65 *, int, u8);
	u8 (*getdcbx)(struct net_device___65 *);
	u8 (*setdcbx)(struct net_device___65 *, u8);
	int (*peer_getappinfo)(struct net_device___65 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___65 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___65 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___65 *, struct cee_pfc *);
};

struct request_sock_ops___40;

struct request_sock___41 {
	struct sock_common___54 __req_common;
	struct request_sock___41 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___40 *rsk_ops;
	struct sock___55 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___11;

struct xfrm_type___11;

struct xfrm_mode___11;

struct xfrm_state___11 {
	struct net___79 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___11 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___11 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___11 *type;
	struct xfrm_mode___11 *inner_mode;
	struct xfrm_mode___11 *inner_mode_iaf;
	struct xfrm_mode___11 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___11 {
	struct sk_buff_head___66 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___11 {
	struct net___79 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___11 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___67 {
	struct sk_buff___68 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___68 *, struct netlink_callback___67 *);
	int (*done)(struct netlink_callback___67 *);
	void *data;
	struct module___172 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___65 {
	int (*create)(struct sk_buff___68 *, struct net_device___65 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___68 *, unsigned char *);
	int (*rebuild)(struct sk_buff___68 *);
	int (*cache)(const struct neighbour___55 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___65 *, const unsigned char *);
};

struct napi_struct___65 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___65 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___65 *dev;
	struct sk_buff___68 *gro_list;
	struct sk_buff___68 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___65 {
	struct net_device___65 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___57 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___65 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___57 kobj;
	struct net_device___65 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___65 {
	int (*ndo_init)(struct net_device___65 *);
	void (*ndo_uninit)(struct net_device___65 *);
	int (*ndo_open)(struct net_device___65 *);
	int (*ndo_stop)(struct net_device___65 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___68 *, struct net_device___65 *);
	u16 (*ndo_select_queue)(struct net_device___65 *, struct sk_buff___68 *);
	void (*ndo_change_rx_flags)(struct net_device___65 *, int);
	void (*ndo_set_rx_mode)(struct net_device___65 *);
	int (*ndo_set_mac_address)(struct net_device___65 *, void *);
	int (*ndo_validate_addr)(struct net_device___65 *);
	int (*ndo_do_ioctl)(struct net_device___65 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___65 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___65 *, int);
	int (*ndo_neigh_setup)(struct net_device___65 *, struct neigh_parms___55 *);
	void (*ndo_tx_timeout)(struct net_device___65 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___65 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___65 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___65 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___65 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___65 *);
	int (*ndo_netpoll_setup)(struct net_device___65 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___65 *);
	int (*ndo_busy_poll)(struct napi_struct___65 *);
	int (*ndo_set_vf_mac)(struct net_device___65 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___65 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___65 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___65 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___65 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___65 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___65 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___65 *, int, struct sk_buff___68 *);
	int (*ndo_setup_tc)(struct net_device___65 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___65 *);
	int (*ndo_fcoe_disable)(struct net_device___65 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___65 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___65 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___65 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___65 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___65 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___65 *, const struct sk_buff___68 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___65 *, struct net_device___65 *);
	int (*ndo_del_slave)(struct net_device___65 *, struct net_device___65 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___55 *);
	void (*ndo_neigh_destroy)(struct neighbour___55 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___68 *, struct netlink_callback___67 *, struct net_device___65 *, int);
	int (*ndo_bridge_setlink)(struct net_device___65 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___68 *, u32, u32, struct net_device___65 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___65 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___65 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___65 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___65 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___65 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___65 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___68 *, struct net_device___65 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___65 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___65 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___65 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___55 {
	struct net___79 *net;
	struct net_device___65 *dev;
	struct neigh_parms___55 *next;
	int (*neigh_setup)(struct neighbour___55 *);
	void (*neigh_cleanup)(struct neighbour___55 *);
	struct neigh_table___55 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___31;

struct ifacaddr6___31;

struct inet6_dev___31 {
	struct net_device___65 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___31 *mc_list;
	struct ifmcaddr6___31 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___31 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___55 *nd_parms;
	struct inet6_dev___31 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___56 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___65 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___79 *, struct net_device___65 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___65 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___65 *, struct list_head *);
	size_t (*get_size)(const struct net_device___65 *);
	int (*fill_info)(struct sk_buff___68 *, const struct net_device___65 *);
	size_t (*get_xstats_size)(const struct net_device___65 *);
	int (*fill_xstats)(struct sk_buff___68 *, const struct net_device___65 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___79 * (*get_link_net)(const struct net_device___65 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___65 *, struct net_device___65 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___65 *, const struct net_device___65 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___68 *, const struct net_device___65 *, const struct net_device___65 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___55 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___68 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___55;

struct neigh_hash_table___55;

struct neigh_table___55 {
	struct neigh_table___55 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___65 *, __u32 *);
	int (*constructor)(struct neighbour___55 *);
	int (*pconstructor)(struct pneigh_entry___55 *);
	void (*pdestructor)(struct pneigh_entry___55 *);
	void (*proxy_redo)(struct sk_buff___68 *);
	char *id;
	struct neigh_parms___55 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___66 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___55 *nht;
	struct pneigh_entry___55 **phash_buckets;
};

struct neigh_ops___55 {
	int family;
	void (*solicit)(struct neighbour___55 *, struct sk_buff___68 *);
	void (*error_report)(struct neighbour___55 *, struct sk_buff___68 *);
	int (*output)(struct neighbour___55 *, struct sk_buff___68 *);
	int (*connected_output)(struct neighbour___55 *, struct sk_buff___68 *);
};

struct pneigh_entry___55 {
	struct pneigh_entry___55 *next;
	struct net___79 *net;
	struct net_device___65 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___55 {
	struct neighbour___55 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___26 {
	struct dst_entry___55 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___37;

struct inet_hashinfo___11;

struct proto___54 {
	void (*close)(struct sock___55 *, long int);
	int (*connect)(struct sock___55 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___55 *, int);
	struct sock___55 * (*accept)(struct sock___55 *, int, int *);
	int (*ioctl)(struct sock___55 *, int, long unsigned int);
	int (*init)(struct sock___55 *);
	void (*destroy)(struct sock___55 *);
	void (*shutdown)(struct sock___55 *, int);
	int (*setsockopt)(struct sock___55 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___55 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___55 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___55 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___55 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___62 *, struct sock___55 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___62 *, struct sock___55 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___55 *, struct page___274 *, int, size_t, int);
	int (*bind)(struct sock___55 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___55 *, struct sk_buff___68 *);
	void (*release_cb)(struct sock___55 *);
	void (*mtu_reduced)(struct sock___55 *);
	void (*hash)(struct sock___55 *);
	void (*unhash)(struct sock___55 *);
	void (*rehash)(struct sock___55 *);
	int (*get_port)(struct sock___55 *, short unsigned int);
	void (*clear_sk)(struct sock___55 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___55 *);
	void (*enter_memory_pressure)(struct sock___55 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___258 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___40 *rsk_prot;
	struct timewait_sock_ops___37 *twsk_prot;
	union {
		struct inet_hashinfo___11 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___172 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___102 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___54 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___54 {
	void (*enter_memory_pressure)(struct sock___55 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___11 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___258 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___40 {
	int family;
	int obj_size;
	struct kmem_cache___258 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___55 *, struct request_sock___41 *);
	void (*send_ack)(struct sock___55 *, struct sk_buff___68 *, struct request_sock___41 *);
	void (*send_reset)(struct sock___55 *, struct sk_buff___68 *);
	void (*destructor)(struct request_sock___41 *);
	void (*syn_ack_timeout)(struct sock___55 *, struct request_sock___41 *);
};

struct timewait_sock_ops___37 {
	struct kmem_cache___258 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___55 *, struct sock___55 *, void *);
	void (*twsk_destructor)(struct sock___55 *);
};

struct listen_sock___6 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___41 *syn_table[0];
};

struct fastopen_queue___6 {
	struct request_sock___41 *rskq_rst_head;
	struct request_sock___41 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___6 {
	struct request_sock___41 *rskq_accept_head;
	struct request_sock___41 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___6 *listen_opt;
	struct fastopen_queue___6 *fastopenq;
};

struct inet_cork___12 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___55 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___12 {
	struct inet_cork___12 base;
	struct flowi fl;
};

struct ipv6_pinfo___11;

struct inet_sock___12 {
	struct sock___55 sk;
	struct ipv6_pinfo___11 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___12 cork;
};

struct ipv6_fl_socklist___10;

struct ipv6_pinfo___11 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___10 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___68 *pktoptions;
	struct sk_buff___68 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___6;

struct inet_connection_sock_af_ops___6 {
	int (*queue_xmit)(struct sk_buff___68 *, struct flowi *);
	void (*send_check)(struct sock___55 *, struct sk_buff___68 *);
	int (*rebuild_header)(struct sock___55 *);
	void (*sk_rx_dst_set)(struct sock___55 *, const struct sk_buff___68 *);
	int (*conn_request)(struct sock___55 *, struct sk_buff___68 *);
	struct sock___55 * (*syn_recv_sock)(struct sock___55 *, struct sk_buff___68 *, struct request_sock___41 *, struct dst_entry___55 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___55 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___55 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___55 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___55 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___55 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___55 *, const struct inet_bind_bucket___6 *, bool);
	void (*mtu_reduced)(struct sock___55 *);
};

struct inet_bind_bucket___6 {
	struct net___79 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___2;

struct inet_connection_sock___6 {
	struct inet_sock___12 icsk_inet;
	struct request_sock_queue___6 icsk_accept_queue;
	struct inet_bind_bucket___6 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___2 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___6 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___55 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___2 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___55 *);
	void (*release)(struct sock___55 *);
	u32 (*ssthresh)(struct sock___55 *);
	void (*cong_avoid)(struct sock___55 *, u32, u32);
	void (*set_state)(struct sock___55 *, u8);
	void (*cwnd_event)(struct sock___55 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___55 *, u32);
	u32 (*undo_cwnd)(struct sock___55 *);
	void (*pkts_acked)(struct sock___55 *, u32, s32);
	int (*get_info)(struct sock___55 *, u32, struct sk_buff___68 *);
	char name[16];
	struct module___172 *owner;
};

enum inet_csk_ack_state_t {
	ICSK_ACK_SCHED = 1,
	ICSK_ACK_TIMER = 2,
	ICSK_ACK_PUSHED = 4,
	ICSK_ACK_PUSHED2 = 8,
};

struct inet_timewait_death_row___3 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___11 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

enum {
	TCP_FLAG_CWR = 32768,
	TCP_FLAG_ECE = 16384,
	TCP_FLAG_URG = 8192,
	TCP_FLAG_ACK = 4096,
	TCP_FLAG_PSH = 2048,
	TCP_FLAG_RST = 1024,
	TCP_FLAG_SYN = 512,
	TCP_FLAG_FIN = 256,
	TCP_RESERVED_BITS = 15,
	TCP_DATA_OFFSET = 240,
};

struct tcp_repair_opt {
	__u32 opt_code;
	__u32 opt_val;
};

enum {
	TCP_NO_QUEUE = 0,
	TCP_RECV_QUEUE = 1,
	TCP_SEND_QUEUE = 2,
	TCP_QUEUES_NR = 3,
};

enum tcp_ca_state {
	TCP_CA_Open = 0,
	TCP_CA_Disorder = 1,
	TCP_CA_CWR = 2,
	TCP_CA_Recovery = 3,
	TCP_CA_Loss = 4,
};

struct tcp_info {
	__u8 tcpi_state;
	__u8 tcpi_ca_state;
	__u8 tcpi_retransmits;
	__u8 tcpi_probes;
	__u8 tcpi_backoff;
	__u8 tcpi_options;
	__u8 tcpi_snd_wscale: 4;
	__u8 tcpi_rcv_wscale: 4;
	__u32 tcpi_rto;
	__u32 tcpi_ato;
	__u32 tcpi_snd_mss;
	__u32 tcpi_rcv_mss;
	__u32 tcpi_unacked;
	__u32 tcpi_sacked;
	__u32 tcpi_lost;
	__u32 tcpi_retrans;
	__u32 tcpi_fackets;
	__u32 tcpi_last_data_sent;
	__u32 tcpi_last_ack_sent;
	__u32 tcpi_last_data_recv;
	__u32 tcpi_last_ack_recv;
	__u32 tcpi_pmtu;
	__u32 tcpi_rcv_ssthresh;
	__u32 tcpi_rtt;
	__u32 tcpi_rttvar;
	__u32 tcpi_snd_ssthresh;
	__u32 tcpi_snd_cwnd;
	__u32 tcpi_advmss;
	__u32 tcpi_reordering;
	__u32 tcpi_rcv_rtt;
	__u32 tcpi_rcv_space;
	__u32 tcpi_total_retrans;
	__u64 tcpi_pacing_rate;
	__u64 tcpi_max_pacing_rate;
};

struct tcp_fastopen_cookie {
	s8 len;
	u8 val[16];
	bool exp;
};

struct tcp_sock_af_ops___2;

struct tcp_md5sig_info___2;

struct tcp_fastopen_request___2;

struct tcp_sock___3 {
	struct inet_connection_sock___6 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___66 prequeue;
		struct task_struct___276 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___9 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___3 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___68 *lost_skb_hint;
	struct sk_buff___68 *retransmit_skb_hint;
	struct sk_buff_head___66 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___68 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___2 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___41 *fastopen_rsk;
};

struct tcp_md5sig_key;

struct tcp_sock_af_ops___2 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___55 *, struct sock___55 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___55 *, const struct request_sock___41 *, const struct sk_buff___68 *);
	int (*md5_parse)(struct sock___55 *, char *, int);
};

struct tcp_md5sig_info___2 {
	struct hlist_head head;
	struct callback_head rcu;
};

struct tcp_fastopen_request___2 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr *data;
	size_t size;
	int copied;
};

enum tsq_flags {
	TSQ_THROTTLED = 0,
	TSQ_QUEUED = 1,
	TCP_TSQ_DEFERRED = 2,
	TCP_WRITE_TIMER_DEFERRED = 3,
	TCP_DELACK_TIMER_DEFERRED = 4,
	TCP_MTU_REDUCED_DEFERRED = 5,
};

union tcp_md5_addr {
	struct in_addr a4;
	struct in6_addr a6;
};

struct tcp_md5sig_key {
	struct hlist_node node;
	u8 keylen;
	u8 family;
	union tcp_md5_addr addr;
	u8 key[80];
	struct callback_head rcu;
};

struct ip6_flowlabel___10;

struct ipv6_fl_socklist___10 {
	struct ipv6_fl_socklist___10 *next;
	struct ip6_flowlabel___10 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___31 {
	struct in6_addr mca_addr;
	struct inet6_dev___31 *idev;
	struct ifmcaddr6___31 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___31 {
	struct in6_addr aca_addr;
	struct inet6_dev___31 *aca_idev;
	struct rt6_info___11 *aca_rt;
	struct ifacaddr6___31 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___10 {
	struct ip6_flowlabel___10 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___79 *fl_net;
};

typedef int (*sk_read_actor_t)(read_descriptor_t *, struct sk_buff___68 *, unsigned int, size_t);

struct tcp_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	__u32 seq;
	__u32 end_seq;
	__u32 tcp_tw_isn;
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u32 ack_seq;
};

struct tcp4_pseudohdr {
	__be32 saddr;
	__be32 daddr;
	__u8 pad;
	__u8 protocol;
	__be16 len;
};

struct tcp6_pseudohdr {
	struct in6_addr saddr;
	struct in6_addr daddr;
	__be32 len;
	__be32 protocol;
};

union tcp_md5sum_block {
	struct tcp4_pseudohdr ip4;
	struct tcp6_pseudohdr ip6;
};

struct tcp_md5sig_pool {
	struct hash_desc___11 md5_desc;
	union tcp_md5sum_block md5_blk;
};

struct xfrm_replay___11 {
	void (*advance)(struct xfrm_state___11 *, __be32);
	int (*check)(struct xfrm_state___11 *, struct sk_buff___68 *, __be32);
	int (*recheck)(struct xfrm_state___11 *, struct sk_buff___68 *, __be32);
	void (*notify)(struct xfrm_state___11 *, int);
	int (*overflow)(struct xfrm_state___11 *, struct sk_buff___68 *);
};

struct xfrm_type___11 {
	char *description;
	struct module___172 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___11 *);
	void (*destructor)(struct xfrm_state___11 *);
	int (*input)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*output)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*reject)(struct xfrm_state___11 *, struct sk_buff___68 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___11 *, struct sk_buff___68 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___11 *, int);
};

struct xfrm_state_afinfo___11;

struct xfrm_mode___11 {
	int (*input2)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*input)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*output2)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*output)(struct xfrm_state___11 *, struct sk_buff___68 *);
	struct xfrm_state_afinfo___11 *afinfo;
	struct module___172 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___11 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___172 *owner;
	const struct xfrm_type___11 *type_map[256];
	struct xfrm_mode___11 *mode_map[5];
	int (*init_flags)(struct xfrm_state___11 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___11 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___11 **, struct xfrm_state___11 **, int);
	union {
		int (*output)(struct sock___55 *, struct sk_buff___68 *);
		struct {
			int (*output)(struct sk_buff___68 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___55 *, struct sk_buff___68 *);
		struct {
			int (*output_finish)(struct sk_buff___68 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*extract_output)(struct xfrm_state___11 *, struct sk_buff___68 *);
	int (*transport_finish)(struct sk_buff___68 *, int);
};

struct tcp_splice_state {
	struct pipe_inode_info___10 *pipe;
	size_t len;
	unsigned int flags;
};

struct dma_device___9;

struct dma_chan_dev___9;

struct dma_chan___10 {
	struct dma_device___9 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___9 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___9;

struct dma_device___9 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___265 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___10 *);
	void (*device_free_chan_resources)(struct dma_chan___10 *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memcpy)(struct dma_chan___10 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor)(struct dma_chan___10 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor_val)(struct dma_chan___10 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq_val)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memset)(struct dma_chan___10 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_interrupt)(struct dma_chan___10 *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_slave_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_cyclic)(struct dma_chan___10 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___9 * (*device_prep_interleaved_dma)(struct dma_chan___10 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___10 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___10 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___10 *);
};

struct dma_chan_dev___9 {
	struct dma_chan___10 *chan;
	struct device___265 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___9 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___10 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___9 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___4 {
	char *base_address;
	int nr_pages;
	struct page___266 **pages;
};

struct dma_pinned_list___4 {
	int nr_iovecs;
	struct dma_page_list___4 page_list[0];
};

struct skb_frag_struct___16 {
	struct {
		struct page___266 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___16 skb_frag_t___16;

struct skb_shared_info___16 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___60 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___16 frags[17];
};

struct listen_sock___7 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___33 *syn_table[0];
};

struct fastopen_queue___7 {
	struct request_sock___33 *rskq_rst_head;
	struct request_sock___33 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___7 {
	struct request_sock___33 *rskq_accept_head;
	struct request_sock___33 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___7 *listen_opt;
	struct fastopen_queue___7 *fastopenq;
};

struct inet_request_sock___3 {
	struct request_sock___33 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___60 *pktopts;
	};
};

struct inet_bind_bucket___7;

struct inet_connection_sock_af_ops___7 {
	int (*queue_xmit)(struct sk_buff___60 *, struct flowi *);
	void (*send_check)(struct sock___47 *, struct sk_buff___60 *);
	int (*rebuild_header)(struct sock___47 *);
	void (*sk_rx_dst_set)(struct sock___47 *, const struct sk_buff___60 *);
	int (*conn_request)(struct sock___47 *, struct sk_buff___60 *);
	struct sock___47 * (*syn_recv_sock)(struct sock___47 *, struct sk_buff___60 *, struct request_sock___33 *, struct dst_entry___47 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___47 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___47 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___47 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___47 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___47 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___47 *, const struct inet_bind_bucket___7 *, bool);
	void (*mtu_reduced)(struct sock___47 *);
};

struct inet_bind_bucket___7 {
	struct net___71 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___3;

struct inet_connection_sock___7 {
	struct inet_sock___5 icsk_inet;
	struct request_sock_queue___7 icsk_accept_queue;
	struct inet_bind_bucket___7 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___3 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___7 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___47 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___3 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___47 *);
	void (*release)(struct sock___47 *);
	u32 (*ssthresh)(struct sock___47 *);
	void (*cong_avoid)(struct sock___47 *, u32, u32);
	void (*set_state)(struct sock___47 *, u8);
	void (*cwnd_event)(struct sock___47 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___47 *, u32);
	u32 (*undo_cwnd)(struct sock___47 *);
	void (*pkts_acked)(struct sock___47 *, u32, s32);
	int (*get_info)(struct sock___47 *, u32, struct sk_buff___60 *);
	char name[16];
	struct module___165 *owner;
};

struct inet_timewait_death_row___4 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___6 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

union tcp_word_hdr {
	struct tcphdr hdr;
	__be32 words[5];
};

struct tcp_sack_block_wire {
	__be32 start_seq;
	__be32 end_seq;
};

struct tcp_request_sock_ops___2;

struct tcp_request_sock___3 {
	struct inet_request_sock___3 req;
	const struct tcp_request_sock_ops___2 *af_specific;
	struct sock___47 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___2 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___47 *, struct request_sock___33 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___47 *, const struct request_sock___33 *, const struct sk_buff___60 *);
	void (*init_req)(struct request_sock___33 *, struct sock___47 *, struct sk_buff___60 *);
	__u32 (*cookie_init_seq)(struct sock___47 *, const struct sk_buff___60 *, __u16 *);
	struct dst_entry___47 * (*route_req)(struct sock___47 *, struct flowi *, const struct request_sock___33 *, bool *);
	__u32 (*init_seq)(const struct sk_buff___60 *);
	int (*send_synack)(struct sock___47 *, struct dst_entry___47 *, struct flowi *, struct request_sock___33 *, u16, struct tcp_fastopen_cookie *);
	void (*queue_hash_add)(struct sock___47 *, struct request_sock___33 *, const long unsigned int);
};

struct tcp_sock_af_ops___3;

struct tcp_sock___4 {
	struct inet_connection_sock___7 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___58 prequeue;
		struct task_struct___268 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___10 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___4 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___60 *lost_skb_hint;
	struct sk_buff___60 *retransmit_skb_hint;
	struct sk_buff_head___58 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___60 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___3 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___33 *fastopen_rsk;
};

struct tcp_sock_af_ops___3 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___47 *, struct sock___47 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___47 *, const struct request_sock___33 *, const struct sk_buff___60 *);
	int (*md5_parse)(struct sock___47 *, char *, int);
};

enum tcp_ca_ack_event_flags {
	CA_ACK_SLOWPATH = 1,
	CA_ACK_WIN_UPDATE = 2,
	CA_ACK_ECE = 4,
};

struct tcp_sacktag_state {
	int reord;
	int fack_count;
	long int rtt_us;
	int flag;
};

struct page___275;

typedef struct page___275 *pgtable_t___275;

struct address_space___276;

struct kmem_cache___259;

struct page___275 {
	long unsigned int flags;
	struct address_space___276 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___275 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___275 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___259 *slab_cache;
		struct page___275 *first_page;
	};
	long: 64;
};

struct task_struct___277;

struct pv_cpu_ops___277 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___277 *);
	void (*end_context_switch)(struct task_struct___277 *);
};

struct mutex___278 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___277 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___270 {
	struct page___275 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___284;

struct nsproxy___156;

struct signal_struct___277;

struct css_set___171;

struct task_struct___277 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___277 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___284 *mm;
	struct mm_struct___284 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___277 *real_parent;
	struct task_struct___277 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___277 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___277 = 0,
		VTIME_USER___277 = 1,
		VTIME_SYS___277 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___156 *nsproxy;
	struct signal_struct___277 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___171 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___278 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___270 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___284 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___284 *, struct mm_struct___284 *);
	void (*dup_mmap)(struct mm_struct___284 *, struct mm_struct___284 *);
	void (*exit_mmap)(struct mm_struct___284 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___284 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___284 *);
	void (*pgd_free)(struct mm_struct___284 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___284 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___284 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___284 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___284 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___284 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___284 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___284 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___284 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___284 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___284 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___284 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___278 lock;
	void *vdso;
} mm_context_t___278;

struct xol_area___275;

struct uprobes_state___275 {
	struct xol_area___275 *xol_area;
};

struct vm_area_struct___284;

struct file___276;

struct core_state___277;

struct mm_struct___284 {
	struct vm_area_struct___284 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___284 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___284 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___278 context;
	long unsigned int flags;
	struct core_state___277 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___277 *owner;
	struct file___276 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___275 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___58;

struct kobj_type___58;

struct kobject___58 {
	const char *name;
	struct list_head entry;
	struct kobject___58 *parent;
	struct kset___58 *kset;
	struct kobj_type___58 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___173;

struct module_kobject___172 {
	struct kobject___58 kobj;
	struct module___173 *mod;
	struct kobject___58 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___172;

struct module___173 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___172 mkobj;
	struct module_attribute___172 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___58 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___277 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___275 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___275 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___258;

struct memcg_cache_params___259;

struct kmem_cache___259 {
	struct kmem_cache_cpu___258 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___58 kobj;
	struct memcg_cache_params___259 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___276;

struct address_space_operations___276;

struct address_space___276 {
	struct inode___276 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___278 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___276 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___276;

struct path___276 {
	struct vfsmount *mnt;
	struct dentry___276 *dentry;
};

struct file_operations___276;

struct file___276 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___276 f_path;
	struct inode___276 *f_inode;
	const struct file_operations___276 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___276 *f_mapping;
	struct mutex___278 f_pos_lock;
};

struct vm_operations_struct___250;

struct vm_area_struct___284 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___284 *vm_next;
	struct vm_area_struct___284 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___284 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___250 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___276 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___246;

struct vm_operations_struct___250 {
	void (*open)(struct vm_area_struct___284 *);
	void (*close)(struct vm_area_struct___284 *);
	int (*fault)(struct vm_area_struct___284 *, struct vm_fault___246 *);
	int (*page_mkwrite)(struct vm_area_struct___284 *, struct vm_fault___246 *);
	int (*access)(struct vm_area_struct___284 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___284 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___284 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___284 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___284 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___277 {
	struct task_struct___277 *task;
	struct core_thread___277 *next;
};

struct core_state___277 {
	atomic_t nr_threads;
	struct core_thread___277 dumper;
	struct completion startup;
};

struct fasync_struct___276;

struct socket_wq___55 {
	wait_queue_head_t wait;
	struct fasync_struct___276 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___276 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___276 *fa_next;
	struct file___276 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___56;

struct proto_ops___55;

struct socket___56 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___55 *wq;
	struct file___276 *file;
	struct sock___56 *sk;
	const struct proto_ops___55 *ops;
};

struct proto___55;

struct net___80;

struct sock_common___55 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___55 *skc_prot;
	struct net___80 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___69;

struct sk_buff_head___67 {
	struct sk_buff___69 *next;
	struct sk_buff___69 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___56;

struct dst_entry___56;

struct cg_proto___55;

struct sock___56 {
	struct sock_common___55 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___67 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___69 *head;
		struct sk_buff___69 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___56 *sk_filter;
	struct socket_wq___55 *sk_wq;
	struct sk_buff_head___67 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___56 *sk_rx_dst;
	struct dst_entry___56 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___67 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___67 sk_error_queue;
	struct proto___55 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___56 *sk_socket;
	void *sk_user_data;
	struct page_frag___270 sk_frag;
	struct sk_buff___69 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___55 *sk_cgrp;
	void (*sk_state_change)(struct sock___56 *);
	void (*sk_data_ready)(struct sock___56 *, int);
	void (*sk_write_space)(struct sock___56 *);
	void (*sk_error_report)(struct sock___56 *);
	int (*sk_backlog_rcv)(struct sock___56 *, struct sk_buff___69 *);
	void (*sk_destruct)(struct sock___56 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___162;

struct kiocb___63;

struct proto_ops___55 {
	int family;
	struct module___173 *owner;
	int (*release)(struct socket___56 *);
	int (*bind)(struct socket___56 *, struct sockaddr *, int);
	int (*connect)(struct socket___56 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___56 *, struct socket___56 *);
	int (*accept)(struct socket___56 *, struct socket___56 *, int);
	int (*getname)(struct socket___56 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___276 *, struct socket___56 *, struct poll_table_struct___162 *);
	int (*ioctl)(struct socket___56 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___56 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___56 *, int);
	int (*shutdown)(struct socket___56 *, int);
	int (*setsockopt)(struct socket___56 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___56 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___56 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___56 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___63 *, struct socket___56 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___63 *, struct socket___56 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___276 *, struct socket___56 *, struct vm_area_struct___284 *);
	ssize_t (*sendpage)(struct socket___56 *, struct page___275 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___56 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___56 *, int);
		struct {
			void (*set_peek_off)(struct sock___56 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___164)(struct file___276 *, wait_queue_head_t *, struct poll_table_struct___162 *);

struct poll_table_struct___162 {
	poll_queue_proc___164 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___63(struct kiocb___63 *, struct io_event *);

struct kiocb___63 {
	atomic_t ki_users;
	struct file___276 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___63 *ki_cancel;
	void (*ki_dtor)(struct kiocb___63 *);
	union {
		void *user;
		struct task_struct___277 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___81;

struct ctl_table_set___81;

struct ctl_dir___81;

struct ctl_node___81;

struct ctl_table_header___81 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___81 *root;
	struct ctl_table_set___81 *set;
	struct ctl_dir___81 *parent;
	struct ctl_node___81 *node;
};

struct ctl_dir___81 {
	struct ctl_table_header___81 header;
	struct rb_root root;
};

struct ctl_table_set___81 {
	int (*is_seen)(struct ctl_table_set___81 *);
	struct ctl_dir___81 dir;
};

struct netns_core___78 {
	struct ctl_table_header___81 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___79 {
	struct mutex___278 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___78 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___81 *ctl;
};

struct netns_ipv4___78 {
	struct ctl_table_header___81 *forw_hdr;
	struct ctl_table_header___81 *frags_hdr;
	struct ctl_table_header___81 *ipv4_hdr;
	struct ctl_table_header___81 *route_hdr;
	struct ctl_table_header___81 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___56 *fibnl;
	struct sock___56 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___78 {
	struct ctl_table_header___81 *hdr;
	struct ctl_table_header___81 *route_hdr;
	struct ctl_table_header___81 *icmp_hdr;
	struct ctl_table_header___81 *frags_hdr;
	struct ctl_table_header___81 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___66;

struct neighbour___56;

struct dst_ops___80 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___80 *);
	struct dst_entry___56 * (*check)(struct dst_entry___56 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___56 *);
	unsigned int (*mtu)(const struct dst_entry___56 *);
	u32 * (*cow_metrics)(struct dst_entry___56 *, long unsigned int);
	void (*destroy)(struct dst_entry___56 *);
	void (*ifdown)(struct dst_entry___56 *, struct net_device___66 *, int);
	struct dst_entry___56 * (*negative_advice)(struct dst_entry___56 *);
	void (*link_failure)(struct sk_buff___69 *);
	void (*update_pmtu)(struct dst_entry___56 *, struct sock___56 *, struct sk_buff___69 *, u32);
	void (*redirect)(struct dst_entry___56 *, struct sock___56 *, struct sk_buff___69 *);
	int (*local_out)(struct sk_buff___69 *);
	struct neighbour___56 * (*neigh_lookup)(const struct dst_entry___56 *, struct sk_buff___69 *, const void *);
	struct kmem_cache___259 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___80 {
	struct netns_sysctl_ipv6___78 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___80 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___56 **icmp_sk;
	struct sock___56 *ndisc_sk;
	struct sock___56 *tcp_sk;
	struct sock___56 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___78 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___81 *sysctl_header;
	struct sock___56 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___55 {
	struct sock___56 *v4_ctl_sk;
	struct sock___56 *v6_ctl_sk;
};

struct netns_nf___78 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___81 *nf_log_dir_header;
};

struct nf_proto_net___78 {
	struct ctl_table_header___81 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___78 {
	struct nf_proto_net___78 pn;
	unsigned int timeout;
};

struct nf_tcp_net___78 {
	struct nf_proto_net___78 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___78 {
	struct nf_proto_net___78 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___78 {
	struct nf_proto_net___78 pn;
	unsigned int timeout;
};

struct nf_ip_net___78 {
	struct nf_generic_net___78 generic;
	struct nf_tcp_net___78 tcp;
	struct nf_udp_net___78 udp;
	struct nf_icmp_net___78 icmp;
	struct nf_icmp_net___78 icmpv6;
};

struct netns_ct___79 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___81 *sysctl_header;
	struct ctl_table_header___81 *acct_sysctl_header;
	struct ctl_table_header___81 *tstamp_sysctl_header;
	struct ctl_table_header___81 *event_sysctl_header;
	struct ctl_table_header___81 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___259 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___78 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___78 {
	struct netns_sysctl_ipv6___78 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___80 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___56 *nlsk;
	struct sock___56 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___81 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___80 xfrm4_dst_ops;
	struct dst_ops___80 xfrm6_dst_ops;
};

struct net___80 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___81 sysctls;
	struct sock___56 *rtnl;
	struct sock___56 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___66 *loopback_dev;
	struct netns_core___78 core;
	struct netns_mib mib;
	struct netns_packet___79 packet;
	struct netns_unix___78 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___78 ipv4;
	struct netns_ipv6___80 ipv6;
	struct netns_sctp___78 sctp;
	struct netns_dccp___55 dccp;
	struct netns_nf___78 nf;
	struct netns_xt xt;
	struct netns_ct___79 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___78 nf_frag;
	struct sock___56 *nfnl;
	struct sock___56 *nfnl_stash;
	struct sk_buff_head___67 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___80 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___56 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___56 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___278 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___278 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___277;

struct lruvec___277 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___277 *zone;
};

struct pglist_data___277;

struct zone___277 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___277 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___277 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___277 {
	struct zone___277 *zone;
	int zone_idx;
};

struct zonelist___277 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___277 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___277 {
	struct zone___277 node_zones[4];
	struct zonelist___277 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___277 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___200;

struct x86_io_apic_ops___200 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___200 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___200;

struct irq_data___200 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___200 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___274;

struct dev_pm_ops___274 {
	int (*prepare)(struct device___274 *);
	void (*complete)(struct device___274 *);
	int (*suspend)(struct device___274 *);
	int (*resume)(struct device___274 *);
	int (*freeze)(struct device___274 *);
	int (*thaw)(struct device___274 *);
	int (*poweroff)(struct device___274 *);
	int (*restore)(struct device___274 *);
	int (*suspend_late)(struct device___274 *);
	int (*resume_early)(struct device___274 *);
	int (*freeze_late)(struct device___274 *);
	int (*thaw_early)(struct device___274 *);
	int (*poweroff_late)(struct device___274 *);
	int (*restore_early)(struct device___274 *);
	int (*suspend_noirq)(struct device___274 *);
	int (*resume_noirq)(struct device___274 *);
	int (*freeze_noirq)(struct device___274 *);
	int (*thaw_noirq)(struct device___274 *);
	int (*poweroff_noirq)(struct device___274 *);
	int (*restore_noirq)(struct device___274 *);
	int (*runtime_suspend)(struct device___274 *);
	int (*runtime_resume)(struct device___274 *);
	int (*runtime_idle)(struct device___274 *);
};

struct dev_pm_qos___77;

struct dev_pm_info___77 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___77 *qos;
};

struct dma_map_ops___139;

struct dev_archdata___139 {
	struct dma_map_ops___139 *dma_ops;
	void *iommu;
};

struct device_type___274;

struct bus_type___274;

struct device_driver___274;

struct dev_pm_domain___274;

struct class___274;

struct attribute_group___236;

struct device_rh___274;

struct device___274 {
	struct device___274 *parent;
	struct device_private *p;
	struct kobject___58 kobj;
	const char *init_name;
	const struct device_type___274 *type;
	struct mutex___278 mutex;
	struct bus_type___274 *bus;
	struct device_driver___274 *driver;
	void *platform_data;
	struct dev_pm_info___77 power;
	struct dev_pm_domain___274 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___139 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___274 *class;
	const struct attribute_group___236 **groups;
	void (*release)(struct device___274 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___274 *device_rh;
};

struct dev_pm_qos_request___78;

struct dev_pm_qos___77 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___78 *latency_req;
	struct dev_pm_qos_request___78 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___78 *latency_tolerance_req;
};

struct dev_pm_info_rh___274 {
	void (*set_latency_tolerance)(struct device___274 *, s32);
};

struct dev_pm_domain___274 {
	struct dev_pm_ops___274 ops;
};

struct smp_ops___277 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___277 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___55 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___56 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___238;

struct attribute_group___236 {
	const char *name;
	umode_t (*is_visible)(struct kobject___58 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___238 **bin_attrs;
};

struct bin_attribute___238 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___276 *, struct kobject___58 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___276 *, struct kobject___58 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	int (*mmap)(struct file___276 *, struct kobject___58 *, struct bin_attribute___238 *, struct vm_area_struct___284 *);
};

struct sysfs_ops___58 {
	ssize_t (*show)(struct kobject___58 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___58 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___58 *, const struct attribute *);
};

struct kset_uevent_ops___58;

struct kset___58 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___58 kobj;
	const struct kset_uevent_ops___58 *uevent_ops;
};

struct kobj_type___58 {
	void (*release)(struct kobject___58 *);
	const struct sysfs_ops___58 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___55 * (*child_ns_type)(struct kobject___58 *);
	const void * (*namespace)(struct kobject___58 *);
};

struct kset_uevent_ops___58 {
	int (* const filter)(struct kset___58 *, struct kobject___58 *);
	const char * (* const name)(struct kset___58 *, struct kobject___58 *);
	int (* const uevent)(struct kset___58 *, struct kobject___58 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___258 {
	void **freelist;
	long unsigned int tid;
	struct page___275 *page;
	struct page___275 *partial;
};

struct memcg_cache_params___259 {
	bool is_root_cache;
	union {
		struct kmem_cache___259 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___259 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___139 {
	void * (*alloc)(struct device___274 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___274 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___274 *, struct vm_area_struct___284 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___274 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___274 *, struct page___275 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___274 *, dma_addr_t);
	int (*dma_supported)(struct device___274 *, u64);
	int (*set_dma_mask)(struct device___274 *, u64);
	int is_phys;
};

struct bus_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___274 *, char *);
	ssize_t (*store)(struct bus_type___274 *, const char *, size_t);
};

struct device_attribute___274;

struct driver_attribute___274;

struct bus_type___274 {
	const char *name;
	const char *dev_name;
	struct device___274 *dev_root;
	struct bus_attribute___274 *bus_attrs;
	struct device_attribute___274 *dev_attrs;
	struct driver_attribute___274 *drv_attrs;
	const struct attribute_group___236 **bus_groups;
	const struct attribute_group___236 **dev_groups;
	const struct attribute_group___236 **drv_groups;
	int (*match)(struct device___274 *, struct device_driver___274 *);
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	int (*probe)(struct device___274 *);
	int (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*online)(struct device___274 *);
	int (*offline)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct device___274 *, struct device_attribute___274 *, char *);
	ssize_t (*store)(struct device___274 *, struct device_attribute___274 *, const char *, size_t);
};

struct driver_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___274 *, char *);
	ssize_t (*store)(struct device_driver___274 *, const char *, size_t);
};

struct device_driver___274 {
	const char *name;
	struct bus_type___274 *bus;
	struct module___173 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___274 *);
	int (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	const struct attribute_group___236 **groups;
	const struct dev_pm_ops___274 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___274 {
	const char *name;
	const struct attribute_group___236 **groups;
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
};

struct class_attribute___274;

struct class___274 {
	const char *name;
	struct module___173 *owner;
	struct class_attribute___274 *class_attrs;
	struct device_attribute___274 *dev_attrs;
	const struct attribute_group___236 **dev_groups;
	struct bin_attribute___238 *dev_bin_attrs;
	struct kobject___58 *dev_kobj;
	int (*dev_uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *);
	void (*class_release)(struct class___274 *);
	void (*dev_release)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	const struct kobj_ns_type_operations___55 *ns_type;
	const void * (*namespace)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
	struct subsys_private *p;
};

struct class_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct class___274 *, struct class_attribute___274 *, char *);
	ssize_t (*store)(struct class___274 *, struct class_attribute___274 *, const char *, size_t);
	const void * (*namespace)(struct class___274 *, const struct class_attribute___274 *);
};

struct device_rh___274 {
	struct dev_pm_info_rh___274 power;
};

struct vm_fault___246 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___275 *page;
};

struct dma_device___10;

struct dma_chan_dev___10;

struct dma_chan___11 {
	struct dma_device___10 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___10 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___10;

struct dma_device___10 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___274 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___11 *);
	void (*device_free_chan_resources)(struct dma_chan___11 *);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_memcpy)(struct dma_chan___11 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_xor)(struct dma_chan___11 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_xor_val)(struct dma_chan___11 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_pq)(struct dma_chan___11 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_pq_val)(struct dma_chan___11 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_memset)(struct dma_chan___11 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_interrupt)(struct dma_chan___11 *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_sg)(struct dma_chan___11 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_slave_sg)(struct dma_chan___11 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_cyclic)(struct dma_chan___11 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___10 * (*device_prep_interleaved_dma)(struct dma_chan___11 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___11 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___11 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___11 *);
};

struct dma_chan_dev___10 {
	struct dma_chan___11 *chan;
	struct device___274 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___10 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___11 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___10 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___5 {
	char *base_address;
	int nr_pages;
	struct page___275 **pages;
};

struct dma_pinned_list___5 {
	int nr_iovecs;
	struct dma_page_list___5 page_list[0];
};

struct ctl_node___81 {
	struct rb_node node;
	struct ctl_table_header___81 *header;
};

struct ctl_table_root___81 {
	struct ctl_table_set___81 default_set;
	struct ctl_table_set___81 * (*lookup)(struct ctl_table_root___81 *, struct nsproxy___156 *);
	int (*permissions)(struct ctl_table_header___81 *, struct ctl_table *);
};

struct nsproxy___156 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___80 *net_ns;
};

struct signal_struct___277 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___277 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___277 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___278 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___171;

struct css_set___171 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___171 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___66 {
	atomic_t use;
	unsigned int mask;
	struct net_device___66 *physindev;
	struct net_device___66 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___66(struct sk_buff___69 **);

struct net_device_ops___66;

struct ethtool_ops___66;

struct header_ops___66;

struct inet6_dev___32;

struct netdev_rx_queue___66;

struct netdev_queue___66;

struct rtnl_link_ops___57;

struct dcbnl_rtnl_ops___66;

struct net_device___66 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___66 *netdev_ops;
	const struct ethtool_ops___66 *ethtool_ops;
	const struct header_ops___66 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___58 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___32 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___66 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___66 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___66 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___66 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___66 = 0,
		NETREG_REGISTERED___66 = 1,
		NETREG_UNREGISTERING___66 = 2,
		NETREG_UNREGISTERED___66 = 3,
		NETREG_RELEASED___66 = 4,
		NETREG_DUMMY___66 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___66 = 0,
		RTNL_LINK_INITIALIZING___66 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___66 *);
	struct netpoll_info *npinfo;
	struct net___80 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___274 dev;
	const struct attribute_group___236 *sysfs_groups[4];
	const struct rtnl_link_ops___57 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___66 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___69 {
	struct sk_buff___69 *next;
	struct sk_buff___69 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___56 *sk;
	struct net_device___66 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___69 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___66 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___17 {
	struct {
		struct page___275 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___17 skb_frag_t___17;

struct skb_shared_info___17 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___69 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___17 frags[17];
};

struct sk_buff_fclones___2 {
	struct sk_buff___69 skb1;
	struct sk_buff___69 skb2;
	atomic_t fclone_ref;
};

struct seq_file___201;

struct irq_chip___200 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___200 *);
	void (*irq_shutdown)(struct irq_data___200 *);
	void (*irq_enable)(struct irq_data___200 *);
	void (*irq_disable)(struct irq_data___200 *);
	void (*irq_ack)(struct irq_data___200 *);
	void (*irq_mask)(struct irq_data___200 *);
	void (*irq_mask_ack)(struct irq_data___200 *);
	void (*irq_unmask)(struct irq_data___200 *);
	void (*irq_eoi)(struct irq_data___200 *);
	int (*irq_set_affinity)(struct irq_data___200 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___200 *);
	int (*irq_set_type)(struct irq_data___200 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___200 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___200 *);
	void (*irq_bus_sync_unlock)(struct irq_data___200 *);
	void (*irq_cpu_online)(struct irq_data___200 *);
	void (*irq_cpu_offline)(struct irq_data___200 *);
	void (*irq_suspend)(struct irq_data___200 *);
	void (*irq_resume)(struct irq_data___200 *);
	void (*irq_pm_shutdown)(struct irq_data___200 *);
	void (*irq_print_chip)(struct irq_data___200 *, struct seq_file___201 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___200 *, void *);
	long unsigned int flags;
};

struct seq_operations___201;

struct seq_file___201 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___278 lock;
	const struct seq_operations___201 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___276;

struct file_operations___276 {
	struct module___173 *owner;
	loff_t (*llseek)(struct file___276 *, loff_t, int);
	ssize_t (*read)(struct file___276 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___276 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___63 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___63 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___276 *, void *, filldir_t);
	unsigned int (*poll)(struct file___276 *, struct poll_table_struct___162 *);
	long int (*unlocked_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___276 *, struct vm_area_struct___284 *);
	int (*open)(struct inode___276 *, struct file___276 *);
	int (*flush)(struct file___276 *, fl_owner_t);
	int (*release)(struct inode___276 *, struct file___276 *);
	int (*fsync)(struct file___276 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___63 *, int);
	int (*fasync)(int, struct file___276 *, int);
	int (*lock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*sendpage)(struct file___276 *, struct page___275 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___276 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___276 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___276 *, long int, struct file_lock___276 **, void **);
		struct {
			int (*setlease)(struct file___276 *, long int, struct file_lock___276 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___276 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___201 *, struct file___276 *);
};

struct dev_pm_qos_request___78 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___274 *dev;
};

struct dentry_operations___276;

struct super_block___276;

struct dentry___276 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___276 *d_parent;
	struct qstr d_name;
	struct inode___276 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___276 *d_op;
	struct super_block___276 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___276;

struct dquot___276;

struct block_device___276;

struct inode___276 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___276 *i_op;
	struct super_block___276 *i_sb;
	struct address_space___276 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___278 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___276 *i_fop;
	struct file_lock___276 *i_flock;
	struct address_space___276 i_data;
	struct dquot___276 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___276 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___276 {
	int (*d_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_hash)(const struct dentry___276 *, struct qstr *);
	int (*d_compare)(const struct dentry___276 *, const struct dentry___276 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___276 *);
	void (*d_release)(struct dentry___276 *);
	void (*d_prune)(struct dentry___276 *);
	void (*d_iput)(struct dentry___276 *, struct inode___276 *);
	char * (*d_dname)(struct dentry___276 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___276 *);
	int (*d_manage)(struct dentry___276 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___276;

struct mem_dqinfo___276 {
	struct quota_format_type___276 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___276;

struct quota_info___276 {
	unsigned int flags;
	struct mutex___278 dqio_mutex;
	struct mutex___278 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___276 *files[2];
	struct mem_dqinfo___276 info[2];
	const struct quota_format_ops___276 *ops[2];
};

struct file_system_type___276;

struct super_operations___276;

struct dquot_operations___276;

struct quotactl_ops___276;

struct xattr_handler___172;

struct super_block___276 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___276 *s_type;
	const struct super_operations___276 *s_op;
	const struct dquot_operations___276 *dq_op;
	const struct quotactl_ops___276 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___276 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___172 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___276 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___276 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___278 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___276 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___276 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___276 *bd_inode;
	struct super_block___276 *bd_super;
	struct mutex___278 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___276 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___278 bd_fsfreeze_mutex;
};

struct cgroup___171;

struct cgroup_subsys_state___171 {
	struct cgroup___171 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___276 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___276 *ia_file;
};

struct dquot___276 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___278 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___276 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___276 {
	int qf_fmt_id;
	const struct quota_format_ops___276 *qf_ops;
	struct module___173 *qf_owner;
	struct quota_format_type___276 *qf_next;
};

struct quota_format_ops___276 {
	int (*check_quota_file)(struct super_block___276 *, int);
	int (*read_file_info)(struct super_block___276 *, int);
	int (*write_file_info)(struct super_block___276 *, int);
	int (*free_file_info)(struct super_block___276 *, int);
	int (*read_dqblk)(struct dquot___276 *);
	int (*commit_dqblk)(struct dquot___276 *);
	int (*release_dqblk)(struct dquot___276 *);
};

struct dquot_operations___276 {
	int (*write_dquot)(struct dquot___276 *);
	struct dquot___276 * (*alloc_dquot)(struct super_block___276 *, int);
	void (*destroy_dquot)(struct dquot___276 *);
	int (*acquire_dquot)(struct dquot___276 *);
	int (*release_dquot)(struct dquot___276 *);
	int (*mark_dirty)(struct dquot___276 *);
	int (*write_info)(struct super_block___276 *, int);
	qsize_t * (*get_reserved_space)(struct inode___276 *);
};

struct quotactl_ops___276 {
	int (*quota_on)(struct super_block___276 *, int, int, struct path___276 *);
	int (*quota_on_meta)(struct super_block___276 *, int, int);
	int (*quota_off)(struct super_block___276 *, int);
	int (*quota_sync)(struct super_block___276 *, int);
	int (*get_info)(struct super_block___276 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___276 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___276 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___276 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___276 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___276 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___276 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___276 *, unsigned int);
};

struct address_space_operations___276 {
	int (*writepage)(struct page___275 *, struct writeback_control *);
	int (*readpage)(struct file___276 *, struct page___275 *);
	int (*writepages)(struct address_space___276 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___275 *);
	int (*readpages)(struct file___276 *, struct address_space___276 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___276 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___275 **, void **);
	int (*write_end)(struct file___276 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___275 *, void *);
	sector_t (*bmap)(struct address_space___276 *, sector_t);
	void (*invalidatepage)(struct page___275 *, long unsigned int);
	int (*releasepage)(struct page___275 *, gfp_t);
	void (*freepage)(struct page___275 *);
	ssize_t (*direct_IO)(int, struct kiocb___63 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___276 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___276 *, struct page___275 *, struct page___275 *, enum migrate_mode);
	int (*launder_page)(struct page___275 *);
	int (*is_partially_uptodate)(struct page___275 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___275 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___276 *, struct page___275 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___276 *, sector_t *);
	void (*swap_deactivate)(struct file___276 *);
	void (*invalidatepage_range)(struct page___275 *, unsigned int, unsigned int);
};

struct inode_operations___276 {
	struct dentry___276 * (*lookup)(struct inode___276 *, struct dentry___276 *, unsigned int);
	void * (*follow_link)(struct dentry___276 *, struct nameidata *);
	int (*permission)(struct inode___276 *, int);
	struct posix_acl * (*get_acl)(struct inode___276 *, int);
	int (*readlink)(struct dentry___276 *, char *, int);
	void (*put_link)(struct dentry___276 *, struct nameidata *, void *);
	int (*create)(struct inode___276 *, struct dentry___276 *, umode_t, bool);
	int (*link)(struct dentry___276 *, struct inode___276 *, struct dentry___276 *);
	int (*unlink)(struct inode___276 *, struct dentry___276 *);
	int (*symlink)(struct inode___276 *, struct dentry___276 *, const char *);
	int (*mkdir)(struct inode___276 *, struct dentry___276 *, umode_t);
	int (*rmdir)(struct inode___276 *, struct dentry___276 *);
	int (*mknod)(struct inode___276 *, struct dentry___276 *, umode_t, dev_t);
	int (*rename)(struct inode___276 *, struct dentry___276 *, struct inode___276 *, struct dentry___276 *);
	int (*setattr)(struct dentry___276 *, struct iattr___276 *);
	int (*getattr)(struct vfsmount *, struct dentry___276 *, struct kstat *);
	int (*setxattr)(struct dentry___276 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___276 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___276 *, char *, size_t);
	int (*removexattr)(struct dentry___276 *, const char *);
	int (*fiemap)(struct inode___276 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___276 *, struct timespec *, int);
	int (*atomic_open)(struct inode___276 *, struct dentry___276 *, struct file___276 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___276;

struct lock_manager_operations___276;

struct file_lock___276 {
	struct file_lock___276 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___276 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___276 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___276 *fl_ops;
	const struct lock_manager_operations___276 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___276 {
	void (*fl_copy_lock)(struct file_lock___276 *, struct file_lock___276 *);
	void (*fl_release_private)(struct file_lock___276 *);
};

struct lock_manager_operations___276 {
	int (*lm_compare_owner)(struct file_lock___276 *, struct file_lock___276 *);
	long unsigned int (*lm_owner_key)(struct file_lock___276 *);
	void (*lm_notify)(struct file_lock___276 *);
	int (*lm_grant)(struct file_lock___276 *, struct file_lock___276 *, int);
	void (*lm_break)(struct file_lock___276 *);
	int (*lm_change)(struct file_lock___276 **, int);
};

struct file_system_type___276 {
	const char *name;
	int fs_flags;
	struct dentry___276 * (*mount)(struct file_system_type___276 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___276 *);
	struct module___173 *owner;
	struct file_system_type___276 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___276 {
	struct inode___276 * (*alloc_inode)(struct super_block___276 *);
	void (*destroy_inode)(struct inode___276 *);
	void (*dirty_inode)(struct inode___276 *, int);
	int (*write_inode)(struct inode___276 *, struct writeback_control *);
	int (*drop_inode)(struct inode___276 *);
	void (*evict_inode)(struct inode___276 *);
	void (*put_super)(struct super_block___276 *);
	int (*sync_fs)(struct super_block___276 *, int);
	int (*freeze_fs)(struct super_block___276 *);
	int (*unfreeze_fs)(struct super_block___276 *);
	int (*statfs)(struct dentry___276 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___276 *, int *, char *);
	void (*umount_begin)(struct super_block___276 *);
	int (*show_options)(struct seq_file___201 *, struct dentry___276 *);
	int (*show_devname)(struct seq_file___201 *, struct dentry___276 *);
	int (*show_path)(struct seq_file___201 *, struct dentry___276 *);
	int (*show_stats)(struct seq_file___201 *, struct dentry___276 *);
	ssize_t (*quota_read)(struct super_block___276 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___276 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___276 *);
	int (*bdev_try_to_free_page)(struct super_block___276 *, struct page___275 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___276 *);
	void (*free_cached_objects)(struct super_block___276 *, int);
};

struct xattr_handler___172 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___276 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___276 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___276 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___66 {
	int (*get_settings)(struct net_device___66 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___66 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___66 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___66 *);
	void (*get_regs)(struct net_device___66 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___66 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___66 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___66 *);
	void (*set_msglevel)(struct net_device___66 *, u32);
	int (*nway_reset)(struct net_device___66 *);
	u32 (*get_link)(struct net_device___66 *);
	int (*get_eeprom_len)(struct net_device___66 *);
	int (*get_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___66 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___66 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___66 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___66 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___66 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___66 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___66 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___66 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___66 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___66 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___66 *);
	void (*complete)(struct net_device___66 *);
	u32 (*get_priv_flags)(struct net_device___66 *);
	int (*set_priv_flags)(struct net_device___66 *, u32);
	int (*get_sset_count)(struct net_device___66 *, int);
	int (*get_rxnfc)(struct net_device___66 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___66 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___66 *, struct ethtool_flash *);
	int (*reset)(struct net_device___66 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___66 *);
	int (*get_rxfh_indir)(struct net_device___66 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___66 *, const u32 *);
	void (*get_channels)(struct net_device___66 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___66 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___66 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___66 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___66 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___66 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___66 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___66 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___66 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___66 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___66 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___66 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___27;

struct dst_entry___56 {
	struct callback_head callback_head;
	struct dst_entry___56 *child;
	struct net_device___66 *dev;
	struct dst_ops___80 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___56 *path;
	struct dst_entry___56 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___69 *);
	union {
		int (*output)(struct sock___56 *, struct sk_buff___69 *);
		struct {
			int (*output)(struct sk_buff___69 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___56 *next;
		struct rtable___27 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___56;

struct neigh_parms___56;

struct neigh_ops___56;

struct neighbour___56 {
	struct neighbour___56 *next;
	struct neigh_table___56 *tbl;
	struct neigh_parms___56 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___67 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___56 *, struct sk_buff___69 *);
	const struct neigh_ops___56 *ops;
	struct callback_head rcu;
	struct net_device___66 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___80 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___69 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___69 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___80 *, struct dst_entry___56 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___69 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___69 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___201 {
	void * (*start)(struct seq_file___201 *, loff_t *);
	void (*stop)(struct seq_file___201 *, void *);
	void * (*next)(struct seq_file___201 *, void *, loff_t *);
	int (*show)(struct seq_file___201 *, void *);
};

struct dcbnl_rtnl_ops___66 {
	int (*ieee_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___66 *);
	u8 (*setstate)(struct net_device___66 *, u8);
	void (*getpermhwaddr)(struct net_device___66 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___66 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___66 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___66 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___66 *, int, u8 *);
	void (*setpfccfg)(struct net_device___66 *, int, u8);
	void (*getpfccfg)(struct net_device___66 *, int, u8 *);
	u8 (*setall)(struct net_device___66 *);
	u8 (*getcap)(struct net_device___66 *, int, u8 *);
	int (*getnumtcs)(struct net_device___66 *, int, u8 *);
	int (*setnumtcs)(struct net_device___66 *, int, u8);
	u8 (*getpfcstate)(struct net_device___66 *);
	void (*setpfcstate)(struct net_device___66 *, u8);
	void (*getbcncfg)(struct net_device___66 *, int, u32 *);
	void (*setbcncfg)(struct net_device___66 *, int, u32);
	void (*getbcnrp)(struct net_device___66 *, int, u8 *);
	void (*setbcnrp)(struct net_device___66 *, int, u8);
	u8 (*setapp)(struct net_device___66 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___66 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___66 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___66 *, int, u8);
	u8 (*getdcbx)(struct net_device___66 *);
	u8 (*setdcbx)(struct net_device___66 *, u8);
	int (*peer_getappinfo)(struct net_device___66 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___66 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___66 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___66 *, struct cee_pfc *);
};

struct cgroupfs_root___171;

struct cgroup___171 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___171 *parent;
	struct dentry___276 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___171 *subsys[11];
	struct cgroupfs_root___171 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___278 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___171 {
	struct super_block___276 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___171 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___107 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___276 *, struct file___276 *);
	ssize_t (*read)(struct cgroup___171 *, struct cftype___107 *, struct file___276 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___171 *, struct cftype___107 *);
	s64 (*read_s64)(struct cgroup___171 *, struct cftype___107 *);
	int (*read_map)(struct cgroup___171 *, struct cftype___107 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___171 *, struct cftype___107 *, struct seq_file___201 *);
	ssize_t (*write)(struct cgroup___171 *, struct cftype___107 *, struct file___276 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___171 *, struct cftype___107 *, u64);
	int (*write_s64)(struct cgroup___171 *, struct cftype___107 *, s64);
	int (*write_string)(struct cgroup___171 *, struct cftype___107 *, const char *);
	int (*trigger)(struct cgroup___171 *, unsigned int);
	int (*release)(struct inode___276 *, struct file___276 *);
	int (*register_event)(struct cgroup___171 *, struct cftype___107 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___171 *, struct cftype___107 *, struct eventfd_ctx *);
};

struct cftype_set___103 {
	struct list_head node;
	struct cftype___107 *cfts;
};

struct task_and_cgroup___103 {
	struct task_struct___277 *task;
	struct cgroup___171 *cgrp;
	struct css_set___171 *cg;
};

struct cgroup_taskset___103 {
	struct task_and_cgroup___103 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___171 *cur_cgrp;
};

struct cgroup_subsys___103 {
	struct cgroup_subsys_state___171 * (*css_alloc)(struct cgroup___171 *);
	int (*css_online)(struct cgroup___171 *);
	void (*css_offline)(struct cgroup___171 *);
	void (*css_free)(struct cgroup___171 *);
	int (*can_attach)(struct cgroup___171 *, struct cgroup_taskset___103 *);
	void (*cancel_attach)(struct cgroup___171 *, struct cgroup_taskset___103 *);
	void (*attach)(struct cgroup___171 *, struct cgroup_taskset___103 *);
	void (*fork)(struct task_struct___277 *);
	void (*exit)(struct cgroup___171 *, struct cgroup___171 *, struct task_struct___277 *);
	void (*bind)(struct cgroup___171 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___171 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___107 *base_cftypes;
	struct cftype_set___103 base_cftset;
	struct module___173 *module;
};

struct request_sock_ops___41;

struct request_sock___42 {
	struct sock_common___55 __req_common;
	struct request_sock___42 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___41 *rsk_ops;
	struct sock___56 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___68 {
	struct sk_buff___69 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___69 *, struct netlink_callback___68 *);
	int (*done)(struct netlink_callback___68 *);
	void *data;
	struct module___173 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___66 {
	int (*create)(struct sk_buff___69 *, struct net_device___66 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___69 *, unsigned char *);
	int (*rebuild)(struct sk_buff___69 *);
	int (*cache)(const struct neighbour___56 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___66 *, const unsigned char *);
};

struct napi_struct___66 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___66 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___66 *dev;
	struct sk_buff___69 *gro_list;
	struct sk_buff___69 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___66 {
	struct net_device___66 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___58 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___66 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___58 kobj;
	struct net_device___66 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___66 {
	int (*ndo_init)(struct net_device___66 *);
	void (*ndo_uninit)(struct net_device___66 *);
	int (*ndo_open)(struct net_device___66 *);
	int (*ndo_stop)(struct net_device___66 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___69 *, struct net_device___66 *);
	u16 (*ndo_select_queue)(struct net_device___66 *, struct sk_buff___69 *);
	void (*ndo_change_rx_flags)(struct net_device___66 *, int);
	void (*ndo_set_rx_mode)(struct net_device___66 *);
	int (*ndo_set_mac_address)(struct net_device___66 *, void *);
	int (*ndo_validate_addr)(struct net_device___66 *);
	int (*ndo_do_ioctl)(struct net_device___66 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___66 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___66 *, int);
	int (*ndo_neigh_setup)(struct net_device___66 *, struct neigh_parms___56 *);
	void (*ndo_tx_timeout)(struct net_device___66 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___66 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___66 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___66 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___66 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___66 *);
	int (*ndo_netpoll_setup)(struct net_device___66 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___66 *);
	int (*ndo_busy_poll)(struct napi_struct___66 *);
	int (*ndo_set_vf_mac)(struct net_device___66 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___66 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___66 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___66 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___66 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___66 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___66 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___66 *, int, struct sk_buff___69 *);
	int (*ndo_setup_tc)(struct net_device___66 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___66 *);
	int (*ndo_fcoe_disable)(struct net_device___66 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___66 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___66 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___66 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___66 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___66 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___66 *, const struct sk_buff___69 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___66 *, struct net_device___66 *);
	int (*ndo_del_slave)(struct net_device___66 *, struct net_device___66 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___56 *);
	void (*ndo_neigh_destroy)(struct neighbour___56 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___69 *, struct netlink_callback___68 *, struct net_device___66 *, int);
	int (*ndo_bridge_setlink)(struct net_device___66 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___69 *, u32, u32, struct net_device___66 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___66 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___66 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___66 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___66 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___66 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___66 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___69 *, struct net_device___66 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___66 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___66 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___66 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___56 {
	struct net___80 *net;
	struct net_device___66 *dev;
	struct neigh_parms___56 *next;
	int (*neigh_setup)(struct neighbour___56 *);
	void (*neigh_cleanup)(struct neighbour___56 *);
	struct neigh_table___56 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___32;

struct ifacaddr6___32;

struct inet6_dev___32 {
	struct net_device___66 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___32 *mc_list;
	struct ifmcaddr6___32 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___32 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___56 *nd_parms;
	struct inet6_dev___32 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___57 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___66 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___80 *, struct net_device___66 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___66 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___66 *, struct list_head *);
	size_t (*get_size)(const struct net_device___66 *);
	int (*fill_info)(struct sk_buff___69 *, const struct net_device___66 *);
	size_t (*get_xstats_size)(const struct net_device___66 *);
	int (*fill_xstats)(struct sk_buff___69 *, const struct net_device___66 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___80 * (*get_link_net)(const struct net_device___66 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___66 *, struct net_device___66 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___66 *, const struct net_device___66 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___69 *, const struct net_device___66 *, const struct net_device___66 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___56 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___69 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___56;

struct neigh_hash_table___56;

struct neigh_table___56 {
	struct neigh_table___56 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___66 *, __u32 *);
	int (*constructor)(struct neighbour___56 *);
	int (*pconstructor)(struct pneigh_entry___56 *);
	void (*pdestructor)(struct pneigh_entry___56 *);
	void (*proxy_redo)(struct sk_buff___69 *);
	char *id;
	struct neigh_parms___56 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___67 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___56 *nht;
	struct pneigh_entry___56 **phash_buckets;
};

struct neigh_ops___56 {
	int family;
	void (*solicit)(struct neighbour___56 *, struct sk_buff___69 *);
	void (*error_report)(struct neighbour___56 *, struct sk_buff___69 *);
	int (*output)(struct neighbour___56 *, struct sk_buff___69 *);
	int (*connected_output)(struct neighbour___56 *, struct sk_buff___69 *);
};

struct pneigh_entry___56 {
	struct pneigh_entry___56 *next;
	struct net___80 *net;
	struct net_device___66 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___56 {
	struct neighbour___56 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___27 {
	struct dst_entry___56 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___38;

struct inet_hashinfo___12;

struct proto___55 {
	void (*close)(struct sock___56 *, long int);
	int (*connect)(struct sock___56 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___56 *, int);
	struct sock___56 * (*accept)(struct sock___56 *, int, int *);
	int (*ioctl)(struct sock___56 *, int, long unsigned int);
	int (*init)(struct sock___56 *);
	void (*destroy)(struct sock___56 *);
	void (*shutdown)(struct sock___56 *, int);
	int (*setsockopt)(struct sock___56 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___56 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___56 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___56 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___56 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___63 *, struct sock___56 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___63 *, struct sock___56 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___56 *, struct page___275 *, int, size_t, int);
	int (*bind)(struct sock___56 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___56 *, struct sk_buff___69 *);
	void (*release_cb)(struct sock___56 *);
	void (*mtu_reduced)(struct sock___56 *);
	void (*hash)(struct sock___56 *);
	void (*unhash)(struct sock___56 *);
	void (*rehash)(struct sock___56 *);
	int (*get_port)(struct sock___56 *, short unsigned int);
	void (*clear_sk)(struct sock___56 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___56 *);
	void (*enter_memory_pressure)(struct sock___56 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___259 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___41 *rsk_prot;
	struct timewait_sock_ops___38 *twsk_prot;
	union {
		struct inet_hashinfo___12 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___173 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___103 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___55 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___55 {
	void (*enter_memory_pressure)(struct sock___56 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___12 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___259 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___41 {
	int family;
	int obj_size;
	struct kmem_cache___259 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___56 *, struct request_sock___42 *);
	void (*send_ack)(struct sock___56 *, struct sk_buff___69 *, struct request_sock___42 *);
	void (*send_reset)(struct sock___56 *, struct sk_buff___69 *);
	void (*destructor)(struct request_sock___42 *);
	void (*syn_ack_timeout)(struct sock___56 *, struct request_sock___42 *);
};

struct timewait_sock_ops___38 {
	struct kmem_cache___259 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___56 *, struct sock___56 *, void *);
	void (*twsk_destructor)(struct sock___56 *);
};

struct listen_sock___8 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___42 *syn_table[0];
};

struct fastopen_queue___8 {
	struct request_sock___42 *rskq_rst_head;
	struct request_sock___42 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___8 {
	struct request_sock___42 *rskq_accept_head;
	struct request_sock___42 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___8 *listen_opt;
	struct fastopen_queue___8 *fastopenq;
};

struct inet_request_sock___4 {
	struct request_sock___42 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___69 *pktopts;
	};
};

struct inet_cork___13 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___56 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___13 {
	struct inet_cork___13 base;
	struct flowi fl;
};

struct ipv6_pinfo___12;

struct inet_sock___13 {
	struct sock___56 sk;
	struct ipv6_pinfo___12 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___13 cork;
};

struct ipv6_fl_socklist___11;

struct ipv6_pinfo___12 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___11 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___69 *pktoptions;
	struct sk_buff___69 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___8;

struct inet_connection_sock_af_ops___8 {
	int (*queue_xmit)(struct sk_buff___69 *, struct flowi *);
	void (*send_check)(struct sock___56 *, struct sk_buff___69 *);
	int (*rebuild_header)(struct sock___56 *);
	void (*sk_rx_dst_set)(struct sock___56 *, const struct sk_buff___69 *);
	int (*conn_request)(struct sock___56 *, struct sk_buff___69 *);
	struct sock___56 * (*syn_recv_sock)(struct sock___56 *, struct sk_buff___69 *, struct request_sock___42 *, struct dst_entry___56 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___56 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___56 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___56 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___56 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___56 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___56 *, const struct inet_bind_bucket___8 *, bool);
	void (*mtu_reduced)(struct sock___56 *);
};

struct inet_bind_bucket___8 {
	struct net___80 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___4;

struct inet_connection_sock___8 {
	struct inet_sock___13 icsk_inet;
	struct request_sock_queue___8 icsk_accept_queue;
	struct inet_bind_bucket___8 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___4 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___8 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___56 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___4 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___56 *);
	void (*release)(struct sock___56 *);
	u32 (*ssthresh)(struct sock___56 *);
	void (*cong_avoid)(struct sock___56 *, u32, u32);
	void (*set_state)(struct sock___56 *, u8);
	void (*cwnd_event)(struct sock___56 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___56 *, u32);
	u32 (*undo_cwnd)(struct sock___56 *);
	void (*pkts_acked)(struct sock___56 *, u32, s32);
	int (*get_info)(struct sock___56 *, u32, struct sk_buff___69 *);
	char name[16];
	struct module___173 *owner;
};

struct tcp_request_sock_ops___3;

struct tcp_request_sock___4 {
	struct inet_request_sock___4 req;
	const struct tcp_request_sock_ops___3 *af_specific;
	struct sock___56 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___3 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___56 *, struct request_sock___42 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___56 *, const struct request_sock___42 *, const struct sk_buff___69 *);
	void (*init_req)(struct request_sock___42 *, struct sock___56 *, struct sk_buff___69 *);
	__u32 (*cookie_init_seq)(struct sock___56 *, const struct sk_buff___69 *, __u16 *);
	struct dst_entry___56 * (*route_req)(struct sock___56 *, struct flowi *, const struct request_sock___42 *, bool *);
	__u32 (*init_seq)(const struct sk_buff___69 *);
	int (*send_synack)(struct sock___56 *, struct dst_entry___56 *, struct flowi *, struct request_sock___42 *, u16, struct tcp_fastopen_cookie *);
	void (*queue_hash_add)(struct sock___56 *, struct request_sock___42 *, const long unsigned int);
};

struct tcp_sock_af_ops___4;

struct tcp_sock___5 {
	struct inet_connection_sock___8 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___67 prequeue;
		struct task_struct___277 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___11 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___5 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___69 *lost_skb_hint;
	struct sk_buff___69 *retransmit_skb_hint;
	struct sk_buff_head___67 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___69 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___4 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___42 *fastopen_rsk;
};

struct tcp_sock_af_ops___4 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___56 *, struct sock___56 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___56 *, const struct request_sock___42 *, const struct sk_buff___69 *);
	int (*md5_parse)(struct sock___56 *, char *, int);
};

struct ip6_flowlabel___11;

struct ipv6_fl_socklist___11 {
	struct ipv6_fl_socklist___11 *next;
	struct ip6_flowlabel___11 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___32 {
	struct in6_addr mca_addr;
	struct inet6_dev___32 *idev;
	struct ifmcaddr6___32 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___32 {
	struct in6_addr aca_addr;
	struct inet6_dev___32 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___32 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___11 {
	struct ip6_flowlabel___11 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___80 *fl_net;
};

struct module_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___172 *, struct module_kobject___172 *, char *);
	ssize_t (*store)(struct module_attribute___172 *, struct module_kobject___172 *, const char *, size_t);
	void (*setup)(struct module___173 *, const char *);
	int (*test)(struct module___173 *);
	void (*free)(struct module___173 *);
};

struct tcp_out_options {
	u16 options;
	u16 mss;
	u8 ws;
	u8 num_sack_blocks;
	u8 hash_size;
	__u8 *hash_location;
	__u32 tsval;
	__u32 tsecr;
	struct tcp_fastopen_cookie *fastopen_cookie;
};

struct tsq_tasklet {
	struct tasklet_struct tasklet;
	struct list_head head;
};

struct dma_device___11;

struct dma_chan_dev___11;

struct dma_chan___12 {
	struct dma_device___11 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___11 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___11;

struct dma_device___11 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___264 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___12 *);
	void (*device_free_chan_resources)(struct dma_chan___12 *);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_memcpy)(struct dma_chan___12 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_xor)(struct dma_chan___12 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_xor_val)(struct dma_chan___12 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_pq)(struct dma_chan___12 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_pq_val)(struct dma_chan___12 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_memset)(struct dma_chan___12 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_interrupt)(struct dma_chan___12 *, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_sg)(struct dma_chan___12 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___11 * (*device_prep_slave_sg)(struct dma_chan___12 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___11 * (*device_prep_dma_cyclic)(struct dma_chan___12 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___11 * (*device_prep_interleaved_dma)(struct dma_chan___12 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___12 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___12 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___12 *);
};

struct dma_chan_dev___11 {
	struct dma_chan___12 *chan;
	struct device___264 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___11 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___12 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___11 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___6 {
	char *base_address;
	int nr_pages;
	struct page___265 **pages;
};

struct dma_pinned_list___6 {
	int nr_iovecs;
	struct dma_page_list___6 page_list[0];
};

struct listen_sock___9 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___32 *syn_table[0];
};

struct fastopen_queue___9 {
	struct request_sock___32 *rskq_rst_head;
	struct request_sock___32 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___9 {
	struct request_sock___32 *rskq_accept_head;
	struct request_sock___32 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___9 *listen_opt;
	struct fastopen_queue___9 *fastopenq;
};

struct inet_cork___14 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___46 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___14 {
	struct inet_cork___14 base;
	struct flowi fl;
};

struct ipv6_pinfo___13;

struct inet_sock___14 {
	struct sock___46 sk;
	struct ipv6_pinfo___13 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___14 cork;
};

struct ipv6_fl_socklist___12;

struct ipv6_pinfo___13 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___12 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___59 *pktoptions;
	struct sk_buff___59 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___9;

struct inet_connection_sock_af_ops___9 {
	int (*queue_xmit)(struct sk_buff___59 *, struct flowi *);
	void (*send_check)(struct sock___46 *, struct sk_buff___59 *);
	int (*rebuild_header)(struct sock___46 *);
	void (*sk_rx_dst_set)(struct sock___46 *, const struct sk_buff___59 *);
	int (*conn_request)(struct sock___46 *, struct sk_buff___59 *);
	struct sock___46 * (*syn_recv_sock)(struct sock___46 *, struct sk_buff___59 *, struct request_sock___32 *, struct dst_entry___46 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___46 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___46 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___46 *, const struct inet_bind_bucket___9 *, bool);
	void (*mtu_reduced)(struct sock___46 *);
};

struct inet_bind_bucket___9 {
	struct net___70 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___5;

struct inet_connection_sock___9 {
	struct inet_sock___14 icsk_inet;
	struct request_sock_queue___9 icsk_accept_queue;
	struct inet_bind_bucket___9 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___5 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___9 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___46 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___5 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___46 *);
	void (*release)(struct sock___46 *);
	u32 (*ssthresh)(struct sock___46 *);
	void (*cong_avoid)(struct sock___46 *, u32, u32);
	void (*set_state)(struct sock___46 *, u8);
	void (*cwnd_event)(struct sock___46 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___46 *, u32);
	u32 (*undo_cwnd)(struct sock___46 *);
	void (*pkts_acked)(struct sock___46 *, u32, s32);
	int (*get_info)(struct sock___46 *, u32, struct sk_buff___59 *);
	char name[16];
	struct module___164 *owner;
};

struct tcp_sock_af_ops___5;

struct tcp_sock___6 {
	struct inet_connection_sock___9 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___57 prequeue;
		struct task_struct___267 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___12 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___6 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___59 *lost_skb_hint;
	struct sk_buff___59 *retransmit_skb_hint;
	struct sk_buff_head___57 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___59 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___5 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___32 *fastopen_rsk;
};

struct tcp_sock_af_ops___5 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___46 *, struct sock___46 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___46 *, const struct request_sock___32 *, const struct sk_buff___59 *);
	int (*md5_parse)(struct sock___46 *, char *, int);
};

struct ip6_flowlabel___12;

struct ipv6_fl_socklist___12 {
	struct ipv6_fl_socklist___12 *next;
	struct ip6_flowlabel___12 *fl;
	struct callback_head rcu;
};

struct ip6_flowlabel___12 {
	struct ip6_flowlabel___12 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___70 *fl_net;
};

enum {
	ICMP_MIB_NUM = 0,
	ICMP_MIB_INMSGS = 1,
	ICMP_MIB_INERRORS = 2,
	ICMP_MIB_INDESTUNREACHS = 3,
	ICMP_MIB_INTIMEEXCDS = 4,
	ICMP_MIB_INPARMPROBS = 5,
	ICMP_MIB_INSRCQUENCHS = 6,
	ICMP_MIB_INREDIRECTS = 7,
	ICMP_MIB_INECHOS = 8,
	ICMP_MIB_INECHOREPS = 9,
	ICMP_MIB_INTIMESTAMPS = 10,
	ICMP_MIB_INTIMESTAMPREPS = 11,
	ICMP_MIB_INADDRMASKS = 12,
	ICMP_MIB_INADDRMASKREPS = 13,
	ICMP_MIB_OUTMSGS = 14,
	ICMP_MIB_OUTERRORS = 15,
	ICMP_MIB_OUTDESTUNREACHS = 16,
	ICMP_MIB_OUTTIMEEXCDS = 17,
	ICMP_MIB_OUTPARMPROBS = 18,
	ICMP_MIB_OUTSRCQUENCHS = 19,
	ICMP_MIB_OUTREDIRECTS = 20,
	ICMP_MIB_OUTECHOS = 21,
	ICMP_MIB_OUTECHOREPS = 22,
	ICMP_MIB_OUTTIMESTAMPS = 23,
	ICMP_MIB_OUTTIMESTAMPREPS = 24,
	ICMP_MIB_OUTADDRMASKS = 25,
	ICMP_MIB_OUTADDRMASKREPS = 26,
	ICMP_MIB_CSUMERRORS = 27,
	__ICMP_MIB_MAX = 28,
};

struct seq_net_private___7 {
	struct net___79 *net;
};

struct pernet_operations___16 {
	struct list_head list;
	int (*init)(struct net___79 *);
	void (*exit)(struct net___79 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct inet_request_sock___5 {
	struct request_sock___41 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___68 *pktopts;
	};
};

struct icmp_err {
	int errno;
	unsigned int fatal: 1;
};

struct inet_timewait_sock___5 {
	struct sock_common___54 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___6 *tw_tb;
	struct hlist_node tw_death_node;
};

struct tcp_md5sig {
	struct __kernel_sockaddr_storage tcpm_addr;
	__u16 __tcpm_pad1;
	__u16 tcpm_keylen;
	__u32 __tcpm_pad2;
	__u8 tcpm_key[80];
};

struct tcp_request_sock_ops___4;

struct tcp_request_sock___5 {
	struct inet_request_sock___5 req;
	const struct tcp_request_sock_ops___4 *af_specific;
	struct sock___55 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___4 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___55 *, struct request_sock___41 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___55 *, const struct request_sock___41 *, const struct sk_buff___68 *);
	void (*init_req)(struct request_sock___41 *, struct sock___55 *, struct sk_buff___68 *);
	__u32 (*cookie_init_seq)(struct sock___55 *, const struct sk_buff___68 *, __u16 *);
	struct dst_entry___55 * (*route_req)(struct sock___55 *, struct flowi *, const struct request_sock___41 *, bool *);
	__u32 (*init_seq)(const struct sk_buff___68 *);
	int (*send_synack)(struct sock___55 *, struct dst_entry___55 *, struct flowi *, struct request_sock___41 *, u16, struct tcp_fastopen_cookie *);
	void (*queue_hash_add)(struct sock___55 *, struct request_sock___41 *, const long unsigned int);
};

struct tcp_timewait_sock {
	struct inet_timewait_sock___5 tw_sk;
	u32 tw_rcv_nxt;
	u32 tw_snd_nxt;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	long int tw_ts_recent_stamp;
	struct tcp_md5sig_key *tw_md5_key;
};

enum tcp_tw_status {
	TCP_TW_SUCCESS = 0,
	TCP_TW_RST = 1,
	TCP_TW_ACK = 2,
	TCP_TW_SYN = 3,
};

enum tcp_seq_states {
	TCP_SEQ_STATE_LISTENING = 0,
	TCP_SEQ_STATE_OPENREQ = 1,
	TCP_SEQ_STATE_ESTABLISHED = 2,
};

struct tcp_seq_afinfo {
	char *name;
	sa_family_t family;
	const struct file_operations___275 *seq_fops;
	struct seq_operations___200 seq_ops;
};

struct tcp_iter_state {
	struct seq_net_private___7 p;
	sa_family_t family;
	enum tcp_seq_states state;
	struct sock___55 *syn_wait_sk;
	int bucket;
	int offset;
	int sbucket;
	int num;
	kuid_t uid;
	loff_t last_pos;
};

struct page___276;

typedef struct page___276 *pgtable_t___276;

struct address_space___277;

struct kmem_cache___260;

struct page___276 {
	long unsigned int flags;
	struct address_space___277 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___276 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___276 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___260 *slab_cache;
		struct page___276 *first_page;
	};
	long: 64;
};

struct task_struct___278;

struct pv_cpu_ops___278 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___278 *);
	void (*end_context_switch)(struct task_struct___278 *);
};

struct mutex___279 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___278 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___271 {
	struct page___276 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___285;

struct nsproxy___157;

struct signal_struct___278;

struct css_set___172;

struct task_struct___278 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___278 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___285 *mm;
	struct mm_struct___285 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___278 *real_parent;
	struct task_struct___278 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___278 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___278 = 0,
		VTIME_USER___278 = 1,
		VTIME_SYS___278 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___157 *nsproxy;
	struct signal_struct___278 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___172 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___279 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___271 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___285 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___285 *, struct mm_struct___285 *);
	void (*dup_mmap)(struct mm_struct___285 *, struct mm_struct___285 *);
	void (*exit_mmap)(struct mm_struct___285 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___285 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___285 *);
	void (*pgd_free)(struct mm_struct___285 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___285 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___285 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___285 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___285 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___285 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___285 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___285 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___285 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___285 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___285 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___285 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___279 lock;
	void *vdso;
} mm_context_t___279;

struct xol_area___276;

struct uprobes_state___276 {
	struct xol_area___276 *xol_area;
};

struct vm_area_struct___285;

struct file___277;

struct core_state___278;

struct mm_struct___285 {
	struct vm_area_struct___285 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___285 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___285 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___279 context;
	long unsigned int flags;
	struct core_state___278 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___278 *owner;
	struct file___277 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___276 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___59;

struct kobj_type___59;

struct kobject___59 {
	const char *name;
	struct list_head entry;
	struct kobject___59 *parent;
	struct kset___59 *kset;
	struct kobj_type___59 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___173 {
	struct kobject___59 kobj;
	struct module___145 *mod;
	struct kobject___59 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___173;

struct module___145 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___173 mkobj;
	struct module_attribute___173 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___59 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___278 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___278;

struct lruvec___278 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___278 *zone;
};

struct pglist_data___278;

struct zone___278 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___278 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___278 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___278 {
	struct zone___278 *zone;
	int zone_idx;
};

struct zonelist___278 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___278 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___278 {
	struct zone___278 node_zones[4];
	struct zonelist___278 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___278 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___201;

struct x86_io_apic_ops___201 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___201 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___201;

struct irq_data___201 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___201 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___275;

struct dev_pm_ops___275 {
	int (*prepare)(struct device___275 *);
	void (*complete)(struct device___275 *);
	int (*suspend)(struct device___275 *);
	int (*resume)(struct device___275 *);
	int (*freeze)(struct device___275 *);
	int (*thaw)(struct device___275 *);
	int (*poweroff)(struct device___275 *);
	int (*restore)(struct device___275 *);
	int (*suspend_late)(struct device___275 *);
	int (*resume_early)(struct device___275 *);
	int (*freeze_late)(struct device___275 *);
	int (*thaw_early)(struct device___275 *);
	int (*poweroff_late)(struct device___275 *);
	int (*restore_early)(struct device___275 *);
	int (*suspend_noirq)(struct device___275 *);
	int (*resume_noirq)(struct device___275 *);
	int (*freeze_noirq)(struct device___275 *);
	int (*thaw_noirq)(struct device___275 *);
	int (*poweroff_noirq)(struct device___275 *);
	int (*restore_noirq)(struct device___275 *);
	int (*runtime_suspend)(struct device___275 *);
	int (*runtime_resume)(struct device___275 *);
	int (*runtime_idle)(struct device___275 *);
};

struct dev_pm_qos___78;

struct dev_pm_info___78 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___78 *qos;
};

struct dma_map_ops___140;

struct dev_archdata___140 {
	struct dma_map_ops___140 *dma_ops;
	void *iommu;
};

struct device_type___275;

struct bus_type___275;

struct device_driver___275;

struct dev_pm_domain___275;

struct class___275;

struct attribute_group___237;

struct device_rh___275;

struct device___275 {
	struct device___275 *parent;
	struct device_private *p;
	struct kobject___59 kobj;
	const char *init_name;
	const struct device_type___275 *type;
	struct mutex___279 mutex;
	struct bus_type___275 *bus;
	struct device_driver___275 *driver;
	void *platform_data;
	struct dev_pm_info___78 power;
	struct dev_pm_domain___275 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___140 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___275 *class;
	const struct attribute_group___237 **groups;
	void (*release)(struct device___275 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___275 *device_rh;
};

struct dev_pm_qos_request___79;

struct dev_pm_qos___78 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___79 *latency_req;
	struct dev_pm_qos_request___79 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___79 *latency_tolerance_req;
};

struct dev_pm_info_rh___275 {
	void (*set_latency_tolerance)(struct device___275 *, s32);
};

struct dev_pm_domain___275 {
	struct dev_pm_ops___275 ops;
};

struct smp_ops___278 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___278 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___276 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___276 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___259;

struct memcg_cache_params___260;

struct kmem_cache___260 {
	struct kmem_cache_cpu___259 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___59 kobj;
	struct memcg_cache_params___260 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___277;

struct address_space_operations___277;

struct address_space___277 {
	struct inode___277 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___279 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___277 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___277;

struct path___277 {
	struct vfsmount *mnt;
	struct dentry___277 *dentry;
};

struct file_operations___277;

struct file___277 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___277 f_path;
	struct inode___277 *f_inode;
	const struct file_operations___277 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___277 *f_mapping;
	struct mutex___279 f_pos_lock;
};

struct vm_operations_struct___251;

struct vm_area_struct___285 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___285 *vm_next;
	struct vm_area_struct___285 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___285 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___251 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___277 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___247;

struct vm_operations_struct___251 {
	void (*open)(struct vm_area_struct___285 *);
	void (*close)(struct vm_area_struct___285 *);
	int (*fault)(struct vm_area_struct___285 *, struct vm_fault___247 *);
	int (*page_mkwrite)(struct vm_area_struct___285 *, struct vm_fault___247 *);
	int (*access)(struct vm_area_struct___285 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___285 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___285 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___285 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___285 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___278 {
	struct task_struct___278 *task;
	struct core_thread___278 *next;
};

struct core_state___278 {
	atomic_t nr_threads;
	struct core_thread___278 dumper;
	struct completion startup;
};

struct vm_fault___247 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___276 *page;
};

struct ctl_table_header___82;

struct ctl_node___82 {
	struct rb_node node;
	struct ctl_table_header___82 *header;
};

struct ctl_table_root___82;

struct ctl_table_set___82;

struct ctl_dir___82;

struct ctl_table_header___82 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___82 *root;
	struct ctl_table_set___82 *set;
	struct ctl_dir___82 *parent;
	struct ctl_node___82 *node;
};

struct ctl_dir___82 {
	struct ctl_table_header___82 header;
	struct rb_root root;
};

struct ctl_table_set___82 {
	int (*is_seen)(struct ctl_table_set___82 *);
	struct ctl_dir___82 dir;
};

struct ctl_table_root___82 {
	struct ctl_table_set___82 default_set;
	struct ctl_table_set___82 * (*lookup)(struct ctl_table_root___82 *, struct nsproxy___157 *);
	int (*permissions)(struct ctl_table_header___82 *, struct ctl_table *);
};

struct net___81;

struct nsproxy___157 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___81 *net_ns;
};

struct kobj_ns_type_operations___56 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___26 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___56;

struct sock_common___56 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___56 *skc_prot;
	struct net___81 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff_head___68 {
	struct sk_buff___36 *next;
	struct sk_buff___36 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___57;

struct socket_wq___56;

struct xfrm_policy___12;

struct dst_entry___57;

struct socket___57;

struct cg_proto___56;

struct sock___26 {
	struct sock_common___56 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___68 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___36 *head;
		struct sk_buff___36 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___57 *sk_filter;
	struct socket_wq___56 *sk_wq;
	struct sk_buff_head___68 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___12 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___57 *sk_rx_dst;
	struct dst_entry___57 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___68 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___68 sk_error_queue;
	struct proto___56 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___57 *sk_socket;
	void *sk_user_data;
	struct page_frag___271 sk_frag;
	struct sk_buff___36 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___56 *sk_cgrp;
	void (*sk_state_change)(struct sock___26 *);
	void (*sk_data_ready)(struct sock___26 *, int);
	void (*sk_write_space)(struct sock___26 *);
	void (*sk_error_report)(struct sock___26 *);
	int (*sk_backlog_rcv)(struct sock___26 *, struct sk_buff___36 *);
	void (*sk_destruct)(struct sock___26 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___239;

struct attribute_group___237 {
	const char *name;
	umode_t (*is_visible)(struct kobject___59 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___239 **bin_attrs;
};

struct bin_attribute___239 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___277 *, struct kobject___59 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___277 *, struct kobject___59 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	int (*mmap)(struct file___277 *, struct kobject___59 *, struct bin_attribute___239 *, struct vm_area_struct___285 *);
};

struct sysfs_ops___59 {
	ssize_t (*show)(struct kobject___59 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___59 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___59 *, const struct attribute *);
};

struct kset_uevent_ops___59;

struct kset___59 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___59 kobj;
	const struct kset_uevent_ops___59 *uevent_ops;
};

struct kobj_type___59 {
	void (*release)(struct kobject___59 *);
	const struct sysfs_ops___59 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___56 * (*child_ns_type)(struct kobject___59 *);
	const void * (*namespace)(struct kobject___59 *);
};

struct kset_uevent_ops___59 {
	int (* const filter)(struct kset___59 *, struct kobject___59 *);
	const char * (* const name)(struct kset___59 *, struct kobject___59 *);
	int (* const uevent)(struct kset___59 *, struct kobject___59 *, struct kobj_uevent_env *);
};

struct module_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___173 *, struct module_kobject___173 *, char *);
	ssize_t (*store)(struct module_attribute___173 *, struct module_kobject___173 *, const char *, size_t);
	void (*setup)(struct module___145 *, const char *);
	int (*test)(struct module___145 *);
	void (*free)(struct module___145 *);
};

struct kmem_cache_cpu___259 {
	void **freelist;
	long unsigned int tid;
	struct page___276 *page;
	struct page___276 *partial;
};

struct memcg_cache_params___260 {
	bool is_root_cache;
	union {
		struct kmem_cache___260 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___260 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct fasync_struct___277;

struct socket_wq___56 {
	wait_queue_head_t wait;
	struct fasync_struct___277 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___277 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___277 *fa_next;
	struct file___277 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___56;

struct socket___57 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___56 *wq;
	struct file___277 *file;
	struct sock___26 *sk;
	const struct proto_ops___56 *ops;
};

struct poll_table_struct___163;

struct kiocb___64;

struct proto_ops___56 {
	int family;
	struct module___145 *owner;
	int (*release)(struct socket___57 *);
	int (*bind)(struct socket___57 *, struct sockaddr *, int);
	int (*connect)(struct socket___57 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___57 *, struct socket___57 *);
	int (*accept)(struct socket___57 *, struct socket___57 *, int);
	int (*getname)(struct socket___57 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___277 *, struct socket___57 *, struct poll_table_struct___163 *);
	int (*ioctl)(struct socket___57 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___57 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___57 *, int);
	int (*shutdown)(struct socket___57 *, int);
	int (*setsockopt)(struct socket___57 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___57 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___57 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___57 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___64 *, struct socket___57 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___64 *, struct socket___57 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___277 *, struct socket___57 *, struct vm_area_struct___285 *);
	ssize_t (*sendpage)(struct socket___57 *, struct page___276 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___57 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___26 *, int);
		struct {
			void (*set_peek_off)(struct sock___26 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___165)(struct file___277 *, wait_queue_head_t *, struct poll_table_struct___163 *);

struct poll_table_struct___163 {
	poll_queue_proc___165 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___64(struct kiocb___64 *, struct io_event *);

struct kiocb___64 {
	atomic_t ki_users;
	struct file___277 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___64 *ki_cancel;
	void (*ki_dtor)(struct kiocb___64 *);
	union {
		void *user;
		struct task_struct___278 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___79 {
	struct ctl_table_header___82 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___80 {
	struct mutex___279 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___79 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___82 *ctl;
};

struct netns_ipv4___79 {
	struct ctl_table_header___82 *forw_hdr;
	struct ctl_table_header___82 *frags_hdr;
	struct ctl_table_header___82 *ipv4_hdr;
	struct ctl_table_header___82 *route_hdr;
	struct ctl_table_header___82 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___26 *fibnl;
	struct sock___26 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___79 {
	struct ctl_table_header___82 *hdr;
	struct ctl_table_header___82 *route_hdr;
	struct ctl_table_header___82 *icmp_hdr;
	struct ctl_table_header___82 *frags_hdr;
	struct ctl_table_header___82 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___67;

struct neighbour___57;

struct dst_ops___81 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___81 *);
	struct dst_entry___57 * (*check)(struct dst_entry___57 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___57 *);
	unsigned int (*mtu)(const struct dst_entry___57 *);
	u32 * (*cow_metrics)(struct dst_entry___57 *, long unsigned int);
	void (*destroy)(struct dst_entry___57 *);
	void (*ifdown)(struct dst_entry___57 *, struct net_device___67 *, int);
	struct dst_entry___57 * (*negative_advice)(struct dst_entry___57 *);
	void (*link_failure)(struct sk_buff___36 *);
	void (*update_pmtu)(struct dst_entry___57 *, struct sock___26 *, struct sk_buff___36 *, u32);
	void (*redirect)(struct dst_entry___57 *, struct sock___26 *, struct sk_buff___36 *);
	int (*local_out)(struct sk_buff___36 *);
	struct neighbour___57 * (*neigh_lookup)(const struct dst_entry___57 *, struct sk_buff___36 *, const void *);
	struct kmem_cache___260 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___12;

struct fib6_table___12;

struct netns_ipv6___81 {
	struct netns_sysctl_ipv6___79 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___12 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___12 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___81 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___12 *ip6_prohibit_entry;
	struct rt6_info___12 *ip6_blk_hole_entry;
	struct fib6_table___12 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___26 **icmp_sk;
	struct sock___26 *ndisc_sk;
	struct sock___26 *tcp_sk;
	struct sock___26 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___79 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___82 *sysctl_header;
	struct sock___26 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___56 {
	struct sock___26 *v4_ctl_sk;
	struct sock___26 *v6_ctl_sk;
};

struct netns_nf___79 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___82 *nf_log_dir_header;
};

struct nf_proto_net___79 {
	struct ctl_table_header___82 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___79 {
	struct nf_proto_net___79 pn;
	unsigned int timeout;
};

struct nf_tcp_net___79 {
	struct nf_proto_net___79 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___79 {
	struct nf_proto_net___79 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___79 {
	struct nf_proto_net___79 pn;
	unsigned int timeout;
};

struct nf_ip_net___79 {
	struct nf_generic_net___79 generic;
	struct nf_tcp_net___79 tcp;
	struct nf_udp_net___79 udp;
	struct nf_icmp_net___79 icmp;
	struct nf_icmp_net___79 icmpv6;
};

struct netns_ct___80 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___82 *sysctl_header;
	struct ctl_table_header___82 *acct_sysctl_header;
	struct ctl_table_header___82 *tstamp_sysctl_header;
	struct ctl_table_header___82 *event_sysctl_header;
	struct ctl_table_header___82 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___260 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___79 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___79 {
	struct netns_sysctl_ipv6___79 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___81 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___26 *nlsk;
	struct sock___26 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___82 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___81 xfrm4_dst_ops;
	struct dst_ops___81 xfrm6_dst_ops;
};

struct net___81 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___82 sysctls;
	struct sock___26 *rtnl;
	struct sock___26 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___67 *loopback_dev;
	struct netns_core___79 core;
	struct netns_mib mib;
	struct netns_packet___80 packet;
	struct netns_unix___79 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___79 ipv4;
	struct netns_ipv6___81 ipv6;
	struct netns_sctp___79 sctp;
	struct netns_dccp___56 dccp;
	struct netns_nf___79 nf;
	struct netns_xt xt;
	struct netns_ct___80 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___79 nf_frag;
	struct sock___26 *nfnl;
	struct sock___26 *nfnl_stash;
	struct sk_buff_head___68 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___81 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___26 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___26 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___279 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___279 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___140 {
	void * (*alloc)(struct device___275 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___275 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___275 *, struct vm_area_struct___285 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___275 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___275 *, struct page___276 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___275 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___275 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___275 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___275 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___275 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___275 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___275 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___275 *, dma_addr_t);
	int (*dma_supported)(struct device___275 *, u64);
	int (*set_dma_mask)(struct device___275 *, u64);
	int is_phys;
};

struct bus_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___275 *, char *);
	ssize_t (*store)(struct bus_type___275 *, const char *, size_t);
};

struct device_attribute___275;

struct driver_attribute___275;

struct bus_type___275 {
	const char *name;
	const char *dev_name;
	struct device___275 *dev_root;
	struct bus_attribute___275 *bus_attrs;
	struct device_attribute___275 *dev_attrs;
	struct driver_attribute___275 *drv_attrs;
	const struct attribute_group___237 **bus_groups;
	const struct attribute_group___237 **dev_groups;
	const struct attribute_group___237 **drv_groups;
	int (*match)(struct device___275 *, struct device_driver___275 *);
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	int (*probe)(struct device___275 *);
	int (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*online)(struct device___275 *);
	int (*offline)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct device___275 *, struct device_attribute___275 *, char *);
	ssize_t (*store)(struct device___275 *, struct device_attribute___275 *, const char *, size_t);
};

struct driver_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___275 *, char *);
	ssize_t (*store)(struct device_driver___275 *, const char *, size_t);
};

struct device_driver___275 {
	const char *name;
	struct bus_type___275 *bus;
	struct module___145 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___275 *);
	int (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	const struct attribute_group___237 **groups;
	const struct dev_pm_ops___275 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___275 {
	const char *name;
	const struct attribute_group___237 **groups;
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
};

struct class_attribute___275;

struct class___275 {
	const char *name;
	struct module___145 *owner;
	struct class_attribute___275 *class_attrs;
	struct device_attribute___275 *dev_attrs;
	const struct attribute_group___237 **dev_groups;
	struct bin_attribute___239 *dev_bin_attrs;
	struct kobject___59 *dev_kobj;
	int (*dev_uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *);
	void (*class_release)(struct class___275 *);
	void (*dev_release)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	const struct kobj_ns_type_operations___56 *ns_type;
	const void * (*namespace)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
	struct subsys_private *p;
};

struct class_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct class___275 *, struct class_attribute___275 *, char *);
	ssize_t (*store)(struct class___275 *, struct class_attribute___275 *, const char *, size_t);
	const void * (*namespace)(struct class___275 *, const struct class_attribute___275 *);
};

struct device_rh___275 {
	struct dev_pm_info_rh___275 power;
};

struct dma_device___12;

struct dma_chan_dev___12;

struct dma_chan___13 {
	struct dma_device___12 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___12 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___12;

struct dma_device___12 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___275 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___13 *);
	void (*device_free_chan_resources)(struct dma_chan___13 *);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_memcpy)(struct dma_chan___13 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_xor)(struct dma_chan___13 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_xor_val)(struct dma_chan___13 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_pq)(struct dma_chan___13 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_pq_val)(struct dma_chan___13 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_memset)(struct dma_chan___13 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_interrupt)(struct dma_chan___13 *, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_sg)(struct dma_chan___13 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___12 * (*device_prep_slave_sg)(struct dma_chan___13 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___12 * (*device_prep_dma_cyclic)(struct dma_chan___13 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___12 * (*device_prep_interleaved_dma)(struct dma_chan___13 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___13 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___13 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___13 *);
};

struct dma_chan_dev___12 {
	struct dma_chan___13 *chan;
	struct device___275 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___12 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___13 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___12 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___7 {
	char *base_address;
	int nr_pages;
	struct page___276 **pages;
};

struct dma_pinned_list___7 {
	int nr_iovecs;
	struct dma_page_list___7 page_list[0];
};

struct signal_struct___278 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___278 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___278 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___279 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___172;

struct css_set___172 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___172 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___67 {
	atomic_t use;
	unsigned int mask;
	struct net_device___67 *physindev;
	struct net_device___67 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___67(struct sk_buff___36 **);

struct net_device_ops___67;

struct ethtool_ops___67;

struct header_ops___67;

struct inet6_dev___33;

struct netdev_rx_queue___67;

struct netdev_queue___67;

struct rtnl_link_ops___58;

struct dcbnl_rtnl_ops___67;

struct net_device___67 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___67 *netdev_ops;
	const struct ethtool_ops___67 *ethtool_ops;
	const struct header_ops___67 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___59 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___33 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___67 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___67 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___67 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___67 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___67 = 0,
		NETREG_REGISTERED___67 = 1,
		NETREG_UNREGISTERING___67 = 2,
		NETREG_UNREGISTERED___67 = 3,
		NETREG_RELEASED___67 = 4,
		NETREG_DUMMY___67 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___67 = 0,
		RTNL_LINK_INITIALIZING___67 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___67 *);
	struct netpoll_info *npinfo;
	struct net___81 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___275 dev;
	const struct attribute_group___237 *sysfs_groups[4];
	const struct rtnl_link_ops___58 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___67 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___12;

struct sk_buff___36 {
	struct sk_buff___36 *next;
	struct sk_buff___36 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___26 *sk;
	struct net_device___67 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___12 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___36 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___67 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___12;

struct sec_path___12 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___12 *xvec[6];
};

struct seq_file___202;

struct irq_chip___201 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___201 *);
	void (*irq_shutdown)(struct irq_data___201 *);
	void (*irq_enable)(struct irq_data___201 *);
	void (*irq_disable)(struct irq_data___201 *);
	void (*irq_ack)(struct irq_data___201 *);
	void (*irq_mask)(struct irq_data___201 *);
	void (*irq_mask_ack)(struct irq_data___201 *);
	void (*irq_unmask)(struct irq_data___201 *);
	void (*irq_eoi)(struct irq_data___201 *);
	int (*irq_set_affinity)(struct irq_data___201 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___201 *);
	int (*irq_set_type)(struct irq_data___201 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___201 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___201 *);
	void (*irq_bus_sync_unlock)(struct irq_data___201 *);
	void (*irq_cpu_online)(struct irq_data___201 *);
	void (*irq_cpu_offline)(struct irq_data___201 *);
	void (*irq_suspend)(struct irq_data___201 *);
	void (*irq_resume)(struct irq_data___201 *);
	void (*irq_pm_shutdown)(struct irq_data___201 *);
	void (*irq_print_chip)(struct irq_data___201 *, struct seq_file___202 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___201 *, void *);
	long unsigned int flags;
};

struct seq_operations___202;

struct seq_file___202 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___279 lock;
	const struct seq_operations___202 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct file_lock___277;

struct file_operations___277 {
	struct module___145 *owner;
	loff_t (*llseek)(struct file___277 *, loff_t, int);
	ssize_t (*read)(struct file___277 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___277 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___64 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___64 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___277 *, void *, filldir_t);
	unsigned int (*poll)(struct file___277 *, struct poll_table_struct___163 *);
	long int (*unlocked_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___277 *, struct vm_area_struct___285 *);
	int (*open)(struct inode___277 *, struct file___277 *);
	int (*flush)(struct file___277 *, fl_owner_t);
	int (*release)(struct inode___277 *, struct file___277 *);
	int (*fsync)(struct file___277 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___64 *, int);
	int (*fasync)(int, struct file___277 *, int);
	int (*lock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*sendpage)(struct file___277 *, struct page___276 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___277 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___277 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___277 *, long int, struct file_lock___277 **, void **);
		struct {
			int (*setlease)(struct file___277 *, long int, struct file_lock___277 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___277 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___202 *, struct file___277 *);
};

struct dev_pm_qos_request___79 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___275 *dev;
};

struct dentry_operations___277;

struct super_block___277;

struct dentry___277 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___277 *d_parent;
	struct qstr d_name;
	struct inode___277 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___277 *d_op;
	struct super_block___277 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___277;

struct dquot___277;

struct block_device___277;

struct inode___277 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___277 *i_op;
	struct super_block___277 *i_sb;
	struct address_space___277 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___279 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___277 *i_fop;
	struct file_lock___277 *i_flock;
	struct address_space___277 i_data;
	struct dquot___277 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___277 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___277 {
	int (*d_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_hash)(const struct dentry___277 *, struct qstr *);
	int (*d_compare)(const struct dentry___277 *, const struct dentry___277 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___277 *);
	void (*d_release)(struct dentry___277 *);
	void (*d_prune)(struct dentry___277 *);
	void (*d_iput)(struct dentry___277 *, struct inode___277 *);
	char * (*d_dname)(struct dentry___277 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___277 *);
	int (*d_manage)(struct dentry___277 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___277;

struct mem_dqinfo___277 {
	struct quota_format_type___277 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___277;

struct quota_info___277 {
	unsigned int flags;
	struct mutex___279 dqio_mutex;
	struct mutex___279 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___277 *files[2];
	struct mem_dqinfo___277 info[2];
	const struct quota_format_ops___277 *ops[2];
};

struct file_system_type___277;

struct super_operations___277;

struct dquot_operations___277;

struct quotactl_ops___277;

struct xattr_handler___173;

struct super_block___277 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___277 *s_type;
	const struct super_operations___277 *s_op;
	const struct dquot_operations___277 *dq_op;
	const struct quotactl_ops___277 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___277 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___173 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___277 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___277 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___279 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___277 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___277 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___277 *bd_inode;
	struct super_block___277 *bd_super;
	struct mutex___279 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___277 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___279 bd_fsfreeze_mutex;
};

struct cgroup___172;

struct cgroup_subsys_state___172 {
	struct cgroup___172 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___277 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___277 *ia_file;
};

struct dquot___277 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___279 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___277 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___277 {
	int qf_fmt_id;
	const struct quota_format_ops___277 *qf_ops;
	struct module___145 *qf_owner;
	struct quota_format_type___277 *qf_next;
};

struct quota_format_ops___277 {
	int (*check_quota_file)(struct super_block___277 *, int);
	int (*read_file_info)(struct super_block___277 *, int);
	int (*write_file_info)(struct super_block___277 *, int);
	int (*free_file_info)(struct super_block___277 *, int);
	int (*read_dqblk)(struct dquot___277 *);
	int (*commit_dqblk)(struct dquot___277 *);
	int (*release_dqblk)(struct dquot___277 *);
};

struct dquot_operations___277 {
	int (*write_dquot)(struct dquot___277 *);
	struct dquot___277 * (*alloc_dquot)(struct super_block___277 *, int);
	void (*destroy_dquot)(struct dquot___277 *);
	int (*acquire_dquot)(struct dquot___277 *);
	int (*release_dquot)(struct dquot___277 *);
	int (*mark_dirty)(struct dquot___277 *);
	int (*write_info)(struct super_block___277 *, int);
	qsize_t * (*get_reserved_space)(struct inode___277 *);
};

struct quotactl_ops___277 {
	int (*quota_on)(struct super_block___277 *, int, int, struct path___277 *);
	int (*quota_on_meta)(struct super_block___277 *, int, int);
	int (*quota_off)(struct super_block___277 *, int);
	int (*quota_sync)(struct super_block___277 *, int);
	int (*get_info)(struct super_block___277 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___277 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___277 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___277 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___277 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___277 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___277 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___277 *, unsigned int);
};

struct address_space_operations___277 {
	int (*writepage)(struct page___276 *, struct writeback_control *);
	int (*readpage)(struct file___277 *, struct page___276 *);
	int (*writepages)(struct address_space___277 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___276 *);
	int (*readpages)(struct file___277 *, struct address_space___277 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___277 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___276 **, void **);
	int (*write_end)(struct file___277 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___276 *, void *);
	sector_t (*bmap)(struct address_space___277 *, sector_t);
	void (*invalidatepage)(struct page___276 *, long unsigned int);
	int (*releasepage)(struct page___276 *, gfp_t);
	void (*freepage)(struct page___276 *);
	ssize_t (*direct_IO)(int, struct kiocb___64 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___277 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___277 *, struct page___276 *, struct page___276 *, enum migrate_mode);
	int (*launder_page)(struct page___276 *);
	int (*is_partially_uptodate)(struct page___276 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___276 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___277 *, struct page___276 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___277 *, sector_t *);
	void (*swap_deactivate)(struct file___277 *);
	void (*invalidatepage_range)(struct page___276 *, unsigned int, unsigned int);
};

struct inode_operations___277 {
	struct dentry___277 * (*lookup)(struct inode___277 *, struct dentry___277 *, unsigned int);
	void * (*follow_link)(struct dentry___277 *, struct nameidata *);
	int (*permission)(struct inode___277 *, int);
	struct posix_acl * (*get_acl)(struct inode___277 *, int);
	int (*readlink)(struct dentry___277 *, char *, int);
	void (*put_link)(struct dentry___277 *, struct nameidata *, void *);
	int (*create)(struct inode___277 *, struct dentry___277 *, umode_t, bool);
	int (*link)(struct dentry___277 *, struct inode___277 *, struct dentry___277 *);
	int (*unlink)(struct inode___277 *, struct dentry___277 *);
	int (*symlink)(struct inode___277 *, struct dentry___277 *, const char *);
	int (*mkdir)(struct inode___277 *, struct dentry___277 *, umode_t);
	int (*rmdir)(struct inode___277 *, struct dentry___277 *);
	int (*mknod)(struct inode___277 *, struct dentry___277 *, umode_t, dev_t);
	int (*rename)(struct inode___277 *, struct dentry___277 *, struct inode___277 *, struct dentry___277 *);
	int (*setattr)(struct dentry___277 *, struct iattr___277 *);
	int (*getattr)(struct vfsmount *, struct dentry___277 *, struct kstat *);
	int (*setxattr)(struct dentry___277 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___277 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___277 *, char *, size_t);
	int (*removexattr)(struct dentry___277 *, const char *);
	int (*fiemap)(struct inode___277 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___277 *, struct timespec *, int);
	int (*atomic_open)(struct inode___277 *, struct dentry___277 *, struct file___277 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___277;

struct lock_manager_operations___277;

struct file_lock___277 {
	struct file_lock___277 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___277 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___277 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___277 *fl_ops;
	const struct lock_manager_operations___277 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___277 {
	void (*fl_copy_lock)(struct file_lock___277 *, struct file_lock___277 *);
	void (*fl_release_private)(struct file_lock___277 *);
};

struct lock_manager_operations___277 {
	int (*lm_compare_owner)(struct file_lock___277 *, struct file_lock___277 *);
	long unsigned int (*lm_owner_key)(struct file_lock___277 *);
	void (*lm_notify)(struct file_lock___277 *);
	int (*lm_grant)(struct file_lock___277 *, struct file_lock___277 *, int);
	void (*lm_break)(struct file_lock___277 *);
	int (*lm_change)(struct file_lock___277 **, int);
};

struct file_system_type___277 {
	const char *name;
	int fs_flags;
	struct dentry___277 * (*mount)(struct file_system_type___277 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___277 *);
	struct module___145 *owner;
	struct file_system_type___277 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___277 {
	struct inode___277 * (*alloc_inode)(struct super_block___277 *);
	void (*destroy_inode)(struct inode___277 *);
	void (*dirty_inode)(struct inode___277 *, int);
	int (*write_inode)(struct inode___277 *, struct writeback_control *);
	int (*drop_inode)(struct inode___277 *);
	void (*evict_inode)(struct inode___277 *);
	void (*put_super)(struct super_block___277 *);
	int (*sync_fs)(struct super_block___277 *, int);
	int (*freeze_fs)(struct super_block___277 *);
	int (*unfreeze_fs)(struct super_block___277 *);
	int (*statfs)(struct dentry___277 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___277 *, int *, char *);
	void (*umount_begin)(struct super_block___277 *);
	int (*show_options)(struct seq_file___202 *, struct dentry___277 *);
	int (*show_devname)(struct seq_file___202 *, struct dentry___277 *);
	int (*show_path)(struct seq_file___202 *, struct dentry___277 *);
	int (*show_stats)(struct seq_file___202 *, struct dentry___277 *);
	ssize_t (*quota_read)(struct super_block___277 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___277 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___277 *);
	int (*bdev_try_to_free_page)(struct super_block___277 *, struct page___276 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___277 *);
	void (*free_cached_objects)(struct super_block___277 *, int);
};

struct xattr_handler___173 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___277 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___277 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___277 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___67 {
	int (*get_settings)(struct net_device___67 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___67 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___67 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___67 *);
	void (*get_regs)(struct net_device___67 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___67 *);
	void (*set_msglevel)(struct net_device___67 *, u32);
	int (*nway_reset)(struct net_device___67 *);
	u32 (*get_link)(struct net_device___67 *);
	int (*get_eeprom_len)(struct net_device___67 *);
	int (*get_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___67 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___67 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___67 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___67 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___67 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___67 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___67 *);
	void (*complete)(struct net_device___67 *);
	u32 (*get_priv_flags)(struct net_device___67 *);
	int (*set_priv_flags)(struct net_device___67 *, u32);
	int (*get_sset_count)(struct net_device___67 *, int);
	int (*get_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___67 *, struct ethtool_flash *);
	int (*reset)(struct net_device___67 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___67 *);
	int (*get_rxfh_indir)(struct net_device___67 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___67 *, const u32 *);
	void (*get_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___67 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___67 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___67 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___67 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___67 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___67 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___67 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___67 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___28;

struct dst_entry___57 {
	struct callback_head callback_head;
	struct dst_entry___57 *child;
	struct net_device___67 *dev;
	struct dst_ops___81 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___57 *path;
	struct dst_entry___57 *from;
	struct xfrm_state___12 *xfrm;
	int (*input)(struct sk_buff___36 *);
	union {
		int (*output)(struct sock___26 *, struct sk_buff___36 *);
		struct {
			int (*output)(struct sk_buff___36 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___57 *next;
		struct rtable___28 *rt_next;
		struct rt6_info___12 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___57;

struct neigh_parms___57;

struct neigh_ops___57;

struct neighbour___57 {
	struct neighbour___57 *next;
	struct neigh_table___57 *tbl;
	struct neigh_parms___57 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___68 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___57 *, struct sk_buff___36 *);
	const struct neigh_ops___57 *ops;
	struct callback_head rcu;
	struct net_device___67 *dev;
	u8 primary_key[0];
};

struct fib6_node___12;

struct rt6_info___12 {
	struct dst_entry___57 dst;
	struct fib6_table___12 *rt6i_table;
	struct fib6_node___12 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___33 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___12 {
	struct fib6_node___12 *parent;
	struct fib6_node___12 *left;
	struct fib6_node___12 *right;
	struct rt6_info___12 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___12 *rr_ptr;
};

struct fib6_table___12 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___12 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___81 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___36 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___36 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___81 *, struct dst_entry___57 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___36 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___36 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___202 {
	void * (*start)(struct seq_file___202 *, loff_t *);
	void (*stop)(struct seq_file___202 *, void *);
	void * (*next)(struct seq_file___202 *, void *, loff_t *);
	int (*show)(struct seq_file___202 *, void *);
};

struct dcbnl_rtnl_ops___67 {
	int (*ieee_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___67 *);
	u8 (*setstate)(struct net_device___67 *, u8);
	void (*getpermhwaddr)(struct net_device___67 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___67 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___67 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___67 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___67 *, int, u8 *);
	void (*setpfccfg)(struct net_device___67 *, int, u8);
	void (*getpfccfg)(struct net_device___67 *, int, u8 *);
	u8 (*setall)(struct net_device___67 *);
	u8 (*getcap)(struct net_device___67 *, int, u8 *);
	int (*getnumtcs)(struct net_device___67 *, int, u8 *);
	int (*setnumtcs)(struct net_device___67 *, int, u8);
	u8 (*getpfcstate)(struct net_device___67 *);
	void (*setpfcstate)(struct net_device___67 *, u8);
	void (*getbcncfg)(struct net_device___67 *, int, u32 *);
	void (*setbcncfg)(struct net_device___67 *, int, u32);
	void (*getbcnrp)(struct net_device___67 *, int, u8 *);
	void (*setbcnrp)(struct net_device___67 *, int, u8);
	u8 (*setapp)(struct net_device___67 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___67 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___67 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___67 *, int, u8);
	u8 (*getdcbx)(struct net_device___67 *);
	u8 (*setdcbx)(struct net_device___67 *, u8);
	int (*peer_getappinfo)(struct net_device___67 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___67 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___67 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___67 *, struct cee_pfc *);
};

struct cgroupfs_root___172;

struct cgroup___172 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___172 *parent;
	struct dentry___277 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___172 *subsys[11];
	struct cgroupfs_root___172 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___279 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___172 {
	struct super_block___277 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___172 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___108 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___277 *, struct file___277 *);
	ssize_t (*read)(struct cgroup___172 *, struct cftype___108 *, struct file___277 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___172 *, struct cftype___108 *);
	s64 (*read_s64)(struct cgroup___172 *, struct cftype___108 *);
	int (*read_map)(struct cgroup___172 *, struct cftype___108 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___172 *, struct cftype___108 *, struct seq_file___202 *);
	ssize_t (*write)(struct cgroup___172 *, struct cftype___108 *, struct file___277 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___172 *, struct cftype___108 *, u64);
	int (*write_s64)(struct cgroup___172 *, struct cftype___108 *, s64);
	int (*write_string)(struct cgroup___172 *, struct cftype___108 *, const char *);
	int (*trigger)(struct cgroup___172 *, unsigned int);
	int (*release)(struct inode___277 *, struct file___277 *);
	int (*register_event)(struct cgroup___172 *, struct cftype___108 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___172 *, struct cftype___108 *, struct eventfd_ctx *);
};

struct cftype_set___104 {
	struct list_head node;
	struct cftype___108 *cfts;
};

struct task_and_cgroup___104 {
	struct task_struct___278 *task;
	struct cgroup___172 *cgrp;
	struct css_set___172 *cg;
};

struct cgroup_taskset___104 {
	struct task_and_cgroup___104 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___172 *cur_cgrp;
};

struct cgroup_subsys___104 {
	struct cgroup_subsys_state___172 * (*css_alloc)(struct cgroup___172 *);
	int (*css_online)(struct cgroup___172 *);
	void (*css_offline)(struct cgroup___172 *);
	void (*css_free)(struct cgroup___172 *);
	int (*can_attach)(struct cgroup___172 *, struct cgroup_taskset___104 *);
	void (*cancel_attach)(struct cgroup___172 *, struct cgroup_taskset___104 *);
	void (*attach)(struct cgroup___172 *, struct cgroup_taskset___104 *);
	void (*fork)(struct task_struct___278 *);
	void (*exit)(struct cgroup___172 *, struct cgroup___172 *, struct task_struct___278 *);
	void (*bind)(struct cgroup___172 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___172 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___108 *base_cftypes;
	struct cftype_set___104 base_cftset;
	struct module___145 *module;
};

struct request_sock_ops___42;

struct request_sock___43 {
	struct sock_common___56 __req_common;
	struct request_sock___43 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___42 *rsk_ops;
	struct sock___26 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___12;

struct xfrm_type___12;

struct xfrm_mode___12;

struct xfrm_state___12 {
	struct net___81 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___12 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___12 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___12 *type;
	struct xfrm_mode___12 *inner_mode;
	struct xfrm_mode___12 *inner_mode_iaf;
	struct xfrm_mode___12 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___12 {
	struct sk_buff_head___68 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___12 {
	struct net___81 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___12 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___69 {
	struct sk_buff___36 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___36 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
	void *data;
	struct module___145 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___67 {
	int (*create)(struct sk_buff___36 *, struct net_device___67 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___36 *, unsigned char *);
	int (*rebuild)(struct sk_buff___36 *);
	int (*cache)(const struct neighbour___57 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___67 *, const unsigned char *);
};

struct napi_struct___67 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___67 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___67 *dev;
	struct sk_buff___36 *gro_list;
	struct sk_buff___36 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___67 {
	struct net_device___67 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___59 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___67 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___59 kobj;
	struct net_device___67 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___67 {
	int (*ndo_init)(struct net_device___67 *);
	void (*ndo_uninit)(struct net_device___67 *);
	int (*ndo_open)(struct net_device___67 *);
	int (*ndo_stop)(struct net_device___67 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___36 *, struct net_device___67 *);
	u16 (*ndo_select_queue)(struct net_device___67 *, struct sk_buff___36 *);
	void (*ndo_change_rx_flags)(struct net_device___67 *, int);
	void (*ndo_set_rx_mode)(struct net_device___67 *);
	int (*ndo_set_mac_address)(struct net_device___67 *, void *);
	int (*ndo_validate_addr)(struct net_device___67 *);
	int (*ndo_do_ioctl)(struct net_device___67 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___67 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___67 *, int);
	int (*ndo_neigh_setup)(struct net_device___67 *, struct neigh_parms___57 *);
	void (*ndo_tx_timeout)(struct net_device___67 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___67 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___67 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___67 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___67 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___67 *);
	int (*ndo_netpoll_setup)(struct net_device___67 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___67 *);
	int (*ndo_busy_poll)(struct napi_struct___67 *);
	int (*ndo_set_vf_mac)(struct net_device___67 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___67 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___67 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___67 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___67 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___67 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___67 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___67 *, int, struct sk_buff___36 *);
	int (*ndo_setup_tc)(struct net_device___67 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___67 *);
	int (*ndo_fcoe_disable)(struct net_device___67 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___67 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___67 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___67 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___67 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___67 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___67 *, const struct sk_buff___36 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___67 *, struct net_device___67 *);
	int (*ndo_del_slave)(struct net_device___67 *, struct net_device___67 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___57 *);
	void (*ndo_neigh_destroy)(struct neighbour___57 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___36 *, struct netlink_callback___69 *, struct net_device___67 *, int);
	int (*ndo_bridge_setlink)(struct net_device___67 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___36 *, u32, u32, struct net_device___67 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___67 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___67 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___67 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___67 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___67 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___67 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___36 *, struct net_device___67 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___67 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___67 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___67 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___57 {
	struct net___81 *net;
	struct net_device___67 *dev;
	struct neigh_parms___57 *next;
	int (*neigh_setup)(struct neighbour___57 *);
	void (*neigh_cleanup)(struct neighbour___57 *);
	struct neigh_table___57 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___33;

struct ifacaddr6___33;

struct inet6_dev___33 {
	struct net_device___67 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___33 *mc_list;
	struct ifmcaddr6___33 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___33 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___57 *nd_parms;
	struct inet6_dev___33 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___58 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___67 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___81 *, struct net_device___67 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___67 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___67 *, struct list_head *);
	size_t (*get_size)(const struct net_device___67 *);
	int (*fill_info)(struct sk_buff___36 *, const struct net_device___67 *);
	size_t (*get_xstats_size)(const struct net_device___67 *);
	int (*fill_xstats)(struct sk_buff___36 *, const struct net_device___67 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___81 * (*get_link_net)(const struct net_device___67 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___67 *, struct net_device___67 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___67 *, const struct net_device___67 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___36 *, const struct net_device___67 *, const struct net_device___67 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___57 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___36 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___57;

struct neigh_hash_table___57;

struct neigh_table___57 {
	struct neigh_table___57 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___67 *, __u32 *);
	int (*constructor)(struct neighbour___57 *);
	int (*pconstructor)(struct pneigh_entry___57 *);
	void (*pdestructor)(struct pneigh_entry___57 *);
	void (*proxy_redo)(struct sk_buff___36 *);
	char *id;
	struct neigh_parms___57 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___68 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___57 *nht;
	struct pneigh_entry___57 **phash_buckets;
};

struct neigh_ops___57 {
	int family;
	void (*solicit)(struct neighbour___57 *, struct sk_buff___36 *);
	void (*error_report)(struct neighbour___57 *, struct sk_buff___36 *);
	int (*output)(struct neighbour___57 *, struct sk_buff___36 *);
	int (*connected_output)(struct neighbour___57 *, struct sk_buff___36 *);
};

struct pneigh_entry___57 {
	struct pneigh_entry___57 *next;
	struct net___81 *net;
	struct net_device___67 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___57 {
	struct neighbour___57 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___28 {
	struct dst_entry___57 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___39;

struct inet_hashinfo___13;

struct proto___56 {
	void (*close)(struct sock___26 *, long int);
	int (*connect)(struct sock___26 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___26 *, int);
	struct sock___26 * (*accept)(struct sock___26 *, int, int *);
	int (*ioctl)(struct sock___26 *, int, long unsigned int);
	int (*init)(struct sock___26 *);
	void (*destroy)(struct sock___26 *);
	void (*shutdown)(struct sock___26 *, int);
	int (*setsockopt)(struct sock___26 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___26 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___26 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___26 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___26 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___64 *, struct sock___26 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___64 *, struct sock___26 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___26 *, struct page___276 *, int, size_t, int);
	int (*bind)(struct sock___26 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___26 *, struct sk_buff___36 *);
	void (*release_cb)(struct sock___26 *);
	void (*mtu_reduced)(struct sock___26 *);
	void (*hash)(struct sock___26 *);
	void (*unhash)(struct sock___26 *);
	void (*rehash)(struct sock___26 *);
	int (*get_port)(struct sock___26 *, short unsigned int);
	void (*clear_sk)(struct sock___26 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___26 *);
	void (*enter_memory_pressure)(struct sock___26 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___260 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___42 *rsk_prot;
	struct timewait_sock_ops___39 *twsk_prot;
	union {
		struct inet_hashinfo___13 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___145 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___104 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___56 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___56 {
	void (*enter_memory_pressure)(struct sock___26 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___13 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___260 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___42 {
	int family;
	int obj_size;
	struct kmem_cache___260 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___26 *, struct request_sock___43 *);
	void (*send_ack)(struct sock___26 *, struct sk_buff___36 *, struct request_sock___43 *);
	void (*send_reset)(struct sock___26 *, struct sk_buff___36 *);
	void (*destructor)(struct request_sock___43 *);
	void (*syn_ack_timeout)(struct sock___26 *, struct request_sock___43 *);
};

struct timewait_sock_ops___39 {
	struct kmem_cache___260 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___26 *, struct sock___26 *, void *);
	void (*twsk_destructor)(struct sock___26 *);
};

struct listen_sock___10 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___43 *syn_table[0];
};

struct fastopen_queue___10 {
	struct request_sock___43 *rskq_rst_head;
	struct request_sock___43 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___10 {
	struct request_sock___43 *rskq_accept_head;
	struct request_sock___43 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___10 *listen_opt;
	struct fastopen_queue___10 *fastopenq;
};

struct inet_request_sock___6 {
	struct request_sock___43 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___36 *pktopts;
	};
};

struct inet_cork___15 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___57 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___15 {
	struct inet_cork___15 base;
	struct flowi fl;
};

struct ipv6_pinfo___14;

struct inet_sock___15 {
	struct sock___26 sk;
	struct ipv6_pinfo___14 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___15 cork;
};

struct ipv6_fl_socklist___13;

struct ipv6_pinfo___14 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___13 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___36 *pktoptions;
	struct sk_buff___36 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___10;

struct inet_connection_sock_af_ops___10 {
	int (*queue_xmit)(struct sk_buff___36 *, struct flowi *);
	void (*send_check)(struct sock___26 *, struct sk_buff___36 *);
	int (*rebuild_header)(struct sock___26 *);
	void (*sk_rx_dst_set)(struct sock___26 *, const struct sk_buff___36 *);
	int (*conn_request)(struct sock___26 *, struct sk_buff___36 *);
	struct sock___26 * (*syn_recv_sock)(struct sock___26 *, struct sk_buff___36 *, struct request_sock___43 *, struct dst_entry___57 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___26 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___26 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___26 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___26 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___26 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___26 *, const struct inet_bind_bucket___10 *, bool);
	void (*mtu_reduced)(struct sock___26 *);
};

struct inet_bind_bucket___10 {
	struct net___81 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_connection_sock___10 {
	struct inet_sock___15 icsk_inet;
	struct request_sock_queue___10 icsk_accept_queue;
	struct inet_bind_bucket___10 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___10 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___26 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct inet_timewait_death_row___5 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___13 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct inet_timewait_sock___6 {
	struct sock_common___56 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___10 *tw_tb;
	struct hlist_node tw_death_node;
};

struct tcp_request_sock_ops___5;

struct tcp_request_sock___6 {
	struct inet_request_sock___6 req;
	const struct tcp_request_sock_ops___5 *af_specific;
	struct sock___26 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___5 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___26 *, struct request_sock___43 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___26 *, const struct request_sock___43 *, const struct sk_buff___36 *);
	void (*init_req)(struct request_sock___43 *, struct sock___26 *, struct sk_buff___36 *);
	__u32 (*cookie_init_seq)(struct sock___26 *, const struct sk_buff___36 *, __u16 *);
	struct dst_entry___57 * (*route_req)(struct sock___26 *, struct flowi *, const struct request_sock___43 *, bool *);
	__u32 (*init_seq)(const struct sk_buff___36 *);
	int (*send_synack)(struct sock___26 *, struct dst_entry___57 *, struct flowi *, struct request_sock___43 *, u16, struct tcp_fastopen_cookie *);
	void (*queue_hash_add)(struct sock___26 *, struct request_sock___43 *, const long unsigned int);
};

struct tcp_sock_af_ops___6;

struct tcp_sock___7 {
	struct inet_connection_sock___10 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___68 prequeue;
		struct task_struct___278 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___13 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___7 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___36 *lost_skb_hint;
	struct sk_buff___36 *retransmit_skb_hint;
	struct sk_buff_head___68 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___36 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___6 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___43 *fastopen_rsk;
};

struct tcp_sock_af_ops___6 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___26 *, struct sock___26 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___26 *, const struct request_sock___43 *, const struct sk_buff___36 *);
	int (*md5_parse)(struct sock___26 *, char *, int);
};

struct tcp_timewait_sock___2 {
	struct inet_timewait_sock___6 tw_sk;
	u32 tw_rcv_nxt;
	u32 tw_snd_nxt;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	long int tw_ts_recent_stamp;
	struct tcp_md5sig_key *tw_md5_key;
};

struct ip6_flowlabel___13;

struct ipv6_fl_socklist___13 {
	struct ipv6_fl_socklist___13 *next;
	struct ip6_flowlabel___13 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___33 {
	struct in6_addr mca_addr;
	struct inet6_dev___33 *idev;
	struct ifmcaddr6___33 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___33 {
	struct in6_addr aca_addr;
	struct inet6_dev___33 *aca_idev;
	struct rt6_info___12 *aca_rt;
	struct ifacaddr6___33 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___13 {
	struct ip6_flowlabel___13 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___81 *fl_net;
};

struct xfrm_replay___12 {
	void (*advance)(struct xfrm_state___12 *, __be32);
	int (*check)(struct xfrm_state___12 *, struct sk_buff___36 *, __be32);
	int (*recheck)(struct xfrm_state___12 *, struct sk_buff___36 *, __be32);
	void (*notify)(struct xfrm_state___12 *, int);
	int (*overflow)(struct xfrm_state___12 *, struct sk_buff___36 *);
};

struct xfrm_type___12 {
	char *description;
	struct module___145 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___12 *);
	void (*destructor)(struct xfrm_state___12 *);
	int (*input)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*output)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*reject)(struct xfrm_state___12 *, struct sk_buff___36 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___12 *, struct sk_buff___36 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___12 *, int);
};

struct xfrm_state_afinfo___12;

struct xfrm_mode___12 {
	int (*input2)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*input)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*output2)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*output)(struct xfrm_state___12 *, struct sk_buff___36 *);
	struct xfrm_state_afinfo___12 *afinfo;
	struct module___145 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___12 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___145 *owner;
	const struct xfrm_type___12 *type_map[256];
	struct xfrm_mode___12 *mode_map[5];
	int (*init_flags)(struct xfrm_state___12 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___12 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___12 **, struct xfrm_state___12 **, int);
	union {
		int (*output)(struct sock___26 *, struct sk_buff___36 *);
		struct {
			int (*output)(struct sk_buff___36 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___26 *, struct sk_buff___36 *);
		struct {
			int (*output_finish)(struct sk_buff___36 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*extract_output)(struct xfrm_state___12 *, struct sk_buff___36 *);
	int (*transport_finish)(struct sk_buff___36 *, int);
};

struct tcp_metrics_block;

struct tcpm_hash_bucket {
	struct tcp_metrics_block *chain;
};

enum tcp_metric_index {
	TCP_METRIC_RTT = 0,
	TCP_METRIC_RTTVAR = 1,
	TCP_METRIC_SSTHRESH = 2,
	TCP_METRIC_CWND = 3,
	TCP_METRIC_REORDERING = 4,
	TCP_METRIC_RTT_US = 5,
	TCP_METRIC_RTTVAR_US = 6,
	__TCP_METRIC_MAX = 7,
};

enum {
	TCP_METRICS_ATTR_UNSPEC = 0,
	TCP_METRICS_ATTR_ADDR_IPV4 = 1,
	TCP_METRICS_ATTR_ADDR_IPV6 = 2,
	TCP_METRICS_ATTR_AGE = 3,
	TCP_METRICS_ATTR_TW_TSVAL = 4,
	TCP_METRICS_ATTR_TW_TS_STAMP = 5,
	TCP_METRICS_ATTR_VALS = 6,
	TCP_METRICS_ATTR_FOPEN_MSS = 7,
	TCP_METRICS_ATTR_FOPEN_SYN_DROPS = 8,
	TCP_METRICS_ATTR_FOPEN_SYN_DROP_TS = 9,
	TCP_METRICS_ATTR_FOPEN_COOKIE = 10,
	TCP_METRICS_ATTR_SADDR_IPV4 = 11,
	TCP_METRICS_ATTR_SADDR_IPV6 = 12,
	__TCP_METRICS_ATTR_MAX = 13,
};

enum {
	TCP_METRICS_CMD_UNSPEC = 0,
	TCP_METRICS_CMD_GET = 1,
	TCP_METRICS_CMD_DEL = 2,
	__TCP_METRICS_CMD_MAX = 3,
};

struct genl_ops___7;

struct genl_info___7;

struct genl_family___7 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___7 *, struct sk_buff___36 *, struct genl_info___7 *);
	void (*post_doit)(const struct genl_ops___7 *, struct sk_buff___36 *, struct genl_info___7 *);
	struct nlattr **attrbuf;
	const struct genl_ops___7 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module___145 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___7 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___36 *, struct genl_info___7 *);
	int (*dumpit)(struct sk_buff___36 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___7 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___81 *_net;
	void *user_ptr[2];
	struct sock___26 *dst_sk;
};

struct tcp_fastopen_metrics {
	u16 mss;
	u16 syn_loss: 10;
	u16 try_exp: 2;
	long unsigned int last_syn_loss;
	struct tcp_fastopen_cookie cookie;
};

struct tcp_metrics_block {
	struct tcp_metrics_block *tcpm_next;
	struct inetpeer_addr tcpm_saddr;
	struct inetpeer_addr tcpm_daddr;
	long unsigned int tcpm_stamp;
	u32 tcpm_ts;
	u32 tcpm_ts_stamp;
	u32 tcpm_lock;
	u32 tcpm_vals[5];
	struct tcp_fastopen_metrics tcpm_fastopen;
	struct callback_head callback_head;
};

struct tcp_fastopen_context {
	struct crypto_cipher *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct napi_gro_cb___3 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___69 *last;
};

struct offload_callbacks___4 {
	struct sk_buff___69 * (*gso_segment)(struct sk_buff___69 *, netdev_features_t);
	struct sk_buff___69 ** (*gro_receive)(struct sk_buff___69 **, struct sk_buff___69 *);
	int (*gro_complete)(struct sk_buff___69 *, int);
};

struct net_offload___2 {
	struct offload_callbacks___4 callbacks;
	unsigned int flags;
};

struct page___277;

typedef struct page___277 *pgtable_t___277;

struct address_space___278;

struct kmem_cache___261;

struct page___277 {
	long unsigned int flags;
	struct address_space___278 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___277 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___277 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___261 *slab_cache;
		struct page___277 *first_page;
	};
	long: 64;
};

struct task_struct___279;

struct pv_cpu_ops___279 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___279 *);
	void (*end_context_switch)(struct task_struct___279 *);
};

struct mutex___280 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___279 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___272 {
	struct page___277 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___286;

struct nsproxy___158;

struct signal_struct___279;

struct css_set___173;

struct task_struct___279 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___279 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___286 *mm;
	struct mm_struct___286 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___279 *real_parent;
	struct task_struct___279 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___279 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___279 = 0,
		VTIME_USER___279 = 1,
		VTIME_SYS___279 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___158 *nsproxy;
	struct signal_struct___279 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___173 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___280 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___272 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___286 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___286 *, struct mm_struct___286 *);
	void (*dup_mmap)(struct mm_struct___286 *, struct mm_struct___286 *);
	void (*exit_mmap)(struct mm_struct___286 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___286 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___286 *);
	void (*pgd_free)(struct mm_struct___286 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___286 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___286 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___286 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___286 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___286 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___286 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___286 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___286 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___286 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___286 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___286 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___280 lock;
	void *vdso;
} mm_context_t___280;

struct xol_area___277;

struct uprobes_state___277 {
	struct xol_area___277 *xol_area;
};

struct vm_area_struct___286;

struct file___278;

struct core_state___279;

struct mm_struct___286 {
	struct vm_area_struct___286 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___286 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___286 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___280 context;
	long unsigned int flags;
	struct core_state___279 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___279 *owner;
	struct file___278 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___277 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct zone___279;

struct lruvec___279 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___279 *zone;
};

struct pglist_data___279;

struct zone___279 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___279 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___279 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___279 {
	struct zone___279 *zone;
	int zone_idx;
};

struct zonelist___279 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___279 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___279 {
	struct zone___279 node_zones[4];
	struct zonelist___279 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___279 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___202;

struct x86_io_apic_ops___202 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___202 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___202;

struct irq_data___202 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___202 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___276;

struct dev_pm_ops___276 {
	int (*prepare)(struct device___276 *);
	void (*complete)(struct device___276 *);
	int (*suspend)(struct device___276 *);
	int (*resume)(struct device___276 *);
	int (*freeze)(struct device___276 *);
	int (*thaw)(struct device___276 *);
	int (*poweroff)(struct device___276 *);
	int (*restore)(struct device___276 *);
	int (*suspend_late)(struct device___276 *);
	int (*resume_early)(struct device___276 *);
	int (*freeze_late)(struct device___276 *);
	int (*thaw_early)(struct device___276 *);
	int (*poweroff_late)(struct device___276 *);
	int (*restore_early)(struct device___276 *);
	int (*suspend_noirq)(struct device___276 *);
	int (*resume_noirq)(struct device___276 *);
	int (*freeze_noirq)(struct device___276 *);
	int (*thaw_noirq)(struct device___276 *);
	int (*poweroff_noirq)(struct device___276 *);
	int (*restore_noirq)(struct device___276 *);
	int (*runtime_suspend)(struct device___276 *);
	int (*runtime_resume)(struct device___276 *);
	int (*runtime_idle)(struct device___276 *);
};

struct kset___60;

struct kobj_type___60;

struct kobject___60 {
	const char *name;
	struct list_head entry;
	struct kobject___60 *parent;
	struct kset___60 *kset;
	struct kobj_type___60 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___79;

struct dev_pm_info___79 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___79 *qos;
};

struct dma_map_ops___141;

struct dev_archdata___141 {
	struct dma_map_ops___141 *dma_ops;
	void *iommu;
};

struct device_type___276;

struct bus_type___276;

struct device_driver___276;

struct dev_pm_domain___276;

struct class___276;

struct attribute_group___238;

struct device_rh___276;

struct device___276 {
	struct device___276 *parent;
	struct device_private *p;
	struct kobject___60 kobj;
	const char *init_name;
	const struct device_type___276 *type;
	struct mutex___280 mutex;
	struct bus_type___276 *bus;
	struct device_driver___276 *driver;
	void *platform_data;
	struct dev_pm_info___79 power;
	struct dev_pm_domain___276 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___141 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___276 *class;
	const struct attribute_group___238 **groups;
	void (*release)(struct device___276 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___276 *device_rh;
};

struct dev_pm_qos_request___80;

struct dev_pm_qos___79 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___80 *latency_req;
	struct dev_pm_qos_request___80 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___80 *latency_tolerance_req;
};

struct dev_pm_info_rh___276 {
	void (*set_latency_tolerance)(struct device___276 *, s32);
};

struct dev_pm_domain___276 {
	struct dev_pm_ops___276 ops;
};

struct smp_ops___279 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___279 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct sock___57;

struct kobj_ns_type_operations___57 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___57 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___57;

struct net___82;

struct sock_common___57 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___57 *skc_prot;
	struct net___82 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___70;

struct sk_buff_head___69 {
	struct sk_buff___70 *next;
	struct sk_buff___70 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___58;

struct socket_wq___57;

struct xfrm_policy___13;

struct dst_entry___58;

struct socket___58;

struct cg_proto___57;

struct sock___57 {
	struct sock_common___57 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___69 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___70 *head;
		struct sk_buff___70 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___58 *sk_filter;
	struct socket_wq___57 *sk_wq;
	struct sk_buff_head___69 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___13 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___58 *sk_rx_dst;
	struct dst_entry___58 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___69 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___69 sk_error_queue;
	struct proto___57 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___58 *sk_socket;
	void *sk_user_data;
	struct page_frag___272 sk_frag;
	struct sk_buff___70 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___57 *sk_cgrp;
	void (*sk_state_change)(struct sock___57 *);
	void (*sk_data_ready)(struct sock___57 *, int);
	void (*sk_write_space)(struct sock___57 *);
	void (*sk_error_report)(struct sock___57 *);
	int (*sk_backlog_rcv)(struct sock___57 *, struct sk_buff___70 *);
	void (*sk_destruct)(struct sock___57 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___240;

struct attribute_group___238 {
	const char *name;
	umode_t (*is_visible)(struct kobject___60 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___240 **bin_attrs;
};

struct bin_attribute___240 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___278 *, struct kobject___60 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___278 *, struct kobject___60 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	int (*mmap)(struct file___278 *, struct kobject___60 *, struct bin_attribute___240 *, struct vm_area_struct___286 *);
};

struct dentry___278;

struct path___278 {
	struct vfsmount *mnt;
	struct dentry___278 *dentry;
};

struct inode___278;

struct file_operations___278;

struct file___278 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___278 f_path;
	struct inode___278 *f_inode;
	const struct file_operations___278 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___278 *f_mapping;
	struct mutex___280 f_pos_lock;
};

struct vm_operations_struct___252;

struct vm_area_struct___286 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___286 *vm_next;
	struct vm_area_struct___286 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___286 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___252 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___278 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___60 {
	ssize_t (*show)(struct kobject___60 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___60 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___60 *, const struct attribute *);
};

struct kset_uevent_ops___60;

struct kset___60 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___60 kobj;
	const struct kset_uevent_ops___60 *uevent_ops;
};

struct kobj_type___60 {
	void (*release)(struct kobject___60 *);
	const struct sysfs_ops___60 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___57 * (*child_ns_type)(struct kobject___60 *);
	const void * (*namespace)(struct kobject___60 *);
};

struct kset_uevent_ops___60 {
	int (* const filter)(struct kset___60 *, struct kobject___60 *);
	const char * (* const name)(struct kset___60 *, struct kobject___60 *);
	int (* const uevent)(struct kset___60 *, struct kobject___60 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___260 {
	void **freelist;
	long unsigned int tid;
	struct page___277 *page;
	struct page___277 *partial;
};

struct memcg_cache_params___261;

struct kmem_cache___261 {
	struct kmem_cache_cpu___260 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___60 kobj;
	struct memcg_cache_params___261 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___261 {
	bool is_root_cache;
	union {
		struct kmem_cache___261 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___261 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct kiocb___65;

typedef int kiocb_cancel_fn___65(struct kiocb___65 *, struct io_event *);

struct kiocb___65 {
	atomic_t ki_users;
	struct file___278 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___65 *ki_cancel;
	void (*ki_dtor)(struct kiocb___65 *);
	union {
		void *user;
		struct task_struct___279 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct seq_file___203;

struct irq_chip___202 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___202 *);
	void (*irq_shutdown)(struct irq_data___202 *);
	void (*irq_enable)(struct irq_data___202 *);
	void (*irq_disable)(struct irq_data___202 *);
	void (*irq_ack)(struct irq_data___202 *);
	void (*irq_mask)(struct irq_data___202 *);
	void (*irq_mask_ack)(struct irq_data___202 *);
	void (*irq_unmask)(struct irq_data___202 *);
	void (*irq_eoi)(struct irq_data___202 *);
	int (*irq_set_affinity)(struct irq_data___202 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___202 *);
	int (*irq_set_type)(struct irq_data___202 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___202 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___202 *);
	void (*irq_bus_sync_unlock)(struct irq_data___202 *);
	void (*irq_cpu_online)(struct irq_data___202 *);
	void (*irq_cpu_offline)(struct irq_data___202 *);
	void (*irq_suspend)(struct irq_data___202 *);
	void (*irq_resume)(struct irq_data___202 *);
	void (*irq_pm_shutdown)(struct irq_data___202 *);
	void (*irq_print_chip)(struct irq_data___202 *, struct seq_file___203 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___202 *, void *);
	long unsigned int flags;
};

struct seq_operations___203;

struct seq_file___203 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___280 lock;
	const struct seq_operations___203 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct poll_table_struct___164;

struct file_lock___278;

struct file_operations___278 {
	struct module *owner;
	loff_t (*llseek)(struct file___278 *, loff_t, int);
	ssize_t (*read)(struct file___278 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___278 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___65 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___65 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___278 *, void *, filldir_t);
	unsigned int (*poll)(struct file___278 *, struct poll_table_struct___164 *);
	long int (*unlocked_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___278 *, struct vm_area_struct___286 *);
	int (*open)(struct inode___278 *, struct file___278 *);
	int (*flush)(struct file___278 *, fl_owner_t);
	int (*release)(struct inode___278 *, struct file___278 *);
	int (*fsync)(struct file___278 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___65 *, int);
	int (*fasync)(int, struct file___278 *, int);
	int (*lock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*sendpage)(struct file___278 *, struct page___277 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___278 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___278 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___278 *, long int, struct file_lock___278 **, void **);
		struct {
			int (*setlease)(struct file___278 *, long int, struct file_lock___278 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___278 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___203 *, struct file___278 *);
};

struct dma_map_ops___141 {
	void * (*alloc)(struct device___276 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___276 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___276 *, struct vm_area_struct___286 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___276 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___276 *, struct page___277 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___276 *, dma_addr_t);
	int (*dma_supported)(struct device___276 *, u64);
	int (*set_dma_mask)(struct device___276 *, u64);
	int is_phys;
};

struct bus_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___276 *, char *);
	ssize_t (*store)(struct bus_type___276 *, const char *, size_t);
};

struct device_attribute___276;

struct driver_attribute___276;

struct bus_type___276 {
	const char *name;
	const char *dev_name;
	struct device___276 *dev_root;
	struct bus_attribute___276 *bus_attrs;
	struct device_attribute___276 *dev_attrs;
	struct driver_attribute___276 *drv_attrs;
	const struct attribute_group___238 **bus_groups;
	const struct attribute_group___238 **dev_groups;
	const struct attribute_group___238 **drv_groups;
	int (*match)(struct device___276 *, struct device_driver___276 *);
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	int (*probe)(struct device___276 *);
	int (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*online)(struct device___276 *);
	int (*offline)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct device___276 *, struct device_attribute___276 *, char *);
	ssize_t (*store)(struct device___276 *, struct device_attribute___276 *, const char *, size_t);
};

struct driver_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___276 *, char *);
	ssize_t (*store)(struct device_driver___276 *, const char *, size_t);
};

struct device_driver___276 {
	const char *name;
	struct bus_type___276 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___276 *);
	int (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	const struct attribute_group___238 **groups;
	const struct dev_pm_ops___276 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___276 {
	const char *name;
	const struct attribute_group___238 **groups;
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
};

struct class_attribute___276;

struct class___276 {
	const char *name;
	struct module *owner;
	struct class_attribute___276 *class_attrs;
	struct device_attribute___276 *dev_attrs;
	const struct attribute_group___238 **dev_groups;
	struct bin_attribute___240 *dev_bin_attrs;
	struct kobject___60 *dev_kobj;
	int (*dev_uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *);
	void (*class_release)(struct class___276 *);
	void (*dev_release)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	const struct kobj_ns_type_operations___57 *ns_type;
	const void * (*namespace)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
	struct subsys_private *p;
};

struct class_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct class___276 *, struct class_attribute___276 *, char *);
	ssize_t (*store)(struct class___276 *, struct class_attribute___276 *, const char *, size_t);
	const void * (*namespace)(struct class___276 *, const struct class_attribute___276 *);
};

struct device_rh___276 {
	struct dev_pm_info_rh___276 power;
};

struct dev_pm_qos_request___80 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___276 *dev;
};

struct xol_area___277 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___277 *page;
	long unsigned int vaddr;
};

struct address_space_operations___278;

struct address_space___278 {
	struct inode___278 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___280 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___278 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___248;

struct vm_operations_struct___252 {
	void (*open)(struct vm_area_struct___286 *);
	void (*close)(struct vm_area_struct___286 *);
	int (*fault)(struct vm_area_struct___286 *, struct vm_fault___248 *);
	int (*page_mkwrite)(struct vm_area_struct___286 *, struct vm_fault___248 *);
	int (*access)(struct vm_area_struct___286 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___286 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___286 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___286 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___286 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___279 {
	struct task_struct___279 *task;
	struct core_thread___279 *next;
};

struct core_state___279 {
	atomic_t nr_threads;
	struct core_thread___279 dumper;
	struct completion startup;
};

struct vm_fault___248 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___277 *page;
};

struct dentry_operations___278;

struct super_block___278;

struct dentry___278 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___278 *d_parent;
	struct qstr d_name;
	struct inode___278 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___278 *d_op;
	struct super_block___278 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___278;

struct dquot___278;

struct block_device___278;

struct inode___278 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___278 *i_op;
	struct super_block___278 *i_sb;
	struct address_space___278 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___280 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___278 *i_fop;
	struct file_lock___278 *i_flock;
	struct address_space___278 i_data;
	struct dquot___278 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___278 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___278 {
	int (*d_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_hash)(const struct dentry___278 *, struct qstr *);
	int (*d_compare)(const struct dentry___278 *, const struct dentry___278 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___278 *);
	void (*d_release)(struct dentry___278 *);
	void (*d_prune)(struct dentry___278 *);
	void (*d_iput)(struct dentry___278 *, struct inode___278 *);
	char * (*d_dname)(struct dentry___278 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___278 *);
	int (*d_manage)(struct dentry___278 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___278;

struct mem_dqinfo___278 {
	struct quota_format_type___278 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___278;

struct quota_info___278 {
	unsigned int flags;
	struct mutex___280 dqio_mutex;
	struct mutex___280 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___278 *files[2];
	struct mem_dqinfo___278 info[2];
	const struct quota_format_ops___278 *ops[2];
};

struct file_system_type___278;

struct super_operations___278;

struct dquot_operations___278;

struct quotactl_ops___278;

struct xattr_handler___174;

struct super_block___278 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___278 *s_type;
	const struct super_operations___278 *s_op;
	const struct dquot_operations___278 *dq_op;
	const struct quotactl_ops___278 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___278 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___174 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___278 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___278 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___280 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___278 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___278 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___278 *bd_inode;
	struct super_block___278 *bd_super;
	struct mutex___280 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___278 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___280 bd_fsfreeze_mutex;
};

struct cgroup___173;

struct cgroup_subsys_state___173 {
	struct cgroup___173 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___278 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___278 *ia_file;
};

struct dquot___278 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___280 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___278 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___278 {
	int qf_fmt_id;
	const struct quota_format_ops___278 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___278 *qf_next;
};

struct quota_format_ops___278 {
	int (*check_quota_file)(struct super_block___278 *, int);
	int (*read_file_info)(struct super_block___278 *, int);
	int (*write_file_info)(struct super_block___278 *, int);
	int (*free_file_info)(struct super_block___278 *, int);
	int (*read_dqblk)(struct dquot___278 *);
	int (*commit_dqblk)(struct dquot___278 *);
	int (*release_dqblk)(struct dquot___278 *);
};

struct dquot_operations___278 {
	int (*write_dquot)(struct dquot___278 *);
	struct dquot___278 * (*alloc_dquot)(struct super_block___278 *, int);
	void (*destroy_dquot)(struct dquot___278 *);
	int (*acquire_dquot)(struct dquot___278 *);
	int (*release_dquot)(struct dquot___278 *);
	int (*mark_dirty)(struct dquot___278 *);
	int (*write_info)(struct super_block___278 *, int);
	qsize_t * (*get_reserved_space)(struct inode___278 *);
};

struct quotactl_ops___278 {
	int (*quota_on)(struct super_block___278 *, int, int, struct path___278 *);
	int (*quota_on_meta)(struct super_block___278 *, int, int);
	int (*quota_off)(struct super_block___278 *, int);
	int (*quota_sync)(struct super_block___278 *, int);
	int (*get_info)(struct super_block___278 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___278 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___278 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___278 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___278 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___278 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___278 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___278 *, unsigned int);
};

struct address_space_operations___278 {
	int (*writepage)(struct page___277 *, struct writeback_control *);
	int (*readpage)(struct file___278 *, struct page___277 *);
	int (*writepages)(struct address_space___278 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___277 *);
	int (*readpages)(struct file___278 *, struct address_space___278 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___278 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___277 **, void **);
	int (*write_end)(struct file___278 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___277 *, void *);
	sector_t (*bmap)(struct address_space___278 *, sector_t);
	void (*invalidatepage)(struct page___277 *, long unsigned int);
	int (*releasepage)(struct page___277 *, gfp_t);
	void (*freepage)(struct page___277 *);
	ssize_t (*direct_IO)(int, struct kiocb___65 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___278 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___278 *, struct page___277 *, struct page___277 *, enum migrate_mode);
	int (*launder_page)(struct page___277 *);
	int (*is_partially_uptodate)(struct page___277 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___277 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___278 *, struct page___277 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___278 *, sector_t *);
	void (*swap_deactivate)(struct file___278 *);
	void (*invalidatepage_range)(struct page___277 *, unsigned int, unsigned int);
};

struct inode_operations___278 {
	struct dentry___278 * (*lookup)(struct inode___278 *, struct dentry___278 *, unsigned int);
	void * (*follow_link)(struct dentry___278 *, struct nameidata *);
	int (*permission)(struct inode___278 *, int);
	struct posix_acl * (*get_acl)(struct inode___278 *, int);
	int (*readlink)(struct dentry___278 *, char *, int);
	void (*put_link)(struct dentry___278 *, struct nameidata *, void *);
	int (*create)(struct inode___278 *, struct dentry___278 *, umode_t, bool);
	int (*link)(struct dentry___278 *, struct inode___278 *, struct dentry___278 *);
	int (*unlink)(struct inode___278 *, struct dentry___278 *);
	int (*symlink)(struct inode___278 *, struct dentry___278 *, const char *);
	int (*mkdir)(struct inode___278 *, struct dentry___278 *, umode_t);
	int (*rmdir)(struct inode___278 *, struct dentry___278 *);
	int (*mknod)(struct inode___278 *, struct dentry___278 *, umode_t, dev_t);
	int (*rename)(struct inode___278 *, struct dentry___278 *, struct inode___278 *, struct dentry___278 *);
	int (*setattr)(struct dentry___278 *, struct iattr___278 *);
	int (*getattr)(struct vfsmount *, struct dentry___278 *, struct kstat *);
	int (*setxattr)(struct dentry___278 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___278 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___278 *, char *, size_t);
	int (*removexattr)(struct dentry___278 *, const char *);
	int (*fiemap)(struct inode___278 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___278 *, struct timespec *, int);
	int (*atomic_open)(struct inode___278 *, struct dentry___278 *, struct file___278 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___278;

struct file_lock_operations___278;

struct lock_manager_operations___278;

struct file_lock___278 {
	struct file_lock___278 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___278 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___278 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___278 *fl_ops;
	const struct lock_manager_operations___278 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___278 {
	void (*fl_copy_lock)(struct file_lock___278 *, struct file_lock___278 *);
	void (*fl_release_private)(struct file_lock___278 *);
};

struct lock_manager_operations___278 {
	int (*lm_compare_owner)(struct file_lock___278 *, struct file_lock___278 *);
	long unsigned int (*lm_owner_key)(struct file_lock___278 *);
	void (*lm_notify)(struct file_lock___278 *);
	int (*lm_grant)(struct file_lock___278 *, struct file_lock___278 *, int);
	void (*lm_break)(struct file_lock___278 *);
	int (*lm_change)(struct file_lock___278 **, int);
};

struct fasync_struct___278 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___278 *fa_next;
	struct file___278 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___278 {
	const char *name;
	int fs_flags;
	struct dentry___278 * (*mount)(struct file_system_type___278 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___278 *);
	struct module *owner;
	struct file_system_type___278 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___278 {
	struct inode___278 * (*alloc_inode)(struct super_block___278 *);
	void (*destroy_inode)(struct inode___278 *);
	void (*dirty_inode)(struct inode___278 *, int);
	int (*write_inode)(struct inode___278 *, struct writeback_control *);
	int (*drop_inode)(struct inode___278 *);
	void (*evict_inode)(struct inode___278 *);
	void (*put_super)(struct super_block___278 *);
	int (*sync_fs)(struct super_block___278 *, int);
	int (*freeze_fs)(struct super_block___278 *);
	int (*unfreeze_fs)(struct super_block___278 *);
	int (*statfs)(struct dentry___278 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___278 *, int *, char *);
	void (*umount_begin)(struct super_block___278 *);
	int (*show_options)(struct seq_file___203 *, struct dentry___278 *);
	int (*show_devname)(struct seq_file___203 *, struct dentry___278 *);
	int (*show_path)(struct seq_file___203 *, struct dentry___278 *);
	int (*show_stats)(struct seq_file___203 *, struct dentry___278 *);
	ssize_t (*quota_read)(struct super_block___278 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___278 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___278 *);
	int (*bdev_try_to_free_page)(struct super_block___278 *, struct page___277 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___278 *);
	void (*free_cached_objects)(struct super_block___278 *, int);
};

struct xattr_handler___174 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___278 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___278 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___278 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___166)(struct file___278 *, wait_queue_head_t *, struct poll_table_struct___164 *);

struct poll_table_struct___164 {
	poll_queue_proc___166 _qproc;
	long unsigned int _key;
};

struct ctl_table_header___83;

struct ctl_node___83 {
	struct rb_node node;
	struct ctl_table_header___83 *header;
};

struct ctl_table_root___83;

struct ctl_table_set___83;

struct ctl_dir___83;

struct ctl_table_header___83 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___83 *root;
	struct ctl_table_set___83 *set;
	struct ctl_dir___83 *parent;
	struct ctl_node___83 *node;
};

struct ctl_dir___83 {
	struct ctl_table_header___83 header;
	struct rb_root root;
};

struct ctl_table_set___83 {
	int (*is_seen)(struct ctl_table_set___83 *);
	struct ctl_dir___83 dir;
};

struct ctl_table_root___83 {
	struct ctl_table_set___83 default_set;
	struct ctl_table_set___83 * (*lookup)(struct ctl_table_root___83 *, struct nsproxy___158 *);
	int (*permissions)(struct ctl_table_header___83 *, struct ctl_table *);
};

struct nsproxy___158 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___82 *net_ns;
};

struct signal_struct___279 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___279 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___279 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___280 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___173 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___173 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___57 {
	wait_queue_head_t wait;
	struct fasync_struct___278 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___57;

struct socket___58 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___57 *wq;
	struct file___278 *file;
	struct sock___57 *sk;
	const struct proto_ops___57 *ops;
};

struct proto_ops___57 {
	int family;
	struct module *owner;
	int (*release)(struct socket___58 *);
	int (*bind)(struct socket___58 *, struct sockaddr *, int);
	int (*connect)(struct socket___58 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___58 *, struct socket___58 *);
	int (*accept)(struct socket___58 *, struct socket___58 *, int);
	int (*getname)(struct socket___58 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___278 *, struct socket___58 *, struct poll_table_struct___164 *);
	int (*ioctl)(struct socket___58 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___58 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___58 *, int);
	int (*shutdown)(struct socket___58 *, int);
	int (*setsockopt)(struct socket___58 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___58 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___58 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___58 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___65 *, struct socket___58 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___65 *, struct socket___58 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___278 *, struct socket___58 *, struct vm_area_struct___286 *);
	ssize_t (*sendpage)(struct socket___58 *, struct page___277 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___58 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___57 *, int);
		struct {
			void (*set_peek_off)(struct sock___57 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___80 {
	struct ctl_table_header___83 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___81 {
	struct mutex___280 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___80 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___83 *ctl;
};

struct netns_ipv4___80 {
	struct ctl_table_header___83 *forw_hdr;
	struct ctl_table_header___83 *frags_hdr;
	struct ctl_table_header___83 *ipv4_hdr;
	struct ctl_table_header___83 *route_hdr;
	struct ctl_table_header___83 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___57 *fibnl;
	struct sock___57 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___80 {
	struct ctl_table_header___83 *hdr;
	struct ctl_table_header___83 *route_hdr;
	struct ctl_table_header___83 *icmp_hdr;
	struct ctl_table_header___83 *frags_hdr;
	struct ctl_table_header___83 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___68;

struct neighbour___58;

struct dst_ops___82 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___82 *);
	struct dst_entry___58 * (*check)(struct dst_entry___58 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___58 *);
	unsigned int (*mtu)(const struct dst_entry___58 *);
	u32 * (*cow_metrics)(struct dst_entry___58 *, long unsigned int);
	void (*destroy)(struct dst_entry___58 *);
	void (*ifdown)(struct dst_entry___58 *, struct net_device___68 *, int);
	struct dst_entry___58 * (*negative_advice)(struct dst_entry___58 *);
	void (*link_failure)(struct sk_buff___70 *);
	void (*update_pmtu)(struct dst_entry___58 *, struct sock___57 *, struct sk_buff___70 *, u32);
	void (*redirect)(struct dst_entry___58 *, struct sock___57 *, struct sk_buff___70 *);
	int (*local_out)(struct sk_buff___70 *);
	struct neighbour___58 * (*neigh_lookup)(const struct dst_entry___58 *, struct sk_buff___70 *, const void *);
	struct kmem_cache___261 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___13;

struct fib6_table___13;

struct netns_ipv6___82 {
	struct netns_sysctl_ipv6___80 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___13 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___13 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___82 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___13 *ip6_prohibit_entry;
	struct rt6_info___13 *ip6_blk_hole_entry;
	struct fib6_table___13 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___57 **icmp_sk;
	struct sock___57 *ndisc_sk;
	struct sock___57 *tcp_sk;
	struct sock___57 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___80 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___83 *sysctl_header;
	struct sock___57 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___57 {
	struct sock___57 *v4_ctl_sk;
	struct sock___57 *v6_ctl_sk;
};

struct netns_nf___80 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___83 *nf_log_dir_header;
};

struct nf_proto_net___80 {
	struct ctl_table_header___83 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___80 {
	struct nf_proto_net___80 pn;
	unsigned int timeout;
};

struct nf_tcp_net___80 {
	struct nf_proto_net___80 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___80 {
	struct nf_proto_net___80 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___80 {
	struct nf_proto_net___80 pn;
	unsigned int timeout;
};

struct nf_ip_net___80 {
	struct nf_generic_net___80 generic;
	struct nf_tcp_net___80 tcp;
	struct nf_udp_net___80 udp;
	struct nf_icmp_net___80 icmp;
	struct nf_icmp_net___80 icmpv6;
};

struct netns_ct___81 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___83 *sysctl_header;
	struct ctl_table_header___83 *acct_sysctl_header;
	struct ctl_table_header___83 *tstamp_sysctl_header;
	struct ctl_table_header___83 *event_sysctl_header;
	struct ctl_table_header___83 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___261 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___80 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___80 {
	struct netns_sysctl_ipv6___80 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___82 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___57 *nlsk;
	struct sock___57 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___83 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___82 xfrm4_dst_ops;
	struct dst_ops___82 xfrm6_dst_ops;
};

struct net___82 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___83 sysctls;
	struct sock___57 *rtnl;
	struct sock___57 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___68 *loopback_dev;
	struct netns_core___80 core;
	struct netns_mib mib;
	struct netns_packet___81 packet;
	struct netns_unix___80 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___80 ipv4;
	struct netns_ipv6___82 ipv6;
	struct netns_sctp___80 sctp;
	struct netns_dccp___57 dccp;
	struct netns_nf___80 nf;
	struct netns_xt xt;
	struct netns_ct___81 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___80 nf_frag;
	struct sock___57 *nfnl;
	struct sock___57 *nfnl_stash;
	struct sk_buff_head___69 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___82 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___57 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___57 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___280 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___280 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___68 {
	atomic_t use;
	unsigned int mask;
	struct net_device___68 *physindev;
	struct net_device___68 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___68(struct sk_buff___70 **);

struct net_device_ops___68;

struct ethtool_ops___68;

struct header_ops___68;

struct inet6_dev___34;

struct netdev_rx_queue___68;

struct netdev_queue___68;

struct rtnl_link_ops___59;

struct dcbnl_rtnl_ops___68;

struct net_device___68 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___68 *netdev_ops;
	const struct ethtool_ops___68 *ethtool_ops;
	const struct header_ops___68 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___60 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___34 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___68 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___68 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___68 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___68 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___68 = 0,
		NETREG_REGISTERED___68 = 1,
		NETREG_UNREGISTERING___68 = 2,
		NETREG_UNREGISTERED___68 = 3,
		NETREG_RELEASED___68 = 4,
		NETREG_DUMMY___68 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___68 = 0,
		RTNL_LINK_INITIALIZING___68 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___68 *);
	struct netpoll_info *npinfo;
	struct net___82 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___276 dev;
	const struct attribute_group___238 *sysfs_groups[4];
	const struct rtnl_link_ops___59 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___68 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___13;

struct sk_buff___70 {
	struct sk_buff___70 *next;
	struct sk_buff___70 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___57 *sk;
	struct net_device___68 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___13 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___70 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___68 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___13;

struct sec_path___13 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___13 *xvec[6];
};

struct ethtool_ops___68 {
	int (*get_settings)(struct net_device___68 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___68 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___68 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___68 *);
	void (*get_regs)(struct net_device___68 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___68 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___68 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___68 *);
	void (*set_msglevel)(struct net_device___68 *, u32);
	int (*nway_reset)(struct net_device___68 *);
	u32 (*get_link)(struct net_device___68 *);
	int (*get_eeprom_len)(struct net_device___68 *);
	int (*get_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___68 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___68 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___68 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___68 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___68 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___68 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___68 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___68 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___68 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___68 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___68 *);
	void (*complete)(struct net_device___68 *);
	u32 (*get_priv_flags)(struct net_device___68 *);
	int (*set_priv_flags)(struct net_device___68 *, u32);
	int (*get_sset_count)(struct net_device___68 *, int);
	int (*get_rxnfc)(struct net_device___68 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___68 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___68 *, struct ethtool_flash *);
	int (*reset)(struct net_device___68 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___68 *);
	int (*get_rxfh_indir)(struct net_device___68 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___68 *, const u32 *);
	void (*get_channels)(struct net_device___68 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___68 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___68 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___68 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___68 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___68 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___68 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___68 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___68 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___68 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___68 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___68 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___29;

struct dst_entry___58 {
	struct callback_head callback_head;
	struct dst_entry___58 *child;
	struct net_device___68 *dev;
	struct dst_ops___82 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___58 *path;
	struct dst_entry___58 *from;
	struct xfrm_state___13 *xfrm;
	int (*input)(struct sk_buff___70 *);
	union {
		int (*output)(struct sock___57 *, struct sk_buff___70 *);
		struct {
			int (*output)(struct sk_buff___70 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___58 *next;
		struct rtable___29 *rt_next;
		struct rt6_info___13 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___58;

struct neigh_parms___58;

struct neigh_ops___58;

struct neighbour___58 {
	struct neighbour___58 *next;
	struct neigh_table___58 *tbl;
	struct neigh_parms___58 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___69 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___58 *, struct sk_buff___70 *);
	const struct neigh_ops___58 *ops;
	struct callback_head rcu;
	struct net_device___68 *dev;
	u8 primary_key[0];
};

struct fib6_node___13;

struct rt6_info___13 {
	struct dst_entry___58 dst;
	struct fib6_table___13 *rt6i_table;
	struct fib6_node___13 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___34 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___13 {
	struct fib6_node___13 *parent;
	struct fib6_node___13 *left;
	struct fib6_node___13 *right;
	struct rt6_info___13 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___13 *rr_ptr;
};

struct fib6_table___13 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___13 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___9 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___68 *in;
	struct net_device___68 *out;
	struct sock___57 *sk;
	int (*okfn)(struct sock___57 *, struct sk_buff___70 *);
};

struct nf_afinfo___82 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___70 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___70 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___82 *, struct dst_entry___58 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___70 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___70 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___203 {
	void * (*start)(struct seq_file___203 *, loff_t *);
	void (*stop)(struct seq_file___203 *, void *);
	void * (*next)(struct seq_file___203 *, void *, loff_t *);
	int (*show)(struct seq_file___203 *, void *);
};

struct seq_net_private___8 {
	struct net___82 *net;
};

struct pernet_operations___17 {
	struct list_head list;
	int (*init)(struct net___82 *);
	void (*exit)(struct net___82 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___68 {
	int (*ieee_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___68 *);
	u8 (*setstate)(struct net_device___68 *, u8);
	void (*getpermhwaddr)(struct net_device___68 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___68 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___68 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___68 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___68 *, int, u8 *);
	void (*setpfccfg)(struct net_device___68 *, int, u8);
	void (*getpfccfg)(struct net_device___68 *, int, u8 *);
	u8 (*setall)(struct net_device___68 *);
	u8 (*getcap)(struct net_device___68 *, int, u8 *);
	int (*getnumtcs)(struct net_device___68 *, int, u8 *);
	int (*setnumtcs)(struct net_device___68 *, int, u8);
	u8 (*getpfcstate)(struct net_device___68 *);
	void (*setpfcstate)(struct net_device___68 *, u8);
	void (*getbcncfg)(struct net_device___68 *, int, u32 *);
	void (*setbcncfg)(struct net_device___68 *, int, u32);
	void (*getbcnrp)(struct net_device___68 *, int, u8 *);
	void (*setbcnrp)(struct net_device___68 *, int, u8);
	u8 (*setapp)(struct net_device___68 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___68 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___68 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___68 *, int, u8);
	u8 (*getdcbx)(struct net_device___68 *);
	u8 (*setdcbx)(struct net_device___68 *, u8);
	int (*peer_getappinfo)(struct net_device___68 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___68 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___68 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___68 *, struct cee_pfc *);
};

struct cgroupfs_root___173;

struct cgroup___173 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___173 *parent;
	struct dentry___278 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___173 *subsys[11];
	struct cgroupfs_root___173 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___280 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___173 {
	struct super_block___278 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___173 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___109 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___278 *, struct file___278 *);
	ssize_t (*read)(struct cgroup___173 *, struct cftype___109 *, struct file___278 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___173 *, struct cftype___109 *);
	s64 (*read_s64)(struct cgroup___173 *, struct cftype___109 *);
	int (*read_map)(struct cgroup___173 *, struct cftype___109 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___173 *, struct cftype___109 *, struct seq_file___203 *);
	ssize_t (*write)(struct cgroup___173 *, struct cftype___109 *, struct file___278 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___173 *, struct cftype___109 *, u64);
	int (*write_s64)(struct cgroup___173 *, struct cftype___109 *, s64);
	int (*write_string)(struct cgroup___173 *, struct cftype___109 *, const char *);
	int (*trigger)(struct cgroup___173 *, unsigned int);
	int (*release)(struct inode___278 *, struct file___278 *);
	int (*register_event)(struct cgroup___173 *, struct cftype___109 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___173 *, struct cftype___109 *, struct eventfd_ctx *);
};

struct cftype_set___105 {
	struct list_head node;
	struct cftype___109 *cfts;
};

struct task_and_cgroup___105 {
	struct task_struct___279 *task;
	struct cgroup___173 *cgrp;
	struct css_set___173 *cg;
};

struct cgroup_taskset___105 {
	struct task_and_cgroup___105 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___173 *cur_cgrp;
};

struct cgroup_subsys___105 {
	struct cgroup_subsys_state___173 * (*css_alloc)(struct cgroup___173 *);
	int (*css_online)(struct cgroup___173 *);
	void (*css_offline)(struct cgroup___173 *);
	void (*css_free)(struct cgroup___173 *);
	int (*can_attach)(struct cgroup___173 *, struct cgroup_taskset___105 *);
	void (*cancel_attach)(struct cgroup___173 *, struct cgroup_taskset___105 *);
	void (*attach)(struct cgroup___173 *, struct cgroup_taskset___105 *);
	void (*fork)(struct task_struct___279 *);
	void (*exit)(struct cgroup___173 *, struct cgroup___173 *, struct task_struct___279 *);
	void (*bind)(struct cgroup___173 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___173 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___109 *base_cftypes;
	struct cftype_set___105 base_cftset;
	struct module *module;
};

struct request_sock_ops___43;

struct request_sock___44 {
	struct sock_common___57 __req_common;
	struct request_sock___44 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___43 *rsk_ops;
	struct sock___57 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___13;

struct xfrm_type___13;

struct xfrm_mode___13;

struct xfrm_state___13 {
	struct net___82 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___13 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___13 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___13 *type;
	struct xfrm_mode___13 *inner_mode;
	struct xfrm_mode___13 *inner_mode_iaf;
	struct xfrm_mode___13 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___13 {
	struct sk_buff_head___69 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___13 {
	struct net___82 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___13 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___70 {
	struct sk_buff___70 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___70 *, struct netlink_callback___70 *);
	int (*done)(struct netlink_callback___70 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___68 {
	int (*create)(struct sk_buff___70 *, struct net_device___68 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___70 *, unsigned char *);
	int (*rebuild)(struct sk_buff___70 *);
	int (*cache)(const struct neighbour___58 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___68 *, const unsigned char *);
};

struct napi_struct___68 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___68 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___68 *dev;
	struct sk_buff___70 *gro_list;
	struct sk_buff___70 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___68 {
	struct net_device___68 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___60 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___68 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___60 kobj;
	struct net_device___68 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___68 {
	int (*ndo_init)(struct net_device___68 *);
	void (*ndo_uninit)(struct net_device___68 *);
	int (*ndo_open)(struct net_device___68 *);
	int (*ndo_stop)(struct net_device___68 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___70 *, struct net_device___68 *);
	u16 (*ndo_select_queue)(struct net_device___68 *, struct sk_buff___70 *);
	void (*ndo_change_rx_flags)(struct net_device___68 *, int);
	void (*ndo_set_rx_mode)(struct net_device___68 *);
	int (*ndo_set_mac_address)(struct net_device___68 *, void *);
	int (*ndo_validate_addr)(struct net_device___68 *);
	int (*ndo_do_ioctl)(struct net_device___68 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___68 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___68 *, int);
	int (*ndo_neigh_setup)(struct net_device___68 *, struct neigh_parms___58 *);
	void (*ndo_tx_timeout)(struct net_device___68 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___68 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___68 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___68 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___68 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___68 *);
	int (*ndo_netpoll_setup)(struct net_device___68 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___68 *);
	int (*ndo_busy_poll)(struct napi_struct___68 *);
	int (*ndo_set_vf_mac)(struct net_device___68 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___68 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___68 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___68 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___68 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___68 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___68 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___68 *, int, struct sk_buff___70 *);
	int (*ndo_setup_tc)(struct net_device___68 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___68 *);
	int (*ndo_fcoe_disable)(struct net_device___68 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___68 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___68 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___68 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___68 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___68 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___68 *, const struct sk_buff___70 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___68 *, struct net_device___68 *);
	int (*ndo_del_slave)(struct net_device___68 *, struct net_device___68 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___58 *);
	void (*ndo_neigh_destroy)(struct neighbour___58 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___70 *, struct netlink_callback___70 *, struct net_device___68 *, int);
	int (*ndo_bridge_setlink)(struct net_device___68 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___70 *, u32, u32, struct net_device___68 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___68 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___68 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___68 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___68 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___68 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___68 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___70 *, struct net_device___68 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___68 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___68 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___68 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___58 {
	struct net___82 *net;
	struct net_device___68 *dev;
	struct neigh_parms___58 *next;
	int (*neigh_setup)(struct neighbour___58 *);
	void (*neigh_cleanup)(struct neighbour___58 *);
	struct neigh_table___58 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___34;

struct ifacaddr6___34;

struct inet6_dev___34 {
	struct net_device___68 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___34 *mc_list;
	struct ifmcaddr6___34 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___34 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___58 *nd_parms;
	struct inet6_dev___34 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___59 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___68 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___82 *, struct net_device___68 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___68 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___68 *, struct list_head *);
	size_t (*get_size)(const struct net_device___68 *);
	int (*fill_info)(struct sk_buff___70 *, const struct net_device___68 *);
	size_t (*get_xstats_size)(const struct net_device___68 *);
	int (*fill_xstats)(struct sk_buff___70 *, const struct net_device___68 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___82 * (*get_link_net)(const struct net_device___68 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___68 *, struct net_device___68 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___68 *, const struct net_device___68 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___70 *, const struct net_device___68 *, const struct net_device___68 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___58 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___70 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___58;

struct neigh_hash_table___58;

struct neigh_table___58 {
	struct neigh_table___58 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___68 *, __u32 *);
	int (*constructor)(struct neighbour___58 *);
	int (*pconstructor)(struct pneigh_entry___58 *);
	void (*pdestructor)(struct pneigh_entry___58 *);
	void (*proxy_redo)(struct sk_buff___70 *);
	char *id;
	struct neigh_parms___58 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___69 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___58 *nht;
	struct pneigh_entry___58 **phash_buckets;
};

struct neigh_ops___58 {
	int family;
	void (*solicit)(struct neighbour___58 *, struct sk_buff___70 *);
	void (*error_report)(struct neighbour___58 *, struct sk_buff___70 *);
	int (*output)(struct neighbour___58 *, struct sk_buff___70 *);
	int (*connected_output)(struct neighbour___58 *, struct sk_buff___70 *);
};

struct pneigh_entry___58 {
	struct pneigh_entry___58 *next;
	struct net___82 *net;
	struct net_device___68 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___58 {
	struct neighbour___58 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___29 {
	struct dst_entry___58 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___40;

struct proto___57 {
	void (*close)(struct sock___57 *, long int);
	int (*connect)(struct sock___57 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___57 *, int);
	struct sock___57 * (*accept)(struct sock___57 *, int, int *);
	int (*ioctl)(struct sock___57 *, int, long unsigned int);
	int (*init)(struct sock___57 *);
	void (*destroy)(struct sock___57 *);
	void (*shutdown)(struct sock___57 *, int);
	int (*setsockopt)(struct sock___57 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___57 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___57 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___57 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___57 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___65 *, struct sock___57 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___65 *, struct sock___57 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___57 *, struct page___277 *, int, size_t, int);
	int (*bind)(struct sock___57 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___57 *, struct sk_buff___70 *);
	void (*release_cb)(struct sock___57 *);
	void (*mtu_reduced)(struct sock___57 *);
	void (*hash)(struct sock___57 *);
	void (*unhash)(struct sock___57 *);
	void (*rehash)(struct sock___57 *);
	int (*get_port)(struct sock___57 *, short unsigned int);
	void (*clear_sk)(struct sock___57 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___57 *);
	void (*enter_memory_pressure)(struct sock___57 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___261 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___43 *rsk_prot;
	struct timewait_sock_ops___40 *twsk_prot;
	union {
		struct inet_hashinfo___13 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___105 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___57 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___57 {
	void (*enter_memory_pressure)(struct sock___57 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___43 {
	int family;
	int obj_size;
	struct kmem_cache___261 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___57 *, struct request_sock___44 *);
	void (*send_ack)(struct sock___57 *, struct sk_buff___70 *, struct request_sock___44 *);
	void (*send_reset)(struct sock___57 *, struct sk_buff___70 *);
	void (*destructor)(struct request_sock___44 *);
	void (*syn_ack_timeout)(struct sock___57 *, struct request_sock___44 *);
};

struct timewait_sock_ops___40 {
	struct kmem_cache___261 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___57 *, struct sock___57 *, void *);
	void (*twsk_destructor)(struct sock___57 *);
};

struct inet_cork___16 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___58 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___16 {
	struct inet_cork___16 base;
	struct flowi fl;
};

struct ipv6_pinfo___15;

struct inet_sock___16 {
	struct sock___57 sk;
	struct ipv6_pinfo___15 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___16 cork;
};

struct ipv6_fl_socklist___14;

struct ipv6_pinfo___15 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___14 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___70 *pktoptions;
	struct sk_buff___70 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___14;

struct ipv6_fl_socklist___14 {
	struct ipv6_fl_socklist___14 *next;
	struct ip6_flowlabel___14 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___34 {
	struct in6_addr mca_addr;
	struct inet6_dev___34 *idev;
	struct ifmcaddr6___34 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___34 {
	struct in6_addr aca_addr;
	struct inet6_dev___34 *aca_idev;
	struct rt6_info___13 *aca_rt;
	struct ifacaddr6___34 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___14 {
	struct ip6_flowlabel___14 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___82 *fl_net;
};

struct icmp_filter {
	__u32 data;
};

struct raw_iter_state {
	struct seq_net_private___8 p;
	int bucket;
	struct raw_hashinfo *h;
};

struct raw_sock {
	struct inet_sock___16 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct xfrm_replay___13 {
	void (*advance)(struct xfrm_state___13 *, __be32);
	int (*check)(struct xfrm_state___13 *, struct sk_buff___70 *, __be32);
	int (*recheck)(struct xfrm_state___13 *, struct sk_buff___70 *, __be32);
	void (*notify)(struct xfrm_state___13 *, int);
	int (*overflow)(struct xfrm_state___13 *, struct sk_buff___70 *);
};

struct xfrm_type___13 {
	char *description;
	struct module *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___13 *);
	void (*destructor)(struct xfrm_state___13 *);
	int (*input)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*output)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*reject)(struct xfrm_state___13 *, struct sk_buff___70 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___13 *, struct sk_buff___70 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___13 *, int);
};

struct xfrm_state_afinfo___13;

struct xfrm_mode___13 {
	int (*input2)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*input)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*output2)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*output)(struct xfrm_state___13 *, struct sk_buff___70 *);
	struct xfrm_state_afinfo___13 *afinfo;
	struct module *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___13 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module *owner;
	const struct xfrm_type___13 *type_map[256];
	struct xfrm_mode___13 *mode_map[5];
	int (*init_flags)(struct xfrm_state___13 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___13 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___13 **, struct xfrm_state___13 **, int);
	union {
		int (*output)(struct sock___57 *, struct sk_buff___70 *);
		struct {
			int (*output)(struct sk_buff___70 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___57 *, struct sk_buff___70 *);
		struct {
			int (*output_finish)(struct sk_buff___70 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*extract_output)(struct xfrm_state___13 *, struct sk_buff___70 *);
	int (*transport_finish)(struct sk_buff___70 *, int);
};

struct page___278;

typedef struct page___278 *pgtable_t___278;

struct address_space___279;

struct kmem_cache___262;

struct page___278 {
	long unsigned int flags;
	struct address_space___279 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___278 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___278 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___262 *slab_cache;
		struct page___278 *first_page;
	};
	long: 64;
};

struct task_struct___280;

struct pv_cpu_ops___280 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___280 *);
	void (*end_context_switch)(struct task_struct___280 *);
};

struct mutex___281 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___280 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___273 {
	struct page___278 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___287;

struct nsproxy___159;

struct signal_struct___280;

struct css_set___174;

struct task_struct___280 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___280 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___287 *mm;
	struct mm_struct___287 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___280 *real_parent;
	struct task_struct___280 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___280 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___280 = 0,
		VTIME_USER___280 = 1,
		VTIME_SYS___280 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___159 *nsproxy;
	struct signal_struct___280 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___174 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___281 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___273 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___287 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___287 *, struct mm_struct___287 *);
	void (*dup_mmap)(struct mm_struct___287 *, struct mm_struct___287 *);
	void (*exit_mmap)(struct mm_struct___287 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___287 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___287 *);
	void (*pgd_free)(struct mm_struct___287 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___287 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___287 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___287 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___287 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___287 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___287 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___287 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___287 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___287 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___287 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___287 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___281 lock;
	void *vdso;
} mm_context_t___281;

struct xol_area___278;

struct uprobes_state___278 {
	struct xol_area___278 *xol_area;
};

struct vm_area_struct___287;

struct file___279;

struct core_state___280;

struct mm_struct___287 {
	struct vm_area_struct___287 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___287 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___287 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___281 context;
	long unsigned int flags;
	struct core_state___280 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___280 *owner;
	struct file___279 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___278 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___61;

struct kobj_type___61;

struct kobject___61 {
	const char *name;
	struct list_head entry;
	struct kobject___61 *parent;
	struct kset___61 *kset;
	struct kobj_type___61 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___174;

struct module_kobject___174 {
	struct kobject___61 kobj;
	struct module___174 *mod;
	struct kobject___61 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___174;

struct module___174 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___174 mkobj;
	struct module_attribute___174 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___61 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___280 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___280;

struct lruvec___280 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___280 *zone;
};

struct pglist_data___280;

struct zone___280 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___280 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___280 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___280 {
	struct zone___280 *zone;
	int zone_idx;
};

struct zonelist___280 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___280 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___280 {
	struct zone___280 node_zones[4];
	struct zonelist___280 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___280 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___203;

struct x86_io_apic_ops___203 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___203 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___203;

struct irq_data___203 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___203 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___277;

struct dev_pm_ops___277 {
	int (*prepare)(struct device___277 *);
	void (*complete)(struct device___277 *);
	int (*suspend)(struct device___277 *);
	int (*resume)(struct device___277 *);
	int (*freeze)(struct device___277 *);
	int (*thaw)(struct device___277 *);
	int (*poweroff)(struct device___277 *);
	int (*restore)(struct device___277 *);
	int (*suspend_late)(struct device___277 *);
	int (*resume_early)(struct device___277 *);
	int (*freeze_late)(struct device___277 *);
	int (*thaw_early)(struct device___277 *);
	int (*poweroff_late)(struct device___277 *);
	int (*restore_early)(struct device___277 *);
	int (*suspend_noirq)(struct device___277 *);
	int (*resume_noirq)(struct device___277 *);
	int (*freeze_noirq)(struct device___277 *);
	int (*thaw_noirq)(struct device___277 *);
	int (*poweroff_noirq)(struct device___277 *);
	int (*restore_noirq)(struct device___277 *);
	int (*runtime_suspend)(struct device___277 *);
	int (*runtime_resume)(struct device___277 *);
	int (*runtime_idle)(struct device___277 *);
};

struct dev_pm_qos___80;

struct dev_pm_info___80 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___80 *qos;
};

struct dma_map_ops___142;

struct dev_archdata___142 {
	struct dma_map_ops___142 *dma_ops;
	void *iommu;
};

struct device_type___277;

struct bus_type___277;

struct device_driver___277;

struct dev_pm_domain___277;

struct class___277;

struct attribute_group___239;

struct device_rh___277;

struct device___277 {
	struct device___277 *parent;
	struct device_private *p;
	struct kobject___61 kobj;
	const char *init_name;
	const struct device_type___277 *type;
	struct mutex___281 mutex;
	struct bus_type___277 *bus;
	struct device_driver___277 *driver;
	void *platform_data;
	struct dev_pm_info___80 power;
	struct dev_pm_domain___277 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___142 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___277 *class;
	const struct attribute_group___239 **groups;
	void (*release)(struct device___277 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___277 *device_rh;
};

struct dev_pm_qos_request___81;

struct dev_pm_qos___80 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___81 *latency_req;
	struct dev_pm_qos_request___81 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___81 *latency_tolerance_req;
};

struct dev_pm_info_rh___277 {
	void (*set_latency_tolerance)(struct device___277 *, s32);
};

struct dev_pm_domain___277 {
	struct dev_pm_ops___277 ops;
};

struct smp_ops___280 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___280 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct inode___279;

struct dentry_operations___279;

struct super_block___279;

struct dentry___279 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___279 *d_parent;
	struct qstr d_name;
	struct inode___279 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___279 *d_op;
	struct super_block___279 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___279;

struct address_space___279 {
	struct inode___279 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___281 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___279 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___279;

struct file_operations___279;

struct file_lock___279;

struct dquot___279;

struct block_device___279;

struct inode___279 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___279 *i_op;
	struct super_block___279 *i_sb;
	struct address_space___279 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___281 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___279 *i_fop;
	struct file_lock___279 *i_flock;
	struct address_space___279 i_data;
	struct dquot___279 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___279 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___279;

struct dentry_operations___279 {
	int (*d_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_hash)(const struct dentry___279 *, struct qstr *);
	int (*d_compare)(const struct dentry___279 *, const struct dentry___279 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___279 *);
	void (*d_release)(struct dentry___279 *);
	void (*d_prune)(struct dentry___279 *);
	void (*d_iput)(struct dentry___279 *, struct inode___279 *);
	char * (*d_dname)(struct dentry___279 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___279 *);
	int (*d_manage)(struct dentry___279 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___279;

struct mem_dqinfo___279 {
	struct quota_format_type___279 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___279;

struct quota_info___279 {
	unsigned int flags;
	struct mutex___281 dqio_mutex;
	struct mutex___281 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___279 *files[2];
	struct mem_dqinfo___279 info[2];
	const struct quota_format_ops___279 *ops[2];
};

struct file_system_type___279;

struct super_operations___279;

struct dquot_operations___279;

struct quotactl_ops___279;

struct xattr_handler___175;

struct super_block___279 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___279 *s_type;
	const struct super_operations___279 *s_op;
	const struct dquot_operations___279 *dq_op;
	const struct quotactl_ops___279 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___279 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___175 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___279 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___279 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___281 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___279 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___279 {
	struct vfsmount *mnt;
	struct dentry___279 *dentry;
};

struct block_device___279 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___279 *bd_inode;
	struct super_block___279 *bd_super;
	struct mutex___281 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___279 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___281 bd_fsfreeze_mutex;
};

struct cgroup___174;

struct cgroup_subsys_state___174 {
	struct cgroup___174 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___66;

typedef int kiocb_cancel_fn___66(struct kiocb___66 *, struct io_event *);

struct kiocb___66 {
	atomic_t ki_users;
	struct file___279 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___66 *ki_cancel;
	void (*ki_dtor)(struct kiocb___66 *);
	union {
		void *user;
		struct task_struct___280 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___279 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___279 *ia_file;
};

struct file___279 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___279 f_path;
	struct inode___279 *f_inode;
	const struct file_operations___279 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___279 *f_mapping;
	struct mutex___281 f_pos_lock;
};

struct dquot___279 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___281 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___279 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___279 {
	int qf_fmt_id;
	const struct quota_format_ops___279 *qf_ops;
	struct module___174 *qf_owner;
	struct quota_format_type___279 *qf_next;
};

struct quota_format_ops___279 {
	int (*check_quota_file)(struct super_block___279 *, int);
	int (*read_file_info)(struct super_block___279 *, int);
	int (*write_file_info)(struct super_block___279 *, int);
	int (*free_file_info)(struct super_block___279 *, int);
	int (*read_dqblk)(struct dquot___279 *);
	int (*commit_dqblk)(struct dquot___279 *);
	int (*release_dqblk)(struct dquot___279 *);
};

struct dquot_operations___279 {
	int (*write_dquot)(struct dquot___279 *);
	struct dquot___279 * (*alloc_dquot)(struct super_block___279 *, int);
	void (*destroy_dquot)(struct dquot___279 *);
	int (*acquire_dquot)(struct dquot___279 *);
	int (*release_dquot)(struct dquot___279 *);
	int (*mark_dirty)(struct dquot___279 *);
	int (*write_info)(struct super_block___279 *, int);
	qsize_t * (*get_reserved_space)(struct inode___279 *);
};

struct quotactl_ops___279 {
	int (*quota_on)(struct super_block___279 *, int, int, struct path___279 *);
	int (*quota_on_meta)(struct super_block___279 *, int, int);
	int (*quota_off)(struct super_block___279 *, int);
	int (*quota_sync)(struct super_block___279 *, int);
	int (*get_info)(struct super_block___279 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___279 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___279 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___279 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___279 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___279 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___279 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___279 *, unsigned int);
};

struct swap_info_struct___48;

struct address_space_operations___279 {
	int (*writepage)(struct page___278 *, struct writeback_control *);
	int (*readpage)(struct file___279 *, struct page___278 *);
	int (*writepages)(struct address_space___279 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___278 *);
	int (*readpages)(struct file___279 *, struct address_space___279 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___279 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___278 **, void **);
	int (*write_end)(struct file___279 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___278 *, void *);
	sector_t (*bmap)(struct address_space___279 *, sector_t);
	void (*invalidatepage)(struct page___278 *, long unsigned int);
	int (*releasepage)(struct page___278 *, gfp_t);
	void (*freepage)(struct page___278 *);
	ssize_t (*direct_IO)(int, struct kiocb___66 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___279 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___279 *, struct page___278 *, struct page___278 *, enum migrate_mode);
	int (*launder_page)(struct page___278 *);
	int (*is_partially_uptodate)(struct page___278 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___278 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___279 *, struct page___278 *);
	int (*swap_activate)(struct swap_info_struct___48 *, struct file___279 *, sector_t *);
	void (*swap_deactivate)(struct file___279 *);
	void (*invalidatepage_range)(struct page___278 *, unsigned int, unsigned int);
};

struct swap_info_struct___48 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___279 *bdev;
	struct file___279 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___279 {
	struct dentry___279 * (*lookup)(struct inode___279 *, struct dentry___279 *, unsigned int);
	void * (*follow_link)(struct dentry___279 *, struct nameidata *);
	int (*permission)(struct inode___279 *, int);
	struct posix_acl * (*get_acl)(struct inode___279 *, int);
	int (*readlink)(struct dentry___279 *, char *, int);
	void (*put_link)(struct dentry___279 *, struct nameidata *, void *);
	int (*create)(struct inode___279 *, struct dentry___279 *, umode_t, bool);
	int (*link)(struct dentry___279 *, struct inode___279 *, struct dentry___279 *);
	int (*unlink)(struct inode___279 *, struct dentry___279 *);
	int (*symlink)(struct inode___279 *, struct dentry___279 *, const char *);
	int (*mkdir)(struct inode___279 *, struct dentry___279 *, umode_t);
	int (*rmdir)(struct inode___279 *, struct dentry___279 *);
	int (*mknod)(struct inode___279 *, struct dentry___279 *, umode_t, dev_t);
	int (*rename)(struct inode___279 *, struct dentry___279 *, struct inode___279 *, struct dentry___279 *);
	int (*setattr)(struct dentry___279 *, struct iattr___279 *);
	int (*getattr)(struct vfsmount *, struct dentry___279 *, struct kstat *);
	int (*setxattr)(struct dentry___279 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___279 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___279 *, char *, size_t);
	int (*removexattr)(struct dentry___279 *, const char *);
	int (*fiemap)(struct inode___279 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___279 *, struct timespec *, int);
	int (*atomic_open)(struct inode___279 *, struct dentry___279 *, struct file___279 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___165;

struct seq_file___204;

struct file_operations___279 {
	struct module___174 *owner;
	loff_t (*llseek)(struct file___279 *, loff_t, int);
	ssize_t (*read)(struct file___279 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___279 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___66 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___66 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___279 *, void *, filldir_t);
	unsigned int (*poll)(struct file___279 *, struct poll_table_struct___165 *);
	long int (*unlocked_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___279 *, struct vm_area_struct___287 *);
	int (*open)(struct inode___279 *, struct file___279 *);
	int (*flush)(struct file___279 *, fl_owner_t);
	int (*release)(struct inode___279 *, struct file___279 *);
	int (*fsync)(struct file___279 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___66 *, int);
	int (*fasync)(int, struct file___279 *, int);
	int (*lock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*sendpage)(struct file___279 *, struct page___278 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___279 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___279 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___279 *, long int, struct file_lock___279 **, void **);
		struct {
			int (*setlease)(struct file___279 *, long int, struct file_lock___279 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___279 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___204 *, struct file___279 *);
};

struct fasync_struct___279;

struct file_lock_operations___279;

struct lock_manager_operations___279;

struct file_lock___279 {
	struct file_lock___279 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___279 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___279 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___279 *fl_ops;
	const struct lock_manager_operations___279 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___279 {
	void (*fl_copy_lock)(struct file_lock___279 *, struct file_lock___279 *);
	void (*fl_release_private)(struct file_lock___279 *);
};

struct lock_manager_operations___279 {
	int (*lm_compare_owner)(struct file_lock___279 *, struct file_lock___279 *);
	long unsigned int (*lm_owner_key)(struct file_lock___279 *);
	void (*lm_notify)(struct file_lock___279 *);
	int (*lm_grant)(struct file_lock___279 *, struct file_lock___279 *, int);
	void (*lm_break)(struct file_lock___279 *);
	int (*lm_change)(struct file_lock___279 **, int);
};

struct fasync_struct___279 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___279 *fa_next;
	struct file___279 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___279 {
	const char *name;
	int fs_flags;
	struct dentry___279 * (*mount)(struct file_system_type___279 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___279 *);
	struct module___174 *owner;
	struct file_system_type___279 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___279 {
	struct inode___279 * (*alloc_inode)(struct super_block___279 *);
	void (*destroy_inode)(struct inode___279 *);
	void (*dirty_inode)(struct inode___279 *, int);
	int (*write_inode)(struct inode___279 *, struct writeback_control *);
	int (*drop_inode)(struct inode___279 *);
	void (*evict_inode)(struct inode___279 *);
	void (*put_super)(struct super_block___279 *);
	int (*sync_fs)(struct super_block___279 *, int);
	int (*freeze_fs)(struct super_block___279 *);
	int (*unfreeze_fs)(struct super_block___279 *);
	int (*statfs)(struct dentry___279 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___279 *, int *, char *);
	void (*umount_begin)(struct super_block___279 *);
	int (*show_options)(struct seq_file___204 *, struct dentry___279 *);
	int (*show_devname)(struct seq_file___204 *, struct dentry___279 *);
	int (*show_path)(struct seq_file___204 *, struct dentry___279 *);
	int (*show_stats)(struct seq_file___204 *, struct dentry___279 *);
	ssize_t (*quota_read)(struct super_block___279 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___279 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___279 *);
	int (*bdev_try_to_free_page)(struct super_block___279 *, struct page___278 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___279 *);
	void (*free_cached_objects)(struct super_block___279 *, int);
};

struct xattr_handler___175 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___279 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___279 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___279 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___167)(struct file___279 *, wait_queue_head_t *, struct poll_table_struct___165 *);

struct poll_table_struct___165 {
	poll_queue_proc___167 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___253;

struct vm_area_struct___287 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___287 *vm_next;
	struct vm_area_struct___287 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___287 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___253 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___279 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___204;

struct seq_file___204 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___281 lock;
	const struct seq_operations___204 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___278 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___278 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___261;

struct memcg_cache_params___262;

struct kmem_cache___262 {
	struct kmem_cache_cpu___261 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___61 kobj;
	struct memcg_cache_params___262 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___249;

struct vm_operations_struct___253 {
	void (*open)(struct vm_area_struct___287 *);
	void (*close)(struct vm_area_struct___287 *);
	int (*fault)(struct vm_area_struct___287 *, struct vm_fault___249 *);
	int (*page_mkwrite)(struct vm_area_struct___287 *, struct vm_fault___249 *);
	int (*access)(struct vm_area_struct___287 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___287 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___287 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___287 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___287 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___280 {
	struct task_struct___280 *task;
	struct core_thread___280 *next;
};

struct core_state___280 {
	atomic_t nr_threads;
	struct core_thread___280 dumper;
	struct completion startup;
};

struct vm_fault___249 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___278 *page;
};

struct irq_chip___203 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___203 *);
	void (*irq_shutdown)(struct irq_data___203 *);
	void (*irq_enable)(struct irq_data___203 *);
	void (*irq_disable)(struct irq_data___203 *);
	void (*irq_ack)(struct irq_data___203 *);
	void (*irq_mask)(struct irq_data___203 *);
	void (*irq_mask_ack)(struct irq_data___203 *);
	void (*irq_unmask)(struct irq_data___203 *);
	void (*irq_eoi)(struct irq_data___203 *);
	int (*irq_set_affinity)(struct irq_data___203 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___203 *);
	int (*irq_set_type)(struct irq_data___203 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___203 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___203 *);
	void (*irq_bus_sync_unlock)(struct irq_data___203 *);
	void (*irq_cpu_online)(struct irq_data___203 *);
	void (*irq_cpu_offline)(struct irq_data___203 *);
	void (*irq_suspend)(struct irq_data___203 *);
	void (*irq_resume)(struct irq_data___203 *);
	void (*irq_pm_shutdown)(struct irq_data___203 *);
	void (*irq_print_chip)(struct irq_data___203 *, struct seq_file___204 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___203 *, void *);
	long unsigned int flags;
};

struct ctl_table_header___84;

struct ctl_node___84 {
	struct rb_node node;
	struct ctl_table_header___84 *header;
};

struct ctl_table_root___84;

struct ctl_table_set___84;

struct ctl_dir___84;

struct ctl_table_header___84 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___84 *root;
	struct ctl_table_set___84 *set;
	struct ctl_dir___84 *parent;
	struct ctl_node___84 *node;
};

struct ctl_dir___84 {
	struct ctl_table_header___84 header;
	struct rb_root root;
};

struct ctl_table_set___84 {
	int (*is_seen)(struct ctl_table_set___84 *);
	struct ctl_dir___84 dir;
};

struct ctl_table_root___84 {
	struct ctl_table_set___84 default_set;
	struct ctl_table_set___84 * (*lookup)(struct ctl_table_root___84 *, struct nsproxy___159 *);
	int (*permissions)(struct ctl_table_header___84 *, struct ctl_table *);
};

struct net___83;

struct nsproxy___159 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___83 *net_ns;
};

struct signal_struct___280 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___280 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___280 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___281 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___174 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___174 *subsys[11];
	struct callback_head callback_head;
};

struct sock___58;

struct kobj_ns_type_operations___58 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___58 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___58;

struct sock_common___58 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___58 *skc_prot;
	struct net___83 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___71;

struct sk_buff_head___70 {
	struct sk_buff___71 *next;
	struct sk_buff___71 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___59;

struct socket_wq___58;

struct xfrm_policy___14;

struct dst_entry___59;

struct socket___59;

struct cg_proto___58;

struct sock___58 {
	struct sock_common___58 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___70 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___71 *head;
		struct sk_buff___71 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___59 *sk_filter;
	struct socket_wq___58 *sk_wq;
	struct sk_buff_head___70 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___14 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___59 *sk_rx_dst;
	struct dst_entry___59 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___70 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___70 sk_error_queue;
	struct proto___58 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___59 *sk_socket;
	void *sk_user_data;
	struct page_frag___273 sk_frag;
	struct sk_buff___71 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___58 *sk_cgrp;
	void (*sk_state_change)(struct sock___58 *);
	void (*sk_data_ready)(struct sock___58 *, int);
	void (*sk_write_space)(struct sock___58 *);
	void (*sk_error_report)(struct sock___58 *);
	int (*sk_backlog_rcv)(struct sock___58 *, struct sk_buff___71 *);
	void (*sk_destruct)(struct sock___58 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___241;

struct attribute_group___239 {
	const char *name;
	umode_t (*is_visible)(struct kobject___61 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___241 **bin_attrs;
};

struct bin_attribute___241 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___279 *, struct kobject___61 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___279 *, struct kobject___61 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	int (*mmap)(struct file___279 *, struct kobject___61 *, struct bin_attribute___241 *, struct vm_area_struct___287 *);
};

struct sysfs_ops___61 {
	ssize_t (*show)(struct kobject___61 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___61 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___61 *, const struct attribute *);
};

struct kset_uevent_ops___61;

struct kset___61 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___61 kobj;
	const struct kset_uevent_ops___61 *uevent_ops;
};

struct kobj_type___61 {
	void (*release)(struct kobject___61 *);
	const struct sysfs_ops___61 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___58 * (*child_ns_type)(struct kobject___61 *);
	const void * (*namespace)(struct kobject___61 *);
};

struct kset_uevent_ops___61 {
	int (* const filter)(struct kset___61 *, struct kobject___61 *);
	const char * (* const name)(struct kset___61 *, struct kobject___61 *);
	int (* const uevent)(struct kset___61 *, struct kobject___61 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___261 {
	void **freelist;
	long unsigned int tid;
	struct page___278 *page;
	struct page___278 *partial;
};

struct memcg_cache_params___262 {
	bool is_root_cache;
	union {
		struct kmem_cache___262 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___262 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct cgroupfs_root___174;

struct cgroup___174 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___174 *parent;
	struct dentry___279 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___174 *subsys[11];
	struct cgroupfs_root___174 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___281 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___174 {
	struct super_block___279 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___174 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___110 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___279 *, struct file___279 *);
	ssize_t (*read)(struct cgroup___174 *, struct cftype___110 *, struct file___279 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___174 *, struct cftype___110 *);
	s64 (*read_s64)(struct cgroup___174 *, struct cftype___110 *);
	int (*read_map)(struct cgroup___174 *, struct cftype___110 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___174 *, struct cftype___110 *, struct seq_file___204 *);
	ssize_t (*write)(struct cgroup___174 *, struct cftype___110 *, struct file___279 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___174 *, struct cftype___110 *, u64);
	int (*write_s64)(struct cgroup___174 *, struct cftype___110 *, s64);
	int (*write_string)(struct cgroup___174 *, struct cftype___110 *, const char *);
	int (*trigger)(struct cgroup___174 *, unsigned int);
	int (*release)(struct inode___279 *, struct file___279 *);
	int (*register_event)(struct cgroup___174 *, struct cftype___110 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___174 *, struct cftype___110 *, struct eventfd_ctx *);
};

struct cftype_set___106 {
	struct list_head node;
	struct cftype___110 *cfts;
};

struct task_and_cgroup___106 {
	struct task_struct___280 *task;
	struct cgroup___174 *cgrp;
	struct css_set___174 *cg;
};

struct cgroup_taskset___106 {
	struct task_and_cgroup___106 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___174 *cur_cgrp;
};

struct cgroup_subsys___106 {
	struct cgroup_subsys_state___174 * (*css_alloc)(struct cgroup___174 *);
	int (*css_online)(struct cgroup___174 *);
	void (*css_offline)(struct cgroup___174 *);
	void (*css_free)(struct cgroup___174 *);
	int (*can_attach)(struct cgroup___174 *, struct cgroup_taskset___106 *);
	void (*cancel_attach)(struct cgroup___174 *, struct cgroup_taskset___106 *);
	void (*attach)(struct cgroup___174 *, struct cgroup_taskset___106 *);
	void (*fork)(struct task_struct___280 *);
	void (*exit)(struct cgroup___174 *, struct cgroup___174 *, struct task_struct___280 *);
	void (*bind)(struct cgroup___174 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___174 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___110 *base_cftypes;
	struct cftype_set___106 base_cftset;
	struct module___174 *module;
};

struct dma_map_ops___142 {
	void * (*alloc)(struct device___277 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___277 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___277 *, struct vm_area_struct___287 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___277 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___277 *, struct page___278 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___277 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___277 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___277 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___277 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___277 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___277 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___277 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___277 *, dma_addr_t);
	int (*dma_supported)(struct device___277 *, u64);
	int (*set_dma_mask)(struct device___277 *, u64);
	int is_phys;
};

struct bus_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___277 *, char *);
	ssize_t (*store)(struct bus_type___277 *, const char *, size_t);
};

struct device_attribute___277;

struct driver_attribute___277;

struct bus_type___277 {
	const char *name;
	const char *dev_name;
	struct device___277 *dev_root;
	struct bus_attribute___277 *bus_attrs;
	struct device_attribute___277 *dev_attrs;
	struct driver_attribute___277 *drv_attrs;
	const struct attribute_group___239 **bus_groups;
	const struct attribute_group___239 **dev_groups;
	const struct attribute_group___239 **drv_groups;
	int (*match)(struct device___277 *, struct device_driver___277 *);
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	int (*probe)(struct device___277 *);
	int (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*online)(struct device___277 *);
	int (*offline)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct device___277 *, struct device_attribute___277 *, char *);
	ssize_t (*store)(struct device___277 *, struct device_attribute___277 *, const char *, size_t);
};

struct driver_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___277 *, char *);
	ssize_t (*store)(struct device_driver___277 *, const char *, size_t);
};

struct device_driver___277 {
	const char *name;
	struct bus_type___277 *bus;
	struct module___174 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___277 *);
	int (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	const struct attribute_group___239 **groups;
	const struct dev_pm_ops___277 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___277 {
	const char *name;
	const struct attribute_group___239 **groups;
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
};

struct class_attribute___277;

struct class___277 {
	const char *name;
	struct module___174 *owner;
	struct class_attribute___277 *class_attrs;
	struct device_attribute___277 *dev_attrs;
	const struct attribute_group___239 **dev_groups;
	struct bin_attribute___241 *dev_bin_attrs;
	struct kobject___61 *dev_kobj;
	int (*dev_uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *);
	void (*class_release)(struct class___277 *);
	void (*dev_release)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	const struct kobj_ns_type_operations___58 *ns_type;
	const void * (*namespace)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
	struct subsys_private *p;
};

struct class_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct class___277 *, struct class_attribute___277 *, char *);
	ssize_t (*store)(struct class___277 *, struct class_attribute___277 *, const char *, size_t);
	const void * (*namespace)(struct class___277 *, const struct class_attribute___277 *);
};

struct device_rh___277 {
	struct dev_pm_info_rh___277 power;
};

struct module_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___174 *, struct module_kobject___174 *, char *);
	ssize_t (*store)(struct module_attribute___174 *, struct module_kobject___174 *, const char *, size_t);
	void (*setup)(struct module___174 *, const char *);
	int (*test)(struct module___174 *);
	void (*free)(struct module___174 *);
};

struct socket_wq___58 {
	wait_queue_head_t wait;
	struct fasync_struct___279 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___58;

struct socket___59 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___58 *wq;
	struct file___279 *file;
	struct sock___58 *sk;
	const struct proto_ops___58 *ops;
};

struct proto_ops___58 {
	int family;
	struct module___174 *owner;
	int (*release)(struct socket___59 *);
	int (*bind)(struct socket___59 *, struct sockaddr *, int);
	int (*connect)(struct socket___59 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___59 *, struct socket___59 *);
	int (*accept)(struct socket___59 *, struct socket___59 *, int);
	int (*getname)(struct socket___59 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___279 *, struct socket___59 *, struct poll_table_struct___165 *);
	int (*ioctl)(struct socket___59 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___59 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___59 *, int);
	int (*shutdown)(struct socket___59 *, int);
	int (*setsockopt)(struct socket___59 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___59 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___59 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___59 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___66 *, struct socket___59 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___66 *, struct socket___59 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___279 *, struct socket___59 *, struct vm_area_struct___287 *);
	ssize_t (*sendpage)(struct socket___59 *, struct page___278 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___59 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___58 *, int);
		struct {
			void (*set_peek_off)(struct sock___58 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___81 {
	struct ctl_table_header___84 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___82 {
	struct mutex___281 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___81 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___84 *ctl;
};

struct netns_ipv4___81 {
	struct ctl_table_header___84 *forw_hdr;
	struct ctl_table_header___84 *frags_hdr;
	struct ctl_table_header___84 *ipv4_hdr;
	struct ctl_table_header___84 *route_hdr;
	struct ctl_table_header___84 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___58 *fibnl;
	struct sock___58 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___81 {
	struct ctl_table_header___84 *hdr;
	struct ctl_table_header___84 *route_hdr;
	struct ctl_table_header___84 *icmp_hdr;
	struct ctl_table_header___84 *frags_hdr;
	struct ctl_table_header___84 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___69;

struct neighbour___59;

struct dst_ops___83 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___83 *);
	struct dst_entry___59 * (*check)(struct dst_entry___59 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___59 *);
	unsigned int (*mtu)(const struct dst_entry___59 *);
	u32 * (*cow_metrics)(struct dst_entry___59 *, long unsigned int);
	void (*destroy)(struct dst_entry___59 *);
	void (*ifdown)(struct dst_entry___59 *, struct net_device___69 *, int);
	struct dst_entry___59 * (*negative_advice)(struct dst_entry___59 *);
	void (*link_failure)(struct sk_buff___71 *);
	void (*update_pmtu)(struct dst_entry___59 *, struct sock___58 *, struct sk_buff___71 *, u32);
	void (*redirect)(struct dst_entry___59 *, struct sock___58 *, struct sk_buff___71 *);
	int (*local_out)(struct sk_buff___71 *);
	struct neighbour___59 * (*neigh_lookup)(const struct dst_entry___59 *, struct sk_buff___71 *, const void *);
	struct kmem_cache___262 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___14;

struct fib6_table___14;

struct netns_ipv6___83 {
	struct netns_sysctl_ipv6___81 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___14 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___14 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___83 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___14 *ip6_prohibit_entry;
	struct rt6_info___14 *ip6_blk_hole_entry;
	struct fib6_table___14 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___58 **icmp_sk;
	struct sock___58 *ndisc_sk;
	struct sock___58 *tcp_sk;
	struct sock___58 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___81 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___84 *sysctl_header;
	struct sock___58 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___58 {
	struct sock___58 *v4_ctl_sk;
	struct sock___58 *v6_ctl_sk;
};

struct netns_nf___81 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___84 *nf_log_dir_header;
};

struct nf_proto_net___81 {
	struct ctl_table_header___84 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___81 {
	struct nf_proto_net___81 pn;
	unsigned int timeout;
};

struct nf_tcp_net___81 {
	struct nf_proto_net___81 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___81 {
	struct nf_proto_net___81 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___81 {
	struct nf_proto_net___81 pn;
	unsigned int timeout;
};

struct nf_ip_net___81 {
	struct nf_generic_net___81 generic;
	struct nf_tcp_net___81 tcp;
	struct nf_udp_net___81 udp;
	struct nf_icmp_net___81 icmp;
	struct nf_icmp_net___81 icmpv6;
};

struct netns_ct___82 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___84 *sysctl_header;
	struct ctl_table_header___84 *acct_sysctl_header;
	struct ctl_table_header___84 *tstamp_sysctl_header;
	struct ctl_table_header___84 *event_sysctl_header;
	struct ctl_table_header___84 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___262 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___81 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___81 {
	struct netns_sysctl_ipv6___81 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___83 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___58 *nlsk;
	struct sock___58 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___84 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___83 xfrm4_dst_ops;
	struct dst_ops___83 xfrm6_dst_ops;
};

struct net___83 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___84 sysctls;
	struct sock___58 *rtnl;
	struct sock___58 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___69 *loopback_dev;
	struct netns_core___81 core;
	struct netns_mib mib;
	struct netns_packet___82 packet;
	struct netns_unix___81 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___81 ipv4;
	struct netns_ipv6___83 ipv6;
	struct netns_sctp___81 sctp;
	struct netns_dccp___58 dccp;
	struct netns_nf___81 nf;
	struct netns_xt xt;
	struct netns_ct___82 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___81 nf_frag;
	struct sock___58 *nfnl;
	struct sock___58 *nfnl_stash;
	struct sk_buff_head___70 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___83 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___58 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___58 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___281 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___281 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___69 {
	atomic_t use;
	unsigned int mask;
	struct net_device___69 *physindev;
	struct net_device___69 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___69(struct sk_buff___71 **);

struct net_device_ops___69;

struct ethtool_ops___69;

struct header_ops___69;

struct inet6_dev___35;

struct netdev_rx_queue___69;

struct netdev_queue___69;

struct rtnl_link_ops___60;

struct dcbnl_rtnl_ops___69;

struct net_device___69 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___69 *netdev_ops;
	const struct ethtool_ops___69 *ethtool_ops;
	const struct header_ops___69 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___61 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___35 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___69 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___69 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___69 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___69 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___69 = 0,
		NETREG_REGISTERED___69 = 1,
		NETREG_UNREGISTERING___69 = 2,
		NETREG_UNREGISTERED___69 = 3,
		NETREG_RELEASED___69 = 4,
		NETREG_DUMMY___69 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___69 = 0,
		RTNL_LINK_INITIALIZING___69 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___69 *);
	struct netpoll_info *npinfo;
	struct net___83 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___277 dev;
	const struct attribute_group___239 *sysfs_groups[4];
	const struct rtnl_link_ops___60 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___69 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___14;

struct sk_buff___71 {
	struct sk_buff___71 *next;
	struct sk_buff___71 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___58 *sk;
	struct net_device___69 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___14 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___71 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___69 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___18 {
	struct {
		struct page___278 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___18 skb_frag_t___18;

struct skb_shared_info___18 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___71 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___18 frags[17];
};

struct xfrm_state___14;

struct sec_path___14 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___14 *xvec[6];
};

struct dev_pm_qos_request___81 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___277 *dev;
};

struct ethtool_ops___69 {
	int (*get_settings)(struct net_device___69 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___69 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___69 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___69 *);
	void (*get_regs)(struct net_device___69 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___69 *);
	void (*set_msglevel)(struct net_device___69 *, u32);
	int (*nway_reset)(struct net_device___69 *);
	u32 (*get_link)(struct net_device___69 *);
	int (*get_eeprom_len)(struct net_device___69 *);
	int (*get_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___69 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___69 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___69 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___69 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___69 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___69 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___69 *);
	void (*complete)(struct net_device___69 *);
	u32 (*get_priv_flags)(struct net_device___69 *);
	int (*set_priv_flags)(struct net_device___69 *, u32);
	int (*get_sset_count)(struct net_device___69 *, int);
	int (*get_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___69 *, struct ethtool_flash *);
	int (*reset)(struct net_device___69 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___69 *);
	int (*get_rxfh_indir)(struct net_device___69 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___69 *, const u32 *);
	void (*get_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___69 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___69 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___69 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___69 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___69 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___69 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___69 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___69 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	UDP_MIB_NUM = 0,
	UDP_MIB_INDATAGRAMS = 1,
	UDP_MIB_NOPORTS = 2,
	UDP_MIB_INERRORS = 3,
	UDP_MIB_OUTDATAGRAMS = 4,
	UDP_MIB_RCVBUFERRORS = 5,
	UDP_MIB_SNDBUFERRORS = 6,
	UDP_MIB_CSUMERRORS = 7,
	__UDP_MIB_MAX = 8,
};

struct rtable___30;

struct dst_entry___59 {
	struct callback_head callback_head;
	struct dst_entry___59 *child;
	struct net_device___69 *dev;
	struct dst_ops___83 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___59 *path;
	struct dst_entry___59 *from;
	struct xfrm_state___14 *xfrm;
	int (*input)(struct sk_buff___71 *);
	union {
		int (*output)(struct sock___58 *, struct sk_buff___71 *);
		struct {
			int (*output)(struct sk_buff___71 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___59 *next;
		struct rtable___30 *rt_next;
		struct rt6_info___14 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___59;

struct neigh_parms___59;

struct neigh_ops___59;

struct neighbour___59 {
	struct neighbour___59 *next;
	struct neigh_table___59 *tbl;
	struct neigh_parms___59 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___70 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___59 *, struct sk_buff___71 *);
	const struct neigh_ops___59 *ops;
	struct callback_head rcu;
	struct net_device___69 *dev;
	u8 primary_key[0];
};

struct fib6_node___14;

struct rt6_info___14 {
	struct dst_entry___59 dst;
	struct fib6_table___14 *rt6i_table;
	struct fib6_node___14 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___35 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___14 {
	struct fib6_node___14 *parent;
	struct fib6_node___14 *left;
	struct fib6_node___14 *right;
	struct rt6_info___14 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___14 *rr_ptr;
};

struct fib6_table___14 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___14 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___83 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___71 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___71 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___83 *, struct dst_entry___59 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___71 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___71 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___204 {
	void * (*start)(struct seq_file___204 *, loff_t *);
	void (*stop)(struct seq_file___204 *, void *);
	void * (*next)(struct seq_file___204 *, void *, loff_t *);
	int (*show)(struct seq_file___204 *, void *);
};

struct seq_net_private___9 {
	struct net___83 *net;
};

struct pernet_operations___18 {
	struct list_head list;
	int (*init)(struct net___83 *);
	void (*exit)(struct net___83 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___69 {
	int (*ieee_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___69 *);
	u8 (*setstate)(struct net_device___69 *, u8);
	void (*getpermhwaddr)(struct net_device___69 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___69 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___69 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___69 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___69 *, int, u8 *);
	void (*setpfccfg)(struct net_device___69 *, int, u8);
	void (*getpfccfg)(struct net_device___69 *, int, u8 *);
	u8 (*setall)(struct net_device___69 *);
	u8 (*getcap)(struct net_device___69 *, int, u8 *);
	int (*getnumtcs)(struct net_device___69 *, int, u8 *);
	int (*setnumtcs)(struct net_device___69 *, int, u8);
	u8 (*getpfcstate)(struct net_device___69 *);
	void (*setpfcstate)(struct net_device___69 *, u8);
	void (*getbcncfg)(struct net_device___69 *, int, u32 *);
	void (*setbcncfg)(struct net_device___69 *, int, u32);
	void (*getbcnrp)(struct net_device___69 *, int, u8 *);
	void (*setbcnrp)(struct net_device___69 *, int, u8);
	u8 (*setapp)(struct net_device___69 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___69 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___69 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___69 *, int, u8);
	u8 (*getdcbx)(struct net_device___69 *);
	u8 (*setdcbx)(struct net_device___69 *, u8);
	int (*peer_getappinfo)(struct net_device___69 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___69 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___69 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___69 *, struct cee_pfc *);
};

struct request_sock_ops___44;

struct request_sock___45 {
	struct sock_common___58 __req_common;
	struct request_sock___45 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___44 *rsk_ops;
	struct sock___58 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___14;

struct xfrm_type___14;

struct xfrm_mode___14;

struct xfrm_state___14 {
	struct net___83 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___14 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___14 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___14 *type;
	struct xfrm_mode___14 *inner_mode;
	struct xfrm_mode___14 *inner_mode_iaf;
	struct xfrm_mode___14 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___14 {
	struct sk_buff_head___70 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___14 {
	struct net___83 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___14 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___71 {
	struct sk_buff___71 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___71 *, struct netlink_callback___71 *);
	int (*done)(struct netlink_callback___71 *);
	void *data;
	struct module___174 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___69 {
	int (*create)(struct sk_buff___71 *, struct net_device___69 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___71 *, unsigned char *);
	int (*rebuild)(struct sk_buff___71 *);
	int (*cache)(const struct neighbour___59 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___69 *, const unsigned char *);
};

struct napi_struct___69 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___69 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___69 *dev;
	struct sk_buff___71 *gro_list;
	struct sk_buff___71 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___69 {
	struct net_device___69 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___61 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___69 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___61 kobj;
	struct net_device___69 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___69 {
	int (*ndo_init)(struct net_device___69 *);
	void (*ndo_uninit)(struct net_device___69 *);
	int (*ndo_open)(struct net_device___69 *);
	int (*ndo_stop)(struct net_device___69 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___71 *, struct net_device___69 *);
	u16 (*ndo_select_queue)(struct net_device___69 *, struct sk_buff___71 *);
	void (*ndo_change_rx_flags)(struct net_device___69 *, int);
	void (*ndo_set_rx_mode)(struct net_device___69 *);
	int (*ndo_set_mac_address)(struct net_device___69 *, void *);
	int (*ndo_validate_addr)(struct net_device___69 *);
	int (*ndo_do_ioctl)(struct net_device___69 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___69 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___69 *, int);
	int (*ndo_neigh_setup)(struct net_device___69 *, struct neigh_parms___59 *);
	void (*ndo_tx_timeout)(struct net_device___69 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___69 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___69 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___69 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___69 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___69 *);
	int (*ndo_netpoll_setup)(struct net_device___69 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___69 *);
	int (*ndo_busy_poll)(struct napi_struct___69 *);
	int (*ndo_set_vf_mac)(struct net_device___69 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___69 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___69 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___69 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___69 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___69 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___69 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___69 *, int, struct sk_buff___71 *);
	int (*ndo_setup_tc)(struct net_device___69 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___69 *);
	int (*ndo_fcoe_disable)(struct net_device___69 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___69 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___69 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___69 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___69 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___69 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___69 *, const struct sk_buff___71 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___69 *, struct net_device___69 *);
	int (*ndo_del_slave)(struct net_device___69 *, struct net_device___69 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___59 *);
	void (*ndo_neigh_destroy)(struct neighbour___59 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___71 *, struct netlink_callback___71 *, struct net_device___69 *, int);
	int (*ndo_bridge_setlink)(struct net_device___69 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___71 *, u32, u32, struct net_device___69 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___69 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___69 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___69 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___69 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___69 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___69 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___71 *, struct net_device___69 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___69 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___69 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___69 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___59 {
	struct net___83 *net;
	struct net_device___69 *dev;
	struct neigh_parms___59 *next;
	int (*neigh_setup)(struct neighbour___59 *);
	void (*neigh_cleanup)(struct neighbour___59 *);
	struct neigh_table___59 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___35;

struct ifacaddr6___35;

struct inet6_dev___35 {
	struct net_device___69 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___35 *mc_list;
	struct ifmcaddr6___35 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___35 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___59 *nd_parms;
	struct inet6_dev___35 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___60 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___69 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___83 *, struct net_device___69 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___69 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___69 *, struct list_head *);
	size_t (*get_size)(const struct net_device___69 *);
	int (*fill_info)(struct sk_buff___71 *, const struct net_device___69 *);
	size_t (*get_xstats_size)(const struct net_device___69 *);
	int (*fill_xstats)(struct sk_buff___71 *, const struct net_device___69 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___83 * (*get_link_net)(const struct net_device___69 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___69 *, struct net_device___69 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___69 *, const struct net_device___69 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___71 *, const struct net_device___69 *, const struct net_device___69 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___59 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___71 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef struct poll_table_struct___165 poll_table___42;

struct pneigh_entry___59;

struct neigh_hash_table___59;

struct neigh_table___59 {
	struct neigh_table___59 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___69 *, __u32 *);
	int (*constructor)(struct neighbour___59 *);
	int (*pconstructor)(struct pneigh_entry___59 *);
	void (*pdestructor)(struct pneigh_entry___59 *);
	void (*proxy_redo)(struct sk_buff___71 *);
	char *id;
	struct neigh_parms___59 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___70 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___59 *nht;
	struct pneigh_entry___59 **phash_buckets;
};

struct neigh_ops___59 {
	int family;
	void (*solicit)(struct neighbour___59 *, struct sk_buff___71 *);
	void (*error_report)(struct neighbour___59 *, struct sk_buff___71 *);
	int (*output)(struct neighbour___59 *, struct sk_buff___71 *);
	int (*connected_output)(struct neighbour___59 *, struct sk_buff___71 *);
};

struct pneigh_entry___59 {
	struct pneigh_entry___59 *next;
	struct net___83 *net;
	struct net_device___69 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___59 {
	struct neighbour___59 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___30 {
	struct dst_entry___59 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___41;

struct proto___58 {
	void (*close)(struct sock___58 *, long int);
	int (*connect)(struct sock___58 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___58 *, int);
	struct sock___58 * (*accept)(struct sock___58 *, int, int *);
	int (*ioctl)(struct sock___58 *, int, long unsigned int);
	int (*init)(struct sock___58 *);
	void (*destroy)(struct sock___58 *);
	void (*shutdown)(struct sock___58 *, int);
	int (*setsockopt)(struct sock___58 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___58 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___58 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___58 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___58 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___66 *, struct sock___58 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___66 *, struct sock___58 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___58 *, struct page___278 *, int, size_t, int);
	int (*bind)(struct sock___58 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___58 *, struct sk_buff___71 *);
	void (*release_cb)(struct sock___58 *);
	void (*mtu_reduced)(struct sock___58 *);
	void (*hash)(struct sock___58 *);
	void (*unhash)(struct sock___58 *);
	void (*rehash)(struct sock___58 *);
	int (*get_port)(struct sock___58 *, short unsigned int);
	void (*clear_sk)(struct sock___58 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___58 *);
	void (*enter_memory_pressure)(struct sock___58 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___262 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___44 *rsk_prot;
	struct timewait_sock_ops___41 *twsk_prot;
	union {
		struct inet_hashinfo___13 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___174 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___106 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___58 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___58 {
	void (*enter_memory_pressure)(struct sock___58 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___44 {
	int family;
	int obj_size;
	struct kmem_cache___262 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___58 *, struct request_sock___45 *);
	void (*send_ack)(struct sock___58 *, struct sk_buff___71 *, struct request_sock___45 *);
	void (*send_reset)(struct sock___58 *, struct sk_buff___71 *);
	void (*destructor)(struct request_sock___45 *);
	void (*syn_ack_timeout)(struct sock___58 *, struct request_sock___45 *);
};

struct timewait_sock_ops___41 {
	struct kmem_cache___262 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___58 *, struct sock___58 *, void *);
	void (*twsk_destructor)(struct sock___58 *);
};

struct inet_cork___17 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___59 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___17 {
	struct inet_cork___17 base;
	struct flowi fl;
};

struct ipv6_pinfo___16;

struct inet_sock___17 {
	struct sock___58 sk;
	struct ipv6_pinfo___16 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___17 cork;
};

struct ipv6_fl_socklist___15;

struct ipv6_pinfo___16 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___15 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___71 *pktoptions;
	struct sk_buff___71 *rxpmtu;
	struct inet6_cork cork;
};

struct udp_sock {
	struct inet_sock___17 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___58 *, struct sk_buff___71 *);
	void (*encap_destroy)(struct sock___58 *);
};

struct ip6_flowlabel___15;

struct ipv6_fl_socklist___15 {
	struct ipv6_fl_socklist___15 *next;
	struct ip6_flowlabel___15 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___35 {
	struct in6_addr mca_addr;
	struct inet6_dev___35 *idev;
	struct ifmcaddr6___35 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___35 {
	struct in6_addr aca_addr;
	struct inet6_dev___35 *aca_idev;
	struct rt6_info___14 *aca_rt;
	struct ifacaddr6___35 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___15 {
	struct ip6_flowlabel___15 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___83 *fl_net;
};

struct xfrm_replay___14 {
	void (*advance)(struct xfrm_state___14 *, __be32);
	int (*check)(struct xfrm_state___14 *, struct sk_buff___71 *, __be32);
	int (*recheck)(struct xfrm_state___14 *, struct sk_buff___71 *, __be32);
	void (*notify)(struct xfrm_state___14 *, int);
	int (*overflow)(struct xfrm_state___14 *, struct sk_buff___71 *);
};

struct xfrm_type___14 {
	char *description;
	struct module___174 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___14 *);
	void (*destructor)(struct xfrm_state___14 *);
	int (*input)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*output)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*reject)(struct xfrm_state___14 *, struct sk_buff___71 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___14 *, struct sk_buff___71 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___14 *, int);
};

struct xfrm_state_afinfo___14;

struct xfrm_mode___14 {
	int (*input2)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*input)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*output2)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*output)(struct xfrm_state___14 *, struct sk_buff___71 *);
	struct xfrm_state_afinfo___14 *afinfo;
	struct module___174 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___14 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___174 *owner;
	const struct xfrm_type___14 *type_map[256];
	struct xfrm_mode___14 *mode_map[5];
	int (*init_flags)(struct xfrm_state___14 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___14 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___14 **, struct xfrm_state___14 **, int);
	union {
		int (*output)(struct sock___58 *, struct sk_buff___71 *);
		struct {
			int (*output)(struct sk_buff___71 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___58 *, struct sk_buff___71 *);
		struct {
			int (*output_finish)(struct sk_buff___71 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*extract_output)(struct xfrm_state___14 *, struct sk_buff___71 *);
	int (*transport_finish)(struct sk_buff___71 *, int);
};

struct udp_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	__u16 cscov;
	__u8 partial_cov;
};

struct udp_seq_afinfo {
	char *name;
	sa_family_t family;
	struct udp_table *udp_table;
	const struct file_operations___279 *seq_fops;
	struct seq_operations___204 seq_ops;
};

struct udp_iter_state {
	struct seq_net_private___9 p;
	sa_family_t family;
	int bucket;
	struct udp_table *udp_table;
};

struct page___279;

typedef struct page___279 *pgtable_t___279;

struct address_space___280;

struct kmem_cache___263;

struct page___279 {
	long unsigned int flags;
	struct address_space___280 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___279 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___279 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___263 *slab_cache;
		struct page___279 *first_page;
	};
	long: 64;
};

struct task_struct___281;

struct pv_cpu_ops___281 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___281 *);
	void (*end_context_switch)(struct task_struct___281 *);
};

struct mutex___282 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___281 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___274 {
	struct page___279 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___288;

struct nsproxy___160;

struct signal_struct___281;

struct css_set___175;

struct task_struct___281 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___281 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___288 *mm;
	struct mm_struct___288 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___281 *real_parent;
	struct task_struct___281 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___281 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___281 = 0,
		VTIME_USER___281 = 1,
		VTIME_SYS___281 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___160 *nsproxy;
	struct signal_struct___281 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___175 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___282 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___274 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___288 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___288 *, struct mm_struct___288 *);
	void (*dup_mmap)(struct mm_struct___288 *, struct mm_struct___288 *);
	void (*exit_mmap)(struct mm_struct___288 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___288 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___288 *);
	void (*pgd_free)(struct mm_struct___288 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___288 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___288 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___288 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___288 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___288 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___288 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___288 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___288 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___288 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___288 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___288 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___282 lock;
	void *vdso;
} mm_context_t___282;

struct xol_area___279;

struct uprobes_state___279 {
	struct xol_area___279 *xol_area;
};

struct vm_area_struct___288;

struct file___280;

struct core_state___281;

struct mm_struct___288 {
	struct vm_area_struct___288 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___288 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___288 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___282 context;
	long unsigned int flags;
	struct core_state___281 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___281 *owner;
	struct file___280 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___279 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___279 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___279 *page;
	long unsigned int vaddr;
};

struct kset___62;

struct kobj_type___62;

struct kobject___62 {
	const char *name;
	struct list_head entry;
	struct kobject___62 *parent;
	struct kset___62 *kset;
	struct kobj_type___62 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___262;

struct memcg_cache_params___263;

struct kmem_cache___263 {
	struct kmem_cache_cpu___262 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___62 kobj;
	struct memcg_cache_params___263 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___280;

struct address_space_operations___280;

struct address_space___280 {
	struct inode___280 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___282 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___280 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___280;

struct path___280 {
	struct vfsmount *mnt;
	struct dentry___280 *dentry;
};

struct file_operations___280;

struct file___280 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___280 f_path;
	struct inode___280 *f_inode;
	const struct file_operations___280 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___280 *f_mapping;
	struct mutex___282 f_pos_lock;
};

struct vm_operations_struct___254;

struct vm_area_struct___288 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___288 *vm_next;
	struct vm_area_struct___288 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___288 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___254 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___280 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___250;

struct vm_operations_struct___254 {
	void (*open)(struct vm_area_struct___288 *);
	void (*close)(struct vm_area_struct___288 *);
	int (*fault)(struct vm_area_struct___288 *, struct vm_fault___250 *);
	int (*page_mkwrite)(struct vm_area_struct___288 *, struct vm_fault___250 *);
	int (*access)(struct vm_area_struct___288 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___288 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___288 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___288 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___288 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___281 {
	struct task_struct___281 *task;
	struct core_thread___281 *next;
};

struct core_state___281 {
	atomic_t nr_threads;
	struct core_thread___281 dumper;
	struct completion startup;
};

struct kiocb___67;

struct poll_table_struct___166;

struct file_lock___280;

struct seq_file___205;

struct file_operations___280 {
	struct module *owner;
	loff_t (*llseek)(struct file___280 *, loff_t, int);
	ssize_t (*read)(struct file___280 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___280 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___67 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___67 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___280 *, void *, filldir_t);
	unsigned int (*poll)(struct file___280 *, struct poll_table_struct___166 *);
	long int (*unlocked_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___280 *, struct vm_area_struct___288 *);
	int (*open)(struct inode___280 *, struct file___280 *);
	int (*flush)(struct file___280 *, fl_owner_t);
	int (*release)(struct inode___280 *, struct file___280 *);
	int (*fsync)(struct file___280 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___67 *, int);
	int (*fasync)(int, struct file___280 *, int);
	int (*lock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*sendpage)(struct file___280 *, struct page___279 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___280 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___280 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___280 *, long int, struct file_lock___280 **, void **);
		struct {
			int (*setlease)(struct file___280 *, long int, struct file_lock___280 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___280 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___205 *, struct file___280 *);
};

struct dev_pm_qos___81;

struct dev_pm_info___81 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___81 *qos;
};

struct dma_map_ops___143;

struct dev_archdata___143 {
	struct dma_map_ops___143 *dma_ops;
	void *iommu;
};

struct device_type___278;

struct bus_type___278;

struct device_driver___278;

struct dev_pm_domain___278;

struct class___278;

struct attribute_group___240;

struct device_rh___278;

struct device___278 {
	struct device___278 *parent;
	struct device_private *p;
	struct kobject___62 kobj;
	const char *init_name;
	const struct device_type___278 *type;
	struct mutex___282 mutex;
	struct bus_type___278 *bus;
	struct device_driver___278 *driver;
	void *platform_data;
	struct dev_pm_info___81 power;
	struct dev_pm_domain___278 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___143 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___42 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___278 *class;
	const struct attribute_group___240 **groups;
	void (*release)(struct device___278 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___278 *device_rh;
};

struct sock___59;

struct kobj_ns_type_operations___59 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___59 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___59;

struct net___84;

struct sock_common___59 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___59 *skc_prot;
	struct net___84 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___72;

struct sk_buff_head___71 {
	struct sk_buff___72 *next;
	struct sk_buff___72 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___60;

struct socket_wq___59;

struct dst_entry___60;

struct socket___60;

struct cg_proto___59;

struct sock___59 {
	struct sock_common___59 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___71 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___72 *head;
		struct sk_buff___72 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___60 *sk_filter;
	struct socket_wq___59 *sk_wq;
	struct sk_buff_head___71 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___60 *sk_rx_dst;
	struct dst_entry___60 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___71 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___71 sk_error_queue;
	struct proto___59 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___60 *sk_socket;
	void *sk_user_data;
	struct page_frag___274 sk_frag;
	struct sk_buff___72 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___59 *sk_cgrp;
	void (*sk_state_change)(struct sock___59 *);
	void (*sk_data_ready)(struct sock___59 *, int);
	void (*sk_write_space)(struct sock___59 *);
	void (*sk_error_report)(struct sock___59 *);
	int (*sk_backlog_rcv)(struct sock___59 *, struct sk_buff___72 *);
	void (*sk_destruct)(struct sock___59 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___242;

struct attribute_group___240 {
	const char *name;
	umode_t (*is_visible)(struct kobject___62 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___242 **bin_attrs;
};

struct bin_attribute___242 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___280 *, struct kobject___62 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___280 *, struct kobject___62 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	int (*mmap)(struct file___280 *, struct kobject___62 *, struct bin_attribute___242 *, struct vm_area_struct___288 *);
};

struct sysfs_ops___62 {
	ssize_t (*show)(struct kobject___62 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___62 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___62 *, const struct attribute *);
};

struct kset_uevent_ops___62;

struct kset___62 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___62 kobj;
	const struct kset_uevent_ops___62 *uevent_ops;
};

struct kobj_type___62 {
	void (*release)(struct kobject___62 *);
	const struct sysfs_ops___62 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___59 * (*child_ns_type)(struct kobject___62 *);
	const void * (*namespace)(struct kobject___62 *);
};

struct kset_uevent_ops___62 {
	int (* const filter)(struct kset___62 *, struct kobject___62 *);
	const char * (* const name)(struct kset___62 *, struct kobject___62 *);
	int (* const uevent)(struct kset___62 *, struct kobject___62 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___278 {
	int (*prepare)(struct device___278 *);
	void (*complete)(struct device___278 *);
	int (*suspend)(struct device___278 *);
	int (*resume)(struct device___278 *);
	int (*freeze)(struct device___278 *);
	int (*thaw)(struct device___278 *);
	int (*poweroff)(struct device___278 *);
	int (*restore)(struct device___278 *);
	int (*suspend_late)(struct device___278 *);
	int (*resume_early)(struct device___278 *);
	int (*freeze_late)(struct device___278 *);
	int (*thaw_early)(struct device___278 *);
	int (*poweroff_late)(struct device___278 *);
	int (*restore_early)(struct device___278 *);
	int (*suspend_noirq)(struct device___278 *);
	int (*resume_noirq)(struct device___278 *);
	int (*freeze_noirq)(struct device___278 *);
	int (*thaw_noirq)(struct device___278 *);
	int (*poweroff_noirq)(struct device___278 *);
	int (*restore_noirq)(struct device___278 *);
	int (*runtime_suspend)(struct device___278 *);
	int (*runtime_resume)(struct device___278 *);
	int (*runtime_idle)(struct device___278 *);
};

struct dev_pm_qos_request___82;

struct dev_pm_qos___81 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___82 *latency_req;
	struct dev_pm_qos_request___82 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___82 *latency_tolerance_req;
};

struct dev_pm_info_rh___278 {
	void (*set_latency_tolerance)(struct device___278 *, s32);
};

struct dev_pm_domain___278 {
	struct dev_pm_ops___278 ops;
};

struct zone___281;

struct lruvec___281 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___281 *zone;
};

struct pglist_data___281;

struct zone___281 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___281 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___281 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___281 {
	struct zone___281 *zone;
	int zone_idx;
};

struct zonelist___281 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___281 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___281 {
	struct zone___281 node_zones[4];
	struct zonelist___281 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___281 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___204;

struct x86_io_apic_ops___204 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___204 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___204;

struct irq_data___204 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___204 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___281 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___281 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___143 {
	void * (*alloc)(struct device___278 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___278 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___278 *, struct vm_area_struct___288 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___278 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___278 *, struct page___279 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___278 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___278 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___278 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___278 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___278 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___278 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___278 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___278 *, dma_addr_t);
	int (*dma_supported)(struct device___278 *, u64);
	int (*set_dma_mask)(struct device___278 *, u64);
	int is_phys;
};

struct bus_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___278 *, char *);
	ssize_t (*store)(struct bus_type___278 *, const char *, size_t);
};

struct device_attribute___278;

struct driver_attribute___278;

struct bus_type___278 {
	const char *name;
	const char *dev_name;
	struct device___278 *dev_root;
	struct bus_attribute___278 *bus_attrs;
	struct device_attribute___278 *dev_attrs;
	struct driver_attribute___278 *drv_attrs;
	const struct attribute_group___240 **bus_groups;
	const struct attribute_group___240 **dev_groups;
	const struct attribute_group___240 **drv_groups;
	int (*match)(struct device___278 *, struct device_driver___278 *);
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	int (*probe)(struct device___278 *);
	int (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*online)(struct device___278 *);
	int (*offline)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct device___278 *, struct device_attribute___278 *, char *);
	ssize_t (*store)(struct device___278 *, struct device_attribute___278 *, const char *, size_t);
};

struct driver_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___278 *, char *);
	ssize_t (*store)(struct device_driver___278 *, const char *, size_t);
};

struct device_driver___278 {
	const char *name;
	struct bus_type___278 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___278 *);
	int (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	const struct attribute_group___240 **groups;
	const struct dev_pm_ops___278 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___278 {
	const char *name;
	const struct attribute_group___240 **groups;
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
};

struct class_attribute___278;

struct class___278 {
	const char *name;
	struct module *owner;
	struct class_attribute___278 *class_attrs;
	struct device_attribute___278 *dev_attrs;
	const struct attribute_group___240 **dev_groups;
	struct bin_attribute___242 *dev_bin_attrs;
	struct kobject___62 *dev_kobj;
	int (*dev_uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *);
	void (*class_release)(struct class___278 *);
	void (*dev_release)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	const struct kobj_ns_type_operations___59 *ns_type;
	const void * (*namespace)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
	struct subsys_private *p;
};

struct class_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct class___278 *, struct class_attribute___278 *, char *);
	ssize_t (*store)(struct class___278 *, struct class_attribute___278 *, const char *, size_t);
	const void * (*namespace)(struct class___278 *, const struct class_attribute___278 *);
};

struct device_rh___278 {
	struct dev_pm_info_rh___278 power;
};

struct dev_pm_qos_request___82 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___278 *dev;
};

struct vm_fault___250 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___279 *page;
};

struct dentry_operations___280;

struct super_block___280;

struct dentry___280 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___280 *d_parent;
	struct qstr d_name;
	struct inode___280 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___280 *d_op;
	struct super_block___280 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___280;

struct dquot___280;

struct block_device___280;

struct inode___280 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___280 *i_op;
	struct super_block___280 *i_sb;
	struct address_space___280 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___282 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___280 *i_fop;
	struct file_lock___280 *i_flock;
	struct address_space___280 i_data;
	struct dquot___280 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___280 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___280 {
	int (*d_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_hash)(const struct dentry___280 *, struct qstr *);
	int (*d_compare)(const struct dentry___280 *, const struct dentry___280 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___280 *);
	void (*d_release)(struct dentry___280 *);
	void (*d_prune)(struct dentry___280 *);
	void (*d_iput)(struct dentry___280 *, struct inode___280 *);
	char * (*d_dname)(struct dentry___280 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___280 *);
	int (*d_manage)(struct dentry___280 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___280;

struct mem_dqinfo___280 {
	struct quota_format_type___280 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___280;

struct quota_info___280 {
	unsigned int flags;
	struct mutex___282 dqio_mutex;
	struct mutex___282 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___280 *files[2];
	struct mem_dqinfo___280 info[2];
	const struct quota_format_ops___280 *ops[2];
};

struct file_system_type___280;

struct super_operations___280;

struct dquot_operations___280;

struct quotactl_ops___280;

struct xattr_handler___176;

struct super_block___280 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___280 *s_type;
	const struct super_operations___280 *s_op;
	const struct dquot_operations___280 *dq_op;
	const struct quotactl_ops___280 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___280 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___176 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___280 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___280 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___282 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___280 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___280 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___280 *bd_inode;
	struct super_block___280 *bd_super;
	struct mutex___282 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___280 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___282 bd_fsfreeze_mutex;
};

struct cgroup___175;

struct cgroup_subsys_state___175 {
	struct cgroup___175 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___67(struct kiocb___67 *, struct io_event *);

struct kiocb___67 {
	atomic_t ki_users;
	struct file___280 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___67 *ki_cancel;
	void (*ki_dtor)(struct kiocb___67 *);
	union {
		void *user;
		struct task_struct___281 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___280 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___280 *ia_file;
};

struct dquot___280 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___282 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___280 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___280 {
	int qf_fmt_id;
	const struct quota_format_ops___280 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___280 *qf_next;
};

struct quota_format_ops___280 {
	int (*check_quota_file)(struct super_block___280 *, int);
	int (*read_file_info)(struct super_block___280 *, int);
	int (*write_file_info)(struct super_block___280 *, int);
	int (*free_file_info)(struct super_block___280 *, int);
	int (*read_dqblk)(struct dquot___280 *);
	int (*commit_dqblk)(struct dquot___280 *);
	int (*release_dqblk)(struct dquot___280 *);
};

struct dquot_operations___280 {
	int (*write_dquot)(struct dquot___280 *);
	struct dquot___280 * (*alloc_dquot)(struct super_block___280 *, int);
	void (*destroy_dquot)(struct dquot___280 *);
	int (*acquire_dquot)(struct dquot___280 *);
	int (*release_dquot)(struct dquot___280 *);
	int (*mark_dirty)(struct dquot___280 *);
	int (*write_info)(struct super_block___280 *, int);
	qsize_t * (*get_reserved_space)(struct inode___280 *);
};

struct quotactl_ops___280 {
	int (*quota_on)(struct super_block___280 *, int, int, struct path___280 *);
	int (*quota_on_meta)(struct super_block___280 *, int, int);
	int (*quota_off)(struct super_block___280 *, int);
	int (*quota_sync)(struct super_block___280 *, int);
	int (*get_info)(struct super_block___280 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___280 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___280 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___280 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___280 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___280 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___280 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___280 *, unsigned int);
};

struct address_space_operations___280 {
	int (*writepage)(struct page___279 *, struct writeback_control *);
	int (*readpage)(struct file___280 *, struct page___279 *);
	int (*writepages)(struct address_space___280 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___279 *);
	int (*readpages)(struct file___280 *, struct address_space___280 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___280 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___279 **, void **);
	int (*write_end)(struct file___280 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___279 *, void *);
	sector_t (*bmap)(struct address_space___280 *, sector_t);
	void (*invalidatepage)(struct page___279 *, long unsigned int);
	int (*releasepage)(struct page___279 *, gfp_t);
	void (*freepage)(struct page___279 *);
	ssize_t (*direct_IO)(int, struct kiocb___67 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___280 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___280 *, struct page___279 *, struct page___279 *, enum migrate_mode);
	int (*launder_page)(struct page___279 *);
	int (*is_partially_uptodate)(struct page___279 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___279 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___280 *, struct page___279 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___280 *, sector_t *);
	void (*swap_deactivate)(struct file___280 *);
	void (*invalidatepage_range)(struct page___279 *, unsigned int, unsigned int);
};

struct inode_operations___280 {
	struct dentry___280 * (*lookup)(struct inode___280 *, struct dentry___280 *, unsigned int);
	void * (*follow_link)(struct dentry___280 *, struct nameidata *);
	int (*permission)(struct inode___280 *, int);
	struct posix_acl * (*get_acl)(struct inode___280 *, int);
	int (*readlink)(struct dentry___280 *, char *, int);
	void (*put_link)(struct dentry___280 *, struct nameidata *, void *);
	int (*create)(struct inode___280 *, struct dentry___280 *, umode_t, bool);
	int (*link)(struct dentry___280 *, struct inode___280 *, struct dentry___280 *);
	int (*unlink)(struct inode___280 *, struct dentry___280 *);
	int (*symlink)(struct inode___280 *, struct dentry___280 *, const char *);
	int (*mkdir)(struct inode___280 *, struct dentry___280 *, umode_t);
	int (*rmdir)(struct inode___280 *, struct dentry___280 *);
	int (*mknod)(struct inode___280 *, struct dentry___280 *, umode_t, dev_t);
	int (*rename)(struct inode___280 *, struct dentry___280 *, struct inode___280 *, struct dentry___280 *);
	int (*setattr)(struct dentry___280 *, struct iattr___280 *);
	int (*getattr)(struct vfsmount *, struct dentry___280 *, struct kstat *);
	int (*setxattr)(struct dentry___280 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___280 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___280 *, char *, size_t);
	int (*removexattr)(struct dentry___280 *, const char *);
	int (*fiemap)(struct inode___280 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___280 *, struct timespec *, int);
	int (*atomic_open)(struct inode___280 *, struct dentry___280 *, struct file___280 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___280;

struct file_lock_operations___280;

struct lock_manager_operations___280;

struct file_lock___280 {
	struct file_lock___280 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___280 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___280 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___280 *fl_ops;
	const struct lock_manager_operations___280 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___280 {
	void (*fl_copy_lock)(struct file_lock___280 *, struct file_lock___280 *);
	void (*fl_release_private)(struct file_lock___280 *);
};

struct lock_manager_operations___280 {
	int (*lm_compare_owner)(struct file_lock___280 *, struct file_lock___280 *);
	long unsigned int (*lm_owner_key)(struct file_lock___280 *);
	void (*lm_notify)(struct file_lock___280 *);
	int (*lm_grant)(struct file_lock___280 *, struct file_lock___280 *, int);
	void (*lm_break)(struct file_lock___280 *);
	int (*lm_change)(struct file_lock___280 **, int);
};

struct fasync_struct___280 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___280 *fa_next;
	struct file___280 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___280 {
	const char *name;
	int fs_flags;
	struct dentry___280 * (*mount)(struct file_system_type___280 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___280 *);
	struct module *owner;
	struct file_system_type___280 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___280 {
	struct inode___280 * (*alloc_inode)(struct super_block___280 *);
	void (*destroy_inode)(struct inode___280 *);
	void (*dirty_inode)(struct inode___280 *, int);
	int (*write_inode)(struct inode___280 *, struct writeback_control *);
	int (*drop_inode)(struct inode___280 *);
	void (*evict_inode)(struct inode___280 *);
	void (*put_super)(struct super_block___280 *);
	int (*sync_fs)(struct super_block___280 *, int);
	int (*freeze_fs)(struct super_block___280 *);
	int (*unfreeze_fs)(struct super_block___280 *);
	int (*statfs)(struct dentry___280 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___280 *, int *, char *);
	void (*umount_begin)(struct super_block___280 *);
	int (*show_options)(struct seq_file___205 *, struct dentry___280 *);
	int (*show_devname)(struct seq_file___205 *, struct dentry___280 *);
	int (*show_path)(struct seq_file___205 *, struct dentry___280 *);
	int (*show_stats)(struct seq_file___205 *, struct dentry___280 *);
	ssize_t (*quota_read)(struct super_block___280 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___280 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___280 *);
	int (*bdev_try_to_free_page)(struct super_block___280 *, struct page___279 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___280 *);
	void (*free_cached_objects)(struct super_block___280 *, int);
};

struct xattr_handler___176 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___280 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___280 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___280 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___168)(struct file___280 *, wait_queue_head_t *, struct poll_table_struct___166 *);

struct poll_table_struct___166 {
	poll_queue_proc___168 _qproc;
	long unsigned int _key;
};

struct seq_operations___205;

struct seq_file___205 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___282 lock;
	const struct seq_operations___205 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_table_header___85;

struct ctl_node___85 {
	struct rb_node node;
	struct ctl_table_header___85 *header;
};

struct ctl_table_root___85;

struct ctl_table_set___85;

struct ctl_dir___85;

struct ctl_table_header___85 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___85 *root;
	struct ctl_table_set___85 *set;
	struct ctl_dir___85 *parent;
	struct ctl_node___85 *node;
};

struct ctl_dir___85 {
	struct ctl_table_header___85 header;
	struct rb_root root;
};

struct ctl_table_set___85 {
	int (*is_seen)(struct ctl_table_set___85 *);
	struct ctl_dir___85 dir;
};

struct ctl_table_root___85 {
	struct ctl_table_set___85 default_set;
	struct ctl_table_set___85 * (*lookup)(struct ctl_table_root___85 *, struct nsproxy___160 *);
	int (*permissions)(struct ctl_table_header___85 *, struct ctl_table *);
};

struct nsproxy___160 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___84 *net_ns;
};

struct signal_struct___281 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___281 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___281 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___282 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___175 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___175 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___59 {
	wait_queue_head_t wait;
	struct fasync_struct___280 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___59;

struct socket___60 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___59 *wq;
	struct file___280 *file;
	struct sock___59 *sk;
	const struct proto_ops___59 *ops;
};

struct proto_ops___59 {
	int family;
	struct module *owner;
	int (*release)(struct socket___60 *);
	int (*bind)(struct socket___60 *, struct sockaddr *, int);
	int (*connect)(struct socket___60 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___60 *, struct socket___60 *);
	int (*accept)(struct socket___60 *, struct socket___60 *, int);
	int (*getname)(struct socket___60 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___280 *, struct socket___60 *, struct poll_table_struct___166 *);
	int (*ioctl)(struct socket___60 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___60 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___60 *, int);
	int (*shutdown)(struct socket___60 *, int);
	int (*setsockopt)(struct socket___60 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___60 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___60 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___60 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___67 *, struct socket___60 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___67 *, struct socket___60 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___280 *, struct socket___60 *, struct vm_area_struct___288 *);
	ssize_t (*sendpage)(struct socket___60 *, struct page___279 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___60 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___59 *, int);
		struct {
			void (*set_peek_off)(struct sock___59 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___82 {
	struct ctl_table_header___85 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___83 {
	struct mutex___282 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___82 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___85 *ctl;
};

struct netns_ipv4___82 {
	struct ctl_table_header___85 *forw_hdr;
	struct ctl_table_header___85 *frags_hdr;
	struct ctl_table_header___85 *ipv4_hdr;
	struct ctl_table_header___85 *route_hdr;
	struct ctl_table_header___85 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___59 *fibnl;
	struct sock___59 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___82 {
	struct ctl_table_header___85 *hdr;
	struct ctl_table_header___85 *route_hdr;
	struct ctl_table_header___85 *icmp_hdr;
	struct ctl_table_header___85 *frags_hdr;
	struct ctl_table_header___85 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___70;

struct neighbour___60;

struct dst_ops___84 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___84 *);
	struct dst_entry___60 * (*check)(struct dst_entry___60 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___60 *);
	unsigned int (*mtu)(const struct dst_entry___60 *);
	u32 * (*cow_metrics)(struct dst_entry___60 *, long unsigned int);
	void (*destroy)(struct dst_entry___60 *);
	void (*ifdown)(struct dst_entry___60 *, struct net_device___70 *, int);
	struct dst_entry___60 * (*negative_advice)(struct dst_entry___60 *);
	void (*link_failure)(struct sk_buff___72 *);
	void (*update_pmtu)(struct dst_entry___60 *, struct sock___59 *, struct sk_buff___72 *, u32);
	void (*redirect)(struct dst_entry___60 *, struct sock___59 *, struct sk_buff___72 *);
	int (*local_out)(struct sk_buff___72 *);
	struct neighbour___60 * (*neigh_lookup)(const struct dst_entry___60 *, struct sk_buff___72 *, const void *);
	struct kmem_cache___263 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___84 {
	struct netns_sysctl_ipv6___82 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___84 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___59 **icmp_sk;
	struct sock___59 *ndisc_sk;
	struct sock___59 *tcp_sk;
	struct sock___59 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___82 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___85 *sysctl_header;
	struct sock___59 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___59 {
	struct sock___59 *v4_ctl_sk;
	struct sock___59 *v6_ctl_sk;
};

struct netns_nf___82 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___85 *nf_log_dir_header;
};

struct nf_proto_net___82 {
	struct ctl_table_header___85 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___82 {
	struct nf_proto_net___82 pn;
	unsigned int timeout;
};

struct nf_tcp_net___82 {
	struct nf_proto_net___82 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___82 {
	struct nf_proto_net___82 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___82 {
	struct nf_proto_net___82 pn;
	unsigned int timeout;
};

struct nf_ip_net___82 {
	struct nf_generic_net___82 generic;
	struct nf_tcp_net___82 tcp;
	struct nf_udp_net___82 udp;
	struct nf_icmp_net___82 icmp;
	struct nf_icmp_net___82 icmpv6;
};

struct netns_ct___83 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___85 *sysctl_header;
	struct ctl_table_header___85 *acct_sysctl_header;
	struct ctl_table_header___85 *tstamp_sysctl_header;
	struct ctl_table_header___85 *event_sysctl_header;
	struct ctl_table_header___85 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___263 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___82 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___82 {
	struct netns_sysctl_ipv6___82 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___84 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___59 *nlsk;
	struct sock___59 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___85 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___84 xfrm4_dst_ops;
	struct dst_ops___84 xfrm6_dst_ops;
};

struct net___84 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___85 sysctls;
	struct sock___59 *rtnl;
	struct sock___59 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___70 *loopback_dev;
	struct netns_core___82 core;
	struct netns_mib mib;
	struct netns_packet___83 packet;
	struct netns_unix___82 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___82 ipv4;
	struct netns_ipv6___84 ipv6;
	struct netns_sctp___82 sctp;
	struct netns_dccp___59 dccp;
	struct netns_nf___82 nf;
	struct netns_xt xt;
	struct netns_ct___83 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___82 nf_frag;
	struct sock___59 *nfnl;
	struct sock___59 *nfnl_stash;
	struct sk_buff_head___71 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___84 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___59 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___59 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___282 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___282 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___262 {
	void **freelist;
	long unsigned int tid;
	struct page___279 *page;
	struct page___279 *partial;
};

struct memcg_cache_params___263 {
	bool is_root_cache;
	union {
		struct kmem_cache___263 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___263 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___70 {
	atomic_t use;
	unsigned int mask;
	struct net_device___70 *physindev;
	struct net_device___70 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___70(struct sk_buff___72 **);

struct net_device_ops___70;

struct ethtool_ops___70;

struct header_ops___70;

struct inet6_dev___36;

struct netdev_rx_queue___70;

struct netdev_queue___70;

struct rtnl_link_ops___61;

struct dcbnl_rtnl_ops___70;

struct net_device___70 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___70 *netdev_ops;
	const struct ethtool_ops___70 *ethtool_ops;
	const struct header_ops___70 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___62 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___36 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___70 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___70 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___70 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___70 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___70 = 0,
		NETREG_REGISTERED___70 = 1,
		NETREG_UNREGISTERING___70 = 2,
		NETREG_UNREGISTERED___70 = 3,
		NETREG_RELEASED___70 = 4,
		NETREG_DUMMY___70 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___70 = 0,
		RTNL_LINK_INITIALIZING___70 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___70 *);
	struct netpoll_info *npinfo;
	struct net___84 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___278 dev;
	const struct attribute_group___240 *sysfs_groups[4];
	const struct rtnl_link_ops___61 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___70 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___72 {
	struct sk_buff___72 *next;
	struct sk_buff___72 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___59 *sk;
	struct net_device___70 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___72 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___70 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___70 {
	int (*get_settings)(struct net_device___70 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___70 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___70 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___70 *);
	void (*get_regs)(struct net_device___70 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___70 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___70 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___70 *);
	void (*set_msglevel)(struct net_device___70 *, u32);
	int (*nway_reset)(struct net_device___70 *);
	u32 (*get_link)(struct net_device___70 *);
	int (*get_eeprom_len)(struct net_device___70 *);
	int (*get_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___70 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___70 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___70 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___70 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___70 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___70 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___70 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___70 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___70 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___70 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___70 *);
	void (*complete)(struct net_device___70 *);
	u32 (*get_priv_flags)(struct net_device___70 *);
	int (*set_priv_flags)(struct net_device___70 *, u32);
	int (*get_sset_count)(struct net_device___70 *, int);
	int (*get_rxnfc)(struct net_device___70 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___70 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___70 *, struct ethtool_flash *);
	int (*reset)(struct net_device___70 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___70 *);
	int (*get_rxfh_indir)(struct net_device___70 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___70 *, const u32 *);
	void (*get_channels)(struct net_device___70 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___70 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___70 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___70 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___70 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___70 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___70 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___70 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___70 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___70 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___70 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___70 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___31;

struct dst_entry___60 {
	struct callback_head callback_head;
	struct dst_entry___60 *child;
	struct net_device___70 *dev;
	struct dst_ops___84 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___60 *path;
	struct dst_entry___60 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___72 *);
	union {
		int (*output)(struct sock___59 *, struct sk_buff___72 *);
		struct {
			int (*output)(struct sk_buff___72 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___60 *next;
		struct rtable___31 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___60;

struct neigh_parms___60;

struct neigh_ops___60;

struct neighbour___60 {
	struct neighbour___60 *next;
	struct neigh_table___60 *tbl;
	struct neigh_parms___60 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___71 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___60 *, struct sk_buff___72 *);
	const struct neigh_ops___60 *ops;
	struct callback_head rcu;
	struct net_device___70 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___84 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___72 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___72 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___84 *, struct dst_entry___60 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___72 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___72 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___204 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___204 *);
	void (*irq_shutdown)(struct irq_data___204 *);
	void (*irq_enable)(struct irq_data___204 *);
	void (*irq_disable)(struct irq_data___204 *);
	void (*irq_ack)(struct irq_data___204 *);
	void (*irq_mask)(struct irq_data___204 *);
	void (*irq_mask_ack)(struct irq_data___204 *);
	void (*irq_unmask)(struct irq_data___204 *);
	void (*irq_eoi)(struct irq_data___204 *);
	int (*irq_set_affinity)(struct irq_data___204 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___204 *);
	int (*irq_set_type)(struct irq_data___204 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___204 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___204 *);
	void (*irq_bus_sync_unlock)(struct irq_data___204 *);
	void (*irq_cpu_online)(struct irq_data___204 *);
	void (*irq_cpu_offline)(struct irq_data___204 *);
	void (*irq_suspend)(struct irq_data___204 *);
	void (*irq_resume)(struct irq_data___204 *);
	void (*irq_pm_shutdown)(struct irq_data___204 *);
	void (*irq_print_chip)(struct irq_data___204 *, struct seq_file___205 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___204 *, void *);
	long unsigned int flags;
};

struct seq_operations___205 {
	void * (*start)(struct seq_file___205 *, loff_t *);
	void (*stop)(struct seq_file___205 *, void *);
	void * (*next)(struct seq_file___205 *, void *, loff_t *);
	int (*show)(struct seq_file___205 *, void *);
};

struct pernet_operations___19 {
	struct list_head list;
	int (*init)(struct net___84 *);
	void (*exit)(struct net___84 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___70 {
	int (*ieee_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___70 *);
	u8 (*setstate)(struct net_device___70 *, u8);
	void (*getpermhwaddr)(struct net_device___70 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___70 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___70 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___70 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___70 *, int, u8 *);
	void (*setpfccfg)(struct net_device___70 *, int, u8);
	void (*getpfccfg)(struct net_device___70 *, int, u8 *);
	u8 (*setall)(struct net_device___70 *);
	u8 (*getcap)(struct net_device___70 *, int, u8 *);
	int (*getnumtcs)(struct net_device___70 *, int, u8 *);
	int (*setnumtcs)(struct net_device___70 *, int, u8);
	u8 (*getpfcstate)(struct net_device___70 *);
	void (*setpfcstate)(struct net_device___70 *, u8);
	void (*getbcncfg)(struct net_device___70 *, int, u32 *);
	void (*setbcncfg)(struct net_device___70 *, int, u32);
	void (*getbcnrp)(struct net_device___70 *, int, u8 *);
	void (*setbcnrp)(struct net_device___70 *, int, u8);
	u8 (*setapp)(struct net_device___70 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___70 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___70 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___70 *, int, u8);
	u8 (*getdcbx)(struct net_device___70 *);
	u8 (*setdcbx)(struct net_device___70 *, u8);
	int (*peer_getappinfo)(struct net_device___70 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___70 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___70 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___70 *, struct cee_pfc *);
};

struct cgroupfs_root___175;

struct cgroup___175 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___175 *parent;
	struct dentry___280 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___175 *subsys[11];
	struct cgroupfs_root___175 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___282 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___175 {
	struct super_block___280 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___175 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___111 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___280 *, struct file___280 *);
	ssize_t (*read)(struct cgroup___175 *, struct cftype___111 *, struct file___280 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___175 *, struct cftype___111 *);
	s64 (*read_s64)(struct cgroup___175 *, struct cftype___111 *);
	int (*read_map)(struct cgroup___175 *, struct cftype___111 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___175 *, struct cftype___111 *, struct seq_file___205 *);
	ssize_t (*write)(struct cgroup___175 *, struct cftype___111 *, struct file___280 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___175 *, struct cftype___111 *, u64);
	int (*write_s64)(struct cgroup___175 *, struct cftype___111 *, s64);
	int (*write_string)(struct cgroup___175 *, struct cftype___111 *, const char *);
	int (*trigger)(struct cgroup___175 *, unsigned int);
	int (*release)(struct inode___280 *, struct file___280 *);
	int (*register_event)(struct cgroup___175 *, struct cftype___111 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___175 *, struct cftype___111 *, struct eventfd_ctx *);
};

struct cftype_set___107 {
	struct list_head node;
	struct cftype___111 *cfts;
};

struct task_and_cgroup___107 {
	struct task_struct___281 *task;
	struct cgroup___175 *cgrp;
	struct css_set___175 *cg;
};

struct cgroup_taskset___107 {
	struct task_and_cgroup___107 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___175 *cur_cgrp;
};

struct cgroup_subsys___107 {
	struct cgroup_subsys_state___175 * (*css_alloc)(struct cgroup___175 *);
	int (*css_online)(struct cgroup___175 *);
	void (*css_offline)(struct cgroup___175 *);
	void (*css_free)(struct cgroup___175 *);
	int (*can_attach)(struct cgroup___175 *, struct cgroup_taskset___107 *);
	void (*cancel_attach)(struct cgroup___175 *, struct cgroup_taskset___107 *);
	void (*attach)(struct cgroup___175 *, struct cgroup_taskset___107 *);
	void (*fork)(struct task_struct___281 *);
	void (*exit)(struct cgroup___175 *, struct cgroup___175 *, struct task_struct___281 *);
	void (*bind)(struct cgroup___175 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___175 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___111 *base_cftypes;
	struct cftype_set___107 base_cftset;
	struct module *module;
};

struct request_sock_ops___45;

struct request_sock___46 {
	struct sock_common___59 __req_common;
	struct request_sock___46 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___45 *rsk_ops;
	struct sock___59 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___72 {
	struct sk_buff___72 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___72 *, struct netlink_callback___72 *);
	int (*done)(struct netlink_callback___72 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___70 {
	int (*create)(struct sk_buff___72 *, struct net_device___70 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___72 *, unsigned char *);
	int (*rebuild)(struct sk_buff___72 *);
	int (*cache)(const struct neighbour___60 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___70 *, const unsigned char *);
};

struct napi_struct___70 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___70 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___70 *dev;
	struct sk_buff___72 *gro_list;
	struct sk_buff___72 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___70 {
	struct net_device___70 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___62 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___70 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___62 kobj;
	struct net_device___70 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___70 {
	int (*ndo_init)(struct net_device___70 *);
	void (*ndo_uninit)(struct net_device___70 *);
	int (*ndo_open)(struct net_device___70 *);
	int (*ndo_stop)(struct net_device___70 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___72 *, struct net_device___70 *);
	u16 (*ndo_select_queue)(struct net_device___70 *, struct sk_buff___72 *);
	void (*ndo_change_rx_flags)(struct net_device___70 *, int);
	void (*ndo_set_rx_mode)(struct net_device___70 *);
	int (*ndo_set_mac_address)(struct net_device___70 *, void *);
	int (*ndo_validate_addr)(struct net_device___70 *);
	int (*ndo_do_ioctl)(struct net_device___70 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___70 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___70 *, int);
	int (*ndo_neigh_setup)(struct net_device___70 *, struct neigh_parms___60 *);
	void (*ndo_tx_timeout)(struct net_device___70 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___70 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___70 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___70 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___70 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___70 *);
	int (*ndo_netpoll_setup)(struct net_device___70 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___70 *);
	int (*ndo_busy_poll)(struct napi_struct___70 *);
	int (*ndo_set_vf_mac)(struct net_device___70 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___70 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___70 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___70 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___70 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___70 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___70 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___70 *, int, struct sk_buff___72 *);
	int (*ndo_setup_tc)(struct net_device___70 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___70 *);
	int (*ndo_fcoe_disable)(struct net_device___70 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___70 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___70 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___70 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___70 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___70 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___70 *, const struct sk_buff___72 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___70 *, struct net_device___70 *);
	int (*ndo_del_slave)(struct net_device___70 *, struct net_device___70 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___60 *);
	void (*ndo_neigh_destroy)(struct neighbour___60 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___72 *, struct netlink_callback___72 *, struct net_device___70 *, int);
	int (*ndo_bridge_setlink)(struct net_device___70 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___72 *, u32, u32, struct net_device___70 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___70 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___70 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___70 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___70 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___70 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___70 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___72 *, struct net_device___70 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___70 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___70 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___70 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___60 {
	struct net___84 *net;
	struct net_device___70 *dev;
	struct neigh_parms___60 *next;
	int (*neigh_setup)(struct neighbour___60 *);
	void (*neigh_cleanup)(struct neighbour___60 *);
	struct neigh_table___60 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___36;

struct ifacaddr6___36;

struct inet6_dev___36 {
	struct net_device___70 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___36 *mc_list;
	struct ifmcaddr6___36 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___36 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___60 *nd_parms;
	struct inet6_dev___36 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___61 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___70 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___84 *, struct net_device___70 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___70 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___70 *, struct list_head *);
	size_t (*get_size)(const struct net_device___70 *);
	int (*fill_info)(struct sk_buff___72 *, const struct net_device___70 *);
	size_t (*get_xstats_size)(const struct net_device___70 *);
	int (*fill_xstats)(struct sk_buff___72 *, const struct net_device___70 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___84 * (*get_link_net)(const struct net_device___70 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___70 *, struct net_device___70 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___70 *, const struct net_device___70 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___72 *, const struct net_device___70 *, const struct net_device___70 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___60 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___72 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___60;

struct neigh_hash_table___60;

struct neigh_table___60 {
	struct neigh_table___60 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___70 *, __u32 *);
	int (*constructor)(struct neighbour___60 *);
	int (*pconstructor)(struct pneigh_entry___60 *);
	void (*pdestructor)(struct pneigh_entry___60 *);
	void (*proxy_redo)(struct sk_buff___72 *);
	char *id;
	struct neigh_parms___60 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___71 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___60 *nht;
	struct pneigh_entry___60 **phash_buckets;
};

struct neigh_ops___60 {
	int family;
	void (*solicit)(struct neighbour___60 *, struct sk_buff___72 *);
	void (*error_report)(struct neighbour___60 *, struct sk_buff___72 *);
	int (*output)(struct neighbour___60 *, struct sk_buff___72 *);
	int (*connected_output)(struct neighbour___60 *, struct sk_buff___72 *);
};

struct pneigh_entry___60 {
	struct pneigh_entry___60 *next;
	struct net___84 *net;
	struct net_device___70 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___60 {
	struct neighbour___60 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___31 {
	struct dst_entry___60 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___42;

struct proto___59 {
	void (*close)(struct sock___59 *, long int);
	int (*connect)(struct sock___59 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___59 *, int);
	struct sock___59 * (*accept)(struct sock___59 *, int, int *);
	int (*ioctl)(struct sock___59 *, int, long unsigned int);
	int (*init)(struct sock___59 *);
	void (*destroy)(struct sock___59 *);
	void (*shutdown)(struct sock___59 *, int);
	int (*setsockopt)(struct sock___59 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___59 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___59 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___59 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___59 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___67 *, struct sock___59 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___67 *, struct sock___59 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___59 *, struct page___279 *, int, size_t, int);
	int (*bind)(struct sock___59 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___59 *, struct sk_buff___72 *);
	void (*release_cb)(struct sock___59 *);
	void (*mtu_reduced)(struct sock___59 *);
	void (*hash)(struct sock___59 *);
	void (*unhash)(struct sock___59 *);
	void (*rehash)(struct sock___59 *);
	int (*get_port)(struct sock___59 *, short unsigned int);
	void (*clear_sk)(struct sock___59 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___59 *);
	void (*enter_memory_pressure)(struct sock___59 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___263 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___45 *rsk_prot;
	struct timewait_sock_ops___42 *twsk_prot;
	union {
		struct inet_hashinfo___13 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___107 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___59 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___59 {
	void (*enter_memory_pressure)(struct sock___59 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___45 {
	int family;
	int obj_size;
	struct kmem_cache___263 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___59 *, struct request_sock___46 *);
	void (*send_ack)(struct sock___59 *, struct sk_buff___72 *, struct request_sock___46 *);
	void (*send_reset)(struct sock___59 *, struct sk_buff___72 *);
	void (*destructor)(struct request_sock___46 *);
	void (*syn_ack_timeout)(struct sock___59 *, struct request_sock___46 *);
};

struct timewait_sock_ops___42 {
	struct kmem_cache___263 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___59 *, struct sock___59 *, void *);
	void (*twsk_destructor)(struct sock___59 *);
};

struct inet_cork___18 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___60 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___18 {
	struct inet_cork___18 base;
	struct flowi fl;
};

struct ipv6_pinfo___17;

struct inet_sock___18 {
	struct sock___59 sk;
	struct ipv6_pinfo___17 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___18 cork;
};

struct ipv6_fl_socklist___16;

struct ipv6_pinfo___17 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___16 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___72 *pktoptions;
	struct sk_buff___72 *rxpmtu;
	struct inet6_cork cork;
};

struct udp_sock___2 {
	struct inet_sock___18 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___59 *, struct sk_buff___72 *);
	void (*encap_destroy)(struct sock___59 *);
};

struct ip6_flowlabel___16;

struct ipv6_fl_socklist___16 {
	struct ipv6_fl_socklist___16 *next;
	struct ip6_flowlabel___16 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___36 {
	struct in6_addr mca_addr;
	struct inet6_dev___36 *idev;
	struct ifmcaddr6___36 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___36 {
	struct in6_addr aca_addr;
	struct inet6_dev___36 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___36 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___16 {
	struct ip6_flowlabel___16 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___84 *fl_net;
};

struct udp_seq_afinfo___2 {
	char *name;
	sa_family_t family;
	struct udp_table *udp_table;
	const struct file_operations___280 *seq_fops;
	struct seq_operations___205 seq_ops;
};

struct net_protocol___3 {
	void (*early_demux)(struct sk_buff___72 *);
	int (*handler)(struct sk_buff___72 *);
	void (*err_handler)(struct sk_buff___72 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct inet_protosw {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___59 *prot;
	const struct proto_ops___59 *ops;
	unsigned char flags;
};

struct udp_offload;

struct udp_offload_callbacks {
	struct sk_buff___69 ** (*gro_receive)(struct sk_buff___69 **, struct sk_buff___69 *, struct udp_offload *);
	int (*gro_complete)(struct sk_buff___69 *, int, struct udp_offload *);
};

struct udp_offload {
	__be16 port;
	u8 ipproto;
	struct udp_offload_callbacks callbacks;
};

struct udp_offload_priv {
	struct udp_offload *offload;
	struct callback_head rcu;
	struct udp_offload_priv *next;
};

struct nf_hook_state___10 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___57 *in;
	struct net_device___57 *out;
	struct sock___47 *sk;
	int (*okfn)(struct sock___47 *, struct sk_buff___60 *);
};

struct seq_net_private___10 {
	struct net___71 *net;
};

struct packet_type___4 {
	__be16 type;
	struct net_device___57 *dev;
	int (*func)(struct sk_buff___60 *, struct net_device___57 *, struct packet_type___4 *, struct net_device___57 *);
	bool (*id_match)(struct packet_type___4 *, struct sock___47 *);
	void *af_packet_priv;
	struct list_head list;
};

struct arpreq {
	struct sockaddr arp_pa;
	struct sockaddr arp_ha;
	int arp_flags;
	struct sockaddr arp_netmask;
	char arp_dev[16];
};

struct arphdr {
	__be16 ar_hrd;
	__be16 ar_pro;
	unsigned char ar_hln;
	unsigned char ar_pln;
	__be16 ar_op;
};

struct neigh_seq_state___2 {
	struct seq_net_private___10 p;
	struct neigh_table___47 *tbl;
	struct neigh_hash_table___47 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state___2 *, struct neighbour___47 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

enum {
	AX25_VALUES_IPDEFMODE = 0,
	AX25_VALUES_AXDEFMODE = 1,
	AX25_VALUES_BACKOFF = 2,
	AX25_VALUES_CONMODE = 3,
	AX25_VALUES_WINDOW = 4,
	AX25_VALUES_EWINDOW = 5,
	AX25_VALUES_T1 = 6,
	AX25_VALUES_T2 = 7,
	AX25_VALUES_T3 = 8,
	AX25_VALUES_IDLE = 9,
	AX25_VALUES_N2 = 10,
	AX25_VALUES_PACLEN = 11,
	AX25_VALUES_PROTOCOL = 12,
	AX25_VALUES_DS_TIMEOUT = 13,
	AX25_MAX_VALUES = 14,
};

struct page___280;

typedef struct page___280 *pgtable_t___280;

struct address_space___281;

struct kmem_cache___264;

struct page___280 {
	long unsigned int flags;
	struct address_space___281 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___280 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___280 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___264 *slab_cache;
		struct page___280 *first_page;
	};
	long: 64;
};

struct task_struct___282;

struct pv_cpu_ops___282 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___282 *);
	void (*end_context_switch)(struct task_struct___282 *);
};

struct mutex___283 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___282 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___275 {
	struct page___280 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___289;

struct nsproxy___161;

struct signal_struct___282;

struct css_set___176;

struct task_struct___282 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___282 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___289 *mm;
	struct mm_struct___289 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___282 *real_parent;
	struct task_struct___282 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___282 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___282 = 0,
		VTIME_USER___282 = 1,
		VTIME_SYS___282 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___161 *nsproxy;
	struct signal_struct___282 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___176 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___283 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___275 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___289 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___289 *, struct mm_struct___289 *);
	void (*dup_mmap)(struct mm_struct___289 *, struct mm_struct___289 *);
	void (*exit_mmap)(struct mm_struct___289 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___289 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___289 *);
	void (*pgd_free)(struct mm_struct___289 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___289 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___289 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___289 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___289 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___289 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___289 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___289 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___289 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___289 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___289 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___289 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___283 lock;
	void *vdso;
} mm_context_t___283;

struct xol_area___280;

struct uprobes_state___280 {
	struct xol_area___280 *xol_area;
};

struct vm_area_struct___289;

struct file___281;

struct core_state___282;

struct mm_struct___289 {
	struct vm_area_struct___289 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___289 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___289 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___283 context;
	long unsigned int flags;
	struct core_state___282 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___282 *owner;
	struct file___281 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___280 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___63;

struct kobj_type___63;

struct kobject___63 {
	const char *name;
	struct list_head entry;
	struct kobject___63 *parent;
	struct kset___63 *kset;
	struct kobj_type___63 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___175;

struct module_kobject___175 {
	struct kobject___63 kobj;
	struct module___175 *mod;
	struct kobject___63 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___175;

struct module___175 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___175 mkobj;
	struct module_attribute___175 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___63 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___282 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___282;

struct lruvec___282 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___282 *zone;
};

struct pglist_data___282;

struct zone___282 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___282 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___282 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___282 {
	struct zone___282 *zone;
	int zone_idx;
};

struct zonelist___282 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___282 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___282 {
	struct zone___282 node_zones[4];
	struct zonelist___282 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___282 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___205;

struct x86_io_apic_ops___205 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___205 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___205;

struct irq_data___205 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___205 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___279;

struct dev_pm_ops___279 {
	int (*prepare)(struct device___279 *);
	void (*complete)(struct device___279 *);
	int (*suspend)(struct device___279 *);
	int (*resume)(struct device___279 *);
	int (*freeze)(struct device___279 *);
	int (*thaw)(struct device___279 *);
	int (*poweroff)(struct device___279 *);
	int (*restore)(struct device___279 *);
	int (*suspend_late)(struct device___279 *);
	int (*resume_early)(struct device___279 *);
	int (*freeze_late)(struct device___279 *);
	int (*thaw_early)(struct device___279 *);
	int (*poweroff_late)(struct device___279 *);
	int (*restore_early)(struct device___279 *);
	int (*suspend_noirq)(struct device___279 *);
	int (*resume_noirq)(struct device___279 *);
	int (*freeze_noirq)(struct device___279 *);
	int (*thaw_noirq)(struct device___279 *);
	int (*poweroff_noirq)(struct device___279 *);
	int (*restore_noirq)(struct device___279 *);
	int (*runtime_suspend)(struct device___279 *);
	int (*runtime_resume)(struct device___279 *);
	int (*runtime_idle)(struct device___279 *);
};

struct dev_pm_qos___82;

struct dev_pm_info___82 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___82 *qos;
};

struct dma_map_ops___144;

struct dev_archdata___144 {
	struct dma_map_ops___144 *dma_ops;
	void *iommu;
};

struct device_type___279;

struct bus_type___279;

struct device_driver___279;

struct dev_pm_domain___279;

struct class___279;

struct attribute_group___241;

struct device_rh___279;

struct device___279 {
	struct device___279 *parent;
	struct device_private *p;
	struct kobject___63 kobj;
	const char *init_name;
	const struct device_type___279 *type;
	struct mutex___283 mutex;
	struct bus_type___279 *bus;
	struct device_driver___279 *driver;
	void *platform_data;
	struct dev_pm_info___82 power;
	struct dev_pm_domain___279 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___144 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___279 *class;
	const struct attribute_group___241 **groups;
	void (*release)(struct device___279 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___279 *device_rh;
};

struct dev_pm_qos_request___83;

struct dev_pm_qos___82 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___83 *latency_req;
	struct dev_pm_qos_request___83 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___83 *latency_tolerance_req;
};

struct dev_pm_info_rh___279 {
	void (*set_latency_tolerance)(struct device___279 *, s32);
};

struct dev_pm_domain___279 {
	struct dev_pm_ops___279 ops;
};

struct smp_ops___282 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___282 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___86;

struct ctl_node___86 {
	struct rb_node node;
	struct ctl_table_header___86 *header;
};

struct ctl_table_root___86;

struct ctl_table_set___86;

struct ctl_dir___86;

struct ctl_table_header___86 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___86 *root;
	struct ctl_table_set___86 *set;
	struct ctl_dir___86 *parent;
	struct ctl_node___86 *node;
};

struct ctl_dir___86 {
	struct ctl_table_header___86 header;
	struct rb_root root;
};

struct ctl_table_set___86 {
	int (*is_seen)(struct ctl_table_set___86 *);
	struct ctl_dir___86 dir;
};

struct ctl_table_root___86 {
	struct ctl_table_set___86 default_set;
	struct ctl_table_set___86 * (*lookup)(struct ctl_table_root___86 *, struct nsproxy___161 *);
	int (*permissions)(struct ctl_table_header___86 *, struct ctl_table *);
};

struct net___85;

struct nsproxy___161 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___85 *net_ns;
};

struct sock___60;

struct kobj_ns_type_operations___60 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___60 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___60;

struct sock_common___60 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___60 *skc_prot;
	struct net___85 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___73;

struct sk_buff_head___72 {
	struct sk_buff___73 *next;
	struct sk_buff___73 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___61;

struct socket_wq___60;

struct xfrm_policy___15;

struct dst_entry___61;

struct socket___61;

struct cg_proto___60;

struct sock___60 {
	struct sock_common___60 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___72 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___73 *head;
		struct sk_buff___73 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___61 *sk_filter;
	struct socket_wq___60 *sk_wq;
	struct sk_buff_head___72 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___15 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___61 *sk_rx_dst;
	struct dst_entry___61 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___72 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___72 sk_error_queue;
	struct proto___60 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___61 *sk_socket;
	void *sk_user_data;
	struct page_frag___275 sk_frag;
	struct sk_buff___73 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___60 *sk_cgrp;
	void (*sk_state_change)(struct sock___60 *);
	void (*sk_data_ready)(struct sock___60 *, int);
	void (*sk_write_space)(struct sock___60 *);
	void (*sk_error_report)(struct sock___60 *);
	int (*sk_backlog_rcv)(struct sock___60 *, struct sk_buff___73 *);
	void (*sk_destruct)(struct sock___60 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___243;

struct attribute_group___241 {
	const char *name;
	umode_t (*is_visible)(struct kobject___63 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___243 **bin_attrs;
};

struct bin_attribute___243 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___281 *, struct kobject___63 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___281 *, struct kobject___63 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	int (*mmap)(struct file___281 *, struct kobject___63 *, struct bin_attribute___243 *, struct vm_area_struct___289 *);
};

struct dentry___281;

struct path___281 {
	struct vfsmount *mnt;
	struct dentry___281 *dentry;
};

struct inode___281;

struct file_operations___281;

struct file___281 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___281 f_path;
	struct inode___281 *f_inode;
	const struct file_operations___281 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___281 *f_mapping;
	struct mutex___283 f_pos_lock;
};

struct vm_operations_struct___255;

struct vm_area_struct___289 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___289 *vm_next;
	struct vm_area_struct___289 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___289 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___255 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___281 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___63 {
	ssize_t (*show)(struct kobject___63 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___63 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___63 *, const struct attribute *);
};

struct kset_uevent_ops___63;

struct kset___63 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___63 kobj;
	const struct kset_uevent_ops___63 *uevent_ops;
};

struct kobj_type___63 {
	void (*release)(struct kobject___63 *);
	const struct sysfs_ops___63 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___60 * (*child_ns_type)(struct kobject___63 *);
	const void * (*namespace)(struct kobject___63 *);
};

struct kset_uevent_ops___63 {
	int (* const filter)(struct kset___63 *, struct kobject___63 *);
	const char * (* const name)(struct kset___63 *, struct kobject___63 *);
	int (* const uevent)(struct kset___63 *, struct kobject___63 *, struct kobj_uevent_env *);
};

struct module_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___175 *, struct module_kobject___175 *, char *);
	ssize_t (*store)(struct module_attribute___175 *, struct module_kobject___175 *, const char *, size_t);
	void (*setup)(struct module___175 *, const char *);
	int (*test)(struct module___175 *);
	void (*free)(struct module___175 *);
};

struct kiocb___68;

struct poll_table_struct___167;

struct file_lock___281;

struct seq_file___206;

struct file_operations___281 {
	struct module___175 *owner;
	loff_t (*llseek)(struct file___281 *, loff_t, int);
	ssize_t (*read)(struct file___281 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___281 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___68 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___68 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___281 *, void *, filldir_t);
	unsigned int (*poll)(struct file___281 *, struct poll_table_struct___167 *);
	long int (*unlocked_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___281 *, struct vm_area_struct___289 *);
	int (*open)(struct inode___281 *, struct file___281 *);
	int (*flush)(struct file___281 *, fl_owner_t);
	int (*release)(struct inode___281 *, struct file___281 *);
	int (*fsync)(struct file___281 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___68 *, int);
	int (*fasync)(int, struct file___281 *, int);
	int (*lock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*sendpage)(struct file___281 *, struct page___280 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___281 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___281 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___281 *, long int, struct file_lock___281 **, void **);
		struct {
			int (*setlease)(struct file___281 *, long int, struct file_lock___281 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___281 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___206 *, struct file___281 *);
};

struct dma_map_ops___144 {
	void * (*alloc)(struct device___279 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___279 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___279 *, struct vm_area_struct___289 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___279 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___279 *, struct page___280 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___279 *, dma_addr_t);
	int (*dma_supported)(struct device___279 *, u64);
	int (*set_dma_mask)(struct device___279 *, u64);
	int is_phys;
};

struct bus_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___279 *, char *);
	ssize_t (*store)(struct bus_type___279 *, const char *, size_t);
};

struct device_attribute___279;

struct driver_attribute___279;

struct bus_type___279 {
	const char *name;
	const char *dev_name;
	struct device___279 *dev_root;
	struct bus_attribute___279 *bus_attrs;
	struct device_attribute___279 *dev_attrs;
	struct driver_attribute___279 *drv_attrs;
	const struct attribute_group___241 **bus_groups;
	const struct attribute_group___241 **dev_groups;
	const struct attribute_group___241 **drv_groups;
	int (*match)(struct device___279 *, struct device_driver___279 *);
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	int (*probe)(struct device___279 *);
	int (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*online)(struct device___279 *);
	int (*offline)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct device___279 *, struct device_attribute___279 *, char *);
	ssize_t (*store)(struct device___279 *, struct device_attribute___279 *, const char *, size_t);
};

struct driver_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___279 *, char *);
	ssize_t (*store)(struct device_driver___279 *, const char *, size_t);
};

struct device_driver___279 {
	const char *name;
	struct bus_type___279 *bus;
	struct module___175 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___279 *);
	int (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	const struct attribute_group___241 **groups;
	const struct dev_pm_ops___279 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___279 {
	const char *name;
	const struct attribute_group___241 **groups;
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
};

struct class_attribute___279;

struct class___279 {
	const char *name;
	struct module___175 *owner;
	struct class_attribute___279 *class_attrs;
	struct device_attribute___279 *dev_attrs;
	const struct attribute_group___241 **dev_groups;
	struct bin_attribute___243 *dev_bin_attrs;
	struct kobject___63 *dev_kobj;
	int (*dev_uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *);
	void (*class_release)(struct class___279 *);
	void (*dev_release)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	const struct kobj_ns_type_operations___60 *ns_type;
	const void * (*namespace)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
	struct subsys_private *p;
};

struct class_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct class___279 *, struct class_attribute___279 *, char *);
	ssize_t (*store)(struct class___279 *, struct class_attribute___279 *, const char *, size_t);
	const void * (*namespace)(struct class___279 *, const struct class_attribute___279 *);
};

struct device_rh___279 {
	struct dev_pm_info_rh___279 power;
};

struct dev_pm_qos_request___83 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___279 *dev;
};

struct xol_area___280 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___280 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___263;

struct memcg_cache_params___264;

struct kmem_cache___264 {
	struct kmem_cache_cpu___263 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___63 kobj;
	struct memcg_cache_params___264 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___281;

struct address_space___281 {
	struct inode___281 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___283 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___281 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___251;

struct vm_operations_struct___255 {
	void (*open)(struct vm_area_struct___289 *);
	void (*close)(struct vm_area_struct___289 *);
	int (*fault)(struct vm_area_struct___289 *, struct vm_fault___251 *);
	int (*page_mkwrite)(struct vm_area_struct___289 *, struct vm_fault___251 *);
	int (*access)(struct vm_area_struct___289 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___289 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___289 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___289 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___289 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___282 {
	struct task_struct___282 *task;
	struct core_thread___282 *next;
};

struct core_state___282 {
	atomic_t nr_threads;
	struct core_thread___282 dumper;
	struct completion startup;
};

struct vm_fault___251 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___280 *page;
};

struct dentry_operations___281;

struct super_block___281;

struct dentry___281 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___281 *d_parent;
	struct qstr d_name;
	struct inode___281 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___281 *d_op;
	struct super_block___281 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___281;

struct dquot___281;

struct block_device___281;

struct inode___281 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___281 *i_op;
	struct super_block___281 *i_sb;
	struct address_space___281 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___283 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___281 *i_fop;
	struct file_lock___281 *i_flock;
	struct address_space___281 i_data;
	struct dquot___281 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___281 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___281 {
	int (*d_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_hash)(const struct dentry___281 *, struct qstr *);
	int (*d_compare)(const struct dentry___281 *, const struct dentry___281 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___281 *);
	void (*d_release)(struct dentry___281 *);
	void (*d_prune)(struct dentry___281 *);
	void (*d_iput)(struct dentry___281 *, struct inode___281 *);
	char * (*d_dname)(struct dentry___281 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___281 *);
	int (*d_manage)(struct dentry___281 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___281;

struct mem_dqinfo___281 {
	struct quota_format_type___281 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___281;

struct quota_info___281 {
	unsigned int flags;
	struct mutex___283 dqio_mutex;
	struct mutex___283 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___281 *files[2];
	struct mem_dqinfo___281 info[2];
	const struct quota_format_ops___281 *ops[2];
};

struct file_system_type___281;

struct super_operations___281;

struct dquot_operations___281;

struct quotactl_ops___281;

struct xattr_handler___177;

struct super_block___281 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___281 *s_type;
	const struct super_operations___281 *s_op;
	const struct dquot_operations___281 *dq_op;
	const struct quotactl_ops___281 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___281 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___177 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___281 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___281 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___283 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___281 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___281 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___281 *bd_inode;
	struct super_block___281 *bd_super;
	struct mutex___283 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___281 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___283 bd_fsfreeze_mutex;
};

struct cgroup___176;

struct cgroup_subsys_state___176 {
	struct cgroup___176 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___68(struct kiocb___68 *, struct io_event *);

struct kiocb___68 {
	atomic_t ki_users;
	struct file___281 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___68 *ki_cancel;
	void (*ki_dtor)(struct kiocb___68 *);
	union {
		void *user;
		struct task_struct___282 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___281 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___281 *ia_file;
};

struct dquot___281 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___283 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___281 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___281 {
	int qf_fmt_id;
	const struct quota_format_ops___281 *qf_ops;
	struct module___175 *qf_owner;
	struct quota_format_type___281 *qf_next;
};

struct quota_format_ops___281 {
	int (*check_quota_file)(struct super_block___281 *, int);
	int (*read_file_info)(struct super_block___281 *, int);
	int (*write_file_info)(struct super_block___281 *, int);
	int (*free_file_info)(struct super_block___281 *, int);
	int (*read_dqblk)(struct dquot___281 *);
	int (*commit_dqblk)(struct dquot___281 *);
	int (*release_dqblk)(struct dquot___281 *);
};

struct dquot_operations___281 {
	int (*write_dquot)(struct dquot___281 *);
	struct dquot___281 * (*alloc_dquot)(struct super_block___281 *, int);
	void (*destroy_dquot)(struct dquot___281 *);
	int (*acquire_dquot)(struct dquot___281 *);
	int (*release_dquot)(struct dquot___281 *);
	int (*mark_dirty)(struct dquot___281 *);
	int (*write_info)(struct super_block___281 *, int);
	qsize_t * (*get_reserved_space)(struct inode___281 *);
};

struct quotactl_ops___281 {
	int (*quota_on)(struct super_block___281 *, int, int, struct path___281 *);
	int (*quota_on_meta)(struct super_block___281 *, int, int);
	int (*quota_off)(struct super_block___281 *, int);
	int (*quota_sync)(struct super_block___281 *, int);
	int (*get_info)(struct super_block___281 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___281 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___281 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___281 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___281 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___281 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___281 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___281 *, unsigned int);
};

struct address_space_operations___281 {
	int (*writepage)(struct page___280 *, struct writeback_control *);
	int (*readpage)(struct file___281 *, struct page___280 *);
	int (*writepages)(struct address_space___281 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___280 *);
	int (*readpages)(struct file___281 *, struct address_space___281 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___281 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___280 **, void **);
	int (*write_end)(struct file___281 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___280 *, void *);
	sector_t (*bmap)(struct address_space___281 *, sector_t);
	void (*invalidatepage)(struct page___280 *, long unsigned int);
	int (*releasepage)(struct page___280 *, gfp_t);
	void (*freepage)(struct page___280 *);
	ssize_t (*direct_IO)(int, struct kiocb___68 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___281 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___281 *, struct page___280 *, struct page___280 *, enum migrate_mode);
	int (*launder_page)(struct page___280 *);
	int (*is_partially_uptodate)(struct page___280 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___280 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___281 *, struct page___280 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___281 *, sector_t *);
	void (*swap_deactivate)(struct file___281 *);
	void (*invalidatepage_range)(struct page___280 *, unsigned int, unsigned int);
};

struct inode_operations___281 {
	struct dentry___281 * (*lookup)(struct inode___281 *, struct dentry___281 *, unsigned int);
	void * (*follow_link)(struct dentry___281 *, struct nameidata *);
	int (*permission)(struct inode___281 *, int);
	struct posix_acl * (*get_acl)(struct inode___281 *, int);
	int (*readlink)(struct dentry___281 *, char *, int);
	void (*put_link)(struct dentry___281 *, struct nameidata *, void *);
	int (*create)(struct inode___281 *, struct dentry___281 *, umode_t, bool);
	int (*link)(struct dentry___281 *, struct inode___281 *, struct dentry___281 *);
	int (*unlink)(struct inode___281 *, struct dentry___281 *);
	int (*symlink)(struct inode___281 *, struct dentry___281 *, const char *);
	int (*mkdir)(struct inode___281 *, struct dentry___281 *, umode_t);
	int (*rmdir)(struct inode___281 *, struct dentry___281 *);
	int (*mknod)(struct inode___281 *, struct dentry___281 *, umode_t, dev_t);
	int (*rename)(struct inode___281 *, struct dentry___281 *, struct inode___281 *, struct dentry___281 *);
	int (*setattr)(struct dentry___281 *, struct iattr___281 *);
	int (*getattr)(struct vfsmount *, struct dentry___281 *, struct kstat *);
	int (*setxattr)(struct dentry___281 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___281 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___281 *, char *, size_t);
	int (*removexattr)(struct dentry___281 *, const char *);
	int (*fiemap)(struct inode___281 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___281 *, struct timespec *, int);
	int (*atomic_open)(struct inode___281 *, struct dentry___281 *, struct file___281 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___281;

struct file_lock_operations___281;

struct lock_manager_operations___281;

struct file_lock___281 {
	struct file_lock___281 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___281 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___281 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___281 *fl_ops;
	const struct lock_manager_operations___281 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___281 {
	void (*fl_copy_lock)(struct file_lock___281 *, struct file_lock___281 *);
	void (*fl_release_private)(struct file_lock___281 *);
};

struct lock_manager_operations___281 {
	int (*lm_compare_owner)(struct file_lock___281 *, struct file_lock___281 *);
	long unsigned int (*lm_owner_key)(struct file_lock___281 *);
	void (*lm_notify)(struct file_lock___281 *);
	int (*lm_grant)(struct file_lock___281 *, struct file_lock___281 *, int);
	void (*lm_break)(struct file_lock___281 *);
	int (*lm_change)(struct file_lock___281 **, int);
};

struct fasync_struct___281 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___281 *fa_next;
	struct file___281 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___281 {
	const char *name;
	int fs_flags;
	struct dentry___281 * (*mount)(struct file_system_type___281 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___281 *);
	struct module___175 *owner;
	struct file_system_type___281 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___281 {
	struct inode___281 * (*alloc_inode)(struct super_block___281 *);
	void (*destroy_inode)(struct inode___281 *);
	void (*dirty_inode)(struct inode___281 *, int);
	int (*write_inode)(struct inode___281 *, struct writeback_control *);
	int (*drop_inode)(struct inode___281 *);
	void (*evict_inode)(struct inode___281 *);
	void (*put_super)(struct super_block___281 *);
	int (*sync_fs)(struct super_block___281 *, int);
	int (*freeze_fs)(struct super_block___281 *);
	int (*unfreeze_fs)(struct super_block___281 *);
	int (*statfs)(struct dentry___281 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___281 *, int *, char *);
	void (*umount_begin)(struct super_block___281 *);
	int (*show_options)(struct seq_file___206 *, struct dentry___281 *);
	int (*show_devname)(struct seq_file___206 *, struct dentry___281 *);
	int (*show_path)(struct seq_file___206 *, struct dentry___281 *);
	int (*show_stats)(struct seq_file___206 *, struct dentry___281 *);
	ssize_t (*quota_read)(struct super_block___281 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___281 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___281 *);
	int (*bdev_try_to_free_page)(struct super_block___281 *, struct page___280 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___281 *);
	void (*free_cached_objects)(struct super_block___281 *, int);
};

struct xattr_handler___177 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___281 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___281 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___281 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___169)(struct file___281 *, wait_queue_head_t *, struct poll_table_struct___167 *);

struct poll_table_struct___167 {
	poll_queue_proc___169 _qproc;
	long unsigned int _key;
};

struct seq_operations___206;

struct seq_file___206 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___283 lock;
	const struct seq_operations___206 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___282 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___282 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___282 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___283 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___176 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___176 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___60 {
	wait_queue_head_t wait;
	struct fasync_struct___281 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___60;

struct socket___61 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___60 *wq;
	struct file___281 *file;
	struct sock___60 *sk;
	const struct proto_ops___60 *ops;
};

struct proto_ops___60 {
	int family;
	struct module___175 *owner;
	int (*release)(struct socket___61 *);
	int (*bind)(struct socket___61 *, struct sockaddr *, int);
	int (*connect)(struct socket___61 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___61 *, struct socket___61 *);
	int (*accept)(struct socket___61 *, struct socket___61 *, int);
	int (*getname)(struct socket___61 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___281 *, struct socket___61 *, struct poll_table_struct___167 *);
	int (*ioctl)(struct socket___61 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___61 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___61 *, int);
	int (*shutdown)(struct socket___61 *, int);
	int (*setsockopt)(struct socket___61 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___61 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___61 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___61 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___68 *, struct socket___61 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___68 *, struct socket___61 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___281 *, struct socket___61 *, struct vm_area_struct___289 *);
	ssize_t (*sendpage)(struct socket___61 *, struct page___280 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___61 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___60 *, int);
		struct {
			void (*set_peek_off)(struct sock___60 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___83 {
	struct ctl_table_header___86 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___84 {
	struct mutex___283 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___83 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___86 *ctl;
};

struct fib_rules_ops___5;

struct netns_ipv4___83 {
	struct ctl_table_header___86 *forw_hdr;
	struct ctl_table_header___86 *frags_hdr;
	struct ctl_table_header___86 *ipv4_hdr;
	struct ctl_table_header___86 *route_hdr;
	struct ctl_table_header___86 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___5 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___60 *fibnl;
	struct sock___60 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___5 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___83 {
	struct ctl_table_header___86 *hdr;
	struct ctl_table_header___86 *route_hdr;
	struct ctl_table_header___86 *icmp_hdr;
	struct ctl_table_header___86 *frags_hdr;
	struct ctl_table_header___86 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___71;

struct neighbour___61;

struct dst_ops___85 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___85 *);
	struct dst_entry___61 * (*check)(struct dst_entry___61 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___61 *);
	unsigned int (*mtu)(const struct dst_entry___61 *);
	u32 * (*cow_metrics)(struct dst_entry___61 *, long unsigned int);
	void (*destroy)(struct dst_entry___61 *);
	void (*ifdown)(struct dst_entry___61 *, struct net_device___71 *, int);
	struct dst_entry___61 * (*negative_advice)(struct dst_entry___61 *);
	void (*link_failure)(struct sk_buff___73 *);
	void (*update_pmtu)(struct dst_entry___61 *, struct sock___60 *, struct sk_buff___73 *, u32);
	void (*redirect)(struct dst_entry___61 *, struct sock___60 *, struct sk_buff___73 *);
	int (*local_out)(struct sk_buff___73 *);
	struct neighbour___61 * (*neigh_lookup)(const struct dst_entry___61 *, struct sk_buff___73 *, const void *);
	struct kmem_cache___264 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___15;

struct fib6_table___15;

struct netns_ipv6___85 {
	struct netns_sysctl_ipv6___83 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___15 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___15 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___85 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___15 *ip6_prohibit_entry;
	struct rt6_info___15 *ip6_blk_hole_entry;
	struct fib6_table___15 *fib6_local_tbl;
	struct fib_rules_ops___5 *fib6_rules_ops;
	struct sock___60 **icmp_sk;
	struct sock___60 *ndisc_sk;
	struct sock___60 *tcp_sk;
	struct sock___60 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___5 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___83 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___86 *sysctl_header;
	struct sock___60 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___60 {
	struct sock___60 *v4_ctl_sk;
	struct sock___60 *v6_ctl_sk;
};

struct netns_nf___83 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___86 *nf_log_dir_header;
};

struct nf_proto_net___83 {
	struct ctl_table_header___86 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___83 {
	struct nf_proto_net___83 pn;
	unsigned int timeout;
};

struct nf_tcp_net___83 {
	struct nf_proto_net___83 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___83 {
	struct nf_proto_net___83 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___83 {
	struct nf_proto_net___83 pn;
	unsigned int timeout;
};

struct nf_ip_net___83 {
	struct nf_generic_net___83 generic;
	struct nf_tcp_net___83 tcp;
	struct nf_udp_net___83 udp;
	struct nf_icmp_net___83 icmp;
	struct nf_icmp_net___83 icmpv6;
};

struct netns_ct___84 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___86 *sysctl_header;
	struct ctl_table_header___86 *acct_sysctl_header;
	struct ctl_table_header___86 *tstamp_sysctl_header;
	struct ctl_table_header___86 *event_sysctl_header;
	struct ctl_table_header___86 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___264 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___83 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___83 {
	struct netns_sysctl_ipv6___83 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___85 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___60 *nlsk;
	struct sock___60 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___86 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___85 xfrm4_dst_ops;
	struct dst_ops___85 xfrm6_dst_ops;
};

struct net___85 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___86 sysctls;
	struct sock___60 *rtnl;
	struct sock___60 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___71 *loopback_dev;
	struct netns_core___83 core;
	struct netns_mib mib;
	struct netns_packet___84 packet;
	struct netns_unix___83 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___83 ipv4;
	struct netns_ipv6___85 ipv6;
	struct netns_sctp___83 sctp;
	struct netns_dccp___60 dccp;
	struct netns_nf___83 nf;
	struct netns_xt xt;
	struct netns_ct___84 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___83 nf_frag;
	struct sock___60 *nfnl;
	struct sock___60 *nfnl_stash;
	struct sk_buff_head___72 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___85 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___60 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___60 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___283 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___283 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___263 {
	void **freelist;
	long unsigned int tid;
	struct page___280 *page;
	struct page___280 *partial;
};

struct memcg_cache_params___264 {
	bool is_root_cache;
	union {
		struct kmem_cache___264 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___264 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___71 {
	atomic_t use;
	unsigned int mask;
	struct net_device___71 *physindev;
	struct net_device___71 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___71(struct sk_buff___73 **);

struct net_device_ops___71;

struct ethtool_ops___71;

struct header_ops___71;

struct in_device___9;

struct inet6_dev___37;

struct netdev_rx_queue___71;

struct netdev_queue___71;

struct rtnl_link_ops___62;

struct dcbnl_rtnl_ops___71;

struct net_device___71 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___71 *netdev_ops;
	const struct ethtool_ops___71 *ethtool_ops;
	const struct header_ops___71 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___63 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___9 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___37 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___71 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___71 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___71 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___71 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___71 = 0,
		NETREG_REGISTERED___71 = 1,
		NETREG_UNREGISTERING___71 = 2,
		NETREG_UNREGISTERED___71 = 3,
		NETREG_RELEASED___71 = 4,
		NETREG_DUMMY___71 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___71 = 0,
		RTNL_LINK_INITIALIZING___71 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___71 *);
	struct netpoll_info *npinfo;
	struct net___85 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___279 dev;
	const struct attribute_group___241 *sysfs_groups[4];
	const struct rtnl_link_ops___62 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___71 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___15;

struct sk_buff___73 {
	struct sk_buff___73 *next;
	struct sk_buff___73 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___60 *sk;
	struct net_device___71 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___15 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___73 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___71 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___15;

struct sec_path___15 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___15 *xvec[6];
};

struct ethtool_ops___71 {
	int (*get_settings)(struct net_device___71 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___71 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___71 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___71 *);
	void (*get_regs)(struct net_device___71 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___71 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___71 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___71 *);
	void (*set_msglevel)(struct net_device___71 *, u32);
	int (*nway_reset)(struct net_device___71 *);
	u32 (*get_link)(struct net_device___71 *);
	int (*get_eeprom_len)(struct net_device___71 *);
	int (*get_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___71 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___71 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___71 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___71 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___71 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___71 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___71 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___71 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___71 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___71 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___71 *);
	void (*complete)(struct net_device___71 *);
	u32 (*get_priv_flags)(struct net_device___71 *);
	int (*set_priv_flags)(struct net_device___71 *, u32);
	int (*get_sset_count)(struct net_device___71 *, int);
	int (*get_rxnfc)(struct net_device___71 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___71 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___71 *, struct ethtool_flash *);
	int (*reset)(struct net_device___71 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___71 *);
	int (*get_rxfh_indir)(struct net_device___71 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___71 *, const u32 *);
	void (*get_channels)(struct net_device___71 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___71 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___71 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___71 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___71 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___71 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___71 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___71 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___71 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___71 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___71 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___71 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib_rule___5;

struct fib_lookup_arg___5;

struct fib_rules_ops___5 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___5 *, struct flowi *, int, struct fib_lookup_arg___5 *);
	int (*match)(struct fib_rule___5 *, struct flowi *, int);
	int (*configure)(struct fib_rule___5 *, struct sk_buff___73 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___5 *);
	int (*compare)(struct fib_rule___5 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___5 *, struct sk_buff___73 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___5 *);
	size_t (*nlmsg_payload)(struct fib_rule___5 *);
	void (*flush_cache)(struct fib_rules_ops___5 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___175 *owner;
	struct net___85 *fro_net;
	struct callback_head rcu;
};

struct rtable___32;

struct dst_entry___61 {
	struct callback_head callback_head;
	struct dst_entry___61 *child;
	struct net_device___71 *dev;
	struct dst_ops___85 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___61 *path;
	struct dst_entry___61 *from;
	struct xfrm_state___15 *xfrm;
	int (*input)(struct sk_buff___73 *);
	union {
		int (*output)(struct sock___60 *, struct sk_buff___73 *);
		struct {
			int (*output)(struct sk_buff___73 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___61 *next;
		struct rtable___32 *rt_next;
		struct rt6_info___15 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___61;

struct neigh_parms___61;

struct neigh_ops___61;

struct neighbour___61 {
	struct neighbour___61 *next;
	struct neigh_table___61 *tbl;
	struct neigh_parms___61 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___72 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___61 *, struct sk_buff___73 *);
	const struct neigh_ops___61 *ops;
	struct callback_head rcu;
	struct net_device___71 *dev;
	u8 primary_key[0];
};

struct fib6_node___15;

struct rt6_info___15 {
	struct dst_entry___61 dst;
	struct fib6_table___15 *rt6i_table;
	struct fib6_node___15 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___37 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___15 {
	struct fib6_node___15 *parent;
	struct fib6_node___15 *left;
	struct fib6_node___15 *right;
	struct rt6_info___15 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___15 *rr_ptr;
};

struct fib6_table___15 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___15 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___85 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___73 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___73 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___85 *, struct dst_entry___61 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___73 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___73 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___205 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___205 *);
	void (*irq_shutdown)(struct irq_data___205 *);
	void (*irq_enable)(struct irq_data___205 *);
	void (*irq_disable)(struct irq_data___205 *);
	void (*irq_ack)(struct irq_data___205 *);
	void (*irq_mask)(struct irq_data___205 *);
	void (*irq_mask_ack)(struct irq_data___205 *);
	void (*irq_unmask)(struct irq_data___205 *);
	void (*irq_eoi)(struct irq_data___205 *);
	int (*irq_set_affinity)(struct irq_data___205 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___205 *);
	int (*irq_set_type)(struct irq_data___205 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___205 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___205 *);
	void (*irq_bus_sync_unlock)(struct irq_data___205 *);
	void (*irq_cpu_online)(struct irq_data___205 *);
	void (*irq_cpu_offline)(struct irq_data___205 *);
	void (*irq_suspend)(struct irq_data___205 *);
	void (*irq_resume)(struct irq_data___205 *);
	void (*irq_pm_shutdown)(struct irq_data___205 *);
	void (*irq_print_chip)(struct irq_data___205 *, struct seq_file___206 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___205 *, void *);
	long unsigned int flags;
};

struct seq_operations___206 {
	void * (*start)(struct seq_file___206 *, loff_t *);
	void (*stop)(struct seq_file___206 *, void *);
	void * (*next)(struct seq_file___206 *, void *, loff_t *);
	int (*show)(struct seq_file___206 *, void *);
};

struct pernet_operations___20 {
	struct list_head list;
	int (*init)(struct net___85 *);
	void (*exit)(struct net___85 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___71 {
	int (*ieee_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___71 *);
	u8 (*setstate)(struct net_device___71 *, u8);
	void (*getpermhwaddr)(struct net_device___71 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___71 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___71 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___71 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___71 *, int, u8 *);
	void (*setpfccfg)(struct net_device___71 *, int, u8);
	void (*getpfccfg)(struct net_device___71 *, int, u8 *);
	u8 (*setall)(struct net_device___71 *);
	u8 (*getcap)(struct net_device___71 *, int, u8 *);
	int (*getnumtcs)(struct net_device___71 *, int, u8 *);
	int (*setnumtcs)(struct net_device___71 *, int, u8);
	u8 (*getpfcstate)(struct net_device___71 *);
	void (*setpfcstate)(struct net_device___71 *, u8);
	void (*getbcncfg)(struct net_device___71 *, int, u32 *);
	void (*setbcncfg)(struct net_device___71 *, int, u32);
	void (*getbcnrp)(struct net_device___71 *, int, u8 *);
	void (*setbcnrp)(struct net_device___71 *, int, u8);
	u8 (*setapp)(struct net_device___71 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___71 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___71 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___71 *, int, u8);
	u8 (*getdcbx)(struct net_device___71 *);
	u8 (*setdcbx)(struct net_device___71 *, u8);
	int (*peer_getappinfo)(struct net_device___71 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___71 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___71 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___71 *, struct cee_pfc *);
};

struct cgroupfs_root___176;

struct cgroup___176 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___176 *parent;
	struct dentry___281 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___176 *subsys[11];
	struct cgroupfs_root___176 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___283 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___176 {
	struct super_block___281 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___176 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___112 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___281 *, struct file___281 *);
	ssize_t (*read)(struct cgroup___176 *, struct cftype___112 *, struct file___281 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___176 *, struct cftype___112 *);
	s64 (*read_s64)(struct cgroup___176 *, struct cftype___112 *);
	int (*read_map)(struct cgroup___176 *, struct cftype___112 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___176 *, struct cftype___112 *, struct seq_file___206 *);
	ssize_t (*write)(struct cgroup___176 *, struct cftype___112 *, struct file___281 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___176 *, struct cftype___112 *, u64);
	int (*write_s64)(struct cgroup___176 *, struct cftype___112 *, s64);
	int (*write_string)(struct cgroup___176 *, struct cftype___112 *, const char *);
	int (*trigger)(struct cgroup___176 *, unsigned int);
	int (*release)(struct inode___281 *, struct file___281 *);
	int (*register_event)(struct cgroup___176 *, struct cftype___112 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___176 *, struct cftype___112 *, struct eventfd_ctx *);
};

struct cftype_set___108 {
	struct list_head node;
	struct cftype___112 *cfts;
};

struct task_and_cgroup___108 {
	struct task_struct___282 *task;
	struct cgroup___176 *cgrp;
	struct css_set___176 *cg;
};

struct cgroup_taskset___108 {
	struct task_and_cgroup___108 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___176 *cur_cgrp;
};

struct cgroup_subsys___108 {
	struct cgroup_subsys_state___176 * (*css_alloc)(struct cgroup___176 *);
	int (*css_online)(struct cgroup___176 *);
	void (*css_offline)(struct cgroup___176 *);
	void (*css_free)(struct cgroup___176 *);
	int (*can_attach)(struct cgroup___176 *, struct cgroup_taskset___108 *);
	void (*cancel_attach)(struct cgroup___176 *, struct cgroup_taskset___108 *);
	void (*attach)(struct cgroup___176 *, struct cgroup_taskset___108 *);
	void (*fork)(struct task_struct___282 *);
	void (*exit)(struct cgroup___176 *, struct cgroup___176 *, struct task_struct___282 *);
	void (*bind)(struct cgroup___176 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___176 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___112 *base_cftypes;
	struct cftype_set___108 base_cftset;
	struct module___175 *module;
};

struct request_sock_ops___46;

struct request_sock___47 {
	struct sock_common___60 __req_common;
	struct request_sock___47 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___46 *rsk_ops;
	struct sock___60 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___15;

struct xfrm_type___15;

struct xfrm_mode___15;

struct xfrm_state___15 {
	struct net___85 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___15 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___15 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___15 *type;
	struct xfrm_mode___15 *inner_mode;
	struct xfrm_mode___15 *inner_mode_iaf;
	struct xfrm_mode___15 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___15 {
	struct sk_buff_head___72 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___15 {
	struct net___85 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___15 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___73 {
	struct sk_buff___73 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___73 *, struct netlink_callback___73 *);
	int (*done)(struct netlink_callback___73 *);
	void *data;
	struct module___175 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___71 {
	int (*create)(struct sk_buff___73 *, struct net_device___71 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___73 *, unsigned char *);
	int (*rebuild)(struct sk_buff___73 *);
	int (*cache)(const struct neighbour___61 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___71 *, const unsigned char *);
};

struct napi_struct___71 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___71 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___71 *dev;
	struct sk_buff___73 *gro_list;
	struct sk_buff___73 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___71 {
	struct net_device___71 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___63 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___71 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___63 kobj;
	struct net_device___71 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___71 {
	int (*ndo_init)(struct net_device___71 *);
	void (*ndo_uninit)(struct net_device___71 *);
	int (*ndo_open)(struct net_device___71 *);
	int (*ndo_stop)(struct net_device___71 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___73 *, struct net_device___71 *);
	u16 (*ndo_select_queue)(struct net_device___71 *, struct sk_buff___73 *);
	void (*ndo_change_rx_flags)(struct net_device___71 *, int);
	void (*ndo_set_rx_mode)(struct net_device___71 *);
	int (*ndo_set_mac_address)(struct net_device___71 *, void *);
	int (*ndo_validate_addr)(struct net_device___71 *);
	int (*ndo_do_ioctl)(struct net_device___71 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___71 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___71 *, int);
	int (*ndo_neigh_setup)(struct net_device___71 *, struct neigh_parms___61 *);
	void (*ndo_tx_timeout)(struct net_device___71 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___71 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___71 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___71 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___71 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___71 *);
	int (*ndo_netpoll_setup)(struct net_device___71 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___71 *);
	int (*ndo_busy_poll)(struct napi_struct___71 *);
	int (*ndo_set_vf_mac)(struct net_device___71 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___71 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___71 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___71 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___71 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___71 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___71 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___71 *, int, struct sk_buff___73 *);
	int (*ndo_setup_tc)(struct net_device___71 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___71 *);
	int (*ndo_fcoe_disable)(struct net_device___71 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___71 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___71 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___71 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___71 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___71 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___71 *, const struct sk_buff___73 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___71 *, struct net_device___71 *);
	int (*ndo_del_slave)(struct net_device___71 *, struct net_device___71 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___61 *);
	void (*ndo_neigh_destroy)(struct neighbour___61 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___73 *, struct netlink_callback___73 *, struct net_device___71 *, int);
	int (*ndo_bridge_setlink)(struct net_device___71 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___73 *, u32, u32, struct net_device___71 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___71 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___71 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___71 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___71 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___71 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___71 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___73 *, struct net_device___71 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___71 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___71 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___71 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___61 {
	struct net___85 *net;
	struct net_device___71 *dev;
	struct neigh_parms___61 *next;
	int (*neigh_setup)(struct neighbour___61 *);
	void (*neigh_cleanup)(struct neighbour___61 *);
	struct neigh_table___61 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___9;

struct in_device___9 {
	struct net_device___71 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___9 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___61 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___37;

struct ifacaddr6___37;

struct inet6_dev___37 {
	struct net_device___71 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___37 *mc_list;
	struct ifmcaddr6___37 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___37 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___61 *nd_parms;
	struct inet6_dev___37 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___62 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___71 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___85 *, struct net_device___71 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___71 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___71 *, struct list_head *);
	size_t (*get_size)(const struct net_device___71 *);
	int (*fill_info)(struct sk_buff___73 *, const struct net_device___71 *);
	size_t (*get_xstats_size)(const struct net_device___71 *);
	int (*fill_xstats)(struct sk_buff___73 *, const struct net_device___71 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___85 * (*get_link_net)(const struct net_device___71 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___71 *, struct net_device___71 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___71 *, const struct net_device___71 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___73 *, const struct net_device___71 *, const struct net_device___71 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___9 {
	struct hlist_node hash;
	struct in_ifaddr___9 *ifa_next;
	struct in_device___9 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___61 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___73 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___61;

struct neigh_hash_table___61;

struct neigh_table___61 {
	struct neigh_table___61 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___71 *, __u32 *);
	int (*constructor)(struct neighbour___61 *);
	int (*pconstructor)(struct pneigh_entry___61 *);
	void (*pdestructor)(struct pneigh_entry___61 *);
	void (*proxy_redo)(struct sk_buff___73 *);
	char *id;
	struct neigh_parms___61 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___72 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___61 *nht;
	struct pneigh_entry___61 **phash_buckets;
};

struct neigh_ops___61 {
	int family;
	void (*solicit)(struct neighbour___61 *, struct sk_buff___73 *);
	void (*error_report)(struct neighbour___61 *, struct sk_buff___73 *);
	int (*output)(struct neighbour___61 *, struct sk_buff___73 *);
	int (*connected_output)(struct neighbour___61 *, struct sk_buff___73 *);
};

struct pneigh_entry___61 {
	struct pneigh_entry___61 *next;
	struct net___85 *net;
	struct net_device___71 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___61 {
	struct neighbour___61 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___32 {
	struct dst_entry___61 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

enum {
	XFRM_LOOKUP_ICMP = 1,
	XFRM_LOOKUP_QUEUE = 2,
	XFRM_LOOKUP_KEEP_DST_REF = 4,
};

struct timewait_sock_ops___43;

struct inet_hashinfo___14;

struct proto___60 {
	void (*close)(struct sock___60 *, long int);
	int (*connect)(struct sock___60 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___60 *, int);
	struct sock___60 * (*accept)(struct sock___60 *, int, int *);
	int (*ioctl)(struct sock___60 *, int, long unsigned int);
	int (*init)(struct sock___60 *);
	void (*destroy)(struct sock___60 *);
	void (*shutdown)(struct sock___60 *, int);
	int (*setsockopt)(struct sock___60 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___60 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___60 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___60 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___60 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___68 *, struct sock___60 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___68 *, struct sock___60 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___60 *, struct page___280 *, int, size_t, int);
	int (*bind)(struct sock___60 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___60 *, struct sk_buff___73 *);
	void (*release_cb)(struct sock___60 *);
	void (*mtu_reduced)(struct sock___60 *);
	void (*hash)(struct sock___60 *);
	void (*unhash)(struct sock___60 *);
	void (*rehash)(struct sock___60 *);
	int (*get_port)(struct sock___60 *, short unsigned int);
	void (*clear_sk)(struct sock___60 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___60 *);
	void (*enter_memory_pressure)(struct sock___60 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___264 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___46 *rsk_prot;
	struct timewait_sock_ops___43 *twsk_prot;
	union {
		struct inet_hashinfo___14 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___175 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___108 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___60 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___60 {
	void (*enter_memory_pressure)(struct sock___60 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___14 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___264 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___46 {
	int family;
	int obj_size;
	struct kmem_cache___264 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___60 *, struct request_sock___47 *);
	void (*send_ack)(struct sock___60 *, struct sk_buff___73 *, struct request_sock___47 *);
	void (*send_reset)(struct sock___60 *, struct sk_buff___73 *);
	void (*destructor)(struct request_sock___47 *);
	void (*syn_ack_timeout)(struct sock___60 *, struct request_sock___47 *);
};

struct timewait_sock_ops___43 {
	struct kmem_cache___264 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___60 *, struct sock___60 *, void *);
	void (*twsk_destructor)(struct sock___60 *);
};

struct inet_cork___19 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___61 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___19 {
	struct inet_cork___19 base;
	struct flowi fl;
};

struct ipv6_pinfo___18;

struct inet_sock___19 {
	struct sock___60 sk;
	struct ipv6_pinfo___18 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___19 cork;
};

struct ipv6_fl_socklist___17;

struct ipv6_pinfo___18 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___17 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___73 *pktoptions;
	struct sk_buff___73 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___17;

struct ipv6_fl_socklist___17 {
	struct ipv6_fl_socklist___17 *next;
	struct ip6_flowlabel___17 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___37 {
	struct in6_addr mca_addr;
	struct inet6_dev___37 *idev;
	struct ifmcaddr6___37 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___37 {
	struct in6_addr aca_addr;
	struct inet6_dev___37 *aca_idev;
	struct rt6_info___15 *aca_rt;
	struct ifacaddr6___37 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___17 {
	struct ip6_flowlabel___17 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___85 *fl_net;
};

struct net_protocol___4 {
	void (*early_demux)(struct sk_buff___73 *);
	int (*handler)(struct sk_buff___73 *);
	void (*err_handler)(struct sk_buff___73 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct xfrm_replay___15 {
	void (*advance)(struct xfrm_state___15 *, __be32);
	int (*check)(struct xfrm_state___15 *, struct sk_buff___73 *, __be32);
	int (*recheck)(struct xfrm_state___15 *, struct sk_buff___73 *, __be32);
	void (*notify)(struct xfrm_state___15 *, int);
	int (*overflow)(struct xfrm_state___15 *, struct sk_buff___73 *);
};

struct xfrm_type___15 {
	char *description;
	struct module___175 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___15 *);
	void (*destructor)(struct xfrm_state___15 *);
	int (*input)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*output)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*reject)(struct xfrm_state___15 *, struct sk_buff___73 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___15 *, struct sk_buff___73 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___15 *, int);
};

struct xfrm_state_afinfo___15;

struct xfrm_mode___15 {
	int (*input2)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*input)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*output2)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*output)(struct xfrm_state___15 *, struct sk_buff___73 *);
	struct xfrm_state_afinfo___15 *afinfo;
	struct module___175 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___15 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___175 *owner;
	const struct xfrm_type___15 *type_map[256];
	struct xfrm_mode___15 *mode_map[5];
	int (*init_flags)(struct xfrm_state___15 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___15 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___15 **, struct xfrm_state___15 **, int);
	union {
		int (*output)(struct sock___60 *, struct sk_buff___73 *);
		struct {
			int (*output)(struct sk_buff___73 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___60 *, struct sk_buff___73 *);
		struct {
			int (*output_finish)(struct sk_buff___73 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*extract_output)(struct xfrm_state___15 *, struct sk_buff___73 *);
	int (*transport_finish)(struct sk_buff___73 *, int);
};

struct fib_rule___5 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___5 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___85 *fr_net;
};

struct fib_lookup_arg___5 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___5 *rule;
	int flags;
};

struct icmp_bxm {
	struct sk_buff___73 *skb;
	int offset;
	int data_len;
	struct {
		struct icmphdr icmph;
		__be32 times[3];
	} data;
	int head_len;
	struct ip_options_data replyopts;
};

struct icmp_control {
	void (*handler)(struct sk_buff___73 *);
	short int error;
};

struct exec_domain___78 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___168 *module;
	struct exec_domain___78 *next;
};

struct thread_info___125 {
	struct task_struct___272 *task;
	struct exec_domain___78 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct netlink_skb_parms___10 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___51 *sk;
	bool nsid_is_set;
	int nsid;
};

struct ifaddrmsg {
	__u8 ifa_family;
	__u8 ifa_prefixlen;
	__u8 ifa_flags;
	__u8 ifa_scope;
	__u32 ifa_index;
};

enum {
	IFA_UNSPEC = 0,
	IFA_ADDRESS = 1,
	IFA_LOCAL = 2,
	IFA_LABEL = 3,
	IFA_BROADCAST = 4,
	IFA_ANYCAST = 5,
	IFA_CACHEINFO = 6,
	IFA_MULTICAST = 7,
	IFA_FLAGS = 8,
	__IFA_MAX = 9,
};

struct ifa_cacheinfo {
	__u32 ifa_prefered;
	__u32 ifa_valid;
	__u32 cstamp;
	__u32 tstamp;
};

struct pernet_operations___21 {
	struct list_head list;
	int (*init)(struct net___75 *);
	void (*exit)(struct net___75 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

enum {
	IFLA_INET_UNSPEC = 0,
	IFLA_INET_CONF = 1,
	__IFLA_INET_MAX = 2,
};

typedef int gifconf_func_t___2(struct net_device___61 *, char *, int);

struct netconfmsg {
	__u8 ncm_family;
};

enum {
	NETCONFA_UNSPEC = 0,
	NETCONFA_IFINDEX = 1,
	NETCONFA_FORWARDING = 2,
	NETCONFA_RP_FILTER = 3,
	NETCONFA_MC_FORWARDING = 4,
	__NETCONFA_MAX = 5,
};

typedef int (*rtnl_doit_func___6)(struct sk_buff___64 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___6)(struct sk_buff___64 *, struct netlink_callback___63 *);

typedef u16 (*rtnl_calcit_func___6)(struct sk_buff___64 *, struct nlmsghdr *);

struct rtnl_af_ops___2 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___64 *, const struct net_device___61 *);
	size_t (*get_link_af_size)(const struct net_device___61 *);
	int (*validate_link_af)(const struct net_device___61 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___61 *, const struct nlattr *);
};

struct fib_nh_exception___2 {
	struct fib_nh_exception___2 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___22 *fnhe_rth;
	long unsigned int fnhe_stamp;
};

struct fnhe_hash_bucket___2 {
	struct fib_nh_exception___2 *chain;
};

struct fib_info___2;

struct fib_nh___2 {
	struct net_device___61 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___2 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	int nh_power;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___22 **nh_pcpu_rth_output;
	struct rtable___22 *nh_rth_input;
	struct fnhe_hash_bucket___2 *nh_exceptions;
};

struct fib_info___2 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___75 *fib_net;
	int fib_treeref;
	atomic_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_priority;
	u32 *fib_metrics;
	int fib_nhs;
	int fib_power;
	struct callback_head rcu;
	struct fib_nh___2 fib_nh[0];
};

struct fib_result___2 {
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___2 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct devinet_sysctl_table {
	struct ctl_table_header___76 *sysctl_header;
	struct ctl_table devinet_vars[27];
};

struct page___281;

typedef struct page___281 *pgtable_t___281;

struct address_space___282;

struct kmem_cache___265;

struct page___281 {
	long unsigned int flags;
	struct address_space___282 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___281 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___281 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___265 *slab_cache;
		struct page___281 *first_page;
	};
	long: 64;
};

struct task_struct___283;

struct pv_cpu_ops___283 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___283 *);
	void (*end_context_switch)(struct task_struct___283 *);
};

struct mutex___284 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___283 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___276 {
	struct page___281 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___290;

struct nsproxy___162;

struct signal_struct___283;

struct css_set___177;

struct task_struct___283 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___283 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___290 *mm;
	struct mm_struct___290 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___283 *real_parent;
	struct task_struct___283 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___283 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___283 = 0,
		VTIME_USER___283 = 1,
		VTIME_SYS___283 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___162 *nsproxy;
	struct signal_struct___283 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___177 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___284 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___276 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___290 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___290 *, struct mm_struct___290 *);
	void (*dup_mmap)(struct mm_struct___290 *, struct mm_struct___290 *);
	void (*exit_mmap)(struct mm_struct___290 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___290 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___290 *);
	void (*pgd_free)(struct mm_struct___290 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___290 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___290 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___290 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___290 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___290 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___290 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___290 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___290 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___290 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___290 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___290 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___284 lock;
	void *vdso;
} mm_context_t___284;

struct xol_area___281;

struct uprobes_state___281 {
	struct xol_area___281 *xol_area;
};

struct vm_area_struct___290;

struct file___282;

struct core_state___283;

struct mm_struct___290 {
	struct vm_area_struct___290 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___290 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___290 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___284 context;
	long unsigned int flags;
	struct core_state___283 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___283 *owner;
	struct file___282 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___281 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___176;

struct exec_domain___79 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___176 *module;
	struct exec_domain___79 *next;
};

struct kset___64;

struct kobj_type___64;

struct kobject___64 {
	const char *name;
	struct list_head entry;
	struct kobject___64 *parent;
	struct kset___64 *kset;
	struct kobj_type___64 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___176 {
	struct kobject___64 kobj;
	struct module___176 *mod;
	struct kobject___64 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___176;

struct module___176 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___176 mkobj;
	struct module_attribute___176 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___64 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___283 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___126 {
	struct task_struct___283 *task;
	struct exec_domain___79 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___283;

struct lruvec___283 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___283 *zone;
};

struct pglist_data___283;

struct zone___283 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___283 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___283 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___283 {
	struct zone___283 *zone;
	int zone_idx;
};

struct zonelist___283 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___283 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___283 {
	struct zone___283 node_zones[4];
	struct zonelist___283 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___283 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___206;

struct x86_io_apic_ops___206 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___206 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___206;

struct irq_data___206 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___206 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___280;

struct dev_pm_ops___280 {
	int (*prepare)(struct device___280 *);
	void (*complete)(struct device___280 *);
	int (*suspend)(struct device___280 *);
	int (*resume)(struct device___280 *);
	int (*freeze)(struct device___280 *);
	int (*thaw)(struct device___280 *);
	int (*poweroff)(struct device___280 *);
	int (*restore)(struct device___280 *);
	int (*suspend_late)(struct device___280 *);
	int (*resume_early)(struct device___280 *);
	int (*freeze_late)(struct device___280 *);
	int (*thaw_early)(struct device___280 *);
	int (*poweroff_late)(struct device___280 *);
	int (*restore_early)(struct device___280 *);
	int (*suspend_noirq)(struct device___280 *);
	int (*resume_noirq)(struct device___280 *);
	int (*freeze_noirq)(struct device___280 *);
	int (*thaw_noirq)(struct device___280 *);
	int (*poweroff_noirq)(struct device___280 *);
	int (*restore_noirq)(struct device___280 *);
	int (*runtime_suspend)(struct device___280 *);
	int (*runtime_resume)(struct device___280 *);
	int (*runtime_idle)(struct device___280 *);
};

struct dev_pm_qos___83;

struct dev_pm_info___83 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___83 *qos;
};

struct dma_map_ops___145;

struct dev_archdata___145 {
	struct dma_map_ops___145 *dma_ops;
	void *iommu;
};

struct device_type___280;

struct bus_type___280;

struct device_driver___280;

struct dev_pm_domain___280;

struct class___280;

struct attribute_group___242;

struct device_rh___280;

struct device___280 {
	struct device___280 *parent;
	struct device_private *p;
	struct kobject___64 kobj;
	const char *init_name;
	const struct device_type___280 *type;
	struct mutex___284 mutex;
	struct bus_type___280 *bus;
	struct device_driver___280 *driver;
	void *platform_data;
	struct dev_pm_info___83 power;
	struct dev_pm_domain___280 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___145 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___280 *class;
	const struct attribute_group___242 **groups;
	void (*release)(struct device___280 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___280 *device_rh;
};

struct dev_pm_qos_request___84;

struct dev_pm_qos___83 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___84 *latency_req;
	struct dev_pm_qos_request___84 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___84 *latency_tolerance_req;
};

struct dev_pm_info_rh___280 {
	void (*set_latency_tolerance)(struct device___280 *, s32);
};

struct dev_pm_domain___280 {
	struct dev_pm_ops___280 ops;
};

struct smp_ops___283 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___283 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___87;

struct ctl_node___87 {
	struct rb_node node;
	struct ctl_table_header___87 *header;
};

struct ctl_table_root___87;

struct ctl_table_set___87;

struct ctl_dir___87;

struct ctl_table_header___87 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___87 *root;
	struct ctl_table_set___87 *set;
	struct ctl_dir___87 *parent;
	struct ctl_node___87 *node;
};

struct ctl_dir___87 {
	struct ctl_table_header___87 header;
	struct rb_root root;
};

struct ctl_table_set___87 {
	int (*is_seen)(struct ctl_table_set___87 *);
	struct ctl_dir___87 dir;
};

struct ctl_table_root___87 {
	struct ctl_table_set___87 default_set;
	struct ctl_table_set___87 * (*lookup)(struct ctl_table_root___87 *, struct nsproxy___162 *);
	int (*permissions)(struct ctl_table_header___87 *, struct ctl_table *);
};

struct net___86;

struct nsproxy___162 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___86 *net_ns;
};

struct sock___61;

struct kobj_ns_type_operations___61 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___61 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___61;

struct sock_common___61 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___61 *skc_prot;
	struct net___86 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___74;

struct sk_buff_head___73 {
	struct sk_buff___74 *next;
	struct sk_buff___74 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___62;

struct socket_wq___61;

struct xfrm_policy___16;

struct dst_entry___62;

struct socket___62;

struct cg_proto___61;

struct sock___61 {
	struct sock_common___61 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___73 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___74 *head;
		struct sk_buff___74 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___62 *sk_filter;
	struct socket_wq___61 *sk_wq;
	struct sk_buff_head___73 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___16 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___62 *sk_rx_dst;
	struct dst_entry___62 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___73 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___73 sk_error_queue;
	struct proto___61 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___62 *sk_socket;
	void *sk_user_data;
	struct page_frag___276 sk_frag;
	struct sk_buff___74 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___61 *sk_cgrp;
	void (*sk_state_change)(struct sock___61 *);
	void (*sk_data_ready)(struct sock___61 *, int);
	void (*sk_write_space)(struct sock___61 *);
	void (*sk_error_report)(struct sock___61 *);
	int (*sk_backlog_rcv)(struct sock___61 *, struct sk_buff___74 *);
	void (*sk_destruct)(struct sock___61 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___244;

struct attribute_group___242 {
	const char *name;
	umode_t (*is_visible)(struct kobject___64 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___244 **bin_attrs;
};

struct bin_attribute___244 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___282 *, struct kobject___64 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___282 *, struct kobject___64 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	int (*mmap)(struct file___282 *, struct kobject___64 *, struct bin_attribute___244 *, struct vm_area_struct___290 *);
};

struct dentry___282;

struct path___282 {
	struct vfsmount *mnt;
	struct dentry___282 *dentry;
};

struct inode___282;

struct file_operations___282;

struct file___282 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___282 f_path;
	struct inode___282 *f_inode;
	const struct file_operations___282 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___282 *f_mapping;
	struct mutex___284 f_pos_lock;
};

struct vm_operations_struct___256;

struct vm_area_struct___290 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___290 *vm_next;
	struct vm_area_struct___290 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___290 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___256 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___282 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___64 {
	ssize_t (*show)(struct kobject___64 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___64 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___64 *, const struct attribute *);
};

struct kset_uevent_ops___64;

struct kset___64 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___64 kobj;
	const struct kset_uevent_ops___64 *uevent_ops;
};

struct kobj_type___64 {
	void (*release)(struct kobject___64 *);
	const struct sysfs_ops___64 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___61 * (*child_ns_type)(struct kobject___64 *);
	const void * (*namespace)(struct kobject___64 *);
};

struct kset_uevent_ops___64 {
	int (* const filter)(struct kset___64 *, struct kobject___64 *);
	const char * (* const name)(struct kset___64 *, struct kobject___64 *);
	int (* const uevent)(struct kset___64 *, struct kobject___64 *, struct kobj_uevent_env *);
};

struct module_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___176 *, struct module_kobject___176 *, char *);
	ssize_t (*store)(struct module_attribute___176 *, struct module_kobject___176 *, const char *, size_t);
	void (*setup)(struct module___176 *, const char *);
	int (*test)(struct module___176 *);
	void (*free)(struct module___176 *);
};

struct xol_area___281 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___281 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___264;

struct memcg_cache_params___265;

struct kmem_cache___265 {
	struct kmem_cache_cpu___264 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___64 kobj;
	struct memcg_cache_params___265 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___282;

struct address_space___282 {
	struct inode___282 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___284 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___282 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___252;

struct vm_operations_struct___256 {
	void (*open)(struct vm_area_struct___290 *);
	void (*close)(struct vm_area_struct___290 *);
	int (*fault)(struct vm_area_struct___290 *, struct vm_fault___252 *);
	int (*page_mkwrite)(struct vm_area_struct___290 *, struct vm_fault___252 *);
	int (*access)(struct vm_area_struct___290 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___290 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___290 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___290 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___290 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___283 {
	struct task_struct___283 *task;
	struct core_thread___283 *next;
};

struct core_state___283 {
	atomic_t nr_threads;
	struct core_thread___283 dumper;
	struct completion startup;
};

struct signal_struct___283 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___283 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___283 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___284 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___177;

struct css_set___177 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___177 *subsys[11];
	struct callback_head callback_head;
};

struct fasync_struct___282;

struct socket_wq___61 {
	wait_queue_head_t wait;
	struct fasync_struct___282 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___282 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___282 *fa_next;
	struct file___282 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___61;

struct socket___62 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___61 *wq;
	struct file___282 *file;
	struct sock___61 *sk;
	const struct proto_ops___61 *ops;
};

struct poll_table_struct___168;

struct kiocb___69;

struct proto_ops___61 {
	int family;
	struct module___176 *owner;
	int (*release)(struct socket___62 *);
	int (*bind)(struct socket___62 *, struct sockaddr *, int);
	int (*connect)(struct socket___62 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___62 *, struct socket___62 *);
	int (*accept)(struct socket___62 *, struct socket___62 *, int);
	int (*getname)(struct socket___62 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___282 *, struct socket___62 *, struct poll_table_struct___168 *);
	int (*ioctl)(struct socket___62 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___62 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___62 *, int);
	int (*shutdown)(struct socket___62 *, int);
	int (*setsockopt)(struct socket___62 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___62 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___62 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___62 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___69 *, struct socket___62 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___69 *, struct socket___62 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___282 *, struct socket___62 *, struct vm_area_struct___290 *);
	ssize_t (*sendpage)(struct socket___62 *, struct page___281 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___62 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___61 *, int);
		struct {
			void (*set_peek_off)(struct sock___61 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___170)(struct file___282 *, wait_queue_head_t *, struct poll_table_struct___168 *);

struct poll_table_struct___168 {
	poll_queue_proc___170 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___69(struct kiocb___69 *, struct io_event *);

struct kiocb___69 {
	atomic_t ki_users;
	struct file___282 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___69 *ki_cancel;
	void (*ki_dtor)(struct kiocb___69 *);
	union {
		void *user;
		struct task_struct___283 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct net_proto_family___4 {
	int family;
	int (*create)(struct net___86 *, struct socket___62 *, int, int);
	struct module___176 *owner;
};

struct netns_core___84 {
	struct ctl_table_header___87 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___85 {
	struct mutex___284 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___84 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___87 *ctl;
};

struct fib_rules_ops___6;

struct netns_ipv4___84 {
	struct ctl_table_header___87 *forw_hdr;
	struct ctl_table_header___87 *frags_hdr;
	struct ctl_table_header___87 *ipv4_hdr;
	struct ctl_table_header___87 *route_hdr;
	struct ctl_table_header___87 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___6 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___61 *fibnl;
	struct sock___61 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___6 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___84 {
	struct ctl_table_header___87 *hdr;
	struct ctl_table_header___87 *route_hdr;
	struct ctl_table_header___87 *icmp_hdr;
	struct ctl_table_header___87 *frags_hdr;
	struct ctl_table_header___87 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___72;

struct neighbour___62;

struct dst_ops___86 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___86 *);
	struct dst_entry___62 * (*check)(struct dst_entry___62 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___62 *);
	unsigned int (*mtu)(const struct dst_entry___62 *);
	u32 * (*cow_metrics)(struct dst_entry___62 *, long unsigned int);
	void (*destroy)(struct dst_entry___62 *);
	void (*ifdown)(struct dst_entry___62 *, struct net_device___72 *, int);
	struct dst_entry___62 * (*negative_advice)(struct dst_entry___62 *);
	void (*link_failure)(struct sk_buff___74 *);
	void (*update_pmtu)(struct dst_entry___62 *, struct sock___61 *, struct sk_buff___74 *, u32);
	void (*redirect)(struct dst_entry___62 *, struct sock___61 *, struct sk_buff___74 *);
	int (*local_out)(struct sk_buff___74 *);
	struct neighbour___62 * (*neigh_lookup)(const struct dst_entry___62 *, struct sk_buff___74 *, const void *);
	struct kmem_cache___265 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___16;

struct fib6_table___16;

struct netns_ipv6___86 {
	struct netns_sysctl_ipv6___84 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___16 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___16 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___86 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___16 *ip6_prohibit_entry;
	struct rt6_info___16 *ip6_blk_hole_entry;
	struct fib6_table___16 *fib6_local_tbl;
	struct fib_rules_ops___6 *fib6_rules_ops;
	struct sock___61 **icmp_sk;
	struct sock___61 *ndisc_sk;
	struct sock___61 *tcp_sk;
	struct sock___61 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___6 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___84 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___87 *sysctl_header;
	struct sock___61 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___61 {
	struct sock___61 *v4_ctl_sk;
	struct sock___61 *v6_ctl_sk;
};

struct netns_nf___84 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___87 *nf_log_dir_header;
};

struct nf_proto_net___84 {
	struct ctl_table_header___87 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___84 {
	struct nf_proto_net___84 pn;
	unsigned int timeout;
};

struct nf_tcp_net___84 {
	struct nf_proto_net___84 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___84 {
	struct nf_proto_net___84 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___84 {
	struct nf_proto_net___84 pn;
	unsigned int timeout;
};

struct nf_ip_net___84 {
	struct nf_generic_net___84 generic;
	struct nf_tcp_net___84 tcp;
	struct nf_udp_net___84 udp;
	struct nf_icmp_net___84 icmp;
	struct nf_icmp_net___84 icmpv6;
};

struct netns_ct___85 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___87 *sysctl_header;
	struct ctl_table_header___87 *acct_sysctl_header;
	struct ctl_table_header___87 *tstamp_sysctl_header;
	struct ctl_table_header___87 *event_sysctl_header;
	struct ctl_table_header___87 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___265 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___84 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___84 {
	struct netns_sysctl_ipv6___84 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___86 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___61 *nlsk;
	struct sock___61 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___87 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___86 xfrm4_dst_ops;
	struct dst_ops___86 xfrm6_dst_ops;
};

struct net___86 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___87 sysctls;
	struct sock___61 *rtnl;
	struct sock___61 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___72 *loopback_dev;
	struct netns_core___84 core;
	struct netns_mib mib;
	struct netns_packet___85 packet;
	struct netns_unix___84 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___84 ipv4;
	struct netns_ipv6___86 ipv6;
	struct netns_sctp___84 sctp;
	struct netns_dccp___61 dccp;
	struct netns_nf___84 nf;
	struct netns_xt xt;
	struct netns_ct___85 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___84 nf_frag;
	struct sock___61 *nfnl;
	struct sock___61 *nfnl_stash;
	struct sk_buff_head___73 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___86 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___61 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___61 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___284 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___284 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___252 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___281 *page;
};

struct seq_file___207;

struct irq_chip___206 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___206 *);
	void (*irq_shutdown)(struct irq_data___206 *);
	void (*irq_enable)(struct irq_data___206 *);
	void (*irq_disable)(struct irq_data___206 *);
	void (*irq_ack)(struct irq_data___206 *);
	void (*irq_mask)(struct irq_data___206 *);
	void (*irq_mask_ack)(struct irq_data___206 *);
	void (*irq_unmask)(struct irq_data___206 *);
	void (*irq_eoi)(struct irq_data___206 *);
	int (*irq_set_affinity)(struct irq_data___206 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___206 *);
	int (*irq_set_type)(struct irq_data___206 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___206 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___206 *);
	void (*irq_bus_sync_unlock)(struct irq_data___206 *);
	void (*irq_cpu_online)(struct irq_data___206 *);
	void (*irq_cpu_offline)(struct irq_data___206 *);
	void (*irq_suspend)(struct irq_data___206 *);
	void (*irq_resume)(struct irq_data___206 *);
	void (*irq_pm_shutdown)(struct irq_data___206 *);
	void (*irq_print_chip)(struct irq_data___206 *, struct seq_file___207 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___206 *, void *);
	long unsigned int flags;
};

struct seq_operations___207;

struct seq_file___207 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___284 lock;
	const struct seq_operations___207 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___282;

struct super_block___282;

struct dentry___282 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___282 *d_parent;
	struct qstr d_name;
	struct inode___282 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___282 *d_op;
	struct super_block___282 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___282;

struct file_lock___282;

struct dquot___282;

struct block_device___282;

struct inode___282 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___282 *i_op;
	struct super_block___282 *i_sb;
	struct address_space___282 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___284 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___282 *i_fop;
	struct file_lock___282 *i_flock;
	struct address_space___282 i_data;
	struct dquot___282 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___282 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___282 {
	int (*d_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_hash)(const struct dentry___282 *, struct qstr *);
	int (*d_compare)(const struct dentry___282 *, const struct dentry___282 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___282 *);
	void (*d_release)(struct dentry___282 *);
	void (*d_prune)(struct dentry___282 *);
	void (*d_iput)(struct dentry___282 *, struct inode___282 *);
	char * (*d_dname)(struct dentry___282 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___282 *);
	int (*d_manage)(struct dentry___282 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___282;

struct mem_dqinfo___282 {
	struct quota_format_type___282 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___282;

struct quota_info___282 {
	unsigned int flags;
	struct mutex___284 dqio_mutex;
	struct mutex___284 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___282 *files[2];
	struct mem_dqinfo___282 info[2];
	const struct quota_format_ops___282 *ops[2];
};

struct file_system_type___282;

struct super_operations___282;

struct dquot_operations___282;

struct quotactl_ops___282;

struct xattr_handler___178;

struct super_block___282 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___282 *s_type;
	const struct super_operations___282 *s_op;
	const struct dquot_operations___282 *dq_op;
	const struct quotactl_ops___282 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___282 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___178 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___282 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___282 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___284 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___282 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___282 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___282 *bd_inode;
	struct super_block___282 *bd_super;
	struct mutex___284 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___282 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___284 bd_fsfreeze_mutex;
};

struct cgroup___177;

struct cgroup_subsys_state___177 {
	struct cgroup___177 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___282 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___282 *ia_file;
};

struct dquot___282 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___284 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___282 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___282 {
	int qf_fmt_id;
	const struct quota_format_ops___282 *qf_ops;
	struct module___176 *qf_owner;
	struct quota_format_type___282 *qf_next;
};

struct quota_format_ops___282 {
	int (*check_quota_file)(struct super_block___282 *, int);
	int (*read_file_info)(struct super_block___282 *, int);
	int (*write_file_info)(struct super_block___282 *, int);
	int (*free_file_info)(struct super_block___282 *, int);
	int (*read_dqblk)(struct dquot___282 *);
	int (*commit_dqblk)(struct dquot___282 *);
	int (*release_dqblk)(struct dquot___282 *);
};

struct dquot_operations___282 {
	int (*write_dquot)(struct dquot___282 *);
	struct dquot___282 * (*alloc_dquot)(struct super_block___282 *, int);
	void (*destroy_dquot)(struct dquot___282 *);
	int (*acquire_dquot)(struct dquot___282 *);
	int (*release_dquot)(struct dquot___282 *);
	int (*mark_dirty)(struct dquot___282 *);
	int (*write_info)(struct super_block___282 *, int);
	qsize_t * (*get_reserved_space)(struct inode___282 *);
};

struct quotactl_ops___282 {
	int (*quota_on)(struct super_block___282 *, int, int, struct path___282 *);
	int (*quota_on_meta)(struct super_block___282 *, int, int);
	int (*quota_off)(struct super_block___282 *, int);
	int (*quota_sync)(struct super_block___282 *, int);
	int (*get_info)(struct super_block___282 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___282 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___282 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___282 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___282 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___282 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___282 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___282 *, unsigned int);
};

struct address_space_operations___282 {
	int (*writepage)(struct page___281 *, struct writeback_control *);
	int (*readpage)(struct file___282 *, struct page___281 *);
	int (*writepages)(struct address_space___282 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___281 *);
	int (*readpages)(struct file___282 *, struct address_space___282 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___282 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___281 **, void **);
	int (*write_end)(struct file___282 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___281 *, void *);
	sector_t (*bmap)(struct address_space___282 *, sector_t);
	void (*invalidatepage)(struct page___281 *, long unsigned int);
	int (*releasepage)(struct page___281 *, gfp_t);
	void (*freepage)(struct page___281 *);
	ssize_t (*direct_IO)(int, struct kiocb___69 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___282 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___282 *, struct page___281 *, struct page___281 *, enum migrate_mode);
	int (*launder_page)(struct page___281 *);
	int (*is_partially_uptodate)(struct page___281 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___281 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___282 *, struct page___281 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___282 *, sector_t *);
	void (*swap_deactivate)(struct file___282 *);
	void (*invalidatepage_range)(struct page___281 *, unsigned int, unsigned int);
};

struct inode_operations___282 {
	struct dentry___282 * (*lookup)(struct inode___282 *, struct dentry___282 *, unsigned int);
	void * (*follow_link)(struct dentry___282 *, struct nameidata *);
	int (*permission)(struct inode___282 *, int);
	struct posix_acl * (*get_acl)(struct inode___282 *, int);
	int (*readlink)(struct dentry___282 *, char *, int);
	void (*put_link)(struct dentry___282 *, struct nameidata *, void *);
	int (*create)(struct inode___282 *, struct dentry___282 *, umode_t, bool);
	int (*link)(struct dentry___282 *, struct inode___282 *, struct dentry___282 *);
	int (*unlink)(struct inode___282 *, struct dentry___282 *);
	int (*symlink)(struct inode___282 *, struct dentry___282 *, const char *);
	int (*mkdir)(struct inode___282 *, struct dentry___282 *, umode_t);
	int (*rmdir)(struct inode___282 *, struct dentry___282 *);
	int (*mknod)(struct inode___282 *, struct dentry___282 *, umode_t, dev_t);
	int (*rename)(struct inode___282 *, struct dentry___282 *, struct inode___282 *, struct dentry___282 *);
	int (*setattr)(struct dentry___282 *, struct iattr___282 *);
	int (*getattr)(struct vfsmount *, struct dentry___282 *, struct kstat *);
	int (*setxattr)(struct dentry___282 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___282 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___282 *, char *, size_t);
	int (*removexattr)(struct dentry___282 *, const char *);
	int (*fiemap)(struct inode___282 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___282 *, struct timespec *, int);
	int (*atomic_open)(struct inode___282 *, struct dentry___282 *, struct file___282 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___282 {
	struct module___176 *owner;
	loff_t (*llseek)(struct file___282 *, loff_t, int);
	ssize_t (*read)(struct file___282 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___282 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___69 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___69 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___282 *, void *, filldir_t);
	unsigned int (*poll)(struct file___282 *, struct poll_table_struct___168 *);
	long int (*unlocked_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___282 *, struct vm_area_struct___290 *);
	int (*open)(struct inode___282 *, struct file___282 *);
	int (*flush)(struct file___282 *, fl_owner_t);
	int (*release)(struct inode___282 *, struct file___282 *);
	int (*fsync)(struct file___282 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___69 *, int);
	int (*fasync)(int, struct file___282 *, int);
	int (*lock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*sendpage)(struct file___282 *, struct page___281 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___282 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___282 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___282 *, long int, struct file_lock___282 **, void **);
		struct {
			int (*setlease)(struct file___282 *, long int, struct file_lock___282 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___282 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___207 *, struct file___282 *);
};

struct file_lock_operations___282;

struct lock_manager_operations___282;

struct file_lock___282 {
	struct file_lock___282 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___282 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___282 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___282 *fl_ops;
	const struct lock_manager_operations___282 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___282 {
	void (*fl_copy_lock)(struct file_lock___282 *, struct file_lock___282 *);
	void (*fl_release_private)(struct file_lock___282 *);
};

struct lock_manager_operations___282 {
	int (*lm_compare_owner)(struct file_lock___282 *, struct file_lock___282 *);
	long unsigned int (*lm_owner_key)(struct file_lock___282 *);
	void (*lm_notify)(struct file_lock___282 *);
	int (*lm_grant)(struct file_lock___282 *, struct file_lock___282 *, int);
	void (*lm_break)(struct file_lock___282 *);
	int (*lm_change)(struct file_lock___282 **, int);
};

struct file_system_type___282 {
	const char *name;
	int fs_flags;
	struct dentry___282 * (*mount)(struct file_system_type___282 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___282 *);
	struct module___176 *owner;
	struct file_system_type___282 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___282 {
	struct inode___282 * (*alloc_inode)(struct super_block___282 *);
	void (*destroy_inode)(struct inode___282 *);
	void (*dirty_inode)(struct inode___282 *, int);
	int (*write_inode)(struct inode___282 *, struct writeback_control *);
	int (*drop_inode)(struct inode___282 *);
	void (*evict_inode)(struct inode___282 *);
	void (*put_super)(struct super_block___282 *);
	int (*sync_fs)(struct super_block___282 *, int);
	int (*freeze_fs)(struct super_block___282 *);
	int (*unfreeze_fs)(struct super_block___282 *);
	int (*statfs)(struct dentry___282 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___282 *, int *, char *);
	void (*umount_begin)(struct super_block___282 *);
	int (*show_options)(struct seq_file___207 *, struct dentry___282 *);
	int (*show_devname)(struct seq_file___207 *, struct dentry___282 *);
	int (*show_path)(struct seq_file___207 *, struct dentry___282 *);
	int (*show_stats)(struct seq_file___207 *, struct dentry___282 *);
	ssize_t (*quota_read)(struct super_block___282 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___282 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___282 *);
	int (*bdev_try_to_free_page)(struct super_block___282 *, struct page___281 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___282 *);
	void (*free_cached_objects)(struct super_block___282 *, int);
};

struct xattr_handler___178 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___282 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___282 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___282 *, const char *, const void *, size_t, int, int);
};

struct kmem_cache_cpu___264 {
	void **freelist;
	long unsigned int tid;
	struct page___281 *page;
	struct page___281 *partial;
};

struct memcg_cache_params___265 {
	bool is_root_cache;
	union {
		struct kmem_cache___265 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___265 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___145 {
	void * (*alloc)(struct device___280 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___280 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___280 *, struct vm_area_struct___290 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___280 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___280 *, struct page___281 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___280 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___280 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___280 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___280 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___280 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___280 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___280 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___280 *, dma_addr_t);
	int (*dma_supported)(struct device___280 *, u64);
	int (*set_dma_mask)(struct device___280 *, u64);
	int is_phys;
};

struct bus_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___280 *, char *);
	ssize_t (*store)(struct bus_type___280 *, const char *, size_t);
};

struct device_attribute___280;

struct driver_attribute___280;

struct bus_type___280 {
	const char *name;
	const char *dev_name;
	struct device___280 *dev_root;
	struct bus_attribute___280 *bus_attrs;
	struct device_attribute___280 *dev_attrs;
	struct driver_attribute___280 *drv_attrs;
	const struct attribute_group___242 **bus_groups;
	const struct attribute_group___242 **dev_groups;
	const struct attribute_group___242 **drv_groups;
	int (*match)(struct device___280 *, struct device_driver___280 *);
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	int (*probe)(struct device___280 *);
	int (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*online)(struct device___280 *);
	int (*offline)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct device___280 *, struct device_attribute___280 *, char *);
	ssize_t (*store)(struct device___280 *, struct device_attribute___280 *, const char *, size_t);
};

struct driver_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___280 *, char *);
	ssize_t (*store)(struct device_driver___280 *, const char *, size_t);
};

struct device_driver___280 {
	const char *name;
	struct bus_type___280 *bus;
	struct module___176 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___280 *);
	int (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	const struct attribute_group___242 **groups;
	const struct dev_pm_ops___280 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___280 {
	const char *name;
	const struct attribute_group___242 **groups;
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
};

struct class_attribute___280;

struct class___280 {
	const char *name;
	struct module___176 *owner;
	struct class_attribute___280 *class_attrs;
	struct device_attribute___280 *dev_attrs;
	const struct attribute_group___242 **dev_groups;
	struct bin_attribute___244 *dev_bin_attrs;
	struct kobject___64 *dev_kobj;
	int (*dev_uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *);
	void (*class_release)(struct class___280 *);
	void (*dev_release)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	const struct kobj_ns_type_operations___61 *ns_type;
	const void * (*namespace)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
	struct subsys_private *p;
};

struct class_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct class___280 *, struct class_attribute___280 *, char *);
	ssize_t (*store)(struct class___280 *, struct class_attribute___280 *, const char *, size_t);
	const void * (*namespace)(struct class___280 *, const struct class_attribute___280 *);
};

struct device_rh___280 {
	struct dev_pm_info_rh___280 power;
};

struct dma_device___13;

struct dma_chan_dev___13;

struct dma_chan___14 {
	struct dma_device___13 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___13 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___13;

struct dma_device___13 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___280 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___14 *);
	void (*device_free_chan_resources)(struct dma_chan___14 *);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_memcpy)(struct dma_chan___14 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_xor)(struct dma_chan___14 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_xor_val)(struct dma_chan___14 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_pq)(struct dma_chan___14 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_pq_val)(struct dma_chan___14 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_memset)(struct dma_chan___14 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_interrupt)(struct dma_chan___14 *, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_sg)(struct dma_chan___14 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___13 * (*device_prep_slave_sg)(struct dma_chan___14 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___13 * (*device_prep_dma_cyclic)(struct dma_chan___14 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___13 * (*device_prep_interleaved_dma)(struct dma_chan___14 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___14 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___14 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___14 *);
};

struct dma_chan_dev___13 {
	struct dma_chan___14 *chan;
	struct device___280 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___13 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___14 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___13 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___8 {
	char *base_address;
	int nr_pages;
	struct page___281 **pages;
};

struct dma_pinned_list___8 {
	int nr_iovecs;
	struct dma_page_list___8 page_list[0];
};

struct nf_bridge_info___72 {
	atomic_t use;
	unsigned int mask;
	struct net_device___72 *physindev;
	struct net_device___72 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___72(struct sk_buff___74 **);

struct net_device_ops___72;

struct ethtool_ops___72;

struct header_ops___72;

struct in_device___10;

struct inet6_dev___38;

struct netdev_rx_queue___72;

struct netdev_queue___72;

struct rtnl_link_ops___63;

struct dcbnl_rtnl_ops___72;

struct net_device___72 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___72 *netdev_ops;
	const struct ethtool_ops___72 *ethtool_ops;
	const struct header_ops___72 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___64 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___10 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___38 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___72 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___72 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___72 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___72 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___72 = 0,
		NETREG_REGISTERED___72 = 1,
		NETREG_UNREGISTERING___72 = 2,
		NETREG_UNREGISTERED___72 = 3,
		NETREG_RELEASED___72 = 4,
		NETREG_DUMMY___72 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___72 = 0,
		RTNL_LINK_INITIALIZING___72 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___72 *);
	struct netpoll_info *npinfo;
	struct net___86 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___280 dev;
	const struct attribute_group___242 *sysfs_groups[4];
	const struct rtnl_link_ops___63 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___72 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___16;

struct sk_buff___74 {
	struct sk_buff___74 *next;
	struct sk_buff___74 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___61 *sk;
	struct net_device___72 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___16 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___74 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___72 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___19 {
	struct {
		struct page___281 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___19 skb_frag_t___19;

struct skb_shared_info___19 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___74 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___19 frags[17];
};

struct xfrm_state___16;

struct sec_path___16 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___16 *xvec[6];
};

struct nf_afinfo___86 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___74 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___74 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___86 *, struct dst_entry___62 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___74 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___74 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct rtable___33;

struct dst_entry___62 {
	struct callback_head callback_head;
	struct dst_entry___62 *child;
	struct net_device___72 *dev;
	struct dst_ops___86 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___62 *path;
	struct dst_entry___62 *from;
	struct xfrm_state___16 *xfrm;
	int (*input)(struct sk_buff___74 *);
	union {
		int (*output)(struct sock___61 *, struct sk_buff___74 *);
		struct {
			int (*output)(struct sk_buff___74 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___62 *next;
		struct rtable___33 *rt_next;
		struct rt6_info___16 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct ip_mc_list___3 {
	struct in_device___10 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___3 *next;
		struct ip_mc_list___3 *next_rcu;
	};
	struct timer_list timer;
	int users;
	atomic_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___10;

struct neigh_parms___62;

struct in_device___10 {
	struct net_device___72 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___10 *ifa_list;
	struct ip_mc_list___3 *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___3 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___62 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct dev_pm_qos_request___84 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___280 *dev;
};

struct ethtool_ops___72 {
	int (*get_settings)(struct net_device___72 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___72 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___72 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___72 *);
	void (*get_regs)(struct net_device___72 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___72 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___72 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___72 *);
	void (*set_msglevel)(struct net_device___72 *, u32);
	int (*nway_reset)(struct net_device___72 *);
	u32 (*get_link)(struct net_device___72 *);
	int (*get_eeprom_len)(struct net_device___72 *);
	int (*get_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___72 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___72 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___72 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___72 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___72 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___72 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___72 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___72 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___72 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___72 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___72 *);
	void (*complete)(struct net_device___72 *);
	u32 (*get_priv_flags)(struct net_device___72 *);
	int (*set_priv_flags)(struct net_device___72 *, u32);
	int (*get_sset_count)(struct net_device___72 *, int);
	int (*get_rxnfc)(struct net_device___72 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___72 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___72 *, struct ethtool_flash *);
	int (*reset)(struct net_device___72 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___72 *);
	int (*get_rxfh_indir)(struct net_device___72 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___72 *, const u32 *);
	void (*get_channels)(struct net_device___72 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___72 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___72 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___72 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___72 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___72 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___72 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___72 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___72 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___72 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___72 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___72 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib_rule___6;

struct fib_lookup_arg___6;

struct fib_rules_ops___6 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___6 *, struct flowi *, int, struct fib_lookup_arg___6 *);
	int (*match)(struct fib_rule___6 *, struct flowi *, int);
	int (*configure)(struct fib_rule___6 *, struct sk_buff___74 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___6 *);
	int (*compare)(struct fib_rule___6 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___6 *, struct sk_buff___74 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___6 *);
	size_t (*nlmsg_payload)(struct fib_rule___6 *);
	void (*flush_cache)(struct fib_rules_ops___6 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___176 *owner;
	struct net___86 *fro_net;
	struct callback_head rcu;
};

struct neigh_table___62;

struct neigh_ops___62;

struct neighbour___62 {
	struct neighbour___62 *next;
	struct neigh_table___62 *tbl;
	struct neigh_parms___62 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___73 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___62 *, struct sk_buff___74 *);
	const struct neigh_ops___62 *ops;
	struct callback_head rcu;
	struct net_device___72 *dev;
	u8 primary_key[0];
};

struct fib6_node___16;

struct rt6_info___16 {
	struct dst_entry___62 dst;
	struct fib6_table___16 *rt6i_table;
	struct fib6_node___16 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___38 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___16 {
	struct fib6_node___16 *parent;
	struct fib6_node___16 *left;
	struct fib6_node___16 *right;
	struct rt6_info___16 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___16 *rr_ptr;
};

struct fib6_table___16 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___16 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct seq_operations___207 {
	void * (*start)(struct seq_file___207 *, loff_t *);
	void (*stop)(struct seq_file___207 *, void *);
	void * (*next)(struct seq_file___207 *, void *, loff_t *);
	int (*show)(struct seq_file___207 *, void *);
};

struct pernet_operations___22 {
	struct list_head list;
	int (*init)(struct net___86 *);
	void (*exit)(struct net___86 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___72 {
	int (*ieee_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___72 *);
	u8 (*setstate)(struct net_device___72 *, u8);
	void (*getpermhwaddr)(struct net_device___72 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___72 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___72 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___72 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___72 *, int, u8 *);
	void (*setpfccfg)(struct net_device___72 *, int, u8);
	void (*getpfccfg)(struct net_device___72 *, int, u8 *);
	u8 (*setall)(struct net_device___72 *);
	u8 (*getcap)(struct net_device___72 *, int, u8 *);
	int (*getnumtcs)(struct net_device___72 *, int, u8 *);
	int (*setnumtcs)(struct net_device___72 *, int, u8);
	u8 (*getpfcstate)(struct net_device___72 *);
	void (*setpfcstate)(struct net_device___72 *, u8);
	void (*getbcncfg)(struct net_device___72 *, int, u32 *);
	void (*setbcncfg)(struct net_device___72 *, int, u32);
	void (*getbcnrp)(struct net_device___72 *, int, u8 *);
	void (*setbcnrp)(struct net_device___72 *, int, u8);
	u8 (*setapp)(struct net_device___72 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___72 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___72 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___72 *, int, u8);
	u8 (*getdcbx)(struct net_device___72 *);
	u8 (*setdcbx)(struct net_device___72 *, u8);
	int (*peer_getappinfo)(struct net_device___72 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___72 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___72 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___72 *, struct cee_pfc *);
};

struct cgroupfs_root___177;

struct cgroup___177 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___177 *parent;
	struct dentry___282 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___177 *subsys[11];
	struct cgroupfs_root___177 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___284 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___177 {
	struct super_block___282 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___177 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___113 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___282 *, struct file___282 *);
	ssize_t (*read)(struct cgroup___177 *, struct cftype___113 *, struct file___282 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___177 *, struct cftype___113 *);
	s64 (*read_s64)(struct cgroup___177 *, struct cftype___113 *);
	int (*read_map)(struct cgroup___177 *, struct cftype___113 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___177 *, struct cftype___113 *, struct seq_file___207 *);
	ssize_t (*write)(struct cgroup___177 *, struct cftype___113 *, struct file___282 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___177 *, struct cftype___113 *, u64);
	int (*write_s64)(struct cgroup___177 *, struct cftype___113 *, s64);
	int (*write_string)(struct cgroup___177 *, struct cftype___113 *, const char *);
	int (*trigger)(struct cgroup___177 *, unsigned int);
	int (*release)(struct inode___282 *, struct file___282 *);
	int (*register_event)(struct cgroup___177 *, struct cftype___113 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___177 *, struct cftype___113 *, struct eventfd_ctx *);
};

struct cftype_set___109 {
	struct list_head node;
	struct cftype___113 *cfts;
};

struct task_and_cgroup___109 {
	struct task_struct___283 *task;
	struct cgroup___177 *cgrp;
	struct css_set___177 *cg;
};

struct cgroup_taskset___109 {
	struct task_and_cgroup___109 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___177 *cur_cgrp;
};

struct cgroup_subsys___109 {
	struct cgroup_subsys_state___177 * (*css_alloc)(struct cgroup___177 *);
	int (*css_online)(struct cgroup___177 *);
	void (*css_offline)(struct cgroup___177 *);
	void (*css_free)(struct cgroup___177 *);
	int (*can_attach)(struct cgroup___177 *, struct cgroup_taskset___109 *);
	void (*cancel_attach)(struct cgroup___177 *, struct cgroup_taskset___109 *);
	void (*attach)(struct cgroup___177 *, struct cgroup_taskset___109 *);
	void (*fork)(struct task_struct___283 *);
	void (*exit)(struct cgroup___177 *, struct cgroup___177 *, struct task_struct___283 *);
	void (*bind)(struct cgroup___177 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___177 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___113 *base_cftypes;
	struct cftype_set___109 base_cftset;
	struct module___176 *module;
};

struct request_sock_ops___47;

struct request_sock___48 {
	struct sock_common___61 __req_common;
	struct request_sock___48 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___47 *rsk_ops;
	struct sock___61 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___16;

struct xfrm_type___16;

struct xfrm_mode___16;

struct xfrm_state___16 {
	struct net___86 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___16 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___16 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___16 *type;
	struct xfrm_mode___16 *inner_mode;
	struct xfrm_mode___16 *inner_mode_iaf;
	struct xfrm_mode___16 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___16 {
	struct sk_buff_head___73 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___16 {
	struct net___86 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___16 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___74 {
	struct sk_buff___74 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___74 *, struct netlink_callback___74 *);
	int (*done)(struct netlink_callback___74 *);
	void *data;
	struct module___176 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___72 {
	int (*create)(struct sk_buff___74 *, struct net_device___72 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___74 *, unsigned char *);
	int (*rebuild)(struct sk_buff___74 *);
	int (*cache)(const struct neighbour___62 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___72 *, const unsigned char *);
};

struct napi_struct___72 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___72 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___72 *dev;
	struct sk_buff___74 *gro_list;
	struct sk_buff___74 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___72 {
	struct net_device___72 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___64 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___72 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___64 kobj;
	struct net_device___72 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___72 {
	int (*ndo_init)(struct net_device___72 *);
	void (*ndo_uninit)(struct net_device___72 *);
	int (*ndo_open)(struct net_device___72 *);
	int (*ndo_stop)(struct net_device___72 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___74 *, struct net_device___72 *);
	u16 (*ndo_select_queue)(struct net_device___72 *, struct sk_buff___74 *);
	void (*ndo_change_rx_flags)(struct net_device___72 *, int);
	void (*ndo_set_rx_mode)(struct net_device___72 *);
	int (*ndo_set_mac_address)(struct net_device___72 *, void *);
	int (*ndo_validate_addr)(struct net_device___72 *);
	int (*ndo_do_ioctl)(struct net_device___72 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___72 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___72 *, int);
	int (*ndo_neigh_setup)(struct net_device___72 *, struct neigh_parms___62 *);
	void (*ndo_tx_timeout)(struct net_device___72 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___72 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___72 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___72 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___72 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___72 *);
	int (*ndo_netpoll_setup)(struct net_device___72 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___72 *);
	int (*ndo_busy_poll)(struct napi_struct___72 *);
	int (*ndo_set_vf_mac)(struct net_device___72 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___72 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___72 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___72 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___72 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___72 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___72 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___72 *, int, struct sk_buff___74 *);
	int (*ndo_setup_tc)(struct net_device___72 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___72 *);
	int (*ndo_fcoe_disable)(struct net_device___72 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___72 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___72 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___72 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___72 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___72 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___72 *, const struct sk_buff___74 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___72 *, struct net_device___72 *);
	int (*ndo_del_slave)(struct net_device___72 *, struct net_device___72 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___62 *);
	void (*ndo_neigh_destroy)(struct neighbour___62 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___74 *, struct netlink_callback___74 *, struct net_device___72 *, int);
	int (*ndo_bridge_setlink)(struct net_device___72 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___74 *, u32, u32, struct net_device___72 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___72 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___72 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___72 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___72 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___72 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___72 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___74 *, struct net_device___72 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___72 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___72 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___72 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___62 {
	struct net___86 *net;
	struct net_device___72 *dev;
	struct neigh_parms___62 *next;
	int (*neigh_setup)(struct neighbour___62 *);
	void (*neigh_cleanup)(struct neighbour___62 *);
	struct neigh_table___62 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___38;

struct ifacaddr6___38;

struct inet6_dev___38 {
	struct net_device___72 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___38 *mc_list;
	struct ifmcaddr6___38 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___38 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___62 *nd_parms;
	struct inet6_dev___38 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___63 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___72 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___86 *, struct net_device___72 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___72 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___72 *, struct list_head *);
	size_t (*get_size)(const struct net_device___72 *);
	int (*fill_info)(struct sk_buff___74 *, const struct net_device___72 *);
	size_t (*get_xstats_size)(const struct net_device___72 *);
	int (*fill_xstats)(struct sk_buff___74 *, const struct net_device___72 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___86 * (*get_link_net)(const struct net_device___72 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___72 *, struct net_device___72 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___72 *, const struct net_device___72 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___74 *, const struct net_device___72 *, const struct net_device___72 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct napi_gro_cb___4 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___74 *last;
};

struct packet_type___5 {
	__be16 type;
	struct net_device___72 *dev;
	int (*func)(struct sk_buff___74 *, struct net_device___72 *, struct packet_type___5 *, struct net_device___72 *);
	bool (*id_match)(struct packet_type___5 *, struct sock___61 *);
	void *af_packet_priv;
	struct list_head list;
};

struct offload_callbacks___5 {
	struct sk_buff___74 * (*gso_segment)(struct sk_buff___74 *, netdev_features_t);
	struct sk_buff___74 ** (*gro_receive)(struct sk_buff___74 **, struct sk_buff___74 *);
	int (*gro_complete)(struct sk_buff___74 *, int);
};

struct packet_offload___3 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___5 callbacks;
	struct list_head list;
};

struct in_ifaddr___10 {
	struct hlist_node hash;
	struct in_ifaddr___10 *ifa_next;
	struct in_device___10 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___62 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___74 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___62;

struct neigh_hash_table___62;

struct neigh_table___62 {
	struct neigh_table___62 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___72 *, __u32 *);
	int (*constructor)(struct neighbour___62 *);
	int (*pconstructor)(struct pneigh_entry___62 *);
	void (*pdestructor)(struct pneigh_entry___62 *);
	void (*proxy_redo)(struct sk_buff___74 *);
	char *id;
	struct neigh_parms___62 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___73 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___62 *nht;
	struct pneigh_entry___62 **phash_buckets;
};

struct neigh_ops___62 {
	int family;
	void (*solicit)(struct neighbour___62 *, struct sk_buff___74 *);
	void (*error_report)(struct neighbour___62 *, struct sk_buff___74 *);
	int (*output)(struct neighbour___62 *, struct sk_buff___74 *);
	int (*connected_output)(struct neighbour___62 *, struct sk_buff___74 *);
};

struct pneigh_entry___62 {
	struct pneigh_entry___62 *next;
	struct net___86 *net;
	struct net_device___72 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___62 {
	struct neighbour___62 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___33 {
	struct dst_entry___62 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___44;

struct inet_hashinfo___15;

struct proto___61 {
	void (*close)(struct sock___61 *, long int);
	int (*connect)(struct sock___61 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___61 *, int);
	struct sock___61 * (*accept)(struct sock___61 *, int, int *);
	int (*ioctl)(struct sock___61 *, int, long unsigned int);
	int (*init)(struct sock___61 *);
	void (*destroy)(struct sock___61 *);
	void (*shutdown)(struct sock___61 *, int);
	int (*setsockopt)(struct sock___61 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___61 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___61 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___61 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___61 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___69 *, struct sock___61 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___69 *, struct sock___61 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___61 *, struct page___281 *, int, size_t, int);
	int (*bind)(struct sock___61 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___61 *, struct sk_buff___74 *);
	void (*release_cb)(struct sock___61 *);
	void (*mtu_reduced)(struct sock___61 *);
	void (*hash)(struct sock___61 *);
	void (*unhash)(struct sock___61 *);
	void (*rehash)(struct sock___61 *);
	int (*get_port)(struct sock___61 *, short unsigned int);
	void (*clear_sk)(struct sock___61 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___61 *);
	void (*enter_memory_pressure)(struct sock___61 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___265 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___47 *rsk_prot;
	struct timewait_sock_ops___44 *twsk_prot;
	union {
		struct inet_hashinfo___15 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___176 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___109 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___61 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___61 {
	void (*enter_memory_pressure)(struct sock___61 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___15 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___265 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___47 {
	int family;
	int obj_size;
	struct kmem_cache___265 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___61 *, struct request_sock___48 *);
	void (*send_ack)(struct sock___61 *, struct sk_buff___74 *, struct request_sock___48 *);
	void (*send_reset)(struct sock___61 *, struct sk_buff___74 *);
	void (*destructor)(struct request_sock___48 *);
	void (*syn_ack_timeout)(struct sock___61 *, struct request_sock___48 *);
};

struct timewait_sock_ops___44 {
	struct kmem_cache___265 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___61 *, struct sock___61 *, void *);
	void (*twsk_destructor)(struct sock___61 *);
};

struct listen_sock___11 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___48 *syn_table[0];
};

struct fastopen_queue___11 {
	struct request_sock___48 *rskq_rst_head;
	struct request_sock___48 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___11 {
	struct request_sock___48 *rskq_accept_head;
	struct request_sock___48 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___11 *listen_opt;
	struct fastopen_queue___11 *fastopenq;
};

struct inet_cork___20 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___62 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___20 {
	struct inet_cork___20 base;
	struct flowi fl;
};

struct ipv6_pinfo___19;

struct inet_sock___20 {
	struct sock___61 sk;
	struct ipv6_pinfo___19 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___20 cork;
};

struct ipv6_fl_socklist___18;

struct ipv6_pinfo___19 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___18 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___74 *pktoptions;
	struct sk_buff___74 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___11;

struct inet_connection_sock_af_ops___11 {
	int (*queue_xmit)(struct sk_buff___74 *, struct flowi *);
	void (*send_check)(struct sock___61 *, struct sk_buff___74 *);
	int (*rebuild_header)(struct sock___61 *);
	void (*sk_rx_dst_set)(struct sock___61 *, const struct sk_buff___74 *);
	int (*conn_request)(struct sock___61 *, struct sk_buff___74 *);
	struct sock___61 * (*syn_recv_sock)(struct sock___61 *, struct sk_buff___74 *, struct request_sock___48 *, struct dst_entry___62 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___61 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___61 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___61 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___61 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___61 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___61 *, const struct inet_bind_bucket___11 *, bool);
	void (*mtu_reduced)(struct sock___61 *);
};

struct inet_bind_bucket___11 {
	struct net___86 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___6;

struct inet_connection_sock___11 {
	struct inet_sock___20 icsk_inet;
	struct request_sock_queue___11 icsk_accept_queue;
	struct inet_bind_bucket___11 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___6 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___11 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___61 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___6 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___61 *);
	void (*release)(struct sock___61 *);
	u32 (*ssthresh)(struct sock___61 *);
	void (*cong_avoid)(struct sock___61 *, u32, u32);
	void (*set_state)(struct sock___61 *, u8);
	void (*cwnd_event)(struct sock___61 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___61 *, u32);
	u32 (*undo_cwnd)(struct sock___61 *);
	void (*pkts_acked)(struct sock___61 *, u32, s32);
	int (*get_info)(struct sock___61 *, u32, struct sk_buff___74 *);
	char name[16];
	struct module___176 *owner;
};

struct tcp_sock_af_ops___7;

struct tcp_sock___8 {
	struct inet_connection_sock___11 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___73 prequeue;
		struct task_struct___283 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___14 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___8 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___74 *lost_skb_hint;
	struct sk_buff___74 *retransmit_skb_hint;
	struct sk_buff_head___73 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___74 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___7 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___48 *fastopen_rsk;
};

struct tcp_sock_af_ops___7 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___61 *, struct sock___61 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___61 *, const struct request_sock___48 *, const struct sk_buff___74 *);
	int (*md5_parse)(struct sock___61 *, char *, int);
};

struct ip6_flowlabel___18;

struct ipv6_fl_socklist___18 {
	struct ipv6_fl_socklist___18 *next;
	struct ip6_flowlabel___18 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___38 {
	struct in6_addr mca_addr;
	struct inet6_dev___38 *idev;
	struct ifmcaddr6___38 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___38 {
	struct in6_addr aca_addr;
	struct inet6_dev___38 *aca_idev;
	struct rt6_info___16 *aca_rt;
	struct ifacaddr6___38 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___18 {
	struct ip6_flowlabel___18 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___86 *fl_net;
};

struct net_protocol___5 {
	void (*early_demux)(struct sk_buff___74 *);
	int (*handler)(struct sk_buff___74 *);
	void (*err_handler)(struct sk_buff___74 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct net_offload___3 {
	struct offload_callbacks___5 callbacks;
	unsigned int flags;
};

struct inet_protosw___2 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___61 *prot;
	const struct proto_ops___61 *ops;
	unsigned char flags;
};

struct fib_rule___6 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___6 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___86 *fr_net;
};

struct fib_lookup_arg___6 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___6 *rule;
	int flags;
};

struct xfrm_replay___16 {
	void (*advance)(struct xfrm_state___16 *, __be32);
	int (*check)(struct xfrm_state___16 *, struct sk_buff___74 *, __be32);
	int (*recheck)(struct xfrm_state___16 *, struct sk_buff___74 *, __be32);
	void (*notify)(struct xfrm_state___16 *, int);
	int (*overflow)(struct xfrm_state___16 *, struct sk_buff___74 *);
};

struct xfrm_type___16 {
	char *description;
	struct module___176 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___16 *);
	void (*destructor)(struct xfrm_state___16 *);
	int (*input)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*output)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*reject)(struct xfrm_state___16 *, struct sk_buff___74 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___16 *, struct sk_buff___74 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___16 *, int);
};

struct xfrm_state_afinfo___16;

struct xfrm_mode___16 {
	int (*input2)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*input)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*output2)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*output)(struct xfrm_state___16 *, struct sk_buff___74 *);
	struct xfrm_state_afinfo___16 *afinfo;
	struct module___176 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___16 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___176 *owner;
	const struct xfrm_type___16 *type_map[256];
	struct xfrm_mode___16 *mode_map[5];
	int (*init_flags)(struct xfrm_state___16 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___16 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___16 **, struct xfrm_state___16 **, int);
	union {
		int (*output)(struct sock___61 *, struct sk_buff___74 *);
		struct {
			int (*output)(struct sk_buff___74 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___61 *, struct sk_buff___74 *);
		struct {
			int (*output_finish)(struct sk_buff___74 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*extract_output)(struct xfrm_state___16 *, struct sk_buff___74 *);
	int (*transport_finish)(struct sk_buff___74 *, int);
};

struct page___282;

typedef struct page___282 *pgtable_t___282;

struct address_space___283;

struct kmem_cache___266;

struct page___282 {
	long unsigned int flags;
	struct address_space___283 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___282 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___282 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___266 *slab_cache;
		struct page___282 *first_page;
	};
	long: 64;
};

struct task_struct___284;

struct pv_cpu_ops___284 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___284 *);
	void (*end_context_switch)(struct task_struct___284 *);
};

struct mutex___285 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___284 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___277 {
	struct page___282 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___291;

struct nsproxy___163;

struct signal_struct___284;

struct css_set___178;

struct task_struct___284 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___284 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___291 *mm;
	struct mm_struct___291 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___284 *real_parent;
	struct task_struct___284 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___284 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___284 = 0,
		VTIME_USER___284 = 1,
		VTIME_SYS___284 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___163 *nsproxy;
	struct signal_struct___284 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___178 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___285 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___277 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___291 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___291 *, struct mm_struct___291 *);
	void (*dup_mmap)(struct mm_struct___291 *, struct mm_struct___291 *);
	void (*exit_mmap)(struct mm_struct___291 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___291 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___291 *);
	void (*pgd_free)(struct mm_struct___291 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___291 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___291 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___291 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___291 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___291 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___291 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___291 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___291 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___291 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___291 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___291 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___285 lock;
	void *vdso;
} mm_context_t___285;

struct xol_area___282;

struct uprobes_state___282 {
	struct xol_area___282 *xol_area;
};

struct vm_area_struct___291;

struct file___283;

struct core_state___284;

struct mm_struct___291 {
	struct vm_area_struct___291 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___291 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___291 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___285 context;
	long unsigned int flags;
	struct core_state___284 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___284 *owner;
	struct file___283 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___282 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___65;

struct kobj_type___65;

struct kobject___65 {
	const char *name;
	struct list_head entry;
	struct kobject___65 *parent;
	struct kset___65 *kset;
	struct kobj_type___65 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___177;

struct module_kobject___177 {
	struct kobject___65 kobj;
	struct module___177 *mod;
	struct kobject___65 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___177;

struct module___177 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___177 mkobj;
	struct module_attribute___177 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___65 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___284 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___284;

struct lruvec___284 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___284 *zone;
};

struct pglist_data___284;

struct zone___284 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___284 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___284 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___284 {
	struct zone___284 *zone;
	int zone_idx;
};

struct zonelist___284 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___284 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___284 {
	struct zone___284 node_zones[4];
	struct zonelist___284 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___284 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___207;

struct x86_io_apic_ops___207 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___207 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___207;

struct irq_data___207 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___207 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___281;

struct dev_pm_ops___281 {
	int (*prepare)(struct device___281 *);
	void (*complete)(struct device___281 *);
	int (*suspend)(struct device___281 *);
	int (*resume)(struct device___281 *);
	int (*freeze)(struct device___281 *);
	int (*thaw)(struct device___281 *);
	int (*poweroff)(struct device___281 *);
	int (*restore)(struct device___281 *);
	int (*suspend_late)(struct device___281 *);
	int (*resume_early)(struct device___281 *);
	int (*freeze_late)(struct device___281 *);
	int (*thaw_early)(struct device___281 *);
	int (*poweroff_late)(struct device___281 *);
	int (*restore_early)(struct device___281 *);
	int (*suspend_noirq)(struct device___281 *);
	int (*resume_noirq)(struct device___281 *);
	int (*freeze_noirq)(struct device___281 *);
	int (*thaw_noirq)(struct device___281 *);
	int (*poweroff_noirq)(struct device___281 *);
	int (*restore_noirq)(struct device___281 *);
	int (*runtime_suspend)(struct device___281 *);
	int (*runtime_resume)(struct device___281 *);
	int (*runtime_idle)(struct device___281 *);
};

struct dev_pm_qos___84;

struct dev_pm_info___84 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___84 *qos;
};

struct dma_map_ops___146;

struct dev_archdata___146 {
	struct dma_map_ops___146 *dma_ops;
	void *iommu;
};

struct device_type___281;

struct bus_type___281;

struct device_driver___281;

struct dev_pm_domain___281;

struct class___281;

struct attribute_group___243;

struct device_rh___281;

struct device___281 {
	struct device___281 *parent;
	struct device_private *p;
	struct kobject___65 kobj;
	const char *init_name;
	const struct device_type___281 *type;
	struct mutex___285 mutex;
	struct bus_type___281 *bus;
	struct device_driver___281 *driver;
	void *platform_data;
	struct dev_pm_info___84 power;
	struct dev_pm_domain___281 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___146 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___43 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___281 *class;
	const struct attribute_group___243 **groups;
	void (*release)(struct device___281 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___281 *device_rh;
};

struct dev_pm_qos_request___85;

struct dev_pm_qos___84 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___85 *latency_req;
	struct dev_pm_qos_request___85 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___85 *latency_tolerance_req;
};

struct dev_pm_info_rh___281 {
	void (*set_latency_tolerance)(struct device___281 *, s32);
};

struct dev_pm_domain___281 {
	struct dev_pm_ops___281 ops;
};

struct smp_ops___284 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___284 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___88;

struct ctl_node___88 {
	struct rb_node node;
	struct ctl_table_header___88 *header;
};

struct ctl_table_root___88;

struct ctl_table_set___88;

struct ctl_dir___88;

struct ctl_table_header___88 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___88 *root;
	struct ctl_table_set___88 *set;
	struct ctl_dir___88 *parent;
	struct ctl_node___88 *node;
};

struct ctl_dir___88 {
	struct ctl_table_header___88 header;
	struct rb_root root;
};

struct ctl_table_set___88 {
	int (*is_seen)(struct ctl_table_set___88 *);
	struct ctl_dir___88 dir;
};

struct ctl_table_root___88 {
	struct ctl_table_set___88 default_set;
	struct ctl_table_set___88 * (*lookup)(struct ctl_table_root___88 *, struct nsproxy___163 *);
	int (*permissions)(struct ctl_table_header___88 *, struct ctl_table *);
};

struct net___87;

struct nsproxy___163 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___87 *net_ns;
};

struct sock___62;

struct kobj_ns_type_operations___62 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___62 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___62;

struct sock_common___62 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___62 *skc_prot;
	struct net___87 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___75;

struct sk_buff_head___74 {
	struct sk_buff___75 *next;
	struct sk_buff___75 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___63;

struct socket_wq___62;

struct dst_entry___63;

struct socket___63;

struct cg_proto___62;

struct sock___62 {
	struct sock_common___62 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___74 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___75 *head;
		struct sk_buff___75 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___63 *sk_filter;
	struct socket_wq___62 *sk_wq;
	struct sk_buff_head___74 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___63 *sk_rx_dst;
	struct dst_entry___63 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___74 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___74 sk_error_queue;
	struct proto___62 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___63 *sk_socket;
	void *sk_user_data;
	struct page_frag___277 sk_frag;
	struct sk_buff___75 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___62 *sk_cgrp;
	void (*sk_state_change)(struct sock___62 *);
	void (*sk_data_ready)(struct sock___62 *, int);
	void (*sk_write_space)(struct sock___62 *);
	void (*sk_error_report)(struct sock___62 *);
	int (*sk_backlog_rcv)(struct sock___62 *, struct sk_buff___75 *);
	void (*sk_destruct)(struct sock___62 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___245;

struct attribute_group___243 {
	const char *name;
	umode_t (*is_visible)(struct kobject___65 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___245 **bin_attrs;
};

struct bin_attribute___245 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___283 *, struct kobject___65 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___283 *, struct kobject___65 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	int (*mmap)(struct file___283 *, struct kobject___65 *, struct bin_attribute___245 *, struct vm_area_struct___291 *);
};

struct dentry___283;

struct path___283 {
	struct vfsmount *mnt;
	struct dentry___283 *dentry;
};

struct inode___283;

struct file_operations___283;

struct file___283 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___283 f_path;
	struct inode___283 *f_inode;
	const struct file_operations___283 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___283 *f_mapping;
	struct mutex___285 f_pos_lock;
};

struct vm_operations_struct___257;

struct vm_area_struct___291 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___291 *vm_next;
	struct vm_area_struct___291 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___291 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___257 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___283 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___65 {
	ssize_t (*show)(struct kobject___65 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___65 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___65 *, const struct attribute *);
};

struct kset_uevent_ops___65;

struct kset___65 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___65 kobj;
	const struct kset_uevent_ops___65 *uevent_ops;
};

struct kobj_type___65 {
	void (*release)(struct kobject___65 *);
	const struct sysfs_ops___65 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___62 * (*child_ns_type)(struct kobject___65 *);
	const void * (*namespace)(struct kobject___65 *);
};

struct kset_uevent_ops___65 {
	int (* const filter)(struct kset___65 *, struct kobject___65 *);
	const char * (* const name)(struct kset___65 *, struct kobject___65 *);
	int (* const uevent)(struct kset___65 *, struct kobject___65 *, struct kobj_uevent_env *);
};

struct module_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___177 *, struct module_kobject___177 *, char *);
	ssize_t (*store)(struct module_attribute___177 *, struct module_kobject___177 *, const char *, size_t);
	void (*setup)(struct module___177 *, const char *);
	int (*test)(struct module___177 *);
	void (*free)(struct module___177 *);
};

struct kmem_cache_cpu___265 {
	void **freelist;
	long unsigned int tid;
	struct page___282 *page;
	struct page___282 *partial;
};

struct memcg_cache_params___266;

struct kmem_cache___266 {
	struct kmem_cache_cpu___265 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___65 kobj;
	struct memcg_cache_params___266 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct memcg_cache_params___266 {
	bool is_root_cache;
	union {
		struct kmem_cache___266 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___266 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct kiocb___70;

struct poll_table_struct___169;

struct file_lock___283;

struct seq_file___208;

struct file_operations___283 {
	struct module___177 *owner;
	loff_t (*llseek)(struct file___283 *, loff_t, int);
	ssize_t (*read)(struct file___283 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___283 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___70 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___70 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___283 *, void *, filldir_t);
	unsigned int (*poll)(struct file___283 *, struct poll_table_struct___169 *);
	long int (*unlocked_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___283 *, struct vm_area_struct___291 *);
	int (*open)(struct inode___283 *, struct file___283 *);
	int (*flush)(struct file___283 *, fl_owner_t);
	int (*release)(struct inode___283 *, struct file___283 *);
	int (*fsync)(struct file___283 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___70 *, int);
	int (*fasync)(int, struct file___283 *, int);
	int (*lock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*sendpage)(struct file___283 *, struct page___282 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___283 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___283 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___283 *, long int, struct file_lock___283 **, void **);
		struct {
			int (*setlease)(struct file___283 *, long int, struct file_lock___283 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___283 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___208 *, struct file___283 *);
};

struct dma_map_ops___146 {
	void * (*alloc)(struct device___281 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___281 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___281 *, struct vm_area_struct___291 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___281 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___281 *, struct page___282 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___281 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___281 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___281 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___281 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___281 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___281 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___281 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___281 *, dma_addr_t);
	int (*dma_supported)(struct device___281 *, u64);
	int (*set_dma_mask)(struct device___281 *, u64);
	int is_phys;
};

struct bus_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___281 *, char *);
	ssize_t (*store)(struct bus_type___281 *, const char *, size_t);
};

struct device_attribute___281;

struct driver_attribute___281;

struct bus_type___281 {
	const char *name;
	const char *dev_name;
	struct device___281 *dev_root;
	struct bus_attribute___281 *bus_attrs;
	struct device_attribute___281 *dev_attrs;
	struct driver_attribute___281 *drv_attrs;
	const struct attribute_group___243 **bus_groups;
	const struct attribute_group___243 **dev_groups;
	const struct attribute_group___243 **drv_groups;
	int (*match)(struct device___281 *, struct device_driver___281 *);
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	int (*probe)(struct device___281 *);
	int (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*online)(struct device___281 *);
	int (*offline)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct device___281 *, struct device_attribute___281 *, char *);
	ssize_t (*store)(struct device___281 *, struct device_attribute___281 *, const char *, size_t);
};

struct driver_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___281 *, char *);
	ssize_t (*store)(struct device_driver___281 *, const char *, size_t);
};

struct device_driver___281 {
	const char *name;
	struct bus_type___281 *bus;
	struct module___177 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___281 *);
	int (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	const struct attribute_group___243 **groups;
	const struct dev_pm_ops___281 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___281 {
	const char *name;
	const struct attribute_group___243 **groups;
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
};

struct class_attribute___281;

struct class___281 {
	const char *name;
	struct module___177 *owner;
	struct class_attribute___281 *class_attrs;
	struct device_attribute___281 *dev_attrs;
	const struct attribute_group___243 **dev_groups;
	struct bin_attribute___245 *dev_bin_attrs;
	struct kobject___65 *dev_kobj;
	int (*dev_uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *);
	void (*class_release)(struct class___281 *);
	void (*dev_release)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	const struct kobj_ns_type_operations___62 *ns_type;
	const void * (*namespace)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
	struct subsys_private *p;
};

struct class_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct class___281 *, struct class_attribute___281 *, char *);
	ssize_t (*store)(struct class___281 *, struct class_attribute___281 *, const char *, size_t);
	const void * (*namespace)(struct class___281 *, const struct class_attribute___281 *);
};

struct device_rh___281 {
	struct dev_pm_info_rh___281 power;
};

struct dev_pm_qos_request___85 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___281 *dev;
};

struct xol_area___282 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___282 *page;
	long unsigned int vaddr;
};

struct address_space_operations___283;

struct address_space___283 {
	struct inode___283 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___285 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___283 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___253;

struct vm_operations_struct___257 {
	void (*open)(struct vm_area_struct___291 *);
	void (*close)(struct vm_area_struct___291 *);
	int (*fault)(struct vm_area_struct___291 *, struct vm_fault___253 *);
	int (*page_mkwrite)(struct vm_area_struct___291 *, struct vm_fault___253 *);
	int (*access)(struct vm_area_struct___291 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___291 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___291 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___291 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___291 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___284 {
	struct task_struct___284 *task;
	struct core_thread___284 *next;
};

struct core_state___284 {
	atomic_t nr_threads;
	struct core_thread___284 dumper;
	struct completion startup;
};

struct vm_fault___253 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___282 *page;
};

struct dentry_operations___283;

struct super_block___283;

struct dentry___283 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___283 *d_parent;
	struct qstr d_name;
	struct inode___283 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___283 *d_op;
	struct super_block___283 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___283;

struct dquot___283;

struct block_device___283;

struct inode___283 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___283 *i_op;
	struct super_block___283 *i_sb;
	struct address_space___283 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___285 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___283 *i_fop;
	struct file_lock___283 *i_flock;
	struct address_space___283 i_data;
	struct dquot___283 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___283 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___283 {
	int (*d_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_hash)(const struct dentry___283 *, struct qstr *);
	int (*d_compare)(const struct dentry___283 *, const struct dentry___283 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___283 *);
	void (*d_release)(struct dentry___283 *);
	void (*d_prune)(struct dentry___283 *);
	void (*d_iput)(struct dentry___283 *, struct inode___283 *);
	char * (*d_dname)(struct dentry___283 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___283 *);
	int (*d_manage)(struct dentry___283 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___283;

struct mem_dqinfo___283 {
	struct quota_format_type___283 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___283;

struct quota_info___283 {
	unsigned int flags;
	struct mutex___285 dqio_mutex;
	struct mutex___285 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___283 *files[2];
	struct mem_dqinfo___283 info[2];
	const struct quota_format_ops___283 *ops[2];
};

struct file_system_type___283;

struct super_operations___283;

struct dquot_operations___283;

struct quotactl_ops___283;

struct xattr_handler___179;

struct super_block___283 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___283 *s_type;
	const struct super_operations___283 *s_op;
	const struct dquot_operations___283 *dq_op;
	const struct quotactl_ops___283 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___283 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___179 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___283 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___283 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___285 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___283 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___283 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___283 *bd_inode;
	struct super_block___283 *bd_super;
	struct mutex___285 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___283 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___285 bd_fsfreeze_mutex;
};

struct cgroup___178;

struct cgroup_subsys_state___178 {
	struct cgroup___178 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___70(struct kiocb___70 *, struct io_event *);

struct kiocb___70 {
	atomic_t ki_users;
	struct file___283 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___70 *ki_cancel;
	void (*ki_dtor)(struct kiocb___70 *);
	union {
		void *user;
		struct task_struct___284 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___283 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___283 *ia_file;
};

struct dquot___283 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___285 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___283 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___283 {
	int qf_fmt_id;
	const struct quota_format_ops___283 *qf_ops;
	struct module___177 *qf_owner;
	struct quota_format_type___283 *qf_next;
};

struct quota_format_ops___283 {
	int (*check_quota_file)(struct super_block___283 *, int);
	int (*read_file_info)(struct super_block___283 *, int);
	int (*write_file_info)(struct super_block___283 *, int);
	int (*free_file_info)(struct super_block___283 *, int);
	int (*read_dqblk)(struct dquot___283 *);
	int (*commit_dqblk)(struct dquot___283 *);
	int (*release_dqblk)(struct dquot___283 *);
};

struct dquot_operations___283 {
	int (*write_dquot)(struct dquot___283 *);
	struct dquot___283 * (*alloc_dquot)(struct super_block___283 *, int);
	void (*destroy_dquot)(struct dquot___283 *);
	int (*acquire_dquot)(struct dquot___283 *);
	int (*release_dquot)(struct dquot___283 *);
	int (*mark_dirty)(struct dquot___283 *);
	int (*write_info)(struct super_block___283 *, int);
	qsize_t * (*get_reserved_space)(struct inode___283 *);
};

struct quotactl_ops___283 {
	int (*quota_on)(struct super_block___283 *, int, int, struct path___283 *);
	int (*quota_on_meta)(struct super_block___283 *, int, int);
	int (*quota_off)(struct super_block___283 *, int);
	int (*quota_sync)(struct super_block___283 *, int);
	int (*get_info)(struct super_block___283 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___283 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___283 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___283 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___283 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___283 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___283 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___283 *, unsigned int);
};

struct address_space_operations___283 {
	int (*writepage)(struct page___282 *, struct writeback_control *);
	int (*readpage)(struct file___283 *, struct page___282 *);
	int (*writepages)(struct address_space___283 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___282 *);
	int (*readpages)(struct file___283 *, struct address_space___283 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___283 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___282 **, void **);
	int (*write_end)(struct file___283 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___282 *, void *);
	sector_t (*bmap)(struct address_space___283 *, sector_t);
	void (*invalidatepage)(struct page___282 *, long unsigned int);
	int (*releasepage)(struct page___282 *, gfp_t);
	void (*freepage)(struct page___282 *);
	ssize_t (*direct_IO)(int, struct kiocb___70 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___283 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___283 *, struct page___282 *, struct page___282 *, enum migrate_mode);
	int (*launder_page)(struct page___282 *);
	int (*is_partially_uptodate)(struct page___282 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___282 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___283 *, struct page___282 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___283 *, sector_t *);
	void (*swap_deactivate)(struct file___283 *);
	void (*invalidatepage_range)(struct page___282 *, unsigned int, unsigned int);
};

struct inode_operations___283 {
	struct dentry___283 * (*lookup)(struct inode___283 *, struct dentry___283 *, unsigned int);
	void * (*follow_link)(struct dentry___283 *, struct nameidata *);
	int (*permission)(struct inode___283 *, int);
	struct posix_acl * (*get_acl)(struct inode___283 *, int);
	int (*readlink)(struct dentry___283 *, char *, int);
	void (*put_link)(struct dentry___283 *, struct nameidata *, void *);
	int (*create)(struct inode___283 *, struct dentry___283 *, umode_t, bool);
	int (*link)(struct dentry___283 *, struct inode___283 *, struct dentry___283 *);
	int (*unlink)(struct inode___283 *, struct dentry___283 *);
	int (*symlink)(struct inode___283 *, struct dentry___283 *, const char *);
	int (*mkdir)(struct inode___283 *, struct dentry___283 *, umode_t);
	int (*rmdir)(struct inode___283 *, struct dentry___283 *);
	int (*mknod)(struct inode___283 *, struct dentry___283 *, umode_t, dev_t);
	int (*rename)(struct inode___283 *, struct dentry___283 *, struct inode___283 *, struct dentry___283 *);
	int (*setattr)(struct dentry___283 *, struct iattr___283 *);
	int (*getattr)(struct vfsmount *, struct dentry___283 *, struct kstat *);
	int (*setxattr)(struct dentry___283 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___283 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___283 *, char *, size_t);
	int (*removexattr)(struct dentry___283 *, const char *);
	int (*fiemap)(struct inode___283 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___283 *, struct timespec *, int);
	int (*atomic_open)(struct inode___283 *, struct dentry___283 *, struct file___283 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___283;

struct file_lock_operations___283;

struct lock_manager_operations___283;

struct file_lock___283 {
	struct file_lock___283 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___283 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___283 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___283 *fl_ops;
	const struct lock_manager_operations___283 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___283 {
	void (*fl_copy_lock)(struct file_lock___283 *, struct file_lock___283 *);
	void (*fl_release_private)(struct file_lock___283 *);
};

struct lock_manager_operations___283 {
	int (*lm_compare_owner)(struct file_lock___283 *, struct file_lock___283 *);
	long unsigned int (*lm_owner_key)(struct file_lock___283 *);
	void (*lm_notify)(struct file_lock___283 *);
	int (*lm_grant)(struct file_lock___283 *, struct file_lock___283 *, int);
	void (*lm_break)(struct file_lock___283 *);
	int (*lm_change)(struct file_lock___283 **, int);
};

struct fasync_struct___283 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___283 *fa_next;
	struct file___283 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___283 {
	const char *name;
	int fs_flags;
	struct dentry___283 * (*mount)(struct file_system_type___283 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___283 *);
	struct module___177 *owner;
	struct file_system_type___283 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___283 {
	struct inode___283 * (*alloc_inode)(struct super_block___283 *);
	void (*destroy_inode)(struct inode___283 *);
	void (*dirty_inode)(struct inode___283 *, int);
	int (*write_inode)(struct inode___283 *, struct writeback_control *);
	int (*drop_inode)(struct inode___283 *);
	void (*evict_inode)(struct inode___283 *);
	void (*put_super)(struct super_block___283 *);
	int (*sync_fs)(struct super_block___283 *, int);
	int (*freeze_fs)(struct super_block___283 *);
	int (*unfreeze_fs)(struct super_block___283 *);
	int (*statfs)(struct dentry___283 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___283 *, int *, char *);
	void (*umount_begin)(struct super_block___283 *);
	int (*show_options)(struct seq_file___208 *, struct dentry___283 *);
	int (*show_devname)(struct seq_file___208 *, struct dentry___283 *);
	int (*show_path)(struct seq_file___208 *, struct dentry___283 *);
	int (*show_stats)(struct seq_file___208 *, struct dentry___283 *);
	ssize_t (*quota_read)(struct super_block___283 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___283 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___283 *);
	int (*bdev_try_to_free_page)(struct super_block___283 *, struct page___282 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___283 *);
	void (*free_cached_objects)(struct super_block___283 *, int);
};

struct xattr_handler___179 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___283 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___283 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___283 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___171)(struct file___283 *, wait_queue_head_t *, struct poll_table_struct___169 *);

struct poll_table_struct___169 {
	poll_queue_proc___171 _qproc;
	long unsigned int _key;
};

struct seq_operations___208;

struct seq_file___208 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___285 lock;
	const struct seq_operations___208 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___284 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___284 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___284 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___285 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___178 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___178 *subsys[11];
	struct callback_head callback_head;
};

struct socket_wq___62 {
	wait_queue_head_t wait;
	struct fasync_struct___283 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___62;

struct socket___63 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___62 *wq;
	struct file___283 *file;
	struct sock___62 *sk;
	const struct proto_ops___62 *ops;
};

struct proto_ops___62 {
	int family;
	struct module___177 *owner;
	int (*release)(struct socket___63 *);
	int (*bind)(struct socket___63 *, struct sockaddr *, int);
	int (*connect)(struct socket___63 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___63 *, struct socket___63 *);
	int (*accept)(struct socket___63 *, struct socket___63 *, int);
	int (*getname)(struct socket___63 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___283 *, struct socket___63 *, struct poll_table_struct___169 *);
	int (*ioctl)(struct socket___63 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___63 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___63 *, int);
	int (*shutdown)(struct socket___63 *, int);
	int (*setsockopt)(struct socket___63 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___63 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___63 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___63 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___70 *, struct socket___63 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___70 *, struct socket___63 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___283 *, struct socket___63 *, struct vm_area_struct___291 *);
	ssize_t (*sendpage)(struct socket___63 *, struct page___282 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___63 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___62 *, int);
		struct {
			void (*set_peek_off)(struct sock___62 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___85 {
	struct ctl_table_header___88 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___86 {
	struct mutex___285 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___85 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___88 *ctl;
};

struct netns_ipv4___85 {
	struct ctl_table_header___88 *forw_hdr;
	struct ctl_table_header___88 *frags_hdr;
	struct ctl_table_header___88 *ipv4_hdr;
	struct ctl_table_header___88 *route_hdr;
	struct ctl_table_header___88 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___62 *fibnl;
	struct sock___62 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___85 {
	struct ctl_table_header___88 *hdr;
	struct ctl_table_header___88 *route_hdr;
	struct ctl_table_header___88 *icmp_hdr;
	struct ctl_table_header___88 *frags_hdr;
	struct ctl_table_header___88 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___73;

struct neighbour___63;

struct dst_ops___87 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___87 *);
	struct dst_entry___63 * (*check)(struct dst_entry___63 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___63 *);
	unsigned int (*mtu)(const struct dst_entry___63 *);
	u32 * (*cow_metrics)(struct dst_entry___63 *, long unsigned int);
	void (*destroy)(struct dst_entry___63 *);
	void (*ifdown)(struct dst_entry___63 *, struct net_device___73 *, int);
	struct dst_entry___63 * (*negative_advice)(struct dst_entry___63 *);
	void (*link_failure)(struct sk_buff___75 *);
	void (*update_pmtu)(struct dst_entry___63 *, struct sock___62 *, struct sk_buff___75 *, u32);
	void (*redirect)(struct dst_entry___63 *, struct sock___62 *, struct sk_buff___75 *);
	int (*local_out)(struct sk_buff___75 *);
	struct neighbour___63 * (*neigh_lookup)(const struct dst_entry___63 *, struct sk_buff___75 *, const void *);
	struct kmem_cache___266 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___87 {
	struct netns_sysctl_ipv6___85 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___87 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___62 **icmp_sk;
	struct sock___62 *ndisc_sk;
	struct sock___62 *tcp_sk;
	struct sock___62 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___85 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___88 *sysctl_header;
	struct sock___62 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___62 {
	struct sock___62 *v4_ctl_sk;
	struct sock___62 *v6_ctl_sk;
};

struct netns_nf___85 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___88 *nf_log_dir_header;
};

struct nf_proto_net___85 {
	struct ctl_table_header___88 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___85 {
	struct nf_proto_net___85 pn;
	unsigned int timeout;
};

struct nf_tcp_net___85 {
	struct nf_proto_net___85 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___85 {
	struct nf_proto_net___85 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___85 {
	struct nf_proto_net___85 pn;
	unsigned int timeout;
};

struct nf_ip_net___85 {
	struct nf_generic_net___85 generic;
	struct nf_tcp_net___85 tcp;
	struct nf_udp_net___85 udp;
	struct nf_icmp_net___85 icmp;
	struct nf_icmp_net___85 icmpv6;
};

struct netns_ct___86 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___88 *sysctl_header;
	struct ctl_table_header___88 *acct_sysctl_header;
	struct ctl_table_header___88 *tstamp_sysctl_header;
	struct ctl_table_header___88 *event_sysctl_header;
	struct ctl_table_header___88 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___266 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___85 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___85 {
	struct netns_sysctl_ipv6___85 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___87 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___62 *nlsk;
	struct sock___62 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___88 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___87 xfrm4_dst_ops;
	struct dst_ops___87 xfrm6_dst_ops;
};

struct net___87 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___88 sysctls;
	struct sock___62 *rtnl;
	struct sock___62 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___73 *loopback_dev;
	struct netns_core___85 core;
	struct netns_mib mib;
	struct netns_packet___86 packet;
	struct netns_unix___85 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___85 ipv4;
	struct netns_ipv6___87 ipv6;
	struct netns_sctp___85 sctp;
	struct netns_dccp___62 dccp;
	struct netns_nf___85 nf;
	struct netns_xt xt;
	struct netns_ct___86 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___85 nf_frag;
	struct sock___62 *nfnl;
	struct sock___62 *nfnl_stash;
	struct sk_buff_head___74 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___87 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___62 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___62 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___285 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___285 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___73 {
	atomic_t use;
	unsigned int mask;
	struct net_device___73 *physindev;
	struct net_device___73 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___73(struct sk_buff___75 **);

struct net_device_ops___73;

struct ethtool_ops___73;

struct header_ops___73;

struct in_device___11;

struct inet6_dev___39;

struct netdev_rx_queue___73;

struct netdev_queue___73;

struct rtnl_link_ops___64;

struct dcbnl_rtnl_ops___73;

struct net_device___73 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___73 *netdev_ops;
	const struct ethtool_ops___73 *ethtool_ops;
	const struct header_ops___73 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___65 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___11 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___39 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___73 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___73 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___73 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___73 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___73 = 0,
		NETREG_REGISTERED___73 = 1,
		NETREG_UNREGISTERING___73 = 2,
		NETREG_UNREGISTERED___73 = 3,
		NETREG_RELEASED___73 = 4,
		NETREG_DUMMY___73 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___73 = 0,
		RTNL_LINK_INITIALIZING___73 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___73 *);
	struct netpoll_info *npinfo;
	struct net___87 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___281 dev;
	const struct attribute_group___243 *sysfs_groups[4];
	const struct rtnl_link_ops___64 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___73 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___75 {
	struct sk_buff___75 *next;
	struct sk_buff___75 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___62 *sk;
	struct net_device___73 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___75 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___73 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___73 {
	int (*get_settings)(struct net_device___73 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___73 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___73 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___73 *);
	void (*get_regs)(struct net_device___73 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___73 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___73 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___73 *);
	void (*set_msglevel)(struct net_device___73 *, u32);
	int (*nway_reset)(struct net_device___73 *);
	u32 (*get_link)(struct net_device___73 *);
	int (*get_eeprom_len)(struct net_device___73 *);
	int (*get_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___73 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___73 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___73 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___73 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___73 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___73 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___73 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___73 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___73 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___73 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___73 *);
	void (*complete)(struct net_device___73 *);
	u32 (*get_priv_flags)(struct net_device___73 *);
	int (*set_priv_flags)(struct net_device___73 *, u32);
	int (*get_sset_count)(struct net_device___73 *, int);
	int (*get_rxnfc)(struct net_device___73 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___73 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___73 *, struct ethtool_flash *);
	int (*reset)(struct net_device___73 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___73 *);
	int (*get_rxfh_indir)(struct net_device___73 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___73 *, const u32 *);
	void (*get_channels)(struct net_device___73 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___73 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___73 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___73 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___73 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___73 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___73 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___73 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___73 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___73 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___73 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___73 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___34;

struct dst_entry___63 {
	struct callback_head callback_head;
	struct dst_entry___63 *child;
	struct net_device___73 *dev;
	struct dst_ops___87 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___63 *path;
	struct dst_entry___63 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___75 *);
	union {
		int (*output)(struct sock___62 *, struct sk_buff___75 *);
		struct {
			int (*output)(struct sk_buff___75 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___63 *next;
		struct rtable___34 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___63;

struct neigh_parms___63;

struct neigh_ops___63;

struct neighbour___63 {
	struct neighbour___63 *next;
	struct neigh_table___63 *tbl;
	struct neigh_parms___63 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___74 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___63 *, struct sk_buff___75 *);
	const struct neigh_ops___63 *ops;
	struct callback_head rcu;
	struct net_device___73 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___87 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___75 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___75 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___87 *, struct dst_entry___63 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___75 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___75 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___207 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___207 *);
	void (*irq_shutdown)(struct irq_data___207 *);
	void (*irq_enable)(struct irq_data___207 *);
	void (*irq_disable)(struct irq_data___207 *);
	void (*irq_ack)(struct irq_data___207 *);
	void (*irq_mask)(struct irq_data___207 *);
	void (*irq_mask_ack)(struct irq_data___207 *);
	void (*irq_unmask)(struct irq_data___207 *);
	void (*irq_eoi)(struct irq_data___207 *);
	int (*irq_set_affinity)(struct irq_data___207 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___207 *);
	int (*irq_set_type)(struct irq_data___207 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___207 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___207 *);
	void (*irq_bus_sync_unlock)(struct irq_data___207 *);
	void (*irq_cpu_online)(struct irq_data___207 *);
	void (*irq_cpu_offline)(struct irq_data___207 *);
	void (*irq_suspend)(struct irq_data___207 *);
	void (*irq_resume)(struct irq_data___207 *);
	void (*irq_pm_shutdown)(struct irq_data___207 *);
	void (*irq_print_chip)(struct irq_data___207 *, struct seq_file___208 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___207 *, void *);
	long unsigned int flags;
};

struct seq_operations___208 {
	void * (*start)(struct seq_file___208 *, loff_t *);
	void (*stop)(struct seq_file___208 *, void *);
	void * (*next)(struct seq_file___208 *, void *, loff_t *);
	int (*show)(struct seq_file___208 *, void *);
};

struct seq_net_private___11 {
	struct net___87 *net;
};

struct pernet_operations___23 {
	struct list_head list;
	int (*init)(struct net___87 *);
	void (*exit)(struct net___87 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___73 {
	int (*ieee_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___73 *);
	u8 (*setstate)(struct net_device___73 *, u8);
	void (*getpermhwaddr)(struct net_device___73 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___73 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___73 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___73 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___73 *, int, u8 *);
	void (*setpfccfg)(struct net_device___73 *, int, u8);
	void (*getpfccfg)(struct net_device___73 *, int, u8 *);
	u8 (*setall)(struct net_device___73 *);
	u8 (*getcap)(struct net_device___73 *, int, u8 *);
	int (*getnumtcs)(struct net_device___73 *, int, u8 *);
	int (*setnumtcs)(struct net_device___73 *, int, u8);
	u8 (*getpfcstate)(struct net_device___73 *);
	void (*setpfcstate)(struct net_device___73 *, u8);
	void (*getbcncfg)(struct net_device___73 *, int, u32 *);
	void (*setbcncfg)(struct net_device___73 *, int, u32);
	void (*getbcnrp)(struct net_device___73 *, int, u8 *);
	void (*setbcnrp)(struct net_device___73 *, int, u8);
	u8 (*setapp)(struct net_device___73 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___73 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___73 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___73 *, int, u8);
	u8 (*getdcbx)(struct net_device___73 *);
	u8 (*setdcbx)(struct net_device___73 *, u8);
	int (*peer_getappinfo)(struct net_device___73 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___73 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___73 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___73 *, struct cee_pfc *);
};

struct cgroupfs_root___178;

struct cgroup___178 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___178 *parent;
	struct dentry___283 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___178 *subsys[11];
	struct cgroupfs_root___178 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___285 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___178 {
	struct super_block___283 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___178 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___114 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___283 *, struct file___283 *);
	ssize_t (*read)(struct cgroup___178 *, struct cftype___114 *, struct file___283 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___178 *, struct cftype___114 *);
	s64 (*read_s64)(struct cgroup___178 *, struct cftype___114 *);
	int (*read_map)(struct cgroup___178 *, struct cftype___114 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___178 *, struct cftype___114 *, struct seq_file___208 *);
	ssize_t (*write)(struct cgroup___178 *, struct cftype___114 *, struct file___283 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___178 *, struct cftype___114 *, u64);
	int (*write_s64)(struct cgroup___178 *, struct cftype___114 *, s64);
	int (*write_string)(struct cgroup___178 *, struct cftype___114 *, const char *);
	int (*trigger)(struct cgroup___178 *, unsigned int);
	int (*release)(struct inode___283 *, struct file___283 *);
	int (*register_event)(struct cgroup___178 *, struct cftype___114 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___178 *, struct cftype___114 *, struct eventfd_ctx *);
};

struct cftype_set___110 {
	struct list_head node;
	struct cftype___114 *cfts;
};

struct task_and_cgroup___110 {
	struct task_struct___284 *task;
	struct cgroup___178 *cgrp;
	struct css_set___178 *cg;
};

struct cgroup_taskset___110 {
	struct task_and_cgroup___110 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___178 *cur_cgrp;
};

struct cgroup_subsys___110 {
	struct cgroup_subsys_state___178 * (*css_alloc)(struct cgroup___178 *);
	int (*css_online)(struct cgroup___178 *);
	void (*css_offline)(struct cgroup___178 *);
	void (*css_free)(struct cgroup___178 *);
	int (*can_attach)(struct cgroup___178 *, struct cgroup_taskset___110 *);
	void (*cancel_attach)(struct cgroup___178 *, struct cgroup_taskset___110 *);
	void (*attach)(struct cgroup___178 *, struct cgroup_taskset___110 *);
	void (*fork)(struct task_struct___284 *);
	void (*exit)(struct cgroup___178 *, struct cgroup___178 *, struct task_struct___284 *);
	void (*bind)(struct cgroup___178 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___178 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___114 *base_cftypes;
	struct cftype_set___110 base_cftset;
	struct module___177 *module;
};

struct request_sock_ops___48;

struct request_sock___49 {
	struct sock_common___62 __req_common;
	struct request_sock___49 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___48 *rsk_ops;
	struct sock___62 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___75 {
	struct sk_buff___75 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___75 *, struct netlink_callback___75 *);
	int (*done)(struct netlink_callback___75 *);
	void *data;
	struct module___177 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___73 {
	int (*create)(struct sk_buff___75 *, struct net_device___73 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___75 *, unsigned char *);
	int (*rebuild)(struct sk_buff___75 *);
	int (*cache)(const struct neighbour___63 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___73 *, const unsigned char *);
};

struct napi_struct___73 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___73 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___73 *dev;
	struct sk_buff___75 *gro_list;
	struct sk_buff___75 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___73 {
	struct net_device___73 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___65 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___73 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___65 kobj;
	struct net_device___73 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___73 {
	int (*ndo_init)(struct net_device___73 *);
	void (*ndo_uninit)(struct net_device___73 *);
	int (*ndo_open)(struct net_device___73 *);
	int (*ndo_stop)(struct net_device___73 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___75 *, struct net_device___73 *);
	u16 (*ndo_select_queue)(struct net_device___73 *, struct sk_buff___75 *);
	void (*ndo_change_rx_flags)(struct net_device___73 *, int);
	void (*ndo_set_rx_mode)(struct net_device___73 *);
	int (*ndo_set_mac_address)(struct net_device___73 *, void *);
	int (*ndo_validate_addr)(struct net_device___73 *);
	int (*ndo_do_ioctl)(struct net_device___73 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___73 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___73 *, int);
	int (*ndo_neigh_setup)(struct net_device___73 *, struct neigh_parms___63 *);
	void (*ndo_tx_timeout)(struct net_device___73 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___73 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___73 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___73 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___73 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___73 *);
	int (*ndo_netpoll_setup)(struct net_device___73 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___73 *);
	int (*ndo_busy_poll)(struct napi_struct___73 *);
	int (*ndo_set_vf_mac)(struct net_device___73 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___73 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___73 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___73 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___73 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___73 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___73 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___73 *, int, struct sk_buff___75 *);
	int (*ndo_setup_tc)(struct net_device___73 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___73 *);
	int (*ndo_fcoe_disable)(struct net_device___73 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___73 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___73 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___73 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___73 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___73 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___73 *, const struct sk_buff___75 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___73 *, struct net_device___73 *);
	int (*ndo_del_slave)(struct net_device___73 *, struct net_device___73 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___63 *);
	void (*ndo_neigh_destroy)(struct neighbour___63 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___75 *, struct netlink_callback___75 *, struct net_device___73 *, int);
	int (*ndo_bridge_setlink)(struct net_device___73 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___75 *, u32, u32, struct net_device___73 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___73 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___73 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___73 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___73 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___73 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___73 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___75 *, struct net_device___73 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___73 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___73 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___73 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___63 {
	struct net___87 *net;
	struct net_device___73 *dev;
	struct neigh_parms___63 *next;
	int (*neigh_setup)(struct neighbour___63 *);
	void (*neigh_cleanup)(struct neighbour___63 *);
	struct neigh_table___63 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___11;

struct ip_mc_list___4;

struct in_device___11 {
	struct net_device___73 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___11 *ifa_list;
	struct ip_mc_list___4 *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___4 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___63 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___39;

struct ifacaddr6___39;

struct inet6_dev___39 {
	struct net_device___73 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___39 *mc_list;
	struct ifmcaddr6___39 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___39 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___63 *nd_parms;
	struct inet6_dev___39 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___64 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___73 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___87 *, struct net_device___73 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___73 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___73 *, struct list_head *);
	size_t (*get_size)(const struct net_device___73 *);
	int (*fill_info)(struct sk_buff___75 *, const struct net_device___73 *);
	size_t (*get_xstats_size)(const struct net_device___73 *);
	int (*fill_xstats)(struct sk_buff___75 *, const struct net_device___73 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___87 * (*get_link_net)(const struct net_device___73 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___73 *, struct net_device___73 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___73 *, const struct net_device___73 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___75 *, const struct net_device___73 *, const struct net_device___73 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___11 {
	struct hlist_node hash;
	struct in_ifaddr___11 *ifa_next;
	struct in_device___11 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___4 {
	struct in_device___11 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___4 *next;
		struct ip_mc_list___4 *next_rcu;
	};
	struct timer_list timer;
	int users;
	atomic_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct igmphdr {
	__u8 type;
	__u8 code;
	__sum16 csum;
	__be32 group;
};

struct igmpv3_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	__be32 grec_mca;
	__be32 grec_src[0];
};

struct igmpv3_report {
	__u8 type;
	__u8 resv1;
	__be16 csum;
	__be16 resv2;
	__be16 ngrec;
	struct igmpv3_grec grec[0];
};

struct igmpv3_query {
	__u8 type;
	__u8 code;
	__be16 csum;
	__be32 group;
	__u8 qrv: 3;
	__u8 suppress: 1;
	__u8 resv: 4;
	__u8 qqic;
	__be16 nsrcs;
	__be32 srcs[0];
};

struct pneigh_entry___63;

struct neigh_hash_table___63;

struct neigh_table___63 {
	struct neigh_table___63 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___73 *, __u32 *);
	int (*constructor)(struct neighbour___63 *);
	int (*pconstructor)(struct pneigh_entry___63 *);
	void (*pdestructor)(struct pneigh_entry___63 *);
	void (*proxy_redo)(struct sk_buff___75 *);
	char *id;
	struct neigh_parms___63 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___74 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___63 *nht;
	struct pneigh_entry___63 **phash_buckets;
};

struct neigh_ops___63 {
	int family;
	void (*solicit)(struct neighbour___63 *, struct sk_buff___75 *);
	void (*error_report)(struct neighbour___63 *, struct sk_buff___75 *);
	int (*output)(struct neighbour___63 *, struct sk_buff___75 *);
	int (*connected_output)(struct neighbour___63 *, struct sk_buff___75 *);
};

struct pneigh_entry___63 {
	struct pneigh_entry___63 *next;
	struct net___87 *net;
	struct net_device___73 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___63 {
	struct neighbour___63 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct sk_filter___63 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___75 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct rtable___34 {
	struct dst_entry___63 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___45;

struct proto___62 {
	void (*close)(struct sock___62 *, long int);
	int (*connect)(struct sock___62 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___62 *, int);
	struct sock___62 * (*accept)(struct sock___62 *, int, int *);
	int (*ioctl)(struct sock___62 *, int, long unsigned int);
	int (*init)(struct sock___62 *);
	void (*destroy)(struct sock___62 *);
	void (*shutdown)(struct sock___62 *, int);
	int (*setsockopt)(struct sock___62 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___62 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___62 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___62 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___62 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___70 *, struct sock___62 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___70 *, struct sock___62 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___62 *, struct page___282 *, int, size_t, int);
	int (*bind)(struct sock___62 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___62 *, struct sk_buff___75 *);
	void (*release_cb)(struct sock___62 *);
	void (*mtu_reduced)(struct sock___62 *);
	void (*hash)(struct sock___62 *);
	void (*unhash)(struct sock___62 *);
	void (*rehash)(struct sock___62 *);
	int (*get_port)(struct sock___62 *, short unsigned int);
	void (*clear_sk)(struct sock___62 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___62 *);
	void (*enter_memory_pressure)(struct sock___62 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___266 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___48 *rsk_prot;
	struct timewait_sock_ops___45 *twsk_prot;
	union {
		struct inet_hashinfo___15 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___177 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___110 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___62 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___62 {
	void (*enter_memory_pressure)(struct sock___62 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___48 {
	int family;
	int obj_size;
	struct kmem_cache___266 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___62 *, struct request_sock___49 *);
	void (*send_ack)(struct sock___62 *, struct sk_buff___75 *, struct request_sock___49 *);
	void (*send_reset)(struct sock___62 *, struct sk_buff___75 *);
	void (*destructor)(struct request_sock___49 *);
	void (*syn_ack_timeout)(struct sock___62 *, struct request_sock___49 *);
};

struct timewait_sock_ops___45 {
	struct kmem_cache___266 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___62 *, struct sock___62 *, void *);
	void (*twsk_destructor)(struct sock___62 *);
};

struct inet_cork___21 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___63 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___21 {
	struct inet_cork___21 base;
	struct flowi fl;
};

struct ipv6_pinfo___20;

struct inet_sock___21 {
	struct sock___62 sk;
	struct ipv6_pinfo___20 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___21 cork;
};

struct ipv6_fl_socklist___19;

struct ipv6_pinfo___20 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___19 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___75 *pktoptions;
	struct sk_buff___75 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___19;

struct ipv6_fl_socklist___19 {
	struct ipv6_fl_socklist___19 *next;
	struct ip6_flowlabel___19 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___39 {
	struct in6_addr mca_addr;
	struct inet6_dev___39 *idev;
	struct ifmcaddr6___39 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___39 {
	struct in6_addr aca_addr;
	struct inet6_dev___39 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___39 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___19 {
	struct ip6_flowlabel___19 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___87 *fl_net;
};

struct igmp_mc_iter_state {
	struct seq_net_private___11 p;
	struct net_device___73 *dev;
	struct in_device___11 *in_dev;
};

struct igmp_mcf_iter_state {
	struct seq_net_private___11 p;
	struct net_device___73 *dev;
	struct in_device___11 *idev;
	struct ip_mc_list___4 *im;
};

struct netlink_kernel_cfg___9 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___60 *);
	struct mutex___269 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___71 *, struct sock___47 *);
};

struct rtnexthop {
	short unsigned int rtnh_len;
	unsigned char rtnh_flags;
	unsigned char rtnh_hops;
	int rtnh_ifindex;
};

struct nl_info {
	struct nlmsghdr *nlh;
	struct net___71 *nl_net;
	u32 portid;
};

struct fib_config {
	u8 fc_dst_len;
	u8 fc_tos;
	u8 fc_protocol;
	u8 fc_scope;
	u8 fc_type;
	u32 fc_table;
	__be32 fc_dst;
	__be32 fc_gw;
	int fc_oif;
	u32 fc_flags;
	u32 fc_priority;
	__be32 fc_prefsrc;
	struct nlattr *fc_mx;
	struct rtnexthop *fc_mp;
	int fc_mx_len;
	int fc_mp_len;
	u32 fc_flow;
	u32 fc_nlflags;
	struct nl_info fc_nlinfo;
};

struct fib_result_nl {
	__be32 fl_addr;
	u32 fl_mark;
	unsigned char fl_tos;
	unsigned char fl_scope;
	unsigned char tb_id_in;
	unsigned char tb_id;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	int err;
};

struct fib_alias {
	struct hlist_node fa_list;
	struct fib_info *fa_info;
	u8 fa_tos;
	u8 fa_type;
	u8 fa_state;
	u8 fa_slen;
	struct callback_head rcu;
};

struct fib_prop {
	int error;
	u8 scope;
};

typedef unsigned int t_key;

struct key_vector {
	t_key key;
	unsigned char pos;
	unsigned char bits;
	unsigned char slen;
	union {
		struct hlist_head leaf;
		struct key_vector *tnode[0];
	};
};

struct tnode {
	struct callback_head rcu;
	t_key empty_children;
	t_key full_children;
	struct key_vector *parent;
	struct key_vector kv[1];
};

struct trie_use_stats {
	unsigned int gets;
	unsigned int backtrack;
	unsigned int semantic_match_passed;
	unsigned int semantic_match_miss;
	unsigned int null_node_hit;
	unsigned int resize_node_skipped;
};

struct trie_stat {
	unsigned int totdepth;
	unsigned int maxdepth;
	unsigned int tnodes;
	unsigned int leaves;
	unsigned int nullpointers;
	unsigned int prefixes;
	unsigned int nodesizes[32];
};

struct trie {
	struct callback_head rcu;
	struct key_vector kv[1];
	struct trie_use_stats *stats;
};

struct fib_trie_iter {
	struct seq_net_private___10 p;
	struct fib_table *tb;
	struct key_vector *tnode;
	unsigned int index;
	unsigned int depth;
};

struct fib_route_iter {
	struct seq_net_private___10 p;
	struct fib_table *main_tb;
	struct key_vector *tnode;
	loff_t pos;
	t_key key;
};

struct ping_table {
	struct hlist_nulls_head hash[64];
	rwlock_t lock;
};

struct ping_iter_state {
	struct seq_net_private___10 p;
	int bucket;
};

struct pingfakehdr {
	struct icmphdr icmph;
	struct iovec *iov;
	__wsum wcheck;
};

struct page___283;

typedef struct page___283 *pgtable_t___283;

struct address_space___284;

struct kmem_cache___267;

struct page___283 {
	long unsigned int flags;
	struct address_space___284 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___283 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___283 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___267 *slab_cache;
		struct page___283 *first_page;
	};
	long: 64;
};

struct task_struct___285;

struct pv_cpu_ops___285 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___285 *);
	void (*end_context_switch)(struct task_struct___285 *);
};

struct mutex___286 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___285 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___278 {
	struct page___283 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___292;

struct nsproxy___164;

struct signal_struct___285;

struct css_set___179;

struct task_struct___285 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___285 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___292 *mm;
	struct mm_struct___292 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___285 *real_parent;
	struct task_struct___285 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___285 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___285 = 0,
		VTIME_USER___285 = 1,
		VTIME_SYS___285 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___164 *nsproxy;
	struct signal_struct___285 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___179 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___286 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___278 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___292 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___292 *, struct mm_struct___292 *);
	void (*dup_mmap)(struct mm_struct___292 *, struct mm_struct___292 *);
	void (*exit_mmap)(struct mm_struct___292 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___292 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___292 *);
	void (*pgd_free)(struct mm_struct___292 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___292 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___292 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___292 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___292 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___292 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___292 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___292 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___292 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___292 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___292 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___292 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___286 lock;
	void *vdso;
} mm_context_t___286;

struct xol_area___283;

struct uprobes_state___283 {
	struct xol_area___283 *xol_area;
};

struct vm_area_struct___292;

struct file___284;

struct core_state___285;

struct mm_struct___292 {
	struct vm_area_struct___292 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___292 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___292 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___286 context;
	long unsigned int flags;
	struct core_state___285 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___285 *owner;
	struct file___284 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___283 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___283 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___283 *page;
	long unsigned int vaddr;
};

struct kset___66;

struct kobj_type___66;

struct kobject___66 {
	const char *name;
	struct list_head entry;
	struct kobject___66 *parent;
	struct kset___66 *kset;
	struct kobj_type___66 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___266;

struct memcg_cache_params___267;

struct kmem_cache___267 {
	struct kmem_cache_cpu___266 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___66 kobj;
	struct memcg_cache_params___267 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___284;

struct address_space_operations___284;

struct address_space___284 {
	struct inode___284 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___286 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___284 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___284;

struct path___284 {
	struct vfsmount *mnt;
	struct dentry___284 *dentry;
};

struct file_operations___284;

struct file___284 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___284 f_path;
	struct inode___284 *f_inode;
	const struct file_operations___284 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___284 *f_mapping;
	struct mutex___286 f_pos_lock;
};

struct vm_operations_struct___258;

struct vm_area_struct___292 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___292 *vm_next;
	struct vm_area_struct___292 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___292 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___258 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___284 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___254;

struct vm_operations_struct___258 {
	void (*open)(struct vm_area_struct___292 *);
	void (*close)(struct vm_area_struct___292 *);
	int (*fault)(struct vm_area_struct___292 *, struct vm_fault___254 *);
	int (*page_mkwrite)(struct vm_area_struct___292 *, struct vm_fault___254 *);
	int (*access)(struct vm_area_struct___292 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___292 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___292 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___292 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___292 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___285 {
	struct task_struct___285 *task;
	struct core_thread___285 *next;
};

struct core_state___285 {
	atomic_t nr_threads;
	struct core_thread___285 dumper;
	struct completion startup;
};

struct fasync_struct___284;

struct socket_wq___63 {
	wait_queue_head_t wait;
	struct fasync_struct___284 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___284 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___284 *fa_next;
	struct file___284 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___63;

struct proto_ops___63;

struct socket___64 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___63 *wq;
	struct file___284 *file;
	struct sock___63 *sk;
	const struct proto_ops___63 *ops;
};

struct proto___63;

struct net___88;

struct sock_common___63 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___63 *skc_prot;
	struct net___88 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___76;

struct sk_buff_head___75 {
	struct sk_buff___76 *next;
	struct sk_buff___76 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___64;

struct xfrm_policy___17;

struct dst_entry___64;

struct cg_proto___63;

struct sock___63 {
	struct sock_common___63 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___75 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___76 *head;
		struct sk_buff___76 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___64 *sk_filter;
	struct socket_wq___63 *sk_wq;
	struct sk_buff_head___75 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___17 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___64 *sk_rx_dst;
	struct dst_entry___64 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___75 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___75 sk_error_queue;
	struct proto___63 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___64 *sk_socket;
	void *sk_user_data;
	struct page_frag___278 sk_frag;
	struct sk_buff___76 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___63 *sk_cgrp;
	void (*sk_state_change)(struct sock___63 *);
	void (*sk_data_ready)(struct sock___63 *, int);
	void (*sk_write_space)(struct sock___63 *);
	void (*sk_error_report)(struct sock___63 *);
	int (*sk_backlog_rcv)(struct sock___63 *, struct sk_buff___76 *);
	void (*sk_destruct)(struct sock___63 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___170;

struct kiocb___71;

struct proto_ops___63 {
	int family;
	struct module *owner;
	int (*release)(struct socket___64 *);
	int (*bind)(struct socket___64 *, struct sockaddr *, int);
	int (*connect)(struct socket___64 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___64 *, struct socket___64 *);
	int (*accept)(struct socket___64 *, struct socket___64 *, int);
	int (*getname)(struct socket___64 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___284 *, struct socket___64 *, struct poll_table_struct___170 *);
	int (*ioctl)(struct socket___64 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___64 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___64 *, int);
	int (*shutdown)(struct socket___64 *, int);
	int (*setsockopt)(struct socket___64 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___64 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___64 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___64 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___71 *, struct socket___64 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___71 *, struct socket___64 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___284 *, struct socket___64 *, struct vm_area_struct___292 *);
	ssize_t (*sendpage)(struct socket___64 *, struct page___283 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___64 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___63 *, int);
		struct {
			void (*set_peek_off)(struct sock___63 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___172)(struct file___284 *, wait_queue_head_t *, struct poll_table_struct___170 *);

struct poll_table_struct___170 {
	poll_queue_proc___172 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___71(struct kiocb___71 *, struct io_event *);

struct kiocb___71 {
	atomic_t ki_users;
	struct file___284 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___71 *ki_cancel;
	void (*ki_dtor)(struct kiocb___71 *);
	union {
		void *user;
		struct task_struct___285 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___89;

struct ctl_table_set___89;

struct ctl_dir___89;

struct ctl_node___89;

struct ctl_table_header___89 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___89 *root;
	struct ctl_table_set___89 *set;
	struct ctl_dir___89 *parent;
	struct ctl_node___89 *node;
};

struct ctl_dir___89 {
	struct ctl_table_header___89 header;
	struct rb_root root;
};

struct ctl_table_set___89 {
	int (*is_seen)(struct ctl_table_set___89 *);
	struct ctl_dir___89 dir;
};

struct netns_core___86 {
	struct ctl_table_header___89 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___87 {
	struct mutex___286 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___86 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___89 *ctl;
};

struct netns_ipv4___86 {
	struct ctl_table_header___89 *forw_hdr;
	struct ctl_table_header___89 *frags_hdr;
	struct ctl_table_header___89 *ipv4_hdr;
	struct ctl_table_header___89 *route_hdr;
	struct ctl_table_header___89 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___63 *fibnl;
	struct sock___63 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___86 {
	struct ctl_table_header___89 *hdr;
	struct ctl_table_header___89 *route_hdr;
	struct ctl_table_header___89 *icmp_hdr;
	struct ctl_table_header___89 *frags_hdr;
	struct ctl_table_header___89 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___74;

struct neighbour___64;

struct dst_ops___88 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___88 *);
	struct dst_entry___64 * (*check)(struct dst_entry___64 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___64 *);
	unsigned int (*mtu)(const struct dst_entry___64 *);
	u32 * (*cow_metrics)(struct dst_entry___64 *, long unsigned int);
	void (*destroy)(struct dst_entry___64 *);
	void (*ifdown)(struct dst_entry___64 *, struct net_device___74 *, int);
	struct dst_entry___64 * (*negative_advice)(struct dst_entry___64 *);
	void (*link_failure)(struct sk_buff___76 *);
	void (*update_pmtu)(struct dst_entry___64 *, struct sock___63 *, struct sk_buff___76 *, u32);
	void (*redirect)(struct dst_entry___64 *, struct sock___63 *, struct sk_buff___76 *);
	int (*local_out)(struct sk_buff___76 *);
	struct neighbour___64 * (*neigh_lookup)(const struct dst_entry___64 *, struct sk_buff___76 *, const void *);
	struct kmem_cache___267 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___17;

struct fib6_table___17;

struct netns_ipv6___88 {
	struct netns_sysctl_ipv6___86 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___17 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___17 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___88 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___17 *ip6_prohibit_entry;
	struct rt6_info___17 *ip6_blk_hole_entry;
	struct fib6_table___17 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___63 **icmp_sk;
	struct sock___63 *ndisc_sk;
	struct sock___63 *tcp_sk;
	struct sock___63 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___86 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___89 *sysctl_header;
	struct sock___63 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___63 {
	struct sock___63 *v4_ctl_sk;
	struct sock___63 *v6_ctl_sk;
};

struct netns_nf___86 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___89 *nf_log_dir_header;
};

struct nf_proto_net___86 {
	struct ctl_table_header___89 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___86 {
	struct nf_proto_net___86 pn;
	unsigned int timeout;
};

struct nf_tcp_net___86 {
	struct nf_proto_net___86 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___86 {
	struct nf_proto_net___86 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___86 {
	struct nf_proto_net___86 pn;
	unsigned int timeout;
};

struct nf_ip_net___86 {
	struct nf_generic_net___86 generic;
	struct nf_tcp_net___86 tcp;
	struct nf_udp_net___86 udp;
	struct nf_icmp_net___86 icmp;
	struct nf_icmp_net___86 icmpv6;
};

struct netns_ct___87 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___89 *sysctl_header;
	struct ctl_table_header___89 *acct_sysctl_header;
	struct ctl_table_header___89 *tstamp_sysctl_header;
	struct ctl_table_header___89 *event_sysctl_header;
	struct ctl_table_header___89 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___267 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___86 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___86 {
	struct netns_sysctl_ipv6___86 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___88 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___63 *nlsk;
	struct sock___63 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___89 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___88 xfrm4_dst_ops;
	struct dst_ops___88 xfrm6_dst_ops;
};

struct net___88 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___89 sysctls;
	struct sock___63 *rtnl;
	struct sock___63 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___74 *loopback_dev;
	struct netns_core___86 core;
	struct netns_mib mib;
	struct netns_packet___87 packet;
	struct netns_unix___86 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___86 ipv4;
	struct netns_ipv6___88 ipv6;
	struct netns_sctp___86 sctp;
	struct netns_dccp___63 dccp;
	struct netns_nf___86 nf;
	struct netns_xt xt;
	struct netns_ct___87 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___86 nf_frag;
	struct sock___63 *nfnl;
	struct sock___63 *nfnl_stash;
	struct sk_buff_head___75 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___88 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___63 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___63 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___286 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___286 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___285;

struct lruvec___285 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___285 *zone;
};

struct pglist_data___285;

struct zone___285 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___285 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___285 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___285 {
	struct zone___285 *zone;
	int zone_idx;
};

struct zonelist___285 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___285 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___285 {
	struct zone___285 node_zones[4];
	struct zonelist___285 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___285 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___208;

struct x86_io_apic_ops___208 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___208 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___208;

struct irq_data___208 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___208 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___282;

struct dev_pm_ops___282 {
	int (*prepare)(struct device___282 *);
	void (*complete)(struct device___282 *);
	int (*suspend)(struct device___282 *);
	int (*resume)(struct device___282 *);
	int (*freeze)(struct device___282 *);
	int (*thaw)(struct device___282 *);
	int (*poweroff)(struct device___282 *);
	int (*restore)(struct device___282 *);
	int (*suspend_late)(struct device___282 *);
	int (*resume_early)(struct device___282 *);
	int (*freeze_late)(struct device___282 *);
	int (*thaw_early)(struct device___282 *);
	int (*poweroff_late)(struct device___282 *);
	int (*restore_early)(struct device___282 *);
	int (*suspend_noirq)(struct device___282 *);
	int (*resume_noirq)(struct device___282 *);
	int (*freeze_noirq)(struct device___282 *);
	int (*thaw_noirq)(struct device___282 *);
	int (*poweroff_noirq)(struct device___282 *);
	int (*restore_noirq)(struct device___282 *);
	int (*runtime_suspend)(struct device___282 *);
	int (*runtime_resume)(struct device___282 *);
	int (*runtime_idle)(struct device___282 *);
};

struct dev_pm_qos___85;

struct dev_pm_info___85 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___85 *qos;
};

struct dma_map_ops___147;

struct dev_archdata___147 {
	struct dma_map_ops___147 *dma_ops;
	void *iommu;
};

struct device_type___282;

struct bus_type___282;

struct device_driver___282;

struct dev_pm_domain___282;

struct class___282;

struct attribute_group___244;

struct device_rh___282;

struct device___282 {
	struct device___282 *parent;
	struct device_private *p;
	struct kobject___66 kobj;
	const char *init_name;
	const struct device_type___282 *type;
	struct mutex___286 mutex;
	struct bus_type___282 *bus;
	struct device_driver___282 *driver;
	void *platform_data;
	struct dev_pm_info___85 power;
	struct dev_pm_domain___282 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___147 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___282 *class;
	const struct attribute_group___244 **groups;
	void (*release)(struct device___282 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___282 *device_rh;
};

struct dev_pm_qos_request___86;

struct dev_pm_qos___85 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___86 *latency_req;
	struct dev_pm_qos_request___86 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___86 *latency_tolerance_req;
};

struct dev_pm_info_rh___282 {
	void (*set_latency_tolerance)(struct device___282 *, s32);
};

struct dev_pm_domain___282 {
	struct dev_pm_ops___282 ops;
};

struct smp_ops___285 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___285 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___63 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___63 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___246;

struct attribute_group___244 {
	const char *name;
	umode_t (*is_visible)(struct kobject___66 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___246 **bin_attrs;
};

struct bin_attribute___246 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___284 *, struct kobject___66 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___284 *, struct kobject___66 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	int (*mmap)(struct file___284 *, struct kobject___66 *, struct bin_attribute___246 *, struct vm_area_struct___292 *);
};

struct sysfs_ops___66 {
	ssize_t (*show)(struct kobject___66 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___66 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___66 *, const struct attribute *);
};

struct kset_uevent_ops___66;

struct kset___66 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___66 kobj;
	const struct kset_uevent_ops___66 *uevent_ops;
};

struct kobj_type___66 {
	void (*release)(struct kobject___66 *);
	const struct sysfs_ops___66 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___63 * (*child_ns_type)(struct kobject___66 *);
	const void * (*namespace)(struct kobject___66 *);
};

struct kset_uevent_ops___66 {
	int (* const filter)(struct kset___66 *, struct kobject___66 *);
	const char * (* const name)(struct kset___66 *, struct kobject___66 *);
	int (* const uevent)(struct kset___66 *, struct kobject___66 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___266 {
	void **freelist;
	long unsigned int tid;
	struct page___283 *page;
	struct page___283 *partial;
};

struct memcg_cache_params___267 {
	bool is_root_cache;
	union {
		struct kmem_cache___267 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___267 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___147 {
	void * (*alloc)(struct device___282 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___282 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___282 *, struct vm_area_struct___292 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___282 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___282 *, struct page___283 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___282 *, dma_addr_t);
	int (*dma_supported)(struct device___282 *, u64);
	int (*set_dma_mask)(struct device___282 *, u64);
	int is_phys;
};

struct bus_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___282 *, char *);
	ssize_t (*store)(struct bus_type___282 *, const char *, size_t);
};

struct device_attribute___282;

struct driver_attribute___282;

struct bus_type___282 {
	const char *name;
	const char *dev_name;
	struct device___282 *dev_root;
	struct bus_attribute___282 *bus_attrs;
	struct device_attribute___282 *dev_attrs;
	struct driver_attribute___282 *drv_attrs;
	const struct attribute_group___244 **bus_groups;
	const struct attribute_group___244 **dev_groups;
	const struct attribute_group___244 **drv_groups;
	int (*match)(struct device___282 *, struct device_driver___282 *);
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	int (*probe)(struct device___282 *);
	int (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*online)(struct device___282 *);
	int (*offline)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct device___282 *, struct device_attribute___282 *, char *);
	ssize_t (*store)(struct device___282 *, struct device_attribute___282 *, const char *, size_t);
};

struct driver_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___282 *, char *);
	ssize_t (*store)(struct device_driver___282 *, const char *, size_t);
};

struct device_driver___282 {
	const char *name;
	struct bus_type___282 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___282 *);
	int (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	const struct attribute_group___244 **groups;
	const struct dev_pm_ops___282 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___282 {
	const char *name;
	const struct attribute_group___244 **groups;
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
};

struct class_attribute___282;

struct class___282 {
	const char *name;
	struct module *owner;
	struct class_attribute___282 *class_attrs;
	struct device_attribute___282 *dev_attrs;
	const struct attribute_group___244 **dev_groups;
	struct bin_attribute___246 *dev_bin_attrs;
	struct kobject___66 *dev_kobj;
	int (*dev_uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *);
	void (*class_release)(struct class___282 *);
	void (*dev_release)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	const struct kobj_ns_type_operations___63 *ns_type;
	const void * (*namespace)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
	struct subsys_private *p;
};

struct class_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct class___282 *, struct class_attribute___282 *, char *);
	ssize_t (*store)(struct class___282 *, struct class_attribute___282 *, const char *, size_t);
	const void * (*namespace)(struct class___282 *, const struct class_attribute___282 *);
};

struct device_rh___282 {
	struct dev_pm_info_rh___282 power;
};

struct vm_fault___254 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___283 *page;
};

struct ctl_node___89 {
	struct rb_node node;
	struct ctl_table_header___89 *header;
};

struct ctl_table_root___89 {
	struct ctl_table_set___89 default_set;
	struct ctl_table_set___89 * (*lookup)(struct ctl_table_root___89 *, struct nsproxy___164 *);
	int (*permissions)(struct ctl_table_header___89 *, struct ctl_table *);
};

struct nsproxy___164 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___88 *net_ns;
};

struct signal_struct___285 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___285 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___285 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___286 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___179;

struct css_set___179 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___179 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___74 {
	atomic_t use;
	unsigned int mask;
	struct net_device___74 *physindev;
	struct net_device___74 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___74(struct sk_buff___76 **);

struct net_device_ops___74;

struct ethtool_ops___74;

struct header_ops___74;

struct in_device___12;

struct inet6_dev___40;

struct netdev_rx_queue___74;

struct netdev_queue___74;

struct rtnl_link_ops___65;

struct dcbnl_rtnl_ops___74;

struct net_device___74 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___74 *netdev_ops;
	const struct ethtool_ops___74 *ethtool_ops;
	const struct header_ops___74 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___66 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___12 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___40 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___74 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___74 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___74 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___74 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___74 = 0,
		NETREG_REGISTERED___74 = 1,
		NETREG_UNREGISTERING___74 = 2,
		NETREG_UNREGISTERED___74 = 3,
		NETREG_RELEASED___74 = 4,
		NETREG_DUMMY___74 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___74 = 0,
		RTNL_LINK_INITIALIZING___74 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___74 *);
	struct netpoll_info *npinfo;
	struct net___88 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___282 dev;
	const struct attribute_group___244 *sysfs_groups[4];
	const struct rtnl_link_ops___65 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___74 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___17;

struct sk_buff___76 {
	struct sk_buff___76 *next;
	struct sk_buff___76 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___63 *sk;
	struct net_device___74 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___17 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___76 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___74 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___20 {
	struct {
		struct page___283 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___20 skb_frag_t___20;

struct skb_shared_info___20 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___76 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___20 frags[17];
};

struct xfrm_state___17;

struct sec_path___17 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___17 *xvec[6];
};

struct file_lock___284;

struct seq_file___209;

struct file_operations___284 {
	struct module *owner;
	loff_t (*llseek)(struct file___284 *, loff_t, int);
	ssize_t (*read)(struct file___284 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___284 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___71 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___71 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___284 *, void *, filldir_t);
	unsigned int (*poll)(struct file___284 *, struct poll_table_struct___170 *);
	long int (*unlocked_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___284 *, struct vm_area_struct___292 *);
	int (*open)(struct inode___284 *, struct file___284 *);
	int (*flush)(struct file___284 *, fl_owner_t);
	int (*release)(struct inode___284 *, struct file___284 *);
	int (*fsync)(struct file___284 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___71 *, int);
	int (*fasync)(int, struct file___284 *, int);
	int (*lock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*sendpage)(struct file___284 *, struct page___283 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___284 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___284 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___284 *, long int, struct file_lock___284 **, void **);
		struct {
			int (*setlease)(struct file___284 *, long int, struct file_lock___284 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___284 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___209 *, struct file___284 *);
};

struct dev_pm_qos_request___86 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___282 *dev;
};

struct dentry_operations___284;

struct super_block___284;

struct dentry___284 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___284 *d_parent;
	struct qstr d_name;
	struct inode___284 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___284 *d_op;
	struct super_block___284 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___284;

struct dquot___284;

struct block_device___284;

struct inode___284 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___284 *i_op;
	struct super_block___284 *i_sb;
	struct address_space___284 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___286 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___284 *i_fop;
	struct file_lock___284 *i_flock;
	struct address_space___284 i_data;
	struct dquot___284 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___284 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___284 {
	int (*d_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_hash)(const struct dentry___284 *, struct qstr *);
	int (*d_compare)(const struct dentry___284 *, const struct dentry___284 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___284 *);
	void (*d_release)(struct dentry___284 *);
	void (*d_prune)(struct dentry___284 *);
	void (*d_iput)(struct dentry___284 *, struct inode___284 *);
	char * (*d_dname)(struct dentry___284 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___284 *);
	int (*d_manage)(struct dentry___284 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___284;

struct mem_dqinfo___284 {
	struct quota_format_type___284 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___284;

struct quota_info___284 {
	unsigned int flags;
	struct mutex___286 dqio_mutex;
	struct mutex___286 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___284 *files[2];
	struct mem_dqinfo___284 info[2];
	const struct quota_format_ops___284 *ops[2];
};

struct file_system_type___284;

struct super_operations___284;

struct dquot_operations___284;

struct quotactl_ops___284;

struct xattr_handler___180;

struct super_block___284 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___284 *s_type;
	const struct super_operations___284 *s_op;
	const struct dquot_operations___284 *dq_op;
	const struct quotactl_ops___284 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___284 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___180 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___284 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___284 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___286 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___284 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___284 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___284 *bd_inode;
	struct super_block___284 *bd_super;
	struct mutex___286 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___284 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___286 bd_fsfreeze_mutex;
};

struct cgroup___179;

struct cgroup_subsys_state___179 {
	struct cgroup___179 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___284 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___284 *ia_file;
};

struct dquot___284 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___286 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___284 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___284 {
	int qf_fmt_id;
	const struct quota_format_ops___284 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___284 *qf_next;
};

struct quota_format_ops___284 {
	int (*check_quota_file)(struct super_block___284 *, int);
	int (*read_file_info)(struct super_block___284 *, int);
	int (*write_file_info)(struct super_block___284 *, int);
	int (*free_file_info)(struct super_block___284 *, int);
	int (*read_dqblk)(struct dquot___284 *);
	int (*commit_dqblk)(struct dquot___284 *);
	int (*release_dqblk)(struct dquot___284 *);
};

struct dquot_operations___284 {
	int (*write_dquot)(struct dquot___284 *);
	struct dquot___284 * (*alloc_dquot)(struct super_block___284 *, int);
	void (*destroy_dquot)(struct dquot___284 *);
	int (*acquire_dquot)(struct dquot___284 *);
	int (*release_dquot)(struct dquot___284 *);
	int (*mark_dirty)(struct dquot___284 *);
	int (*write_info)(struct super_block___284 *, int);
	qsize_t * (*get_reserved_space)(struct inode___284 *);
};

struct quotactl_ops___284 {
	int (*quota_on)(struct super_block___284 *, int, int, struct path___284 *);
	int (*quota_on_meta)(struct super_block___284 *, int, int);
	int (*quota_off)(struct super_block___284 *, int);
	int (*quota_sync)(struct super_block___284 *, int);
	int (*get_info)(struct super_block___284 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___284 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___284 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___284 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___284 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___284 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___284 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___284 *, unsigned int);
};

struct address_space_operations___284 {
	int (*writepage)(struct page___283 *, struct writeback_control *);
	int (*readpage)(struct file___284 *, struct page___283 *);
	int (*writepages)(struct address_space___284 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___283 *);
	int (*readpages)(struct file___284 *, struct address_space___284 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___284 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___283 **, void **);
	int (*write_end)(struct file___284 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___283 *, void *);
	sector_t (*bmap)(struct address_space___284 *, sector_t);
	void (*invalidatepage)(struct page___283 *, long unsigned int);
	int (*releasepage)(struct page___283 *, gfp_t);
	void (*freepage)(struct page___283 *);
	ssize_t (*direct_IO)(int, struct kiocb___71 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___284 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___284 *, struct page___283 *, struct page___283 *, enum migrate_mode);
	int (*launder_page)(struct page___283 *);
	int (*is_partially_uptodate)(struct page___283 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___283 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___284 *, struct page___283 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___284 *, sector_t *);
	void (*swap_deactivate)(struct file___284 *);
	void (*invalidatepage_range)(struct page___283 *, unsigned int, unsigned int);
};

struct inode_operations___284 {
	struct dentry___284 * (*lookup)(struct inode___284 *, struct dentry___284 *, unsigned int);
	void * (*follow_link)(struct dentry___284 *, struct nameidata *);
	int (*permission)(struct inode___284 *, int);
	struct posix_acl * (*get_acl)(struct inode___284 *, int);
	int (*readlink)(struct dentry___284 *, char *, int);
	void (*put_link)(struct dentry___284 *, struct nameidata *, void *);
	int (*create)(struct inode___284 *, struct dentry___284 *, umode_t, bool);
	int (*link)(struct dentry___284 *, struct inode___284 *, struct dentry___284 *);
	int (*unlink)(struct inode___284 *, struct dentry___284 *);
	int (*symlink)(struct inode___284 *, struct dentry___284 *, const char *);
	int (*mkdir)(struct inode___284 *, struct dentry___284 *, umode_t);
	int (*rmdir)(struct inode___284 *, struct dentry___284 *);
	int (*mknod)(struct inode___284 *, struct dentry___284 *, umode_t, dev_t);
	int (*rename)(struct inode___284 *, struct dentry___284 *, struct inode___284 *, struct dentry___284 *);
	int (*setattr)(struct dentry___284 *, struct iattr___284 *);
	int (*getattr)(struct vfsmount *, struct dentry___284 *, struct kstat *);
	int (*setxattr)(struct dentry___284 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___284 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___284 *, char *, size_t);
	int (*removexattr)(struct dentry___284 *, const char *);
	int (*fiemap)(struct inode___284 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___284 *, struct timespec *, int);
	int (*atomic_open)(struct inode___284 *, struct dentry___284 *, struct file___284 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___284;

struct lock_manager_operations___284;

struct file_lock___284 {
	struct file_lock___284 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___284 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___284 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___284 *fl_ops;
	const struct lock_manager_operations___284 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___284 {
	void (*fl_copy_lock)(struct file_lock___284 *, struct file_lock___284 *);
	void (*fl_release_private)(struct file_lock___284 *);
};

struct lock_manager_operations___284 {
	int (*lm_compare_owner)(struct file_lock___284 *, struct file_lock___284 *);
	long unsigned int (*lm_owner_key)(struct file_lock___284 *);
	void (*lm_notify)(struct file_lock___284 *);
	int (*lm_grant)(struct file_lock___284 *, struct file_lock___284 *, int);
	void (*lm_break)(struct file_lock___284 *);
	int (*lm_change)(struct file_lock___284 **, int);
};

struct file_system_type___284 {
	const char *name;
	int fs_flags;
	struct dentry___284 * (*mount)(struct file_system_type___284 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___284 *);
	struct module *owner;
	struct file_system_type___284 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___284 {
	struct inode___284 * (*alloc_inode)(struct super_block___284 *);
	void (*destroy_inode)(struct inode___284 *);
	void (*dirty_inode)(struct inode___284 *, int);
	int (*write_inode)(struct inode___284 *, struct writeback_control *);
	int (*drop_inode)(struct inode___284 *);
	void (*evict_inode)(struct inode___284 *);
	void (*put_super)(struct super_block___284 *);
	int (*sync_fs)(struct super_block___284 *, int);
	int (*freeze_fs)(struct super_block___284 *);
	int (*unfreeze_fs)(struct super_block___284 *);
	int (*statfs)(struct dentry___284 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___284 *, int *, char *);
	void (*umount_begin)(struct super_block___284 *);
	int (*show_options)(struct seq_file___209 *, struct dentry___284 *);
	int (*show_devname)(struct seq_file___209 *, struct dentry___284 *);
	int (*show_path)(struct seq_file___209 *, struct dentry___284 *);
	int (*show_stats)(struct seq_file___209 *, struct dentry___284 *);
	ssize_t (*quota_read)(struct super_block___284 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___284 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___284 *);
	int (*bdev_try_to_free_page)(struct super_block___284 *, struct page___283 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___284 *);
	void (*free_cached_objects)(struct super_block___284 *, int);
};

struct xattr_handler___180 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___284 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___284 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___284 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___209;

struct seq_file___209 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___286 lock;
	const struct seq_operations___209 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___74 {
	int (*get_settings)(struct net_device___74 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___74 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___74 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___74 *);
	void (*get_regs)(struct net_device___74 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___74 *);
	void (*set_msglevel)(struct net_device___74 *, u32);
	int (*nway_reset)(struct net_device___74 *);
	u32 (*get_link)(struct net_device___74 *);
	int (*get_eeprom_len)(struct net_device___74 *);
	int (*get_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___74 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___74 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___74 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___74 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___74 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___74 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___74 *);
	void (*complete)(struct net_device___74 *);
	u32 (*get_priv_flags)(struct net_device___74 *);
	int (*set_priv_flags)(struct net_device___74 *, u32);
	int (*get_sset_count)(struct net_device___74 *, int);
	int (*get_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___74 *, struct ethtool_flash *);
	int (*reset)(struct net_device___74 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___74 *);
	int (*get_rxfh_indir)(struct net_device___74 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___74 *, const u32 *);
	void (*get_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___74 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___74 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___74 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___74 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___74 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___74 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___74 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___74 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___35;

struct dst_entry___64 {
	struct callback_head callback_head;
	struct dst_entry___64 *child;
	struct net_device___74 *dev;
	struct dst_ops___88 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___64 *path;
	struct dst_entry___64 *from;
	struct xfrm_state___17 *xfrm;
	int (*input)(struct sk_buff___76 *);
	union {
		int (*output)(struct sock___63 *, struct sk_buff___76 *);
		struct {
			int (*output)(struct sk_buff___76 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___64 *next;
		struct rtable___35 *rt_next;
		struct rt6_info___17 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___64;

struct neigh_parms___64;

struct neigh_ops___64;

struct neighbour___64 {
	struct neighbour___64 *next;
	struct neigh_table___64 *tbl;
	struct neigh_parms___64 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___75 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___64 *, struct sk_buff___76 *);
	const struct neigh_ops___64 *ops;
	struct callback_head rcu;
	struct net_device___74 *dev;
	u8 primary_key[0];
};

struct fib6_node___17;

struct rt6_info___17 {
	struct dst_entry___64 dst;
	struct fib6_table___17 *rt6i_table;
	struct fib6_node___17 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___40 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___17 {
	struct fib6_node___17 *parent;
	struct fib6_node___17 *left;
	struct fib6_node___17 *right;
	struct rt6_info___17 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___17 *rr_ptr;
};

struct fib6_table___17 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___17 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___88 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___76 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___76 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___88 *, struct dst_entry___64 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___76 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___76 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___208 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___208 *);
	void (*irq_shutdown)(struct irq_data___208 *);
	void (*irq_enable)(struct irq_data___208 *);
	void (*irq_disable)(struct irq_data___208 *);
	void (*irq_ack)(struct irq_data___208 *);
	void (*irq_mask)(struct irq_data___208 *);
	void (*irq_mask_ack)(struct irq_data___208 *);
	void (*irq_unmask)(struct irq_data___208 *);
	void (*irq_eoi)(struct irq_data___208 *);
	int (*irq_set_affinity)(struct irq_data___208 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___208 *);
	int (*irq_set_type)(struct irq_data___208 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___208 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___208 *);
	void (*irq_bus_sync_unlock)(struct irq_data___208 *);
	void (*irq_cpu_online)(struct irq_data___208 *);
	void (*irq_cpu_offline)(struct irq_data___208 *);
	void (*irq_suspend)(struct irq_data___208 *);
	void (*irq_resume)(struct irq_data___208 *);
	void (*irq_pm_shutdown)(struct irq_data___208 *);
	void (*irq_print_chip)(struct irq_data___208 *, struct seq_file___209 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___208 *, void *);
	long unsigned int flags;
};

struct seq_operations___209 {
	void * (*start)(struct seq_file___209 *, loff_t *);
	void (*stop)(struct seq_file___209 *, void *);
	void * (*next)(struct seq_file___209 *, void *, loff_t *);
	int (*show)(struct seq_file___209 *, void *);
};

struct dcbnl_rtnl_ops___74 {
	int (*ieee_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___74 *);
	u8 (*setstate)(struct net_device___74 *, u8);
	void (*getpermhwaddr)(struct net_device___74 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___74 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___74 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___74 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___74 *, int, u8 *);
	void (*setpfccfg)(struct net_device___74 *, int, u8);
	void (*getpfccfg)(struct net_device___74 *, int, u8 *);
	u8 (*setall)(struct net_device___74 *);
	u8 (*getcap)(struct net_device___74 *, int, u8 *);
	int (*getnumtcs)(struct net_device___74 *, int, u8 *);
	int (*setnumtcs)(struct net_device___74 *, int, u8);
	u8 (*getpfcstate)(struct net_device___74 *);
	void (*setpfcstate)(struct net_device___74 *, u8);
	void (*getbcncfg)(struct net_device___74 *, int, u32 *);
	void (*setbcncfg)(struct net_device___74 *, int, u32);
	void (*getbcnrp)(struct net_device___74 *, int, u8 *);
	void (*setbcnrp)(struct net_device___74 *, int, u8);
	u8 (*setapp)(struct net_device___74 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___74 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___74 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___74 *, int, u8);
	u8 (*getdcbx)(struct net_device___74 *);
	u8 (*setdcbx)(struct net_device___74 *, u8);
	int (*peer_getappinfo)(struct net_device___74 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___74 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___74 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___74 *, struct cee_pfc *);
};

struct cgroupfs_root___179;

struct cgroup___179 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___179 *parent;
	struct dentry___284 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___179 *subsys[11];
	struct cgroupfs_root___179 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___286 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___179 {
	struct super_block___284 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___179 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___115 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___284 *, struct file___284 *);
	ssize_t (*read)(struct cgroup___179 *, struct cftype___115 *, struct file___284 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___179 *, struct cftype___115 *);
	s64 (*read_s64)(struct cgroup___179 *, struct cftype___115 *);
	int (*read_map)(struct cgroup___179 *, struct cftype___115 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___179 *, struct cftype___115 *, struct seq_file___209 *);
	ssize_t (*write)(struct cgroup___179 *, struct cftype___115 *, struct file___284 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___179 *, struct cftype___115 *, u64);
	int (*write_s64)(struct cgroup___179 *, struct cftype___115 *, s64);
	int (*write_string)(struct cgroup___179 *, struct cftype___115 *, const char *);
	int (*trigger)(struct cgroup___179 *, unsigned int);
	int (*release)(struct inode___284 *, struct file___284 *);
	int (*register_event)(struct cgroup___179 *, struct cftype___115 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___179 *, struct cftype___115 *, struct eventfd_ctx *);
};

struct cftype_set___111 {
	struct list_head node;
	struct cftype___115 *cfts;
};

struct task_and_cgroup___111 {
	struct task_struct___285 *task;
	struct cgroup___179 *cgrp;
	struct css_set___179 *cg;
};

struct cgroup_taskset___111 {
	struct task_and_cgroup___111 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___179 *cur_cgrp;
};

struct cgroup_subsys___111 {
	struct cgroup_subsys_state___179 * (*css_alloc)(struct cgroup___179 *);
	int (*css_online)(struct cgroup___179 *);
	void (*css_offline)(struct cgroup___179 *);
	void (*css_free)(struct cgroup___179 *);
	int (*can_attach)(struct cgroup___179 *, struct cgroup_taskset___111 *);
	void (*cancel_attach)(struct cgroup___179 *, struct cgroup_taskset___111 *);
	void (*attach)(struct cgroup___179 *, struct cgroup_taskset___111 *);
	void (*fork)(struct task_struct___285 *);
	void (*exit)(struct cgroup___179 *, struct cgroup___179 *, struct task_struct___285 *);
	void (*bind)(struct cgroup___179 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___179 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___115 *base_cftypes;
	struct cftype_set___111 base_cftset;
	struct module *module;
};

struct request_sock_ops___49;

struct request_sock___50 {
	struct sock_common___63 __req_common;
	struct request_sock___50 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___49 *rsk_ops;
	struct sock___63 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___17;

struct xfrm_type___17;

struct xfrm_mode___17;

struct xfrm_state___17 {
	struct net___88 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___17 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___17 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___17 *type;
	struct xfrm_mode___17 *inner_mode;
	struct xfrm_mode___17 *inner_mode_iaf;
	struct xfrm_mode___17 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___17 {
	struct sk_buff_head___75 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___17 {
	struct net___88 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___17 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___76 {
	struct sk_buff___76 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___76 *, struct netlink_callback___76 *);
	int (*done)(struct netlink_callback___76 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___74 {
	int (*create)(struct sk_buff___76 *, struct net_device___74 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___76 *, unsigned char *);
	int (*rebuild)(struct sk_buff___76 *);
	int (*cache)(const struct neighbour___64 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___74 *, const unsigned char *);
};

struct napi_struct___74 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___74 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___74 *dev;
	struct sk_buff___76 *gro_list;
	struct sk_buff___76 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___74 {
	struct net_device___74 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___66 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___74 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___66 kobj;
	struct net_device___74 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___74 {
	int (*ndo_init)(struct net_device___74 *);
	void (*ndo_uninit)(struct net_device___74 *);
	int (*ndo_open)(struct net_device___74 *);
	int (*ndo_stop)(struct net_device___74 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___76 *, struct net_device___74 *);
	u16 (*ndo_select_queue)(struct net_device___74 *, struct sk_buff___76 *);
	void (*ndo_change_rx_flags)(struct net_device___74 *, int);
	void (*ndo_set_rx_mode)(struct net_device___74 *);
	int (*ndo_set_mac_address)(struct net_device___74 *, void *);
	int (*ndo_validate_addr)(struct net_device___74 *);
	int (*ndo_do_ioctl)(struct net_device___74 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___74 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___74 *, int);
	int (*ndo_neigh_setup)(struct net_device___74 *, struct neigh_parms___64 *);
	void (*ndo_tx_timeout)(struct net_device___74 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___74 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___74 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___74 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___74 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___74 *);
	int (*ndo_netpoll_setup)(struct net_device___74 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___74 *);
	int (*ndo_busy_poll)(struct napi_struct___74 *);
	int (*ndo_set_vf_mac)(struct net_device___74 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___74 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___74 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___74 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___74 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___74 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___74 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___74 *, int, struct sk_buff___76 *);
	int (*ndo_setup_tc)(struct net_device___74 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___74 *);
	int (*ndo_fcoe_disable)(struct net_device___74 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___74 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___74 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___74 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___74 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___74 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___74 *, const struct sk_buff___76 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___74 *, struct net_device___74 *);
	int (*ndo_del_slave)(struct net_device___74 *, struct net_device___74 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___64 *);
	void (*ndo_neigh_destroy)(struct neighbour___64 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___76 *, struct netlink_callback___76 *, struct net_device___74 *, int);
	int (*ndo_bridge_setlink)(struct net_device___74 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___76 *, u32, u32, struct net_device___74 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___74 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___74 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___74 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___74 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___74 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___74 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___76 *, struct net_device___74 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___74 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___74 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___74 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___64 {
	struct net___88 *net;
	struct net_device___74 *dev;
	struct neigh_parms___64 *next;
	int (*neigh_setup)(struct neighbour___64 *);
	void (*neigh_cleanup)(struct neighbour___64 *);
	struct neigh_table___64 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___12;

struct in_device___12 {
	struct net_device___74 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___12 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___64 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___40;

struct ifacaddr6___40;

struct inet6_dev___40 {
	struct net_device___74 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___40 *mc_list;
	struct ifmcaddr6___40 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___40 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___64 *nd_parms;
	struct inet6_dev___40 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___65 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___74 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___88 *, struct net_device___74 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___74 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___74 *, struct list_head *);
	size_t (*get_size)(const struct net_device___74 *);
	int (*fill_info)(struct sk_buff___76 *, const struct net_device___74 *);
	size_t (*get_xstats_size)(const struct net_device___74 *);
	int (*fill_xstats)(struct sk_buff___76 *, const struct net_device___74 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___88 * (*get_link_net)(const struct net_device___74 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___74 *, struct net_device___74 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___74 *, const struct net_device___74 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___76 *, const struct net_device___74 *, const struct net_device___74 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___64 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___76 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___64;

struct neigh_hash_table___64;

struct neigh_table___64 {
	struct neigh_table___64 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___74 *, __u32 *);
	int (*constructor)(struct neighbour___64 *);
	int (*pconstructor)(struct pneigh_entry___64 *);
	void (*pdestructor)(struct pneigh_entry___64 *);
	void (*proxy_redo)(struct sk_buff___76 *);
	char *id;
	struct neigh_parms___64 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___75 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___64 *nht;
	struct pneigh_entry___64 **phash_buckets;
};

struct neigh_ops___64 {
	int family;
	void (*solicit)(struct neighbour___64 *, struct sk_buff___76 *);
	void (*error_report)(struct neighbour___64 *, struct sk_buff___76 *);
	int (*output)(struct neighbour___64 *, struct sk_buff___76 *);
	int (*connected_output)(struct neighbour___64 *, struct sk_buff___76 *);
};

struct pneigh_entry___64 {
	struct pneigh_entry___64 *next;
	struct net___88 *net;
	struct net_device___74 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___64 {
	struct neighbour___64 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___35 {
	struct dst_entry___64 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___46;

struct proto___63 {
	void (*close)(struct sock___63 *, long int);
	int (*connect)(struct sock___63 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___63 *, int);
	struct sock___63 * (*accept)(struct sock___63 *, int, int *);
	int (*ioctl)(struct sock___63 *, int, long unsigned int);
	int (*init)(struct sock___63 *);
	void (*destroy)(struct sock___63 *);
	void (*shutdown)(struct sock___63 *, int);
	int (*setsockopt)(struct sock___63 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___63 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___63 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___63 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___63 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___71 *, struct sock___63 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___71 *, struct sock___63 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___63 *, struct page___283 *, int, size_t, int);
	int (*bind)(struct sock___63 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___63 *, struct sk_buff___76 *);
	void (*release_cb)(struct sock___63 *);
	void (*mtu_reduced)(struct sock___63 *);
	void (*hash)(struct sock___63 *);
	void (*unhash)(struct sock___63 *);
	void (*rehash)(struct sock___63 *);
	int (*get_port)(struct sock___63 *, short unsigned int);
	void (*clear_sk)(struct sock___63 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___63 *);
	void (*enter_memory_pressure)(struct sock___63 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___267 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___49 *rsk_prot;
	struct timewait_sock_ops___46 *twsk_prot;
	union {
		struct inet_hashinfo___15 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___111 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___63 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___63 {
	void (*enter_memory_pressure)(struct sock___63 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___49 {
	int family;
	int obj_size;
	struct kmem_cache___267 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___63 *, struct request_sock___50 *);
	void (*send_ack)(struct sock___63 *, struct sk_buff___76 *, struct request_sock___50 *);
	void (*send_reset)(struct sock___63 *, struct sk_buff___76 *);
	void (*destructor)(struct request_sock___50 *);
	void (*syn_ack_timeout)(struct sock___63 *, struct request_sock___50 *);
};

struct timewait_sock_ops___46 {
	struct kmem_cache___267 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___63 *, struct sock___63 *, void *);
	void (*twsk_destructor)(struct sock___63 *);
};

struct in_ifaddr___12 {
	struct hlist_node hash;
	struct in_ifaddr___12 *ifa_next;
	struct in_device___12 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ifmcaddr6___40 {
	struct in6_addr mca_addr;
	struct inet6_dev___40 *idev;
	struct ifmcaddr6___40 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___40 {
	struct in6_addr aca_addr;
	struct inet6_dev___40 *aca_idev;
	struct rt6_info___17 *aca_rt;
	struct ifacaddr6___40 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct xfrm_replay___17 {
	void (*advance)(struct xfrm_state___17 *, __be32);
	int (*check)(struct xfrm_state___17 *, struct sk_buff___76 *, __be32);
	int (*recheck)(struct xfrm_state___17 *, struct sk_buff___76 *, __be32);
	void (*notify)(struct xfrm_state___17 *, int);
	int (*overflow)(struct xfrm_state___17 *, struct sk_buff___76 *);
};

struct xfrm_type___17 {
	char *description;
	struct module *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___17 *);
	void (*destructor)(struct xfrm_state___17 *);
	int (*input)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*output)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*reject)(struct xfrm_state___17 *, struct sk_buff___76 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___17 *, struct sk_buff___76 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___17 *, int);
};

struct xfrm_state_afinfo___17;

struct xfrm_mode___17 {
	int (*input2)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*input)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*output2)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*output)(struct xfrm_state___17 *, struct sk_buff___76 *);
	struct xfrm_state_afinfo___17 *afinfo;
	struct module *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___17 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module *owner;
	const struct xfrm_type___17 *type_map[256];
	struct xfrm_mode___17 *mode_map[5];
	int (*init_flags)(struct xfrm_state___17 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___17 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___17 **, struct xfrm_state___17 **, int);
	union {
		int (*output)(struct sock___63 *, struct sk_buff___76 *);
		struct {
			int (*output)(struct sk_buff___76 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___63 *, struct sk_buff___76 *);
		struct {
			int (*output_finish)(struct sk_buff___76 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*extract_output)(struct xfrm_state___17 *, struct sk_buff___76 *);
	int (*transport_finish)(struct sk_buff___76 *, int);
};

struct napi_gro_cb___5 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___76 *last;
};

struct offload_callbacks___6 {
	struct sk_buff___76 * (*gso_segment)(struct sk_buff___76 *, netdev_features_t);
	struct sk_buff___76 ** (*gro_receive)(struct sk_buff___76 **, struct sk_buff___76 *);
	int (*gro_complete)(struct sk_buff___76 *, int);
};

struct packet_offload___4 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___6 callbacks;
	struct list_head list;
};

struct net_offload___4 {
	struct offload_callbacks___6 callbacks;
	unsigned int flags;
};

struct gre_base_hdr {
	__be16 flags;
	__be16 protocol;
};

struct page___284;

typedef struct page___284 *pgtable_t___284;

struct address_space___285;

struct kmem_cache___268;

struct page___284 {
	long unsigned int flags;
	struct address_space___285 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___284 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___284 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___268 *slab_cache;
		struct page___284 *first_page;
	};
	long: 64;
};

struct task_struct___286;

struct pv_cpu_ops___286 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___286 *);
	void (*end_context_switch)(struct task_struct___286 *);
};

struct mutex___287 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___286 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___279 {
	struct page___284 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___293;

struct nsproxy___165;

struct signal_struct___286;

struct css_set___180;

struct task_struct___286 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___286 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___293 *mm;
	struct mm_struct___293 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___286 *real_parent;
	struct task_struct___286 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___286 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___286 = 0,
		VTIME_USER___286 = 1,
		VTIME_SYS___286 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___165 *nsproxy;
	struct signal_struct___286 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___180 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___287 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___279 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___293 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___293 *, struct mm_struct___293 *);
	void (*dup_mmap)(struct mm_struct___293 *, struct mm_struct___293 *);
	void (*exit_mmap)(struct mm_struct___293 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___293 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___293 *);
	void (*pgd_free)(struct mm_struct___293 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___293 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___293 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___293 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___293 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___293 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___293 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___293 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___293 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___293 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___293 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___293 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___287 lock;
	void *vdso;
} mm_context_t___287;

struct xol_area___284;

struct uprobes_state___284 {
	struct xol_area___284 *xol_area;
};

struct vm_area_struct___293;

struct file___285;

struct core_state___286;

struct mm_struct___293 {
	struct vm_area_struct___293 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___293 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___293 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___287 context;
	long unsigned int flags;
	struct core_state___286 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___286 *owner;
	struct file___285 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___284 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___67;

struct kobj_type___67;

struct kobject___67 {
	const char *name;
	struct list_head entry;
	struct kobject___67 *parent;
	struct kset___67 *kset;
	struct kobj_type___67 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___178;

struct module_kobject___178 {
	struct kobject___67 kobj;
	struct module___178 *mod;
	struct kobject___67 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___178;

struct module___178 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___178 mkobj;
	struct module_attribute___178 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___67 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___286 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___286;

struct lruvec___286 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___286 *zone;
};

struct pglist_data___286;

struct zone___286 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___286 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___286 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___286 {
	struct zone___286 *zone;
	int zone_idx;
};

struct zonelist___286 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___286 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___286 {
	struct zone___286 node_zones[4];
	struct zonelist___286 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___286 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___209;

struct x86_io_apic_ops___209 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___209 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___209;

struct irq_data___209 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___209 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___283;

struct dev_pm_ops___283 {
	int (*prepare)(struct device___283 *);
	void (*complete)(struct device___283 *);
	int (*suspend)(struct device___283 *);
	int (*resume)(struct device___283 *);
	int (*freeze)(struct device___283 *);
	int (*thaw)(struct device___283 *);
	int (*poweroff)(struct device___283 *);
	int (*restore)(struct device___283 *);
	int (*suspend_late)(struct device___283 *);
	int (*resume_early)(struct device___283 *);
	int (*freeze_late)(struct device___283 *);
	int (*thaw_early)(struct device___283 *);
	int (*poweroff_late)(struct device___283 *);
	int (*restore_early)(struct device___283 *);
	int (*suspend_noirq)(struct device___283 *);
	int (*resume_noirq)(struct device___283 *);
	int (*freeze_noirq)(struct device___283 *);
	int (*thaw_noirq)(struct device___283 *);
	int (*poweroff_noirq)(struct device___283 *);
	int (*restore_noirq)(struct device___283 *);
	int (*runtime_suspend)(struct device___283 *);
	int (*runtime_resume)(struct device___283 *);
	int (*runtime_idle)(struct device___283 *);
};

struct dev_pm_qos___86;

struct dev_pm_info___86 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___86 *qos;
};

struct dma_map_ops___148;

struct dev_archdata___148 {
	struct dma_map_ops___148 *dma_ops;
	void *iommu;
};

struct device_type___283;

struct bus_type___283;

struct device_driver___283;

struct dev_pm_domain___283;

struct class___283;

struct attribute_group___245;

struct device_rh___283;

struct device___283 {
	struct device___283 *parent;
	struct device_private *p;
	struct kobject___67 kobj;
	const char *init_name;
	const struct device_type___283 *type;
	struct mutex___287 mutex;
	struct bus_type___283 *bus;
	struct device_driver___283 *driver;
	void *platform_data;
	struct dev_pm_info___86 power;
	struct dev_pm_domain___283 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___148 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___283 *class;
	const struct attribute_group___245 **groups;
	void (*release)(struct device___283 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___283 *device_rh;
};

struct dev_pm_qos_request___87;

struct dev_pm_qos___86 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___87 *latency_req;
	struct dev_pm_qos_request___87 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___87 *latency_tolerance_req;
};

struct dev_pm_info_rh___283 {
	void (*set_latency_tolerance)(struct device___283 *, s32);
};

struct dev_pm_domain___283 {
	struct dev_pm_ops___283 ops;
};

struct smp_ops___286 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___286 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct xol_area___284 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___284 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___267;

struct memcg_cache_params___268;

struct kmem_cache___268 {
	struct kmem_cache_cpu___267 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___67 kobj;
	struct memcg_cache_params___268 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___285;

struct address_space_operations___285;

struct address_space___285 {
	struct inode___285 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___287 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___285 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___285;

struct path___285 {
	struct vfsmount *mnt;
	struct dentry___285 *dentry;
};

struct file_operations___285;

struct file___285 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___285 f_path;
	struct inode___285 *f_inode;
	const struct file_operations___285 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___285 *f_mapping;
	struct mutex___287 f_pos_lock;
};

struct vm_operations_struct___259;

struct vm_area_struct___293 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___293 *vm_next;
	struct vm_area_struct___293 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___293 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___259 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___285 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___255;

struct vm_operations_struct___259 {
	void (*open)(struct vm_area_struct___293 *);
	void (*close)(struct vm_area_struct___293 *);
	int (*fault)(struct vm_area_struct___293 *, struct vm_fault___255 *);
	int (*page_mkwrite)(struct vm_area_struct___293 *, struct vm_fault___255 *);
	int (*access)(struct vm_area_struct___293 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___293 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___293 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___293 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___293 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___286 {
	struct task_struct___286 *task;
	struct core_thread___286 *next;
};

struct core_state___286 {
	atomic_t nr_threads;
	struct core_thread___286 dumper;
	struct completion startup;
};

struct vm_fault___255 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___284 *page;
};

struct ctl_table_header___90;

struct ctl_node___90 {
	struct rb_node node;
	struct ctl_table_header___90 *header;
};

struct ctl_table_root___90;

struct ctl_table_set___90;

struct ctl_dir___90;

struct ctl_table_header___90 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___90 *root;
	struct ctl_table_set___90 *set;
	struct ctl_dir___90 *parent;
	struct ctl_node___90 *node;
};

struct ctl_dir___90 {
	struct ctl_table_header___90 header;
	struct rb_root root;
};

struct ctl_table_set___90 {
	int (*is_seen)(struct ctl_table_set___90 *);
	struct ctl_dir___90 dir;
};

struct ctl_table_root___90 {
	struct ctl_table_set___90 default_set;
	struct ctl_table_set___90 * (*lookup)(struct ctl_table_root___90 *, struct nsproxy___165 *);
	int (*permissions)(struct ctl_table_header___90 *, struct ctl_table *);
};

struct net___89;

struct nsproxy___165 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___89 *net_ns;
};

struct sock___64;

struct kobj_ns_type_operations___64 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___64 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___64;

struct sock_common___64 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___64 *skc_prot;
	struct net___89 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___77;

struct sk_buff_head___76 {
	struct sk_buff___77 *next;
	struct sk_buff___77 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___65;

struct socket_wq___64;

struct dst_entry___65;

struct socket___65;

struct cg_proto___64;

struct sock___64 {
	struct sock_common___64 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___76 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___77 *head;
		struct sk_buff___77 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___65 *sk_filter;
	struct socket_wq___64 *sk_wq;
	struct sk_buff_head___76 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___65 *sk_rx_dst;
	struct dst_entry___65 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___76 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___76 sk_error_queue;
	struct proto___64 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___65 *sk_socket;
	void *sk_user_data;
	struct page_frag___279 sk_frag;
	struct sk_buff___77 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___64 *sk_cgrp;
	void (*sk_state_change)(struct sock___64 *);
	void (*sk_data_ready)(struct sock___64 *, int);
	void (*sk_write_space)(struct sock___64 *);
	void (*sk_error_report)(struct sock___64 *);
	int (*sk_backlog_rcv)(struct sock___64 *, struct sk_buff___77 *);
	void (*sk_destruct)(struct sock___64 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___247;

struct attribute_group___245 {
	const char *name;
	umode_t (*is_visible)(struct kobject___67 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___247 **bin_attrs;
};

struct bin_attribute___247 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___285 *, struct kobject___67 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___285 *, struct kobject___67 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	int (*mmap)(struct file___285 *, struct kobject___67 *, struct bin_attribute___247 *, struct vm_area_struct___293 *);
};

struct sysfs_ops___67 {
	ssize_t (*show)(struct kobject___67 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___67 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___67 *, const struct attribute *);
};

struct kset_uevent_ops___67;

struct kset___67 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___67 kobj;
	const struct kset_uevent_ops___67 *uevent_ops;
};

struct kobj_type___67 {
	void (*release)(struct kobject___67 *);
	const struct sysfs_ops___67 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___64 * (*child_ns_type)(struct kobject___67 *);
	const void * (*namespace)(struct kobject___67 *);
};

struct kset_uevent_ops___67 {
	int (* const filter)(struct kset___67 *, struct kobject___67 *);
	const char * (* const name)(struct kset___67 *, struct kobject___67 *);
	int (* const uevent)(struct kset___67 *, struct kobject___67 *, struct kobj_uevent_env *);
};

struct module_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___178 *, struct module_kobject___178 *, char *);
	ssize_t (*store)(struct module_attribute___178 *, struct module_kobject___178 *, const char *, size_t);
	void (*setup)(struct module___178 *, const char *);
	int (*test)(struct module___178 *);
	void (*free)(struct module___178 *);
};

struct fasync_struct___285;

struct socket_wq___64 {
	wait_queue_head_t wait;
	struct fasync_struct___285 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___285 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___285 *fa_next;
	struct file___285 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___64;

struct socket___65 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___64 *wq;
	struct file___285 *file;
	struct sock___64 *sk;
	const struct proto_ops___64 *ops;
};

struct poll_table_struct___171;

struct kiocb___72;

struct proto_ops___64 {
	int family;
	struct module___178 *owner;
	int (*release)(struct socket___65 *);
	int (*bind)(struct socket___65 *, struct sockaddr *, int);
	int (*connect)(struct socket___65 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___65 *, struct socket___65 *);
	int (*accept)(struct socket___65 *, struct socket___65 *, int);
	int (*getname)(struct socket___65 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___285 *, struct socket___65 *, struct poll_table_struct___171 *);
	int (*ioctl)(struct socket___65 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___65 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___65 *, int);
	int (*shutdown)(struct socket___65 *, int);
	int (*setsockopt)(struct socket___65 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___65 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___65 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___65 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___72 *, struct socket___65 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___72 *, struct socket___65 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___285 *, struct socket___65 *, struct vm_area_struct___293 *);
	ssize_t (*sendpage)(struct socket___65 *, struct page___284 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___65 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___64 *, int);
		struct {
			void (*set_peek_off)(struct sock___64 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___173)(struct file___285 *, wait_queue_head_t *, struct poll_table_struct___171 *);

struct poll_table_struct___171 {
	poll_queue_proc___173 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___72(struct kiocb___72 *, struct io_event *);

struct kiocb___72 {
	atomic_t ki_users;
	struct file___285 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___72 *ki_cancel;
	void (*ki_dtor)(struct kiocb___72 *);
	union {
		void *user;
		struct task_struct___286 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___87 {
	struct ctl_table_header___90 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___88 {
	struct mutex___287 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___87 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___90 *ctl;
};

struct netns_ipv4___87 {
	struct ctl_table_header___90 *forw_hdr;
	struct ctl_table_header___90 *frags_hdr;
	struct ctl_table_header___90 *ipv4_hdr;
	struct ctl_table_header___90 *route_hdr;
	struct ctl_table_header___90 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___64 *fibnl;
	struct sock___64 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___87 {
	struct ctl_table_header___90 *hdr;
	struct ctl_table_header___90 *route_hdr;
	struct ctl_table_header___90 *icmp_hdr;
	struct ctl_table_header___90 *frags_hdr;
	struct ctl_table_header___90 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___75;

struct neighbour___65;

struct dst_ops___89 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___89 *);
	struct dst_entry___65 * (*check)(struct dst_entry___65 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___65 *);
	unsigned int (*mtu)(const struct dst_entry___65 *);
	u32 * (*cow_metrics)(struct dst_entry___65 *, long unsigned int);
	void (*destroy)(struct dst_entry___65 *);
	void (*ifdown)(struct dst_entry___65 *, struct net_device___75 *, int);
	struct dst_entry___65 * (*negative_advice)(struct dst_entry___65 *);
	void (*link_failure)(struct sk_buff___77 *);
	void (*update_pmtu)(struct dst_entry___65 *, struct sock___64 *, struct sk_buff___77 *, u32);
	void (*redirect)(struct dst_entry___65 *, struct sock___64 *, struct sk_buff___77 *);
	int (*local_out)(struct sk_buff___77 *);
	struct neighbour___65 * (*neigh_lookup)(const struct dst_entry___65 *, struct sk_buff___77 *, const void *);
	struct kmem_cache___268 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___89 {
	struct netns_sysctl_ipv6___87 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___89 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___64 **icmp_sk;
	struct sock___64 *ndisc_sk;
	struct sock___64 *tcp_sk;
	struct sock___64 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___87 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___90 *sysctl_header;
	struct sock___64 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___64 {
	struct sock___64 *v4_ctl_sk;
	struct sock___64 *v6_ctl_sk;
};

struct netns_nf___87 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___90 *nf_log_dir_header;
};

struct nf_proto_net___87 {
	struct ctl_table_header___90 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___87 {
	struct nf_proto_net___87 pn;
	unsigned int timeout;
};

struct nf_tcp_net___87 {
	struct nf_proto_net___87 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___87 {
	struct nf_proto_net___87 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___87 {
	struct nf_proto_net___87 pn;
	unsigned int timeout;
};

struct nf_ip_net___87 {
	struct nf_generic_net___87 generic;
	struct nf_tcp_net___87 tcp;
	struct nf_udp_net___87 udp;
	struct nf_icmp_net___87 icmp;
	struct nf_icmp_net___87 icmpv6;
};

struct netns_ct___88 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___90 *sysctl_header;
	struct ctl_table_header___90 *acct_sysctl_header;
	struct ctl_table_header___90 *tstamp_sysctl_header;
	struct ctl_table_header___90 *event_sysctl_header;
	struct ctl_table_header___90 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___268 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___87 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___87 {
	struct netns_sysctl_ipv6___87 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___89 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___64 *nlsk;
	struct sock___64 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___90 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___89 xfrm4_dst_ops;
	struct dst_ops___89 xfrm6_dst_ops;
};

struct net___89 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___90 sysctls;
	struct sock___64 *rtnl;
	struct sock___64 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___75 *loopback_dev;
	struct netns_core___87 core;
	struct netns_mib mib;
	struct netns_packet___88 packet;
	struct netns_unix___87 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___87 ipv4;
	struct netns_ipv6___89 ipv6;
	struct netns_sctp___87 sctp;
	struct netns_dccp___64 dccp;
	struct netns_nf___87 nf;
	struct netns_xt xt;
	struct netns_ct___88 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___87 nf_frag;
	struct sock___64 *nfnl;
	struct sock___64 *nfnl_stash;
	struct sk_buff_head___76 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___89 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___64 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___64 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___287 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___287 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___267 {
	void **freelist;
	long unsigned int tid;
	struct page___284 *page;
	struct page___284 *partial;
};

struct memcg_cache_params___268 {
	bool is_root_cache;
	union {
		struct kmem_cache___268 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___268 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___148 {
	void * (*alloc)(struct device___283 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___283 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___283 *, struct vm_area_struct___293 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___283 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___283 *, struct page___284 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___283 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___283 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___283 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___283 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___283 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___283 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___283 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___283 *, dma_addr_t);
	int (*dma_supported)(struct device___283 *, u64);
	int (*set_dma_mask)(struct device___283 *, u64);
	int is_phys;
};

struct bus_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___283 *, char *);
	ssize_t (*store)(struct bus_type___283 *, const char *, size_t);
};

struct device_attribute___283;

struct driver_attribute___283;

struct bus_type___283 {
	const char *name;
	const char *dev_name;
	struct device___283 *dev_root;
	struct bus_attribute___283 *bus_attrs;
	struct device_attribute___283 *dev_attrs;
	struct driver_attribute___283 *drv_attrs;
	const struct attribute_group___245 **bus_groups;
	const struct attribute_group___245 **dev_groups;
	const struct attribute_group___245 **drv_groups;
	int (*match)(struct device___283 *, struct device_driver___283 *);
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	int (*probe)(struct device___283 *);
	int (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*online)(struct device___283 *);
	int (*offline)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct device___283 *, struct device_attribute___283 *, char *);
	ssize_t (*store)(struct device___283 *, struct device_attribute___283 *, const char *, size_t);
};

struct driver_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___283 *, char *);
	ssize_t (*store)(struct device_driver___283 *, const char *, size_t);
};

struct device_driver___283 {
	const char *name;
	struct bus_type___283 *bus;
	struct module___178 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___283 *);
	int (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	const struct attribute_group___245 **groups;
	const struct dev_pm_ops___283 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___283 {
	const char *name;
	const struct attribute_group___245 **groups;
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
};

struct class_attribute___283;

struct class___283 {
	const char *name;
	struct module___178 *owner;
	struct class_attribute___283 *class_attrs;
	struct device_attribute___283 *dev_attrs;
	const struct attribute_group___245 **dev_groups;
	struct bin_attribute___247 *dev_bin_attrs;
	struct kobject___67 *dev_kobj;
	int (*dev_uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *);
	void (*class_release)(struct class___283 *);
	void (*dev_release)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	const struct kobj_ns_type_operations___64 *ns_type;
	const void * (*namespace)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
	struct subsys_private *p;
};

struct class_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct class___283 *, struct class_attribute___283 *, char *);
	ssize_t (*store)(struct class___283 *, struct class_attribute___283 *, const char *, size_t);
	const void * (*namespace)(struct class___283 *, const struct class_attribute___283 *);
};

struct device_rh___283 {
	struct dev_pm_info_rh___283 power;
};

struct signal_struct___286 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___286 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___286 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___287 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___180;

struct css_set___180 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___180 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___75 {
	atomic_t use;
	unsigned int mask;
	struct net_device___75 *physindev;
	struct net_device___75 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___75(struct sk_buff___77 **);

struct net_device_ops___75;

struct ethtool_ops___75;

struct header_ops___75;

struct in_device___13;

struct inet6_dev___41;

struct netdev_rx_queue___75;

struct netdev_queue___75;

struct rtnl_link_ops___66;

struct dcbnl_rtnl_ops___75;

struct net_device___75 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___75 *netdev_ops;
	const struct ethtool_ops___75 *ethtool_ops;
	const struct header_ops___75 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___67 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___13 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___41 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___75 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___75 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___75 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___75 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___75 = 0,
		NETREG_REGISTERED___75 = 1,
		NETREG_UNREGISTERING___75 = 2,
		NETREG_UNREGISTERED___75 = 3,
		NETREG_RELEASED___75 = 4,
		NETREG_DUMMY___75 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___75 = 0,
		RTNL_LINK_INITIALIZING___75 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___75 *);
	struct netpoll_info *npinfo;
	struct net___89 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___283 dev;
	const struct attribute_group___245 *sysfs_groups[4];
	const struct rtnl_link_ops___66 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___75 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___77 {
	struct sk_buff___77 *next;
	struct sk_buff___77 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___64 *sk;
	struct net_device___75 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___77 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___75 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ip_mc_list___5 {
	struct in_device___13 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___5 *next;
		struct ip_mc_list___5 *next_rcu;
	};
	struct timer_list timer;
	int users;
	atomic_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___13;

struct neigh_parms___65;

struct in_device___13 {
	struct net_device___75 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___13 *ifa_list;
	struct ip_mc_list___5 *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___5 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___65 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct file_lock___285;

struct seq_file___210;

struct file_operations___285 {
	struct module___178 *owner;
	loff_t (*llseek)(struct file___285 *, loff_t, int);
	ssize_t (*read)(struct file___285 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___285 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___72 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___72 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___285 *, void *, filldir_t);
	unsigned int (*poll)(struct file___285 *, struct poll_table_struct___171 *);
	long int (*unlocked_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___285 *, struct vm_area_struct___293 *);
	int (*open)(struct inode___285 *, struct file___285 *);
	int (*flush)(struct file___285 *, fl_owner_t);
	int (*release)(struct inode___285 *, struct file___285 *);
	int (*fsync)(struct file___285 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___72 *, int);
	int (*fasync)(int, struct file___285 *, int);
	int (*lock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*sendpage)(struct file___285 *, struct page___284 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___285 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___285 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___285 *, long int, struct file_lock___285 **, void **);
		struct {
			int (*setlease)(struct file___285 *, long int, struct file_lock___285 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___285 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___210 *, struct file___285 *);
};

struct dev_pm_qos_request___87 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___283 *dev;
};

struct dentry_operations___285;

struct super_block___285;

struct dentry___285 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___285 *d_parent;
	struct qstr d_name;
	struct inode___285 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___285 *d_op;
	struct super_block___285 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___285;

struct dquot___285;

struct block_device___285;

struct inode___285 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___285 *i_op;
	struct super_block___285 *i_sb;
	struct address_space___285 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___287 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___285 *i_fop;
	struct file_lock___285 *i_flock;
	struct address_space___285 i_data;
	struct dquot___285 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___285 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___285 {
	int (*d_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_hash)(const struct dentry___285 *, struct qstr *);
	int (*d_compare)(const struct dentry___285 *, const struct dentry___285 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___285 *);
	void (*d_release)(struct dentry___285 *);
	void (*d_prune)(struct dentry___285 *);
	void (*d_iput)(struct dentry___285 *, struct inode___285 *);
	char * (*d_dname)(struct dentry___285 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___285 *);
	int (*d_manage)(struct dentry___285 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___285;

struct mem_dqinfo___285 {
	struct quota_format_type___285 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___285;

struct quota_info___285 {
	unsigned int flags;
	struct mutex___287 dqio_mutex;
	struct mutex___287 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___285 *files[2];
	struct mem_dqinfo___285 info[2];
	const struct quota_format_ops___285 *ops[2];
};

struct file_system_type___285;

struct super_operations___285;

struct dquot_operations___285;

struct quotactl_ops___285;

struct xattr_handler___181;

struct super_block___285 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___285 *s_type;
	const struct super_operations___285 *s_op;
	const struct dquot_operations___285 *dq_op;
	const struct quotactl_ops___285 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___285 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___181 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___285 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___285 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___287 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___285 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___285 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___285 *bd_inode;
	struct super_block___285 *bd_super;
	struct mutex___287 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___285 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___287 bd_fsfreeze_mutex;
};

struct cgroup___180;

struct cgroup_subsys_state___180 {
	struct cgroup___180 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___285 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___285 *ia_file;
};

struct dquot___285 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___287 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___285 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___285 {
	int qf_fmt_id;
	const struct quota_format_ops___285 *qf_ops;
	struct module___178 *qf_owner;
	struct quota_format_type___285 *qf_next;
};

struct quota_format_ops___285 {
	int (*check_quota_file)(struct super_block___285 *, int);
	int (*read_file_info)(struct super_block___285 *, int);
	int (*write_file_info)(struct super_block___285 *, int);
	int (*free_file_info)(struct super_block___285 *, int);
	int (*read_dqblk)(struct dquot___285 *);
	int (*commit_dqblk)(struct dquot___285 *);
	int (*release_dqblk)(struct dquot___285 *);
};

struct dquot_operations___285 {
	int (*write_dquot)(struct dquot___285 *);
	struct dquot___285 * (*alloc_dquot)(struct super_block___285 *, int);
	void (*destroy_dquot)(struct dquot___285 *);
	int (*acquire_dquot)(struct dquot___285 *);
	int (*release_dquot)(struct dquot___285 *);
	int (*mark_dirty)(struct dquot___285 *);
	int (*write_info)(struct super_block___285 *, int);
	qsize_t * (*get_reserved_space)(struct inode___285 *);
};

struct quotactl_ops___285 {
	int (*quota_on)(struct super_block___285 *, int, int, struct path___285 *);
	int (*quota_on_meta)(struct super_block___285 *, int, int);
	int (*quota_off)(struct super_block___285 *, int);
	int (*quota_sync)(struct super_block___285 *, int);
	int (*get_info)(struct super_block___285 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___285 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___285 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___285 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___285 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___285 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___285 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___285 *, unsigned int);
};

struct swap_info_struct___49;

struct address_space_operations___285 {
	int (*writepage)(struct page___284 *, struct writeback_control *);
	int (*readpage)(struct file___285 *, struct page___284 *);
	int (*writepages)(struct address_space___285 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___284 *);
	int (*readpages)(struct file___285 *, struct address_space___285 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___285 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___284 **, void **);
	int (*write_end)(struct file___285 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___284 *, void *);
	sector_t (*bmap)(struct address_space___285 *, sector_t);
	void (*invalidatepage)(struct page___284 *, long unsigned int);
	int (*releasepage)(struct page___284 *, gfp_t);
	void (*freepage)(struct page___284 *);
	ssize_t (*direct_IO)(int, struct kiocb___72 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___285 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___285 *, struct page___284 *, struct page___284 *, enum migrate_mode);
	int (*launder_page)(struct page___284 *);
	int (*is_partially_uptodate)(struct page___284 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___284 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___285 *, struct page___284 *);
	int (*swap_activate)(struct swap_info_struct___49 *, struct file___285 *, sector_t *);
	void (*swap_deactivate)(struct file___285 *);
	void (*invalidatepage_range)(struct page___284 *, unsigned int, unsigned int);
};

struct swap_info_struct___49 {
	long unsigned int flags;
	short int prio;
	signed char type;
	signed char next;
	unsigned int max;
	unsigned char *swap_map;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int lowest_alloc;
	unsigned int highest_alloc;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___285 *bdev;
	struct file___285 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	struct plist_node list;
	struct plist_node avail_list;
};

struct inode_operations___285 {
	struct dentry___285 * (*lookup)(struct inode___285 *, struct dentry___285 *, unsigned int);
	void * (*follow_link)(struct dentry___285 *, struct nameidata *);
	int (*permission)(struct inode___285 *, int);
	struct posix_acl * (*get_acl)(struct inode___285 *, int);
	int (*readlink)(struct dentry___285 *, char *, int);
	void (*put_link)(struct dentry___285 *, struct nameidata *, void *);
	int (*create)(struct inode___285 *, struct dentry___285 *, umode_t, bool);
	int (*link)(struct dentry___285 *, struct inode___285 *, struct dentry___285 *);
	int (*unlink)(struct inode___285 *, struct dentry___285 *);
	int (*symlink)(struct inode___285 *, struct dentry___285 *, const char *);
	int (*mkdir)(struct inode___285 *, struct dentry___285 *, umode_t);
	int (*rmdir)(struct inode___285 *, struct dentry___285 *);
	int (*mknod)(struct inode___285 *, struct dentry___285 *, umode_t, dev_t);
	int (*rename)(struct inode___285 *, struct dentry___285 *, struct inode___285 *, struct dentry___285 *);
	int (*setattr)(struct dentry___285 *, struct iattr___285 *);
	int (*getattr)(struct vfsmount *, struct dentry___285 *, struct kstat *);
	int (*setxattr)(struct dentry___285 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___285 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___285 *, char *, size_t);
	int (*removexattr)(struct dentry___285 *, const char *);
	int (*fiemap)(struct inode___285 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___285 *, struct timespec *, int);
	int (*atomic_open)(struct inode___285 *, struct dentry___285 *, struct file___285 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___285;

struct lock_manager_operations___285;

struct file_lock___285 {
	struct file_lock___285 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___285 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___285 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___285 *fl_ops;
	const struct lock_manager_operations___285 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___285 {
	void (*fl_copy_lock)(struct file_lock___285 *, struct file_lock___285 *);
	void (*fl_release_private)(struct file_lock___285 *);
};

struct lock_manager_operations___285 {
	int (*lm_compare_owner)(struct file_lock___285 *, struct file_lock___285 *);
	long unsigned int (*lm_owner_key)(struct file_lock___285 *);
	void (*lm_notify)(struct file_lock___285 *);
	int (*lm_grant)(struct file_lock___285 *, struct file_lock___285 *, int);
	void (*lm_break)(struct file_lock___285 *);
	int (*lm_change)(struct file_lock___285 **, int);
};

struct file_system_type___285 {
	const char *name;
	int fs_flags;
	struct dentry___285 * (*mount)(struct file_system_type___285 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___285 *);
	struct module___178 *owner;
	struct file_system_type___285 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___285 {
	struct inode___285 * (*alloc_inode)(struct super_block___285 *);
	void (*destroy_inode)(struct inode___285 *);
	void (*dirty_inode)(struct inode___285 *, int);
	int (*write_inode)(struct inode___285 *, struct writeback_control *);
	int (*drop_inode)(struct inode___285 *);
	void (*evict_inode)(struct inode___285 *);
	void (*put_super)(struct super_block___285 *);
	int (*sync_fs)(struct super_block___285 *, int);
	int (*freeze_fs)(struct super_block___285 *);
	int (*unfreeze_fs)(struct super_block___285 *);
	int (*statfs)(struct dentry___285 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___285 *, int *, char *);
	void (*umount_begin)(struct super_block___285 *);
	int (*show_options)(struct seq_file___210 *, struct dentry___285 *);
	int (*show_devname)(struct seq_file___210 *, struct dentry___285 *);
	int (*show_path)(struct seq_file___210 *, struct dentry___285 *);
	int (*show_stats)(struct seq_file___210 *, struct dentry___285 *);
	ssize_t (*quota_read)(struct super_block___285 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___285 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___285 *);
	int (*bdev_try_to_free_page)(struct super_block___285 *, struct page___284 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___285 *);
	void (*free_cached_objects)(struct super_block___285 *, int);
};

struct xattr_handler___181 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___285 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___285 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___285 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___210;

struct seq_file___210 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___287 lock;
	const struct seq_operations___210 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___75 {
	int (*get_settings)(struct net_device___75 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___75 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___75 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___75 *);
	void (*get_regs)(struct net_device___75 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___75 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___75 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___75 *);
	void (*set_msglevel)(struct net_device___75 *, u32);
	int (*nway_reset)(struct net_device___75 *);
	u32 (*get_link)(struct net_device___75 *);
	int (*get_eeprom_len)(struct net_device___75 *);
	int (*get_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___75 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___75 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___75 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___75 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___75 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___75 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___75 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___75 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___75 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___75 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___75 *);
	void (*complete)(struct net_device___75 *);
	u32 (*get_priv_flags)(struct net_device___75 *);
	int (*set_priv_flags)(struct net_device___75 *, u32);
	int (*get_sset_count)(struct net_device___75 *, int);
	int (*get_rxnfc)(struct net_device___75 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___75 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___75 *, struct ethtool_flash *);
	int (*reset)(struct net_device___75 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___75 *);
	int (*get_rxfh_indir)(struct net_device___75 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___75 *, const u32 *);
	void (*get_channels)(struct net_device___75 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___75 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___75 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___75 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___75 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___75 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___75 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___75 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___75 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___75 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___75 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___75 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___36;

struct dst_entry___65 {
	struct callback_head callback_head;
	struct dst_entry___65 *child;
	struct net_device___75 *dev;
	struct dst_ops___89 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___65 *path;
	struct dst_entry___65 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___77 *);
	union {
		int (*output)(struct sock___64 *, struct sk_buff___77 *);
		struct {
			int (*output)(struct sk_buff___77 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___65 *next;
		struct rtable___36 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___65;

struct neigh_ops___65;

struct neighbour___65 {
	struct neighbour___65 *next;
	struct neigh_table___65 *tbl;
	struct neigh_parms___65 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___76 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___65 *, struct sk_buff___77 *);
	const struct neigh_ops___65 *ops;
	struct callback_head rcu;
	struct net_device___75 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___89 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___77 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___77 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___89 *, struct dst_entry___65 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___77 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___77 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___209 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___209 *);
	void (*irq_shutdown)(struct irq_data___209 *);
	void (*irq_enable)(struct irq_data___209 *);
	void (*irq_disable)(struct irq_data___209 *);
	void (*irq_ack)(struct irq_data___209 *);
	void (*irq_mask)(struct irq_data___209 *);
	void (*irq_mask_ack)(struct irq_data___209 *);
	void (*irq_unmask)(struct irq_data___209 *);
	void (*irq_eoi)(struct irq_data___209 *);
	int (*irq_set_affinity)(struct irq_data___209 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___209 *);
	int (*irq_set_type)(struct irq_data___209 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___209 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___209 *);
	void (*irq_bus_sync_unlock)(struct irq_data___209 *);
	void (*irq_cpu_online)(struct irq_data___209 *);
	void (*irq_cpu_offline)(struct irq_data___209 *);
	void (*irq_suspend)(struct irq_data___209 *);
	void (*irq_resume)(struct irq_data___209 *);
	void (*irq_pm_shutdown)(struct irq_data___209 *);
	void (*irq_print_chip)(struct irq_data___209 *, struct seq_file___210 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___209 *, void *);
	long unsigned int flags;
};

struct seq_operations___210 {
	void * (*start)(struct seq_file___210 *, loff_t *);
	void (*stop)(struct seq_file___210 *, void *);
	void * (*next)(struct seq_file___210 *, void *, loff_t *);
	int (*show)(struct seq_file___210 *, void *);
};

struct pernet_operations___24 {
	struct list_head list;
	int (*init)(struct net___89 *);
	void (*exit)(struct net___89 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___75 {
	int (*ieee_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___75 *);
	u8 (*setstate)(struct net_device___75 *, u8);
	void (*getpermhwaddr)(struct net_device___75 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___75 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___75 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___75 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___75 *, int, u8 *);
	void (*setpfccfg)(struct net_device___75 *, int, u8);
	void (*getpfccfg)(struct net_device___75 *, int, u8 *);
	u8 (*setall)(struct net_device___75 *);
	u8 (*getcap)(struct net_device___75 *, int, u8 *);
	int (*getnumtcs)(struct net_device___75 *, int, u8 *);
	int (*setnumtcs)(struct net_device___75 *, int, u8);
	u8 (*getpfcstate)(struct net_device___75 *);
	void (*setpfcstate)(struct net_device___75 *, u8);
	void (*getbcncfg)(struct net_device___75 *, int, u32 *);
	void (*setbcncfg)(struct net_device___75 *, int, u32);
	void (*getbcnrp)(struct net_device___75 *, int, u8 *);
	void (*setbcnrp)(struct net_device___75 *, int, u8);
	u8 (*setapp)(struct net_device___75 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___75 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___75 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___75 *, int, u8);
	u8 (*getdcbx)(struct net_device___75 *);
	u8 (*setdcbx)(struct net_device___75 *, u8);
	int (*peer_getappinfo)(struct net_device___75 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___75 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___75 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___75 *, struct cee_pfc *);
};

struct cgroupfs_root___180;

struct cgroup___180 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___180 *parent;
	struct dentry___285 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___180 *subsys[11];
	struct cgroupfs_root___180 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___287 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___180 {
	struct super_block___285 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___180 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___116 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___285 *, struct file___285 *);
	ssize_t (*read)(struct cgroup___180 *, struct cftype___116 *, struct file___285 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___180 *, struct cftype___116 *);
	s64 (*read_s64)(struct cgroup___180 *, struct cftype___116 *);
	int (*read_map)(struct cgroup___180 *, struct cftype___116 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___180 *, struct cftype___116 *, struct seq_file___210 *);
	ssize_t (*write)(struct cgroup___180 *, struct cftype___116 *, struct file___285 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___180 *, struct cftype___116 *, u64);
	int (*write_s64)(struct cgroup___180 *, struct cftype___116 *, s64);
	int (*write_string)(struct cgroup___180 *, struct cftype___116 *, const char *);
	int (*trigger)(struct cgroup___180 *, unsigned int);
	int (*release)(struct inode___285 *, struct file___285 *);
	int (*register_event)(struct cgroup___180 *, struct cftype___116 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___180 *, struct cftype___116 *, struct eventfd_ctx *);
};

struct cftype_set___112 {
	struct list_head node;
	struct cftype___116 *cfts;
};

struct task_and_cgroup___112 {
	struct task_struct___286 *task;
	struct cgroup___180 *cgrp;
	struct css_set___180 *cg;
};

struct cgroup_taskset___112 {
	struct task_and_cgroup___112 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___180 *cur_cgrp;
};

struct cgroup_subsys___112 {
	struct cgroup_subsys_state___180 * (*css_alloc)(struct cgroup___180 *);
	int (*css_online)(struct cgroup___180 *);
	void (*css_offline)(struct cgroup___180 *);
	void (*css_free)(struct cgroup___180 *);
	int (*can_attach)(struct cgroup___180 *, struct cgroup_taskset___112 *);
	void (*cancel_attach)(struct cgroup___180 *, struct cgroup_taskset___112 *);
	void (*attach)(struct cgroup___180 *, struct cgroup_taskset___112 *);
	void (*fork)(struct task_struct___286 *);
	void (*exit)(struct cgroup___180 *, struct cgroup___180 *, struct task_struct___286 *);
	void (*bind)(struct cgroup___180 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___180 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___116 *base_cftypes;
	struct cftype_set___112 base_cftset;
	struct module___178 *module;
};

struct request_sock_ops___50;

struct request_sock___51 {
	struct sock_common___64 __req_common;
	struct request_sock___51 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___50 *rsk_ops;
	struct sock___64 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___77 {
	struct sk_buff___77 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___77 *, struct netlink_callback___77 *);
	int (*done)(struct netlink_callback___77 *);
	void *data;
	struct module___178 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___75 {
	int (*create)(struct sk_buff___77 *, struct net_device___75 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___77 *, unsigned char *);
	int (*rebuild)(struct sk_buff___77 *);
	int (*cache)(const struct neighbour___65 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___75 *, const unsigned char *);
};

struct napi_struct___75 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___75 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___75 *dev;
	struct sk_buff___77 *gro_list;
	struct sk_buff___77 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___75 {
	struct net_device___75 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___67 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___75 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___67 kobj;
	struct net_device___75 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___75 {
	int (*ndo_init)(struct net_device___75 *);
	void (*ndo_uninit)(struct net_device___75 *);
	int (*ndo_open)(struct net_device___75 *);
	int (*ndo_stop)(struct net_device___75 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___77 *, struct net_device___75 *);
	u16 (*ndo_select_queue)(struct net_device___75 *, struct sk_buff___77 *);
	void (*ndo_change_rx_flags)(struct net_device___75 *, int);
	void (*ndo_set_rx_mode)(struct net_device___75 *);
	int (*ndo_set_mac_address)(struct net_device___75 *, void *);
	int (*ndo_validate_addr)(struct net_device___75 *);
	int (*ndo_do_ioctl)(struct net_device___75 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___75 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___75 *, int);
	int (*ndo_neigh_setup)(struct net_device___75 *, struct neigh_parms___65 *);
	void (*ndo_tx_timeout)(struct net_device___75 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___75 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___75 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___75 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___75 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___75 *);
	int (*ndo_netpoll_setup)(struct net_device___75 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___75 *);
	int (*ndo_busy_poll)(struct napi_struct___75 *);
	int (*ndo_set_vf_mac)(struct net_device___75 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___75 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___75 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___75 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___75 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___75 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___75 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___75 *, int, struct sk_buff___77 *);
	int (*ndo_setup_tc)(struct net_device___75 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___75 *);
	int (*ndo_fcoe_disable)(struct net_device___75 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___75 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___75 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___75 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___75 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___75 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___75 *, const struct sk_buff___77 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___75 *, struct net_device___75 *);
	int (*ndo_del_slave)(struct net_device___75 *, struct net_device___75 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___65 *);
	void (*ndo_neigh_destroy)(struct neighbour___65 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___77 *, struct netlink_callback___77 *, struct net_device___75 *, int);
	int (*ndo_bridge_setlink)(struct net_device___75 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___77 *, u32, u32, struct net_device___75 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___75 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___75 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___75 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___75 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___75 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___75 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___77 *, struct net_device___75 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___75 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___75 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___75 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___65 {
	struct net___89 *net;
	struct net_device___75 *dev;
	struct neigh_parms___65 *next;
	int (*neigh_setup)(struct neighbour___65 *);
	void (*neigh_cleanup)(struct neighbour___65 *);
	struct neigh_table___65 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___41;

struct ifacaddr6___41;

struct inet6_dev___41 {
	struct net_device___75 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___41 *mc_list;
	struct ifmcaddr6___41 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___41 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___65 *nd_parms;
	struct inet6_dev___41 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___66 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___75 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___89 *, struct net_device___75 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___75 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___75 *, struct list_head *);
	size_t (*get_size)(const struct net_device___75 *);
	int (*fill_info)(struct sk_buff___77 *, const struct net_device___75 *);
	size_t (*get_xstats_size)(const struct net_device___75 *);
	int (*fill_xstats)(struct sk_buff___77 *, const struct net_device___75 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___89 * (*get_link_net)(const struct net_device___75 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___75 *, struct net_device___75 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___75 *, const struct net_device___75 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___77 *, const struct net_device___75 *, const struct net_device___75 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___13 {
	struct hlist_node hash;
	struct in_ifaddr___13 *ifa_next;
	struct in_device___13 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___65 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___77 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___65;

struct neigh_hash_table___65;

struct neigh_table___65 {
	struct neigh_table___65 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___75 *, __u32 *);
	int (*constructor)(struct neighbour___65 *);
	int (*pconstructor)(struct pneigh_entry___65 *);
	void (*pdestructor)(struct pneigh_entry___65 *);
	void (*proxy_redo)(struct sk_buff___77 *);
	char *id;
	struct neigh_parms___65 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___76 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___65 *nht;
	struct pneigh_entry___65 **phash_buckets;
};

struct neigh_ops___65 {
	int family;
	void (*solicit)(struct neighbour___65 *, struct sk_buff___77 *);
	void (*error_report)(struct neighbour___65 *, struct sk_buff___77 *);
	int (*output)(struct neighbour___65 *, struct sk_buff___77 *);
	int (*connected_output)(struct neighbour___65 *, struct sk_buff___77 *);
};

struct pneigh_entry___65 {
	struct pneigh_entry___65 *next;
	struct net___89 *net;
	struct net_device___75 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___65 {
	struct neighbour___65 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___36 {
	struct dst_entry___65 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___47;

struct inet_hashinfo___16;

struct proto___64 {
	void (*close)(struct sock___64 *, long int);
	int (*connect)(struct sock___64 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___64 *, int);
	struct sock___64 * (*accept)(struct sock___64 *, int, int *);
	int (*ioctl)(struct sock___64 *, int, long unsigned int);
	int (*init)(struct sock___64 *);
	void (*destroy)(struct sock___64 *);
	void (*shutdown)(struct sock___64 *, int);
	int (*setsockopt)(struct sock___64 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___64 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___64 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___64 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___64 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___72 *, struct sock___64 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___72 *, struct sock___64 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___64 *, struct page___284 *, int, size_t, int);
	int (*bind)(struct sock___64 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___64 *, struct sk_buff___77 *);
	void (*release_cb)(struct sock___64 *);
	void (*mtu_reduced)(struct sock___64 *);
	void (*hash)(struct sock___64 *);
	void (*unhash)(struct sock___64 *);
	void (*rehash)(struct sock___64 *);
	int (*get_port)(struct sock___64 *, short unsigned int);
	void (*clear_sk)(struct sock___64 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___64 *);
	void (*enter_memory_pressure)(struct sock___64 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___268 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___50 *rsk_prot;
	struct timewait_sock_ops___47 *twsk_prot;
	union {
		struct inet_hashinfo___16 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___178 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___112 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___64 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___64 {
	void (*enter_memory_pressure)(struct sock___64 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___16 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___268 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___50 {
	int family;
	int obj_size;
	struct kmem_cache___268 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___64 *, struct request_sock___51 *);
	void (*send_ack)(struct sock___64 *, struct sk_buff___77 *, struct request_sock___51 *);
	void (*send_reset)(struct sock___64 *, struct sk_buff___77 *);
	void (*destructor)(struct request_sock___51 *);
	void (*syn_ack_timeout)(struct sock___64 *, struct request_sock___51 *);
};

struct timewait_sock_ops___47 {
	struct kmem_cache___268 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___64 *, struct sock___64 *, void *);
	void (*twsk_destructor)(struct sock___64 *);
};

struct inet_timewait_death_row___6 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___16 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct ifmcaddr6___41 {
	struct in6_addr mca_addr;
	struct inet6_dev___41 *idev;
	struct ifmcaddr6___41 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___41 {
	struct in6_addr aca_addr;
	struct inet6_dev___41 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___41 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct crypto_async_request___12;

typedef void (*crypto_completion_t___12)(struct crypto_async_request___12 *, int);

struct crypto_tfm___12;

struct crypto_async_request___12 {
	struct list_head list;
	crypto_completion_t___12 complete;
	void *data;
	struct crypto_tfm___12 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___12;

struct ablkcipher_request___12;

struct ablkcipher_tfm___12 {
	int (*setkey)(struct crypto_ablkcipher___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___12 *);
	int (*decrypt)(struct ablkcipher_request___12 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___12 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___12;

struct aead_request___12;

struct aead_tfm___12 {
	int (*setkey)(struct crypto_aead___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___12 *);
	int (*decrypt)(struct aead_request___12 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___12 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___12;

struct blkcipher_tfm___12 {
	void *iv;
	int (*setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___12 {
	int (*cit_setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___12 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___12 *, u8 *, const u8 *);
};

struct hash_desc___12;

struct crypto_hash___12;

struct hash_tfm___12 {
	int (*init)(struct hash_desc___12 *);
	int (*update)(struct hash_desc___12 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___12 *, u8 *);
	int (*digest)(struct hash_desc___12 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___12 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___12 {
	int (*cot_compress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___12;

struct rng_tfm___12 {
	int (*rng_gen_random)(struct crypto_rng___12 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___12 *, u8 *, unsigned int);
};

struct crypto_alg___12;

struct crypto_tfm___12 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___12 ablkcipher;
		struct aead_tfm___12 aead;
		struct blkcipher_tfm___12 blkcipher;
		struct cipher_tfm___12 cipher;
		struct hash_tfm___12 hash;
		struct compress_tfm___12 compress;
		struct rng_tfm___12 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___12 *);
	struct crypto_alg___12 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___12 {
	struct crypto_async_request___12 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___12 {
	struct crypto_async_request___12 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___12;

struct blkcipher_desc___12 {
	struct crypto_blkcipher___12 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___12 {
	struct crypto_tfm___12 base;
};

struct hash_desc___12 {
	struct crypto_hash___12 *tfm;
	u32 flags;
};

struct crypto_hash___12 {
	struct crypto_tfm___12 base;
};

struct ablkcipher_alg___12 {
	int (*setkey)(struct crypto_ablkcipher___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___12 *);
	int (*decrypt)(struct ablkcipher_request___12 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___12 {
	struct crypto_tfm___12 base;
};

struct aead_alg___12 {
	int (*setkey)(struct crypto_aead___12 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___12 *, unsigned int);
	int (*encrypt)(struct aead_request___12 *);
	int (*decrypt)(struct aead_request___12 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___12 {
	struct crypto_tfm___12 base;
};

struct blkcipher_alg___12 {
	int (*setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___12 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
};

struct compress_alg___12 {
	int (*coa_compress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___12 {
	int (*rng_make_random)(struct crypto_rng___12 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___12 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___12 {
	struct crypto_tfm___12 base;
};

struct crypto_alg___12 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___12 ablkcipher;
		struct aead_alg___12 aead;
		struct blkcipher_alg___12 blkcipher;
		struct cipher_alg___12 cipher;
		struct compress_alg___12 compress;
		struct rng_alg___12 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___12 *);
	void (*cra_exit)(struct crypto_tfm___12 *);
	void (*cra_destroy)(struct crypto_alg___12 *);
	struct module___178 *cra_module;
};

struct crypto_cipher___2 {
	struct crypto_tfm___12 base;
};

struct tcp_fastopen_context___2 {
	struct crypto_cipher___2 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct page___285;

typedef struct page___285 *pgtable_t___285;

struct address_space___286;

struct kmem_cache___269;

struct page___285 {
	long unsigned int flags;
	struct address_space___286 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___285 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___285 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___269 *slab_cache;
		struct page___285 *first_page;
	};
	long: 64;
};

struct task_struct___287;

struct pv_cpu_ops___287 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___287 *);
	void (*end_context_switch)(struct task_struct___287 *);
};

struct mutex___288 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___287 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___280 {
	struct page___285 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___294;

struct nsproxy___166;

struct signal_struct___287;

struct css_set___181;

struct task_struct___287 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___287 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___294 *mm;
	struct mm_struct___294 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___287 *real_parent;
	struct task_struct___287 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___287 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___287 = 0,
		VTIME_USER___287 = 1,
		VTIME_SYS___287 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___166 *nsproxy;
	struct signal_struct___287 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___181 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___288 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___280 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___294 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___294 *, struct mm_struct___294 *);
	void (*dup_mmap)(struct mm_struct___294 *, struct mm_struct___294 *);
	void (*exit_mmap)(struct mm_struct___294 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___294 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___294 *);
	void (*pgd_free)(struct mm_struct___294 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___294 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___294 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___294 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___294 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___294 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___294 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___294 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___294 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___294 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___294 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___294 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___288 lock;
	void *vdso;
} mm_context_t___288;

struct xol_area___285;

struct uprobes_state___285 {
	struct xol_area___285 *xol_area;
};

struct vm_area_struct___294;

struct file___286;

struct core_state___287;

struct mm_struct___294 {
	struct vm_area_struct___294 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___294 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___294 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___288 context;
	long unsigned int flags;
	struct core_state___287 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___287 *owner;
	struct file___286 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___285 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct ctl_table_header___91;

struct ctl_node___91 {
	struct rb_node node;
	struct ctl_table_header___91 *header;
};

struct ctl_table_root___91;

struct ctl_table_set___91;

struct ctl_dir___91;

struct ctl_table_header___91 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___91 *root;
	struct ctl_table_set___91 *set;
	struct ctl_dir___91 *parent;
	struct ctl_node___91 *node;
};

struct ctl_dir___91 {
	struct ctl_table_header___91 header;
	struct rb_root root;
};

struct ctl_table_set___91 {
	int (*is_seen)(struct ctl_table_set___91 *);
	struct ctl_dir___91 dir;
};

struct ctl_table_root___91 {
	struct ctl_table_set___91 default_set;
	struct ctl_table_set___91 * (*lookup)(struct ctl_table_root___91 *, struct nsproxy___166 *);
	int (*permissions)(struct ctl_table_header___91 *, struct ctl_table *);
};

struct net___90;

struct nsproxy___166 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___90 *net_ns;
};

struct netns_core___88 {
	struct ctl_table_header___91 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct irq_data___210;

struct x86_io_apic_ops___210 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___210 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___210;

struct irq_data___210 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___210 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___284;

struct dev_pm_ops___284 {
	int (*prepare)(struct device___284 *);
	void (*complete)(struct device___284 *);
	int (*suspend)(struct device___284 *);
	int (*resume)(struct device___284 *);
	int (*freeze)(struct device___284 *);
	int (*thaw)(struct device___284 *);
	int (*poweroff)(struct device___284 *);
	int (*restore)(struct device___284 *);
	int (*suspend_late)(struct device___284 *);
	int (*resume_early)(struct device___284 *);
	int (*freeze_late)(struct device___284 *);
	int (*thaw_early)(struct device___284 *);
	int (*poweroff_late)(struct device___284 *);
	int (*restore_early)(struct device___284 *);
	int (*suspend_noirq)(struct device___284 *);
	int (*resume_noirq)(struct device___284 *);
	int (*freeze_noirq)(struct device___284 *);
	int (*thaw_noirq)(struct device___284 *);
	int (*poweroff_noirq)(struct device___284 *);
	int (*restore_noirq)(struct device___284 *);
	int (*runtime_suspend)(struct device___284 *);
	int (*runtime_resume)(struct device___284 *);
	int (*runtime_idle)(struct device___284 *);
};

struct kset___68;

struct kobj_type___68;

struct kobject___68 {
	const char *name;
	struct list_head entry;
	struct kobject___68 *parent;
	struct kset___68 *kset;
	struct kobj_type___68 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___87;

struct dev_pm_info___87 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___87 *qos;
};

struct dma_map_ops___149;

struct dev_archdata___149 {
	struct dma_map_ops___149 *dma_ops;
	void *iommu;
};

struct device_type___284;

struct bus_type___284;

struct device_driver___284;

struct dev_pm_domain___284;

struct class___284;

struct attribute_group___246;

struct device_rh___284;

struct device___284 {
	struct device___284 *parent;
	struct device_private *p;
	struct kobject___68 kobj;
	const char *init_name;
	const struct device_type___284 *type;
	struct mutex___288 mutex;
	struct bus_type___284 *bus;
	struct device_driver___284 *driver;
	void *platform_data;
	struct dev_pm_info___87 power;
	struct dev_pm_domain___284 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___149 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___284 *class;
	const struct attribute_group___246 **groups;
	void (*release)(struct device___284 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___284 *device_rh;
};

struct dev_pm_qos_request___88;

struct dev_pm_qos___87 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___88 *latency_req;
	struct dev_pm_qos_request___88 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___88 *latency_tolerance_req;
};

struct dev_pm_info_rh___284 {
	void (*set_latency_tolerance)(struct device___284 *, s32);
};

struct dev_pm_domain___284 {
	struct dev_pm_ops___284 ops;
};

struct smp_ops___287 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___287 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct snmp_mib {
	const char *name;
	int entry;
};

struct netns_unix___88 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___91 *ctl;
};

struct netns_packet___89 {
	struct mutex___288 sklist_lock;
	struct hlist_head sklist;
};

struct zone___287;

struct lruvec___287 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___287 *zone;
};

struct pglist_data___287;

struct zone___287 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___287 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___287 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___287 {
	struct zone___287 *zone;
	int zone_idx;
};

struct zonelist___287 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___287 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___287 {
	struct zone___287 node_zones[4];
	struct zonelist___287 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___287 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sock___65;

struct net_device___76;

struct nf_bridge_info___76;

struct sk_buff___78 {
	struct sk_buff___78 *next;
	struct sk_buff___78 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___65 *sk;
	struct net_device___76 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___78 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___76 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct netns_ipv4___88 {
	struct ctl_table_header___91 *forw_hdr;
	struct ctl_table_header___91 *frags_hdr;
	struct ctl_table_header___91 *ipv4_hdr;
	struct ctl_table_header___91 *route_hdr;
	struct ctl_table_header___91 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___65 *fibnl;
	struct sock___65 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proto___65;

struct sock_common___65 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___65 *skc_prot;
	struct net___90 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff_head___77 {
	struct sk_buff___78 *next;
	struct sk_buff___78 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___66;

struct socket_wq___65;

struct dst_entry___66;

struct socket___66;

struct cg_proto___65;

struct sock___65 {
	struct sock_common___65 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___77 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___78 *head;
		struct sk_buff___78 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___66 *sk_filter;
	struct socket_wq___65 *sk_wq;
	struct sk_buff_head___77 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___66 *sk_rx_dst;
	struct dst_entry___66 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___77 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___77 sk_error_queue;
	struct proto___65 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___66 *sk_socket;
	void *sk_user_data;
	struct page_frag___280 sk_frag;
	struct sk_buff___78 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___65 *sk_cgrp;
	void (*sk_state_change)(struct sock___65 *);
	void (*sk_data_ready)(struct sock___65 *, int);
	void (*sk_write_space)(struct sock___65 *);
	void (*sk_error_report)(struct sock___65 *);
	int (*sk_backlog_rcv)(struct sock___65 *, struct sk_buff___78 *);
	void (*sk_destruct)(struct sock___65 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct neighbour___66;

struct dst_ops___90 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___90 *);
	struct dst_entry___66 * (*check)(struct dst_entry___66 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___66 *);
	unsigned int (*mtu)(const struct dst_entry___66 *);
	u32 * (*cow_metrics)(struct dst_entry___66 *, long unsigned int);
	void (*destroy)(struct dst_entry___66 *);
	void (*ifdown)(struct dst_entry___66 *, struct net_device___76 *, int);
	struct dst_entry___66 * (*negative_advice)(struct dst_entry___66 *);
	void (*link_failure)(struct sk_buff___78 *);
	void (*update_pmtu)(struct dst_entry___66 *, struct sock___65 *, struct sk_buff___78 *, u32);
	void (*redirect)(struct dst_entry___66 *, struct sock___65 *, struct sk_buff___78 *);
	int (*local_out)(struct sk_buff___78 *);
	struct neighbour___66 * (*neigh_lookup)(const struct dst_entry___66 *, struct sk_buff___78 *, const void *);
	struct kmem_cache___269 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rtable___37;

struct dst_entry___66 {
	struct callback_head callback_head;
	struct dst_entry___66 *child;
	struct net_device___76 *dev;
	struct dst_ops___90 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___66 *path;
	struct dst_entry___66 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___78 *);
	union {
		int (*output)(struct sock___65 *, struct sk_buff___78 *);
		struct {
			int (*output)(struct sk_buff___78 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___66 *next;
		struct rtable___37 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

typedef rx_handler_result_t rx_handler_func_t___76(struct sk_buff___78 **);

struct net_device_ops___76;

struct ethtool_ops___76;

struct header_ops___76;

struct in_device___14;

struct inet6_dev___42;

struct netdev_rx_queue___76;

struct netdev_queue___76;

struct rtnl_link_ops___67;

struct dcbnl_rtnl_ops___76;

struct net_device___76 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___76 *netdev_ops;
	const struct ethtool_ops___76 *ethtool_ops;
	const struct header_ops___76 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___68 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___14 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___42 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___76 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___76 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___76 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___76 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___76 = 0,
		NETREG_REGISTERED___76 = 1,
		NETREG_UNREGISTERING___76 = 2,
		NETREG_UNREGISTERED___76 = 3,
		NETREG_RELEASED___76 = 4,
		NETREG_DUMMY___76 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___76 = 0,
		RTNL_LINK_INITIALIZING___76 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___76 *);
	struct netpoll_info *npinfo;
	struct net___90 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___284 dev;
	const struct attribute_group___246 *sysfs_groups[4];
	const struct rtnl_link_ops___67 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___76 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___66;

struct neigh_parms___66;

struct neigh_ops___66;

struct neighbour___66 {
	struct neighbour___66 *next;
	struct neigh_table___66 *tbl;
	struct neigh_parms___66 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___77 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___66 *, struct sk_buff___78 *);
	const struct neigh_ops___66 *ops;
	struct callback_head rcu;
	struct net_device___76 *dev;
	u8 primary_key[0];
};

struct kmem_cache_cpu___268;

struct memcg_cache_params___269;

struct kmem_cache___269 {
	struct kmem_cache_cpu___268 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___68 kobj;
	struct memcg_cache_params___269 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct netns_sysctl_ipv6___88 {
	struct ctl_table_header___91 *hdr;
	struct ctl_table_header___91 *route_hdr;
	struct ctl_table_header___91 *icmp_hdr;
	struct ctl_table_header___91 *frags_hdr;
	struct ctl_table_header___91 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct netns_ipv6___90 {
	struct netns_sysctl_ipv6___88 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___90 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___65 **icmp_sk;
	struct sock___65 *ndisc_sk;
	struct sock___65 *tcp_sk;
	struct sock___65 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_nf_frag___88 {
	struct netns_sysctl_ipv6___88 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_sctp___88 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___91 *sysctl_header;
	struct sock___65 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___65 {
	struct sock___65 *v4_ctl_sk;
	struct sock___65 *v6_ctl_sk;
};

struct inode___286;

struct dentry_operations___286;

struct super_block___286;

struct dentry___286 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___286 *d_parent;
	struct qstr d_name;
	struct inode___286 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___286 *d_op;
	struct super_block___286 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___286;

struct address_space___286 {
	struct inode___286 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___288 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___286 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___286;

struct file_operations___286;

struct file_lock___286;

struct dquot___286;

struct block_device___286;

struct inode___286 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___286 *i_op;
	struct super_block___286 *i_sb;
	struct address_space___286 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___288 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___286 *i_fop;
	struct file_lock___286 *i_flock;
	struct address_space___286 i_data;
	struct dquot___286 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___286 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct path___286;

struct dentry_operations___286 {
	int (*d_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_hash)(const struct dentry___286 *, struct qstr *);
	int (*d_compare)(const struct dentry___286 *, const struct dentry___286 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___286 *);
	void (*d_release)(struct dentry___286 *);
	void (*d_prune)(struct dentry___286 *);
	void (*d_iput)(struct dentry___286 *, struct inode___286 *);
	char * (*d_dname)(struct dentry___286 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___286 *);
	int (*d_manage)(struct dentry___286 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___286;

struct mem_dqinfo___286 {
	struct quota_format_type___286 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___286;

struct quota_info___286 {
	unsigned int flags;
	struct mutex___288 dqio_mutex;
	struct mutex___288 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___286 *files[2];
	struct mem_dqinfo___286 info[2];
	const struct quota_format_ops___286 *ops[2];
};

struct file_system_type___286;

struct super_operations___286;

struct dquot_operations___286;

struct quotactl_ops___286;

struct xattr_handler___182;

struct super_block___286 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___286 *s_type;
	const struct super_operations___286 *s_op;
	const struct dquot_operations___286 *dq_op;
	const struct quotactl_ops___286 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___286 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___182 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___286 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___286 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___288 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___286 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct path___286 {
	struct vfsmount *mnt;
	struct dentry___286 *dentry;
};

struct block_device___286 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___286 *bd_inode;
	struct super_block___286 *bd_super;
	struct mutex___288 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___286 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___288 bd_fsfreeze_mutex;
};

struct cgroup___181;

struct cgroup_subsys_state___181 {
	struct cgroup___181 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___73;

typedef int kiocb_cancel_fn___73(struct kiocb___73 *, struct io_event *);

struct kiocb___73 {
	atomic_t ki_users;
	struct file___286 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___73 *ki_cancel;
	void (*ki_dtor)(struct kiocb___73 *);
	union {
		void *user;
		struct task_struct___287 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___286 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___286 *ia_file;
};

struct file___286 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___286 f_path;
	struct inode___286 *f_inode;
	const struct file_operations___286 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___286 *f_mapping;
	struct mutex___288 f_pos_lock;
};

struct dquot___286 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___288 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___286 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___286 {
	int qf_fmt_id;
	const struct quota_format_ops___286 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___286 *qf_next;
};

struct quota_format_ops___286 {
	int (*check_quota_file)(struct super_block___286 *, int);
	int (*read_file_info)(struct super_block___286 *, int);
	int (*write_file_info)(struct super_block___286 *, int);
	int (*free_file_info)(struct super_block___286 *, int);
	int (*read_dqblk)(struct dquot___286 *);
	int (*commit_dqblk)(struct dquot___286 *);
	int (*release_dqblk)(struct dquot___286 *);
};

struct dquot_operations___286 {
	int (*write_dquot)(struct dquot___286 *);
	struct dquot___286 * (*alloc_dquot)(struct super_block___286 *, int);
	void (*destroy_dquot)(struct dquot___286 *);
	int (*acquire_dquot)(struct dquot___286 *);
	int (*release_dquot)(struct dquot___286 *);
	int (*mark_dirty)(struct dquot___286 *);
	int (*write_info)(struct super_block___286 *, int);
	qsize_t * (*get_reserved_space)(struct inode___286 *);
};

struct quotactl_ops___286 {
	int (*quota_on)(struct super_block___286 *, int, int, struct path___286 *);
	int (*quota_on_meta)(struct super_block___286 *, int, int);
	int (*quota_off)(struct super_block___286 *, int);
	int (*quota_sync)(struct super_block___286 *, int);
	int (*get_info)(struct super_block___286 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___286 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___286 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___286 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___286 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___286 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___286 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___286 *, unsigned int);
};

struct address_space_operations___286 {
	int (*writepage)(struct page___285 *, struct writeback_control *);
	int (*readpage)(struct file___286 *, struct page___285 *);
	int (*writepages)(struct address_space___286 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___285 *);
	int (*readpages)(struct file___286 *, struct address_space___286 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___286 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___285 **, void **);
	int (*write_end)(struct file___286 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___285 *, void *);
	sector_t (*bmap)(struct address_space___286 *, sector_t);
	void (*invalidatepage)(struct page___285 *, long unsigned int);
	int (*releasepage)(struct page___285 *, gfp_t);
	void (*freepage)(struct page___285 *);
	ssize_t (*direct_IO)(int, struct kiocb___73 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___286 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___286 *, struct page___285 *, struct page___285 *, enum migrate_mode);
	int (*launder_page)(struct page___285 *);
	int (*is_partially_uptodate)(struct page___285 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___285 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___286 *, struct page___285 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___286 *, sector_t *);
	void (*swap_deactivate)(struct file___286 *);
	void (*invalidatepage_range)(struct page___285 *, unsigned int, unsigned int);
};

struct inode_operations___286 {
	struct dentry___286 * (*lookup)(struct inode___286 *, struct dentry___286 *, unsigned int);
	void * (*follow_link)(struct dentry___286 *, struct nameidata *);
	int (*permission)(struct inode___286 *, int);
	struct posix_acl * (*get_acl)(struct inode___286 *, int);
	int (*readlink)(struct dentry___286 *, char *, int);
	void (*put_link)(struct dentry___286 *, struct nameidata *, void *);
	int (*create)(struct inode___286 *, struct dentry___286 *, umode_t, bool);
	int (*link)(struct dentry___286 *, struct inode___286 *, struct dentry___286 *);
	int (*unlink)(struct inode___286 *, struct dentry___286 *);
	int (*symlink)(struct inode___286 *, struct dentry___286 *, const char *);
	int (*mkdir)(struct inode___286 *, struct dentry___286 *, umode_t);
	int (*rmdir)(struct inode___286 *, struct dentry___286 *);
	int (*mknod)(struct inode___286 *, struct dentry___286 *, umode_t, dev_t);
	int (*rename)(struct inode___286 *, struct dentry___286 *, struct inode___286 *, struct dentry___286 *);
	int (*setattr)(struct dentry___286 *, struct iattr___286 *);
	int (*getattr)(struct vfsmount *, struct dentry___286 *, struct kstat *);
	int (*setxattr)(struct dentry___286 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___286 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___286 *, char *, size_t);
	int (*removexattr)(struct dentry___286 *, const char *);
	int (*fiemap)(struct inode___286 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___286 *, struct timespec *, int);
	int (*atomic_open)(struct inode___286 *, struct dentry___286 *, struct file___286 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___172;

struct seq_file___211;

struct file_operations___286 {
	struct module *owner;
	loff_t (*llseek)(struct file___286 *, loff_t, int);
	ssize_t (*read)(struct file___286 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___286 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___73 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___73 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___286 *, void *, filldir_t);
	unsigned int (*poll)(struct file___286 *, struct poll_table_struct___172 *);
	long int (*unlocked_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___286 *, struct vm_area_struct___294 *);
	int (*open)(struct inode___286 *, struct file___286 *);
	int (*flush)(struct file___286 *, fl_owner_t);
	int (*release)(struct inode___286 *, struct file___286 *);
	int (*fsync)(struct file___286 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___73 *, int);
	int (*fasync)(int, struct file___286 *, int);
	int (*lock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*sendpage)(struct file___286 *, struct page___285 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___286 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___286 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___286 *, long int, struct file_lock___286 **, void **);
		struct {
			int (*setlease)(struct file___286 *, long int, struct file_lock___286 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___286 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___211 *, struct file___286 *);
};

struct fasync_struct___286;

struct file_lock_operations___286;

struct lock_manager_operations___286;

struct file_lock___286 {
	struct file_lock___286 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___286 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___286 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___286 *fl_ops;
	const struct lock_manager_operations___286 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___286 {
	void (*fl_copy_lock)(struct file_lock___286 *, struct file_lock___286 *);
	void (*fl_release_private)(struct file_lock___286 *);
};

struct lock_manager_operations___286 {
	int (*lm_compare_owner)(struct file_lock___286 *, struct file_lock___286 *);
	long unsigned int (*lm_owner_key)(struct file_lock___286 *);
	void (*lm_notify)(struct file_lock___286 *);
	int (*lm_grant)(struct file_lock___286 *, struct file_lock___286 *, int);
	void (*lm_break)(struct file_lock___286 *);
	int (*lm_change)(struct file_lock___286 **, int);
};

struct fasync_struct___286 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___286 *fa_next;
	struct file___286 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___286 {
	const char *name;
	int fs_flags;
	struct dentry___286 * (*mount)(struct file_system_type___286 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___286 *);
	struct module *owner;
	struct file_system_type___286 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___286 {
	struct inode___286 * (*alloc_inode)(struct super_block___286 *);
	void (*destroy_inode)(struct inode___286 *);
	void (*dirty_inode)(struct inode___286 *, int);
	int (*write_inode)(struct inode___286 *, struct writeback_control *);
	int (*drop_inode)(struct inode___286 *);
	void (*evict_inode)(struct inode___286 *);
	void (*put_super)(struct super_block___286 *);
	int (*sync_fs)(struct super_block___286 *, int);
	int (*freeze_fs)(struct super_block___286 *);
	int (*unfreeze_fs)(struct super_block___286 *);
	int (*statfs)(struct dentry___286 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___286 *, int *, char *);
	void (*umount_begin)(struct super_block___286 *);
	int (*show_options)(struct seq_file___211 *, struct dentry___286 *);
	int (*show_devname)(struct seq_file___211 *, struct dentry___286 *);
	int (*show_path)(struct seq_file___211 *, struct dentry___286 *);
	int (*show_stats)(struct seq_file___211 *, struct dentry___286 *);
	ssize_t (*quota_read)(struct super_block___286 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___286 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___286 *);
	int (*bdev_try_to_free_page)(struct super_block___286 *, struct page___285 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___286 *);
	void (*free_cached_objects)(struct super_block___286 *, int);
};

struct xattr_handler___182 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___286 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___286 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___286 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___174)(struct file___286 *, wait_queue_head_t *, struct poll_table_struct___172 *);

struct poll_table_struct___172 {
	poll_queue_proc___174 _qproc;
	long unsigned int _key;
};

struct vm_operations_struct___260;

struct vm_area_struct___294 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___294 *vm_next;
	struct vm_area_struct___294 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___294 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___260 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___286 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___211;

struct seq_file___211 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___288 lock;
	const struct seq_operations___211 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___285 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___285 *page;
	long unsigned int vaddr;
};

struct vm_fault___256;

struct vm_operations_struct___260 {
	void (*open)(struct vm_area_struct___294 *);
	void (*close)(struct vm_area_struct___294 *);
	int (*fault)(struct vm_area_struct___294 *, struct vm_fault___256 *);
	int (*page_mkwrite)(struct vm_area_struct___294 *, struct vm_fault___256 *);
	int (*access)(struct vm_area_struct___294 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___294 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___294 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___294 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___294 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___287 {
	struct task_struct___287 *task;
	struct core_thread___287 *next;
};

struct core_state___287 {
	atomic_t nr_threads;
	struct core_thread___287 dumper;
	struct completion startup;
};

struct socket_wq___65 {
	wait_queue_head_t wait;
	struct fasync_struct___286 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___65;

struct socket___66 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___65 *wq;
	struct file___286 *file;
	struct sock___65 *sk;
	const struct proto_ops___65 *ops;
};

struct proto_ops___65 {
	int family;
	struct module *owner;
	int (*release)(struct socket___66 *);
	int (*bind)(struct socket___66 *, struct sockaddr *, int);
	int (*connect)(struct socket___66 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___66 *, struct socket___66 *);
	int (*accept)(struct socket___66 *, struct socket___66 *, int);
	int (*getname)(struct socket___66 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___286 *, struct socket___66 *, struct poll_table_struct___172 *);
	int (*ioctl)(struct socket___66 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___66 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___66 *, int);
	int (*shutdown)(struct socket___66 *, int);
	int (*setsockopt)(struct socket___66 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___66 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___66 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___66 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___73 *, struct socket___66 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___73 *, struct socket___66 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___286 *, struct socket___66 *, struct vm_area_struct___294 *);
	ssize_t (*sendpage)(struct socket___66 *, struct page___285 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___66 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___65 *, int);
		struct {
			void (*set_peek_off)(struct sock___65 *, int);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
};

struct netns_nf___88 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___91 *nf_log_dir_header;
};

struct nf_proto_net___88 {
	struct ctl_table_header___91 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___88 {
	struct nf_proto_net___88 pn;
	unsigned int timeout;
};

struct nf_tcp_net___88 {
	struct nf_proto_net___88 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___88 {
	struct nf_proto_net___88 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___88 {
	struct nf_proto_net___88 pn;
	unsigned int timeout;
};

struct nf_ip_net___88 {
	struct nf_generic_net___88 generic;
	struct nf_tcp_net___88 tcp;
	struct nf_udp_net___88 udp;
	struct nf_icmp_net___88 icmp;
	struct nf_icmp_net___88 icmpv6;
};

struct netns_ct___89 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___91 *sysctl_header;
	struct ctl_table_header___91 *acct_sysctl_header;
	struct ctl_table_header___91 *tstamp_sysctl_header;
	struct ctl_table_header___91 *event_sysctl_header;
	struct ctl_table_header___91 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___269 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___88 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_xfrm___90 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___65 *nlsk;
	struct sock___65 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___91 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___90 xfrm4_dst_ops;
	struct dst_ops___90 xfrm6_dst_ops;
};

struct net___90 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___91 sysctls;
	struct sock___65 *rtnl;
	struct sock___65 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___76 *loopback_dev;
	struct netns_core___88 core;
	struct netns_mib mib;
	struct netns_packet___89 packet;
	struct netns_unix___88 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___88 ipv4;
	struct netns_ipv6___90 ipv6;
	struct netns_sctp___88 sctp;
	struct netns_dccp___65 dccp;
	struct netns_nf___88 nf;
	struct netns_xt xt;
	struct netns_ct___89 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___88 nf_frag;
	struct sock___65 *nfnl;
	struct sock___65 *nfnl_stash;
	struct sk_buff_head___77 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___90 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___65 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___65 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___288 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___288 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___65 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___65 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___248;

struct attribute_group___246 {
	const char *name;
	umode_t (*is_visible)(struct kobject___68 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___248 **bin_attrs;
};

struct bin_attribute___248 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___286 *, struct kobject___68 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___286 *, struct kobject___68 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	int (*mmap)(struct file___286 *, struct kobject___68 *, struct bin_attribute___248 *, struct vm_area_struct___294 *);
};

struct sysfs_ops___68 {
	ssize_t (*show)(struct kobject___68 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___68 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___68 *, const struct attribute *);
};

struct kset_uevent_ops___68;

struct kset___68 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___68 kobj;
	const struct kset_uevent_ops___68 *uevent_ops;
};

struct kobj_type___68 {
	void (*release)(struct kobject___68 *);
	const struct sysfs_ops___68 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___65 * (*child_ns_type)(struct kobject___68 *);
	const void * (*namespace)(struct kobject___68 *);
};

struct kset_uevent_ops___68 {
	int (* const filter)(struct kset___68 *, struct kobject___68 *);
	const char * (* const name)(struct kset___68 *, struct kobject___68 *);
	int (* const uevent)(struct kset___68 *, struct kobject___68 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___268 {
	void **freelist;
	long unsigned int tid;
	struct page___285 *page;
	struct page___285 *partial;
};

struct memcg_cache_params___269 {
	bool is_root_cache;
	union {
		struct kmem_cache___269 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___269 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___149 {
	void * (*alloc)(struct device___284 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___284 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___284 *, struct vm_area_struct___294 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___284 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___284 *, struct page___285 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___284 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___284 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___284 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___284 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___284 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___284 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___284 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___284 *, dma_addr_t);
	int (*dma_supported)(struct device___284 *, u64);
	int (*set_dma_mask)(struct device___284 *, u64);
	int is_phys;
};

struct bus_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___284 *, char *);
	ssize_t (*store)(struct bus_type___284 *, const char *, size_t);
};

struct device_attribute___284;

struct driver_attribute___284;

struct bus_type___284 {
	const char *name;
	const char *dev_name;
	struct device___284 *dev_root;
	struct bus_attribute___284 *bus_attrs;
	struct device_attribute___284 *dev_attrs;
	struct driver_attribute___284 *drv_attrs;
	const struct attribute_group___246 **bus_groups;
	const struct attribute_group___246 **dev_groups;
	const struct attribute_group___246 **drv_groups;
	int (*match)(struct device___284 *, struct device_driver___284 *);
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	int (*probe)(struct device___284 *);
	int (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*online)(struct device___284 *);
	int (*offline)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct device___284 *, struct device_attribute___284 *, char *);
	ssize_t (*store)(struct device___284 *, struct device_attribute___284 *, const char *, size_t);
};

struct driver_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___284 *, char *);
	ssize_t (*store)(struct device_driver___284 *, const char *, size_t);
};

struct device_driver___284 {
	const char *name;
	struct bus_type___284 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___284 *);
	int (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	const struct attribute_group___246 **groups;
	const struct dev_pm_ops___284 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___284 {
	const char *name;
	const struct attribute_group___246 **groups;
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
};

struct class_attribute___284;

struct class___284 {
	const char *name;
	struct module *owner;
	struct class_attribute___284 *class_attrs;
	struct device_attribute___284 *dev_attrs;
	const struct attribute_group___246 **dev_groups;
	struct bin_attribute___248 *dev_bin_attrs;
	struct kobject___68 *dev_kobj;
	int (*dev_uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *);
	void (*class_release)(struct class___284 *);
	void (*dev_release)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	const struct kobj_ns_type_operations___65 *ns_type;
	const void * (*namespace)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
	struct subsys_private *p;
};

struct class_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct class___284 *, struct class_attribute___284 *, char *);
	ssize_t (*store)(struct class___284 *, struct class_attribute___284 *, const char *, size_t);
	const void * (*namespace)(struct class___284 *, const struct class_attribute___284 *);
};

struct device_rh___284 {
	struct dev_pm_info_rh___284 power;
};

struct vm_fault___256 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___285 *page;
};

struct signal_struct___287 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___287 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___287 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___288 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___181 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___181 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___76 {
	atomic_t use;
	unsigned int mask;
	struct net_device___76 *physindev;
	struct net_device___76 *physoutdev;
	long unsigned int data[4];
};

struct nf_afinfo___90 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___78 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___78 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___90 *, struct dst_entry___66 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___78 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___78 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___210 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___210 *);
	void (*irq_shutdown)(struct irq_data___210 *);
	void (*irq_enable)(struct irq_data___210 *);
	void (*irq_disable)(struct irq_data___210 *);
	void (*irq_ack)(struct irq_data___210 *);
	void (*irq_mask)(struct irq_data___210 *);
	void (*irq_mask_ack)(struct irq_data___210 *);
	void (*irq_unmask)(struct irq_data___210 *);
	void (*irq_eoi)(struct irq_data___210 *);
	int (*irq_set_affinity)(struct irq_data___210 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___210 *);
	int (*irq_set_type)(struct irq_data___210 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___210 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___210 *);
	void (*irq_bus_sync_unlock)(struct irq_data___210 *);
	void (*irq_cpu_online)(struct irq_data___210 *);
	void (*irq_cpu_offline)(struct irq_data___210 *);
	void (*irq_suspend)(struct irq_data___210 *);
	void (*irq_resume)(struct irq_data___210 *);
	void (*irq_pm_shutdown)(struct irq_data___210 *);
	void (*irq_print_chip)(struct irq_data___210 *, struct seq_file___211 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___210 *, void *);
	long unsigned int flags;
};

struct seq_operations___211 {
	void * (*start)(struct seq_file___211 *, loff_t *);
	void (*stop)(struct seq_file___211 *, void *);
	void * (*next)(struct seq_file___211 *, void *, loff_t *);
	int (*show)(struct seq_file___211 *, void *);
};

struct pernet_operations___25 {
	struct list_head list;
	int (*init)(struct net___90 *);
	void (*exit)(struct net___90 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dev_pm_qos_request___88 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___284 *dev;
};

struct ethtool_ops___76 {
	int (*get_settings)(struct net_device___76 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___76 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___76 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___76 *);
	void (*get_regs)(struct net_device___76 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___76 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___76 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___76 *);
	void (*set_msglevel)(struct net_device___76 *, u32);
	int (*nway_reset)(struct net_device___76 *);
	u32 (*get_link)(struct net_device___76 *);
	int (*get_eeprom_len)(struct net_device___76 *);
	int (*get_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___76 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___76 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___76 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___76 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___76 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___76 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___76 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___76 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___76 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___76 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___76 *);
	void (*complete)(struct net_device___76 *);
	u32 (*get_priv_flags)(struct net_device___76 *);
	int (*set_priv_flags)(struct net_device___76 *, u32);
	int (*get_sset_count)(struct net_device___76 *, int);
	int (*get_rxnfc)(struct net_device___76 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___76 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___76 *, struct ethtool_flash *);
	int (*reset)(struct net_device___76 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___76 *);
	int (*get_rxfh_indir)(struct net_device___76 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___76 *, const u32 *);
	void (*get_channels)(struct net_device___76 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___76 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___76 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___76 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___76 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___76 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___76 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___76 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___76 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___76 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___76 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___76 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dcbnl_rtnl_ops___76 {
	int (*ieee_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___76 *);
	u8 (*setstate)(struct net_device___76 *, u8);
	void (*getpermhwaddr)(struct net_device___76 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___76 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___76 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___76 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___76 *, int, u8 *);
	void (*setpfccfg)(struct net_device___76 *, int, u8);
	void (*getpfccfg)(struct net_device___76 *, int, u8 *);
	u8 (*setall)(struct net_device___76 *);
	u8 (*getcap)(struct net_device___76 *, int, u8 *);
	int (*getnumtcs)(struct net_device___76 *, int, u8 *);
	int (*setnumtcs)(struct net_device___76 *, int, u8);
	u8 (*getpfcstate)(struct net_device___76 *);
	void (*setpfcstate)(struct net_device___76 *, u8);
	void (*getbcncfg)(struct net_device___76 *, int, u32 *);
	void (*setbcncfg)(struct net_device___76 *, int, u32);
	void (*getbcnrp)(struct net_device___76 *, int, u8 *);
	void (*setbcnrp)(struct net_device___76 *, int, u8);
	u8 (*setapp)(struct net_device___76 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___76 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___76 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___76 *, int, u8);
	u8 (*getdcbx)(struct net_device___76 *);
	u8 (*setdcbx)(struct net_device___76 *, u8);
	int (*peer_getappinfo)(struct net_device___76 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___76 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___76 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___76 *, struct cee_pfc *);
};

struct cgroupfs_root___181;

struct cgroup___181 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___181 *parent;
	struct dentry___286 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___181 *subsys[11];
	struct cgroupfs_root___181 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___288 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___181 {
	struct super_block___286 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___181 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___117 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___286 *, struct file___286 *);
	ssize_t (*read)(struct cgroup___181 *, struct cftype___117 *, struct file___286 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___181 *, struct cftype___117 *);
	s64 (*read_s64)(struct cgroup___181 *, struct cftype___117 *);
	int (*read_map)(struct cgroup___181 *, struct cftype___117 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___181 *, struct cftype___117 *, struct seq_file___211 *);
	ssize_t (*write)(struct cgroup___181 *, struct cftype___117 *, struct file___286 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___181 *, struct cftype___117 *, u64);
	int (*write_s64)(struct cgroup___181 *, struct cftype___117 *, s64);
	int (*write_string)(struct cgroup___181 *, struct cftype___117 *, const char *);
	int (*trigger)(struct cgroup___181 *, unsigned int);
	int (*release)(struct inode___286 *, struct file___286 *);
	int (*register_event)(struct cgroup___181 *, struct cftype___117 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___181 *, struct cftype___117 *, struct eventfd_ctx *);
};

struct cftype_set___113 {
	struct list_head node;
	struct cftype___117 *cfts;
};

struct task_and_cgroup___113 {
	struct task_struct___287 *task;
	struct cgroup___181 *cgrp;
	struct css_set___181 *cg;
};

struct cgroup_taskset___113 {
	struct task_and_cgroup___113 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___181 *cur_cgrp;
};

struct cgroup_subsys___113 {
	struct cgroup_subsys_state___181 * (*css_alloc)(struct cgroup___181 *);
	int (*css_online)(struct cgroup___181 *);
	void (*css_offline)(struct cgroup___181 *);
	void (*css_free)(struct cgroup___181 *);
	int (*can_attach)(struct cgroup___181 *, struct cgroup_taskset___113 *);
	void (*cancel_attach)(struct cgroup___181 *, struct cgroup_taskset___113 *);
	void (*attach)(struct cgroup___181 *, struct cgroup_taskset___113 *);
	void (*fork)(struct task_struct___287 *);
	void (*exit)(struct cgroup___181 *, struct cgroup___181 *, struct task_struct___287 *);
	void (*bind)(struct cgroup___181 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___181 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___117 *base_cftypes;
	struct cftype_set___113 base_cftset;
	struct module *module;
};

struct request_sock_ops___51;

struct request_sock___52 {
	struct sock_common___65 __req_common;
	struct request_sock___52 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___51 *rsk_ops;
	struct sock___65 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___78 {
	struct sk_buff___78 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___78 *, struct netlink_callback___78 *);
	int (*done)(struct netlink_callback___78 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___76 {
	int (*create)(struct sk_buff___78 *, struct net_device___76 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___78 *, unsigned char *);
	int (*rebuild)(struct sk_buff___78 *);
	int (*cache)(const struct neighbour___66 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___76 *, const unsigned char *);
};

struct napi_struct___76 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___76 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___76 *dev;
	struct sk_buff___78 *gro_list;
	struct sk_buff___78 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___76 {
	struct net_device___76 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___68 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___76 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___68 kobj;
	struct net_device___76 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___76 {
	int (*ndo_init)(struct net_device___76 *);
	void (*ndo_uninit)(struct net_device___76 *);
	int (*ndo_open)(struct net_device___76 *);
	int (*ndo_stop)(struct net_device___76 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___78 *, struct net_device___76 *);
	u16 (*ndo_select_queue)(struct net_device___76 *, struct sk_buff___78 *);
	void (*ndo_change_rx_flags)(struct net_device___76 *, int);
	void (*ndo_set_rx_mode)(struct net_device___76 *);
	int (*ndo_set_mac_address)(struct net_device___76 *, void *);
	int (*ndo_validate_addr)(struct net_device___76 *);
	int (*ndo_do_ioctl)(struct net_device___76 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___76 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___76 *, int);
	int (*ndo_neigh_setup)(struct net_device___76 *, struct neigh_parms___66 *);
	void (*ndo_tx_timeout)(struct net_device___76 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___76 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___76 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___76 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___76 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___76 *);
	int (*ndo_netpoll_setup)(struct net_device___76 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___76 *);
	int (*ndo_busy_poll)(struct napi_struct___76 *);
	int (*ndo_set_vf_mac)(struct net_device___76 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___76 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___76 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___76 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___76 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___76 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___76 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___76 *, int, struct sk_buff___78 *);
	int (*ndo_setup_tc)(struct net_device___76 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___76 *);
	int (*ndo_fcoe_disable)(struct net_device___76 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___76 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___76 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___76 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___76 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___76 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___76 *, const struct sk_buff___78 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___76 *, struct net_device___76 *);
	int (*ndo_del_slave)(struct net_device___76 *, struct net_device___76 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___66 *);
	void (*ndo_neigh_destroy)(struct neighbour___66 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___78 *, struct netlink_callback___78 *, struct net_device___76 *, int);
	int (*ndo_bridge_setlink)(struct net_device___76 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___78 *, u32, u32, struct net_device___76 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___76 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___76 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___76 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___76 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___76 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___76 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___78 *, struct net_device___76 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___76 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___76 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___76 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___66 {
	struct net___90 *net;
	struct net_device___76 *dev;
	struct neigh_parms___66 *next;
	int (*neigh_setup)(struct neighbour___66 *);
	void (*neigh_cleanup)(struct neighbour___66 *);
	struct neigh_table___66 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___14;

struct in_device___14 {
	struct net_device___76 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___14 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___66 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___42;

struct ifacaddr6___42;

struct inet6_dev___42 {
	struct net_device___76 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___42 *mc_list;
	struct ifmcaddr6___42 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___42 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___66 *nd_parms;
	struct inet6_dev___42 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___67 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___76 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___90 *, struct net_device___76 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___76 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___76 *, struct list_head *);
	size_t (*get_size)(const struct net_device___76 *);
	int (*fill_info)(struct sk_buff___78 *, const struct net_device___76 *);
	size_t (*get_xstats_size)(const struct net_device___76 *);
	int (*fill_xstats)(struct sk_buff___78 *, const struct net_device___76 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___90 * (*get_link_net)(const struct net_device___76 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___76 *, struct net_device___76 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___76 *, const struct net_device___76 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___78 *, const struct net_device___76 *, const struct net_device___76 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___66 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___78 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___66;

struct neigh_hash_table___66;

struct neigh_table___66 {
	struct neigh_table___66 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___76 *, __u32 *);
	int (*constructor)(struct neighbour___66 *);
	int (*pconstructor)(struct pneigh_entry___66 *);
	void (*pdestructor)(struct pneigh_entry___66 *);
	void (*proxy_redo)(struct sk_buff___78 *);
	char *id;
	struct neigh_parms___66 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___77 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___66 *nht;
	struct pneigh_entry___66 **phash_buckets;
};

struct neigh_ops___66 {
	int family;
	void (*solicit)(struct neighbour___66 *, struct sk_buff___78 *);
	void (*error_report)(struct neighbour___66 *, struct sk_buff___78 *);
	int (*output)(struct neighbour___66 *, struct sk_buff___78 *);
	int (*connected_output)(struct neighbour___66 *, struct sk_buff___78 *);
};

struct pneigh_entry___66 {
	struct pneigh_entry___66 *next;
	struct net___90 *net;
	struct net_device___76 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___66 {
	struct neighbour___66 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___37 {
	struct dst_entry___66 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___48;

struct inet_hashinfo___17;

struct proto___65 {
	void (*close)(struct sock___65 *, long int);
	int (*connect)(struct sock___65 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___65 *, int);
	struct sock___65 * (*accept)(struct sock___65 *, int, int *);
	int (*ioctl)(struct sock___65 *, int, long unsigned int);
	int (*init)(struct sock___65 *);
	void (*destroy)(struct sock___65 *);
	void (*shutdown)(struct sock___65 *, int);
	int (*setsockopt)(struct sock___65 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___65 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___65 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___65 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___65 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___73 *, struct sock___65 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___73 *, struct sock___65 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___65 *, struct page___285 *, int, size_t, int);
	int (*bind)(struct sock___65 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___65 *, struct sk_buff___78 *);
	void (*release_cb)(struct sock___65 *);
	void (*mtu_reduced)(struct sock___65 *);
	void (*hash)(struct sock___65 *);
	void (*unhash)(struct sock___65 *);
	void (*rehash)(struct sock___65 *);
	int (*get_port)(struct sock___65 *, short unsigned int);
	void (*clear_sk)(struct sock___65 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___65 *);
	void (*enter_memory_pressure)(struct sock___65 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___269 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___51 *rsk_prot;
	struct timewait_sock_ops___48 *twsk_prot;
	union {
		struct inet_hashinfo___17 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___113 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___65 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___65 {
	void (*enter_memory_pressure)(struct sock___65 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___17 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___269 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___51 {
	int family;
	int obj_size;
	struct kmem_cache___269 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___65 *, struct request_sock___52 *);
	void (*send_ack)(struct sock___65 *, struct sk_buff___78 *, struct request_sock___52 *);
	void (*send_reset)(struct sock___65 *, struct sk_buff___78 *);
	void (*destructor)(struct request_sock___52 *);
	void (*syn_ack_timeout)(struct sock___65 *, struct request_sock___52 *);
};

struct timewait_sock_ops___48 {
	struct kmem_cache___269 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___65 *, struct sock___65 *, void *);
	void (*twsk_destructor)(struct sock___65 *);
};

struct inet_timewait_death_row___7 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___17 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct ifmcaddr6___42 {
	struct in6_addr mca_addr;
	struct inet6_dev___42 *idev;
	struct ifmcaddr6___42 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___42 {
	struct in6_addr aca_addr;
	struct inet6_dev___42 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___42 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct in_ifaddr___14 {
	struct hlist_node hash;
	struct in_ifaddr___14 *ifa_next;
	struct in_device___14 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct fib_nh_exception___3 {
	struct fib_nh_exception___3 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___32 *fnhe_rth;
	long unsigned int fnhe_stamp;
};

struct fnhe_hash_bucket___3 {
	struct fib_nh_exception___3 *chain;
};

struct fib_info___3;

struct fib_nh___3 {
	struct net_device___71 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___3 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	int nh_power;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___32 **nh_pcpu_rth_output;
	struct rtable___32 *nh_rth_input;
	struct fnhe_hash_bucket___3 *nh_exceptions;
};

struct fib_info___3 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___85 *fib_net;
	int fib_treeref;
	atomic_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_priority;
	u32 *fib_metrics;
	int fib_nhs;
	int fib_power;
	struct callback_head rcu;
	struct fib_nh___3 fib_nh[0];
};

struct fib_result___3 {
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___3 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct fib4_rule {
	struct fib_rule___5 common;
	u8 dst_len;
	u8 src_len;
	u8 tos;
	__be32 src;
	__be32 srcmask;
	__be32 dst;
	__be32 dstmask;
	u32 tclassid;
};

struct thread_info___127 {
	struct task_struct___268 *task;
	struct exec_domain___79 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct rta_mfc_stats {
	__u64 mfcs_packets;
	__u64 mfcs_bytes;
	__u64 mfcs_wrong_if;
};

struct pimreghdr {
	__u8 type;
	__u8 reserved;
	__be16 csum;
	__be32 flags;
};

typedef short unsigned int vifi_t;

struct vifctl {
	vifi_t vifc_vifi;
	unsigned char vifc_flags;
	unsigned char vifc_threshold;
	unsigned int vifc_rate_limit;
	union {
		struct in_addr vifc_lcl_addr;
		int vifc_lcl_ifindex;
	};
	struct in_addr vifc_rmt_addr;
};

struct mfcctl {
	struct in_addr mfcc_origin;
	struct in_addr mfcc_mcastgrp;
	vifi_t mfcc_parent;
	unsigned char mfcc_ttls[32];
	unsigned int mfcc_pkt_cnt;
	unsigned int mfcc_byte_cnt;
	unsigned int mfcc_wrong_if;
	int mfcc_expire;
};

struct sioc_sg_req {
	struct in_addr src;
	struct in_addr grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_vif_req {
	vifi_t vifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct igmpmsg {
	__u32 unused1;
	__u32 unused2;
	unsigned char im_msgtype;
	unsigned char im_mbz;
	unsigned char im_vif;
	unsigned char unused3;
	struct in_addr im_src;
	struct in_addr im_dst;
};

struct vif_device {
	struct net_device___57 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	__be32 local;
	__be32 remote;
	int link;
};

struct mfc_cache {
	struct list_head list;
	__be32 mfc_mcastgrp;
	__be32 mfc_origin;
	vifi_t mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___58 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			unsigned char ttls[32];
		} res;
	} mfc_un;
	struct callback_head rcu;
};

struct net_protocol___6 {
	void (*early_demux)(struct sk_buff___60 *);
	int (*handler)(struct sk_buff___60 *);
	void (*err_handler)(struct sk_buff___60 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct raw_sock___2 {
	struct inet_sock___5 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct ip_tunnel_parm {
	char name[16];
	int link;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	struct iphdr iph;
};

struct mr_table {
	struct list_head list;
	struct net___71 *net;
	u32 id;
	struct sock___47 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct list_head mfc_cache_array[64];
	struct vif_device vif_table[32];
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	int mroute_reg_vif_num;
};

struct ipmr_result {
	struct mr_table *mrt;
};

struct compat_sioc_sg_req {
	struct in_addr src;
	struct in_addr grp;
	compat_ulong_t pktcnt;
	compat_ulong_t bytecnt;
	compat_ulong_t wrong_if;
};

struct compat_sioc_vif_req {
	vifi_t vifi;
	compat_ulong_t icount;
	compat_ulong_t ocount;
	compat_ulong_t ibytes;
	compat_ulong_t obytes;
};

struct ipmr_vif_iter {
	struct seq_net_private___10 p;
	struct mr_table *mrt;
	int ct;
};

struct ipmr_mfc_iter {
	struct seq_net_private___10 p;
	struct mr_table *mrt;
	struct list_head *cache;
	int ct;
};

struct skb_frag_struct___21 {
	struct {
		struct page___280 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___21 skb_frag_t___21;

struct skb_shared_info___21 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___73 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___21 frags[17];
};

struct net_lro_stats {
	long unsigned int aggregated;
	long unsigned int flushed;
	long unsigned int no_desc;
};

struct net_lro_desc {
	struct sk_buff___73 *parent;
	struct sk_buff___73 *last_skb;
	struct skb_frag_struct___21 *next_frag;
	struct iphdr *iph;
	struct tcphdr *tcph;
	__wsum data_csum;
	__be32 tcp_rcv_tsecr;
	__be32 tcp_rcv_tsval;
	__be32 tcp_ack;
	u32 tcp_next_seq;
	u32 skb_tot_frags_len;
	u16 ip_tot_len;
	u16 tcp_saw_tstamp;
	__be16 tcp_window;
	int pkt_aggr_cnt;
	int vlan_packet;
	int mss;
	int active;
};

struct net_lro_mgr {
	struct net_device___71 *dev;
	struct net_lro_stats stats;
	long unsigned int features;
	u32 ip_summed;
	u32 ip_summed_aggr;
	int max_desc;
	int max_aggr;
	int frag_align_pad;
	struct net_lro_desc *lro_arr;
	int (*get_skb_header)(struct sk_buff___73 *, void **, void **, u64 *, void *);
	int (*get_frag_header)(struct skb_frag_struct___21 *, void **, void **, void **, u64 *, void *);
};

struct nf_hook_state___11 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___74 *in;
	struct net_device___74 *out;
	struct sock___63 *sk;
	int (*okfn)(struct sock___63 *, struct sk_buff___76 *);
};

struct nf_hook_ops___5;

typedef unsigned int nf_hookfn___5(const struct nf_hook_ops___5 *, struct sk_buff___76 *, const struct net_device___74 *, const struct net_device___74 *, const struct nf_hook_state___11 *);

struct nf_hook_ops___5 {
	struct list_head list;
	nf_hookfn___5 *hook;
	struct module *owner;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
	long unsigned int __rht_reserved1;
	long unsigned int __rht_reserved2;
	long unsigned int __rht_reserved3;
	long unsigned int __rht_reserved4;
	long unsigned int __rht_reserved5;
};

struct nf_queue_entry___2;

struct nf_afinfo___91 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___76 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___76 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___88 *, struct dst_entry___64 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___76 *, struct nf_queue_entry___2 *);
	int (*reroute)(struct sk_buff___76 *, const struct nf_queue_entry___2 *);
	int route_key_size;
};

struct nf_queue_entry___2 {
	struct list_head list;
	struct sk_buff___76 *skb;
	unsigned int id;
	struct nf_hook_ops___5 *elem;
	struct nf_hook_state___11 state;
	u16 size;
};

struct inet_cork___22 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___64 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___22 {
	struct inet_cork___22 base;
	struct flowi fl;
};

struct ipv6_pinfo___21;

struct inet_sock___22 {
	struct sock___63 sk;
	struct ipv6_pinfo___21 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___22 cork;
};

struct ipv6_fl_socklist___20;

struct ipv6_pinfo___21 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___20 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___76 *pktoptions;
	struct sk_buff___76 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___20;

struct ipv6_fl_socklist___20 {
	struct ipv6_fl_socklist___20 *next;
	struct ip6_flowlabel___20 *fl;
	struct callback_head rcu;
};

struct ip6_flowlabel___20 {
	struct ip6_flowlabel___20 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___88 *fl_net;
};

struct ip_rt_info {
	__be32 daddr;
	__be32 saddr;
	u_int8_t tos;
	u_int32_t mark;
};

struct module_version_attribute___5 {
	struct module_attribute___178 mattr;
	const char *module_name;
	const char *version;
};

struct bictcp {
	u32 cnt;
	u32 last_max_cwnd;
	u32 loss_cwnd;
	u32 last_cwnd;
	u32 last_time;
	u32 bic_origin_point;
	u32 bic_K;
	u32 delay_min;
	u32 epoch_start;
	u32 ack_cnt;
	u32 tcp_cwnd;
	u16 unused;
	u8 sample_cnt;
	u8 found;
	u32 round_start;
	u32 end_seq;
	u32 last_ack;
	u32 curr_rtt;
};

struct tcp_memcontrol___2 {
	struct cg_proto___55 cg_proto;
	struct res_counter tcp_memory_allocated;
	struct percpu_counter tcp_sockets_allocated;
	long int tcp_prot_mem[3];
	int tcp_memory_pressure;
};

struct page___286;

typedef struct page___286 *pgtable_t___286;

struct address_space___287;

struct kmem_cache___270;

struct page___286 {
	long unsigned int flags;
	struct address_space___287 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___286 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___286 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___270 *slab_cache;
		struct page___286 *first_page;
	};
	long: 64;
};

struct task_struct___288;

struct pv_cpu_ops___288 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___288 *);
	void (*end_context_switch)(struct task_struct___288 *);
};

struct mutex___289 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___288 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___281 {
	struct page___286 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___295;

struct nsproxy___167;

struct signal_struct___288;

struct css_set___182;

struct task_struct___288 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___288 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___295 *mm;
	struct mm_struct___295 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___288 *real_parent;
	struct task_struct___288 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___288 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___288 = 0,
		VTIME_USER___288 = 1,
		VTIME_SYS___288 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___167 *nsproxy;
	struct signal_struct___288 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___182 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___289 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___281 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___295 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___295 *, struct mm_struct___295 *);
	void (*dup_mmap)(struct mm_struct___295 *, struct mm_struct___295 *);
	void (*exit_mmap)(struct mm_struct___295 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___295 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___295 *);
	void (*pgd_free)(struct mm_struct___295 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___295 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___295 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___295 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___295 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___295 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___295 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___295 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___295 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___295 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___295 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___295 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___289 lock;
	void *vdso;
} mm_context_t___289;

struct xol_area___286;

struct uprobes_state___286 {
	struct xol_area___286 *xol_area;
};

struct vm_area_struct___295;

struct file___287;

struct core_state___288;

struct mm_struct___295 {
	struct vm_area_struct___295 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___295 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___295 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___289 context;
	long unsigned int flags;
	struct core_state___288 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___288 *owner;
	struct file___287 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___286 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___286 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___286 *page;
	long unsigned int vaddr;
};

struct kset___69;

struct kobj_type___69;

struct kobject___69 {
	const char *name;
	struct list_head entry;
	struct kobject___69 *parent;
	struct kset___69 *kset;
	struct kobj_type___69 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___269;

struct memcg_cache_params___270;

struct kmem_cache___270 {
	struct kmem_cache_cpu___269 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___69 kobj;
	struct memcg_cache_params___270 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___287;

struct address_space_operations___287;

struct address_space___287 {
	struct inode___287 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___289 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___287 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___287;

struct path___287 {
	struct vfsmount *mnt;
	struct dentry___287 *dentry;
};

struct file_operations___287;

struct file___287 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___287 f_path;
	struct inode___287 *f_inode;
	const struct file_operations___287 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___287 *f_mapping;
	struct mutex___289 f_pos_lock;
};

struct vm_operations_struct___261;

struct vm_area_struct___295 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___295 *vm_next;
	struct vm_area_struct___295 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___295 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___261 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___287 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___257;

struct vm_operations_struct___261 {
	void (*open)(struct vm_area_struct___295 *);
	void (*close)(struct vm_area_struct___295 *);
	int (*fault)(struct vm_area_struct___295 *, struct vm_fault___257 *);
	int (*page_mkwrite)(struct vm_area_struct___295 *, struct vm_fault___257 *);
	int (*access)(struct vm_area_struct___295 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___295 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___295 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___295 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___295 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___288 {
	struct task_struct___288 *task;
	struct core_thread___288 *next;
};

struct core_state___288 {
	atomic_t nr_threads;
	struct core_thread___288 dumper;
	struct completion startup;
};

struct irq_data___211;

struct x86_io_apic_ops___211 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___211 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___211;

struct irq_data___211 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___211 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___285;

struct dev_pm_ops___285 {
	int (*prepare)(struct device___285 *);
	void (*complete)(struct device___285 *);
	int (*suspend)(struct device___285 *);
	int (*resume)(struct device___285 *);
	int (*freeze)(struct device___285 *);
	int (*thaw)(struct device___285 *);
	int (*poweroff)(struct device___285 *);
	int (*restore)(struct device___285 *);
	int (*suspend_late)(struct device___285 *);
	int (*resume_early)(struct device___285 *);
	int (*freeze_late)(struct device___285 *);
	int (*thaw_early)(struct device___285 *);
	int (*poweroff_late)(struct device___285 *);
	int (*restore_early)(struct device___285 *);
	int (*suspend_noirq)(struct device___285 *);
	int (*resume_noirq)(struct device___285 *);
	int (*freeze_noirq)(struct device___285 *);
	int (*thaw_noirq)(struct device___285 *);
	int (*poweroff_noirq)(struct device___285 *);
	int (*restore_noirq)(struct device___285 *);
	int (*runtime_suspend)(struct device___285 *);
	int (*runtime_resume)(struct device___285 *);
	int (*runtime_idle)(struct device___285 *);
};

struct dev_pm_qos___88;

struct dev_pm_info___88 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___88 *qos;
};

struct dma_map_ops___150;

struct dev_archdata___150 {
	struct dma_map_ops___150 *dma_ops;
	void *iommu;
};

struct device_type___285;

struct bus_type___285;

struct device_driver___285;

struct dev_pm_domain___285;

struct class___285;

struct attribute_group___247;

struct device_rh___285;

struct device___285 {
	struct device___285 *parent;
	struct device_private *p;
	struct kobject___69 kobj;
	const char *init_name;
	const struct device_type___285 *type;
	struct mutex___289 mutex;
	struct bus_type___285 *bus;
	struct device_driver___285 *driver;
	void *platform_data;
	struct dev_pm_info___88 power;
	struct dev_pm_domain___285 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___150 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___285 *class;
	const struct attribute_group___247 **groups;
	void (*release)(struct device___285 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___285 *device_rh;
};

struct dev_pm_qos_request___89;

struct dev_pm_qos___88 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___89 *latency_req;
	struct dev_pm_qos_request___89 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___89 *latency_tolerance_req;
};

struct dev_pm_info_rh___285 {
	void (*set_latency_tolerance)(struct device___285 *, s32);
};

struct dev_pm_domain___285 {
	struct dev_pm_ops___285 ops;
};

struct smp_ops___288 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___288 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___288;

struct lruvec___288 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___288 *zone;
};

struct pglist_data___288;

struct zone___288 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___288 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___288 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___288 {
	struct zone___288 *zone;
	int zone_idx;
};

struct zonelist___288 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___288 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___288 {
	struct zone___288 node_zones[4];
	struct zonelist___288 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___288 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___92;

struct ctl_node___92 {
	struct rb_node node;
	struct ctl_table_header___92 *header;
};

struct ctl_table_root___92;

struct ctl_table_set___92;

struct ctl_dir___92;

struct ctl_table_header___92 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___92 *root;
	struct ctl_table_set___92 *set;
	struct ctl_dir___92 *parent;
	struct ctl_node___92 *node;
};

struct ctl_dir___92 {
	struct ctl_table_header___92 header;
	struct rb_root root;
};

struct ctl_table_set___92 {
	int (*is_seen)(struct ctl_table_set___92 *);
	struct ctl_dir___92 dir;
};

struct ctl_table_root___92 {
	struct ctl_table_set___92 default_set;
	struct ctl_table_set___92 * (*lookup)(struct ctl_table_root___92 *, struct nsproxy___167 *);
	int (*permissions)(struct ctl_table_header___92 *, struct ctl_table *);
};

struct net___91;

struct nsproxy___167 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___91 *net_ns;
};

struct signal_struct___288 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___288 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___288 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___289 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___182;

struct css_set___182 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___182 *subsys[11];
	struct callback_head callback_head;
};

struct sock___66;

struct kobj_ns_type_operations___66 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___66 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___66;

struct sock_common___66 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___66 *skc_prot;
	struct net___91 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___79;

struct sk_buff_head___78 {
	struct sk_buff___79 *next;
	struct sk_buff___79 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___67;

struct socket_wq___66;

struct dst_entry___67;

struct socket___67;

struct cg_proto___66;

struct sock___66 {
	struct sock_common___66 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___78 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___79 *head;
		struct sk_buff___79 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___67 *sk_filter;
	struct socket_wq___66 *sk_wq;
	struct sk_buff_head___78 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___67 *sk_rx_dst;
	struct dst_entry___67 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___78 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___78 sk_error_queue;
	struct proto___66 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___67 *sk_socket;
	void *sk_user_data;
	struct page_frag___281 sk_frag;
	struct sk_buff___79 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___66 *sk_cgrp;
	void (*sk_state_change)(struct sock___66 *);
	void (*sk_data_ready)(struct sock___66 *, int);
	void (*sk_write_space)(struct sock___66 *);
	void (*sk_error_report)(struct sock___66 *);
	int (*sk_backlog_rcv)(struct sock___66 *, struct sk_buff___79 *);
	void (*sk_destruct)(struct sock___66 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___249;

struct attribute_group___247 {
	const char *name;
	umode_t (*is_visible)(struct kobject___69 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___249 **bin_attrs;
};

struct bin_attribute___249 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___287 *, struct kobject___69 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___287 *, struct kobject___69 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	int (*mmap)(struct file___287 *, struct kobject___69 *, struct bin_attribute___249 *, struct vm_area_struct___295 *);
};

struct sysfs_ops___69 {
	ssize_t (*show)(struct kobject___69 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___69 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___69 *, const struct attribute *);
};

struct kset_uevent_ops___69;

struct kset___69 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___69 kobj;
	const struct kset_uevent_ops___69 *uevent_ops;
};

struct kobj_type___69 {
	void (*release)(struct kobject___69 *);
	const struct sysfs_ops___69 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___66 * (*child_ns_type)(struct kobject___69 *);
	const void * (*namespace)(struct kobject___69 *);
};

struct kset_uevent_ops___69 {
	int (* const filter)(struct kset___69 *, struct kobject___69 *);
	const char * (* const name)(struct kset___69 *, struct kobject___69 *);
	int (* const uevent)(struct kset___69 *, struct kobject___69 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___269 {
	void **freelist;
	long unsigned int tid;
	struct page___286 *page;
	struct page___286 *partial;
};

struct memcg_cache_params___270 {
	bool is_root_cache;
	union {
		struct kmem_cache___270 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___270 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct fasync_struct___287;

struct socket_wq___66 {
	wait_queue_head_t wait;
	struct fasync_struct___287 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___287 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___287 *fa_next;
	struct file___287 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___66;

struct socket___67 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___66 *wq;
	struct file___287 *file;
	struct sock___66 *sk;
	const struct proto_ops___66 *ops;
};

struct poll_table_struct___173;

struct kiocb___74;

struct proto_ops___66 {
	int family;
	struct module *owner;
	int (*release)(struct socket___67 *);
	int (*bind)(struct socket___67 *, struct sockaddr *, int);
	int (*connect)(struct socket___67 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___67 *, struct socket___67 *);
	int (*accept)(struct socket___67 *, struct socket___67 *, int);
	int (*getname)(struct socket___67 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___287 *, struct socket___67 *, struct poll_table_struct___173 *);
	int (*ioctl)(struct socket___67 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___67 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___67 *, int);
	int (*shutdown)(struct socket___67 *, int);
	int (*setsockopt)(struct socket___67 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___67 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___67 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___67 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___74 *, struct socket___67 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___74 *, struct socket___67 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___287 *, struct socket___67 *, struct vm_area_struct___295 *);
	ssize_t (*sendpage)(struct socket___67 *, struct page___286 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___67 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___66 *, int);
		struct {
			void (*set_peek_off)(struct sock___66 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___175)(struct file___287 *, wait_queue_head_t *, struct poll_table_struct___173 *);

struct poll_table_struct___173 {
	poll_queue_proc___175 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___74(struct kiocb___74 *, struct io_event *);

struct kiocb___74 {
	atomic_t ki_users;
	struct file___287 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___74 *ki_cancel;
	void (*ki_dtor)(struct kiocb___74 *);
	union {
		void *user;
		struct task_struct___288 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___89 {
	struct ctl_table_header___92 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___90 {
	struct mutex___289 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___89 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___92 *ctl;
};

struct netns_ipv4___89 {
	struct ctl_table_header___92 *forw_hdr;
	struct ctl_table_header___92 *frags_hdr;
	struct ctl_table_header___92 *ipv4_hdr;
	struct ctl_table_header___92 *route_hdr;
	struct ctl_table_header___92 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___66 *fibnl;
	struct sock___66 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___89 {
	struct ctl_table_header___92 *hdr;
	struct ctl_table_header___92 *route_hdr;
	struct ctl_table_header___92 *icmp_hdr;
	struct ctl_table_header___92 *frags_hdr;
	struct ctl_table_header___92 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___77;

struct neighbour___67;

struct dst_ops___91 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___91 *);
	struct dst_entry___67 * (*check)(struct dst_entry___67 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___67 *);
	unsigned int (*mtu)(const struct dst_entry___67 *);
	u32 * (*cow_metrics)(struct dst_entry___67 *, long unsigned int);
	void (*destroy)(struct dst_entry___67 *);
	void (*ifdown)(struct dst_entry___67 *, struct net_device___77 *, int);
	struct dst_entry___67 * (*negative_advice)(struct dst_entry___67 *);
	void (*link_failure)(struct sk_buff___79 *);
	void (*update_pmtu)(struct dst_entry___67 *, struct sock___66 *, struct sk_buff___79 *, u32);
	void (*redirect)(struct dst_entry___67 *, struct sock___66 *, struct sk_buff___79 *);
	int (*local_out)(struct sk_buff___79 *);
	struct neighbour___67 * (*neigh_lookup)(const struct dst_entry___67 *, struct sk_buff___79 *, const void *);
	struct kmem_cache___270 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___91 {
	struct netns_sysctl_ipv6___89 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___91 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___66 **icmp_sk;
	struct sock___66 *ndisc_sk;
	struct sock___66 *tcp_sk;
	struct sock___66 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___89 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___92 *sysctl_header;
	struct sock___66 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___66 {
	struct sock___66 *v4_ctl_sk;
	struct sock___66 *v6_ctl_sk;
};

struct netns_nf___89 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___92 *nf_log_dir_header;
};

struct nf_proto_net___89 {
	struct ctl_table_header___92 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___89 {
	struct nf_proto_net___89 pn;
	unsigned int timeout;
};

struct nf_tcp_net___89 {
	struct nf_proto_net___89 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___89 {
	struct nf_proto_net___89 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___89 {
	struct nf_proto_net___89 pn;
	unsigned int timeout;
};

struct nf_ip_net___89 {
	struct nf_generic_net___89 generic;
	struct nf_tcp_net___89 tcp;
	struct nf_udp_net___89 udp;
	struct nf_icmp_net___89 icmp;
	struct nf_icmp_net___89 icmpv6;
};

struct netns_ct___90 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___92 *sysctl_header;
	struct ctl_table_header___92 *acct_sysctl_header;
	struct ctl_table_header___92 *tstamp_sysctl_header;
	struct ctl_table_header___92 *event_sysctl_header;
	struct ctl_table_header___92 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___270 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___89 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___89 {
	struct netns_sysctl_ipv6___89 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___91 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___66 *nlsk;
	struct sock___66 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___92 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___91 xfrm4_dst_ops;
	struct dst_ops___91 xfrm6_dst_ops;
};

struct net___91 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___92 sysctls;
	struct sock___66 *rtnl;
	struct sock___66 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___77 *loopback_dev;
	struct netns_core___89 core;
	struct netns_mib mib;
	struct netns_packet___90 packet;
	struct netns_unix___89 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___89 ipv4;
	struct netns_ipv6___91 ipv6;
	struct netns_sctp___89 sctp;
	struct netns_dccp___66 dccp;
	struct netns_nf___89 nf;
	struct netns_xt xt;
	struct netns_ct___90 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___89 nf_frag;
	struct sock___66 *nfnl;
	struct sock___66 *nfnl_stash;
	struct sk_buff_head___78 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___91 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___66 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___66 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___289 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___289 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dma_map_ops___150 {
	void * (*alloc)(struct device___285 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___285 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___285 *, struct vm_area_struct___295 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___285 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___285 *, struct page___286 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___285 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___285 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___285 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___285 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___285 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___285 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___285 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___285 *, dma_addr_t);
	int (*dma_supported)(struct device___285 *, u64);
	int (*set_dma_mask)(struct device___285 *, u64);
	int is_phys;
};

struct bus_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___285 *, char *);
	ssize_t (*store)(struct bus_type___285 *, const char *, size_t);
};

struct device_attribute___285;

struct driver_attribute___285;

struct bus_type___285 {
	const char *name;
	const char *dev_name;
	struct device___285 *dev_root;
	struct bus_attribute___285 *bus_attrs;
	struct device_attribute___285 *dev_attrs;
	struct driver_attribute___285 *drv_attrs;
	const struct attribute_group___247 **bus_groups;
	const struct attribute_group___247 **dev_groups;
	const struct attribute_group___247 **drv_groups;
	int (*match)(struct device___285 *, struct device_driver___285 *);
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	int (*probe)(struct device___285 *);
	int (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*online)(struct device___285 *);
	int (*offline)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct device___285 *, struct device_attribute___285 *, char *);
	ssize_t (*store)(struct device___285 *, struct device_attribute___285 *, const char *, size_t);
};

struct driver_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___285 *, char *);
	ssize_t (*store)(struct device_driver___285 *, const char *, size_t);
};

struct device_driver___285 {
	const char *name;
	struct bus_type___285 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___285 *);
	int (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	const struct attribute_group___247 **groups;
	const struct dev_pm_ops___285 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___285 {
	const char *name;
	const struct attribute_group___247 **groups;
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
};

struct class_attribute___285;

struct class___285 {
	const char *name;
	struct module *owner;
	struct class_attribute___285 *class_attrs;
	struct device_attribute___285 *dev_attrs;
	const struct attribute_group___247 **dev_groups;
	struct bin_attribute___249 *dev_bin_attrs;
	struct kobject___69 *dev_kobj;
	int (*dev_uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *);
	void (*class_release)(struct class___285 *);
	void (*dev_release)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	const struct kobj_ns_type_operations___66 *ns_type;
	const void * (*namespace)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
	struct subsys_private *p;
};

struct class_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct class___285 *, struct class_attribute___285 *, char *);
	ssize_t (*store)(struct class___285 *, struct class_attribute___285 *, const char *, size_t);
	const void * (*namespace)(struct class___285 *, const struct class_attribute___285 *);
};

struct device_rh___285 {
	struct dev_pm_info_rh___285 power;
};

struct vm_fault___257 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___286 *page;
};

struct nf_bridge_info___77 {
	atomic_t use;
	unsigned int mask;
	struct net_device___77 *physindev;
	struct net_device___77 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___77(struct sk_buff___79 **);

struct net_device_ops___77;

struct ethtool_ops___77;

struct header_ops___77;

struct inet6_dev___43;

struct netdev_rx_queue___77;

struct netdev_queue___77;

struct rtnl_link_ops___68;

struct dcbnl_rtnl_ops___77;

struct net_device___77 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___77 *netdev_ops;
	const struct ethtool_ops___77 *ethtool_ops;
	const struct header_ops___77 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___69 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___43 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___77 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___77 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___77 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___77 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___77 = 0,
		NETREG_REGISTERED___77 = 1,
		NETREG_UNREGISTERING___77 = 2,
		NETREG_UNREGISTERED___77 = 3,
		NETREG_RELEASED___77 = 4,
		NETREG_DUMMY___77 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___77 = 0,
		RTNL_LINK_INITIALIZING___77 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___77 *);
	struct netpoll_info *npinfo;
	struct net___91 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___285 dev;
	const struct attribute_group___247 *sysfs_groups[4];
	const struct rtnl_link_ops___68 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___77 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___79 {
	struct sk_buff___79 *next;
	struct sk_buff___79 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___66 *sk;
	struct net_device___77 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___79 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___77 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___22 {
	struct {
		struct page___286 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___22 skb_frag_t___22;

struct skb_shared_info___22 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___79 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___22 frags[17];
};

struct file_lock___287;

struct seq_file___212;

struct file_operations___287 {
	struct module *owner;
	loff_t (*llseek)(struct file___287 *, loff_t, int);
	ssize_t (*read)(struct file___287 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___287 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___74 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___74 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___287 *, void *, filldir_t);
	unsigned int (*poll)(struct file___287 *, struct poll_table_struct___173 *);
	long int (*unlocked_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___287 *, struct vm_area_struct___295 *);
	int (*open)(struct inode___287 *, struct file___287 *);
	int (*flush)(struct file___287 *, fl_owner_t);
	int (*release)(struct inode___287 *, struct file___287 *);
	int (*fsync)(struct file___287 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___74 *, int);
	int (*fasync)(int, struct file___287 *, int);
	int (*lock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*sendpage)(struct file___287 *, struct page___286 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___287 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___287 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___287 *, long int, struct file_lock___287 **, void **);
		struct {
			int (*setlease)(struct file___287 *, long int, struct file_lock___287 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___287 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___212 *, struct file___287 *);
};

struct dev_pm_qos_request___89 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___285 *dev;
};

struct dentry_operations___287;

struct super_block___287;

struct dentry___287 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___287 *d_parent;
	struct qstr d_name;
	struct inode___287 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___287 *d_op;
	struct super_block___287 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___287;

struct dquot___287;

struct block_device___287;

struct inode___287 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___287 *i_op;
	struct super_block___287 *i_sb;
	struct address_space___287 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___289 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___287 *i_fop;
	struct file_lock___287 *i_flock;
	struct address_space___287 i_data;
	struct dquot___287 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___287 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___287 {
	int (*d_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_hash)(const struct dentry___287 *, struct qstr *);
	int (*d_compare)(const struct dentry___287 *, const struct dentry___287 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___287 *);
	void (*d_release)(struct dentry___287 *);
	void (*d_prune)(struct dentry___287 *);
	void (*d_iput)(struct dentry___287 *, struct inode___287 *);
	char * (*d_dname)(struct dentry___287 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___287 *);
	int (*d_manage)(struct dentry___287 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___287;

struct mem_dqinfo___287 {
	struct quota_format_type___287 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___287;

struct quota_info___287 {
	unsigned int flags;
	struct mutex___289 dqio_mutex;
	struct mutex___289 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___287 *files[2];
	struct mem_dqinfo___287 info[2];
	const struct quota_format_ops___287 *ops[2];
};

struct file_system_type___287;

struct super_operations___287;

struct dquot_operations___287;

struct quotactl_ops___287;

struct xattr_handler___183;

struct super_block___287 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___287 *s_type;
	const struct super_operations___287 *s_op;
	const struct dquot_operations___287 *dq_op;
	const struct quotactl_ops___287 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___287 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___183 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___287 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___287 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___289 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___287 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___287 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___287 *bd_inode;
	struct super_block___287 *bd_super;
	struct mutex___289 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___287 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___289 bd_fsfreeze_mutex;
};

struct cgroup___182;

struct cgroup_subsys_state___182 {
	struct cgroup___182 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___287 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___287 *ia_file;
};

struct dquot___287 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___289 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___287 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___287 {
	int qf_fmt_id;
	const struct quota_format_ops___287 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___287 *qf_next;
};

struct quota_format_ops___287 {
	int (*check_quota_file)(struct super_block___287 *, int);
	int (*read_file_info)(struct super_block___287 *, int);
	int (*write_file_info)(struct super_block___287 *, int);
	int (*free_file_info)(struct super_block___287 *, int);
	int (*read_dqblk)(struct dquot___287 *);
	int (*commit_dqblk)(struct dquot___287 *);
	int (*release_dqblk)(struct dquot___287 *);
};

struct dquot_operations___287 {
	int (*write_dquot)(struct dquot___287 *);
	struct dquot___287 * (*alloc_dquot)(struct super_block___287 *, int);
	void (*destroy_dquot)(struct dquot___287 *);
	int (*acquire_dquot)(struct dquot___287 *);
	int (*release_dquot)(struct dquot___287 *);
	int (*mark_dirty)(struct dquot___287 *);
	int (*write_info)(struct super_block___287 *, int);
	qsize_t * (*get_reserved_space)(struct inode___287 *);
};

struct quotactl_ops___287 {
	int (*quota_on)(struct super_block___287 *, int, int, struct path___287 *);
	int (*quota_on_meta)(struct super_block___287 *, int, int);
	int (*quota_off)(struct super_block___287 *, int);
	int (*quota_sync)(struct super_block___287 *, int);
	int (*get_info)(struct super_block___287 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___287 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___287 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___287 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___287 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___287 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___287 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___287 *, unsigned int);
};

struct address_space_operations___287 {
	int (*writepage)(struct page___286 *, struct writeback_control *);
	int (*readpage)(struct file___287 *, struct page___286 *);
	int (*writepages)(struct address_space___287 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___286 *);
	int (*readpages)(struct file___287 *, struct address_space___287 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___287 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___286 **, void **);
	int (*write_end)(struct file___287 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___286 *, void *);
	sector_t (*bmap)(struct address_space___287 *, sector_t);
	void (*invalidatepage)(struct page___286 *, long unsigned int);
	int (*releasepage)(struct page___286 *, gfp_t);
	void (*freepage)(struct page___286 *);
	ssize_t (*direct_IO)(int, struct kiocb___74 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___287 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___287 *, struct page___286 *, struct page___286 *, enum migrate_mode);
	int (*launder_page)(struct page___286 *);
	int (*is_partially_uptodate)(struct page___286 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___286 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___287 *, struct page___286 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___287 *, sector_t *);
	void (*swap_deactivate)(struct file___287 *);
	void (*invalidatepage_range)(struct page___286 *, unsigned int, unsigned int);
};

struct inode_operations___287 {
	struct dentry___287 * (*lookup)(struct inode___287 *, struct dentry___287 *, unsigned int);
	void * (*follow_link)(struct dentry___287 *, struct nameidata *);
	int (*permission)(struct inode___287 *, int);
	struct posix_acl * (*get_acl)(struct inode___287 *, int);
	int (*readlink)(struct dentry___287 *, char *, int);
	void (*put_link)(struct dentry___287 *, struct nameidata *, void *);
	int (*create)(struct inode___287 *, struct dentry___287 *, umode_t, bool);
	int (*link)(struct dentry___287 *, struct inode___287 *, struct dentry___287 *);
	int (*unlink)(struct inode___287 *, struct dentry___287 *);
	int (*symlink)(struct inode___287 *, struct dentry___287 *, const char *);
	int (*mkdir)(struct inode___287 *, struct dentry___287 *, umode_t);
	int (*rmdir)(struct inode___287 *, struct dentry___287 *);
	int (*mknod)(struct inode___287 *, struct dentry___287 *, umode_t, dev_t);
	int (*rename)(struct inode___287 *, struct dentry___287 *, struct inode___287 *, struct dentry___287 *);
	int (*setattr)(struct dentry___287 *, struct iattr___287 *);
	int (*getattr)(struct vfsmount *, struct dentry___287 *, struct kstat *);
	int (*setxattr)(struct dentry___287 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___287 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___287 *, char *, size_t);
	int (*removexattr)(struct dentry___287 *, const char *);
	int (*fiemap)(struct inode___287 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___287 *, struct timespec *, int);
	int (*atomic_open)(struct inode___287 *, struct dentry___287 *, struct file___287 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___287;

struct lock_manager_operations___287;

struct file_lock___287 {
	struct file_lock___287 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___287 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___287 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___287 *fl_ops;
	const struct lock_manager_operations___287 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___287 {
	void (*fl_copy_lock)(struct file_lock___287 *, struct file_lock___287 *);
	void (*fl_release_private)(struct file_lock___287 *);
};

struct lock_manager_operations___287 {
	int (*lm_compare_owner)(struct file_lock___287 *, struct file_lock___287 *);
	long unsigned int (*lm_owner_key)(struct file_lock___287 *);
	void (*lm_notify)(struct file_lock___287 *);
	int (*lm_grant)(struct file_lock___287 *, struct file_lock___287 *, int);
	void (*lm_break)(struct file_lock___287 *);
	int (*lm_change)(struct file_lock___287 **, int);
};

struct file_system_type___287 {
	const char *name;
	int fs_flags;
	struct dentry___287 * (*mount)(struct file_system_type___287 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___287 *);
	struct module *owner;
	struct file_system_type___287 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___287 {
	struct inode___287 * (*alloc_inode)(struct super_block___287 *);
	void (*destroy_inode)(struct inode___287 *);
	void (*dirty_inode)(struct inode___287 *, int);
	int (*write_inode)(struct inode___287 *, struct writeback_control *);
	int (*drop_inode)(struct inode___287 *);
	void (*evict_inode)(struct inode___287 *);
	void (*put_super)(struct super_block___287 *);
	int (*sync_fs)(struct super_block___287 *, int);
	int (*freeze_fs)(struct super_block___287 *);
	int (*unfreeze_fs)(struct super_block___287 *);
	int (*statfs)(struct dentry___287 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___287 *, int *, char *);
	void (*umount_begin)(struct super_block___287 *);
	int (*show_options)(struct seq_file___212 *, struct dentry___287 *);
	int (*show_devname)(struct seq_file___212 *, struct dentry___287 *);
	int (*show_path)(struct seq_file___212 *, struct dentry___287 *);
	int (*show_stats)(struct seq_file___212 *, struct dentry___287 *);
	ssize_t (*quota_read)(struct super_block___287 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___287 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___287 *);
	int (*bdev_try_to_free_page)(struct super_block___287 *, struct page___286 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___287 *);
	void (*free_cached_objects)(struct super_block___287 *, int);
};

struct xattr_handler___183 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___287 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___287 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___287 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___212;

struct seq_file___212 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___289 lock;
	const struct seq_operations___212 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___77 {
	int (*get_settings)(struct net_device___77 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___77 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___77 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___77 *);
	void (*get_regs)(struct net_device___77 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___77 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___77 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___77 *);
	void (*set_msglevel)(struct net_device___77 *, u32);
	int (*nway_reset)(struct net_device___77 *);
	u32 (*get_link)(struct net_device___77 *);
	int (*get_eeprom_len)(struct net_device___77 *);
	int (*get_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___77 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___77 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___77 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___77 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___77 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___77 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___77 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___77 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___77 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___77 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___77 *);
	void (*complete)(struct net_device___77 *);
	u32 (*get_priv_flags)(struct net_device___77 *);
	int (*set_priv_flags)(struct net_device___77 *, u32);
	int (*get_sset_count)(struct net_device___77 *, int);
	int (*get_rxnfc)(struct net_device___77 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___77 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___77 *, struct ethtool_flash *);
	int (*reset)(struct net_device___77 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___77 *);
	int (*get_rxfh_indir)(struct net_device___77 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___77 *, const u32 *);
	void (*get_channels)(struct net_device___77 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___77 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___77 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___77 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___77 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___77 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___77 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___77 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___77 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___77 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___77 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___77 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___38;

struct dst_entry___67 {
	struct callback_head callback_head;
	struct dst_entry___67 *child;
	struct net_device___77 *dev;
	struct dst_ops___91 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___67 *path;
	struct dst_entry___67 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___79 *);
	union {
		int (*output)(struct sock___66 *, struct sk_buff___79 *);
		struct {
			int (*output)(struct sk_buff___79 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___67 *next;
		struct rtable___38 *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___67;

struct neigh_parms___67;

struct neigh_ops___67;

struct neighbour___67 {
	struct neighbour___67 *next;
	struct neigh_table___67 *tbl;
	struct neigh_parms___67 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___78 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___67 *, struct sk_buff___79 *);
	const struct neigh_ops___67 *ops;
	struct callback_head rcu;
	struct net_device___77 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___92 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___79 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___79 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___91 *, struct dst_entry___67 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___79 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___79 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___211 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___211 *);
	void (*irq_shutdown)(struct irq_data___211 *);
	void (*irq_enable)(struct irq_data___211 *);
	void (*irq_disable)(struct irq_data___211 *);
	void (*irq_ack)(struct irq_data___211 *);
	void (*irq_mask)(struct irq_data___211 *);
	void (*irq_mask_ack)(struct irq_data___211 *);
	void (*irq_unmask)(struct irq_data___211 *);
	void (*irq_eoi)(struct irq_data___211 *);
	int (*irq_set_affinity)(struct irq_data___211 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___211 *);
	int (*irq_set_type)(struct irq_data___211 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___211 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___211 *);
	void (*irq_bus_sync_unlock)(struct irq_data___211 *);
	void (*irq_cpu_online)(struct irq_data___211 *);
	void (*irq_cpu_offline)(struct irq_data___211 *);
	void (*irq_suspend)(struct irq_data___211 *);
	void (*irq_resume)(struct irq_data___211 *);
	void (*irq_pm_shutdown)(struct irq_data___211 *);
	void (*irq_print_chip)(struct irq_data___211 *, struct seq_file___212 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___211 *, void *);
	long unsigned int flags;
};

struct seq_operations___212 {
	void * (*start)(struct seq_file___212 *, loff_t *);
	void (*stop)(struct seq_file___212 *, void *);
	void * (*next)(struct seq_file___212 *, void *, loff_t *);
	int (*show)(struct seq_file___212 *, void *);
};

struct dcbnl_rtnl_ops___77 {
	int (*ieee_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___77 *);
	u8 (*setstate)(struct net_device___77 *, u8);
	void (*getpermhwaddr)(struct net_device___77 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___77 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___77 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___77 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___77 *, int, u8 *);
	void (*setpfccfg)(struct net_device___77 *, int, u8);
	void (*getpfccfg)(struct net_device___77 *, int, u8 *);
	u8 (*setall)(struct net_device___77 *);
	u8 (*getcap)(struct net_device___77 *, int, u8 *);
	int (*getnumtcs)(struct net_device___77 *, int, u8 *);
	int (*setnumtcs)(struct net_device___77 *, int, u8);
	u8 (*getpfcstate)(struct net_device___77 *);
	void (*setpfcstate)(struct net_device___77 *, u8);
	void (*getbcncfg)(struct net_device___77 *, int, u32 *);
	void (*setbcncfg)(struct net_device___77 *, int, u32);
	void (*getbcnrp)(struct net_device___77 *, int, u8 *);
	void (*setbcnrp)(struct net_device___77 *, int, u8);
	u8 (*setapp)(struct net_device___77 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___77 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___77 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___77 *, int, u8);
	u8 (*getdcbx)(struct net_device___77 *);
	u8 (*setdcbx)(struct net_device___77 *, u8);
	int (*peer_getappinfo)(struct net_device___77 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___77 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___77 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___77 *, struct cee_pfc *);
};

struct cgroupfs_root___182;

struct cgroup___182 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___182 *parent;
	struct dentry___287 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___182 *subsys[11];
	struct cgroupfs_root___182 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___289 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___182 {
	struct super_block___287 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___182 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___118 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___287 *, struct file___287 *);
	ssize_t (*read)(struct cgroup___182 *, struct cftype___118 *, struct file___287 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___182 *, struct cftype___118 *);
	s64 (*read_s64)(struct cgroup___182 *, struct cftype___118 *);
	int (*read_map)(struct cgroup___182 *, struct cftype___118 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___182 *, struct cftype___118 *, struct seq_file___212 *);
	ssize_t (*write)(struct cgroup___182 *, struct cftype___118 *, struct file___287 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___182 *, struct cftype___118 *, u64);
	int (*write_s64)(struct cgroup___182 *, struct cftype___118 *, s64);
	int (*write_string)(struct cgroup___182 *, struct cftype___118 *, const char *);
	int (*trigger)(struct cgroup___182 *, unsigned int);
	int (*release)(struct inode___287 *, struct file___287 *);
	int (*register_event)(struct cgroup___182 *, struct cftype___118 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___182 *, struct cftype___118 *, struct eventfd_ctx *);
};

struct cftype_set___114 {
	struct list_head node;
	struct cftype___118 *cfts;
};

struct task_and_cgroup___114 {
	struct task_struct___288 *task;
	struct cgroup___182 *cgrp;
	struct css_set___182 *cg;
};

struct cgroup_taskset___114 {
	struct task_and_cgroup___114 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___182 *cur_cgrp;
};

struct cgroup_subsys___114 {
	struct cgroup_subsys_state___182 * (*css_alloc)(struct cgroup___182 *);
	int (*css_online)(struct cgroup___182 *);
	void (*css_offline)(struct cgroup___182 *);
	void (*css_free)(struct cgroup___182 *);
	int (*can_attach)(struct cgroup___182 *, struct cgroup_taskset___114 *);
	void (*cancel_attach)(struct cgroup___182 *, struct cgroup_taskset___114 *);
	void (*attach)(struct cgroup___182 *, struct cgroup_taskset___114 *);
	void (*fork)(struct task_struct___288 *);
	void (*exit)(struct cgroup___182 *, struct cgroup___182 *, struct task_struct___288 *);
	void (*bind)(struct cgroup___182 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___182 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___118 *base_cftypes;
	struct cftype_set___114 base_cftset;
	struct module *module;
};

struct request_sock_ops___52;

struct request_sock___53 {
	struct sock_common___66 __req_common;
	struct request_sock___53 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___52 *rsk_ops;
	struct sock___66 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___79 {
	struct sk_buff___79 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___79 *, struct netlink_callback___79 *);
	int (*done)(struct netlink_callback___79 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___77 {
	int (*create)(struct sk_buff___79 *, struct net_device___77 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___79 *, unsigned char *);
	int (*rebuild)(struct sk_buff___79 *);
	int (*cache)(const struct neighbour___67 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___77 *, const unsigned char *);
};

struct napi_struct___77 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___77 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___77 *dev;
	struct sk_buff___79 *gro_list;
	struct sk_buff___79 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___77 {
	struct net_device___77 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___69 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___77 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___69 kobj;
	struct net_device___77 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___77 {
	int (*ndo_init)(struct net_device___77 *);
	void (*ndo_uninit)(struct net_device___77 *);
	int (*ndo_open)(struct net_device___77 *);
	int (*ndo_stop)(struct net_device___77 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___79 *, struct net_device___77 *);
	u16 (*ndo_select_queue)(struct net_device___77 *, struct sk_buff___79 *);
	void (*ndo_change_rx_flags)(struct net_device___77 *, int);
	void (*ndo_set_rx_mode)(struct net_device___77 *);
	int (*ndo_set_mac_address)(struct net_device___77 *, void *);
	int (*ndo_validate_addr)(struct net_device___77 *);
	int (*ndo_do_ioctl)(struct net_device___77 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___77 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___77 *, int);
	int (*ndo_neigh_setup)(struct net_device___77 *, struct neigh_parms___67 *);
	void (*ndo_tx_timeout)(struct net_device___77 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___77 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___77 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___77 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___77 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___77 *);
	int (*ndo_netpoll_setup)(struct net_device___77 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___77 *);
	int (*ndo_busy_poll)(struct napi_struct___77 *);
	int (*ndo_set_vf_mac)(struct net_device___77 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___77 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___77 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___77 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___77 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___77 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___77 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___77 *, int, struct sk_buff___79 *);
	int (*ndo_setup_tc)(struct net_device___77 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___77 *);
	int (*ndo_fcoe_disable)(struct net_device___77 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___77 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___77 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___77 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___77 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___77 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___77 *, const struct sk_buff___79 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___77 *, struct net_device___77 *);
	int (*ndo_del_slave)(struct net_device___77 *, struct net_device___77 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___67 *);
	void (*ndo_neigh_destroy)(struct neighbour___67 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___79 *, struct netlink_callback___79 *, struct net_device___77 *, int);
	int (*ndo_bridge_setlink)(struct net_device___77 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___79 *, u32, u32, struct net_device___77 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___77 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___77 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___77 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___77 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___77 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___77 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___79 *, struct net_device___77 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___77 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___77 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___77 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___67 {
	struct net___91 *net;
	struct net_device___77 *dev;
	struct neigh_parms___67 *next;
	int (*neigh_setup)(struct neighbour___67 *);
	void (*neigh_cleanup)(struct neighbour___67 *);
	struct neigh_table___67 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___43;

struct ifacaddr6___43;

struct inet6_dev___43 {
	struct net_device___77 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___43 *mc_list;
	struct ifmcaddr6___43 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___43 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___67 *nd_parms;
	struct inet6_dev___43 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___68 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___77 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___91 *, struct net_device___77 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___77 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___77 *, struct list_head *);
	size_t (*get_size)(const struct net_device___77 *);
	int (*fill_info)(struct sk_buff___79 *, const struct net_device___77 *);
	size_t (*get_xstats_size)(const struct net_device___77 *);
	int (*fill_xstats)(struct sk_buff___79 *, const struct net_device___77 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___91 * (*get_link_net)(const struct net_device___77 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___77 *, struct net_device___77 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___77 *, const struct net_device___77 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___79 *, const struct net_device___77 *, const struct net_device___77 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___67 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___79 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___67;

struct neigh_hash_table___67;

struct neigh_table___67 {
	struct neigh_table___67 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___77 *, __u32 *);
	int (*constructor)(struct neighbour___67 *);
	int (*pconstructor)(struct pneigh_entry___67 *);
	void (*pdestructor)(struct pneigh_entry___67 *);
	void (*proxy_redo)(struct sk_buff___79 *);
	char *id;
	struct neigh_parms___67 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___78 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___67 *nht;
	struct pneigh_entry___67 **phash_buckets;
};

struct neigh_ops___67 {
	int family;
	void (*solicit)(struct neighbour___67 *, struct sk_buff___79 *);
	void (*error_report)(struct neighbour___67 *, struct sk_buff___79 *);
	int (*output)(struct neighbour___67 *, struct sk_buff___79 *);
	int (*connected_output)(struct neighbour___67 *, struct sk_buff___79 *);
};

struct pneigh_entry___67 {
	struct pneigh_entry___67 *next;
	struct net___91 *net;
	struct net_device___77 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___67 {
	struct neighbour___67 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___38 {
	struct dst_entry___67 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___49;

struct inet_hashinfo___18;

struct proto___66 {
	void (*close)(struct sock___66 *, long int);
	int (*connect)(struct sock___66 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___66 *, int);
	struct sock___66 * (*accept)(struct sock___66 *, int, int *);
	int (*ioctl)(struct sock___66 *, int, long unsigned int);
	int (*init)(struct sock___66 *);
	void (*destroy)(struct sock___66 *);
	void (*shutdown)(struct sock___66 *, int);
	int (*setsockopt)(struct sock___66 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___66 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___66 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___66 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___66 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___74 *, struct sock___66 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___74 *, struct sock___66 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___66 *, struct page___286 *, int, size_t, int);
	int (*bind)(struct sock___66 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___66 *, struct sk_buff___79 *);
	void (*release_cb)(struct sock___66 *);
	void (*mtu_reduced)(struct sock___66 *);
	void (*hash)(struct sock___66 *);
	void (*unhash)(struct sock___66 *);
	void (*rehash)(struct sock___66 *);
	int (*get_port)(struct sock___66 *, short unsigned int);
	void (*clear_sk)(struct sock___66 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___66 *);
	void (*enter_memory_pressure)(struct sock___66 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___270 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___52 *rsk_prot;
	struct timewait_sock_ops___49 *twsk_prot;
	union {
		struct inet_hashinfo___18 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___114 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___66 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___66 {
	void (*enter_memory_pressure)(struct sock___66 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___18 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___270 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___52 {
	int family;
	int obj_size;
	struct kmem_cache___270 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___66 *, struct request_sock___53 *);
	void (*send_ack)(struct sock___66 *, struct sk_buff___79 *, struct request_sock___53 *);
	void (*send_reset)(struct sock___66 *, struct sk_buff___79 *);
	void (*destructor)(struct request_sock___53 *);
	void (*syn_ack_timeout)(struct sock___66 *, struct request_sock___53 *);
};

struct timewait_sock_ops___49 {
	struct kmem_cache___270 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___66 *, struct sock___66 *, void *);
	void (*twsk_destructor)(struct sock___66 *);
};

struct listen_sock___12 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___53 *syn_table[0];
};

struct fastopen_queue___12 {
	struct request_sock___53 *rskq_rst_head;
	struct request_sock___53 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___12 {
	struct request_sock___53 *rskq_accept_head;
	struct request_sock___53 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___12 *listen_opt;
	struct fastopen_queue___12 *fastopenq;
};

struct inet_request_sock___7 {
	struct request_sock___53 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___79 *pktopts;
	};
};

struct inet_cork___23 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___67 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___23 {
	struct inet_cork___23 base;
	struct flowi fl;
};

struct ipv6_pinfo___22;

struct inet_sock___23 {
	struct sock___66 sk;
	struct ipv6_pinfo___22 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___23 cork;
};

struct ipv6_fl_socklist___21;

struct ipv6_pinfo___22 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___21 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___79 *pktoptions;
	struct sk_buff___79 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___12;

struct inet_connection_sock_af_ops___12 {
	int (*queue_xmit)(struct sk_buff___79 *, struct flowi *);
	void (*send_check)(struct sock___66 *, struct sk_buff___79 *);
	int (*rebuild_header)(struct sock___66 *);
	void (*sk_rx_dst_set)(struct sock___66 *, const struct sk_buff___79 *);
	int (*conn_request)(struct sock___66 *, struct sk_buff___79 *);
	struct sock___66 * (*syn_recv_sock)(struct sock___66 *, struct sk_buff___79 *, struct request_sock___53 *, struct dst_entry___67 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___66 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___66 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___66 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___66 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___66 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___66 *, const struct inet_bind_bucket___12 *, bool);
	void (*mtu_reduced)(struct sock___66 *);
};

struct inet_bind_bucket___12 {
	struct net___91 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___7;

struct inet_connection_sock___12 {
	struct inet_sock___23 icsk_inet;
	struct request_sock_queue___12 icsk_accept_queue;
	struct inet_bind_bucket___12 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___7 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___12 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___66 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___7 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___66 *);
	void (*release)(struct sock___66 *);
	u32 (*ssthresh)(struct sock___66 *);
	void (*cong_avoid)(struct sock___66 *, u32, u32);
	void (*set_state)(struct sock___66 *, u8);
	void (*cwnd_event)(struct sock___66 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___66 *, u32);
	u32 (*undo_cwnd)(struct sock___66 *);
	void (*pkts_acked)(struct sock___66 *, u32, s32);
	int (*get_info)(struct sock___66 *, u32, struct sk_buff___79 *);
	char name[16];
	struct module *owner;
};

struct ip6_flowlabel___21;

struct ipv6_fl_socklist___21 {
	struct ipv6_fl_socklist___21 *next;
	struct ip6_flowlabel___21 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___43 {
	struct in6_addr mca_addr;
	struct inet6_dev___43 *idev;
	struct ifmcaddr6___43 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___43 {
	struct in6_addr aca_addr;
	struct inet6_dev___43 *aca_idev;
	struct rt6_info *aca_rt;
	struct ifacaddr6___43 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___21 {
	struct ip6_flowlabel___21 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___91 *fl_net;
};

struct netlbl_audit {
	u32 secid;
	kuid_t loginuid;
	u32 sessionid;
};

struct cipso_v4_std_map_tbl {
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} lvl;
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} cat;
};

struct cipso_v4_doi {
	u32 doi;
	u32 type;
	union {
		struct cipso_v4_std_map_tbl *std;
	} map;
	u8 tags[5];
	atomic_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

struct cipso_v4_map_cache_bkt {
	spinlock_t lock;
	u32 size;
	struct list_head list;
};

struct cipso_v4_map_cache_entry {
	u32 hash;
	unsigned char *key;
	size_t key_len;
	struct netlbl_lsm_cache *lsm_data;
	u32 activity;
	struct list_head list;
};

struct xfrm_dst;

struct xfrm_policy_afinfo {
	short unsigned int family;
	struct dst_ops___85 *dst_ops;
	void (*garbage_collect)(struct net___85 *);
	struct dst_entry___61 * (*dst_lookup)(struct net___85 *, int, const xfrm_address_t *, const xfrm_address_t *);
	int (*get_saddr)(struct net___85 *, xfrm_address_t *, xfrm_address_t *);
	void (*decode_session)(struct sk_buff___73 *, struct flowi *, int);
	int (*get_tos)(const struct flowi *);
	void (*init_dst)(struct net___85 *, struct xfrm_dst *);
	int (*init_path)(struct xfrm_dst *, struct dst_entry___61 *, int);
	int (*fill_dst)(struct xfrm_dst *, struct net_device___71 *, const struct flowi *);
	struct dst_entry___61 * (*blackhole_route)(struct net___85 *, struct dst_entry___61 *);
};

struct xfrm_dst {
	union {
		struct dst_entry___61 dst;
		struct rtable___32 rt;
		struct rt6_info___15 rt6;
	} u;
	struct dst_entry___61 *route;
	struct flow_cache_object flo;
	struct xfrm_policy___15 *pols[2];
	int num_pols;
	int num_xfrms;
	struct flowi *origin;
	struct xfrm_selector *partner;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_tunnel;

struct ip6_tnl;

struct xfrm_tunnel_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	union {
		struct ip_tunnel *ip4;
		struct ip6_tnl *ip6;
	} tunnel;
};

struct xfrm_mode_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	__be16 id;
	__be16 frag_off;
	u8 ihl;
	u8 tos;
	u8 ttl;
	u8 protocol;
	u8 optlen;
	u8 flow_lbl[3];
};

struct nf_hook_state___12 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___67 *in;
	struct net_device___67 *out;
	struct sock___26 *sk;
	int (*okfn)(struct sock___26 *, struct sk_buff___36 *);
};

struct udp_sock___3 {
	struct inet_sock___15 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___26 *, struct sk_buff___36 *);
	void (*encap_destroy)(struct sock___26 *);
};

struct xfrm_spi_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	unsigned int daddroff;
	unsigned int family;
};

struct page___287;

typedef struct page___287 *pgtable_t___287;

struct address_space___288;

struct kmem_cache___271;

struct page___287 {
	long unsigned int flags;
	struct address_space___288 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___287 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___287 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___271 *slab_cache;
		struct page___287 *first_page;
	};
	long: 64;
};

struct task_struct___289;

struct pv_cpu_ops___289 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___289 *);
	void (*end_context_switch)(struct task_struct___289 *);
};

struct mutex___290 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___289 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___282 {
	struct page___287 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___296;

struct nsproxy___168;

struct signal_struct___289;

struct css_set___183;

struct task_struct___289 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___289 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___296 *mm;
	struct mm_struct___296 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___289 *real_parent;
	struct task_struct___289 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___289 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___289 = 0,
		VTIME_USER___289 = 1,
		VTIME_SYS___289 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___168 *nsproxy;
	struct signal_struct___289 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___183 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___290 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___282 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___296 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___296 *, struct mm_struct___296 *);
	void (*dup_mmap)(struct mm_struct___296 *, struct mm_struct___296 *);
	void (*exit_mmap)(struct mm_struct___296 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___296 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___296 *);
	void (*pgd_free)(struct mm_struct___296 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___296 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___296 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___296 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___296 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___296 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___296 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___296 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___296 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___296 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___296 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___296 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___290 lock;
	void *vdso;
} mm_context_t___290;

struct xol_area___287;

struct uprobes_state___287 {
	struct xol_area___287 *xol_area;
};

struct vm_area_struct___296;

struct file___288;

struct core_state___289;

struct mm_struct___296 {
	struct vm_area_struct___296 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___296 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___296 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___290 context;
	long unsigned int flags;
	struct core_state___289 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___289 *owner;
	struct file___288 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___287 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___70;

struct kobj_type___70;

struct kobject___70 {
	const char *name;
	struct list_head entry;
	struct kobject___70 *parent;
	struct kset___70 *kset;
	struct kobj_type___70 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___179;

struct module_kobject___179 {
	struct kobject___70 kobj;
	struct module___179 *mod;
	struct kobject___70 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___179;

struct module___179 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___179 mkobj;
	struct module_attribute___179 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___70 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___289 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___287 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___287 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___270;

struct memcg_cache_params___271;

struct kmem_cache___271 {
	struct kmem_cache_cpu___270 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___70 kobj;
	struct memcg_cache_params___271 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___288;

struct address_space_operations___288;

struct address_space___288 {
	struct inode___288 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___290 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___288 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___288;

struct path___288 {
	struct vfsmount *mnt;
	struct dentry___288 *dentry;
};

struct file_operations___288;

struct file___288 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___288 f_path;
	struct inode___288 *f_inode;
	const struct file_operations___288 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___288 *f_mapping;
	struct mutex___290 f_pos_lock;
};

struct vm_operations_struct___262;

struct vm_area_struct___296 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___296 *vm_next;
	struct vm_area_struct___296 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___296 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___262 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___288 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___258;

struct vm_operations_struct___262 {
	void (*open)(struct vm_area_struct___296 *);
	void (*close)(struct vm_area_struct___296 *);
	int (*fault)(struct vm_area_struct___296 *, struct vm_fault___258 *);
	int (*page_mkwrite)(struct vm_area_struct___296 *, struct vm_fault___258 *);
	int (*access)(struct vm_area_struct___296 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___296 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___296 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___296 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___296 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___289 {
	struct task_struct___289 *task;
	struct core_thread___289 *next;
};

struct core_state___289 {
	atomic_t nr_threads;
	struct core_thread___289 dumper;
	struct completion startup;
};

struct fasync_struct___288;

struct socket_wq___67 {
	wait_queue_head_t wait;
	struct fasync_struct___288 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___288 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___288 *fa_next;
	struct file___288 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___67;

struct proto_ops___67;

struct socket___68 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___67 *wq;
	struct file___288 *file;
	struct sock___67 *sk;
	const struct proto_ops___67 *ops;
};

struct proto___67;

struct net___92;

struct sock_common___67 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___67 *skc_prot;
	struct net___92 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___80;

struct sk_buff_head___79 {
	struct sk_buff___80 *next;
	struct sk_buff___80 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___68;

struct xfrm_policy___18;

struct dst_entry___68;

struct cg_proto___67;

struct sock___67 {
	struct sock_common___67 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___79 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___80 *head;
		struct sk_buff___80 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___68 *sk_filter;
	struct socket_wq___67 *sk_wq;
	struct sk_buff_head___79 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___18 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___68 *sk_rx_dst;
	struct dst_entry___68 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___79 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___79 sk_error_queue;
	struct proto___67 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___68 *sk_socket;
	void *sk_user_data;
	struct page_frag___282 sk_frag;
	struct sk_buff___80 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___67 *sk_cgrp;
	void (*sk_state_change)(struct sock___67 *);
	void (*sk_data_ready)(struct sock___67 *, int);
	void (*sk_write_space)(struct sock___67 *);
	void (*sk_error_report)(struct sock___67 *);
	int (*sk_backlog_rcv)(struct sock___67 *, struct sk_buff___80 *);
	void (*sk_destruct)(struct sock___67 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___174;

struct kiocb___75;

struct proto_ops___67 {
	int family;
	struct module___179 *owner;
	int (*release)(struct socket___68 *);
	int (*bind)(struct socket___68 *, struct sockaddr *, int);
	int (*connect)(struct socket___68 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___68 *, struct socket___68 *);
	int (*accept)(struct socket___68 *, struct socket___68 *, int);
	int (*getname)(struct socket___68 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___288 *, struct socket___68 *, struct poll_table_struct___174 *);
	int (*ioctl)(struct socket___68 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___68 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___68 *, int);
	int (*shutdown)(struct socket___68 *, int);
	int (*setsockopt)(struct socket___68 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___68 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___68 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___68 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___75 *, struct socket___68 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___75 *, struct socket___68 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___288 *, struct socket___68 *, struct vm_area_struct___296 *);
	ssize_t (*sendpage)(struct socket___68 *, struct page___287 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___68 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___67 *, int);
		struct {
			void (*set_peek_off)(struct sock___67 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___176)(struct file___288 *, wait_queue_head_t *, struct poll_table_struct___174 *);

struct poll_table_struct___174 {
	poll_queue_proc___176 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___75(struct kiocb___75 *, struct io_event *);

struct kiocb___75 {
	atomic_t ki_users;
	struct file___288 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___75 *ki_cancel;
	void (*ki_dtor)(struct kiocb___75 *);
	union {
		void *user;
		struct task_struct___289 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___93;

struct ctl_table_set___93;

struct ctl_dir___93;

struct ctl_node___93;

struct ctl_table_header___93 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___93 *root;
	struct ctl_table_set___93 *set;
	struct ctl_dir___93 *parent;
	struct ctl_node___93 *node;
};

struct ctl_dir___93 {
	struct ctl_table_header___93 header;
	struct rb_root root;
};

struct ctl_table_set___93 {
	int (*is_seen)(struct ctl_table_set___93 *);
	struct ctl_dir___93 dir;
};

struct netns_core___90 {
	struct ctl_table_header___93 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___91 {
	struct mutex___290 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___90 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___93 *ctl;
};

struct netns_ipv4___90 {
	struct ctl_table_header___93 *forw_hdr;
	struct ctl_table_header___93 *frags_hdr;
	struct ctl_table_header___93 *ipv4_hdr;
	struct ctl_table_header___93 *route_hdr;
	struct ctl_table_header___93 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___67 *fibnl;
	struct sock___67 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___90 {
	struct ctl_table_header___93 *hdr;
	struct ctl_table_header___93 *route_hdr;
	struct ctl_table_header___93 *icmp_hdr;
	struct ctl_table_header___93 *frags_hdr;
	struct ctl_table_header___93 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___78;

struct neighbour___68;

struct dst_ops___92 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___92 *);
	struct dst_entry___68 * (*check)(struct dst_entry___68 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___68 *);
	unsigned int (*mtu)(const struct dst_entry___68 *);
	u32 * (*cow_metrics)(struct dst_entry___68 *, long unsigned int);
	void (*destroy)(struct dst_entry___68 *);
	void (*ifdown)(struct dst_entry___68 *, struct net_device___78 *, int);
	struct dst_entry___68 * (*negative_advice)(struct dst_entry___68 *);
	void (*link_failure)(struct sk_buff___80 *);
	void (*update_pmtu)(struct dst_entry___68 *, struct sock___67 *, struct sk_buff___80 *, u32);
	void (*redirect)(struct dst_entry___68 *, struct sock___67 *, struct sk_buff___80 *);
	int (*local_out)(struct sk_buff___80 *);
	struct neighbour___68 * (*neigh_lookup)(const struct dst_entry___68 *, struct sk_buff___80 *, const void *);
	struct kmem_cache___271 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___18;

struct fib6_table___18;

struct netns_ipv6___92 {
	struct netns_sysctl_ipv6___90 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___18 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___18 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___92 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___18 *ip6_prohibit_entry;
	struct rt6_info___18 *ip6_blk_hole_entry;
	struct fib6_table___18 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___67 **icmp_sk;
	struct sock___67 *ndisc_sk;
	struct sock___67 *tcp_sk;
	struct sock___67 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___90 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___93 *sysctl_header;
	struct sock___67 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___67 {
	struct sock___67 *v4_ctl_sk;
	struct sock___67 *v6_ctl_sk;
};

struct netns_nf___90 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___93 *nf_log_dir_header;
};

struct nf_proto_net___90 {
	struct ctl_table_header___93 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___90 {
	struct nf_proto_net___90 pn;
	unsigned int timeout;
};

struct nf_tcp_net___90 {
	struct nf_proto_net___90 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___90 {
	struct nf_proto_net___90 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___90 {
	struct nf_proto_net___90 pn;
	unsigned int timeout;
};

struct nf_ip_net___90 {
	struct nf_generic_net___90 generic;
	struct nf_tcp_net___90 tcp;
	struct nf_udp_net___90 udp;
	struct nf_icmp_net___90 icmp;
	struct nf_icmp_net___90 icmpv6;
};

struct netns_ct___91 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___93 *sysctl_header;
	struct ctl_table_header___93 *acct_sysctl_header;
	struct ctl_table_header___93 *tstamp_sysctl_header;
	struct ctl_table_header___93 *event_sysctl_header;
	struct ctl_table_header___93 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___271 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___90 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___90 {
	struct netns_sysctl_ipv6___90 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___92 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___67 *nlsk;
	struct sock___67 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___93 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___92 xfrm4_dst_ops;
	struct dst_ops___92 xfrm6_dst_ops;
};

struct net___92 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___93 sysctls;
	struct sock___67 *rtnl;
	struct sock___67 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___78 *loopback_dev;
	struct netns_core___90 core;
	struct netns_mib mib;
	struct netns_packet___91 packet;
	struct netns_unix___90 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___90 ipv4;
	struct netns_ipv6___92 ipv6;
	struct netns_sctp___90 sctp;
	struct netns_dccp___67 dccp;
	struct netns_nf___90 nf;
	struct netns_xt xt;
	struct netns_ct___91 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___90 nf_frag;
	struct sock___67 *nfnl;
	struct sock___67 *nfnl_stash;
	struct sk_buff_head___79 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___92 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___67 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___67 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___290 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___290 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___289;

struct lruvec___289 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___289 *zone;
};

struct pglist_data___289;

struct zone___289 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___289 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___289 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___289 {
	struct zone___289 *zone;
	int zone_idx;
};

struct zonelist___289 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___289 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___289 {
	struct zone___289 node_zones[4];
	struct zonelist___289 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___289 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___212;

struct x86_io_apic_ops___212 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___212 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___212;

struct irq_data___212 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___212 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___286;

struct dev_pm_ops___286 {
	int (*prepare)(struct device___286 *);
	void (*complete)(struct device___286 *);
	int (*suspend)(struct device___286 *);
	int (*resume)(struct device___286 *);
	int (*freeze)(struct device___286 *);
	int (*thaw)(struct device___286 *);
	int (*poweroff)(struct device___286 *);
	int (*restore)(struct device___286 *);
	int (*suspend_late)(struct device___286 *);
	int (*resume_early)(struct device___286 *);
	int (*freeze_late)(struct device___286 *);
	int (*thaw_early)(struct device___286 *);
	int (*poweroff_late)(struct device___286 *);
	int (*restore_early)(struct device___286 *);
	int (*suspend_noirq)(struct device___286 *);
	int (*resume_noirq)(struct device___286 *);
	int (*freeze_noirq)(struct device___286 *);
	int (*thaw_noirq)(struct device___286 *);
	int (*poweroff_noirq)(struct device___286 *);
	int (*restore_noirq)(struct device___286 *);
	int (*runtime_suspend)(struct device___286 *);
	int (*runtime_resume)(struct device___286 *);
	int (*runtime_idle)(struct device___286 *);
};

struct dev_pm_qos___89;

struct dev_pm_info___89 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___89 *qos;
};

struct dma_map_ops___151;

struct dev_archdata___151 {
	struct dma_map_ops___151 *dma_ops;
	void *iommu;
};

struct device_type___286;

struct bus_type___286;

struct device_driver___286;

struct dev_pm_domain___286;

struct class___286;

struct attribute_group___248;

struct device_rh___286;

struct device___286 {
	struct device___286 *parent;
	struct device_private *p;
	struct kobject___70 kobj;
	const char *init_name;
	const struct device_type___286 *type;
	struct mutex___290 mutex;
	struct bus_type___286 *bus;
	struct device_driver___286 *driver;
	void *platform_data;
	struct dev_pm_info___89 power;
	struct dev_pm_domain___286 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___151 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___286 *class;
	const struct attribute_group___248 **groups;
	void (*release)(struct device___286 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___286 *device_rh;
};

struct dev_pm_qos_request___90;

struct dev_pm_qos___89 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___90 *latency_req;
	struct dev_pm_qos_request___90 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___90 *latency_tolerance_req;
};

struct dev_pm_info_rh___286 {
	void (*set_latency_tolerance)(struct device___286 *, s32);
};

struct dev_pm_domain___286 {
	struct dev_pm_ops___286 ops;
};

struct smp_ops___289 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___289 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct kobj_ns_type_operations___67 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___67 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___250;

struct attribute_group___248 {
	const char *name;
	umode_t (*is_visible)(struct kobject___70 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___250 **bin_attrs;
};

struct bin_attribute___250 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___288 *, struct kobject___70 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___288 *, struct kobject___70 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	int (*mmap)(struct file___288 *, struct kobject___70 *, struct bin_attribute___250 *, struct vm_area_struct___296 *);
};

struct sysfs_ops___70 {
	ssize_t (*show)(struct kobject___70 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___70 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___70 *, const struct attribute *);
};

struct kset_uevent_ops___70;

struct kset___70 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___70 kobj;
	const struct kset_uevent_ops___70 *uevent_ops;
};

struct kobj_type___70 {
	void (*release)(struct kobject___70 *);
	const struct sysfs_ops___70 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___67 * (*child_ns_type)(struct kobject___70 *);
	const void * (*namespace)(struct kobject___70 *);
};

struct kset_uevent_ops___70 {
	int (* const filter)(struct kset___70 *, struct kobject___70 *);
	const char * (* const name)(struct kset___70 *, struct kobject___70 *);
	int (* const uevent)(struct kset___70 *, struct kobject___70 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___270 {
	void **freelist;
	long unsigned int tid;
	struct page___287 *page;
	struct page___287 *partial;
};

struct memcg_cache_params___271 {
	bool is_root_cache;
	union {
		struct kmem_cache___271 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___271 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___151 {
	void * (*alloc)(struct device___286 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___286 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___286 *, struct vm_area_struct___296 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___286 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___286 *, struct page___287 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___286 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___286 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___286 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___286 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___286 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___286 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___286 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___286 *, dma_addr_t);
	int (*dma_supported)(struct device___286 *, u64);
	int (*set_dma_mask)(struct device___286 *, u64);
	int is_phys;
};

struct bus_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___286 *, char *);
	ssize_t (*store)(struct bus_type___286 *, const char *, size_t);
};

struct device_attribute___286;

struct driver_attribute___286;

struct bus_type___286 {
	const char *name;
	const char *dev_name;
	struct device___286 *dev_root;
	struct bus_attribute___286 *bus_attrs;
	struct device_attribute___286 *dev_attrs;
	struct driver_attribute___286 *drv_attrs;
	const struct attribute_group___248 **bus_groups;
	const struct attribute_group___248 **dev_groups;
	const struct attribute_group___248 **drv_groups;
	int (*match)(struct device___286 *, struct device_driver___286 *);
	int (*uevent)(struct device___286 *, struct kobj_uevent_env *);
	int (*probe)(struct device___286 *);
	int (*remove)(struct device___286 *);
	void (*shutdown)(struct device___286 *);
	int (*online)(struct device___286 *);
	int (*offline)(struct device___286 *);
	int (*suspend)(struct device___286 *, pm_message_t);
	int (*resume)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct device___286 *, struct device_attribute___286 *, char *);
	ssize_t (*store)(struct device___286 *, struct device_attribute___286 *, const char *, size_t);
};

struct driver_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___286 *, char *);
	ssize_t (*store)(struct device_driver___286 *, const char *, size_t);
};

struct device_driver___286 {
	const char *name;
	struct bus_type___286 *bus;
	struct module___179 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___286 *);
	int (*remove)(struct device___286 *);
	void (*shutdown)(struct device___286 *);
	int (*suspend)(struct device___286 *, pm_message_t);
	int (*resume)(struct device___286 *);
	const struct attribute_group___248 **groups;
	const struct dev_pm_ops___286 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___286 {
	const char *name;
	const struct attribute_group___248 **groups;
	int (*uevent)(struct device___286 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___286 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
};

struct class_attribute___286;

struct class___286 {
	const char *name;
	struct module___179 *owner;
	struct class_attribute___286 *class_attrs;
	struct device_attribute___286 *dev_attrs;
	const struct attribute_group___248 **dev_groups;
	struct bin_attribute___250 *dev_bin_attrs;
	struct kobject___70 *dev_kobj;
	int (*dev_uevent)(struct device___286 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___286 *, umode_t *);
	void (*class_release)(struct class___286 *);
	void (*dev_release)(struct device___286 *);
	int (*suspend)(struct device___286 *, pm_message_t);
	int (*resume)(struct device___286 *);
	const struct kobj_ns_type_operations___67 *ns_type;
	const void * (*namespace)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
	struct subsys_private *p;
};

struct class_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct class___286 *, struct class_attribute___286 *, char *);
	ssize_t (*store)(struct class___286 *, struct class_attribute___286 *, const char *, size_t);
	const void * (*namespace)(struct class___286 *, const struct class_attribute___286 *);
};

struct device_rh___286 {
	struct dev_pm_info_rh___286 power;
};

struct vm_fault___258 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___287 *page;
};

struct ctl_node___93 {
	struct rb_node node;
	struct ctl_table_header___93 *header;
};

struct ctl_table_root___93 {
	struct ctl_table_set___93 default_set;
	struct ctl_table_set___93 * (*lookup)(struct ctl_table_root___93 *, struct nsproxy___168 *);
	int (*permissions)(struct ctl_table_header___93 *, struct ctl_table *);
};

struct nsproxy___168 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___92 *net_ns;
};

struct signal_struct___289 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___289 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___289 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___290 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___183;

struct css_set___183 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___183 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___78 {
	atomic_t use;
	unsigned int mask;
	struct net_device___78 *physindev;
	struct net_device___78 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___78(struct sk_buff___80 **);

struct net_device_ops___78;

struct ethtool_ops___78;

struct header_ops___78;

struct inet6_dev___44;

struct netdev_rx_queue___78;

struct netdev_queue___78;

struct rtnl_link_ops___69;

struct dcbnl_rtnl_ops___78;

struct net_device___78 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___78 *netdev_ops;
	const struct ethtool_ops___78 *ethtool_ops;
	const struct header_ops___78 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___70 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___44 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___78 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___78 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___78 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___78 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___78 = 0,
		NETREG_REGISTERED___78 = 1,
		NETREG_UNREGISTERING___78 = 2,
		NETREG_UNREGISTERED___78 = 3,
		NETREG_RELEASED___78 = 4,
		NETREG_DUMMY___78 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___78 = 0,
		RTNL_LINK_INITIALIZING___78 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___78 *);
	struct netpoll_info *npinfo;
	struct net___92 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___286 dev;
	const struct attribute_group___248 *sysfs_groups[4];
	const struct rtnl_link_ops___69 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___78 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___18;

struct sk_buff___80 {
	struct sk_buff___80 *next;
	struct sk_buff___80 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___67 *sk;
	struct net_device___78 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___18 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___80 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___78 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___18;

struct sec_path___18 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___18 *xvec[6];
};

struct module_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___179 *, struct module_kobject___179 *, char *);
	ssize_t (*store)(struct module_attribute___179 *, struct module_kobject___179 *, const char *, size_t);
	void (*setup)(struct module___179 *, const char *);
	int (*test)(struct module___179 *);
	void (*free)(struct module___179 *);
};

struct nf_hook_state___13 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___78 *in;
	struct net_device___78 *out;
	struct sock___67 *sk;
	int (*okfn)(struct sock___67 *, struct sk_buff___80 *);
};

struct nf_afinfo___93 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___80 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___80 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___92 *, struct dst_entry___68 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___80 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___80 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct rtable___39;

struct dst_entry___68 {
	struct callback_head callback_head;
	struct dst_entry___68 *child;
	struct net_device___78 *dev;
	struct dst_ops___92 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___68 *path;
	struct dst_entry___68 *from;
	struct xfrm_state___18 *xfrm;
	int (*input)(struct sk_buff___80 *);
	union {
		int (*output)(struct sock___67 *, struct sk_buff___80 *);
		struct {
			int (*output)(struct sk_buff___80 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___68 *next;
		struct rtable___39 *rt_next;
		struct rt6_info___18 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___68;

struct neigh_parms___68;

struct neigh_ops___68;

struct neighbour___68 {
	struct neighbour___68 *next;
	struct neigh_table___68 *tbl;
	struct neigh_parms___68 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___79 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___68 *, struct sk_buff___80 *);
	const struct neigh_ops___68 *ops;
	struct callback_head rcu;
	struct net_device___78 *dev;
	u8 primary_key[0];
};

struct file_lock___288;

struct seq_file___213;

struct file_operations___288 {
	struct module___179 *owner;
	loff_t (*llseek)(struct file___288 *, loff_t, int);
	ssize_t (*read)(struct file___288 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___288 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___75 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___75 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___288 *, void *, filldir_t);
	unsigned int (*poll)(struct file___288 *, struct poll_table_struct___174 *);
	long int (*unlocked_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___288 *, struct vm_area_struct___296 *);
	int (*open)(struct inode___288 *, struct file___288 *);
	int (*flush)(struct file___288 *, fl_owner_t);
	int (*release)(struct inode___288 *, struct file___288 *);
	int (*fsync)(struct file___288 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___75 *, int);
	int (*fasync)(int, struct file___288 *, int);
	int (*lock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*sendpage)(struct file___288 *, struct page___287 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___288 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___288 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___288 *, long int, struct file_lock___288 **, void **);
		struct {
			int (*setlease)(struct file___288 *, long int, struct file_lock___288 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___288 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___213 *, struct file___288 *);
};

struct dev_pm_qos_request___90 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___286 *dev;
};

struct dentry_operations___288;

struct super_block___288;

struct dentry___288 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___288 *d_parent;
	struct qstr d_name;
	struct inode___288 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___288 *d_op;
	struct super_block___288 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___288;

struct dquot___288;

struct block_device___288;

struct inode___288 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___288 *i_op;
	struct super_block___288 *i_sb;
	struct address_space___288 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___290 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___288 *i_fop;
	struct file_lock___288 *i_flock;
	struct address_space___288 i_data;
	struct dquot___288 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___288 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___288 {
	int (*d_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_hash)(const struct dentry___288 *, struct qstr *);
	int (*d_compare)(const struct dentry___288 *, const struct dentry___288 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___288 *);
	void (*d_release)(struct dentry___288 *);
	void (*d_prune)(struct dentry___288 *);
	void (*d_iput)(struct dentry___288 *, struct inode___288 *);
	char * (*d_dname)(struct dentry___288 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___288 *);
	int (*d_manage)(struct dentry___288 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___288;

struct mem_dqinfo___288 {
	struct quota_format_type___288 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___288;

struct quota_info___288 {
	unsigned int flags;
	struct mutex___290 dqio_mutex;
	struct mutex___290 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___288 *files[2];
	struct mem_dqinfo___288 info[2];
	const struct quota_format_ops___288 *ops[2];
};

struct file_system_type___288;

struct super_operations___288;

struct dquot_operations___288;

struct quotactl_ops___288;

struct xattr_handler___184;

struct super_block___288 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___288 *s_type;
	const struct super_operations___288 *s_op;
	const struct dquot_operations___288 *dq_op;
	const struct quotactl_ops___288 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___288 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___184 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___288 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___288 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___290 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___288 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___288 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___288 *bd_inode;
	struct super_block___288 *bd_super;
	struct mutex___290 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___288 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___290 bd_fsfreeze_mutex;
};

struct cgroup___183;

struct cgroup_subsys_state___183 {
	struct cgroup___183 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___288 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___288 *ia_file;
};

struct dquot___288 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___290 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___288 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___288 {
	int qf_fmt_id;
	const struct quota_format_ops___288 *qf_ops;
	struct module___179 *qf_owner;
	struct quota_format_type___288 *qf_next;
};

struct quota_format_ops___288 {
	int (*check_quota_file)(struct super_block___288 *, int);
	int (*read_file_info)(struct super_block___288 *, int);
	int (*write_file_info)(struct super_block___288 *, int);
	int (*free_file_info)(struct super_block___288 *, int);
	int (*read_dqblk)(struct dquot___288 *);
	int (*commit_dqblk)(struct dquot___288 *);
	int (*release_dqblk)(struct dquot___288 *);
};

struct dquot_operations___288 {
	int (*write_dquot)(struct dquot___288 *);
	struct dquot___288 * (*alloc_dquot)(struct super_block___288 *, int);
	void (*destroy_dquot)(struct dquot___288 *);
	int (*acquire_dquot)(struct dquot___288 *);
	int (*release_dquot)(struct dquot___288 *);
	int (*mark_dirty)(struct dquot___288 *);
	int (*write_info)(struct super_block___288 *, int);
	qsize_t * (*get_reserved_space)(struct inode___288 *);
};

struct quotactl_ops___288 {
	int (*quota_on)(struct super_block___288 *, int, int, struct path___288 *);
	int (*quota_on_meta)(struct super_block___288 *, int, int);
	int (*quota_off)(struct super_block___288 *, int);
	int (*quota_sync)(struct super_block___288 *, int);
	int (*get_info)(struct super_block___288 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___288 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___288 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___288 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___288 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___288 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___288 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___288 *, unsigned int);
};

struct address_space_operations___288 {
	int (*writepage)(struct page___287 *, struct writeback_control *);
	int (*readpage)(struct file___288 *, struct page___287 *);
	int (*writepages)(struct address_space___288 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___287 *);
	int (*readpages)(struct file___288 *, struct address_space___288 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___288 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___287 **, void **);
	int (*write_end)(struct file___288 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___287 *, void *);
	sector_t (*bmap)(struct address_space___288 *, sector_t);
	void (*invalidatepage)(struct page___287 *, long unsigned int);
	int (*releasepage)(struct page___287 *, gfp_t);
	void (*freepage)(struct page___287 *);
	ssize_t (*direct_IO)(int, struct kiocb___75 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___288 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___288 *, struct page___287 *, struct page___287 *, enum migrate_mode);
	int (*launder_page)(struct page___287 *);
	int (*is_partially_uptodate)(struct page___287 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___287 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___288 *, struct page___287 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___288 *, sector_t *);
	void (*swap_deactivate)(struct file___288 *);
	void (*invalidatepage_range)(struct page___287 *, unsigned int, unsigned int);
};

struct inode_operations___288 {
	struct dentry___288 * (*lookup)(struct inode___288 *, struct dentry___288 *, unsigned int);
	void * (*follow_link)(struct dentry___288 *, struct nameidata *);
	int (*permission)(struct inode___288 *, int);
	struct posix_acl * (*get_acl)(struct inode___288 *, int);
	int (*readlink)(struct dentry___288 *, char *, int);
	void (*put_link)(struct dentry___288 *, struct nameidata *, void *);
	int (*create)(struct inode___288 *, struct dentry___288 *, umode_t, bool);
	int (*link)(struct dentry___288 *, struct inode___288 *, struct dentry___288 *);
	int (*unlink)(struct inode___288 *, struct dentry___288 *);
	int (*symlink)(struct inode___288 *, struct dentry___288 *, const char *);
	int (*mkdir)(struct inode___288 *, struct dentry___288 *, umode_t);
	int (*rmdir)(struct inode___288 *, struct dentry___288 *);
	int (*mknod)(struct inode___288 *, struct dentry___288 *, umode_t, dev_t);
	int (*rename)(struct inode___288 *, struct dentry___288 *, struct inode___288 *, struct dentry___288 *);
	int (*setattr)(struct dentry___288 *, struct iattr___288 *);
	int (*getattr)(struct vfsmount *, struct dentry___288 *, struct kstat *);
	int (*setxattr)(struct dentry___288 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___288 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___288 *, char *, size_t);
	int (*removexattr)(struct dentry___288 *, const char *);
	int (*fiemap)(struct inode___288 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___288 *, struct timespec *, int);
	int (*atomic_open)(struct inode___288 *, struct dentry___288 *, struct file___288 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___288;

struct lock_manager_operations___288;

struct file_lock___288 {
	struct file_lock___288 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___288 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___288 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___288 *fl_ops;
	const struct lock_manager_operations___288 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___288 {
	void (*fl_copy_lock)(struct file_lock___288 *, struct file_lock___288 *);
	void (*fl_release_private)(struct file_lock___288 *);
};

struct lock_manager_operations___288 {
	int (*lm_compare_owner)(struct file_lock___288 *, struct file_lock___288 *);
	long unsigned int (*lm_owner_key)(struct file_lock___288 *);
	void (*lm_notify)(struct file_lock___288 *);
	int (*lm_grant)(struct file_lock___288 *, struct file_lock___288 *, int);
	void (*lm_break)(struct file_lock___288 *);
	int (*lm_change)(struct file_lock___288 **, int);
};

struct file_system_type___288 {
	const char *name;
	int fs_flags;
	struct dentry___288 * (*mount)(struct file_system_type___288 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___288 *);
	struct module___179 *owner;
	struct file_system_type___288 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___288 {
	struct inode___288 * (*alloc_inode)(struct super_block___288 *);
	void (*destroy_inode)(struct inode___288 *);
	void (*dirty_inode)(struct inode___288 *, int);
	int (*write_inode)(struct inode___288 *, struct writeback_control *);
	int (*drop_inode)(struct inode___288 *);
	void (*evict_inode)(struct inode___288 *);
	void (*put_super)(struct super_block___288 *);
	int (*sync_fs)(struct super_block___288 *, int);
	int (*freeze_fs)(struct super_block___288 *);
	int (*unfreeze_fs)(struct super_block___288 *);
	int (*statfs)(struct dentry___288 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___288 *, int *, char *);
	void (*umount_begin)(struct super_block___288 *);
	int (*show_options)(struct seq_file___213 *, struct dentry___288 *);
	int (*show_devname)(struct seq_file___213 *, struct dentry___288 *);
	int (*show_path)(struct seq_file___213 *, struct dentry___288 *);
	int (*show_stats)(struct seq_file___213 *, struct dentry___288 *);
	ssize_t (*quota_read)(struct super_block___288 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___288 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___288 *);
	int (*bdev_try_to_free_page)(struct super_block___288 *, struct page___287 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___288 *);
	void (*free_cached_objects)(struct super_block___288 *, int);
};

struct xattr_handler___184 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___288 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___288 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___288 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___213;

struct seq_file___213 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___290 lock;
	const struct seq_operations___213 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___78 {
	int (*get_settings)(struct net_device___78 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___78 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___78 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___78 *);
	void (*get_regs)(struct net_device___78 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___78 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___78 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___78 *);
	void (*set_msglevel)(struct net_device___78 *, u32);
	int (*nway_reset)(struct net_device___78 *);
	u32 (*get_link)(struct net_device___78 *);
	int (*get_eeprom_len)(struct net_device___78 *);
	int (*get_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___78 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___78 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___78 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___78 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___78 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___78 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___78 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___78 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___78 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___78 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___78 *);
	void (*complete)(struct net_device___78 *);
	u32 (*get_priv_flags)(struct net_device___78 *);
	int (*set_priv_flags)(struct net_device___78 *, u32);
	int (*get_sset_count)(struct net_device___78 *, int);
	int (*get_rxnfc)(struct net_device___78 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___78 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___78 *, struct ethtool_flash *);
	int (*reset)(struct net_device___78 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___78 *);
	int (*get_rxfh_indir)(struct net_device___78 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___78 *, const u32 *);
	void (*get_channels)(struct net_device___78 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___78 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___78 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___78 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___78 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___78 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___78 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___78 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___78 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___78 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___78 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___78 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib6_node___18;

struct rt6_info___18 {
	struct dst_entry___68 dst;
	struct fib6_table___18 *rt6i_table;
	struct fib6_node___18 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___44 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___18 {
	struct fib6_node___18 *parent;
	struct fib6_node___18 *left;
	struct fib6_node___18 *right;
	struct rt6_info___18 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___18 *rr_ptr;
};

struct fib6_table___18 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___18 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct irq_chip___212 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___212 *);
	void (*irq_shutdown)(struct irq_data___212 *);
	void (*irq_enable)(struct irq_data___212 *);
	void (*irq_disable)(struct irq_data___212 *);
	void (*irq_ack)(struct irq_data___212 *);
	void (*irq_mask)(struct irq_data___212 *);
	void (*irq_mask_ack)(struct irq_data___212 *);
	void (*irq_unmask)(struct irq_data___212 *);
	void (*irq_eoi)(struct irq_data___212 *);
	int (*irq_set_affinity)(struct irq_data___212 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___212 *);
	int (*irq_set_type)(struct irq_data___212 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___212 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___212 *);
	void (*irq_bus_sync_unlock)(struct irq_data___212 *);
	void (*irq_cpu_online)(struct irq_data___212 *);
	void (*irq_cpu_offline)(struct irq_data___212 *);
	void (*irq_suspend)(struct irq_data___212 *);
	void (*irq_resume)(struct irq_data___212 *);
	void (*irq_pm_shutdown)(struct irq_data___212 *);
	void (*irq_print_chip)(struct irq_data___212 *, struct seq_file___213 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___212 *, void *);
	long unsigned int flags;
};

struct seq_operations___213 {
	void * (*start)(struct seq_file___213 *, loff_t *);
	void (*stop)(struct seq_file___213 *, void *);
	void * (*next)(struct seq_file___213 *, void *, loff_t *);
	int (*show)(struct seq_file___213 *, void *);
};

struct dcbnl_rtnl_ops___78 {
	int (*ieee_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___78 *);
	u8 (*setstate)(struct net_device___78 *, u8);
	void (*getpermhwaddr)(struct net_device___78 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___78 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___78 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___78 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___78 *, int, u8 *);
	void (*setpfccfg)(struct net_device___78 *, int, u8);
	void (*getpfccfg)(struct net_device___78 *, int, u8 *);
	u8 (*setall)(struct net_device___78 *);
	u8 (*getcap)(struct net_device___78 *, int, u8 *);
	int (*getnumtcs)(struct net_device___78 *, int, u8 *);
	int (*setnumtcs)(struct net_device___78 *, int, u8);
	u8 (*getpfcstate)(struct net_device___78 *);
	void (*setpfcstate)(struct net_device___78 *, u8);
	void (*getbcncfg)(struct net_device___78 *, int, u32 *);
	void (*setbcncfg)(struct net_device___78 *, int, u32);
	void (*getbcnrp)(struct net_device___78 *, int, u8 *);
	void (*setbcnrp)(struct net_device___78 *, int, u8);
	u8 (*setapp)(struct net_device___78 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___78 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___78 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___78 *, int, u8);
	u8 (*getdcbx)(struct net_device___78 *);
	u8 (*setdcbx)(struct net_device___78 *, u8);
	int (*peer_getappinfo)(struct net_device___78 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___78 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___78 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___78 *, struct cee_pfc *);
};

struct cgroupfs_root___183;

struct cgroup___183 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___183 *parent;
	struct dentry___288 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___183 *subsys[11];
	struct cgroupfs_root___183 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___290 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___183 {
	struct super_block___288 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___183 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___119 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___288 *, struct file___288 *);
	ssize_t (*read)(struct cgroup___183 *, struct cftype___119 *, struct file___288 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___183 *, struct cftype___119 *);
	s64 (*read_s64)(struct cgroup___183 *, struct cftype___119 *);
	int (*read_map)(struct cgroup___183 *, struct cftype___119 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___183 *, struct cftype___119 *, struct seq_file___213 *);
	ssize_t (*write)(struct cgroup___183 *, struct cftype___119 *, struct file___288 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___183 *, struct cftype___119 *, u64);
	int (*write_s64)(struct cgroup___183 *, struct cftype___119 *, s64);
	int (*write_string)(struct cgroup___183 *, struct cftype___119 *, const char *);
	int (*trigger)(struct cgroup___183 *, unsigned int);
	int (*release)(struct inode___288 *, struct file___288 *);
	int (*register_event)(struct cgroup___183 *, struct cftype___119 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___183 *, struct cftype___119 *, struct eventfd_ctx *);
};

struct cftype_set___115 {
	struct list_head node;
	struct cftype___119 *cfts;
};

struct task_and_cgroup___115 {
	struct task_struct___289 *task;
	struct cgroup___183 *cgrp;
	struct css_set___183 *cg;
};

struct cgroup_taskset___115 {
	struct task_and_cgroup___115 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___183 *cur_cgrp;
};

struct cgroup_subsys___115 {
	struct cgroup_subsys_state___183 * (*css_alloc)(struct cgroup___183 *);
	int (*css_online)(struct cgroup___183 *);
	void (*css_offline)(struct cgroup___183 *);
	void (*css_free)(struct cgroup___183 *);
	int (*can_attach)(struct cgroup___183 *, struct cgroup_taskset___115 *);
	void (*cancel_attach)(struct cgroup___183 *, struct cgroup_taskset___115 *);
	void (*attach)(struct cgroup___183 *, struct cgroup_taskset___115 *);
	void (*fork)(struct task_struct___289 *);
	void (*exit)(struct cgroup___183 *, struct cgroup___183 *, struct task_struct___289 *);
	void (*bind)(struct cgroup___183 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___183 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___119 *base_cftypes;
	struct cftype_set___115 base_cftset;
	struct module___179 *module;
};

struct request_sock_ops___53;

struct request_sock___54 {
	struct sock_common___67 __req_common;
	struct request_sock___54 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___53 *rsk_ops;
	struct sock___67 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___18;

struct xfrm_type___18;

struct xfrm_mode___18;

struct xfrm_state___18 {
	struct net___92 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___18 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___18 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___18 *type;
	struct xfrm_mode___18 *inner_mode;
	struct xfrm_mode___18 *inner_mode_iaf;
	struct xfrm_mode___18 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___18 {
	struct sk_buff_head___79 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___18 {
	struct net___92 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___18 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___80 {
	struct sk_buff___80 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___80 *, struct netlink_callback___80 *);
	int (*done)(struct netlink_callback___80 *);
	void *data;
	struct module___179 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___78 {
	int (*create)(struct sk_buff___80 *, struct net_device___78 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___80 *, unsigned char *);
	int (*rebuild)(struct sk_buff___80 *);
	int (*cache)(const struct neighbour___68 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___78 *, const unsigned char *);
};

struct napi_struct___78 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___78 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___78 *dev;
	struct sk_buff___80 *gro_list;
	struct sk_buff___80 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___78 {
	struct net_device___78 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___70 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___78 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___70 kobj;
	struct net_device___78 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___78 {
	int (*ndo_init)(struct net_device___78 *);
	void (*ndo_uninit)(struct net_device___78 *);
	int (*ndo_open)(struct net_device___78 *);
	int (*ndo_stop)(struct net_device___78 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___80 *, struct net_device___78 *);
	u16 (*ndo_select_queue)(struct net_device___78 *, struct sk_buff___80 *);
	void (*ndo_change_rx_flags)(struct net_device___78 *, int);
	void (*ndo_set_rx_mode)(struct net_device___78 *);
	int (*ndo_set_mac_address)(struct net_device___78 *, void *);
	int (*ndo_validate_addr)(struct net_device___78 *);
	int (*ndo_do_ioctl)(struct net_device___78 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___78 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___78 *, int);
	int (*ndo_neigh_setup)(struct net_device___78 *, struct neigh_parms___68 *);
	void (*ndo_tx_timeout)(struct net_device___78 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___78 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___78 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___78 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___78 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___78 *);
	int (*ndo_netpoll_setup)(struct net_device___78 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___78 *);
	int (*ndo_busy_poll)(struct napi_struct___78 *);
	int (*ndo_set_vf_mac)(struct net_device___78 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___78 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___78 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___78 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___78 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___78 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___78 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___78 *, int, struct sk_buff___80 *);
	int (*ndo_setup_tc)(struct net_device___78 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___78 *);
	int (*ndo_fcoe_disable)(struct net_device___78 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___78 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___78 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___78 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___78 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___78 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___78 *, const struct sk_buff___80 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___78 *, struct net_device___78 *);
	int (*ndo_del_slave)(struct net_device___78 *, struct net_device___78 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___68 *);
	void (*ndo_neigh_destroy)(struct neighbour___68 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___80 *, struct netlink_callback___80 *, struct net_device___78 *, int);
	int (*ndo_bridge_setlink)(struct net_device___78 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___80 *, u32, u32, struct net_device___78 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___78 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___78 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___78 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___78 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___78 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___78 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___80 *, struct net_device___78 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___78 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___78 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___78 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___68 {
	struct net___92 *net;
	struct net_device___78 *dev;
	struct neigh_parms___68 *next;
	int (*neigh_setup)(struct neighbour___68 *);
	void (*neigh_cleanup)(struct neighbour___68 *);
	struct neigh_table___68 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___44;

struct ifacaddr6___44;

struct inet6_dev___44 {
	struct net_device___78 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___44 *mc_list;
	struct ifmcaddr6___44 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___44 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___68 *nd_parms;
	struct inet6_dev___44 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___69 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___78 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___92 *, struct net_device___78 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___78 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___78 *, struct list_head *);
	size_t (*get_size)(const struct net_device___78 *);
	int (*fill_info)(struct sk_buff___80 *, const struct net_device___78 *);
	size_t (*get_xstats_size)(const struct net_device___78 *);
	int (*fill_xstats)(struct sk_buff___80 *, const struct net_device___78 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___92 * (*get_link_net)(const struct net_device___78 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___78 *, struct net_device___78 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___78 *, const struct net_device___78 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___80 *, const struct net_device___78 *, const struct net_device___78 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct pneigh_entry___68;

struct neigh_hash_table___68;

struct neigh_table___68 {
	struct neigh_table___68 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___78 *, __u32 *);
	int (*constructor)(struct neighbour___68 *);
	int (*pconstructor)(struct pneigh_entry___68 *);
	void (*pdestructor)(struct pneigh_entry___68 *);
	void (*proxy_redo)(struct sk_buff___80 *);
	char *id;
	struct neigh_parms___68 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___79 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___68 *nht;
	struct pneigh_entry___68 **phash_buckets;
};

struct neigh_ops___68 {
	int family;
	void (*solicit)(struct neighbour___68 *, struct sk_buff___80 *);
	void (*error_report)(struct neighbour___68 *, struct sk_buff___80 *);
	int (*output)(struct neighbour___68 *, struct sk_buff___80 *);
	int (*connected_output)(struct neighbour___68 *, struct sk_buff___80 *);
};

struct pneigh_entry___68 {
	struct pneigh_entry___68 *next;
	struct net___92 *net;
	struct net_device___78 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___68 {
	struct neighbour___68 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___39 {
	struct dst_entry___68 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct sk_filter___68 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___80 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct timewait_sock_ops___50;

struct proto___67 {
	void (*close)(struct sock___67 *, long int);
	int (*connect)(struct sock___67 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___67 *, int);
	struct sock___67 * (*accept)(struct sock___67 *, int, int *);
	int (*ioctl)(struct sock___67 *, int, long unsigned int);
	int (*init)(struct sock___67 *);
	void (*destroy)(struct sock___67 *);
	void (*shutdown)(struct sock___67 *, int);
	int (*setsockopt)(struct sock___67 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___67 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___67 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___67 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___67 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___75 *, struct sock___67 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___75 *, struct sock___67 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___67 *, struct page___287 *, int, size_t, int);
	int (*bind)(struct sock___67 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___67 *, struct sk_buff___80 *);
	void (*release_cb)(struct sock___67 *);
	void (*mtu_reduced)(struct sock___67 *);
	void (*hash)(struct sock___67 *);
	void (*unhash)(struct sock___67 *);
	void (*rehash)(struct sock___67 *);
	int (*get_port)(struct sock___67 *, short unsigned int);
	void (*clear_sk)(struct sock___67 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___67 *);
	void (*enter_memory_pressure)(struct sock___67 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___271 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___53 *rsk_prot;
	struct timewait_sock_ops___50 *twsk_prot;
	union {
		struct inet_hashinfo___18 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___179 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___115 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___67 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___67 {
	void (*enter_memory_pressure)(struct sock___67 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___53 {
	int family;
	int obj_size;
	struct kmem_cache___271 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___67 *, struct request_sock___54 *);
	void (*send_ack)(struct sock___67 *, struct sk_buff___80 *, struct request_sock___54 *);
	void (*send_reset)(struct sock___67 *, struct sk_buff___80 *);
	void (*destructor)(struct request_sock___54 *);
	void (*syn_ack_timeout)(struct sock___67 *, struct request_sock___54 *);
};

struct timewait_sock_ops___50 {
	struct kmem_cache___271 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___67 *, struct sock___67 *, void *);
	void (*twsk_destructor)(struct sock___67 *);
};

struct inet_cork___24 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___68 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___24 {
	struct inet_cork___24 base;
	struct flowi fl;
};

struct ipv6_pinfo___23;

struct inet_sock___24 {
	struct sock___67 sk;
	struct ipv6_pinfo___23 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___24 cork;
};

struct ipv6_fl_socklist___22;

struct ipv6_pinfo___23 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___22 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___80 *pktoptions;
	struct sk_buff___80 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___22;

struct ipv6_fl_socklist___22 {
	struct ipv6_fl_socklist___22 *next;
	struct ip6_flowlabel___22 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___44 {
	struct in6_addr mca_addr;
	struct inet6_dev___44 *idev;
	struct ifmcaddr6___44 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___44 {
	struct in6_addr aca_addr;
	struct inet6_dev___44 *aca_idev;
	struct rt6_info___18 *aca_rt;
	struct ifacaddr6___44 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___22 {
	struct ip6_flowlabel___22 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___92 *fl_net;
};

struct xfrm_replay___18 {
	void (*advance)(struct xfrm_state___18 *, __be32);
	int (*check)(struct xfrm_state___18 *, struct sk_buff___80 *, __be32);
	int (*recheck)(struct xfrm_state___18 *, struct sk_buff___80 *, __be32);
	void (*notify)(struct xfrm_state___18 *, int);
	int (*overflow)(struct xfrm_state___18 *, struct sk_buff___80 *);
};

struct xfrm_type___18 {
	char *description;
	struct module___179 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___18 *);
	void (*destructor)(struct xfrm_state___18 *);
	int (*input)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*output)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*reject)(struct xfrm_state___18 *, struct sk_buff___80 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___18 *, struct sk_buff___80 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___18 *, int);
};

struct xfrm_state_afinfo___18;

struct xfrm_mode___18 {
	int (*input2)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*input)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*output2)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*output)(struct xfrm_state___18 *, struct sk_buff___80 *);
	struct xfrm_state_afinfo___18 *afinfo;
	struct module___179 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___18 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___179 *owner;
	const struct xfrm_type___18 *type_map[256];
	struct xfrm_mode___18 *mode_map[5];
	int (*init_flags)(struct xfrm_state___18 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___18 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___18 **, struct xfrm_state___18 **, int);
	union {
		int (*output)(struct sock___67 *, struct sk_buff___80 *);
		struct {
			int (*output)(struct sk_buff___80 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___67 *, struct sk_buff___80 *);
		struct {
			int (*output_finish)(struct sk_buff___80 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*extract_output)(struct xfrm_state___18 *, struct sk_buff___80 *);
	int (*transport_finish)(struct sk_buff___80 *, int);
};

struct net_protocol___7 {
	void (*early_demux)(struct sk_buff___80 *);
	int (*handler)(struct sk_buff___80 *);
	void (*err_handler)(struct sk_buff___80 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
};

struct xfrm_input_afinfo {
	unsigned int family;
	struct module *owner;
	int (*callback)(struct sk_buff___80 *, u8, int);
};

struct xfrm4_protocol {
	int (*handler)(struct sk_buff___80 *);
	int (*input_handler)(struct sk_buff___80 *, int, __be32, int);
	int (*cb_handler)(struct sk_buff___80 *, int);
	int (*err_handler)(struct sk_buff___80 *, u32);
	struct xfrm4_protocol *next;
	int priority;
};

enum {
	LINUX_MIB_XFRMNUM = 0,
	LINUX_MIB_XFRMINERROR = 1,
	LINUX_MIB_XFRMINBUFFERERROR = 2,
	LINUX_MIB_XFRMINHDRERROR = 3,
	LINUX_MIB_XFRMINNOSTATES = 4,
	LINUX_MIB_XFRMINSTATEPROTOERROR = 5,
	LINUX_MIB_XFRMINSTATEMODEERROR = 6,
	LINUX_MIB_XFRMINSTATESEQERROR = 7,
	LINUX_MIB_XFRMINSTATEEXPIRED = 8,
	LINUX_MIB_XFRMINSTATEMISMATCH = 9,
	LINUX_MIB_XFRMINSTATEINVALID = 10,
	LINUX_MIB_XFRMINTMPLMISMATCH = 11,
	LINUX_MIB_XFRMINNOPOLS = 12,
	LINUX_MIB_XFRMINPOLBLOCK = 13,
	LINUX_MIB_XFRMINPOLERROR = 14,
	LINUX_MIB_XFRMOUTERROR = 15,
	LINUX_MIB_XFRMOUTBUNDLEGENERROR = 16,
	LINUX_MIB_XFRMOUTBUNDLECHECKERROR = 17,
	LINUX_MIB_XFRMOUTNOSTATES = 18,
	LINUX_MIB_XFRMOUTSTATEPROTOERROR = 19,
	LINUX_MIB_XFRMOUTSTATEMODEERROR = 20,
	LINUX_MIB_XFRMOUTSTATESEQERROR = 21,
	LINUX_MIB_XFRMOUTSTATEEXPIRED = 22,
	LINUX_MIB_XFRMOUTPOLBLOCK = 23,
	LINUX_MIB_XFRMOUTPOLDEAD = 24,
	LINUX_MIB_XFRMOUTPOLERROR = 25,
	LINUX_MIB_XFRMFWDHDRERROR = 26,
	LINUX_MIB_XFRMOUTSTATEINVALID = 27,
	__LINUX_MIB_XFRMMAX = 28,
};

typedef struct flow_cache_object * (*flow_resolve_t___2)(struct net___85 *, const struct flowi *, u16, u8, struct flow_cache_object *, void *);

enum {
	XFRM_STATE_VOID = 0,
	XFRM_STATE_ACQ = 1,
	XFRM_STATE_VALID = 2,
	XFRM_STATE_ERROR = 3,
	XFRM_STATE_EXPIRED = 4,
	XFRM_STATE_DEAD = 5,
};

struct xfrm_policy_walk {
	struct xfrm_policy_walk_entry walk;
	u8 type;
	u32 seq;
};

struct xfrm_kmaddress {
	xfrm_address_t local;
	xfrm_address_t remote;
	u32 reserved;
	u16 family;
};

struct xfrm_migrate {
	xfrm_address_t old_daddr;
	xfrm_address_t old_saddr;
	xfrm_address_t new_daddr;
	xfrm_address_t new_saddr;
	u8 proto;
	u8 mode;
	u16 reserved;
	u32 reqid;
	u16 old_family;
	u16 new_family;
};

struct xfrm_audit {
	u32 secid;
	kuid_t loginuid;
	u32 sessionid;
};

struct xfrmk_spdinfo {
	u32 incnt;
	u32 outcnt;
	u32 fwdcnt;
	u32 inscnt;
	u32 outscnt;
	u32 fwdscnt;
	u32 spdhcnt;
	u32 spdhmcnt;
};

struct xfrm_flo {
	struct dst_entry___61 *dst_orig;
	u8 flags;
};

enum xfrm_ae_ftype_t {
	XFRM_AE_UNSPEC = 0,
	XFRM_AE_RTHR = 1,
	XFRM_AE_RVAL = 2,
	XFRM_AE_LVAL = 4,
	XFRM_AE_ETHR = 8,
	XFRM_AE_CR = 16,
	XFRM_AE_CE = 32,
	XFRM_AE_CU = 64,
	__XFRM_AE_MAX = 65,
};

enum xfrm_nlgroups {
	XFRMNLGRP_NONE = 0,
	XFRMNLGRP_ACQUIRE = 1,
	XFRMNLGRP_EXPIRE = 2,
	XFRMNLGRP_SA = 3,
	XFRMNLGRP_POLICY = 4,
	XFRMNLGRP_AEVENTS = 5,
	XFRMNLGRP_REPORT = 6,
	XFRMNLGRP_MIGRATE = 7,
	XFRMNLGRP_MAPPING = 8,
	__XFRMNLGRP_MAX = 9,
};

struct km_event {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___92 *net;
};

enum {
	XFRM_MODE_FLAG_TUNNEL = 1,
};

struct xfrm_mgr {
	struct list_head list;
	char *id;
	int (*notify)(struct xfrm_state___18 *, const struct km_event *);
	int (*acquire)(struct xfrm_state___18 *, struct xfrm_tmpl *, struct xfrm_policy___18 *);
	struct xfrm_policy___18 * (*compile_policy)(struct sock___67 *, int, u8 *, int, int *);
	int (*new_mapping)(struct xfrm_state___18 *, xfrm_address_t *, __be16);
	int (*notify_policy)(struct xfrm_policy___18 *, int, const struct km_event *);
	int (*report)(struct net___92 *, u8, struct xfrm_selector *, xfrm_address_t *);
	int (*migrate)(const struct xfrm_selector *, u8, u8, const struct xfrm_migrate *, int, const struct xfrm_kmaddress *);
};

struct xfrmk_sadinfo {
	u32 sadhcnt;
	u32 sadhmcnt;
	u32 sadcnt;
};

struct xfrm_input_afinfo___2 {
	unsigned int family;
	struct module___175 *owner;
	int (*callback)(struct sk_buff___73 *, u8, int);
};

struct ip_tunnel_encap {
	__u16 type;
	__u16 flags;
	__be16 sport;
	__be16 dport;
};

struct ip_tunnel_6rd_parm {
	struct in6_addr prefix;
	__be32 relay_prefix;
	u16 prefixlen;
	u16 relay_prefixlen;
};

struct gro_cell;

struct gro_cells {
	unsigned int gro_cells_mask;
	struct gro_cell *cells;
};

struct ip_tunnel_dst;

struct ip_tunnel_prl_entry;

struct ip_tunnel {
	struct ip_tunnel *next;
	struct hlist_node hash_node;
	struct net_device___71 *dev;
	struct net___85 *net;
	int err_count;
	long unsigned int err_time;
	__u32 i_seqno;
	__u32 o_seqno;
	int tun_hlen;
	int mlink;
	struct ip_tunnel_dst *dst_cache;
	struct ip_tunnel_parm parms;
	int encap_hlen;
	struct ip_tunnel_encap encap;
	int hlen;
	struct ip_tunnel_6rd_parm ip6rd;
	struct ip_tunnel_prl_entry *prl;
	unsigned int prl_count;
	int ip_tnl_net_id;
	struct gro_cells gro_cells;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct __ip6_tnl_parm {
	char name[16];
	int link;
	__u8 proto;
	__u8 encap_limit;
	__u8 hop_limit;
	__be32 flowinfo;
	__u32 flags;
	struct in6_addr laddr;
	struct in6_addr raddr;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
};

struct ip6_tnl {
	struct ip6_tnl *next;
	struct net_device___71 *dev;
	struct net___85 *net;
	struct __ip6_tnl_parm parms;
	int: 32;
	struct flowi fl;
	struct dst_entry___61 *dst_cache;
	u32 dst_cookie;
	int err_count;
	long unsigned int err_time;
	__u32 i_seqno;
	__u32 o_seqno;
	int hlen;
	int mlink;
};

struct xfrm_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	union {
		struct {
			__u32 low;
			__u32 hi;
		} output;
		struct {
			__be32 low;
			__be32 hi;
		} input;
	} seq;
};

struct gro_cell {
	struct sk_buff_head___72 napi_skbs;
	struct napi_struct___71 napi;
	long: 64;
	long: 64;
};

struct ip_tunnel_prl_entry {
	struct ip_tunnel_prl_entry *next;
	__be32 addr;
	u16 flags;
	struct callback_head callback_head;
};

struct ip_tunnel_dst {
	struct dst_entry___61 *dst;
	__be32 saddr;
};

struct nf_hook_state___14 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___71 *in;
	struct net_device___71 *out;
	struct sock___60 *sk;
	int (*okfn)(struct sock___60 *, struct sk_buff___73 *);
};

struct sadb_alg {
	__u8 sadb_alg_id;
	__u8 sadb_alg_ivlen;
	__u16 sadb_alg_minbits;
	__u16 sadb_alg_maxbits;
	__u16 sadb_alg_reserved;
};

struct xfrm_algo_aead_info {
	u16 icv_truncbits;
};

struct xfrm_algo_auth_info {
	u16 icv_truncbits;
	u16 icv_fullbits;
};

struct xfrm_algo_encr_info {
	u16 blockbits;
	u16 defkeybits;
};

struct xfrm_algo_comp_info {
	u16 threshold;
};

struct xfrm_algo_desc {
	char *name;
	char *compat;
	u8 available: 1;
	u8 pfkey_supported: 1;
	union {
		struct xfrm_algo_aead_info aead;
		struct xfrm_algo_auth_info auth;
		struct xfrm_algo_encr_info encr;
		struct xfrm_algo_comp_info comp;
	} uinfo;
	struct sadb_alg desc;
};

struct xfrm_algo_list {
	struct xfrm_algo_desc *algs;
	int entries;
	u32 type;
	u32 mask;
};

struct xfrm_aead_name {
	const char *name;
	int icvbits;
};

enum {
	XFRM_SHARE_ANY = 0,
	XFRM_SHARE_SESSION = 1,
	XFRM_SHARE_USER = 2,
	XFRM_SHARE_UNIQUE = 3,
};

struct xfrm_user_tmpl {
	struct xfrm_id id;
	__u16 family;
	xfrm_address_t saddr;
	__u32 reqid;
	__u8 mode;
	__u8 share;
	__u8 optional;
	__u32 aalgos;
	__u32 ealgos;
	__u32 calgos;
};

struct xfrm_userpolicy_type {
	__u8 type;
	__u16 reserved1;
	__u8 reserved2;
};

enum xfrm_attr_type_t {
	XFRMA_UNSPEC = 0,
	XFRMA_ALG_AUTH = 1,
	XFRMA_ALG_CRYPT = 2,
	XFRMA_ALG_COMP = 3,
	XFRMA_ENCAP = 4,
	XFRMA_TMPL = 5,
	XFRMA_SA = 6,
	XFRMA_POLICY = 7,
	XFRMA_SEC_CTX = 8,
	XFRMA_LTIME_VAL = 9,
	XFRMA_REPLAY_VAL = 10,
	XFRMA_REPLAY_THRESH = 11,
	XFRMA_ETIMER_THRESH = 12,
	XFRMA_SRCADDR = 13,
	XFRMA_COADDR = 14,
	XFRMA_LASTUSED = 15,
	XFRMA_POLICY_TYPE = 16,
	XFRMA_MIGRATE = 17,
	XFRMA_ALG_AEAD = 18,
	XFRMA_KMADDRESS = 19,
	XFRMA_ALG_AUTH_TRUNC = 20,
	XFRMA_MARK = 21,
	XFRMA_TFCPAD = 22,
	XFRMA_REPLAY_ESN_VAL = 23,
	XFRMA_SA_EXTRA_FLAGS = 24,
	__XFRMA_MAX = 25,
};

enum xfrm_sadattr_type_t {
	XFRMA_SAD_UNSPEC = 0,
	XFRMA_SAD_CNT = 1,
	XFRMA_SAD_HINFO = 2,
	__XFRMA_SAD_MAX = 3,
};

struct xfrmu_sadhinfo {
	__u32 sadhcnt;
	__u32 sadhmcnt;
};

enum xfrm_spdattr_type_t {
	XFRMA_SPD_UNSPEC = 0,
	XFRMA_SPD_INFO = 1,
	XFRMA_SPD_HINFO = 2,
	__XFRMA_SPD_MAX = 3,
};

struct xfrmu_spdinfo {
	__u32 incnt;
	__u32 outcnt;
	__u32 fwdcnt;
	__u32 inscnt;
	__u32 outscnt;
	__u32 fwdscnt;
};

struct xfrmu_spdhinfo {
	__u32 spdhcnt;
	__u32 spdhmcnt;
};

struct xfrm_usersa_info {
	struct xfrm_selector sel;
	struct xfrm_id id;
	xfrm_address_t saddr;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_stats stats;
	__u32 seq;
	__u32 reqid;
	__u16 family;
	__u8 mode;
	__u8 replay_window;
	__u8 flags;
};

struct xfrm_usersa_id {
	xfrm_address_t daddr;
	__be32 spi;
	__u16 family;
	__u8 proto;
};

struct xfrm_aevent_id {
	struct xfrm_usersa_id sa_id;
	xfrm_address_t saddr;
	__u32 flags;
	__u32 reqid;
};

struct xfrm_userspi_info {
	struct xfrm_usersa_info info;
	__u32 min;
	__u32 max;
};

struct xfrm_userpolicy_info {
	struct xfrm_selector sel;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	__u32 priority;
	__u32 index;
	__u8 dir;
	__u8 action;
	__u8 flags;
	__u8 share;
};

struct xfrm_userpolicy_id {
	struct xfrm_selector sel;
	__u32 index;
	__u8 dir;
};

struct xfrm_user_acquire {
	struct xfrm_id id;
	xfrm_address_t saddr;
	struct xfrm_selector sel;
	struct xfrm_userpolicy_info policy;
	__u32 aalgos;
	__u32 ealgos;
	__u32 calgos;
	__u32 seq;
};

struct xfrm_user_expire {
	struct xfrm_usersa_info state;
	__u8 hard;
};

struct xfrm_user_polexpire {
	struct xfrm_userpolicy_info pol;
	__u8 hard;
};

struct xfrm_usersa_flush {
	__u8 proto;
};

struct xfrm_user_report {
	__u8 proto;
	struct xfrm_selector sel;
};

struct xfrm_user_kmaddress {
	xfrm_address_t local;
	xfrm_address_t remote;
	__u32 reserved;
	__u16 family;
};

struct xfrm_user_migrate {
	xfrm_address_t old_daddr;
	xfrm_address_t old_saddr;
	xfrm_address_t new_daddr;
	xfrm_address_t new_saddr;
	__u8 proto;
	__u8 mode;
	__u16 reserved;
	__u32 reqid;
	__u16 old_family;
	__u16 new_family;
};

struct xfrm_user_mapping {
	struct xfrm_usersa_id id;
	__u32 reqid;
	xfrm_address_t old_saddr;
	xfrm_address_t new_saddr;
	__be16 old_sport;
	__be16 new_sport;
};

struct pernet_operations___26 {
	struct list_head list;
	int (*init)(struct net___81 *);
	void (*exit)(struct net___81 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct netlink_skb_parms___11 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___26 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___10 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___36 *);
	struct mutex___279 *cb_mutex;
	void (*bind)(int);
	bool (*compare)(struct net___81 *, struct sock___26 *);
};

struct netlink_dump_control___3 {
	int (*dump)(struct sk_buff___36 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
	void *data;
	struct module___145 *module;
	u16 min_dump_alloc;
};

struct km_event___2 {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___81 *net;
};

struct xfrm_mgr___2 {
	struct list_head list;
	char *id;
	int (*notify)(struct xfrm_state___12 *, const struct km_event___2 *);
	int (*acquire)(struct xfrm_state___12 *, struct xfrm_tmpl *, struct xfrm_policy___12 *);
	struct xfrm_policy___12 * (*compile_policy)(struct sock___26 *, int, u8 *, int, int *);
	int (*new_mapping)(struct xfrm_state___12 *, xfrm_address_t *, __be16);
	int (*notify_policy)(struct xfrm_policy___12 *, int, const struct km_event___2 *);
	int (*report)(struct net___81 *, u8, struct xfrm_selector *, xfrm_address_t *);
	int (*migrate)(const struct xfrm_selector *, u8, u8, const struct xfrm_migrate *, int, const struct xfrm_kmaddress *);
};

struct xfrm_dump_info {
	struct sk_buff___36 *in_skb;
	struct sk_buff___36 *out_skb;
	u32 nlmsg_seq;
	u16 nlmsg_flags;
};

struct xfrm_link {
	int (*doit)(struct sk_buff___36 *, struct nlmsghdr *, struct nlattr **);
	int (*dump)(struct sk_buff___36 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
};

struct page___288;

typedef struct page___288 *pgtable_t___288;

struct address_space___289;

struct kmem_cache___272;

struct page___288 {
	long unsigned int flags;
	struct address_space___289 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___288 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___288 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___272 *slab_cache;
		struct page___288 *first_page;
	};
	long: 64;
};

struct task_struct___290;

struct pv_cpu_ops___290 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___290 *);
	void (*end_context_switch)(struct task_struct___290 *);
};

struct mutex___291 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___290 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___283 {
	struct page___288 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___297;

struct nsproxy___169;

struct signal_struct___290;

struct css_set___184;

struct pipe_inode_info___11;

struct task_struct___290 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___290 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___297 *mm;
	struct mm_struct___297 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___290 *real_parent;
	struct task_struct___290 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___290 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___290 = 0,
		VTIME_USER___290 = 1,
		VTIME_SYS___290 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___169 *nsproxy;
	struct signal_struct___290 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___184 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___291 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info___11 *splice_pipe;
	struct page_frag___283 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___297 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___297 *, struct mm_struct___297 *);
	void (*dup_mmap)(struct mm_struct___297 *, struct mm_struct___297 *);
	void (*exit_mmap)(struct mm_struct___297 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___297 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___297 *);
	void (*pgd_free)(struct mm_struct___297 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___297 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___297 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___297 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___297 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___297 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___297 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___297 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___297 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___297 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___297 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___297 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___291 lock;
	void *vdso;
} mm_context_t___291;

struct xol_area___288;

struct uprobes_state___288 {
	struct xol_area___288 *xol_area;
};

struct vm_area_struct___297;

struct file___289;

struct core_state___290;

struct mm_struct___297 {
	struct vm_area_struct___297 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___297 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___297 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___291 context;
	long unsigned int flags;
	struct core_state___290 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___290 *owner;
	struct file___289 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___288 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___180;

struct exec_domain___80 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___180 *module;
	struct exec_domain___80 *next;
};

struct kset___71;

struct kobj_type___71;

struct kobject___71 {
	const char *name;
	struct list_head entry;
	struct kobject___71 *parent;
	struct kset___71 *kset;
	struct kobj_type___71 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module_kobject___180 {
	struct kobject___71 kobj;
	struct module___180 *mod;
	struct kobject___71 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___180;

struct module___180 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___180 mkobj;
	struct module_attribute___180 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___71 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___290 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct thread_info___128 {
	struct task_struct___290 *task;
	struct exec_domain___80 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct zone___290;

struct lruvec___290 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___290 *zone;
};

struct pglist_data___290;

struct zone___290 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___290 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___290 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___290 {
	struct zone___290 *zone;
	int zone_idx;
};

struct zonelist___290 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___290 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___290 {
	struct zone___290 node_zones[4];
	struct zonelist___290 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___290 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___213;

struct x86_io_apic_ops___213 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___213 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___213;

struct irq_data___213 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___213 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___287;

struct dev_pm_ops___287 {
	int (*prepare)(struct device___287 *);
	void (*complete)(struct device___287 *);
	int (*suspend)(struct device___287 *);
	int (*resume)(struct device___287 *);
	int (*freeze)(struct device___287 *);
	int (*thaw)(struct device___287 *);
	int (*poweroff)(struct device___287 *);
	int (*restore)(struct device___287 *);
	int (*suspend_late)(struct device___287 *);
	int (*resume_early)(struct device___287 *);
	int (*freeze_late)(struct device___287 *);
	int (*thaw_early)(struct device___287 *);
	int (*poweroff_late)(struct device___287 *);
	int (*restore_early)(struct device___287 *);
	int (*suspend_noirq)(struct device___287 *);
	int (*resume_noirq)(struct device___287 *);
	int (*freeze_noirq)(struct device___287 *);
	int (*thaw_noirq)(struct device___287 *);
	int (*poweroff_noirq)(struct device___287 *);
	int (*restore_noirq)(struct device___287 *);
	int (*runtime_suspend)(struct device___287 *);
	int (*runtime_resume)(struct device___287 *);
	int (*runtime_idle)(struct device___287 *);
};

struct dev_pm_qos___90;

struct dev_pm_info___90 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___90 *qos;
};

struct dma_map_ops___152;

struct dev_archdata___152 {
	struct dma_map_ops___152 *dma_ops;
	void *iommu;
};

struct device_type___287;

struct bus_type___287;

struct device_driver___287;

struct dev_pm_domain___287;

struct class___287;

struct attribute_group___249;

struct device_rh___287;

struct device___287 {
	struct device___287 *parent;
	struct device_private *p;
	struct kobject___71 kobj;
	const char *init_name;
	const struct device_type___287 *type;
	struct mutex___291 mutex;
	struct bus_type___287 *bus;
	struct device_driver___287 *driver;
	void *platform_data;
	struct dev_pm_info___90 power;
	struct dev_pm_domain___287 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___152 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___3 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___287 *class;
	const struct attribute_group___249 **groups;
	void (*release)(struct device___287 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___287 *device_rh;
};

struct dev_pm_qos_request___91;

struct dev_pm_qos___90 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___91 *latency_req;
	struct dev_pm_qos_request___91 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___91 *latency_tolerance_req;
};

struct dev_pm_info_rh___287 {
	void (*set_latency_tolerance)(struct device___287 *, s32);
};

struct dev_pm_domain___287 {
	struct dev_pm_ops___287 ops;
};

struct smp_ops___290 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___290 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___94;

struct ctl_node___94 {
	struct rb_node node;
	struct ctl_table_header___94 *header;
};

struct ctl_table_root___94;

struct ctl_table_set___94;

struct ctl_dir___94;

struct ctl_table_header___94 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___94 *root;
	struct ctl_table_set___94 *set;
	struct ctl_dir___94 *parent;
	struct ctl_node___94 *node;
};

struct ctl_dir___94 {
	struct ctl_table_header___94 header;
	struct rb_root root;
};

struct ctl_table_set___94 {
	int (*is_seen)(struct ctl_table_set___94 *);
	struct ctl_dir___94 dir;
};

struct ctl_table_root___94 {
	struct ctl_table_set___94 default_set;
	struct ctl_table_set___94 * (*lookup)(struct ctl_table_root___94 *, struct nsproxy___169 *);
	int (*permissions)(struct ctl_table_header___94 *, struct ctl_table *);
};

struct net___93;

struct nsproxy___169 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___93 *net_ns;
};

struct sock___68;

struct kobj_ns_type_operations___68 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___68 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___68;

struct sock_common___68 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___68 *skc_prot;
	struct net___93 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___81;

struct sk_buff_head___80 {
	struct sk_buff___81 *next;
	struct sk_buff___81 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___69;

struct socket_wq___68;

struct dst_entry___69;

struct socket___69;

struct cg_proto___68;

struct sock___68 {
	struct sock_common___68 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___80 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___81 *head;
		struct sk_buff___81 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___69 *sk_filter;
	struct socket_wq___68 *sk_wq;
	struct sk_buff_head___80 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___69 *sk_rx_dst;
	struct dst_entry___69 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___80 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___80 sk_error_queue;
	struct proto___68 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___69 *sk_socket;
	void *sk_user_data;
	struct page_frag___283 sk_frag;
	struct sk_buff___81 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___68 *sk_cgrp;
	void (*sk_state_change)(struct sock___68 *);
	void (*sk_data_ready)(struct sock___68 *, int);
	void (*sk_write_space)(struct sock___68 *);
	void (*sk_error_report)(struct sock___68 *);
	int (*sk_backlog_rcv)(struct sock___68 *, struct sk_buff___81 *);
	void (*sk_destruct)(struct sock___68 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___251;

struct attribute_group___249 {
	const char *name;
	umode_t (*is_visible)(struct kobject___71 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___251 **bin_attrs;
};

struct bin_attribute___251 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___289 *, struct kobject___71 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___289 *, struct kobject___71 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	int (*mmap)(struct file___289 *, struct kobject___71 *, struct bin_attribute___251 *, struct vm_area_struct___297 *);
};

struct vfsmount___46;

struct dentry___289;

struct path___289 {
	struct vfsmount___46 *mnt;
	struct dentry___289 *dentry;
};

struct inode___289;

struct file_operations___289;

struct file___289 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___289 f_path;
	struct inode___289 *f_inode;
	const struct file_operations___289 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___289 *f_mapping;
	struct mutex___291 f_pos_lock;
};

struct vm_operations_struct___263;

struct vm_area_struct___297 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___297 *vm_next;
	struct vm_area_struct___297 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___297 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___263 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___289 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___71 {
	ssize_t (*show)(struct kobject___71 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___71 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___71 *, const struct attribute *);
};

struct kset_uevent_ops___71;

struct kset___71 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___71 kobj;
	const struct kset_uevent_ops___71 *uevent_ops;
};

struct kobj_type___71 {
	void (*release)(struct kobject___71 *);
	const struct sysfs_ops___71 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___68 * (*child_ns_type)(struct kobject___71 *);
	const void * (*namespace)(struct kobject___71 *);
};

struct kset_uevent_ops___71 {
	int (* const filter)(struct kset___71 *, struct kobject___71 *);
	const char * (* const name)(struct kset___71 *, struct kobject___71 *);
	int (* const uevent)(struct kset___71 *, struct kobject___71 *, struct kobj_uevent_env *);
};

struct module_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___180 *, struct module_kobject___180 *, char *);
	ssize_t (*store)(struct module_attribute___180 *, struct module_kobject___180 *, const char *, size_t);
	void (*setup)(struct module___180 *, const char *);
	int (*test)(struct module___180 *);
	void (*free)(struct module___180 *);
};

struct xol_area___288 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___288 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___271;

struct memcg_cache_params___272;

struct kmem_cache___272 {
	struct kmem_cache_cpu___271 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___71 kobj;
	struct memcg_cache_params___272 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___289;

struct address_space___289 {
	struct inode___289 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___291 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___289 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___259;

struct vm_operations_struct___263 {
	void (*open)(struct vm_area_struct___297 *);
	void (*close)(struct vm_area_struct___297 *);
	int (*fault)(struct vm_area_struct___297 *, struct vm_fault___259 *);
	int (*page_mkwrite)(struct vm_area_struct___297 *, struct vm_fault___259 *);
	int (*access)(struct vm_area_struct___297 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___297 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___297 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___297 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___297 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___290 {
	struct task_struct___290 *task;
	struct core_thread___290 *next;
};

struct core_state___290 {
	atomic_t nr_threads;
	struct core_thread___290 dumper;
	struct completion startup;
};

struct signal_struct___290 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___290 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___290 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___291 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___184;

struct css_set___184 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___184 *subsys[11];
	struct callback_head callback_head;
};

struct fasync_struct___289;

struct pipe_buffer___11;

struct pipe_inode_info___11 {
	struct mutex___291 mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___288 *tmp_page;
	struct fasync_struct___289 *fasync_readers;
	struct fasync_struct___289 *fasync_writers;
	struct pipe_buffer___11 *bufs;
};

struct dentry_operations___289;

struct super_block___289;

struct dentry___289 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___289 *d_parent;
	struct qstr d_name;
	struct inode___289 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___289 *d_op;
	struct super_block___289 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___289;

struct file_lock___289;

struct dquot___289;

struct block_device___289;

struct inode___289 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___289 *i_op;
	struct super_block___289 *i_sb;
	struct address_space___289 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___291 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___289 *i_fop;
	struct file_lock___289 *i_flock;
	struct address_space___289 i_data;
	struct dquot___289 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info___11 *i_pipe;
		struct block_device___289 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___289 {
	int (*d_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_hash)(const struct dentry___289 *, struct qstr *);
	int (*d_compare)(const struct dentry___289 *, const struct dentry___289 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___289 *);
	void (*d_release)(struct dentry___289 *);
	void (*d_prune)(struct dentry___289 *);
	void (*d_iput)(struct dentry___289 *, struct inode___289 *);
	char * (*d_dname)(struct dentry___289 *, char *, int);
	struct vfsmount___46 * (*d_automount)(struct path___289 *);
	int (*d_manage)(struct dentry___289 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___289;

struct mem_dqinfo___289 {
	struct quota_format_type___289 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___289;

struct quota_info___289 {
	unsigned int flags;
	struct mutex___291 dqio_mutex;
	struct mutex___291 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___289 *files[2];
	struct mem_dqinfo___289 info[2];
	const struct quota_format_ops___289 *ops[2];
};

struct file_system_type___289;

struct super_operations___289;

struct dquot_operations___289;

struct quotactl_ops___289;

struct xattr_handler___185;

struct super_block___289 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___289 *s_type;
	const struct super_operations___289 *s_op;
	const struct dquot_operations___289 *dq_op;
	const struct quotactl_ops___289 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___289 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___185 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___289 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___289 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___291 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___289 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct vfsmount___46 {
	struct dentry___289 *mnt_root;
	struct super_block___289 *mnt_sb;
	int mnt_flags;
};

struct nameidata___27 {
	struct path___289 path;
	struct qstr last;
	struct path___289 root;
	struct inode___289 *inode;
	unsigned int flags;
	unsigned int seq;
	int last_type;
	unsigned int depth;
	char *saved_names[9];
};

struct socket_wq___68 {
	wait_queue_head_t wait;
	struct fasync_struct___289 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___289 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___289 *fa_next;
	struct file___289 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___68;

struct socket___69 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___68 *wq;
	struct file___289 *file;
	struct sock___68 *sk;
	const struct proto_ops___68 *ops;
};

struct poll_table_struct___175;

struct kiocb___76;

struct proto_ops___68 {
	int family;
	struct module___180 *owner;
	int (*release)(struct socket___69 *);
	int (*bind)(struct socket___69 *, struct sockaddr *, int);
	int (*connect)(struct socket___69 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___69 *, struct socket___69 *);
	int (*accept)(struct socket___69 *, struct socket___69 *, int);
	int (*getname)(struct socket___69 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___289 *, struct socket___69 *, struct poll_table_struct___175 *);
	int (*ioctl)(struct socket___69 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___69 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___69 *, int);
	int (*shutdown)(struct socket___69 *, int);
	int (*setsockopt)(struct socket___69 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___69 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___69 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___69 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___76 *, struct socket___69 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___76 *, struct socket___69 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___289 *, struct socket___69 *, struct vm_area_struct___297 *);
	ssize_t (*sendpage)(struct socket___69 *, struct page___288 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___69 *, loff_t *, struct pipe_inode_info___11 *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___68 *, int);
		struct {
			void (*set_peek_off)(struct sock___68 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___177)(struct file___289 *, wait_queue_head_t *, struct poll_table_struct___175 *);

struct poll_table_struct___175 {
	poll_queue_proc___177 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___76(struct kiocb___76 *, struct io_event *);

struct kiocb___76 {
	atomic_t ki_users;
	struct file___289 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___76 *ki_cancel;
	void (*ki_dtor)(struct kiocb___76 *);
	union {
		void *user;
		struct task_struct___290 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct net_proto_family___5 {
	int family;
	int (*create)(struct net___93 *, struct socket___69 *, int, int);
	struct module___180 *owner;
};

struct netns_core___91 {
	struct ctl_table_header___94 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___92 {
	struct mutex___291 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___91 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___94 *ctl;
};

struct netns_ipv4___91 {
	struct ctl_table_header___94 *forw_hdr;
	struct ctl_table_header___94 *frags_hdr;
	struct ctl_table_header___94 *ipv4_hdr;
	struct ctl_table_header___94 *route_hdr;
	struct ctl_table_header___94 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___68 *fibnl;
	struct sock___68 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___91 {
	struct ctl_table_header___94 *hdr;
	struct ctl_table_header___94 *route_hdr;
	struct ctl_table_header___94 *icmp_hdr;
	struct ctl_table_header___94 *frags_hdr;
	struct ctl_table_header___94 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___79;

struct neighbour___69;

struct dst_ops___93 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___93 *);
	struct dst_entry___69 * (*check)(struct dst_entry___69 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___69 *);
	unsigned int (*mtu)(const struct dst_entry___69 *);
	u32 * (*cow_metrics)(struct dst_entry___69 *, long unsigned int);
	void (*destroy)(struct dst_entry___69 *);
	void (*ifdown)(struct dst_entry___69 *, struct net_device___79 *, int);
	struct dst_entry___69 * (*negative_advice)(struct dst_entry___69 *);
	void (*link_failure)(struct sk_buff___81 *);
	void (*update_pmtu)(struct dst_entry___69 *, struct sock___68 *, struct sk_buff___81 *, u32);
	void (*redirect)(struct dst_entry___69 *, struct sock___68 *, struct sk_buff___81 *);
	int (*local_out)(struct sk_buff___81 *);
	struct neighbour___69 * (*neigh_lookup)(const struct dst_entry___69 *, struct sk_buff___81 *, const void *);
	struct kmem_cache___272 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___93 {
	struct netns_sysctl_ipv6___91 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___93 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___68 **icmp_sk;
	struct sock___68 *ndisc_sk;
	struct sock___68 *tcp_sk;
	struct sock___68 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___91 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___94 *sysctl_header;
	struct sock___68 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___68 {
	struct sock___68 *v4_ctl_sk;
	struct sock___68 *v6_ctl_sk;
};

struct netns_nf___91 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___94 *nf_log_dir_header;
};

struct nf_proto_net___91 {
	struct ctl_table_header___94 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___91 {
	struct nf_proto_net___91 pn;
	unsigned int timeout;
};

struct nf_tcp_net___91 {
	struct nf_proto_net___91 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___91 {
	struct nf_proto_net___91 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___91 {
	struct nf_proto_net___91 pn;
	unsigned int timeout;
};

struct nf_ip_net___91 {
	struct nf_generic_net___91 generic;
	struct nf_tcp_net___91 tcp;
	struct nf_udp_net___91 udp;
	struct nf_icmp_net___91 icmp;
	struct nf_icmp_net___91 icmpv6;
};

struct netns_ct___92 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___94 *sysctl_header;
	struct ctl_table_header___94 *acct_sysctl_header;
	struct ctl_table_header___94 *tstamp_sysctl_header;
	struct ctl_table_header___94 *event_sysctl_header;
	struct ctl_table_header___94 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___272 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___91 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___91 {
	struct netns_sysctl_ipv6___91 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___93 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___68 *nlsk;
	struct sock___68 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___94 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___93 xfrm4_dst_ops;
	struct dst_ops___93 xfrm6_dst_ops;
};

struct net___93 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___94 sysctls;
	struct sock___68 *rtnl;
	struct sock___68 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___79 *loopback_dev;
	struct netns_core___91 core;
	struct netns_mib mib;
	struct netns_packet___92 packet;
	struct netns_unix___91 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___91 ipv4;
	struct netns_ipv6___93 ipv6;
	struct netns_sctp___91 sctp;
	struct netns_dccp___68 dccp;
	struct netns_nf___91 nf;
	struct netns_xt xt;
	struct netns_ct___92 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___91 nf_frag;
	struct sock___68 *nfnl;
	struct sock___68 *nfnl_stash;
	struct sk_buff_head___80 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___93 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___68 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___68 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___291 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___291 flow_flush_sem;
	long: 64;
	long: 64;
};

struct block_device___289 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___289 *bd_inode;
	struct super_block___289 *bd_super;
	struct mutex___291 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___289 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___291 bd_fsfreeze_mutex;
};

struct cgroup___184;

struct cgroup_subsys_state___184 {
	struct cgroup___184 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___289 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___289 *ia_file;
};

struct dquot___289 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___291 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___289 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___289 {
	int qf_fmt_id;
	const struct quota_format_ops___289 *qf_ops;
	struct module___180 *qf_owner;
	struct quota_format_type___289 *qf_next;
};

struct quota_format_ops___289 {
	int (*check_quota_file)(struct super_block___289 *, int);
	int (*read_file_info)(struct super_block___289 *, int);
	int (*write_file_info)(struct super_block___289 *, int);
	int (*free_file_info)(struct super_block___289 *, int);
	int (*read_dqblk)(struct dquot___289 *);
	int (*commit_dqblk)(struct dquot___289 *);
	int (*release_dqblk)(struct dquot___289 *);
};

struct dquot_operations___289 {
	int (*write_dquot)(struct dquot___289 *);
	struct dquot___289 * (*alloc_dquot)(struct super_block___289 *, int);
	void (*destroy_dquot)(struct dquot___289 *);
	int (*acquire_dquot)(struct dquot___289 *);
	int (*release_dquot)(struct dquot___289 *);
	int (*mark_dirty)(struct dquot___289 *);
	int (*write_info)(struct super_block___289 *, int);
	qsize_t * (*get_reserved_space)(struct inode___289 *);
};

struct quotactl_ops___289 {
	int (*quota_on)(struct super_block___289 *, int, int, struct path___289 *);
	int (*quota_on_meta)(struct super_block___289 *, int, int);
	int (*quota_off)(struct super_block___289 *, int);
	int (*quota_sync)(struct super_block___289 *, int);
	int (*get_info)(struct super_block___289 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___289 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___289 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___289 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___289 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___289 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___289 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___289 *, unsigned int);
};

struct address_space_operations___289 {
	int (*writepage)(struct page___288 *, struct writeback_control *);
	int (*readpage)(struct file___289 *, struct page___288 *);
	int (*writepages)(struct address_space___289 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___288 *);
	int (*readpages)(struct file___289 *, struct address_space___289 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___289 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___288 **, void **);
	int (*write_end)(struct file___289 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___288 *, void *);
	sector_t (*bmap)(struct address_space___289 *, sector_t);
	void (*invalidatepage)(struct page___288 *, long unsigned int);
	int (*releasepage)(struct page___288 *, gfp_t);
	void (*freepage)(struct page___288 *);
	ssize_t (*direct_IO)(int, struct kiocb___76 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___289 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___289 *, struct page___288 *, struct page___288 *, enum migrate_mode);
	int (*launder_page)(struct page___288 *);
	int (*is_partially_uptodate)(struct page___288 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___288 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___289 *, struct page___288 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___289 *, sector_t *);
	void (*swap_deactivate)(struct file___289 *);
	void (*invalidatepage_range)(struct page___288 *, unsigned int, unsigned int);
};

struct inode_operations___289 {
	struct dentry___289 * (*lookup)(struct inode___289 *, struct dentry___289 *, unsigned int);
	void * (*follow_link)(struct dentry___289 *, struct nameidata___27 *);
	int (*permission)(struct inode___289 *, int);
	struct posix_acl * (*get_acl)(struct inode___289 *, int);
	int (*readlink)(struct dentry___289 *, char *, int);
	void (*put_link)(struct dentry___289 *, struct nameidata___27 *, void *);
	int (*create)(struct inode___289 *, struct dentry___289 *, umode_t, bool);
	int (*link)(struct dentry___289 *, struct inode___289 *, struct dentry___289 *);
	int (*unlink)(struct inode___289 *, struct dentry___289 *);
	int (*symlink)(struct inode___289 *, struct dentry___289 *, const char *);
	int (*mkdir)(struct inode___289 *, struct dentry___289 *, umode_t);
	int (*rmdir)(struct inode___289 *, struct dentry___289 *);
	int (*mknod)(struct inode___289 *, struct dentry___289 *, umode_t, dev_t);
	int (*rename)(struct inode___289 *, struct dentry___289 *, struct inode___289 *, struct dentry___289 *);
	int (*setattr)(struct dentry___289 *, struct iattr___289 *);
	int (*getattr)(struct vfsmount___46 *, struct dentry___289 *, struct kstat *);
	int (*setxattr)(struct dentry___289 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___289 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___289 *, char *, size_t);
	int (*removexattr)(struct dentry___289 *, const char *);
	int (*fiemap)(struct inode___289 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___289 *, struct timespec *, int);
	int (*atomic_open)(struct inode___289 *, struct dentry___289 *, struct file___289 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___214;

struct file_operations___289 {
	struct module___180 *owner;
	loff_t (*llseek)(struct file___289 *, loff_t, int);
	ssize_t (*read)(struct file___289 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___289 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___76 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___76 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___289 *, void *, filldir_t);
	unsigned int (*poll)(struct file___289 *, struct poll_table_struct___175 *);
	long int (*unlocked_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___289 *, struct vm_area_struct___297 *);
	int (*open)(struct inode___289 *, struct file___289 *);
	int (*flush)(struct file___289 *, fl_owner_t);
	int (*release)(struct inode___289 *, struct file___289 *);
	int (*fsync)(struct file___289 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___76 *, int);
	int (*fasync)(int, struct file___289 *, int);
	int (*lock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*sendpage)(struct file___289 *, struct page___288 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*splice_write)(struct pipe_inode_info___11 *, struct file___289 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___289 *, loff_t *, struct pipe_inode_info___11 *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___289 *, long int, struct file_lock___289 **, void **);
		struct {
			int (*setlease)(struct file___289 *, long int, struct file_lock___289 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___289 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___214 *, struct file___289 *);
};

struct file_lock_operations___289;

struct lock_manager_operations___289;

struct file_lock___289 {
	struct file_lock___289 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___289 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___289 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___289 *fl_ops;
	const struct lock_manager_operations___289 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___289 {
	void (*fl_copy_lock)(struct file_lock___289 *, struct file_lock___289 *);
	void (*fl_release_private)(struct file_lock___289 *);
};

struct lock_manager_operations___289 {
	int (*lm_compare_owner)(struct file_lock___289 *, struct file_lock___289 *);
	long unsigned int (*lm_owner_key)(struct file_lock___289 *);
	void (*lm_notify)(struct file_lock___289 *);
	int (*lm_grant)(struct file_lock___289 *, struct file_lock___289 *, int);
	void (*lm_break)(struct file_lock___289 *);
	int (*lm_change)(struct file_lock___289 **, int);
};

struct file_system_type___289 {
	const char *name;
	int fs_flags;
	struct dentry___289 * (*mount)(struct file_system_type___289 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___289 *);
	struct module___180 *owner;
	struct file_system_type___289 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___289 {
	struct inode___289 * (*alloc_inode)(struct super_block___289 *);
	void (*destroy_inode)(struct inode___289 *);
	void (*dirty_inode)(struct inode___289 *, int);
	int (*write_inode)(struct inode___289 *, struct writeback_control *);
	int (*drop_inode)(struct inode___289 *);
	void (*evict_inode)(struct inode___289 *);
	void (*put_super)(struct super_block___289 *);
	int (*sync_fs)(struct super_block___289 *, int);
	int (*freeze_fs)(struct super_block___289 *);
	int (*unfreeze_fs)(struct super_block___289 *);
	int (*statfs)(struct dentry___289 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___289 *, int *, char *);
	void (*umount_begin)(struct super_block___289 *);
	int (*show_options)(struct seq_file___214 *, struct dentry___289 *);
	int (*show_devname)(struct seq_file___214 *, struct dentry___289 *);
	int (*show_path)(struct seq_file___214 *, struct dentry___289 *);
	int (*show_stats)(struct seq_file___214 *, struct dentry___289 *);
	ssize_t (*quota_read)(struct super_block___289 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___289 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___289 *);
	int (*bdev_try_to_free_page)(struct super_block___289 *, struct page___288 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___289 *);
	void (*free_cached_objects)(struct super_block___289 *, int);
};

struct xattr_handler___185 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___289 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___289 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___289 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___214;

struct seq_file___214 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___291 lock;
	const struct seq_operations___214 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kmem_cache_cpu___271 {
	void **freelist;
	long unsigned int tid;
	struct page___288 *page;
	struct page___288 *partial;
};

struct memcg_cache_params___272 {
	bool is_root_cache;
	union {
		struct kmem_cache___272 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___272 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___152 {
	void * (*alloc)(struct device___287 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___287 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___287 *, struct vm_area_struct___297 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___287 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___287 *, struct page___288 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___287 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___287 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___287 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___287 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___287 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___287 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___287 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___287 *, dma_addr_t);
	int (*dma_supported)(struct device___287 *, u64);
	int (*set_dma_mask)(struct device___287 *, u64);
	int is_phys;
};

struct bus_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___287 *, char *);
	ssize_t (*store)(struct bus_type___287 *, const char *, size_t);
};

struct device_attribute___287;

struct driver_attribute___287;

struct bus_type___287 {
	const char *name;
	const char *dev_name;
	struct device___287 *dev_root;
	struct bus_attribute___287 *bus_attrs;
	struct device_attribute___287 *dev_attrs;
	struct driver_attribute___287 *drv_attrs;
	const struct attribute_group___249 **bus_groups;
	const struct attribute_group___249 **dev_groups;
	const struct attribute_group___249 **drv_groups;
	int (*match)(struct device___287 *, struct device_driver___287 *);
	int (*uevent)(struct device___287 *, struct kobj_uevent_env *);
	int (*probe)(struct device___287 *);
	int (*remove)(struct device___287 *);
	void (*shutdown)(struct device___287 *);
	int (*online)(struct device___287 *);
	int (*offline)(struct device___287 *);
	int (*suspend)(struct device___287 *, pm_message_t);
	int (*resume)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct device___287 *, struct device_attribute___287 *, char *);
	ssize_t (*store)(struct device___287 *, struct device_attribute___287 *, const char *, size_t);
};

struct driver_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___287 *, char *);
	ssize_t (*store)(struct device_driver___287 *, const char *, size_t);
};

struct device_driver___287 {
	const char *name;
	struct bus_type___287 *bus;
	struct module___180 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___287 *);
	int (*remove)(struct device___287 *);
	void (*shutdown)(struct device___287 *);
	int (*suspend)(struct device___287 *, pm_message_t);
	int (*resume)(struct device___287 *);
	const struct attribute_group___249 **groups;
	const struct dev_pm_ops___287 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___287 {
	const char *name;
	const struct attribute_group___249 **groups;
	int (*uevent)(struct device___287 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___287 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
};

struct class_attribute___287;

struct class___287 {
	const char *name;
	struct module___180 *owner;
	struct class_attribute___287 *class_attrs;
	struct device_attribute___287 *dev_attrs;
	const struct attribute_group___249 **dev_groups;
	struct bin_attribute___251 *dev_bin_attrs;
	struct kobject___71 *dev_kobj;
	int (*dev_uevent)(struct device___287 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___287 *, umode_t *);
	void (*class_release)(struct class___287 *);
	void (*dev_release)(struct device___287 *);
	int (*suspend)(struct device___287 *, pm_message_t);
	int (*resume)(struct device___287 *);
	const struct kobj_ns_type_operations___68 *ns_type;
	const void * (*namespace)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
	struct subsys_private *p;
};

struct class_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct class___287 *, struct class_attribute___287 *, char *);
	ssize_t (*store)(struct class___287 *, struct class_attribute___287 *, const char *, size_t);
	const void * (*namespace)(struct class___287 *, const struct class_attribute___287 *);
};

struct device_rh___287 {
	struct dev_pm_info_rh___287 power;
};

struct vm_fault___259 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___288 *page;
};

struct nf_bridge_info___79 {
	atomic_t use;
	unsigned int mask;
	struct net_device___79 *physindev;
	struct net_device___79 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___79(struct sk_buff___81 **);

struct net_device_ops___79;

struct ethtool_ops___79;

struct header_ops___79;

struct netdev_rx_queue___79;

struct netdev_queue___79;

struct rtnl_link_ops___70;

struct dcbnl_rtnl_ops___79;

struct net_device___79 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___79 *netdev_ops;
	const struct ethtool_ops___79 *ethtool_ops;
	const struct header_ops___79 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___71 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___79 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___79 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___79 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___79 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___79 = 0,
		NETREG_REGISTERED___79 = 1,
		NETREG_UNREGISTERING___79 = 2,
		NETREG_UNREGISTERED___79 = 3,
		NETREG_RELEASED___79 = 4,
		NETREG_DUMMY___79 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___79 = 0,
		RTNL_LINK_INITIALIZING___79 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___79 *);
	struct netpoll_info *npinfo;
	struct net___93 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___287 dev;
	const struct attribute_group___249 *sysfs_groups[4];
	const struct rtnl_link_ops___70 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___79 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___81 {
	struct sk_buff___81 *next;
	struct sk_buff___81 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___68 *sk;
	struct net_device___79 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___81 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___79 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct dev_pm_qos_request___91 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___287 *dev;
};

struct ethtool_ops___79 {
	int (*get_settings)(struct net_device___79 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___79 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___79 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___79 *);
	void (*get_regs)(struct net_device___79 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___79 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___79 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___79 *);
	void (*set_msglevel)(struct net_device___79 *, u32);
	int (*nway_reset)(struct net_device___79 *);
	u32 (*get_link)(struct net_device___79 *);
	int (*get_eeprom_len)(struct net_device___79 *);
	int (*get_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___79 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___79 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___79 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___79 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___79 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___79 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___79 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___79 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___79 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___79 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___79 *);
	void (*complete)(struct net_device___79 *);
	u32 (*get_priv_flags)(struct net_device___79 *);
	int (*set_priv_flags)(struct net_device___79 *, u32);
	int (*get_sset_count)(struct net_device___79 *, int);
	int (*get_rxnfc)(struct net_device___79 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___79 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___79 *, struct ethtool_flash *);
	int (*reset)(struct net_device___79 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___79 *);
	int (*get_rxfh_indir)(struct net_device___79 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___79 *, const u32 *);
	void (*get_channels)(struct net_device___79 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___79 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___79 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___79 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___79 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___79 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___79 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___79 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___79 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___79 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___79 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___79 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___69 {
	struct callback_head callback_head;
	struct dst_entry___69 *child;
	struct net_device___79 *dev;
	struct dst_ops___93 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___69 *path;
	struct dst_entry___69 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___81 *);
	union {
		int (*output)(struct sock___68 *, struct sk_buff___81 *);
		struct {
			int (*output)(struct sk_buff___81 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___69 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___69;

struct neigh_parms___69;

struct neigh_ops___69;

struct neighbour___69 {
	struct neighbour___69 *next;
	struct neigh_table___69 *tbl;
	struct neigh_parms___69 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___80 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___69 *, struct sk_buff___81 *);
	const struct neigh_ops___69 *ops;
	struct callback_head rcu;
	struct net_device___79 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___94 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___81 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___81 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___93 *, struct dst_entry___69 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___81 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___81 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___213 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___213 *);
	void (*irq_shutdown)(struct irq_data___213 *);
	void (*irq_enable)(struct irq_data___213 *);
	void (*irq_disable)(struct irq_data___213 *);
	void (*irq_ack)(struct irq_data___213 *);
	void (*irq_mask)(struct irq_data___213 *);
	void (*irq_mask_ack)(struct irq_data___213 *);
	void (*irq_unmask)(struct irq_data___213 *);
	void (*irq_eoi)(struct irq_data___213 *);
	int (*irq_set_affinity)(struct irq_data___213 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___213 *);
	int (*irq_set_type)(struct irq_data___213 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___213 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___213 *);
	void (*irq_bus_sync_unlock)(struct irq_data___213 *);
	void (*irq_cpu_online)(struct irq_data___213 *);
	void (*irq_cpu_offline)(struct irq_data___213 *);
	void (*irq_suspend)(struct irq_data___213 *);
	void (*irq_resume)(struct irq_data___213 *);
	void (*irq_pm_shutdown)(struct irq_data___213 *);
	void (*irq_print_chip)(struct irq_data___213 *, struct seq_file___214 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___213 *, void *);
	long unsigned int flags;
};

struct seq_operations___214 {
	void * (*start)(struct seq_file___214 *, loff_t *);
	void (*stop)(struct seq_file___214 *, void *);
	void * (*next)(struct seq_file___214 *, void *, loff_t *);
	int (*show)(struct seq_file___214 *, void *);
};

struct seq_net_private___12 {
	struct net___93 *net;
};

struct pernet_operations___27 {
	struct list_head list;
	int (*init)(struct net___93 *);
	void (*exit)(struct net___93 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___79 {
	int (*ieee_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___79 *);
	u8 (*setstate)(struct net_device___79 *, u8);
	void (*getpermhwaddr)(struct net_device___79 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___79 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___79 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___79 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___79 *, int, u8 *);
	void (*setpfccfg)(struct net_device___79 *, int, u8);
	void (*getpfccfg)(struct net_device___79 *, int, u8 *);
	u8 (*setall)(struct net_device___79 *);
	u8 (*getcap)(struct net_device___79 *, int, u8 *);
	int (*getnumtcs)(struct net_device___79 *, int, u8 *);
	int (*setnumtcs)(struct net_device___79 *, int, u8);
	u8 (*getpfcstate)(struct net_device___79 *);
	void (*setpfcstate)(struct net_device___79 *, u8);
	void (*getbcncfg)(struct net_device___79 *, int, u32 *);
	void (*setbcncfg)(struct net_device___79 *, int, u32);
	void (*getbcnrp)(struct net_device___79 *, int, u8 *);
	void (*setbcnrp)(struct net_device___79 *, int, u8);
	u8 (*setapp)(struct net_device___79 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___79 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___79 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___79 *, int, u8);
	u8 (*getdcbx)(struct net_device___79 *);
	u8 (*setdcbx)(struct net_device___79 *, u8);
	int (*peer_getappinfo)(struct net_device___79 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___79 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___79 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___79 *, struct cee_pfc *);
};

struct cgroupfs_root___184;

struct cgroup___184 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___184 *parent;
	struct dentry___289 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___184 *subsys[11];
	struct cgroupfs_root___184 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___291 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___184 {
	struct super_block___289 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___184 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___120 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___289 *, struct file___289 *);
	ssize_t (*read)(struct cgroup___184 *, struct cftype___120 *, struct file___289 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___184 *, struct cftype___120 *);
	s64 (*read_s64)(struct cgroup___184 *, struct cftype___120 *);
	int (*read_map)(struct cgroup___184 *, struct cftype___120 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___184 *, struct cftype___120 *, struct seq_file___214 *);
	ssize_t (*write)(struct cgroup___184 *, struct cftype___120 *, struct file___289 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___184 *, struct cftype___120 *, u64);
	int (*write_s64)(struct cgroup___184 *, struct cftype___120 *, s64);
	int (*write_string)(struct cgroup___184 *, struct cftype___120 *, const char *);
	int (*trigger)(struct cgroup___184 *, unsigned int);
	int (*release)(struct inode___289 *, struct file___289 *);
	int (*register_event)(struct cgroup___184 *, struct cftype___120 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___184 *, struct cftype___120 *, struct eventfd_ctx *);
};

struct cftype_set___116 {
	struct list_head node;
	struct cftype___120 *cfts;
};

struct task_and_cgroup___116 {
	struct task_struct___290 *task;
	struct cgroup___184 *cgrp;
	struct css_set___184 *cg;
};

struct cgroup_taskset___116 {
	struct task_and_cgroup___116 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___184 *cur_cgrp;
};

struct cgroup_subsys___116 {
	struct cgroup_subsys_state___184 * (*css_alloc)(struct cgroup___184 *);
	int (*css_online)(struct cgroup___184 *);
	void (*css_offline)(struct cgroup___184 *);
	void (*css_free)(struct cgroup___184 *);
	int (*can_attach)(struct cgroup___184 *, struct cgroup_taskset___116 *);
	void (*cancel_attach)(struct cgroup___184 *, struct cgroup_taskset___116 *);
	void (*attach)(struct cgroup___184 *, struct cgroup_taskset___116 *);
	void (*fork)(struct task_struct___290 *);
	void (*exit)(struct cgroup___184 *, struct cgroup___184 *, struct task_struct___290 *);
	void (*bind)(struct cgroup___184 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___184 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___120 *base_cftypes;
	struct cftype_set___116 base_cftset;
	struct module___180 *module;
};

struct scm_fp_list___5 {
	short int count;
	short int max;
	struct file___289 *fp[253];
};

struct scm_cookie___5 {
	struct pid___97 *pid;
	struct scm_fp_list___5 *fp;
	struct scm_creds creds;
	u32 secid;
};

struct netlink_callback___81 {
	struct sk_buff___81 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___81 *, struct netlink_callback___81 *);
	int (*done)(struct netlink_callback___81 *);
	void *data;
	struct module___180 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___79 {
	int (*create)(struct sk_buff___81 *, struct net_device___79 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___81 *, unsigned char *);
	int (*rebuild)(struct sk_buff___81 *);
	int (*cache)(const struct neighbour___69 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___79 *, const unsigned char *);
};

struct napi_struct___79 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___79 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___79 *dev;
	struct sk_buff___81 *gro_list;
	struct sk_buff___81 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___79 {
	struct net_device___79 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___71 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___79 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___71 kobj;
	struct net_device___79 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___79 {
	int (*ndo_init)(struct net_device___79 *);
	void (*ndo_uninit)(struct net_device___79 *);
	int (*ndo_open)(struct net_device___79 *);
	int (*ndo_stop)(struct net_device___79 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___81 *, struct net_device___79 *);
	u16 (*ndo_select_queue)(struct net_device___79 *, struct sk_buff___81 *);
	void (*ndo_change_rx_flags)(struct net_device___79 *, int);
	void (*ndo_set_rx_mode)(struct net_device___79 *);
	int (*ndo_set_mac_address)(struct net_device___79 *, void *);
	int (*ndo_validate_addr)(struct net_device___79 *);
	int (*ndo_do_ioctl)(struct net_device___79 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___79 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___79 *, int);
	int (*ndo_neigh_setup)(struct net_device___79 *, struct neigh_parms___69 *);
	void (*ndo_tx_timeout)(struct net_device___79 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___79 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___79 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___79 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___79 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___79 *);
	int (*ndo_netpoll_setup)(struct net_device___79 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___79 *);
	int (*ndo_busy_poll)(struct napi_struct___79 *);
	int (*ndo_set_vf_mac)(struct net_device___79 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___79 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___79 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___79 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___79 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___79 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___79 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___79 *, int, struct sk_buff___81 *);
	int (*ndo_setup_tc)(struct net_device___79 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___79 *);
	int (*ndo_fcoe_disable)(struct net_device___79 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___79 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___79 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___79 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___79 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___79 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___79 *, const struct sk_buff___81 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___79 *, struct net_device___79 *);
	int (*ndo_del_slave)(struct net_device___79 *, struct net_device___79 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___69 *);
	void (*ndo_neigh_destroy)(struct neighbour___69 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___81 *, struct netlink_callback___81 *, struct net_device___79 *, int);
	int (*ndo_bridge_setlink)(struct net_device___79 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___81 *, u32, u32, struct net_device___79 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___79 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___79 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___79 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___79 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___79 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___79 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___81 *, struct net_device___79 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___79 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___79 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___79 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___69 {
	struct net___93 *net;
	struct net_device___79 *dev;
	struct neigh_parms___69 *next;
	int (*neigh_setup)(struct neighbour___69 *);
	void (*neigh_cleanup)(struct neighbour___69 *);
	struct neigh_table___69 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___70 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___79 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___93 *, struct net_device___79 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___79 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___79 *, struct list_head *);
	size_t (*get_size)(const struct net_device___79 *);
	int (*fill_info)(struct sk_buff___81 *, const struct net_device___79 *);
	size_t (*get_xstats_size)(const struct net_device___79 *);
	int (*fill_xstats)(struct sk_buff___81 *, const struct net_device___79 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___93 * (*get_link_net)(const struct net_device___79 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___79 *, struct net_device___79 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___79 *, const struct net_device___79 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___81 *, const struct net_device___79 *, const struct net_device___79 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___69 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___81 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef struct poll_table_struct___175 poll_table___43;

struct pneigh_entry___69;

struct neigh_hash_table___69;

struct neigh_table___69 {
	struct neigh_table___69 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___79 *, __u32 *);
	int (*constructor)(struct neighbour___69 *);
	int (*pconstructor)(struct pneigh_entry___69 *);
	void (*pdestructor)(struct pneigh_entry___69 *);
	void (*proxy_redo)(struct sk_buff___81 *);
	char *id;
	struct neigh_parms___69 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___80 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___69 *nht;
	struct pneigh_entry___69 **phash_buckets;
};

struct neigh_ops___69 {
	int family;
	void (*solicit)(struct neighbour___69 *, struct sk_buff___81 *);
	void (*error_report)(struct neighbour___69 *, struct sk_buff___81 *);
	int (*output)(struct neighbour___69 *, struct sk_buff___81 *);
	int (*connected_output)(struct neighbour___69 *, struct sk_buff___81 *);
};

struct pneigh_entry___69 {
	struct pneigh_entry___69 *next;
	struct net___93 *net;
	struct net_device___79 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___69 {
	struct neighbour___69 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___68 {
	void (*close)(struct sock___68 *, long int);
	int (*connect)(struct sock___68 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___68 *, int);
	struct sock___68 * (*accept)(struct sock___68 *, int, int *);
	int (*ioctl)(struct sock___68 *, int, long unsigned int);
	int (*init)(struct sock___68 *);
	void (*destroy)(struct sock___68 *);
	void (*shutdown)(struct sock___68 *, int);
	int (*setsockopt)(struct sock___68 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___68 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___68 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___68 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___68 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___76 *, struct sock___68 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___76 *, struct sock___68 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___68 *, struct page___288 *, int, size_t, int);
	int (*bind)(struct sock___68 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___68 *, struct sk_buff___81 *);
	void (*release_cb)(struct sock___68 *);
	void (*mtu_reduced)(struct sock___68 *);
	void (*hash)(struct sock___68 *);
	void (*unhash)(struct sock___68 *);
	void (*rehash)(struct sock___68 *);
	int (*get_port)(struct sock___68 *, short unsigned int);
	void (*clear_sk)(struct sock___68 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___68 *);
	void (*enter_memory_pressure)(struct sock___68 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___272 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___18 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___180 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___116 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___68 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___68 {
	void (*enter_memory_pressure)(struct sock___68 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct sock_iocb___3 {
	struct list_head list;
	int flags;
	int size;
	struct socket___69 *sock;
	struct sock___68 *sk;
	struct scm_cookie___5 *scm;
	struct msghdr *msg;
	struct msghdr async_msg;
	struct kiocb___76 *kiocb;
};

struct socket_alloc___5 {
	struct socket___69 socket;
	struct inode___289 vfs_inode;
};

struct unix_skb_parms {
	struct pid___97 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list___5 *fp;
	u32 secid;
	u32 consumed;
};

struct unix_sock___2 {
	struct sock___68 sk;
	struct unix_address *addr;
	struct path___289 path;
	struct mutex___291 readlock;
	struct sock___68 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	unsigned char recursion_level;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___68 peer_wq;
};

struct pipe_buf_operations___11;

struct pipe_buffer___11 {
	struct page___288 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___11 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___11 {
	int can_merge;
	void * (*map)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *, int);
	void (*unmap)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *, void *);
	int (*confirm)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	void (*release)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	int (*steal)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	void (*get)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
};

struct splice_pipe_desc___6 {
	struct page___288 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	unsigned int flags;
	const struct pipe_buf_operations___11 *ops;
	void (*spd_release)(struct splice_pipe_desc___6 *, unsigned int);
};

struct unix_stream_read_state {
	int (*recv_actor)(struct sk_buff___81 *, int, int, struct unix_stream_read_state *);
	struct socket___69 *socket;
	struct msghdr *msg;
	struct kiocb___76 *kiocb;
	struct pipe_inode_info___11 *pipe;
	size_t size;
	int flags;
	unsigned int splice_flags;
};

struct page___289;

typedef struct page___289 *pgtable_t___289;

struct address_space___290;

struct kmem_cache___273;

struct page___289 {
	long unsigned int flags;
	struct address_space___290 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___289 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___289 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___273 *slab_cache;
		struct page___289 *first_page;
	};
	long: 64;
};

struct task_struct___291;

struct pv_cpu_ops___291 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___291 *);
	void (*end_context_switch)(struct task_struct___291 *);
};

struct mutex___292 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___291 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___284 {
	struct page___289 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___298;

struct nsproxy___170;

struct signal_struct___291;

struct css_set___185;

struct task_struct___291 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___291 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___298 *mm;
	struct mm_struct___298 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___291 *real_parent;
	struct task_struct___291 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___291 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___291 = 0,
		VTIME_USER___291 = 1,
		VTIME_SYS___291 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___170 *nsproxy;
	struct signal_struct___291 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___185 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___292 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___284 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___298 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___298 *, struct mm_struct___298 *);
	void (*dup_mmap)(struct mm_struct___298 *, struct mm_struct___298 *);
	void (*exit_mmap)(struct mm_struct___298 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___298 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___298 *);
	void (*pgd_free)(struct mm_struct___298 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___298 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___298 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___298 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___298 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___298 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___298 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___298 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___298 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___298 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___298 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___298 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___292 lock;
	void *vdso;
} mm_context_t___292;

struct xol_area___289;

struct uprobes_state___289 {
	struct xol_area___289 *xol_area;
};

struct vm_area_struct___298;

struct file___290;

struct core_state___291;

struct mm_struct___298 {
	struct vm_area_struct___298 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___298 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___298 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___292 context;
	long unsigned int flags;
	struct core_state___291 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___291 *owner;
	struct file___290 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___289 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___289 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___289 *page;
	long unsigned int vaddr;
};

struct kset___72;

struct kobj_type___72;

struct kobject___72 {
	const char *name;
	struct list_head entry;
	struct kobject___72 *parent;
	struct kset___72 *kset;
	struct kobj_type___72 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___272;

struct memcg_cache_params___273;

struct kmem_cache___273 {
	struct kmem_cache_cpu___272 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___72 kobj;
	struct memcg_cache_params___273 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___290;

struct address_space_operations___290;

struct address_space___290 {
	struct inode___290 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___292 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___290 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___290;

struct path___290 {
	struct vfsmount *mnt;
	struct dentry___290 *dentry;
};

struct file_operations___290;

struct file___290 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___290 f_path;
	struct inode___290 *f_inode;
	const struct file_operations___290 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___290 *f_mapping;
	struct mutex___292 f_pos_lock;
};

struct vm_operations_struct___264;

struct vm_area_struct___298 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___298 *vm_next;
	struct vm_area_struct___298 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___298 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___264 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___290 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___260;

struct vm_operations_struct___264 {
	void (*open)(struct vm_area_struct___298 *);
	void (*close)(struct vm_area_struct___298 *);
	int (*fault)(struct vm_area_struct___298 *, struct vm_fault___260 *);
	int (*page_mkwrite)(struct vm_area_struct___298 *, struct vm_fault___260 *);
	int (*access)(struct vm_area_struct___298 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___298 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___298 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___298 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___298 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___291 {
	struct task_struct___291 *task;
	struct core_thread___291 *next;
};

struct core_state___291 {
	atomic_t nr_threads;
	struct core_thread___291 dumper;
	struct completion startup;
};

struct fasync_struct___290;

struct socket_wq___69 {
	wait_queue_head_t wait;
	struct fasync_struct___290 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___290 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___290 *fa_next;
	struct file___290 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___69;

struct proto_ops___69;

struct socket___70 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___69 *wq;
	struct file___290 *file;
	struct sock___69 *sk;
	const struct proto_ops___69 *ops;
};

struct proto___69;

struct net___94;

struct sock_common___69 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___69 *skc_prot;
	struct net___94 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___82;

struct sk_buff_head___81 {
	struct sk_buff___82 *next;
	struct sk_buff___82 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___70;

struct dst_entry___70;

struct cg_proto___69;

struct sock___69 {
	struct sock_common___69 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___81 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___82 *head;
		struct sk_buff___82 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___70 *sk_filter;
	struct socket_wq___69 *sk_wq;
	struct sk_buff_head___81 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___70 *sk_rx_dst;
	struct dst_entry___70 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___81 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___81 sk_error_queue;
	struct proto___69 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___70 *sk_socket;
	void *sk_user_data;
	struct page_frag___284 sk_frag;
	struct sk_buff___82 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___69 *sk_cgrp;
	void (*sk_state_change)(struct sock___69 *);
	void (*sk_data_ready)(struct sock___69 *, int);
	void (*sk_write_space)(struct sock___69 *);
	void (*sk_error_report)(struct sock___69 *);
	int (*sk_backlog_rcv)(struct sock___69 *, struct sk_buff___82 *);
	void (*sk_destruct)(struct sock___69 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___176;

struct kiocb___77;

struct proto_ops___69 {
	int family;
	struct module *owner;
	int (*release)(struct socket___70 *);
	int (*bind)(struct socket___70 *, struct sockaddr *, int);
	int (*connect)(struct socket___70 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___70 *, struct socket___70 *);
	int (*accept)(struct socket___70 *, struct socket___70 *, int);
	int (*getname)(struct socket___70 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___290 *, struct socket___70 *, struct poll_table_struct___176 *);
	int (*ioctl)(struct socket___70 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___70 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___70 *, int);
	int (*shutdown)(struct socket___70 *, int);
	int (*setsockopt)(struct socket___70 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___70 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___70 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___70 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___77 *, struct socket___70 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___77 *, struct socket___70 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___290 *, struct socket___70 *, struct vm_area_struct___298 *);
	ssize_t (*sendpage)(struct socket___70 *, struct page___289 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___70 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___69 *, int);
		struct {
			void (*set_peek_off)(struct sock___69 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___178)(struct file___290 *, wait_queue_head_t *, struct poll_table_struct___176 *);

struct poll_table_struct___176 {
	poll_queue_proc___178 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___77(struct kiocb___77 *, struct io_event *);

struct kiocb___77 {
	atomic_t ki_users;
	struct file___290 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___77 *ki_cancel;
	void (*ki_dtor)(struct kiocb___77 *);
	union {
		void *user;
		struct task_struct___291 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___95;

struct ctl_table_set___95;

struct ctl_dir___95;

struct ctl_node___95;

struct ctl_table_header___95 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___95 *root;
	struct ctl_table_set___95 *set;
	struct ctl_dir___95 *parent;
	struct ctl_node___95 *node;
};

struct ctl_dir___95 {
	struct ctl_table_header___95 header;
	struct rb_root root;
};

struct ctl_table_set___95 {
	int (*is_seen)(struct ctl_table_set___95 *);
	struct ctl_dir___95 dir;
};

struct netns_core___92 {
	struct ctl_table_header___95 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___93 {
	struct mutex___292 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___92 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___95 *ctl;
};

struct netns_ipv4___92 {
	struct ctl_table_header___95 *forw_hdr;
	struct ctl_table_header___95 *frags_hdr;
	struct ctl_table_header___95 *ipv4_hdr;
	struct ctl_table_header___95 *route_hdr;
	struct ctl_table_header___95 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___69 *fibnl;
	struct sock___69 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___92 {
	struct ctl_table_header___95 *hdr;
	struct ctl_table_header___95 *route_hdr;
	struct ctl_table_header___95 *icmp_hdr;
	struct ctl_table_header___95 *frags_hdr;
	struct ctl_table_header___95 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___80;

struct neighbour___70;

struct dst_ops___94 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___94 *);
	struct dst_entry___70 * (*check)(struct dst_entry___70 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___70 *);
	unsigned int (*mtu)(const struct dst_entry___70 *);
	u32 * (*cow_metrics)(struct dst_entry___70 *, long unsigned int);
	void (*destroy)(struct dst_entry___70 *);
	void (*ifdown)(struct dst_entry___70 *, struct net_device___80 *, int);
	struct dst_entry___70 * (*negative_advice)(struct dst_entry___70 *);
	void (*link_failure)(struct sk_buff___82 *);
	void (*update_pmtu)(struct dst_entry___70 *, struct sock___69 *, struct sk_buff___82 *, u32);
	void (*redirect)(struct dst_entry___70 *, struct sock___69 *, struct sk_buff___82 *);
	int (*local_out)(struct sk_buff___82 *);
	struct neighbour___70 * (*neigh_lookup)(const struct dst_entry___70 *, struct sk_buff___82 *, const void *);
	struct kmem_cache___273 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___94 {
	struct netns_sysctl_ipv6___92 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___94 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___69 **icmp_sk;
	struct sock___69 *ndisc_sk;
	struct sock___69 *tcp_sk;
	struct sock___69 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___92 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___95 *sysctl_header;
	struct sock___69 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___69 {
	struct sock___69 *v4_ctl_sk;
	struct sock___69 *v6_ctl_sk;
};

struct netns_nf___92 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___95 *nf_log_dir_header;
};

struct nf_proto_net___92 {
	struct ctl_table_header___95 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___92 {
	struct nf_proto_net___92 pn;
	unsigned int timeout;
};

struct nf_tcp_net___92 {
	struct nf_proto_net___92 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___92 {
	struct nf_proto_net___92 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___92 {
	struct nf_proto_net___92 pn;
	unsigned int timeout;
};

struct nf_ip_net___92 {
	struct nf_generic_net___92 generic;
	struct nf_tcp_net___92 tcp;
	struct nf_udp_net___92 udp;
	struct nf_icmp_net___92 icmp;
	struct nf_icmp_net___92 icmpv6;
};

struct netns_ct___93 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___95 *sysctl_header;
	struct ctl_table_header___95 *acct_sysctl_header;
	struct ctl_table_header___95 *tstamp_sysctl_header;
	struct ctl_table_header___95 *event_sysctl_header;
	struct ctl_table_header___95 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___273 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___92 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___92 {
	struct netns_sysctl_ipv6___92 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___94 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___69 *nlsk;
	struct sock___69 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___95 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___94 xfrm4_dst_ops;
	struct dst_ops___94 xfrm6_dst_ops;
};

struct net___94 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___95 sysctls;
	struct sock___69 *rtnl;
	struct sock___69 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___80 *loopback_dev;
	struct netns_core___92 core;
	struct netns_mib mib;
	struct netns_packet___93 packet;
	struct netns_unix___92 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___92 ipv4;
	struct netns_ipv6___94 ipv6;
	struct netns_sctp___92 sctp;
	struct netns_dccp___69 dccp;
	struct netns_nf___92 nf;
	struct netns_xt xt;
	struct netns_ct___93 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___92 nf_frag;
	struct sock___69 *nfnl;
	struct sock___69 *nfnl_stash;
	struct sk_buff_head___81 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___94 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___69 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___69 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___292 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___292 flow_flush_sem;
	long: 64;
	long: 64;
};

struct dentry_operations___290;

struct super_block___290;

struct dentry___290 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___290 *d_parent;
	struct qstr d_name;
	struct inode___290 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___290 *d_op;
	struct super_block___290 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___290;

struct file_lock___290;

struct dquot___290;

struct block_device___290;

struct inode___290 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___290 *i_op;
	struct super_block___290 *i_sb;
	struct address_space___290 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___292 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___290 *i_fop;
	struct file_lock___290 *i_flock;
	struct address_space___290 i_data;
	struct dquot___290 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___290 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___290 {
	int (*d_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_hash)(const struct dentry___290 *, struct qstr *);
	int (*d_compare)(const struct dentry___290 *, const struct dentry___290 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___290 *);
	void (*d_release)(struct dentry___290 *);
	void (*d_prune)(struct dentry___290 *);
	void (*d_iput)(struct dentry___290 *, struct inode___290 *);
	char * (*d_dname)(struct dentry___290 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___290 *);
	int (*d_manage)(struct dentry___290 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___290;

struct mem_dqinfo___290 {
	struct quota_format_type___290 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___290;

struct quota_info___290 {
	unsigned int flags;
	struct mutex___292 dqio_mutex;
	struct mutex___292 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___290 *files[2];
	struct mem_dqinfo___290 info[2];
	const struct quota_format_ops___290 *ops[2];
};

struct file_system_type___290;

struct super_operations___290;

struct dquot_operations___290;

struct quotactl_ops___290;

struct xattr_handler___186;

struct super_block___290 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___290 *s_type;
	const struct super_operations___290 *s_op;
	const struct dquot_operations___290 *dq_op;
	const struct quotactl_ops___290 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___290 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___186 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___290 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___290 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___292 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___290 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct irq_data___214;

struct x86_io_apic_ops___214 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___214 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___214;

struct irq_data___214 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___214 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___288;

struct dev_pm_ops___288 {
	int (*prepare)(struct device___288 *);
	void (*complete)(struct device___288 *);
	int (*suspend)(struct device___288 *);
	int (*resume)(struct device___288 *);
	int (*freeze)(struct device___288 *);
	int (*thaw)(struct device___288 *);
	int (*poweroff)(struct device___288 *);
	int (*restore)(struct device___288 *);
	int (*suspend_late)(struct device___288 *);
	int (*resume_early)(struct device___288 *);
	int (*freeze_late)(struct device___288 *);
	int (*thaw_early)(struct device___288 *);
	int (*poweroff_late)(struct device___288 *);
	int (*restore_early)(struct device___288 *);
	int (*suspend_noirq)(struct device___288 *);
	int (*resume_noirq)(struct device___288 *);
	int (*freeze_noirq)(struct device___288 *);
	int (*thaw_noirq)(struct device___288 *);
	int (*poweroff_noirq)(struct device___288 *);
	int (*restore_noirq)(struct device___288 *);
	int (*runtime_suspend)(struct device___288 *);
	int (*runtime_resume)(struct device___288 *);
	int (*runtime_idle)(struct device___288 *);
};

struct dev_pm_qos___91;

struct dev_pm_info___91 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___91 *qos;
};

struct dma_map_ops___153;

struct dev_archdata___153 {
	struct dma_map_ops___153 *dma_ops;
	void *iommu;
};

struct device_type___288;

struct bus_type___288;

struct device_driver___288;

struct dev_pm_domain___288;

struct class___288;

struct attribute_group___250;

struct device_rh___288;

struct device___288 {
	struct device___288 *parent;
	struct device_private *p;
	struct kobject___72 kobj;
	const char *init_name;
	const struct device_type___288 *type;
	struct mutex___292 mutex;
	struct bus_type___288 *bus;
	struct device_driver___288 *driver;
	void *platform_data;
	struct dev_pm_info___91 power;
	struct dev_pm_domain___288 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___153 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___288 *class;
	const struct attribute_group___250 **groups;
	void (*release)(struct device___288 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___288 *device_rh;
};

struct dev_pm_qos_request___92;

struct dev_pm_qos___91 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___92 *latency_req;
	struct dev_pm_qos_request___92 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___92 *latency_tolerance_req;
};

struct dev_pm_info_rh___288 {
	void (*set_latency_tolerance)(struct device___288 *, s32);
};

struct dev_pm_domain___288 {
	struct dev_pm_ops___288 ops;
};

struct smp_ops___291 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___291 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct block_device___290 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___290 *bd_inode;
	struct super_block___290 *bd_super;
	struct mutex___292 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___290 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___292 bd_fsfreeze_mutex;
};

struct cgroup___185;

struct cgroup_subsys_state___185 {
	struct cgroup___185 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___290 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___290 *ia_file;
};

struct zone___291;

struct lruvec___291 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___291 *zone;
};

struct pglist_data___291;

struct zone___291 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___291 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___291 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___291 {
	struct zone___291 *zone;
	int zone_idx;
};

struct zonelist___291 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___291 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___291 {
	struct zone___291 node_zones[4];
	struct zonelist___291 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___291 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dquot___290 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___292 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___290 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___290 {
	int qf_fmt_id;
	const struct quota_format_ops___290 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___290 *qf_next;
};

struct quota_format_ops___290 {
	int (*check_quota_file)(struct super_block___290 *, int);
	int (*read_file_info)(struct super_block___290 *, int);
	int (*write_file_info)(struct super_block___290 *, int);
	int (*free_file_info)(struct super_block___290 *, int);
	int (*read_dqblk)(struct dquot___290 *);
	int (*commit_dqblk)(struct dquot___290 *);
	int (*release_dqblk)(struct dquot___290 *);
};

struct dquot_operations___290 {
	int (*write_dquot)(struct dquot___290 *);
	struct dquot___290 * (*alloc_dquot)(struct super_block___290 *, int);
	void (*destroy_dquot)(struct dquot___290 *);
	int (*acquire_dquot)(struct dquot___290 *);
	int (*release_dquot)(struct dquot___290 *);
	int (*mark_dirty)(struct dquot___290 *);
	int (*write_info)(struct super_block___290 *, int);
	qsize_t * (*get_reserved_space)(struct inode___290 *);
};

struct quotactl_ops___290 {
	int (*quota_on)(struct super_block___290 *, int, int, struct path___290 *);
	int (*quota_on_meta)(struct super_block___290 *, int, int);
	int (*quota_off)(struct super_block___290 *, int);
	int (*quota_sync)(struct super_block___290 *, int);
	int (*get_info)(struct super_block___290 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___290 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___290 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___290 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___290 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___290 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___290 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___290 *, unsigned int);
};

struct address_space_operations___290 {
	int (*writepage)(struct page___289 *, struct writeback_control *);
	int (*readpage)(struct file___290 *, struct page___289 *);
	int (*writepages)(struct address_space___290 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___289 *);
	int (*readpages)(struct file___290 *, struct address_space___290 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___290 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___289 **, void **);
	int (*write_end)(struct file___290 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___289 *, void *);
	sector_t (*bmap)(struct address_space___290 *, sector_t);
	void (*invalidatepage)(struct page___289 *, long unsigned int);
	int (*releasepage)(struct page___289 *, gfp_t);
	void (*freepage)(struct page___289 *);
	ssize_t (*direct_IO)(int, struct kiocb___77 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___290 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___290 *, struct page___289 *, struct page___289 *, enum migrate_mode);
	int (*launder_page)(struct page___289 *);
	int (*is_partially_uptodate)(struct page___289 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___289 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___290 *, struct page___289 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___290 *, sector_t *);
	void (*swap_deactivate)(struct file___290 *);
	void (*invalidatepage_range)(struct page___289 *, unsigned int, unsigned int);
};

struct inode_operations___290 {
	struct dentry___290 * (*lookup)(struct inode___290 *, struct dentry___290 *, unsigned int);
	void * (*follow_link)(struct dentry___290 *, struct nameidata *);
	int (*permission)(struct inode___290 *, int);
	struct posix_acl * (*get_acl)(struct inode___290 *, int);
	int (*readlink)(struct dentry___290 *, char *, int);
	void (*put_link)(struct dentry___290 *, struct nameidata *, void *);
	int (*create)(struct inode___290 *, struct dentry___290 *, umode_t, bool);
	int (*link)(struct dentry___290 *, struct inode___290 *, struct dentry___290 *);
	int (*unlink)(struct inode___290 *, struct dentry___290 *);
	int (*symlink)(struct inode___290 *, struct dentry___290 *, const char *);
	int (*mkdir)(struct inode___290 *, struct dentry___290 *, umode_t);
	int (*rmdir)(struct inode___290 *, struct dentry___290 *);
	int (*mknod)(struct inode___290 *, struct dentry___290 *, umode_t, dev_t);
	int (*rename)(struct inode___290 *, struct dentry___290 *, struct inode___290 *, struct dentry___290 *);
	int (*setattr)(struct dentry___290 *, struct iattr___290 *);
	int (*getattr)(struct vfsmount *, struct dentry___290 *, struct kstat *);
	int (*setxattr)(struct dentry___290 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___290 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___290 *, char *, size_t);
	int (*removexattr)(struct dentry___290 *, const char *);
	int (*fiemap)(struct inode___290 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___290 *, struct timespec *, int);
	int (*atomic_open)(struct inode___290 *, struct dentry___290 *, struct file___290 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___215;

struct file_operations___290 {
	struct module *owner;
	loff_t (*llseek)(struct file___290 *, loff_t, int);
	ssize_t (*read)(struct file___290 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___290 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___77 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___77 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___290 *, void *, filldir_t);
	unsigned int (*poll)(struct file___290 *, struct poll_table_struct___176 *);
	long int (*unlocked_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___290 *, struct vm_area_struct___298 *);
	int (*open)(struct inode___290 *, struct file___290 *);
	int (*flush)(struct file___290 *, fl_owner_t);
	int (*release)(struct inode___290 *, struct file___290 *);
	int (*fsync)(struct file___290 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___77 *, int);
	int (*fasync)(int, struct file___290 *, int);
	int (*lock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*sendpage)(struct file___290 *, struct page___289 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___290 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___290 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___290 *, long int, struct file_lock___290 **, void **);
		struct {
			int (*setlease)(struct file___290 *, long int, struct file_lock___290 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___290 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___215 *, struct file___290 *);
};

struct file_lock_operations___290;

struct lock_manager_operations___290;

struct file_lock___290 {
	struct file_lock___290 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___290 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___290 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___290 *fl_ops;
	const struct lock_manager_operations___290 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___290 {
	void (*fl_copy_lock)(struct file_lock___290 *, struct file_lock___290 *);
	void (*fl_release_private)(struct file_lock___290 *);
};

struct lock_manager_operations___290 {
	int (*lm_compare_owner)(struct file_lock___290 *, struct file_lock___290 *);
	long unsigned int (*lm_owner_key)(struct file_lock___290 *);
	void (*lm_notify)(struct file_lock___290 *);
	int (*lm_grant)(struct file_lock___290 *, struct file_lock___290 *, int);
	void (*lm_break)(struct file_lock___290 *);
	int (*lm_change)(struct file_lock___290 **, int);
};

struct file_system_type___290 {
	const char *name;
	int fs_flags;
	struct dentry___290 * (*mount)(struct file_system_type___290 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___290 *);
	struct module *owner;
	struct file_system_type___290 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___290 {
	struct inode___290 * (*alloc_inode)(struct super_block___290 *);
	void (*destroy_inode)(struct inode___290 *);
	void (*dirty_inode)(struct inode___290 *, int);
	int (*write_inode)(struct inode___290 *, struct writeback_control *);
	int (*drop_inode)(struct inode___290 *);
	void (*evict_inode)(struct inode___290 *);
	void (*put_super)(struct super_block___290 *);
	int (*sync_fs)(struct super_block___290 *, int);
	int (*freeze_fs)(struct super_block___290 *);
	int (*unfreeze_fs)(struct super_block___290 *);
	int (*statfs)(struct dentry___290 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___290 *, int *, char *);
	void (*umount_begin)(struct super_block___290 *);
	int (*show_options)(struct seq_file___215 *, struct dentry___290 *);
	int (*show_devname)(struct seq_file___215 *, struct dentry___290 *);
	int (*show_path)(struct seq_file___215 *, struct dentry___290 *);
	int (*show_stats)(struct seq_file___215 *, struct dentry___290 *);
	ssize_t (*quota_read)(struct super_block___290 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___290 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___290 *);
	int (*bdev_try_to_free_page)(struct super_block___290 *, struct page___289 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___290 *);
	void (*free_cached_objects)(struct super_block___290 *, int);
};

struct xattr_handler___186 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___290 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___290 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___290 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___215;

struct seq_file___215 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___292 lock;
	const struct seq_operations___215 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct kobj_ns_type_operations___69 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___69 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___252;

struct attribute_group___250 {
	const char *name;
	umode_t (*is_visible)(struct kobject___72 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___252 **bin_attrs;
};

struct bin_attribute___252 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___290 *, struct kobject___72 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___290 *, struct kobject___72 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	int (*mmap)(struct file___290 *, struct kobject___72 *, struct bin_attribute___252 *, struct vm_area_struct___298 *);
};

struct sysfs_ops___72 {
	ssize_t (*show)(struct kobject___72 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___72 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___72 *, const struct attribute *);
};

struct kset_uevent_ops___72;

struct kset___72 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___72 kobj;
	const struct kset_uevent_ops___72 *uevent_ops;
};

struct kobj_type___72 {
	void (*release)(struct kobject___72 *);
	const struct sysfs_ops___72 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___69 * (*child_ns_type)(struct kobject___72 *);
	const void * (*namespace)(struct kobject___72 *);
};

struct kset_uevent_ops___72 {
	int (* const filter)(struct kset___72 *, struct kobject___72 *);
	const char * (* const name)(struct kset___72 *, struct kobject___72 *);
	int (* const uevent)(struct kset___72 *, struct kobject___72 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___272 {
	void **freelist;
	long unsigned int tid;
	struct page___289 *page;
	struct page___289 *partial;
};

struct memcg_cache_params___273 {
	bool is_root_cache;
	union {
		struct kmem_cache___273 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___273 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___153 {
	void * (*alloc)(struct device___288 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___288 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___288 *, struct vm_area_struct___298 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___288 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___288 *, struct page___289 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___288 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___288 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___288 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___288 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___288 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___288 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___288 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___288 *, dma_addr_t);
	int (*dma_supported)(struct device___288 *, u64);
	int (*set_dma_mask)(struct device___288 *, u64);
	int is_phys;
};

struct bus_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___288 *, char *);
	ssize_t (*store)(struct bus_type___288 *, const char *, size_t);
};

struct device_attribute___288;

struct driver_attribute___288;

struct bus_type___288 {
	const char *name;
	const char *dev_name;
	struct device___288 *dev_root;
	struct bus_attribute___288 *bus_attrs;
	struct device_attribute___288 *dev_attrs;
	struct driver_attribute___288 *drv_attrs;
	const struct attribute_group___250 **bus_groups;
	const struct attribute_group___250 **dev_groups;
	const struct attribute_group___250 **drv_groups;
	int (*match)(struct device___288 *, struct device_driver___288 *);
	int (*uevent)(struct device___288 *, struct kobj_uevent_env *);
	int (*probe)(struct device___288 *);
	int (*remove)(struct device___288 *);
	void (*shutdown)(struct device___288 *);
	int (*online)(struct device___288 *);
	int (*offline)(struct device___288 *);
	int (*suspend)(struct device___288 *, pm_message_t);
	int (*resume)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct device___288 *, struct device_attribute___288 *, char *);
	ssize_t (*store)(struct device___288 *, struct device_attribute___288 *, const char *, size_t);
};

struct driver_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___288 *, char *);
	ssize_t (*store)(struct device_driver___288 *, const char *, size_t);
};

struct device_driver___288 {
	const char *name;
	struct bus_type___288 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___288 *);
	int (*remove)(struct device___288 *);
	void (*shutdown)(struct device___288 *);
	int (*suspend)(struct device___288 *, pm_message_t);
	int (*resume)(struct device___288 *);
	const struct attribute_group___250 **groups;
	const struct dev_pm_ops___288 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___288 {
	const char *name;
	const struct attribute_group___250 **groups;
	int (*uevent)(struct device___288 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___288 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
};

struct class_attribute___288;

struct class___288 {
	const char *name;
	struct module *owner;
	struct class_attribute___288 *class_attrs;
	struct device_attribute___288 *dev_attrs;
	const struct attribute_group___250 **dev_groups;
	struct bin_attribute___252 *dev_bin_attrs;
	struct kobject___72 *dev_kobj;
	int (*dev_uevent)(struct device___288 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___288 *, umode_t *);
	void (*class_release)(struct class___288 *);
	void (*dev_release)(struct device___288 *);
	int (*suspend)(struct device___288 *, pm_message_t);
	int (*resume)(struct device___288 *);
	const struct kobj_ns_type_operations___69 *ns_type;
	const void * (*namespace)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
	struct subsys_private *p;
};

struct class_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct class___288 *, struct class_attribute___288 *, char *);
	ssize_t (*store)(struct class___288 *, struct class_attribute___288 *, const char *, size_t);
	const void * (*namespace)(struct class___288 *, const struct class_attribute___288 *);
};

struct device_rh___288 {
	struct dev_pm_info_rh___288 power;
};

struct vm_fault___260 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___289 *page;
};

struct ctl_node___95 {
	struct rb_node node;
	struct ctl_table_header___95 *header;
};

struct ctl_table_root___95 {
	struct ctl_table_set___95 default_set;
	struct ctl_table_set___95 * (*lookup)(struct ctl_table_root___95 *, struct nsproxy___170 *);
	int (*permissions)(struct ctl_table_header___95 *, struct ctl_table *);
};

struct nsproxy___170 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___94 *net_ns;
};

struct signal_struct___291 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___291 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___291 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___292 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___185 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___185 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___80 {
	atomic_t use;
	unsigned int mask;
	struct net_device___80 *physindev;
	struct net_device___80 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___80(struct sk_buff___82 **);

struct net_device_ops___80;

struct ethtool_ops___80;

struct header_ops___80;

struct netdev_rx_queue___80;

struct netdev_queue___80;

struct rtnl_link_ops___71;

struct dcbnl_rtnl_ops___80;

struct net_device___80 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___80 *netdev_ops;
	const struct ethtool_ops___80 *ethtool_ops;
	const struct header_ops___80 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___72 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___80 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___80 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___80 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___80 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___80 = 0,
		NETREG_REGISTERED___80 = 1,
		NETREG_UNREGISTERING___80 = 2,
		NETREG_UNREGISTERED___80 = 3,
		NETREG_RELEASED___80 = 4,
		NETREG_DUMMY___80 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___80 = 0,
		RTNL_LINK_INITIALIZING___80 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___80 *);
	struct netpoll_info *npinfo;
	struct net___94 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___288 dev;
	const struct attribute_group___250 *sysfs_groups[4];
	const struct rtnl_link_ops___71 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___80 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___82 {
	struct sk_buff___82 *next;
	struct sk_buff___82 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___69 *sk;
	struct net_device___80 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___82 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___80 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct dev_pm_qos_request___92 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___288 *dev;
};

struct ethtool_ops___80 {
	int (*get_settings)(struct net_device___80 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___80 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___80 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___80 *);
	void (*get_regs)(struct net_device___80 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___80 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___80 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___80 *);
	void (*set_msglevel)(struct net_device___80 *, u32);
	int (*nway_reset)(struct net_device___80 *);
	u32 (*get_link)(struct net_device___80 *);
	int (*get_eeprom_len)(struct net_device___80 *);
	int (*get_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___80 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___80 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___80 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___80 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___80 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___80 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___80 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___80 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___80 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___80 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___80 *);
	void (*complete)(struct net_device___80 *);
	u32 (*get_priv_flags)(struct net_device___80 *);
	int (*set_priv_flags)(struct net_device___80 *, u32);
	int (*get_sset_count)(struct net_device___80 *, int);
	int (*get_rxnfc)(struct net_device___80 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___80 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___80 *, struct ethtool_flash *);
	int (*reset)(struct net_device___80 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___80 *);
	int (*get_rxfh_indir)(struct net_device___80 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___80 *, const u32 *);
	void (*get_channels)(struct net_device___80 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___80 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___80 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___80 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___80 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___80 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___80 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___80 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___80 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___80 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___80 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___80 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___70 {
	struct callback_head callback_head;
	struct dst_entry___70 *child;
	struct net_device___80 *dev;
	struct dst_ops___94 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___70 *path;
	struct dst_entry___70 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___82 *);
	union {
		int (*output)(struct sock___69 *, struct sk_buff___82 *);
		struct {
			int (*output)(struct sk_buff___82 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___70 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___70;

struct neigh_parms___70;

struct neigh_ops___70;

struct neighbour___70 {
	struct neighbour___70 *next;
	struct neigh_table___70 *tbl;
	struct neigh_parms___70 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___81 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___70 *, struct sk_buff___82 *);
	const struct neigh_ops___70 *ops;
	struct callback_head rcu;
	struct net_device___80 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___95 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___82 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___82 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___94 *, struct dst_entry___70 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___82 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___82 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___214 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___214 *);
	void (*irq_shutdown)(struct irq_data___214 *);
	void (*irq_enable)(struct irq_data___214 *);
	void (*irq_disable)(struct irq_data___214 *);
	void (*irq_ack)(struct irq_data___214 *);
	void (*irq_mask)(struct irq_data___214 *);
	void (*irq_mask_ack)(struct irq_data___214 *);
	void (*irq_unmask)(struct irq_data___214 *);
	void (*irq_eoi)(struct irq_data___214 *);
	int (*irq_set_affinity)(struct irq_data___214 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___214 *);
	int (*irq_set_type)(struct irq_data___214 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___214 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___214 *);
	void (*irq_bus_sync_unlock)(struct irq_data___214 *);
	void (*irq_cpu_online)(struct irq_data___214 *);
	void (*irq_cpu_offline)(struct irq_data___214 *);
	void (*irq_suspend)(struct irq_data___214 *);
	void (*irq_resume)(struct irq_data___214 *);
	void (*irq_pm_shutdown)(struct irq_data___214 *);
	void (*irq_print_chip)(struct irq_data___214 *, struct seq_file___215 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___214 *, void *);
	long unsigned int flags;
};

struct seq_operations___215 {
	void * (*start)(struct seq_file___215 *, loff_t *);
	void (*stop)(struct seq_file___215 *, void *);
	void * (*next)(struct seq_file___215 *, void *, loff_t *);
	int (*show)(struct seq_file___215 *, void *);
};

struct dcbnl_rtnl_ops___80 {
	int (*ieee_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___80 *);
	u8 (*setstate)(struct net_device___80 *, u8);
	void (*getpermhwaddr)(struct net_device___80 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___80 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___80 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___80 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___80 *, int, u8 *);
	void (*setpfccfg)(struct net_device___80 *, int, u8);
	void (*getpfccfg)(struct net_device___80 *, int, u8 *);
	u8 (*setall)(struct net_device___80 *);
	u8 (*getcap)(struct net_device___80 *, int, u8 *);
	int (*getnumtcs)(struct net_device___80 *, int, u8 *);
	int (*setnumtcs)(struct net_device___80 *, int, u8);
	u8 (*getpfcstate)(struct net_device___80 *);
	void (*setpfcstate)(struct net_device___80 *, u8);
	void (*getbcncfg)(struct net_device___80 *, int, u32 *);
	void (*setbcncfg)(struct net_device___80 *, int, u32);
	void (*getbcnrp)(struct net_device___80 *, int, u8 *);
	void (*setbcnrp)(struct net_device___80 *, int, u8);
	u8 (*setapp)(struct net_device___80 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___80 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___80 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___80 *, int, u8);
	u8 (*getdcbx)(struct net_device___80 *);
	u8 (*setdcbx)(struct net_device___80 *, u8);
	int (*peer_getappinfo)(struct net_device___80 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___80 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___80 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___80 *, struct cee_pfc *);
};

struct cgroupfs_root___185;

struct cgroup___185 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___185 *parent;
	struct dentry___290 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___185 *subsys[11];
	struct cgroupfs_root___185 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___292 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___185 {
	struct super_block___290 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___185 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___121 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___290 *, struct file___290 *);
	ssize_t (*read)(struct cgroup___185 *, struct cftype___121 *, struct file___290 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___185 *, struct cftype___121 *);
	s64 (*read_s64)(struct cgroup___185 *, struct cftype___121 *);
	int (*read_map)(struct cgroup___185 *, struct cftype___121 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___185 *, struct cftype___121 *, struct seq_file___215 *);
	ssize_t (*write)(struct cgroup___185 *, struct cftype___121 *, struct file___290 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___185 *, struct cftype___121 *, u64);
	int (*write_s64)(struct cgroup___185 *, struct cftype___121 *, s64);
	int (*write_string)(struct cgroup___185 *, struct cftype___121 *, const char *);
	int (*trigger)(struct cgroup___185 *, unsigned int);
	int (*release)(struct inode___290 *, struct file___290 *);
	int (*register_event)(struct cgroup___185 *, struct cftype___121 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___185 *, struct cftype___121 *, struct eventfd_ctx *);
};

struct cftype_set___117 {
	struct list_head node;
	struct cftype___121 *cfts;
};

struct task_and_cgroup___117 {
	struct task_struct___291 *task;
	struct cgroup___185 *cgrp;
	struct css_set___185 *cg;
};

struct cgroup_taskset___117 {
	struct task_and_cgroup___117 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___185 *cur_cgrp;
};

struct cgroup_subsys___117 {
	struct cgroup_subsys_state___185 * (*css_alloc)(struct cgroup___185 *);
	int (*css_online)(struct cgroup___185 *);
	void (*css_offline)(struct cgroup___185 *);
	void (*css_free)(struct cgroup___185 *);
	int (*can_attach)(struct cgroup___185 *, struct cgroup_taskset___117 *);
	void (*cancel_attach)(struct cgroup___185 *, struct cgroup_taskset___117 *);
	void (*attach)(struct cgroup___185 *, struct cgroup_taskset___117 *);
	void (*fork)(struct task_struct___291 *);
	void (*exit)(struct cgroup___185 *, struct cgroup___185 *, struct task_struct___291 *);
	void (*bind)(struct cgroup___185 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___185 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___121 *base_cftypes;
	struct cftype_set___117 base_cftset;
	struct module *module;
};

struct scm_fp_list___6 {
	short int count;
	short int max;
	struct file___290 *fp[253];
};

struct netlink_callback___82 {
	struct sk_buff___82 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___82 *, struct netlink_callback___82 *);
	int (*done)(struct netlink_callback___82 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___80 {
	int (*create)(struct sk_buff___82 *, struct net_device___80 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___82 *, unsigned char *);
	int (*rebuild)(struct sk_buff___82 *);
	int (*cache)(const struct neighbour___70 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___80 *, const unsigned char *);
};

struct napi_struct___80 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___80 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___80 *dev;
	struct sk_buff___82 *gro_list;
	struct sk_buff___82 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___80 {
	struct net_device___80 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___72 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___80 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___72 kobj;
	struct net_device___80 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___80 {
	int (*ndo_init)(struct net_device___80 *);
	void (*ndo_uninit)(struct net_device___80 *);
	int (*ndo_open)(struct net_device___80 *);
	int (*ndo_stop)(struct net_device___80 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___82 *, struct net_device___80 *);
	u16 (*ndo_select_queue)(struct net_device___80 *, struct sk_buff___82 *);
	void (*ndo_change_rx_flags)(struct net_device___80 *, int);
	void (*ndo_set_rx_mode)(struct net_device___80 *);
	int (*ndo_set_mac_address)(struct net_device___80 *, void *);
	int (*ndo_validate_addr)(struct net_device___80 *);
	int (*ndo_do_ioctl)(struct net_device___80 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___80 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___80 *, int);
	int (*ndo_neigh_setup)(struct net_device___80 *, struct neigh_parms___70 *);
	void (*ndo_tx_timeout)(struct net_device___80 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___80 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___80 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___80 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___80 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___80 *);
	int (*ndo_netpoll_setup)(struct net_device___80 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___80 *);
	int (*ndo_busy_poll)(struct napi_struct___80 *);
	int (*ndo_set_vf_mac)(struct net_device___80 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___80 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___80 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___80 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___80 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___80 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___80 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___80 *, int, struct sk_buff___82 *);
	int (*ndo_setup_tc)(struct net_device___80 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___80 *);
	int (*ndo_fcoe_disable)(struct net_device___80 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___80 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___80 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___80 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___80 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___80 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___80 *, const struct sk_buff___82 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___80 *, struct net_device___80 *);
	int (*ndo_del_slave)(struct net_device___80 *, struct net_device___80 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___70 *);
	void (*ndo_neigh_destroy)(struct neighbour___70 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___82 *, struct netlink_callback___82 *, struct net_device___80 *, int);
	int (*ndo_bridge_setlink)(struct net_device___80 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___82 *, u32, u32, struct net_device___80 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___80 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___80 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___80 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___80 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___80 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___80 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___82 *, struct net_device___80 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___80 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___80 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___80 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___70 {
	struct net___94 *net;
	struct net_device___80 *dev;
	struct neigh_parms___70 *next;
	int (*neigh_setup)(struct neighbour___70 *);
	void (*neigh_cleanup)(struct neighbour___70 *);
	struct neigh_table___70 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___71 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___80 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___94 *, struct net_device___80 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___80 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___80 *, struct list_head *);
	size_t (*get_size)(const struct net_device___80 *);
	int (*fill_info)(struct sk_buff___82 *, const struct net_device___80 *);
	size_t (*get_xstats_size)(const struct net_device___80 *);
	int (*fill_xstats)(struct sk_buff___82 *, const struct net_device___80 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___94 * (*get_link_net)(const struct net_device___80 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___80 *, struct net_device___80 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___80 *, const struct net_device___80 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___82 *, const struct net_device___80 *, const struct net_device___80 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___70 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___82 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___70;

struct neigh_hash_table___70;

struct neigh_table___70 {
	struct neigh_table___70 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___80 *, __u32 *);
	int (*constructor)(struct neighbour___70 *);
	int (*pconstructor)(struct pneigh_entry___70 *);
	void (*pdestructor)(struct pneigh_entry___70 *);
	void (*proxy_redo)(struct sk_buff___82 *);
	char *id;
	struct neigh_parms___70 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___81 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___70 *nht;
	struct pneigh_entry___70 **phash_buckets;
};

struct neigh_ops___70 {
	int family;
	void (*solicit)(struct neighbour___70 *, struct sk_buff___82 *);
	void (*error_report)(struct neighbour___70 *, struct sk_buff___82 *);
	int (*output)(struct neighbour___70 *, struct sk_buff___82 *);
	int (*connected_output)(struct neighbour___70 *, struct sk_buff___82 *);
};

struct pneigh_entry___70 {
	struct pneigh_entry___70 *next;
	struct net___94 *net;
	struct net_device___80 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___70 {
	struct neighbour___70 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___69 {
	void (*close)(struct sock___69 *, long int);
	int (*connect)(struct sock___69 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___69 *, int);
	struct sock___69 * (*accept)(struct sock___69 *, int, int *);
	int (*ioctl)(struct sock___69 *, int, long unsigned int);
	int (*init)(struct sock___69 *);
	void (*destroy)(struct sock___69 *);
	void (*shutdown)(struct sock___69 *, int);
	int (*setsockopt)(struct sock___69 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___69 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___69 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___69 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___69 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___77 *, struct sock___69 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___77 *, struct sock___69 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___69 *, struct page___289 *, int, size_t, int);
	int (*bind)(struct sock___69 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___69 *, struct sk_buff___82 *);
	void (*release_cb)(struct sock___69 *);
	void (*mtu_reduced)(struct sock___69 *);
	void (*hash)(struct sock___69 *);
	void (*unhash)(struct sock___69 *);
	void (*rehash)(struct sock___69 *);
	int (*get_port)(struct sock___69 *, short unsigned int);
	void (*clear_sk)(struct sock___69 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___69 *);
	void (*enter_memory_pressure)(struct sock___69 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___273 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___18 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___117 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___69 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___69 {
	void (*enter_memory_pressure)(struct sock___69 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct socket_alloc___6 {
	struct socket___70 socket;
	struct inode___290 vfs_inode;
};

struct unix_skb_parms___2 {
	struct pid___97 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list___6 *fp;
	u32 secid;
	u32 consumed;
};

struct unix_sock___3 {
	struct sock___69 sk;
	struct unix_address *addr;
	struct path___290 path;
	struct mutex___292 readlock;
	struct sock___69 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	unsigned char recursion_level;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___69 peer_wq;
};

struct page___290;

typedef struct page___290 *pgtable_t___290;

struct address_space___291;

struct kmem_cache___274;

struct page___290 {
	long unsigned int flags;
	struct address_space___291 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___290 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___290 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___274 *slab_cache;
		struct page___290 *first_page;
	};
	long: 64;
};

struct task_struct___292;

struct pv_cpu_ops___292 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___292 *);
	void (*end_context_switch)(struct task_struct___292 *);
};

struct mutex___293 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___292 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___285 {
	struct page___290 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___299;

struct nsproxy___171;

struct signal_struct___292;

struct css_set___186;

struct task_struct___292 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___292 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___299 *mm;
	struct mm_struct___299 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___292 *real_parent;
	struct task_struct___292 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___292 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___292 = 0,
		VTIME_USER___292 = 1,
		VTIME_SYS___292 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___171 *nsproxy;
	struct signal_struct___292 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___186 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___293 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___285 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___299 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___299 *, struct mm_struct___299 *);
	void (*dup_mmap)(struct mm_struct___299 *, struct mm_struct___299 *);
	void (*exit_mmap)(struct mm_struct___299 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___299 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___299 *);
	void (*pgd_free)(struct mm_struct___299 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___299 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___299 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___299 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___299 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___299 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___299 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___299 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___299 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___299 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___299 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___299 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___293 lock;
	void *vdso;
} mm_context_t___293;

struct xol_area___290;

struct uprobes_state___290 {
	struct xol_area___290 *xol_area;
};

struct vm_area_struct___299;

struct file___291;

struct core_state___292;

struct mm_struct___299 {
	struct vm_area_struct___299 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___299 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___299 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___293 context;
	long unsigned int flags;
	struct core_state___292 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___292 *owner;
	struct file___291 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___290 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___73;

struct kobj_type___73;

struct kobject___73 {
	const char *name;
	struct list_head entry;
	struct kobject___73 *parent;
	struct kset___73 *kset;
	struct kobj_type___73 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___181;

struct module_kobject___181 {
	struct kobject___73 kobj;
	struct module___181 *mod;
	struct kobject___73 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___181;

struct module___181 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___181 mkobj;
	struct module_attribute___181 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___73 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___292 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___292;

struct lruvec___292 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___292 *zone;
};

struct pglist_data___292;

struct zone___292 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___292 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___292 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___292 {
	struct zone___292 *zone;
	int zone_idx;
};

struct zonelist___292 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___292 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___292 {
	struct zone___292 node_zones[4];
	struct zonelist___292 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___292 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___215;

struct x86_io_apic_ops___215 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___215 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___215;

struct irq_data___215 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___215 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___289;

struct dev_pm_ops___289 {
	int (*prepare)(struct device___289 *);
	void (*complete)(struct device___289 *);
	int (*suspend)(struct device___289 *);
	int (*resume)(struct device___289 *);
	int (*freeze)(struct device___289 *);
	int (*thaw)(struct device___289 *);
	int (*poweroff)(struct device___289 *);
	int (*restore)(struct device___289 *);
	int (*suspend_late)(struct device___289 *);
	int (*resume_early)(struct device___289 *);
	int (*freeze_late)(struct device___289 *);
	int (*thaw_early)(struct device___289 *);
	int (*poweroff_late)(struct device___289 *);
	int (*restore_early)(struct device___289 *);
	int (*suspend_noirq)(struct device___289 *);
	int (*resume_noirq)(struct device___289 *);
	int (*freeze_noirq)(struct device___289 *);
	int (*thaw_noirq)(struct device___289 *);
	int (*poweroff_noirq)(struct device___289 *);
	int (*restore_noirq)(struct device___289 *);
	int (*runtime_suspend)(struct device___289 *);
	int (*runtime_resume)(struct device___289 *);
	int (*runtime_idle)(struct device___289 *);
};

struct dev_pm_qos___92;

struct dev_pm_info___92 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___92 *qos;
};

struct dma_map_ops___154;

struct dev_archdata___154 {
	struct dma_map_ops___154 *dma_ops;
	void *iommu;
};

struct device_type___289;

struct bus_type___289;

struct device_driver___289;

struct dev_pm_domain___289;

struct class___289;

struct attribute_group___251;

struct device_rh___289;

struct device___289 {
	struct device___289 *parent;
	struct device_private *p;
	struct kobject___73 kobj;
	const char *init_name;
	const struct device_type___289 *type;
	struct mutex___293 mutex;
	struct bus_type___289 *bus;
	struct device_driver___289 *driver;
	void *platform_data;
	struct dev_pm_info___92 power;
	struct dev_pm_domain___289 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___154 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___289 *class;
	const struct attribute_group___251 **groups;
	void (*release)(struct device___289 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___289 *device_rh;
};

struct dev_pm_qos_request___93;

struct dev_pm_qos___92 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___93 *latency_req;
	struct dev_pm_qos_request___93 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___93 *latency_tolerance_req;
};

struct dev_pm_info_rh___289 {
	void (*set_latency_tolerance)(struct device___289 *, s32);
};

struct dev_pm_domain___289 {
	struct dev_pm_ops___289 ops;
};

struct smp_ops___292 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___292 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___96;

struct ctl_node___96 {
	struct rb_node node;
	struct ctl_table_header___96 *header;
};

struct ctl_table_root___96;

struct ctl_table_set___96;

struct ctl_dir___96;

struct ctl_table_header___96 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___96 *root;
	struct ctl_table_set___96 *set;
	struct ctl_dir___96 *parent;
	struct ctl_node___96 *node;
};

struct ctl_dir___96 {
	struct ctl_table_header___96 header;
	struct rb_root root;
};

struct ctl_table_set___96 {
	int (*is_seen)(struct ctl_table_set___96 *);
	struct ctl_dir___96 dir;
};

struct ctl_table_root___96 {
	struct ctl_table_set___96 default_set;
	struct ctl_table_set___96 * (*lookup)(struct ctl_table_root___96 *, struct nsproxy___171 *);
	int (*permissions)(struct ctl_table_header___96 *, struct ctl_table *);
};

struct net___95;

struct nsproxy___171 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___95 *net_ns;
};

struct sock___70;

struct kobj_ns_type_operations___70 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___70 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___70;

struct sock_common___70 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___70 *skc_prot;
	struct net___95 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___83;

struct sk_buff_head___82 {
	struct sk_buff___83 *next;
	struct sk_buff___83 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___71;

struct socket_wq___70;

struct dst_entry___71;

struct socket___71;

struct cg_proto___70;

struct sock___70 {
	struct sock_common___70 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___82 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___83 *head;
		struct sk_buff___83 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___71 *sk_filter;
	struct socket_wq___70 *sk_wq;
	struct sk_buff_head___82 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___71 *sk_rx_dst;
	struct dst_entry___71 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___82 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___82 sk_error_queue;
	struct proto___70 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___71 *sk_socket;
	void *sk_user_data;
	struct page_frag___285 sk_frag;
	struct sk_buff___83 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___70 *sk_cgrp;
	void (*sk_state_change)(struct sock___70 *);
	void (*sk_data_ready)(struct sock___70 *, int);
	void (*sk_write_space)(struct sock___70 *);
	void (*sk_error_report)(struct sock___70 *);
	int (*sk_backlog_rcv)(struct sock___70 *, struct sk_buff___83 *);
	void (*sk_destruct)(struct sock___70 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___253;

struct attribute_group___251 {
	const char *name;
	umode_t (*is_visible)(struct kobject___73 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___253 **bin_attrs;
};

struct bin_attribute___253 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___291 *, struct kobject___73 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___291 *, struct kobject___73 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	int (*mmap)(struct file___291 *, struct kobject___73 *, struct bin_attribute___253 *, struct vm_area_struct___299 *);
};

struct dentry___291;

struct path___291 {
	struct vfsmount *mnt;
	struct dentry___291 *dentry;
};

struct inode___291;

struct file_operations___291;

struct file___291 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___291 f_path;
	struct inode___291 *f_inode;
	const struct file_operations___291 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___291 *f_mapping;
	struct mutex___293 f_pos_lock;
};

struct vm_operations_struct___265;

struct vm_area_struct___299 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___299 *vm_next;
	struct vm_area_struct___299 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___299 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___265 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___291 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___73 {
	ssize_t (*show)(struct kobject___73 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___73 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___73 *, const struct attribute *);
};

struct kset_uevent_ops___73;

struct kset___73 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___73 kobj;
	const struct kset_uevent_ops___73 *uevent_ops;
};

struct kobj_type___73 {
	void (*release)(struct kobject___73 *);
	const struct sysfs_ops___73 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___70 * (*child_ns_type)(struct kobject___73 *);
	const void * (*namespace)(struct kobject___73 *);
};

struct kset_uevent_ops___73 {
	int (* const filter)(struct kset___73 *, struct kobject___73 *);
	const char * (* const name)(struct kset___73 *, struct kobject___73 *);
	int (* const uevent)(struct kset___73 *, struct kobject___73 *, struct kobj_uevent_env *);
};

struct module_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___181 *, struct module_kobject___181 *, char *);
	ssize_t (*store)(struct module_attribute___181 *, struct module_kobject___181 *, const char *, size_t);
	void (*setup)(struct module___181 *, const char *);
	int (*test)(struct module___181 *);
	void (*free)(struct module___181 *);
};

struct xol_area___290 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___290 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___273;

struct memcg_cache_params___274;

struct kmem_cache___274 {
	struct kmem_cache_cpu___273 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___73 kobj;
	struct memcg_cache_params___274 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___291;

struct address_space___291 {
	struct inode___291 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___293 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___291 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___261;

struct vm_operations_struct___265 {
	void (*open)(struct vm_area_struct___299 *);
	void (*close)(struct vm_area_struct___299 *);
	int (*fault)(struct vm_area_struct___299 *, struct vm_fault___261 *);
	int (*page_mkwrite)(struct vm_area_struct___299 *, struct vm_fault___261 *);
	int (*access)(struct vm_area_struct___299 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___299 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___299 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___299 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___299 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___292 {
	struct task_struct___292 *task;
	struct core_thread___292 *next;
};

struct core_state___292 {
	atomic_t nr_threads;
	struct core_thread___292 dumper;
	struct completion startup;
};

struct fasync_struct___291;

struct socket_wq___70 {
	wait_queue_head_t wait;
	struct fasync_struct___291 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___291 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___291 *fa_next;
	struct file___291 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___70;

struct socket___71 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___70 *wq;
	struct file___291 *file;
	struct sock___70 *sk;
	const struct proto_ops___70 *ops;
};

struct poll_table_struct___177;

struct kiocb___78;

struct proto_ops___70 {
	int family;
	struct module___181 *owner;
	int (*release)(struct socket___71 *);
	int (*bind)(struct socket___71 *, struct sockaddr *, int);
	int (*connect)(struct socket___71 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___71 *, struct socket___71 *);
	int (*accept)(struct socket___71 *, struct socket___71 *, int);
	int (*getname)(struct socket___71 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___291 *, struct socket___71 *, struct poll_table_struct___177 *);
	int (*ioctl)(struct socket___71 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___71 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___71 *, int);
	int (*shutdown)(struct socket___71 *, int);
	int (*setsockopt)(struct socket___71 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___71 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___71 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___71 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___78 *, struct socket___71 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___78 *, struct socket___71 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___291 *, struct socket___71 *, struct vm_area_struct___299 *);
	ssize_t (*sendpage)(struct socket___71 *, struct page___290 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___71 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___70 *, int);
		struct {
			void (*set_peek_off)(struct sock___70 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___179)(struct file___291 *, wait_queue_head_t *, struct poll_table_struct___177 *);

struct poll_table_struct___177 {
	poll_queue_proc___179 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___78(struct kiocb___78 *, struct io_event *);

struct kiocb___78 {
	atomic_t ki_users;
	struct file___291 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___78 *ki_cancel;
	void (*ki_dtor)(struct kiocb___78 *);
	union {
		void *user;
		struct task_struct___292 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct net_proto_family___6 {
	int family;
	int (*create)(struct net___95 *, struct socket___71 *, int, int);
	struct module___181 *owner;
};

struct netns_core___93 {
	struct ctl_table_header___96 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___94 {
	struct mutex___293 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___93 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___96 *ctl;
};

struct netns_ipv4___93 {
	struct ctl_table_header___96 *forw_hdr;
	struct ctl_table_header___96 *frags_hdr;
	struct ctl_table_header___96 *ipv4_hdr;
	struct ctl_table_header___96 *route_hdr;
	struct ctl_table_header___96 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___70 *fibnl;
	struct sock___70 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___93 {
	struct ctl_table_header___96 *hdr;
	struct ctl_table_header___96 *route_hdr;
	struct ctl_table_header___96 *icmp_hdr;
	struct ctl_table_header___96 *frags_hdr;
	struct ctl_table_header___96 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___81;

struct neighbour___71;

struct dst_ops___95 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___95 *);
	struct dst_entry___71 * (*check)(struct dst_entry___71 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___71 *);
	unsigned int (*mtu)(const struct dst_entry___71 *);
	u32 * (*cow_metrics)(struct dst_entry___71 *, long unsigned int);
	void (*destroy)(struct dst_entry___71 *);
	void (*ifdown)(struct dst_entry___71 *, struct net_device___81 *, int);
	struct dst_entry___71 * (*negative_advice)(struct dst_entry___71 *);
	void (*link_failure)(struct sk_buff___83 *);
	void (*update_pmtu)(struct dst_entry___71 *, struct sock___70 *, struct sk_buff___83 *, u32);
	void (*redirect)(struct dst_entry___71 *, struct sock___70 *, struct sk_buff___83 *);
	int (*local_out)(struct sk_buff___83 *);
	struct neighbour___71 * (*neigh_lookup)(const struct dst_entry___71 *, struct sk_buff___83 *, const void *);
	struct kmem_cache___274 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___19;

struct fib6_table___19;

struct netns_ipv6___95 {
	struct netns_sysctl_ipv6___93 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___19 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___19 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___95 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___19 *ip6_prohibit_entry;
	struct rt6_info___19 *ip6_blk_hole_entry;
	struct fib6_table___19 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___70 **icmp_sk;
	struct sock___70 *ndisc_sk;
	struct sock___70 *tcp_sk;
	struct sock___70 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___93 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___96 *sysctl_header;
	struct sock___70 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___70 {
	struct sock___70 *v4_ctl_sk;
	struct sock___70 *v6_ctl_sk;
};

struct netns_nf___93 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___96 *nf_log_dir_header;
};

struct nf_proto_net___93 {
	struct ctl_table_header___96 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___93 {
	struct nf_proto_net___93 pn;
	unsigned int timeout;
};

struct nf_tcp_net___93 {
	struct nf_proto_net___93 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___93 {
	struct nf_proto_net___93 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___93 {
	struct nf_proto_net___93 pn;
	unsigned int timeout;
};

struct nf_ip_net___93 {
	struct nf_generic_net___93 generic;
	struct nf_tcp_net___93 tcp;
	struct nf_udp_net___93 udp;
	struct nf_icmp_net___93 icmp;
	struct nf_icmp_net___93 icmpv6;
};

struct netns_ct___94 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___96 *sysctl_header;
	struct ctl_table_header___96 *acct_sysctl_header;
	struct ctl_table_header___96 *tstamp_sysctl_header;
	struct ctl_table_header___96 *event_sysctl_header;
	struct ctl_table_header___96 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___274 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___93 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___93 {
	struct netns_sysctl_ipv6___93 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___95 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___70 *nlsk;
	struct sock___70 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___96 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___95 xfrm4_dst_ops;
	struct dst_ops___95 xfrm6_dst_ops;
};

struct net___95 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___96 sysctls;
	struct sock___70 *rtnl;
	struct sock___70 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___81 *loopback_dev;
	struct netns_core___93 core;
	struct netns_mib mib;
	struct netns_packet___94 packet;
	struct netns_unix___93 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___93 ipv4;
	struct netns_ipv6___95 ipv6;
	struct netns_sctp___93 sctp;
	struct netns_dccp___70 dccp;
	struct netns_nf___93 nf;
	struct netns_xt xt;
	struct netns_ct___94 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___93 nf_frag;
	struct sock___70 *nfnl;
	struct sock___70 *nfnl_stash;
	struct sk_buff_head___82 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___95 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___70 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___70 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___293 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___293 flow_flush_sem;
	long: 64;
	long: 64;
};

struct vm_fault___261 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___290 *page;
};

struct seq_file___216;

struct irq_chip___215 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___215 *);
	void (*irq_shutdown)(struct irq_data___215 *);
	void (*irq_enable)(struct irq_data___215 *);
	void (*irq_disable)(struct irq_data___215 *);
	void (*irq_ack)(struct irq_data___215 *);
	void (*irq_mask)(struct irq_data___215 *);
	void (*irq_mask_ack)(struct irq_data___215 *);
	void (*irq_unmask)(struct irq_data___215 *);
	void (*irq_eoi)(struct irq_data___215 *);
	int (*irq_set_affinity)(struct irq_data___215 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___215 *);
	int (*irq_set_type)(struct irq_data___215 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___215 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___215 *);
	void (*irq_bus_sync_unlock)(struct irq_data___215 *);
	void (*irq_cpu_online)(struct irq_data___215 *);
	void (*irq_cpu_offline)(struct irq_data___215 *);
	void (*irq_suspend)(struct irq_data___215 *);
	void (*irq_resume)(struct irq_data___215 *);
	void (*irq_pm_shutdown)(struct irq_data___215 *);
	void (*irq_print_chip)(struct irq_data___215 *, struct seq_file___216 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___215 *, void *);
	long unsigned int flags;
};

struct seq_operations___216;

struct seq_file___216 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___293 lock;
	const struct seq_operations___216 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct dentry_operations___291;

struct super_block___291;

struct dentry___291 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___291 *d_parent;
	struct qstr d_name;
	struct inode___291 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___291 *d_op;
	struct super_block___291 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___291;

struct file_lock___291;

struct dquot___291;

struct block_device___291;

struct inode___291 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___291 *i_op;
	struct super_block___291 *i_sb;
	struct address_space___291 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___293 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___291 *i_fop;
	struct file_lock___291 *i_flock;
	struct address_space___291 i_data;
	struct dquot___291 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___291 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___291 {
	int (*d_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_hash)(const struct dentry___291 *, struct qstr *);
	int (*d_compare)(const struct dentry___291 *, const struct dentry___291 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___291 *);
	void (*d_release)(struct dentry___291 *);
	void (*d_prune)(struct dentry___291 *);
	void (*d_iput)(struct dentry___291 *, struct inode___291 *);
	char * (*d_dname)(struct dentry___291 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___291 *);
	int (*d_manage)(struct dentry___291 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___291;

struct mem_dqinfo___291 {
	struct quota_format_type___291 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___291;

struct quota_info___291 {
	unsigned int flags;
	struct mutex___293 dqio_mutex;
	struct mutex___293 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___291 *files[2];
	struct mem_dqinfo___291 info[2];
	const struct quota_format_ops___291 *ops[2];
};

struct file_system_type___291;

struct super_operations___291;

struct dquot_operations___291;

struct quotactl_ops___291;

struct xattr_handler___187;

struct super_block___291 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___291 *s_type;
	const struct super_operations___291 *s_op;
	const struct dquot_operations___291 *dq_op;
	const struct quotactl_ops___291 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___291 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___187 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___291 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___291 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___293 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___291 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___291 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___291 *bd_inode;
	struct super_block___291 *bd_super;
	struct mutex___293 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___291 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___293 bd_fsfreeze_mutex;
};

struct cgroup___186;

struct cgroup_subsys_state___186 {
	struct cgroup___186 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___291 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___291 *ia_file;
};

struct dquot___291 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___293 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___291 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___291 {
	int qf_fmt_id;
	const struct quota_format_ops___291 *qf_ops;
	struct module___181 *qf_owner;
	struct quota_format_type___291 *qf_next;
};

struct quota_format_ops___291 {
	int (*check_quota_file)(struct super_block___291 *, int);
	int (*read_file_info)(struct super_block___291 *, int);
	int (*write_file_info)(struct super_block___291 *, int);
	int (*free_file_info)(struct super_block___291 *, int);
	int (*read_dqblk)(struct dquot___291 *);
	int (*commit_dqblk)(struct dquot___291 *);
	int (*release_dqblk)(struct dquot___291 *);
};

struct dquot_operations___291 {
	int (*write_dquot)(struct dquot___291 *);
	struct dquot___291 * (*alloc_dquot)(struct super_block___291 *, int);
	void (*destroy_dquot)(struct dquot___291 *);
	int (*acquire_dquot)(struct dquot___291 *);
	int (*release_dquot)(struct dquot___291 *);
	int (*mark_dirty)(struct dquot___291 *);
	int (*write_info)(struct super_block___291 *, int);
	qsize_t * (*get_reserved_space)(struct inode___291 *);
};

struct quotactl_ops___291 {
	int (*quota_on)(struct super_block___291 *, int, int, struct path___291 *);
	int (*quota_on_meta)(struct super_block___291 *, int, int);
	int (*quota_off)(struct super_block___291 *, int);
	int (*quota_sync)(struct super_block___291 *, int);
	int (*get_info)(struct super_block___291 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___291 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___291 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___291 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___291 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___291 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___291 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___291 *, unsigned int);
};

struct address_space_operations___291 {
	int (*writepage)(struct page___290 *, struct writeback_control *);
	int (*readpage)(struct file___291 *, struct page___290 *);
	int (*writepages)(struct address_space___291 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___290 *);
	int (*readpages)(struct file___291 *, struct address_space___291 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___291 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___290 **, void **);
	int (*write_end)(struct file___291 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___290 *, void *);
	sector_t (*bmap)(struct address_space___291 *, sector_t);
	void (*invalidatepage)(struct page___290 *, long unsigned int);
	int (*releasepage)(struct page___290 *, gfp_t);
	void (*freepage)(struct page___290 *);
	ssize_t (*direct_IO)(int, struct kiocb___78 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___291 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___291 *, struct page___290 *, struct page___290 *, enum migrate_mode);
	int (*launder_page)(struct page___290 *);
	int (*is_partially_uptodate)(struct page___290 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___290 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___291 *, struct page___290 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___291 *, sector_t *);
	void (*swap_deactivate)(struct file___291 *);
	void (*invalidatepage_range)(struct page___290 *, unsigned int, unsigned int);
};

struct inode_operations___291 {
	struct dentry___291 * (*lookup)(struct inode___291 *, struct dentry___291 *, unsigned int);
	void * (*follow_link)(struct dentry___291 *, struct nameidata *);
	int (*permission)(struct inode___291 *, int);
	struct posix_acl * (*get_acl)(struct inode___291 *, int);
	int (*readlink)(struct dentry___291 *, char *, int);
	void (*put_link)(struct dentry___291 *, struct nameidata *, void *);
	int (*create)(struct inode___291 *, struct dentry___291 *, umode_t, bool);
	int (*link)(struct dentry___291 *, struct inode___291 *, struct dentry___291 *);
	int (*unlink)(struct inode___291 *, struct dentry___291 *);
	int (*symlink)(struct inode___291 *, struct dentry___291 *, const char *);
	int (*mkdir)(struct inode___291 *, struct dentry___291 *, umode_t);
	int (*rmdir)(struct inode___291 *, struct dentry___291 *);
	int (*mknod)(struct inode___291 *, struct dentry___291 *, umode_t, dev_t);
	int (*rename)(struct inode___291 *, struct dentry___291 *, struct inode___291 *, struct dentry___291 *);
	int (*setattr)(struct dentry___291 *, struct iattr___291 *);
	int (*getattr)(struct vfsmount *, struct dentry___291 *, struct kstat *);
	int (*setxattr)(struct dentry___291 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___291 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___291 *, char *, size_t);
	int (*removexattr)(struct dentry___291 *, const char *);
	int (*fiemap)(struct inode___291 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___291 *, struct timespec *, int);
	int (*atomic_open)(struct inode___291 *, struct dentry___291 *, struct file___291 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_operations___291 {
	struct module___181 *owner;
	loff_t (*llseek)(struct file___291 *, loff_t, int);
	ssize_t (*read)(struct file___291 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___291 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___78 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___78 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___291 *, void *, filldir_t);
	unsigned int (*poll)(struct file___291 *, struct poll_table_struct___177 *);
	long int (*unlocked_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___291 *, struct vm_area_struct___299 *);
	int (*open)(struct inode___291 *, struct file___291 *);
	int (*flush)(struct file___291 *, fl_owner_t);
	int (*release)(struct inode___291 *, struct file___291 *);
	int (*fsync)(struct file___291 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___78 *, int);
	int (*fasync)(int, struct file___291 *, int);
	int (*lock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*sendpage)(struct file___291 *, struct page___290 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___291 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___291 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___291 *, long int, struct file_lock___291 **, void **);
		struct {
			int (*setlease)(struct file___291 *, long int, struct file_lock___291 **);
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long int (*fallocate)(struct file___291 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___216 *, struct file___291 *);
};

struct file_lock_operations___291;

struct lock_manager_operations___291;

struct file_lock___291 {
	struct file_lock___291 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___291 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___291 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___291 *fl_ops;
	const struct lock_manager_operations___291 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___291 {
	void (*fl_copy_lock)(struct file_lock___291 *, struct file_lock___291 *);
	void (*fl_release_private)(struct file_lock___291 *);
};

struct lock_manager_operations___291 {
	int (*lm_compare_owner)(struct file_lock___291 *, struct file_lock___291 *);
	long unsigned int (*lm_owner_key)(struct file_lock___291 *);
	void (*lm_notify)(struct file_lock___291 *);
	int (*lm_grant)(struct file_lock___291 *, struct file_lock___291 *, int);
	void (*lm_break)(struct file_lock___291 *);
	int (*lm_change)(struct file_lock___291 **, int);
};

struct file_system_type___291 {
	const char *name;
	int fs_flags;
	struct dentry___291 * (*mount)(struct file_system_type___291 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___291 *);
	struct module___181 *owner;
	struct file_system_type___291 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___291 {
	struct inode___291 * (*alloc_inode)(struct super_block___291 *);
	void (*destroy_inode)(struct inode___291 *);
	void (*dirty_inode)(struct inode___291 *, int);
	int (*write_inode)(struct inode___291 *, struct writeback_control *);
	int (*drop_inode)(struct inode___291 *);
	void (*evict_inode)(struct inode___291 *);
	void (*put_super)(struct super_block___291 *);
	int (*sync_fs)(struct super_block___291 *, int);
	int (*freeze_fs)(struct super_block___291 *);
	int (*unfreeze_fs)(struct super_block___291 *);
	int (*statfs)(struct dentry___291 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___291 *, int *, char *);
	void (*umount_begin)(struct super_block___291 *);
	int (*show_options)(struct seq_file___216 *, struct dentry___291 *);
	int (*show_devname)(struct seq_file___216 *, struct dentry___291 *);
	int (*show_path)(struct seq_file___216 *, struct dentry___291 *);
	int (*show_stats)(struct seq_file___216 *, struct dentry___291 *);
	ssize_t (*quota_read)(struct super_block___291 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___291 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___291 *);
	int (*bdev_try_to_free_page)(struct super_block___291 *, struct page___290 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___291 *);
	void (*free_cached_objects)(struct super_block___291 *, int);
};

struct xattr_handler___187 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___291 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___291 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___291 *, const char *, const void *, size_t, int, int);
};

struct kmem_cache_cpu___273 {
	void **freelist;
	long unsigned int tid;
	struct page___290 *page;
	struct page___290 *partial;
};

struct memcg_cache_params___274 {
	bool is_root_cache;
	union {
		struct kmem_cache___274 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___274 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___154 {
	void * (*alloc)(struct device___289 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___289 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___289 *, struct vm_area_struct___299 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___289 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___289 *, struct page___290 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___289 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___289 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___289 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___289 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___289 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___289 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___289 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___289 *, dma_addr_t);
	int (*dma_supported)(struct device___289 *, u64);
	int (*set_dma_mask)(struct device___289 *, u64);
	int is_phys;
};

struct bus_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___289 *, char *);
	ssize_t (*store)(struct bus_type___289 *, const char *, size_t);
};

struct device_attribute___289;

struct driver_attribute___289;

struct bus_type___289 {
	const char *name;
	const char *dev_name;
	struct device___289 *dev_root;
	struct bus_attribute___289 *bus_attrs;
	struct device_attribute___289 *dev_attrs;
	struct driver_attribute___289 *drv_attrs;
	const struct attribute_group___251 **bus_groups;
	const struct attribute_group___251 **dev_groups;
	const struct attribute_group___251 **drv_groups;
	int (*match)(struct device___289 *, struct device_driver___289 *);
	int (*uevent)(struct device___289 *, struct kobj_uevent_env *);
	int (*probe)(struct device___289 *);
	int (*remove)(struct device___289 *);
	void (*shutdown)(struct device___289 *);
	int (*online)(struct device___289 *);
	int (*offline)(struct device___289 *);
	int (*suspend)(struct device___289 *, pm_message_t);
	int (*resume)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct device___289 *, struct device_attribute___289 *, char *);
	ssize_t (*store)(struct device___289 *, struct device_attribute___289 *, const char *, size_t);
};

struct driver_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___289 *, char *);
	ssize_t (*store)(struct device_driver___289 *, const char *, size_t);
};

struct device_driver___289 {
	const char *name;
	struct bus_type___289 *bus;
	struct module___181 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___289 *);
	int (*remove)(struct device___289 *);
	void (*shutdown)(struct device___289 *);
	int (*suspend)(struct device___289 *, pm_message_t);
	int (*resume)(struct device___289 *);
	const struct attribute_group___251 **groups;
	const struct dev_pm_ops___289 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___289 {
	const char *name;
	const struct attribute_group___251 **groups;
	int (*uevent)(struct device___289 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___289 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
};

struct class_attribute___289;

struct class___289 {
	const char *name;
	struct module___181 *owner;
	struct class_attribute___289 *class_attrs;
	struct device_attribute___289 *dev_attrs;
	const struct attribute_group___251 **dev_groups;
	struct bin_attribute___253 *dev_bin_attrs;
	struct kobject___73 *dev_kobj;
	int (*dev_uevent)(struct device___289 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___289 *, umode_t *);
	void (*class_release)(struct class___289 *);
	void (*dev_release)(struct device___289 *);
	int (*suspend)(struct device___289 *, pm_message_t);
	int (*resume)(struct device___289 *);
	const struct kobj_ns_type_operations___70 *ns_type;
	const void * (*namespace)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
	struct subsys_private *p;
};

struct class_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct class___289 *, struct class_attribute___289 *, char *);
	ssize_t (*store)(struct class___289 *, struct class_attribute___289 *, const char *, size_t);
	const void * (*namespace)(struct class___289 *, const struct class_attribute___289 *);
};

struct device_rh___289 {
	struct dev_pm_info_rh___289 power;
};

struct dev_pm_qos_request___93 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___289 *dev;
};

struct signal_struct___292 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___292 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___292 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___293 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___186 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___186 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___81 {
	atomic_t use;
	unsigned int mask;
	struct net_device___81 *physindev;
	struct net_device___81 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___81(struct sk_buff___83 **);

struct net_device_ops___81;

struct ethtool_ops___81;

struct header_ops___81;

struct inet6_dev___45;

struct netdev_rx_queue___81;

struct netdev_queue___81;

struct rtnl_link_ops___72;

struct dcbnl_rtnl_ops___81;

struct net_device___81 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___81 *netdev_ops;
	const struct ethtool_ops___81 *ethtool_ops;
	const struct header_ops___81 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___73 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___45 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___81 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___81 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___81 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___81 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___81 = 0,
		NETREG_REGISTERED___81 = 1,
		NETREG_UNREGISTERING___81 = 2,
		NETREG_UNREGISTERED___81 = 3,
		NETREG_RELEASED___81 = 4,
		NETREG_DUMMY___81 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___81 = 0,
		RTNL_LINK_INITIALIZING___81 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___81 *);
	struct netpoll_info *npinfo;
	struct net___95 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___289 dev;
	const struct attribute_group___251 *sysfs_groups[4];
	const struct rtnl_link_ops___72 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___81 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___83 {
	struct sk_buff___83 *next;
	struct sk_buff___83 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___70 *sk;
	struct net_device___81 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___83 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___81 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___81 {
	int (*get_settings)(struct net_device___81 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___81 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___81 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___81 *);
	void (*get_regs)(struct net_device___81 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___81 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___81 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___81 *);
	void (*set_msglevel)(struct net_device___81 *, u32);
	int (*nway_reset)(struct net_device___81 *);
	u32 (*get_link)(struct net_device___81 *);
	int (*get_eeprom_len)(struct net_device___81 *);
	int (*get_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___81 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___81 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___81 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___81 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___81 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___81 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___81 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___81 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___81 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___81 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___81 *);
	void (*complete)(struct net_device___81 *);
	u32 (*get_priv_flags)(struct net_device___81 *);
	int (*set_priv_flags)(struct net_device___81 *, u32);
	int (*get_sset_count)(struct net_device___81 *, int);
	int (*get_rxnfc)(struct net_device___81 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___81 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___81 *, struct ethtool_flash *);
	int (*reset)(struct net_device___81 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___81 *);
	int (*get_rxfh_indir)(struct net_device___81 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___81 *, const u32 *);
	void (*get_channels)(struct net_device___81 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___81 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___81 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___81 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___81 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___81 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___81 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___81 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___81 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___81 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___81 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___81 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___40;

struct dst_entry___71 {
	struct callback_head callback_head;
	struct dst_entry___71 *child;
	struct net_device___81 *dev;
	struct dst_ops___95 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___71 *path;
	struct dst_entry___71 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___83 *);
	union {
		int (*output)(struct sock___70 *, struct sk_buff___83 *);
		struct {
			int (*output)(struct sk_buff___83 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___71 *next;
		struct rtable___40 *rt_next;
		struct rt6_info___19 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___71;

struct neigh_parms___71;

struct neigh_ops___71;

struct neighbour___71 {
	struct neighbour___71 *next;
	struct neigh_table___71 *tbl;
	struct neigh_parms___71 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___82 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___71 *, struct sk_buff___83 *);
	const struct neigh_ops___71 *ops;
	struct callback_head rcu;
	struct net_device___81 *dev;
	u8 primary_key[0];
};

struct fib6_node___19;

struct rt6_info___19 {
	struct dst_entry___71 dst;
	struct fib6_table___19 *rt6i_table;
	struct fib6_node___19 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___45 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___19 {
	struct fib6_node___19 *parent;
	struct fib6_node___19 *left;
	struct fib6_node___19 *right;
	struct rt6_info___19 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___19 *rr_ptr;
};

struct fib6_table___19 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___19 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___96 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___83 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___83 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___95 *, struct dst_entry___71 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___83 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___83 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___216 {
	void * (*start)(struct seq_file___216 *, loff_t *);
	void (*stop)(struct seq_file___216 *, void *);
	void * (*next)(struct seq_file___216 *, void *, loff_t *);
	int (*show)(struct seq_file___216 *, void *);
};

struct pernet_operations___28 {
	struct list_head list;
	int (*init)(struct net___95 *);
	void (*exit)(struct net___95 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___81 {
	int (*ieee_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___81 *);
	u8 (*setstate)(struct net_device___81 *, u8);
	void (*getpermhwaddr)(struct net_device___81 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___81 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___81 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___81 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___81 *, int, u8 *);
	void (*setpfccfg)(struct net_device___81 *, int, u8);
	void (*getpfccfg)(struct net_device___81 *, int, u8 *);
	u8 (*setall)(struct net_device___81 *);
	u8 (*getcap)(struct net_device___81 *, int, u8 *);
	int (*getnumtcs)(struct net_device___81 *, int, u8 *);
	int (*setnumtcs)(struct net_device___81 *, int, u8);
	u8 (*getpfcstate)(struct net_device___81 *);
	void (*setpfcstate)(struct net_device___81 *, u8);
	void (*getbcncfg)(struct net_device___81 *, int, u32 *);
	void (*setbcncfg)(struct net_device___81 *, int, u32);
	void (*getbcnrp)(struct net_device___81 *, int, u8 *);
	void (*setbcnrp)(struct net_device___81 *, int, u8);
	u8 (*setapp)(struct net_device___81 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___81 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___81 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___81 *, int, u8);
	u8 (*getdcbx)(struct net_device___81 *);
	u8 (*setdcbx)(struct net_device___81 *, u8);
	int (*peer_getappinfo)(struct net_device___81 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___81 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___81 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___81 *, struct cee_pfc *);
};

struct cgroupfs_root___186;

struct cgroup___186 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___186 *parent;
	struct dentry___291 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___186 *subsys[11];
	struct cgroupfs_root___186 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___293 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___186 {
	struct super_block___291 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___186 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___122 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___291 *, struct file___291 *);
	ssize_t (*read)(struct cgroup___186 *, struct cftype___122 *, struct file___291 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___186 *, struct cftype___122 *);
	s64 (*read_s64)(struct cgroup___186 *, struct cftype___122 *);
	int (*read_map)(struct cgroup___186 *, struct cftype___122 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___186 *, struct cftype___122 *, struct seq_file___216 *);
	ssize_t (*write)(struct cgroup___186 *, struct cftype___122 *, struct file___291 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___186 *, struct cftype___122 *, u64);
	int (*write_s64)(struct cgroup___186 *, struct cftype___122 *, s64);
	int (*write_string)(struct cgroup___186 *, struct cftype___122 *, const char *);
	int (*trigger)(struct cgroup___186 *, unsigned int);
	int (*release)(struct inode___291 *, struct file___291 *);
	int (*register_event)(struct cgroup___186 *, struct cftype___122 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___186 *, struct cftype___122 *, struct eventfd_ctx *);
};

struct cftype_set___118 {
	struct list_head node;
	struct cftype___122 *cfts;
};

struct task_and_cgroup___118 {
	struct task_struct___292 *task;
	struct cgroup___186 *cgrp;
	struct css_set___186 *cg;
};

struct cgroup_taskset___118 {
	struct task_and_cgroup___118 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___186 *cur_cgrp;
};

struct cgroup_subsys___118 {
	struct cgroup_subsys_state___186 * (*css_alloc)(struct cgroup___186 *);
	int (*css_online)(struct cgroup___186 *);
	void (*css_offline)(struct cgroup___186 *);
	void (*css_free)(struct cgroup___186 *);
	int (*can_attach)(struct cgroup___186 *, struct cgroup_taskset___118 *);
	void (*cancel_attach)(struct cgroup___186 *, struct cgroup_taskset___118 *);
	void (*attach)(struct cgroup___186 *, struct cgroup_taskset___118 *);
	void (*fork)(struct task_struct___292 *);
	void (*exit)(struct cgroup___186 *, struct cgroup___186 *, struct task_struct___292 *);
	void (*bind)(struct cgroup___186 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___186 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___122 *base_cftypes;
	struct cftype_set___118 base_cftset;
	struct module___181 *module;
};

struct request_sock_ops___54;

struct request_sock___55 {
	struct sock_common___70 __req_common;
	struct request_sock___55 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___54 *rsk_ops;
	struct sock___70 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___83 {
	struct sk_buff___83 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___83 *, struct netlink_callback___83 *);
	int (*done)(struct netlink_callback___83 *);
	void *data;
	struct module___181 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___81 {
	int (*create)(struct sk_buff___83 *, struct net_device___81 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___83 *, unsigned char *);
	int (*rebuild)(struct sk_buff___83 *);
	int (*cache)(const struct neighbour___71 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___81 *, const unsigned char *);
};

struct napi_struct___81 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___81 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___81 *dev;
	struct sk_buff___83 *gro_list;
	struct sk_buff___83 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___81 {
	struct net_device___81 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___73 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___81 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___73 kobj;
	struct net_device___81 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___81 {
	int (*ndo_init)(struct net_device___81 *);
	void (*ndo_uninit)(struct net_device___81 *);
	int (*ndo_open)(struct net_device___81 *);
	int (*ndo_stop)(struct net_device___81 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___83 *, struct net_device___81 *);
	u16 (*ndo_select_queue)(struct net_device___81 *, struct sk_buff___83 *);
	void (*ndo_change_rx_flags)(struct net_device___81 *, int);
	void (*ndo_set_rx_mode)(struct net_device___81 *);
	int (*ndo_set_mac_address)(struct net_device___81 *, void *);
	int (*ndo_validate_addr)(struct net_device___81 *);
	int (*ndo_do_ioctl)(struct net_device___81 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___81 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___81 *, int);
	int (*ndo_neigh_setup)(struct net_device___81 *, struct neigh_parms___71 *);
	void (*ndo_tx_timeout)(struct net_device___81 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___81 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___81 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___81 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___81 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___81 *);
	int (*ndo_netpoll_setup)(struct net_device___81 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___81 *);
	int (*ndo_busy_poll)(struct napi_struct___81 *);
	int (*ndo_set_vf_mac)(struct net_device___81 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___81 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___81 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___81 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___81 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___81 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___81 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___81 *, int, struct sk_buff___83 *);
	int (*ndo_setup_tc)(struct net_device___81 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___81 *);
	int (*ndo_fcoe_disable)(struct net_device___81 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___81 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___81 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___81 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___81 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___81 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___81 *, const struct sk_buff___83 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___81 *, struct net_device___81 *);
	int (*ndo_del_slave)(struct net_device___81 *, struct net_device___81 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___71 *);
	void (*ndo_neigh_destroy)(struct neighbour___71 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___83 *, struct netlink_callback___83 *, struct net_device___81 *, int);
	int (*ndo_bridge_setlink)(struct net_device___81 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___83 *, u32, u32, struct net_device___81 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___81 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___81 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___81 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___81 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___81 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___81 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___83 *, struct net_device___81 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___81 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___81 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___81 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___71 {
	struct net___95 *net;
	struct net_device___81 *dev;
	struct neigh_parms___71 *next;
	int (*neigh_setup)(struct neighbour___71 *);
	void (*neigh_cleanup)(struct neighbour___71 *);
	struct neigh_table___71 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___45;

struct ifacaddr6___45;

struct inet6_dev___45 {
	struct net_device___81 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___45 *mc_list;
	struct ifmcaddr6___45 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___45 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___71 *nd_parms;
	struct inet6_dev___45 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___72 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___81 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___95 *, struct net_device___81 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___81 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___81 *, struct list_head *);
	size_t (*get_size)(const struct net_device___81 *);
	int (*fill_info)(struct sk_buff___83 *, const struct net_device___81 *);
	size_t (*get_xstats_size)(const struct net_device___81 *);
	int (*fill_xstats)(struct sk_buff___83 *, const struct net_device___81 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___95 * (*get_link_net)(const struct net_device___81 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___81 *, struct net_device___81 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___81 *, const struct net_device___81 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___83 *, const struct net_device___81 *, const struct net_device___81 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct packet_type___6 {
	__be16 type;
	struct net_device___81 *dev;
	int (*func)(struct sk_buff___83 *, struct net_device___81 *, struct packet_type___6 *, struct net_device___81 *);
	bool (*id_match)(struct packet_type___6 *, struct sock___70 *);
	void *af_packet_priv;
	struct list_head list;
};

struct nf_ipv6_ops___7 {
	int (*chk_addr)(struct net___95 *, const struct in6_addr *, const struct net_device___81 *, int);
};

struct sk_filter___71 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___83 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___71;

struct neigh_hash_table___71;

struct neigh_table___71 {
	struct neigh_table___71 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___81 *, __u32 *);
	int (*constructor)(struct neighbour___71 *);
	int (*pconstructor)(struct pneigh_entry___71 *);
	void (*pdestructor)(struct pneigh_entry___71 *);
	void (*proxy_redo)(struct sk_buff___83 *);
	char *id;
	struct neigh_parms___71 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___82 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___71 *nht;
	struct pneigh_entry___71 **phash_buckets;
};

struct neigh_ops___71 {
	int family;
	void (*solicit)(struct neighbour___71 *, struct sk_buff___83 *);
	void (*error_report)(struct neighbour___71 *, struct sk_buff___83 *);
	int (*output)(struct neighbour___71 *, struct sk_buff___83 *);
	int (*connected_output)(struct neighbour___71 *, struct sk_buff___83 *);
};

struct pneigh_entry___71 {
	struct pneigh_entry___71 *next;
	struct net___95 *net;
	struct net_device___81 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___71 {
	struct neighbour___71 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___40 {
	struct dst_entry___71 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___51;

struct inet_hashinfo___19;

struct proto___70 {
	void (*close)(struct sock___70 *, long int);
	int (*connect)(struct sock___70 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___70 *, int);
	struct sock___70 * (*accept)(struct sock___70 *, int, int *);
	int (*ioctl)(struct sock___70 *, int, long unsigned int);
	int (*init)(struct sock___70 *);
	void (*destroy)(struct sock___70 *);
	void (*shutdown)(struct sock___70 *, int);
	int (*setsockopt)(struct sock___70 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___70 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___70 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___70 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___70 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___78 *, struct sock___70 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___78 *, struct sock___70 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___70 *, struct page___290 *, int, size_t, int);
	int (*bind)(struct sock___70 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___70 *, struct sk_buff___83 *);
	void (*release_cb)(struct sock___70 *);
	void (*mtu_reduced)(struct sock___70 *);
	void (*hash)(struct sock___70 *);
	void (*unhash)(struct sock___70 *);
	void (*rehash)(struct sock___70 *);
	int (*get_port)(struct sock___70 *, short unsigned int);
	void (*clear_sk)(struct sock___70 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___70 *);
	void (*enter_memory_pressure)(struct sock___70 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___274 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___54 *rsk_prot;
	struct timewait_sock_ops___51 *twsk_prot;
	union {
		struct inet_hashinfo___19 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___181 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___118 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___70 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___70 {
	void (*enter_memory_pressure)(struct sock___70 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___19 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___274 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___54 {
	int family;
	int obj_size;
	struct kmem_cache___274 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___70 *, struct request_sock___55 *);
	void (*send_ack)(struct sock___70 *, struct sk_buff___83 *, struct request_sock___55 *);
	void (*send_reset)(struct sock___70 *, struct sk_buff___83 *);
	void (*destructor)(struct request_sock___55 *);
	void (*syn_ack_timeout)(struct sock___70 *, struct request_sock___55 *);
};

struct timewait_sock_ops___51 {
	struct kmem_cache___274 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___70 *, struct sock___70 *, void *);
	void (*twsk_destructor)(struct sock___70 *);
};

struct inet_cork___25 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___71 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___25 {
	struct inet_cork___25 base;
	struct flowi fl;
};

struct ipv6_pinfo___24;

struct inet_sock___25 {
	struct sock___70 sk;
	struct ipv6_pinfo___24 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___25 cork;
};

struct ipv6_fl_socklist___23;

struct ipv6_pinfo___24 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___23 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___83 *pktoptions;
	struct sk_buff___83 *rxpmtu;
	struct inet6_cork cork;
};

struct ipv6_params {
	__s32 disable_ipv6;
	__s32 autoconf;
};

struct ip6_flowlabel___23;

struct ipv6_fl_socklist___23 {
	struct ipv6_fl_socklist___23 *next;
	struct ip6_flowlabel___23 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___45 {
	struct in6_addr mca_addr;
	struct inet6_dev___45 *idev;
	struct ifmcaddr6___45 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___45 {
	struct in6_addr aca_addr;
	struct inet6_dev___45 *aca_idev;
	struct rt6_info___19 *aca_rt;
	struct ifacaddr6___45 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___23 {
	struct ip6_flowlabel___23 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___95 *fl_net;
};

struct inet_protosw___3 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___70 *prot;
	const struct proto_ops___70 *ops;
	unsigned char flags;
};

struct ipv6_stub {
	int (*ipv6_sock_mc_join)(struct sock___70 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___70 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct sock___70 *, struct dst_entry___71 **, struct flowi6 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___81 *, struct neighbour___71 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___71 *nd_tbl;
};

struct seq_net_private___13 {
	struct net___72 *net;
};

struct ac6_iter_state {
	struct seq_net_private___13 p;
	struct net_device___58 *dev;
	struct inet6_dev___24 *idev;
};

struct page___291;

typedef struct page___291 *pgtable_t___291;

struct address_space___292;

struct kmem_cache___275;

struct page___291 {
	long unsigned int flags;
	struct address_space___292 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___291 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___291 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___275 *slab_cache;
		struct page___291 *first_page;
	};
	long: 64;
};

struct task_struct___293;

struct pv_cpu_ops___293 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___293 *);
	void (*end_context_switch)(struct task_struct___293 *);
};

struct mutex___294 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___293 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___286 {
	struct page___291 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___300;

struct nsproxy___172;

struct signal_struct___293;

struct css_set___187;

struct task_struct___293 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___293 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___300 *mm;
	struct mm_struct___300 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___293 *real_parent;
	struct task_struct___293 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___293 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___293 = 0,
		VTIME_USER___293 = 1,
		VTIME_SYS___293 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___172 *nsproxy;
	struct signal_struct___293 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___187 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___294 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___286 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___300 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___300 *, struct mm_struct___300 *);
	void (*dup_mmap)(struct mm_struct___300 *, struct mm_struct___300 *);
	void (*exit_mmap)(struct mm_struct___300 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___300 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___300 *);
	void (*pgd_free)(struct mm_struct___300 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___300 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___300 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___300 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___300 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___300 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___300 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___300 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___300 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___300 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___300 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___300 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___294 lock;
	void *vdso;
} mm_context_t___294;

struct xol_area___291;

struct uprobes_state___291 {
	struct xol_area___291 *xol_area;
};

struct vm_area_struct___300;

struct file___292;

struct core_state___293;

struct mm_struct___300 {
	struct vm_area_struct___300 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___300 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___300 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___294 context;
	long unsigned int flags;
	struct core_state___293 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___293 *owner;
	struct file___292 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___291 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___74;

struct kobj_type___74;

struct kobject___74 {
	const char *name;
	struct list_head entry;
	struct kobject___74 *parent;
	struct kset___74 *kset;
	struct kobj_type___74 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___182;

struct module_kobject___182 {
	struct kobject___74 kobj;
	struct module___182 *mod;
	struct kobject___74 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___182;

struct module___182 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___182 mkobj;
	struct module_attribute___182 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___74 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___293 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct xol_area___291 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___291 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___274;

struct memcg_cache_params___275;

struct kmem_cache___275 {
	struct kmem_cache_cpu___274 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___74 kobj;
	struct memcg_cache_params___275 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___292;

struct address_space_operations___292;

struct address_space___292 {
	struct inode___292 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___294 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___292 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___292;

struct path___292 {
	struct vfsmount *mnt;
	struct dentry___292 *dentry;
};

struct file_operations___292;

struct file___292 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___292 f_path;
	struct inode___292 *f_inode;
	const struct file_operations___292 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___292 *f_mapping;
	struct mutex___294 f_pos_lock;
};

struct vm_operations_struct___266;

struct vm_area_struct___300 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___300 *vm_next;
	struct vm_area_struct___300 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___300 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___266 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___292 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___262;

struct vm_operations_struct___266 {
	void (*open)(struct vm_area_struct___300 *);
	void (*close)(struct vm_area_struct___300 *);
	int (*fault)(struct vm_area_struct___300 *, struct vm_fault___262 *);
	int (*page_mkwrite)(struct vm_area_struct___300 *, struct vm_fault___262 *);
	int (*access)(struct vm_area_struct___300 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___300 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___300 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___300 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___300 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___293 {
	struct task_struct___293 *task;
	struct core_thread___293 *next;
};

struct core_state___293 {
	atomic_t nr_threads;
	struct core_thread___293 dumper;
	struct completion startup;
};

struct fasync_struct___292;

struct socket_wq___71 {
	wait_queue_head_t wait;
	struct fasync_struct___292 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___292 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___292 *fa_next;
	struct file___292 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___71;

struct proto_ops___71;

struct socket___72 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___71 *wq;
	struct file___292 *file;
	struct sock___71 *sk;
	const struct proto_ops___71 *ops;
};

struct proto___71;

struct net___96;

struct sock_common___71 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___71 *skc_prot;
	struct net___96 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___84;

struct sk_buff_head___83 {
	struct sk_buff___84 *next;
	struct sk_buff___84 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___72;

struct xfrm_policy___19;

struct dst_entry___72;

struct cg_proto___71;

struct sock___71 {
	struct sock_common___71 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___83 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___84 *head;
		struct sk_buff___84 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___72 *sk_filter;
	struct socket_wq___71 *sk_wq;
	struct sk_buff_head___83 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___19 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___72 *sk_rx_dst;
	struct dst_entry___72 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___83 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___83 sk_error_queue;
	struct proto___71 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___72 *sk_socket;
	void *sk_user_data;
	struct page_frag___286 sk_frag;
	struct sk_buff___84 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___71 *sk_cgrp;
	void (*sk_state_change)(struct sock___71 *);
	void (*sk_data_ready)(struct sock___71 *, int);
	void (*sk_write_space)(struct sock___71 *);
	void (*sk_error_report)(struct sock___71 *);
	int (*sk_backlog_rcv)(struct sock___71 *, struct sk_buff___84 *);
	void (*sk_destruct)(struct sock___71 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___178;

struct kiocb___79;

struct proto_ops___71 {
	int family;
	struct module___182 *owner;
	int (*release)(struct socket___72 *);
	int (*bind)(struct socket___72 *, struct sockaddr *, int);
	int (*connect)(struct socket___72 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___72 *, struct socket___72 *);
	int (*accept)(struct socket___72 *, struct socket___72 *, int);
	int (*getname)(struct socket___72 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___292 *, struct socket___72 *, struct poll_table_struct___178 *);
	int (*ioctl)(struct socket___72 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___72 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___72 *, int);
	int (*shutdown)(struct socket___72 *, int);
	int (*setsockopt)(struct socket___72 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___72 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___72 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___72 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___79 *, struct socket___72 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___79 *, struct socket___72 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___292 *, struct socket___72 *, struct vm_area_struct___300 *);
	ssize_t (*sendpage)(struct socket___72 *, struct page___291 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___72 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___71 *, int);
		struct {
			void (*set_peek_off)(struct sock___71 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___180)(struct file___292 *, wait_queue_head_t *, struct poll_table_struct___178 *);

struct poll_table_struct___178 {
	poll_queue_proc___180 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___79(struct kiocb___79 *, struct io_event *);

struct kiocb___79 {
	atomic_t ki_users;
	struct file___292 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___79 *ki_cancel;
	void (*ki_dtor)(struct kiocb___79 *);
	union {
		void *user;
		struct task_struct___293 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___97;

struct ctl_table_set___97;

struct ctl_dir___97;

struct ctl_node___97;

struct ctl_table_header___97 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___97 *root;
	struct ctl_table_set___97 *set;
	struct ctl_dir___97 *parent;
	struct ctl_node___97 *node;
};

struct ctl_dir___97 {
	struct ctl_table_header___97 header;
	struct rb_root root;
};

struct ctl_table_set___97 {
	int (*is_seen)(struct ctl_table_set___97 *);
	struct ctl_dir___97 dir;
};

struct netns_core___94 {
	struct ctl_table_header___97 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___95 {
	struct mutex___294 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___94 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___97 *ctl;
};

struct netns_ipv4___94 {
	struct ctl_table_header___97 *forw_hdr;
	struct ctl_table_header___97 *frags_hdr;
	struct ctl_table_header___97 *ipv4_hdr;
	struct ctl_table_header___97 *route_hdr;
	struct ctl_table_header___97 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___71 *fibnl;
	struct sock___71 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___94 {
	struct ctl_table_header___97 *hdr;
	struct ctl_table_header___97 *route_hdr;
	struct ctl_table_header___97 *icmp_hdr;
	struct ctl_table_header___97 *frags_hdr;
	struct ctl_table_header___97 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___82;

struct neighbour___72;

struct dst_ops___96 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___96 *);
	struct dst_entry___72 * (*check)(struct dst_entry___72 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___72 *);
	unsigned int (*mtu)(const struct dst_entry___72 *);
	u32 * (*cow_metrics)(struct dst_entry___72 *, long unsigned int);
	void (*destroy)(struct dst_entry___72 *);
	void (*ifdown)(struct dst_entry___72 *, struct net_device___82 *, int);
	struct dst_entry___72 * (*negative_advice)(struct dst_entry___72 *);
	void (*link_failure)(struct sk_buff___84 *);
	void (*update_pmtu)(struct dst_entry___72 *, struct sock___71 *, struct sk_buff___84 *, u32);
	void (*redirect)(struct dst_entry___72 *, struct sock___71 *, struct sk_buff___84 *);
	int (*local_out)(struct sk_buff___84 *);
	struct neighbour___72 * (*neigh_lookup)(const struct dst_entry___72 *, struct sk_buff___84 *, const void *);
	struct kmem_cache___275 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___20;

struct fib6_table___20;

struct netns_ipv6___96 {
	struct netns_sysctl_ipv6___94 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___20 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___20 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___96 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___20 *ip6_prohibit_entry;
	struct rt6_info___20 *ip6_blk_hole_entry;
	struct fib6_table___20 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___71 **icmp_sk;
	struct sock___71 *ndisc_sk;
	struct sock___71 *tcp_sk;
	struct sock___71 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___94 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___97 *sysctl_header;
	struct sock___71 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___71 {
	struct sock___71 *v4_ctl_sk;
	struct sock___71 *v6_ctl_sk;
};

struct netns_nf___94 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___97 *nf_log_dir_header;
};

struct nf_proto_net___94 {
	struct ctl_table_header___97 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___94 {
	struct nf_proto_net___94 pn;
	unsigned int timeout;
};

struct nf_tcp_net___94 {
	struct nf_proto_net___94 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___94 {
	struct nf_proto_net___94 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___94 {
	struct nf_proto_net___94 pn;
	unsigned int timeout;
};

struct nf_ip_net___94 {
	struct nf_generic_net___94 generic;
	struct nf_tcp_net___94 tcp;
	struct nf_udp_net___94 udp;
	struct nf_icmp_net___94 icmp;
	struct nf_icmp_net___94 icmpv6;
};

struct netns_ct___95 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___97 *sysctl_header;
	struct ctl_table_header___97 *acct_sysctl_header;
	struct ctl_table_header___97 *tstamp_sysctl_header;
	struct ctl_table_header___97 *event_sysctl_header;
	struct ctl_table_header___97 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___275 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___94 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___94 {
	struct netns_sysctl_ipv6___94 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___96 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___71 *nlsk;
	struct sock___71 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___97 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___96 xfrm4_dst_ops;
	struct dst_ops___96 xfrm6_dst_ops;
};

struct net___96 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___97 sysctls;
	struct sock___71 *rtnl;
	struct sock___71 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___82 *loopback_dev;
	struct netns_core___94 core;
	struct netns_mib mib;
	struct netns_packet___95 packet;
	struct netns_unix___94 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___94 ipv4;
	struct netns_ipv6___96 ipv6;
	struct netns_sctp___94 sctp;
	struct netns_dccp___71 dccp;
	struct netns_nf___94 nf;
	struct netns_xt xt;
	struct netns_ct___95 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___94 nf_frag;
	struct sock___71 *nfnl;
	struct sock___71 *nfnl_stash;
	struct sk_buff_head___83 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___96 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___71 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___71 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___294 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___294 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___292;

struct seq_file___217;

struct file_operations___292 {
	struct module___182 *owner;
	loff_t (*llseek)(struct file___292 *, loff_t, int);
	ssize_t (*read)(struct file___292 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___292 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___79 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___79 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___292 *, void *, filldir_t);
	unsigned int (*poll)(struct file___292 *, struct poll_table_struct___178 *);
	long int (*unlocked_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___292 *, struct vm_area_struct___300 *);
	int (*open)(struct inode___292 *, struct file___292 *);
	int (*flush)(struct file___292 *, fl_owner_t);
	int (*release)(struct inode___292 *, struct file___292 *);
	int (*fsync)(struct file___292 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___79 *, int);
	int (*fasync)(int, struct file___292 *, int);
	int (*lock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*sendpage)(struct file___292 *, struct page___291 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___292 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___292 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___292 *, long int, struct file_lock___292 **, void **);
		struct {
			int (*setlease)(struct file___292 *, long int, struct file_lock___292 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___292 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___217 *, struct file___292 *);
};

struct dev_pm_qos___93;

struct dev_pm_info___93 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___93 *qos;
};

struct dma_map_ops___155;

struct dev_archdata___155 {
	struct dma_map_ops___155 *dma_ops;
	void *iommu;
};

struct device_type___290;

struct bus_type___290;

struct device_driver___290;

struct dev_pm_domain___290;

struct class___290;

struct attribute_group___252;

struct device_rh___290;

struct device___290 {
	struct device___290 *parent;
	struct device_private *p;
	struct kobject___74 kobj;
	const char *init_name;
	const struct device_type___290 *type;
	struct mutex___294 mutex;
	struct bus_type___290 *bus;
	struct device_driver___290 *driver;
	void *platform_data;
	struct dev_pm_info___93 power;
	struct dev_pm_domain___290 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___155 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___290 *class;
	const struct attribute_group___252 **groups;
	void (*release)(struct device___290 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___290 *device_rh;
};

struct kobj_ns_type_operations___71 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___71 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___254;

struct attribute_group___252 {
	const char *name;
	umode_t (*is_visible)(struct kobject___74 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___254 **bin_attrs;
};

struct bin_attribute___254 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___292 *, struct kobject___74 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___292 *, struct kobject___74 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	int (*mmap)(struct file___292 *, struct kobject___74 *, struct bin_attribute___254 *, struct vm_area_struct___300 *);
};

struct sysfs_ops___74 {
	ssize_t (*show)(struct kobject___74 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___74 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___74 *, const struct attribute *);
};

struct kset_uevent_ops___74;

struct kset___74 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___74 kobj;
	const struct kset_uevent_ops___74 *uevent_ops;
};

struct kobj_type___74 {
	void (*release)(struct kobject___74 *);
	const struct sysfs_ops___74 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___71 * (*child_ns_type)(struct kobject___74 *);
	const void * (*namespace)(struct kobject___74 *);
};

struct kset_uevent_ops___74 {
	int (* const filter)(struct kset___74 *, struct kobject___74 *);
	const char * (* const name)(struct kset___74 *, struct kobject___74 *);
	int (* const uevent)(struct kset___74 *, struct kobject___74 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___290 {
	int (*prepare)(struct device___290 *);
	void (*complete)(struct device___290 *);
	int (*suspend)(struct device___290 *);
	int (*resume)(struct device___290 *);
	int (*freeze)(struct device___290 *);
	int (*thaw)(struct device___290 *);
	int (*poweroff)(struct device___290 *);
	int (*restore)(struct device___290 *);
	int (*suspend_late)(struct device___290 *);
	int (*resume_early)(struct device___290 *);
	int (*freeze_late)(struct device___290 *);
	int (*thaw_early)(struct device___290 *);
	int (*poweroff_late)(struct device___290 *);
	int (*restore_early)(struct device___290 *);
	int (*suspend_noirq)(struct device___290 *);
	int (*resume_noirq)(struct device___290 *);
	int (*freeze_noirq)(struct device___290 *);
	int (*thaw_noirq)(struct device___290 *);
	int (*poweroff_noirq)(struct device___290 *);
	int (*restore_noirq)(struct device___290 *);
	int (*runtime_suspend)(struct device___290 *);
	int (*runtime_resume)(struct device___290 *);
	int (*runtime_idle)(struct device___290 *);
};

struct dev_pm_qos_request___94;

struct dev_pm_qos___93 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___94 *latency_req;
	struct dev_pm_qos_request___94 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___94 *latency_tolerance_req;
};

struct dev_pm_info_rh___290 {
	void (*set_latency_tolerance)(struct device___290 *, s32);
};

struct dev_pm_domain___290 {
	struct dev_pm_ops___290 ops;
};

struct zone___293;

struct lruvec___293 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___293 *zone;
};

struct pglist_data___293;

struct zone___293 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___293 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___293 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___293 {
	struct zone___293 *zone;
	int zone_idx;
};

struct zonelist___293 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___293 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___293 {
	struct zone___293 node_zones[4];
	struct zonelist___293 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___293 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___216;

struct x86_io_apic_ops___216 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___216 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___216;

struct irq_data___216 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___216 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___293 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___293 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___155 {
	void * (*alloc)(struct device___290 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___290 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___290 *, struct vm_area_struct___300 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___290 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___290 *, struct page___291 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___290 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___290 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___290 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___290 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___290 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___290 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___290 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___290 *, dma_addr_t);
	int (*dma_supported)(struct device___290 *, u64);
	int (*set_dma_mask)(struct device___290 *, u64);
	int is_phys;
};

struct bus_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___290 *, char *);
	ssize_t (*store)(struct bus_type___290 *, const char *, size_t);
};

struct device_attribute___290;

struct driver_attribute___290;

struct bus_type___290 {
	const char *name;
	const char *dev_name;
	struct device___290 *dev_root;
	struct bus_attribute___290 *bus_attrs;
	struct device_attribute___290 *dev_attrs;
	struct driver_attribute___290 *drv_attrs;
	const struct attribute_group___252 **bus_groups;
	const struct attribute_group___252 **dev_groups;
	const struct attribute_group___252 **drv_groups;
	int (*match)(struct device___290 *, struct device_driver___290 *);
	int (*uevent)(struct device___290 *, struct kobj_uevent_env *);
	int (*probe)(struct device___290 *);
	int (*remove)(struct device___290 *);
	void (*shutdown)(struct device___290 *);
	int (*online)(struct device___290 *);
	int (*offline)(struct device___290 *);
	int (*suspend)(struct device___290 *, pm_message_t);
	int (*resume)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct device___290 *, struct device_attribute___290 *, char *);
	ssize_t (*store)(struct device___290 *, struct device_attribute___290 *, const char *, size_t);
};

struct driver_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___290 *, char *);
	ssize_t (*store)(struct device_driver___290 *, const char *, size_t);
};

struct device_driver___290 {
	const char *name;
	struct bus_type___290 *bus;
	struct module___182 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___290 *);
	int (*remove)(struct device___290 *);
	void (*shutdown)(struct device___290 *);
	int (*suspend)(struct device___290 *, pm_message_t);
	int (*resume)(struct device___290 *);
	const struct attribute_group___252 **groups;
	const struct dev_pm_ops___290 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___290 {
	const char *name;
	const struct attribute_group___252 **groups;
	int (*uevent)(struct device___290 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___290 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
};

struct class_attribute___290;

struct class___290 {
	const char *name;
	struct module___182 *owner;
	struct class_attribute___290 *class_attrs;
	struct device_attribute___290 *dev_attrs;
	const struct attribute_group___252 **dev_groups;
	struct bin_attribute___254 *dev_bin_attrs;
	struct kobject___74 *dev_kobj;
	int (*dev_uevent)(struct device___290 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___290 *, umode_t *);
	void (*class_release)(struct class___290 *);
	void (*dev_release)(struct device___290 *);
	int (*suspend)(struct device___290 *, pm_message_t);
	int (*resume)(struct device___290 *);
	const struct kobj_ns_type_operations___71 *ns_type;
	const void * (*namespace)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
	struct subsys_private *p;
};

struct class_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct class___290 *, struct class_attribute___290 *, char *);
	ssize_t (*store)(struct class___290 *, struct class_attribute___290 *, const char *, size_t);
	const void * (*namespace)(struct class___290 *, const struct class_attribute___290 *);
};

struct device_rh___290 {
	struct dev_pm_info_rh___290 power;
};

struct dev_pm_qos_request___94 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___290 *dev;
};

struct vm_fault___262 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___291 *page;
};

struct dentry_operations___292;

struct super_block___292;

struct dentry___292 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___292 *d_parent;
	struct qstr d_name;
	struct inode___292 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___292 *d_op;
	struct super_block___292 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___292;

struct dquot___292;

struct block_device___292;

struct inode___292 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___292 *i_op;
	struct super_block___292 *i_sb;
	struct address_space___292 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___294 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___292 *i_fop;
	struct file_lock___292 *i_flock;
	struct address_space___292 i_data;
	struct dquot___292 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___292 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___292 {
	int (*d_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_hash)(const struct dentry___292 *, struct qstr *);
	int (*d_compare)(const struct dentry___292 *, const struct dentry___292 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___292 *);
	void (*d_release)(struct dentry___292 *);
	void (*d_prune)(struct dentry___292 *);
	void (*d_iput)(struct dentry___292 *, struct inode___292 *);
	char * (*d_dname)(struct dentry___292 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___292 *);
	int (*d_manage)(struct dentry___292 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___292;

struct mem_dqinfo___292 {
	struct quota_format_type___292 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___292;

struct quota_info___292 {
	unsigned int flags;
	struct mutex___294 dqio_mutex;
	struct mutex___294 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___292 *files[2];
	struct mem_dqinfo___292 info[2];
	const struct quota_format_ops___292 *ops[2];
};

struct file_system_type___292;

struct super_operations___292;

struct dquot_operations___292;

struct quotactl_ops___292;

struct xattr_handler___188;

struct super_block___292 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___292 *s_type;
	const struct super_operations___292 *s_op;
	const struct dquot_operations___292 *dq_op;
	const struct quotactl_ops___292 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___292 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___188 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___292 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___292 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___294 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___292 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___292 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___292 *bd_inode;
	struct super_block___292 *bd_super;
	struct mutex___294 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___292 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___294 bd_fsfreeze_mutex;
};

struct cgroup___187;

struct cgroup_subsys_state___187 {
	struct cgroup___187 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___292 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___292 *ia_file;
};

struct dquot___292 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___294 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___292 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___292 {
	int qf_fmt_id;
	const struct quota_format_ops___292 *qf_ops;
	struct module___182 *qf_owner;
	struct quota_format_type___292 *qf_next;
};

struct quota_format_ops___292 {
	int (*check_quota_file)(struct super_block___292 *, int);
	int (*read_file_info)(struct super_block___292 *, int);
	int (*write_file_info)(struct super_block___292 *, int);
	int (*free_file_info)(struct super_block___292 *, int);
	int (*read_dqblk)(struct dquot___292 *);
	int (*commit_dqblk)(struct dquot___292 *);
	int (*release_dqblk)(struct dquot___292 *);
};

struct dquot_operations___292 {
	int (*write_dquot)(struct dquot___292 *);
	struct dquot___292 * (*alloc_dquot)(struct super_block___292 *, int);
	void (*destroy_dquot)(struct dquot___292 *);
	int (*acquire_dquot)(struct dquot___292 *);
	int (*release_dquot)(struct dquot___292 *);
	int (*mark_dirty)(struct dquot___292 *);
	int (*write_info)(struct super_block___292 *, int);
	qsize_t * (*get_reserved_space)(struct inode___292 *);
};

struct quotactl_ops___292 {
	int (*quota_on)(struct super_block___292 *, int, int, struct path___292 *);
	int (*quota_on_meta)(struct super_block___292 *, int, int);
	int (*quota_off)(struct super_block___292 *, int);
	int (*quota_sync)(struct super_block___292 *, int);
	int (*get_info)(struct super_block___292 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___292 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___292 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___292 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___292 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___292 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___292 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___292 *, unsigned int);
};

struct address_space_operations___292 {
	int (*writepage)(struct page___291 *, struct writeback_control *);
	int (*readpage)(struct file___292 *, struct page___291 *);
	int (*writepages)(struct address_space___292 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___291 *);
	int (*readpages)(struct file___292 *, struct address_space___292 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___292 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___291 **, void **);
	int (*write_end)(struct file___292 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___291 *, void *);
	sector_t (*bmap)(struct address_space___292 *, sector_t);
	void (*invalidatepage)(struct page___291 *, long unsigned int);
	int (*releasepage)(struct page___291 *, gfp_t);
	void (*freepage)(struct page___291 *);
	ssize_t (*direct_IO)(int, struct kiocb___79 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___292 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___292 *, struct page___291 *, struct page___291 *, enum migrate_mode);
	int (*launder_page)(struct page___291 *);
	int (*is_partially_uptodate)(struct page___291 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___291 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___292 *, struct page___291 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___292 *, sector_t *);
	void (*swap_deactivate)(struct file___292 *);
	void (*invalidatepage_range)(struct page___291 *, unsigned int, unsigned int);
};

struct inode_operations___292 {
	struct dentry___292 * (*lookup)(struct inode___292 *, struct dentry___292 *, unsigned int);
	void * (*follow_link)(struct dentry___292 *, struct nameidata *);
	int (*permission)(struct inode___292 *, int);
	struct posix_acl * (*get_acl)(struct inode___292 *, int);
	int (*readlink)(struct dentry___292 *, char *, int);
	void (*put_link)(struct dentry___292 *, struct nameidata *, void *);
	int (*create)(struct inode___292 *, struct dentry___292 *, umode_t, bool);
	int (*link)(struct dentry___292 *, struct inode___292 *, struct dentry___292 *);
	int (*unlink)(struct inode___292 *, struct dentry___292 *);
	int (*symlink)(struct inode___292 *, struct dentry___292 *, const char *);
	int (*mkdir)(struct inode___292 *, struct dentry___292 *, umode_t);
	int (*rmdir)(struct inode___292 *, struct dentry___292 *);
	int (*mknod)(struct inode___292 *, struct dentry___292 *, umode_t, dev_t);
	int (*rename)(struct inode___292 *, struct dentry___292 *, struct inode___292 *, struct dentry___292 *);
	int (*setattr)(struct dentry___292 *, struct iattr___292 *);
	int (*getattr)(struct vfsmount *, struct dentry___292 *, struct kstat *);
	int (*setxattr)(struct dentry___292 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___292 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___292 *, char *, size_t);
	int (*removexattr)(struct dentry___292 *, const char *);
	int (*fiemap)(struct inode___292 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___292 *, struct timespec *, int);
	int (*atomic_open)(struct inode___292 *, struct dentry___292 *, struct file___292 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___292;

struct lock_manager_operations___292;

struct file_lock___292 {
	struct file_lock___292 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___292 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___292 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___292 *fl_ops;
	const struct lock_manager_operations___292 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___292 {
	void (*fl_copy_lock)(struct file_lock___292 *, struct file_lock___292 *);
	void (*fl_release_private)(struct file_lock___292 *);
};

struct lock_manager_operations___292 {
	int (*lm_compare_owner)(struct file_lock___292 *, struct file_lock___292 *);
	long unsigned int (*lm_owner_key)(struct file_lock___292 *);
	void (*lm_notify)(struct file_lock___292 *);
	int (*lm_grant)(struct file_lock___292 *, struct file_lock___292 *, int);
	void (*lm_break)(struct file_lock___292 *);
	int (*lm_change)(struct file_lock___292 **, int);
};

struct file_system_type___292 {
	const char *name;
	int fs_flags;
	struct dentry___292 * (*mount)(struct file_system_type___292 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___292 *);
	struct module___182 *owner;
	struct file_system_type___292 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___292 {
	struct inode___292 * (*alloc_inode)(struct super_block___292 *);
	void (*destroy_inode)(struct inode___292 *);
	void (*dirty_inode)(struct inode___292 *, int);
	int (*write_inode)(struct inode___292 *, struct writeback_control *);
	int (*drop_inode)(struct inode___292 *);
	void (*evict_inode)(struct inode___292 *);
	void (*put_super)(struct super_block___292 *);
	int (*sync_fs)(struct super_block___292 *, int);
	int (*freeze_fs)(struct super_block___292 *);
	int (*unfreeze_fs)(struct super_block___292 *);
	int (*statfs)(struct dentry___292 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___292 *, int *, char *);
	void (*umount_begin)(struct super_block___292 *);
	int (*show_options)(struct seq_file___217 *, struct dentry___292 *);
	int (*show_devname)(struct seq_file___217 *, struct dentry___292 *);
	int (*show_path)(struct seq_file___217 *, struct dentry___292 *);
	int (*show_stats)(struct seq_file___217 *, struct dentry___292 *);
	ssize_t (*quota_read)(struct super_block___292 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___292 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___292 *);
	int (*bdev_try_to_free_page)(struct super_block___292 *, struct page___291 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___292 *);
	void (*free_cached_objects)(struct super_block___292 *, int);
};

struct xattr_handler___188 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___292 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___292 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___292 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___217;

struct seq_file___217 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___294 lock;
	const struct seq_operations___217 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_node___97 {
	struct rb_node node;
	struct ctl_table_header___97 *header;
};

struct ctl_table_root___97 {
	struct ctl_table_set___97 default_set;
	struct ctl_table_set___97 * (*lookup)(struct ctl_table_root___97 *, struct nsproxy___172 *);
	int (*permissions)(struct ctl_table_header___97 *, struct ctl_table *);
};

struct nsproxy___172 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___96 *net_ns;
};

struct signal_struct___293 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___293 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___293 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___294 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___187 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___187 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___274 {
	void **freelist;
	long unsigned int tid;
	struct page___291 *page;
	struct page___291 *partial;
};

struct memcg_cache_params___275 {
	bool is_root_cache;
	union {
		struct kmem_cache___275 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___275 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___82 {
	atomic_t use;
	unsigned int mask;
	struct net_device___82 *physindev;
	struct net_device___82 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___82(struct sk_buff___84 **);

struct net_device_ops___82;

struct ethtool_ops___82;

struct header_ops___82;

struct inet6_dev___46;

struct netdev_rx_queue___82;

struct netdev_queue___82;

struct rtnl_link_ops___73;

struct dcbnl_rtnl_ops___82;

struct net_device___82 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___82 *netdev_ops;
	const struct ethtool_ops___82 *ethtool_ops;
	const struct header_ops___82 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___74 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___46 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___82 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___82 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___82 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___82 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___82 = 0,
		NETREG_REGISTERED___82 = 1,
		NETREG_UNREGISTERING___82 = 2,
		NETREG_UNREGISTERED___82 = 3,
		NETREG_RELEASED___82 = 4,
		NETREG_DUMMY___82 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___82 = 0,
		RTNL_LINK_INITIALIZING___82 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___82 *);
	struct netpoll_info *npinfo;
	struct net___96 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___290 dev;
	const struct attribute_group___252 *sysfs_groups[4];
	const struct rtnl_link_ops___73 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___82 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___19;

struct sk_buff___84 {
	struct sk_buff___84 *next;
	struct sk_buff___84 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___71 *sk;
	struct net_device___82 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___19 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___84 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___82 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___23 {
	struct {
		struct page___291 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___23 skb_frag_t___23;

struct skb_shared_info___23 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___84 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___23 frags[17];
};

struct xfrm_state___19;

struct sec_path___19 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___19 *xvec[6];
};

struct ethtool_ops___82 {
	int (*get_settings)(struct net_device___82 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___82 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___82 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___82 *);
	void (*get_regs)(struct net_device___82 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___82 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___82 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___82 *);
	void (*set_msglevel)(struct net_device___82 *, u32);
	int (*nway_reset)(struct net_device___82 *);
	u32 (*get_link)(struct net_device___82 *);
	int (*get_eeprom_len)(struct net_device___82 *);
	int (*get_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___82 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___82 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___82 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___82 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___82 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___82 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___82 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___82 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___82 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___82 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___82 *);
	void (*complete)(struct net_device___82 *);
	u32 (*get_priv_flags)(struct net_device___82 *);
	int (*set_priv_flags)(struct net_device___82 *, u32);
	int (*get_sset_count)(struct net_device___82 *, int);
	int (*get_rxnfc)(struct net_device___82 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___82 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___82 *, struct ethtool_flash *);
	int (*reset)(struct net_device___82 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___82 *);
	int (*get_rxfh_indir)(struct net_device___82 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___82 *, const u32 *);
	void (*get_channels)(struct net_device___82 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___82 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___82 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___82 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___82 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___82 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___82 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___82 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___82 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___82 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___82 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___82 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

enum {
	ICMP6_MIB_NUM = 0,
	ICMP6_MIB_INMSGS = 1,
	ICMP6_MIB_INERRORS = 2,
	ICMP6_MIB_OUTMSGS = 3,
	ICMP6_MIB_OUTERRORS = 4,
	ICMP6_MIB_CSUMERRORS = 5,
	__ICMP6_MIB_MAX = 6,
};

struct rtable___41;

struct dst_entry___72 {
	struct callback_head callback_head;
	struct dst_entry___72 *child;
	struct net_device___82 *dev;
	struct dst_ops___96 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___72 *path;
	struct dst_entry___72 *from;
	struct xfrm_state___19 *xfrm;
	int (*input)(struct sk_buff___84 *);
	union {
		int (*output)(struct sock___71 *, struct sk_buff___84 *);
		struct {
			int (*output)(struct sk_buff___84 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___72 *next;
		struct rtable___41 *rt_next;
		struct rt6_info___20 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___72;

struct neigh_parms___72;

struct neigh_ops___72;

struct neighbour___72 {
	struct neighbour___72 *next;
	struct neigh_table___72 *tbl;
	struct neigh_parms___72 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___83 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___72 *, struct sk_buff___84 *);
	const struct neigh_ops___72 *ops;
	struct callback_head rcu;
	struct net_device___82 *dev;
	u8 primary_key[0];
};

struct fib6_node___20;

struct rt6_info___20 {
	struct dst_entry___72 dst;
	struct fib6_table___20 *rt6i_table;
	struct fib6_node___20 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___46 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___20 {
	struct fib6_node___20 *parent;
	struct fib6_node___20 *left;
	struct fib6_node___20 *right;
	struct rt6_info___20 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___20 *rr_ptr;
};

struct fib6_table___20 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___20 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___15 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___82 *in;
	struct net_device___82 *out;
	struct sock___71 *sk;
	int (*okfn)(struct sock___71 *, struct sk_buff___84 *);
};

struct nf_afinfo___97 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___84 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___84 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___96 *, struct dst_entry___72 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___84 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___84 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___216 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___216 *);
	void (*irq_shutdown)(struct irq_data___216 *);
	void (*irq_enable)(struct irq_data___216 *);
	void (*irq_disable)(struct irq_data___216 *);
	void (*irq_ack)(struct irq_data___216 *);
	void (*irq_mask)(struct irq_data___216 *);
	void (*irq_mask_ack)(struct irq_data___216 *);
	void (*irq_unmask)(struct irq_data___216 *);
	void (*irq_eoi)(struct irq_data___216 *);
	int (*irq_set_affinity)(struct irq_data___216 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___216 *);
	int (*irq_set_type)(struct irq_data___216 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___216 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___216 *);
	void (*irq_bus_sync_unlock)(struct irq_data___216 *);
	void (*irq_cpu_online)(struct irq_data___216 *);
	void (*irq_cpu_offline)(struct irq_data___216 *);
	void (*irq_suspend)(struct irq_data___216 *);
	void (*irq_resume)(struct irq_data___216 *);
	void (*irq_pm_shutdown)(struct irq_data___216 *);
	void (*irq_print_chip)(struct irq_data___216 *, struct seq_file___217 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___216 *, void *);
	long unsigned int flags;
};

struct seq_operations___217 {
	void * (*start)(struct seq_file___217 *, loff_t *);
	void (*stop)(struct seq_file___217 *, void *);
	void * (*next)(struct seq_file___217 *, void *, loff_t *);
	int (*show)(struct seq_file___217 *, void *);
};

struct dcbnl_rtnl_ops___82 {
	int (*ieee_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___82 *);
	u8 (*setstate)(struct net_device___82 *, u8);
	void (*getpermhwaddr)(struct net_device___82 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___82 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___82 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___82 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___82 *, int, u8 *);
	void (*setpfccfg)(struct net_device___82 *, int, u8);
	void (*getpfccfg)(struct net_device___82 *, int, u8 *);
	u8 (*setall)(struct net_device___82 *);
	u8 (*getcap)(struct net_device___82 *, int, u8 *);
	int (*getnumtcs)(struct net_device___82 *, int, u8 *);
	int (*setnumtcs)(struct net_device___82 *, int, u8);
	u8 (*getpfcstate)(struct net_device___82 *);
	void (*setpfcstate)(struct net_device___82 *, u8);
	void (*getbcncfg)(struct net_device___82 *, int, u32 *);
	void (*setbcncfg)(struct net_device___82 *, int, u32);
	void (*getbcnrp)(struct net_device___82 *, int, u8 *);
	void (*setbcnrp)(struct net_device___82 *, int, u8);
	u8 (*setapp)(struct net_device___82 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___82 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___82 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___82 *, int, u8);
	u8 (*getdcbx)(struct net_device___82 *);
	u8 (*setdcbx)(struct net_device___82 *, u8);
	int (*peer_getappinfo)(struct net_device___82 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___82 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___82 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___82 *, struct cee_pfc *);
};

struct cgroupfs_root___187;

struct cgroup___187 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___187 *parent;
	struct dentry___292 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___187 *subsys[11];
	struct cgroupfs_root___187 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___294 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___187 {
	struct super_block___292 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___187 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___123 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___292 *, struct file___292 *);
	ssize_t (*read)(struct cgroup___187 *, struct cftype___123 *, struct file___292 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___187 *, struct cftype___123 *);
	s64 (*read_s64)(struct cgroup___187 *, struct cftype___123 *);
	int (*read_map)(struct cgroup___187 *, struct cftype___123 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___187 *, struct cftype___123 *, struct seq_file___217 *);
	ssize_t (*write)(struct cgroup___187 *, struct cftype___123 *, struct file___292 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___187 *, struct cftype___123 *, u64);
	int (*write_s64)(struct cgroup___187 *, struct cftype___123 *, s64);
	int (*write_string)(struct cgroup___187 *, struct cftype___123 *, const char *);
	int (*trigger)(struct cgroup___187 *, unsigned int);
	int (*release)(struct inode___292 *, struct file___292 *);
	int (*register_event)(struct cgroup___187 *, struct cftype___123 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___187 *, struct cftype___123 *, struct eventfd_ctx *);
};

struct cftype_set___119 {
	struct list_head node;
	struct cftype___123 *cfts;
};

struct task_and_cgroup___119 {
	struct task_struct___293 *task;
	struct cgroup___187 *cgrp;
	struct css_set___187 *cg;
};

struct cgroup_taskset___119 {
	struct task_and_cgroup___119 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___187 *cur_cgrp;
};

struct cgroup_subsys___119 {
	struct cgroup_subsys_state___187 * (*css_alloc)(struct cgroup___187 *);
	int (*css_online)(struct cgroup___187 *);
	void (*css_offline)(struct cgroup___187 *);
	void (*css_free)(struct cgroup___187 *);
	int (*can_attach)(struct cgroup___187 *, struct cgroup_taskset___119 *);
	void (*cancel_attach)(struct cgroup___187 *, struct cgroup_taskset___119 *);
	void (*attach)(struct cgroup___187 *, struct cgroup_taskset___119 *);
	void (*fork)(struct task_struct___293 *);
	void (*exit)(struct cgroup___187 *, struct cgroup___187 *, struct task_struct___293 *);
	void (*bind)(struct cgroup___187 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___187 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___123 *base_cftypes;
	struct cftype_set___119 base_cftset;
	struct module___182 *module;
};

struct request_sock_ops___55;

struct request_sock___56 {
	struct sock_common___71 __req_common;
	struct request_sock___56 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___55 *rsk_ops;
	struct sock___71 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___19;

struct xfrm_type___19;

struct xfrm_mode___19;

struct xfrm_state___19 {
	struct net___96 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___19 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___19 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___19 *type;
	struct xfrm_mode___19 *inner_mode;
	struct xfrm_mode___19 *inner_mode_iaf;
	struct xfrm_mode___19 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___19 {
	struct sk_buff_head___83 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___19 {
	struct net___96 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___19 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___84 {
	struct sk_buff___84 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___84 *, struct netlink_callback___84 *);
	int (*done)(struct netlink_callback___84 *);
	void *data;
	struct module___182 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___82 {
	int (*create)(struct sk_buff___84 *, struct net_device___82 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___84 *, unsigned char *);
	int (*rebuild)(struct sk_buff___84 *);
	int (*cache)(const struct neighbour___72 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___82 *, const unsigned char *);
};

struct napi_struct___82 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___82 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___82 *dev;
	struct sk_buff___84 *gro_list;
	struct sk_buff___84 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___82 {
	struct net_device___82 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___74 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___82 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___74 kobj;
	struct net_device___82 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___82 {
	int (*ndo_init)(struct net_device___82 *);
	void (*ndo_uninit)(struct net_device___82 *);
	int (*ndo_open)(struct net_device___82 *);
	int (*ndo_stop)(struct net_device___82 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___84 *, struct net_device___82 *);
	u16 (*ndo_select_queue)(struct net_device___82 *, struct sk_buff___84 *);
	void (*ndo_change_rx_flags)(struct net_device___82 *, int);
	void (*ndo_set_rx_mode)(struct net_device___82 *);
	int (*ndo_set_mac_address)(struct net_device___82 *, void *);
	int (*ndo_validate_addr)(struct net_device___82 *);
	int (*ndo_do_ioctl)(struct net_device___82 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___82 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___82 *, int);
	int (*ndo_neigh_setup)(struct net_device___82 *, struct neigh_parms___72 *);
	void (*ndo_tx_timeout)(struct net_device___82 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___82 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___82 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___82 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___82 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___82 *);
	int (*ndo_netpoll_setup)(struct net_device___82 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___82 *);
	int (*ndo_busy_poll)(struct napi_struct___82 *);
	int (*ndo_set_vf_mac)(struct net_device___82 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___82 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___82 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___82 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___82 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___82 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___82 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___82 *, int, struct sk_buff___84 *);
	int (*ndo_setup_tc)(struct net_device___82 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___82 *);
	int (*ndo_fcoe_disable)(struct net_device___82 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___82 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___82 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___82 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___82 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___82 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___82 *, const struct sk_buff___84 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___82 *, struct net_device___82 *);
	int (*ndo_del_slave)(struct net_device___82 *, struct net_device___82 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___72 *);
	void (*ndo_neigh_destroy)(struct neighbour___72 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___84 *, struct netlink_callback___84 *, struct net_device___82 *, int);
	int (*ndo_bridge_setlink)(struct net_device___82 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___84 *, u32, u32, struct net_device___82 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___82 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___82 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___82 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___82 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___82 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___82 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___84 *, struct net_device___82 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___82 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___82 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___82 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___72 {
	struct net___96 *net;
	struct net_device___82 *dev;
	struct neigh_parms___72 *next;
	int (*neigh_setup)(struct neighbour___72 *);
	void (*neigh_cleanup)(struct neighbour___72 *);
	struct neigh_table___72 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___46;

struct ifacaddr6___46;

struct inet6_dev___46 {
	struct net_device___82 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___46 *mc_list;
	struct ifmcaddr6___46 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___46 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___72 *nd_parms;
	struct inet6_dev___46 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___73 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___82 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___96 *, struct net_device___82 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___82 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___82 *, struct list_head *);
	size_t (*get_size)(const struct net_device___82 *);
	int (*fill_info)(struct sk_buff___84 *, const struct net_device___82 *);
	size_t (*get_xstats_size)(const struct net_device___82 *);
	int (*fill_xstats)(struct sk_buff___84 *, const struct net_device___82 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___96 * (*get_link_net)(const struct net_device___82 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___82 *, struct net_device___82 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___82 *, const struct net_device___82 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___84 *, const struct net_device___82 *, const struct net_device___82 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___72 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___84 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___72;

struct neigh_hash_table___72;

struct neigh_table___72 {
	struct neigh_table___72 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___82 *, __u32 *);
	int (*constructor)(struct neighbour___72 *);
	int (*pconstructor)(struct pneigh_entry___72 *);
	void (*pdestructor)(struct pneigh_entry___72 *);
	void (*proxy_redo)(struct sk_buff___84 *);
	char *id;
	struct neigh_parms___72 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___83 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___72 *nht;
	struct pneigh_entry___72 **phash_buckets;
};

struct neigh_ops___72 {
	int family;
	void (*solicit)(struct neighbour___72 *, struct sk_buff___84 *);
	void (*error_report)(struct neighbour___72 *, struct sk_buff___84 *);
	int (*output)(struct neighbour___72 *, struct sk_buff___84 *);
	int (*connected_output)(struct neighbour___72 *, struct sk_buff___84 *);
};

struct pneigh_entry___72 {
	struct pneigh_entry___72 *next;
	struct net___96 *net;
	struct net_device___82 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___72 {
	struct neighbour___72 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___41 {
	struct dst_entry___72 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___52;

struct proto___71 {
	void (*close)(struct sock___71 *, long int);
	int (*connect)(struct sock___71 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___71 *, int);
	struct sock___71 * (*accept)(struct sock___71 *, int, int *);
	int (*ioctl)(struct sock___71 *, int, long unsigned int);
	int (*init)(struct sock___71 *);
	void (*destroy)(struct sock___71 *);
	void (*shutdown)(struct sock___71 *, int);
	int (*setsockopt)(struct sock___71 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___71 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___71 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___71 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___71 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___79 *, struct sock___71 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___79 *, struct sock___71 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___71 *, struct page___291 *, int, size_t, int);
	int (*bind)(struct sock___71 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___71 *, struct sk_buff___84 *);
	void (*release_cb)(struct sock___71 *);
	void (*mtu_reduced)(struct sock___71 *);
	void (*hash)(struct sock___71 *);
	void (*unhash)(struct sock___71 *);
	void (*rehash)(struct sock___71 *);
	int (*get_port)(struct sock___71 *, short unsigned int);
	void (*clear_sk)(struct sock___71 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___71 *);
	void (*enter_memory_pressure)(struct sock___71 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___275 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___55 *rsk_prot;
	struct timewait_sock_ops___52 *twsk_prot;
	union {
		struct inet_hashinfo___19 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___182 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___119 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___71 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___71 {
	void (*enter_memory_pressure)(struct sock___71 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___55 {
	int family;
	int obj_size;
	struct kmem_cache___275 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___71 *, struct request_sock___56 *);
	void (*send_ack)(struct sock___71 *, struct sk_buff___84 *, struct request_sock___56 *);
	void (*send_reset)(struct sock___71 *, struct sk_buff___84 *);
	void (*destructor)(struct request_sock___56 *);
	void (*syn_ack_timeout)(struct sock___71 *, struct request_sock___56 *);
};

struct timewait_sock_ops___52 {
	struct kmem_cache___275 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___71 *, struct sock___71 *, void *);
	void (*twsk_destructor)(struct sock___71 *);
};

struct inet_cork___26 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___72 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___26 {
	struct inet_cork___26 base;
	struct flowi fl;
};

struct ipv6_pinfo___25;

struct inet_sock___26 {
	struct sock___71 sk;
	struct ipv6_pinfo___25 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___26 cork;
};

struct ipv6_fl_socklist___24;

struct ipv6_pinfo___25 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___24 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___84 *pktoptions;
	struct sk_buff___84 *rxpmtu;
	struct inet6_cork cork;
};

struct module_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___182 *, struct module_kobject___182 *, char *);
	ssize_t (*store)(struct module_attribute___182 *, struct module_kobject___182 *, const char *, size_t);
	void (*setup)(struct module___182 *, const char *);
	int (*test)(struct module___182 *);
	void (*free)(struct module___182 *);
};

struct nf_ipv6_ops___8 {
	int (*chk_addr)(struct net___96 *, const struct in6_addr *, const struct net_device___82 *, int);
};

struct icmpv6_echo {
	__be16 identifier;
	__be16 sequence;
};

struct icmpv6_nd_advt {
	__u32 reserved: 5;
	__u32 override: 1;
	__u32 solicited: 1;
	__u32 router: 1;
	__u32 reserved2: 24;
};

struct icmpv6_nd_ra {
	__u8 hop_limit;
	__u8 reserved: 3;
	__u8 router_pref: 2;
	__u8 home_agent: 1;
	__u8 other: 1;
	__u8 managed: 1;
	__be16 rt_lifetime;
};

struct icmp6hdr {
	__u8 icmp6_type;
	__u8 icmp6_code;
	__sum16 icmp6_cksum;
	union {
		__be32 un_data32[1];
		__be16 un_data16[2];
		__u8 un_data8[4];
		struct icmpv6_echo u_echo;
		struct icmpv6_nd_advt u_nd_advt;
		struct icmpv6_nd_ra u_nd_ra;
	} icmp6_dataun;
};

struct ip6_flowlabel___24;

struct ipv6_fl_socklist___24 {
	struct ipv6_fl_socklist___24 *next;
	struct ip6_flowlabel___24 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___2 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 valid_lft;
	__u32 prefered_lft;
	atomic_t refcnt;
	spinlock_t lock;
	spinlock_t state_lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u16 scope;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___46 *idev;
	struct rt6_info___20 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___2 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___46 {
	struct in6_addr mca_addr;
	struct inet6_dev___46 *idev;
	struct ifmcaddr6___46 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___46 {
	struct in6_addr aca_addr;
	struct inet6_dev___46 *aca_idev;
	struct rt6_info___20 *aca_rt;
	struct ifacaddr6___46 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct frag_hdr {
	__u8 nexthdr;
	__u8 reserved;
	__be16 frag_off;
	__be32 identification;
};

struct ip6_ra_chain {
	struct ip6_ra_chain *next;
	struct sock___71 *sk;
	int sel;
	void (*destructor)(struct sock___71 *);
};

struct ip6_flowlabel___24 {
	struct ip6_flowlabel___24 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___96 *fl_net;
};

struct xfrm_replay___19 {
	void (*advance)(struct xfrm_state___19 *, __be32);
	int (*check)(struct xfrm_state___19 *, struct sk_buff___84 *, __be32);
	int (*recheck)(struct xfrm_state___19 *, struct sk_buff___84 *, __be32);
	void (*notify)(struct xfrm_state___19 *, int);
	int (*overflow)(struct xfrm_state___19 *, struct sk_buff___84 *);
};

struct xfrm_type___19 {
	char *description;
	struct module___182 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___19 *);
	void (*destructor)(struct xfrm_state___19 *);
	int (*input)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*output)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*reject)(struct xfrm_state___19 *, struct sk_buff___84 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___19 *, struct sk_buff___84 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___19 *, int);
};

struct xfrm_state_afinfo___19;

struct xfrm_mode___19 {
	int (*input2)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*input)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*output2)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*output)(struct xfrm_state___19 *, struct sk_buff___84 *);
	struct xfrm_state_afinfo___19 *afinfo;
	struct module___182 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___19 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___182 *owner;
	const struct xfrm_type___19 *type_map[256];
	struct xfrm_mode___19 *mode_map[5];
	int (*init_flags)(struct xfrm_state___19 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___19 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___19 **, struct xfrm_state___19 **, int);
	union {
		int (*output)(struct sock___71 *, struct sk_buff___84 *);
		struct {
			int (*output)(struct sk_buff___84 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___71 *, struct sk_buff___84 *);
		struct {
			int (*output_finish)(struct sk_buff___84 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*extract_output)(struct xfrm_state___19 *, struct sk_buff___84 *);
	int (*transport_finish)(struct sk_buff___84 *, int);
};

struct packet_type___7 {
	__be16 type;
	struct net_device___82 *dev;
	int (*func)(struct sk_buff___84 *, struct net_device___82 *, struct packet_type___7 *, struct net_device___82 *);
	bool (*id_match)(struct packet_type___7 *, struct sock___71 *);
	void *af_packet_priv;
	struct list_head list;
};

struct inet6_protocol {
	void (*early_demux)(struct sk_buff___84 *);
	int (*handler)(struct sk_buff___84 *);
	void (*err_handler)(struct sk_buff___84 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct page___292;

typedef struct page___292 *pgtable_t___292;

struct address_space___293;

struct kmem_cache___276;

struct page___292 {
	long unsigned int flags;
	struct address_space___293 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___292 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___292 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___276 *slab_cache;
		struct page___292 *first_page;
	};
	long: 64;
};

struct task_struct___294;

struct pv_cpu_ops___294 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___294 *);
	void (*end_context_switch)(struct task_struct___294 *);
};

struct mutex___295 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___294 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___287 {
	struct page___292 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___301;

struct nsproxy___173;

struct signal_struct___294;

struct css_set___188;

struct task_struct___294 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___294 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___301 *mm;
	struct mm_struct___301 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___294 *real_parent;
	struct task_struct___294 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___294 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___294 = 0,
		VTIME_USER___294 = 1,
		VTIME_SYS___294 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___173 *nsproxy;
	struct signal_struct___294 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___188 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___295 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___287 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___301 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___301 *, struct mm_struct___301 *);
	void (*dup_mmap)(struct mm_struct___301 *, struct mm_struct___301 *);
	void (*exit_mmap)(struct mm_struct___301 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___301 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___301 *);
	void (*pgd_free)(struct mm_struct___301 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___301 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___301 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___301 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___301 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___301 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___301 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___301 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___301 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___301 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___301 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___301 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___295 lock;
	void *vdso;
} mm_context_t___295;

struct xol_area___292;

struct uprobes_state___292 {
	struct xol_area___292 *xol_area;
};

struct vm_area_struct___301;

struct file___293;

struct core_state___294;

struct mm_struct___301 {
	struct vm_area_struct___301 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___301 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___301 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___295 context;
	long unsigned int flags;
	struct core_state___294 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___294 *owner;
	struct file___293 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___292 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___129 {
	struct task_struct___294 *task;
	struct exec_domain___80 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___292 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___292 *page;
	long unsigned int vaddr;
};

struct kset___75;

struct kobj_type___75;

struct kobject___75 {
	const char *name;
	struct list_head entry;
	struct kobject___75 *parent;
	struct kset___75 *kset;
	struct kobj_type___75 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___275;

struct memcg_cache_params___276;

struct kmem_cache___276 {
	struct kmem_cache_cpu___275 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___75 kobj;
	struct memcg_cache_params___276 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___293;

struct address_space_operations___293;

struct address_space___293 {
	struct inode___293 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___295 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___293 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___293;

struct path___293 {
	struct vfsmount *mnt;
	struct dentry___293 *dentry;
};

struct file_operations___293;

struct file___293 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___293 f_path;
	struct inode___293 *f_inode;
	const struct file_operations___293 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___293 *f_mapping;
	struct mutex___295 f_pos_lock;
};

struct vm_operations_struct___267;

struct vm_area_struct___301 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___301 *vm_next;
	struct vm_area_struct___301 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___301 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___267 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___293 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___263;

struct vm_operations_struct___267 {
	void (*open)(struct vm_area_struct___301 *);
	void (*close)(struct vm_area_struct___301 *);
	int (*fault)(struct vm_area_struct___301 *, struct vm_fault___263 *);
	int (*page_mkwrite)(struct vm_area_struct___301 *, struct vm_fault___263 *);
	int (*access)(struct vm_area_struct___301 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___301 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___301 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___301 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___301 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___294 {
	struct task_struct___294 *task;
	struct core_thread___294 *next;
};

struct core_state___294 {
	atomic_t nr_threads;
	struct core_thread___294 dumper;
	struct completion startup;
};

struct fasync_struct___293;

struct socket_wq___72 {
	wait_queue_head_t wait;
	struct fasync_struct___293 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___293 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___293 *fa_next;
	struct file___293 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___72;

struct proto_ops___72;

struct socket___73 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___72 *wq;
	struct file___293 *file;
	struct sock___72 *sk;
	const struct proto_ops___72 *ops;
};

struct proto___72;

struct net___97;

struct sock_common___72 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___72 *skc_prot;
	struct net___97 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___85;

struct sk_buff_head___84 {
	struct sk_buff___85 *next;
	struct sk_buff___85 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___73;

struct dst_entry___73;

struct cg_proto___72;

struct sock___72 {
	struct sock_common___72 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___84 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___85 *head;
		struct sk_buff___85 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___73 *sk_filter;
	struct socket_wq___72 *sk_wq;
	struct sk_buff_head___84 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___73 *sk_rx_dst;
	struct dst_entry___73 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___84 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___84 sk_error_queue;
	struct proto___72 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___73 *sk_socket;
	void *sk_user_data;
	struct page_frag___287 sk_frag;
	struct sk_buff___85 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___72 *sk_cgrp;
	void (*sk_state_change)(struct sock___72 *);
	void (*sk_data_ready)(struct sock___72 *, int);
	void (*sk_write_space)(struct sock___72 *);
	void (*sk_error_report)(struct sock___72 *);
	int (*sk_backlog_rcv)(struct sock___72 *, struct sk_buff___85 *);
	void (*sk_destruct)(struct sock___72 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___179;

struct kiocb___80;

struct proto_ops___72 {
	int family;
	struct module *owner;
	int (*release)(struct socket___73 *);
	int (*bind)(struct socket___73 *, struct sockaddr *, int);
	int (*connect)(struct socket___73 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___73 *, struct socket___73 *);
	int (*accept)(struct socket___73 *, struct socket___73 *, int);
	int (*getname)(struct socket___73 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___293 *, struct socket___73 *, struct poll_table_struct___179 *);
	int (*ioctl)(struct socket___73 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___73 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___73 *, int);
	int (*shutdown)(struct socket___73 *, int);
	int (*setsockopt)(struct socket___73 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___73 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___73 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___73 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___80 *, struct socket___73 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___80 *, struct socket___73 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___293 *, struct socket___73 *, struct vm_area_struct___301 *);
	ssize_t (*sendpage)(struct socket___73 *, struct page___292 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___73 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___72 *, int);
		struct {
			void (*set_peek_off)(struct sock___72 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___181)(struct file___293 *, wait_queue_head_t *, struct poll_table_struct___179 *);

struct poll_table_struct___179 {
	poll_queue_proc___181 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___80(struct kiocb___80 *, struct io_event *);

struct kiocb___80 {
	atomic_t ki_users;
	struct file___293 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___80 *ki_cancel;
	void (*ki_dtor)(struct kiocb___80 *);
	union {
		void *user;
		struct task_struct___294 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___98;

struct ctl_table_set___98;

struct ctl_dir___98;

struct ctl_node___98;

struct ctl_table_header___98 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___98 *root;
	struct ctl_table_set___98 *set;
	struct ctl_dir___98 *parent;
	struct ctl_node___98 *node;
};

struct ctl_dir___98 {
	struct ctl_table_header___98 header;
	struct rb_root root;
};

struct ctl_table_set___98 {
	int (*is_seen)(struct ctl_table_set___98 *);
	struct ctl_dir___98 dir;
};

struct netns_core___95 {
	struct ctl_table_header___98 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___96 {
	struct mutex___295 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___95 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___98 *ctl;
};

struct netns_ipv4___95 {
	struct ctl_table_header___98 *forw_hdr;
	struct ctl_table_header___98 *frags_hdr;
	struct ctl_table_header___98 *ipv4_hdr;
	struct ctl_table_header___98 *route_hdr;
	struct ctl_table_header___98 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___72 *fibnl;
	struct sock___72 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___95 {
	struct ctl_table_header___98 *hdr;
	struct ctl_table_header___98 *route_hdr;
	struct ctl_table_header___98 *icmp_hdr;
	struct ctl_table_header___98 *frags_hdr;
	struct ctl_table_header___98 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___83;

struct neighbour___73;

struct dst_ops___97 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___97 *);
	struct dst_entry___73 * (*check)(struct dst_entry___73 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___73 *);
	unsigned int (*mtu)(const struct dst_entry___73 *);
	u32 * (*cow_metrics)(struct dst_entry___73 *, long unsigned int);
	void (*destroy)(struct dst_entry___73 *);
	void (*ifdown)(struct dst_entry___73 *, struct net_device___83 *, int);
	struct dst_entry___73 * (*negative_advice)(struct dst_entry___73 *);
	void (*link_failure)(struct sk_buff___85 *);
	void (*update_pmtu)(struct dst_entry___73 *, struct sock___72 *, struct sk_buff___85 *, u32);
	void (*redirect)(struct dst_entry___73 *, struct sock___72 *, struct sk_buff___85 *);
	int (*local_out)(struct sk_buff___85 *);
	struct neighbour___73 * (*neigh_lookup)(const struct dst_entry___73 *, struct sk_buff___85 *, const void *);
	struct kmem_cache___276 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___21;

struct fib6_table___21;

struct netns_ipv6___97 {
	struct netns_sysctl_ipv6___95 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___21 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___21 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___97 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___21 *ip6_prohibit_entry;
	struct rt6_info___21 *ip6_blk_hole_entry;
	struct fib6_table___21 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___72 **icmp_sk;
	struct sock___72 *ndisc_sk;
	struct sock___72 *tcp_sk;
	struct sock___72 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___95 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___98 *sysctl_header;
	struct sock___72 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___72 {
	struct sock___72 *v4_ctl_sk;
	struct sock___72 *v6_ctl_sk;
};

struct netns_nf___95 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___98 *nf_log_dir_header;
};

struct nf_proto_net___95 {
	struct ctl_table_header___98 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___95 {
	struct nf_proto_net___95 pn;
	unsigned int timeout;
};

struct nf_tcp_net___95 {
	struct nf_proto_net___95 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___95 {
	struct nf_proto_net___95 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___95 {
	struct nf_proto_net___95 pn;
	unsigned int timeout;
};

struct nf_ip_net___95 {
	struct nf_generic_net___95 generic;
	struct nf_tcp_net___95 tcp;
	struct nf_udp_net___95 udp;
	struct nf_icmp_net___95 icmp;
	struct nf_icmp_net___95 icmpv6;
};

struct netns_ct___96 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___98 *sysctl_header;
	struct ctl_table_header___98 *acct_sysctl_header;
	struct ctl_table_header___98 *tstamp_sysctl_header;
	struct ctl_table_header___98 *event_sysctl_header;
	struct ctl_table_header___98 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___276 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___95 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___95 {
	struct netns_sysctl_ipv6___95 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___97 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___72 *nlsk;
	struct sock___72 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___98 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___97 xfrm4_dst_ops;
	struct dst_ops___97 xfrm6_dst_ops;
};

struct net___97 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___98 sysctls;
	struct sock___72 *rtnl;
	struct sock___72 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___83 *loopback_dev;
	struct netns_core___95 core;
	struct netns_mib mib;
	struct netns_packet___96 packet;
	struct netns_unix___95 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___95 ipv4;
	struct netns_ipv6___97 ipv6;
	struct netns_sctp___95 sctp;
	struct netns_dccp___72 dccp;
	struct netns_nf___95 nf;
	struct netns_xt xt;
	struct netns_ct___96 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___95 nf_frag;
	struct sock___72 *nfnl;
	struct sock___72 *nfnl_stash;
	struct sk_buff_head___84 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___97 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___72 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___72 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___295 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___295 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___293;

struct seq_file___218;

struct file_operations___293 {
	struct module *owner;
	loff_t (*llseek)(struct file___293 *, loff_t, int);
	ssize_t (*read)(struct file___293 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___293 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___80 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___80 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___293 *, void *, filldir_t);
	unsigned int (*poll)(struct file___293 *, struct poll_table_struct___179 *);
	long int (*unlocked_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___293 *, struct vm_area_struct___301 *);
	int (*open)(struct inode___293 *, struct file___293 *);
	int (*flush)(struct file___293 *, fl_owner_t);
	int (*release)(struct inode___293 *, struct file___293 *);
	int (*fsync)(struct file___293 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___80 *, int);
	int (*fasync)(int, struct file___293 *, int);
	int (*lock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*sendpage)(struct file___293 *, struct page___292 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___293 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___293 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___293 *, long int, struct file_lock___293 **, void **);
		struct {
			int (*setlease)(struct file___293 *, long int, struct file_lock___293 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___293 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___218 *, struct file___293 *);
};

struct dev_pm_qos___94;

struct dev_pm_info___94 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___94 *qos;
};

struct dma_map_ops___156;

struct dev_archdata___156 {
	struct dma_map_ops___156 *dma_ops;
	void *iommu;
};

struct device_type___291;

struct bus_type___291;

struct device_driver___291;

struct dev_pm_domain___291;

struct class___291;

struct attribute_group___253;

struct device_rh___291;

struct device___291 {
	struct device___291 *parent;
	struct device_private *p;
	struct kobject___75 kobj;
	const char *init_name;
	const struct device_type___291 *type;
	struct mutex___295 mutex;
	struct bus_type___291 *bus;
	struct device_driver___291 *driver;
	void *platform_data;
	struct dev_pm_info___94 power;
	struct dev_pm_domain___291 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___156 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___291 *class;
	const struct attribute_group___253 **groups;
	void (*release)(struct device___291 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___291 *device_rh;
};

struct kobj_ns_type_operations___72 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___72 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___255;

struct attribute_group___253 {
	const char *name;
	umode_t (*is_visible)(struct kobject___75 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___255 **bin_attrs;
};

struct bin_attribute___255 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___293 *, struct kobject___75 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___293 *, struct kobject___75 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	int (*mmap)(struct file___293 *, struct kobject___75 *, struct bin_attribute___255 *, struct vm_area_struct___301 *);
};

struct sysfs_ops___75 {
	ssize_t (*show)(struct kobject___75 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___75 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___75 *, const struct attribute *);
};

struct kset_uevent_ops___75;

struct kset___75 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___75 kobj;
	const struct kset_uevent_ops___75 *uevent_ops;
};

struct kobj_type___75 {
	void (*release)(struct kobject___75 *);
	const struct sysfs_ops___75 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___72 * (*child_ns_type)(struct kobject___75 *);
	const void * (*namespace)(struct kobject___75 *);
};

struct kset_uevent_ops___75 {
	int (* const filter)(struct kset___75 *, struct kobject___75 *);
	const char * (* const name)(struct kset___75 *, struct kobject___75 *);
	int (* const uevent)(struct kset___75 *, struct kobject___75 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___291 {
	int (*prepare)(struct device___291 *);
	void (*complete)(struct device___291 *);
	int (*suspend)(struct device___291 *);
	int (*resume)(struct device___291 *);
	int (*freeze)(struct device___291 *);
	int (*thaw)(struct device___291 *);
	int (*poweroff)(struct device___291 *);
	int (*restore)(struct device___291 *);
	int (*suspend_late)(struct device___291 *);
	int (*resume_early)(struct device___291 *);
	int (*freeze_late)(struct device___291 *);
	int (*thaw_early)(struct device___291 *);
	int (*poweroff_late)(struct device___291 *);
	int (*restore_early)(struct device___291 *);
	int (*suspend_noirq)(struct device___291 *);
	int (*resume_noirq)(struct device___291 *);
	int (*freeze_noirq)(struct device___291 *);
	int (*thaw_noirq)(struct device___291 *);
	int (*poweroff_noirq)(struct device___291 *);
	int (*restore_noirq)(struct device___291 *);
	int (*runtime_suspend)(struct device___291 *);
	int (*runtime_resume)(struct device___291 *);
	int (*runtime_idle)(struct device___291 *);
};

struct dev_pm_qos_request___95;

struct dev_pm_qos___94 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___95 *latency_req;
	struct dev_pm_qos_request___95 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___95 *latency_tolerance_req;
};

struct dev_pm_info_rh___291 {
	void (*set_latency_tolerance)(struct device___291 *, s32);
};

struct dev_pm_domain___291 {
	struct dev_pm_ops___291 ops;
};

struct zone___294;

struct lruvec___294 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___294 *zone;
};

struct pglist_data___294;

struct zone___294 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___294 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___294 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___294 {
	struct zone___294 *zone;
	int zone_idx;
};

struct zonelist___294 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___294 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___294 {
	struct zone___294 node_zones[4];
	struct zonelist___294 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___294 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___217;

struct x86_io_apic_ops___217 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___217 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___217;

struct irq_data___217 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___217 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___294 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___294 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___156 {
	void * (*alloc)(struct device___291 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___291 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___291 *, struct vm_area_struct___301 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___291 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___291 *, struct page___292 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___291 *, dma_addr_t);
	int (*dma_supported)(struct device___291 *, u64);
	int (*set_dma_mask)(struct device___291 *, u64);
	int is_phys;
};

struct bus_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___291 *, char *);
	ssize_t (*store)(struct bus_type___291 *, const char *, size_t);
};

struct device_attribute___291;

struct driver_attribute___291;

struct bus_type___291 {
	const char *name;
	const char *dev_name;
	struct device___291 *dev_root;
	struct bus_attribute___291 *bus_attrs;
	struct device_attribute___291 *dev_attrs;
	struct driver_attribute___291 *drv_attrs;
	const struct attribute_group___253 **bus_groups;
	const struct attribute_group___253 **dev_groups;
	const struct attribute_group___253 **drv_groups;
	int (*match)(struct device___291 *, struct device_driver___291 *);
	int (*uevent)(struct device___291 *, struct kobj_uevent_env *);
	int (*probe)(struct device___291 *);
	int (*remove)(struct device___291 *);
	void (*shutdown)(struct device___291 *);
	int (*online)(struct device___291 *);
	int (*offline)(struct device___291 *);
	int (*suspend)(struct device___291 *, pm_message_t);
	int (*resume)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct device___291 *, struct device_attribute___291 *, char *);
	ssize_t (*store)(struct device___291 *, struct device_attribute___291 *, const char *, size_t);
};

struct driver_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___291 *, char *);
	ssize_t (*store)(struct device_driver___291 *, const char *, size_t);
};

struct device_driver___291 {
	const char *name;
	struct bus_type___291 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___291 *);
	int (*remove)(struct device___291 *);
	void (*shutdown)(struct device___291 *);
	int (*suspend)(struct device___291 *, pm_message_t);
	int (*resume)(struct device___291 *);
	const struct attribute_group___253 **groups;
	const struct dev_pm_ops___291 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___291 {
	const char *name;
	const struct attribute_group___253 **groups;
	int (*uevent)(struct device___291 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___291 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
};

struct class_attribute___291;

struct class___291 {
	const char *name;
	struct module *owner;
	struct class_attribute___291 *class_attrs;
	struct device_attribute___291 *dev_attrs;
	const struct attribute_group___253 **dev_groups;
	struct bin_attribute___255 *dev_bin_attrs;
	struct kobject___75 *dev_kobj;
	int (*dev_uevent)(struct device___291 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___291 *, umode_t *);
	void (*class_release)(struct class___291 *);
	void (*dev_release)(struct device___291 *);
	int (*suspend)(struct device___291 *, pm_message_t);
	int (*resume)(struct device___291 *);
	const struct kobj_ns_type_operations___72 *ns_type;
	const void * (*namespace)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
	struct subsys_private *p;
};

struct class_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct class___291 *, struct class_attribute___291 *, char *);
	ssize_t (*store)(struct class___291 *, struct class_attribute___291 *, const char *, size_t);
	const void * (*namespace)(struct class___291 *, const struct class_attribute___291 *);
};

struct device_rh___291 {
	struct dev_pm_info_rh___291 power;
};

struct dev_pm_qos_request___95 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___291 *dev;
};

struct vm_fault___263 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___292 *page;
};

struct dentry_operations___293;

struct super_block___293;

struct dentry___293 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___293 *d_parent;
	struct qstr d_name;
	struct inode___293 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___293 *d_op;
	struct super_block___293 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___293;

struct dquot___293;

struct block_device___293;

struct inode___293 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___293 *i_op;
	struct super_block___293 *i_sb;
	struct address_space___293 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___295 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___293 *i_fop;
	struct file_lock___293 *i_flock;
	struct address_space___293 i_data;
	struct dquot___293 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___293 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___293 {
	int (*d_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_hash)(const struct dentry___293 *, struct qstr *);
	int (*d_compare)(const struct dentry___293 *, const struct dentry___293 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___293 *);
	void (*d_release)(struct dentry___293 *);
	void (*d_prune)(struct dentry___293 *);
	void (*d_iput)(struct dentry___293 *, struct inode___293 *);
	char * (*d_dname)(struct dentry___293 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___293 *);
	int (*d_manage)(struct dentry___293 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___293;

struct mem_dqinfo___293 {
	struct quota_format_type___293 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___293;

struct quota_info___293 {
	unsigned int flags;
	struct mutex___295 dqio_mutex;
	struct mutex___295 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___293 *files[2];
	struct mem_dqinfo___293 info[2];
	const struct quota_format_ops___293 *ops[2];
};

struct file_system_type___293;

struct super_operations___293;

struct dquot_operations___293;

struct quotactl_ops___293;

struct xattr_handler___189;

struct super_block___293 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___293 *s_type;
	const struct super_operations___293 *s_op;
	const struct dquot_operations___293 *dq_op;
	const struct quotactl_ops___293 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___293 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___189 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___293 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___293 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___295 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___293 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___293 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___293 *bd_inode;
	struct super_block___293 *bd_super;
	struct mutex___295 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___293 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___295 bd_fsfreeze_mutex;
};

struct cgroup___188;

struct cgroup_subsys_state___188 {
	struct cgroup___188 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___293 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___293 *ia_file;
};

struct dquot___293 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___295 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___293 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___293 {
	int qf_fmt_id;
	const struct quota_format_ops___293 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___293 *qf_next;
};

struct quota_format_ops___293 {
	int (*check_quota_file)(struct super_block___293 *, int);
	int (*read_file_info)(struct super_block___293 *, int);
	int (*write_file_info)(struct super_block___293 *, int);
	int (*free_file_info)(struct super_block___293 *, int);
	int (*read_dqblk)(struct dquot___293 *);
	int (*commit_dqblk)(struct dquot___293 *);
	int (*release_dqblk)(struct dquot___293 *);
};

struct dquot_operations___293 {
	int (*write_dquot)(struct dquot___293 *);
	struct dquot___293 * (*alloc_dquot)(struct super_block___293 *, int);
	void (*destroy_dquot)(struct dquot___293 *);
	int (*acquire_dquot)(struct dquot___293 *);
	int (*release_dquot)(struct dquot___293 *);
	int (*mark_dirty)(struct dquot___293 *);
	int (*write_info)(struct super_block___293 *, int);
	qsize_t * (*get_reserved_space)(struct inode___293 *);
};

struct quotactl_ops___293 {
	int (*quota_on)(struct super_block___293 *, int, int, struct path___293 *);
	int (*quota_on_meta)(struct super_block___293 *, int, int);
	int (*quota_off)(struct super_block___293 *, int);
	int (*quota_sync)(struct super_block___293 *, int);
	int (*get_info)(struct super_block___293 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___293 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___293 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___293 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___293 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___293 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___293 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___293 *, unsigned int);
};

struct address_space_operations___293 {
	int (*writepage)(struct page___292 *, struct writeback_control *);
	int (*readpage)(struct file___293 *, struct page___292 *);
	int (*writepages)(struct address_space___293 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___292 *);
	int (*readpages)(struct file___293 *, struct address_space___293 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___293 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___292 **, void **);
	int (*write_end)(struct file___293 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___292 *, void *);
	sector_t (*bmap)(struct address_space___293 *, sector_t);
	void (*invalidatepage)(struct page___292 *, long unsigned int);
	int (*releasepage)(struct page___292 *, gfp_t);
	void (*freepage)(struct page___292 *);
	ssize_t (*direct_IO)(int, struct kiocb___80 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___293 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___293 *, struct page___292 *, struct page___292 *, enum migrate_mode);
	int (*launder_page)(struct page___292 *);
	int (*is_partially_uptodate)(struct page___292 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___292 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___293 *, struct page___292 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___293 *, sector_t *);
	void (*swap_deactivate)(struct file___293 *);
	void (*invalidatepage_range)(struct page___292 *, unsigned int, unsigned int);
};

struct inode_operations___293 {
	struct dentry___293 * (*lookup)(struct inode___293 *, struct dentry___293 *, unsigned int);
	void * (*follow_link)(struct dentry___293 *, struct nameidata *);
	int (*permission)(struct inode___293 *, int);
	struct posix_acl * (*get_acl)(struct inode___293 *, int);
	int (*readlink)(struct dentry___293 *, char *, int);
	void (*put_link)(struct dentry___293 *, struct nameidata *, void *);
	int (*create)(struct inode___293 *, struct dentry___293 *, umode_t, bool);
	int (*link)(struct dentry___293 *, struct inode___293 *, struct dentry___293 *);
	int (*unlink)(struct inode___293 *, struct dentry___293 *);
	int (*symlink)(struct inode___293 *, struct dentry___293 *, const char *);
	int (*mkdir)(struct inode___293 *, struct dentry___293 *, umode_t);
	int (*rmdir)(struct inode___293 *, struct dentry___293 *);
	int (*mknod)(struct inode___293 *, struct dentry___293 *, umode_t, dev_t);
	int (*rename)(struct inode___293 *, struct dentry___293 *, struct inode___293 *, struct dentry___293 *);
	int (*setattr)(struct dentry___293 *, struct iattr___293 *);
	int (*getattr)(struct vfsmount *, struct dentry___293 *, struct kstat *);
	int (*setxattr)(struct dentry___293 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___293 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___293 *, char *, size_t);
	int (*removexattr)(struct dentry___293 *, const char *);
	int (*fiemap)(struct inode___293 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___293 *, struct timespec *, int);
	int (*atomic_open)(struct inode___293 *, struct dentry___293 *, struct file___293 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___293;

struct lock_manager_operations___293;

struct file_lock___293 {
	struct file_lock___293 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___293 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___293 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___293 *fl_ops;
	const struct lock_manager_operations___293 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___293 {
	void (*fl_copy_lock)(struct file_lock___293 *, struct file_lock___293 *);
	void (*fl_release_private)(struct file_lock___293 *);
};

struct lock_manager_operations___293 {
	int (*lm_compare_owner)(struct file_lock___293 *, struct file_lock___293 *);
	long unsigned int (*lm_owner_key)(struct file_lock___293 *);
	void (*lm_notify)(struct file_lock___293 *);
	int (*lm_grant)(struct file_lock___293 *, struct file_lock___293 *, int);
	void (*lm_break)(struct file_lock___293 *);
	int (*lm_change)(struct file_lock___293 **, int);
};

struct file_system_type___293 {
	const char *name;
	int fs_flags;
	struct dentry___293 * (*mount)(struct file_system_type___293 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___293 *);
	struct module *owner;
	struct file_system_type___293 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___293 {
	struct inode___293 * (*alloc_inode)(struct super_block___293 *);
	void (*destroy_inode)(struct inode___293 *);
	void (*dirty_inode)(struct inode___293 *, int);
	int (*write_inode)(struct inode___293 *, struct writeback_control *);
	int (*drop_inode)(struct inode___293 *);
	void (*evict_inode)(struct inode___293 *);
	void (*put_super)(struct super_block___293 *);
	int (*sync_fs)(struct super_block___293 *, int);
	int (*freeze_fs)(struct super_block___293 *);
	int (*unfreeze_fs)(struct super_block___293 *);
	int (*statfs)(struct dentry___293 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___293 *, int *, char *);
	void (*umount_begin)(struct super_block___293 *);
	int (*show_options)(struct seq_file___218 *, struct dentry___293 *);
	int (*show_devname)(struct seq_file___218 *, struct dentry___293 *);
	int (*show_path)(struct seq_file___218 *, struct dentry___293 *);
	int (*show_stats)(struct seq_file___218 *, struct dentry___293 *);
	ssize_t (*quota_read)(struct super_block___293 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___293 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___293 *);
	int (*bdev_try_to_free_page)(struct super_block___293 *, struct page___292 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___293 *);
	void (*free_cached_objects)(struct super_block___293 *, int);
};

struct xattr_handler___189 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___293 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___293 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___293 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___218;

struct seq_file___218 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___295 lock;
	const struct seq_operations___218 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_node___98 {
	struct rb_node node;
	struct ctl_table_header___98 *header;
};

struct ctl_table_root___98 {
	struct ctl_table_set___98 default_set;
	struct ctl_table_set___98 * (*lookup)(struct ctl_table_root___98 *, struct nsproxy___173 *);
	int (*permissions)(struct ctl_table_header___98 *, struct ctl_table *);
};

struct nsproxy___173 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___97 *net_ns;
};

struct signal_struct___294 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___294 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___294 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___295 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___188 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___188 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___275 {
	void **freelist;
	long unsigned int tid;
	struct page___292 *page;
	struct page___292 *partial;
};

struct memcg_cache_params___276 {
	bool is_root_cache;
	union {
		struct kmem_cache___276 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___276 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___83 {
	atomic_t use;
	unsigned int mask;
	struct net_device___83 *physindev;
	struct net_device___83 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___83(struct sk_buff___85 **);

struct net_device_ops___83;

struct ethtool_ops___83;

struct header_ops___83;

struct in_device___15;

struct inet6_dev___47;

struct netdev_rx_queue___83;

struct netdev_queue___83;

struct Qdisc___9;

struct rtnl_link_ops___74;

struct dcbnl_rtnl_ops___83;

struct net_device___83 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___83 *netdev_ops;
	const struct ethtool_ops___83 *ethtool_ops;
	const struct header_ops___83 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___75 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___15 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___47 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___83 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___83 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___83 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___83 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___9 *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___83 = 0,
		NETREG_REGISTERED___83 = 1,
		NETREG_UNREGISTERING___83 = 2,
		NETREG_UNREGISTERED___83 = 3,
		NETREG_RELEASED___83 = 4,
		NETREG_DUMMY___83 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___83 = 0,
		RTNL_LINK_INITIALIZING___83 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___83 *);
	struct netpoll_info *npinfo;
	struct net___97 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___291 dev;
	const struct attribute_group___253 *sysfs_groups[4];
	const struct rtnl_link_ops___74 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___83 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___85 {
	struct sk_buff___85 *next;
	struct sk_buff___85 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___72 *sk;
	struct net_device___83 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___85 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___83 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___83 {
	int (*get_settings)(struct net_device___83 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___83 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___83 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___83 *);
	void (*get_regs)(struct net_device___83 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___83 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___83 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___83 *);
	void (*set_msglevel)(struct net_device___83 *, u32);
	int (*nway_reset)(struct net_device___83 *);
	u32 (*get_link)(struct net_device___83 *);
	int (*get_eeprom_len)(struct net_device___83 *);
	int (*get_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___83 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___83 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___83 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___83 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___83 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___83 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___83 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___83 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___83 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___83 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___83 *);
	void (*complete)(struct net_device___83 *);
	u32 (*get_priv_flags)(struct net_device___83 *);
	int (*set_priv_flags)(struct net_device___83 *, u32);
	int (*get_sset_count)(struct net_device___83 *, int);
	int (*get_rxnfc)(struct net_device___83 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___83 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___83 *, struct ethtool_flash *);
	int (*reset)(struct net_device___83 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___83 *);
	int (*get_rxfh_indir)(struct net_device___83 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___83 *, const u32 *);
	void (*get_channels)(struct net_device___83 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___83 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___83 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___83 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___83 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___83 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___83 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___83 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___83 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___83 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___83 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___83 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___42;

struct dst_entry___73 {
	struct callback_head callback_head;
	struct dst_entry___73 *child;
	struct net_device___83 *dev;
	struct dst_ops___97 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___73 *path;
	struct dst_entry___73 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___85 *);
	union {
		int (*output)(struct sock___72 *, struct sk_buff___85 *);
		struct {
			int (*output)(struct sk_buff___85 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___73 *next;
		struct rtable___42 *rt_next;
		struct rt6_info___21 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___73;

struct neigh_parms___73;

struct neigh_ops___73;

struct neighbour___73 {
	struct neighbour___73 *next;
	struct neigh_table___73 *tbl;
	struct neigh_parms___73 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___84 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___73 *, struct sk_buff___85 *);
	const struct neigh_ops___73 *ops;
	struct callback_head rcu;
	struct net_device___83 *dev;
	u8 primary_key[0];
};

struct fib6_node___21;

struct rt6_info___21 {
	struct dst_entry___73 dst;
	struct fib6_table___21 *rt6i_table;
	struct fib6_node___21 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___47 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___21 {
	struct fib6_node___21 *parent;
	struct fib6_node___21 *left;
	struct fib6_node___21 *right;
	struct rt6_info___21 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___21 *rr_ptr;
};

struct fib6_table___21 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___21 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___98 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___85 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___85 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___97 *, struct dst_entry___73 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___85 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___85 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___217 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___217 *);
	void (*irq_shutdown)(struct irq_data___217 *);
	void (*irq_enable)(struct irq_data___217 *);
	void (*irq_disable)(struct irq_data___217 *);
	void (*irq_ack)(struct irq_data___217 *);
	void (*irq_mask)(struct irq_data___217 *);
	void (*irq_mask_ack)(struct irq_data___217 *);
	void (*irq_unmask)(struct irq_data___217 *);
	void (*irq_eoi)(struct irq_data___217 *);
	int (*irq_set_affinity)(struct irq_data___217 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___217 *);
	int (*irq_set_type)(struct irq_data___217 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___217 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___217 *);
	void (*irq_bus_sync_unlock)(struct irq_data___217 *);
	void (*irq_cpu_online)(struct irq_data___217 *);
	void (*irq_cpu_offline)(struct irq_data___217 *);
	void (*irq_suspend)(struct irq_data___217 *);
	void (*irq_resume)(struct irq_data___217 *);
	void (*irq_pm_shutdown)(struct irq_data___217 *);
	void (*irq_print_chip)(struct irq_data___217 *, struct seq_file___218 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___217 *, void *);
	long unsigned int flags;
};

struct seq_operations___218 {
	void * (*start)(struct seq_file___218 *, loff_t *);
	void (*stop)(struct seq_file___218 *, void *);
	void * (*next)(struct seq_file___218 *, void *, loff_t *);
	int (*show)(struct seq_file___218 *, void *);
};

struct seq_net_private___14 {
	struct net___97 *net;
};

struct pernet_operations___29 {
	struct list_head list;
	int (*init)(struct net___97 *);
	void (*exit)(struct net___97 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___83 {
	int (*ieee_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___83 *);
	u8 (*setstate)(struct net_device___83 *, u8);
	void (*getpermhwaddr)(struct net_device___83 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___83 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___83 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___83 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___83 *, int, u8 *);
	void (*setpfccfg)(struct net_device___83 *, int, u8);
	void (*getpfccfg)(struct net_device___83 *, int, u8 *);
	u8 (*setall)(struct net_device___83 *);
	u8 (*getcap)(struct net_device___83 *, int, u8 *);
	int (*getnumtcs)(struct net_device___83 *, int, u8 *);
	int (*setnumtcs)(struct net_device___83 *, int, u8);
	u8 (*getpfcstate)(struct net_device___83 *);
	void (*setpfcstate)(struct net_device___83 *, u8);
	void (*getbcncfg)(struct net_device___83 *, int, u32 *);
	void (*setbcncfg)(struct net_device___83 *, int, u32);
	void (*getbcnrp)(struct net_device___83 *, int, u8 *);
	void (*setbcnrp)(struct net_device___83 *, int, u8);
	u8 (*setapp)(struct net_device___83 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___83 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___83 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___83 *, int, u8);
	u8 (*getdcbx)(struct net_device___83 *);
	u8 (*setdcbx)(struct net_device___83 *, u8);
	int (*peer_getappinfo)(struct net_device___83 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___83 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___83 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___83 *, struct cee_pfc *);
};

struct cgroupfs_root___188;

struct cgroup___188 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___188 *parent;
	struct dentry___293 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___188 *subsys[11];
	struct cgroupfs_root___188 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___295 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___188 {
	struct super_block___293 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___188 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___124 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___293 *, struct file___293 *);
	ssize_t (*read)(struct cgroup___188 *, struct cftype___124 *, struct file___293 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___188 *, struct cftype___124 *);
	s64 (*read_s64)(struct cgroup___188 *, struct cftype___124 *);
	int (*read_map)(struct cgroup___188 *, struct cftype___124 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___188 *, struct cftype___124 *, struct seq_file___218 *);
	ssize_t (*write)(struct cgroup___188 *, struct cftype___124 *, struct file___293 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___188 *, struct cftype___124 *, u64);
	int (*write_s64)(struct cgroup___188 *, struct cftype___124 *, s64);
	int (*write_string)(struct cgroup___188 *, struct cftype___124 *, const char *);
	int (*trigger)(struct cgroup___188 *, unsigned int);
	int (*release)(struct inode___293 *, struct file___293 *);
	int (*register_event)(struct cgroup___188 *, struct cftype___124 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___188 *, struct cftype___124 *, struct eventfd_ctx *);
};

struct cftype_set___120 {
	struct list_head node;
	struct cftype___124 *cfts;
};

struct task_and_cgroup___120 {
	struct task_struct___294 *task;
	struct cgroup___188 *cgrp;
	struct css_set___188 *cg;
};

struct cgroup_taskset___120 {
	struct task_and_cgroup___120 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___188 *cur_cgrp;
};

struct cgroup_subsys___120 {
	struct cgroup_subsys_state___188 * (*css_alloc)(struct cgroup___188 *);
	int (*css_online)(struct cgroup___188 *);
	void (*css_offline)(struct cgroup___188 *);
	void (*css_free)(struct cgroup___188 *);
	int (*can_attach)(struct cgroup___188 *, struct cgroup_taskset___120 *);
	void (*cancel_attach)(struct cgroup___188 *, struct cgroup_taskset___120 *);
	void (*attach)(struct cgroup___188 *, struct cgroup_taskset___120 *);
	void (*fork)(struct task_struct___294 *);
	void (*exit)(struct cgroup___188 *, struct cgroup___188 *, struct task_struct___294 *);
	void (*bind)(struct cgroup___188 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___188 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___124 *base_cftypes;
	struct cftype_set___120 base_cftset;
	struct module *module;
};

struct request_sock_ops___56;

struct request_sock___57 {
	struct sock_common___72 __req_common;
	struct request_sock___57 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___56 *rsk_ops;
	struct sock___72 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_skb_parms___12 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___72 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___85 {
	struct sk_buff___85 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___85 *, struct netlink_callback___85 *);
	int (*done)(struct netlink_callback___85 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

enum {
	IFLA_INET6_UNSPEC = 0,
	IFLA_INET6_FLAGS = 1,
	IFLA_INET6_CONF = 2,
	IFLA_INET6_STATS = 3,
	IFLA_INET6_MCAST = 4,
	IFLA_INET6_CACHEINFO = 5,
	IFLA_INET6_ICMP6STATS = 6,
	IFLA_INET6_TOKEN = 7,
	IFLA_INET6_ADDR_GEN_MODE = 8,
	__IFLA_INET6_MAX = 9,
};

enum in6_addr_gen_mode {
	IN6_ADDR_GEN_MODE_EUI64 = 0,
	IN6_ADDR_GEN_MODE_NONE = 1,
};

struct ifla_cacheinfo {
	__u32 max_reasm_len;
	__u32 tstamp;
	__u32 reachable_time;
	__u32 retrans_time;
};

struct header_ops___83 {
	int (*create)(struct sk_buff___85 *, struct net_device___83 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___85 *, unsigned char *);
	int (*rebuild)(struct sk_buff___85 *);
	int (*cache)(const struct neighbour___73 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___83 *, const unsigned char *);
};

struct napi_struct___83 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___83 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___83 *dev;
	struct sk_buff___85 *gro_list;
	struct sk_buff___85 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___83 {
	struct net_device___83 *dev;
	struct Qdisc___9 *qdisc;
	struct Qdisc___9 *qdisc_sleeping;
	struct kobject___75 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct Qdisc_ops___9;

struct Qdisc___9 {
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___9 *);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___9 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___9 *ops;
	struct qdisc_size_table *stab;
	struct list_head list;
	u32 handle;
	u32 parent;
	int (*reshape_fail)(struct sk_buff___85 *, struct Qdisc___9 *);
	void *u32_node;
	struct Qdisc___9 *__parent;
	struct netdev_queue___83 *dev_queue;
	struct gnet_stats_rate_est64 rate_est;
	struct Qdisc___9 *next_sched;
	struct sk_buff___85 *gso_skb;
	long unsigned int state;
	struct sk_buff_head___84 q;
	struct gnet_stats_basic_packed bstats;
	unsigned int __state;
	struct gnet_stats_queue qstats;
	struct callback_head callback_head;
	int padded;
	atomic_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t busylock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___83 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___75 kobj;
	struct net_device___83 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___83 {
	int (*ndo_init)(struct net_device___83 *);
	void (*ndo_uninit)(struct net_device___83 *);
	int (*ndo_open)(struct net_device___83 *);
	int (*ndo_stop)(struct net_device___83 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___85 *, struct net_device___83 *);
	u16 (*ndo_select_queue)(struct net_device___83 *, struct sk_buff___85 *);
	void (*ndo_change_rx_flags)(struct net_device___83 *, int);
	void (*ndo_set_rx_mode)(struct net_device___83 *);
	int (*ndo_set_mac_address)(struct net_device___83 *, void *);
	int (*ndo_validate_addr)(struct net_device___83 *);
	int (*ndo_do_ioctl)(struct net_device___83 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___83 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___83 *, int);
	int (*ndo_neigh_setup)(struct net_device___83 *, struct neigh_parms___73 *);
	void (*ndo_tx_timeout)(struct net_device___83 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___83 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___83 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___83 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___83 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___83 *);
	int (*ndo_netpoll_setup)(struct net_device___83 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___83 *);
	int (*ndo_busy_poll)(struct napi_struct___83 *);
	int (*ndo_set_vf_mac)(struct net_device___83 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___83 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___83 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___83 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___83 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___83 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___83 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___83 *, int, struct sk_buff___85 *);
	int (*ndo_setup_tc)(struct net_device___83 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___83 *);
	int (*ndo_fcoe_disable)(struct net_device___83 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___83 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___83 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___83 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___83 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___83 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___83 *, const struct sk_buff___85 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___83 *, struct net_device___83 *);
	int (*ndo_del_slave)(struct net_device___83 *, struct net_device___83 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___73 *);
	void (*ndo_neigh_destroy)(struct neighbour___73 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___85 *, struct netlink_callback___85 *, struct net_device___83 *, int);
	int (*ndo_bridge_setlink)(struct net_device___83 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___85 *, u32, u32, struct net_device___83 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___83 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___83 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___83 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___83 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___83 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___83 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___85 *, struct net_device___83 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___83 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___83 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___83 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___73 {
	struct net___97 *net;
	struct net_device___83 *dev;
	struct neigh_parms___73 *next;
	int (*neigh_setup)(struct neighbour___73 *);
	void (*neigh_cleanup)(struct neighbour___73 *);
	struct neigh_table___73 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___15;

struct in_device___15 {
	struct net_device___83 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___15 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___73 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___47;

struct ifacaddr6___47;

struct inet6_dev___47 {
	struct net_device___83 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___47 *mc_list;
	struct ifmcaddr6___47 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___47 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___73 *nd_parms;
	struct inet6_dev___47 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___74 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___83 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___97 *, struct net_device___83 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___83 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___83 *, struct list_head *);
	size_t (*get_size)(const struct net_device___83 *);
	int (*fill_info)(struct sk_buff___85 *, const struct net_device___83 *);
	size_t (*get_xstats_size)(const struct net_device___83 *);
	int (*fill_xstats)(struct sk_buff___85 *, const struct net_device___83 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___97 * (*get_link_net)(const struct net_device___83 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___83 *, struct net_device___83 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___83 *, const struct net_device___83 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___85 *, const struct net_device___83 *, const struct net_device___83 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct prefixmsg {
	unsigned char prefix_family;
	unsigned char prefix_pad1;
	short unsigned int prefix_pad2;
	int prefix_ifindex;
	unsigned char prefix_type;
	unsigned char prefix_len;
	unsigned char prefix_flags;
	unsigned char prefix_pad3;
};

enum {
	PREFIX_UNSPEC = 0,
	PREFIX_ADDRESS = 1,
	PREFIX_CACHEINFO = 2,
	__PREFIX_MAX = 3,
};

struct prefix_cacheinfo {
	__u32 preferred_time;
	__u32 valid_time;
};

struct in_ifaddr___15 {
	struct hlist_node hash;
	struct in_ifaddr___15 *ifa_next;
	struct in_device___15 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___73 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___85 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct nl_info___2 {
	struct nlmsghdr *nlh;
	struct net___97 *nl_net;
	u32 portid;
};

typedef int (*rtnl_doit_func___7)(struct sk_buff___85 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___7)(struct sk_buff___85 *, struct netlink_callback___85 *);

typedef u16 (*rtnl_calcit_func___7)(struct sk_buff___85 *, struct nlmsghdr *);

struct rtnl_af_ops___3 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___85 *, const struct net_device___83 *);
	size_t (*get_link_af_size)(const struct net_device___83 *);
	int (*validate_link_af)(const struct net_device___83 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___83 *, const struct nlattr *);
};

struct pneigh_entry___73;

struct neigh_hash_table___73;

struct neigh_table___73 {
	struct neigh_table___73 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___83 *, __u32 *);
	int (*constructor)(struct neighbour___73 *);
	int (*pconstructor)(struct pneigh_entry___73 *);
	void (*pdestructor)(struct pneigh_entry___73 *);
	void (*proxy_redo)(struct sk_buff___85 *);
	char *id;
	struct neigh_parms___73 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___84 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___73 *nht;
	struct pneigh_entry___73 **phash_buckets;
};

struct neigh_ops___73 {
	int family;
	void (*solicit)(struct neighbour___73 *, struct sk_buff___85 *);
	void (*error_report)(struct neighbour___73 *, struct sk_buff___85 *);
	int (*output)(struct neighbour___73 *, struct sk_buff___85 *);
	int (*connected_output)(struct neighbour___73 *, struct sk_buff___85 *);
};

struct pneigh_entry___73 {
	struct pneigh_entry___73 *next;
	struct net___97 *net;
	struct net_device___83 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___73 {
	struct neighbour___73 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___42 {
	struct dst_entry___73 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___53;

struct inet_hashinfo___20;

struct proto___72 {
	void (*close)(struct sock___72 *, long int);
	int (*connect)(struct sock___72 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___72 *, int);
	struct sock___72 * (*accept)(struct sock___72 *, int, int *);
	int (*ioctl)(struct sock___72 *, int, long unsigned int);
	int (*init)(struct sock___72 *);
	void (*destroy)(struct sock___72 *);
	void (*shutdown)(struct sock___72 *, int);
	int (*setsockopt)(struct sock___72 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___72 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___72 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___72 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___72 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___80 *, struct sock___72 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___80 *, struct sock___72 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___72 *, struct page___292 *, int, size_t, int);
	int (*bind)(struct sock___72 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___72 *, struct sk_buff___85 *);
	void (*release_cb)(struct sock___72 *);
	void (*mtu_reduced)(struct sock___72 *);
	void (*hash)(struct sock___72 *);
	void (*unhash)(struct sock___72 *);
	void (*rehash)(struct sock___72 *);
	int (*get_port)(struct sock___72 *, short unsigned int);
	void (*clear_sk)(struct sock___72 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___72 *);
	void (*enter_memory_pressure)(struct sock___72 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___276 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___56 *rsk_prot;
	struct timewait_sock_ops___53 *twsk_prot;
	union {
		struct inet_hashinfo___20 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___120 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___72 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___72 {
	void (*enter_memory_pressure)(struct sock___72 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___20 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___276 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___56 {
	int family;
	int obj_size;
	struct kmem_cache___276 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___72 *, struct request_sock___57 *);
	void (*send_ack)(struct sock___72 *, struct sk_buff___85 *, struct request_sock___57 *);
	void (*send_reset)(struct sock___72 *, struct sk_buff___85 *);
	void (*destructor)(struct request_sock___57 *);
	void (*syn_ack_timeout)(struct sock___72 *, struct request_sock___57 *);
};

struct timewait_sock_ops___53 {
	struct kmem_cache___276 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___72 *, struct sock___72 *, void *);
	void (*twsk_destructor)(struct sock___72 *);
};

union fwnet_hwaddr {
	u8 u[16];
	struct {
		__be64 uniq_id;
		u8 max_rec;
		u8 sspd;
		__be16 fifo_hi;
		__be32 fifo_lo;
	} uc;
};

struct in6_ifreq {
	struct in6_addr ifr6_addr;
	__u32 ifr6_prefixlen;
	int ifr6_ifindex;
};

enum {
	DEVCONF_FORWARDING = 0,
	DEVCONF_HOPLIMIT = 1,
	DEVCONF_MTU6 = 2,
	DEVCONF_ACCEPT_RA = 3,
	DEVCONF_ACCEPT_REDIRECTS = 4,
	DEVCONF_AUTOCONF = 5,
	DEVCONF_DAD_TRANSMITS = 6,
	DEVCONF_RTR_SOLICITS = 7,
	DEVCONF_RTR_SOLICIT_INTERVAL = 8,
	DEVCONF_RTR_SOLICIT_DELAY = 9,
	DEVCONF_USE_TEMPADDR = 10,
	DEVCONF_TEMP_VALID_LFT = 11,
	DEVCONF_TEMP_PREFERED_LFT = 12,
	DEVCONF_REGEN_MAX_RETRY = 13,
	DEVCONF_MAX_DESYNC_FACTOR = 14,
	DEVCONF_MAX_ADDRESSES = 15,
	DEVCONF_FORCE_MLD_VERSION = 16,
	DEVCONF_ACCEPT_RA_DEFRTR = 17,
	DEVCONF_ACCEPT_RA_PINFO = 18,
	DEVCONF_ACCEPT_RA_RTR_PREF = 19,
	DEVCONF_RTR_PROBE_INTERVAL = 20,
	DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN = 21,
	DEVCONF_PROXY_NDP = 22,
	DEVCONF_OPTIMISTIC_DAD = 23,
	DEVCONF_ACCEPT_SOURCE_ROUTE = 24,
	DEVCONF_MC_FORWARDING = 25,
	DEVCONF_DISABLE_IPV6 = 26,
	DEVCONF_ACCEPT_DAD = 27,
	DEVCONF_FORCE_TLLAO = 28,
	DEVCONF_NDISC_NOTIFY = 29,
	DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL = 30,
	DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL = 31,
	DEVCONF_MAX = 32,
};

enum {
	INET6_IFADDR_STATE_PREDAD = 0,
	INET6_IFADDR_STATE_DAD = 1,
	INET6_IFADDR_STATE_POSTDAD = 2,
	INET6_IFADDR_STATE_ERRDAD = 3,
	INET6_IFADDR_STATE_UP = 4,
	INET6_IFADDR_STATE_DEAD = 5,
};

struct inet6_ifaddr___3 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 valid_lft;
	__u32 prefered_lft;
	atomic_t refcnt;
	spinlock_t lock;
	spinlock_t state_lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u16 scope;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___47 *idev;
	struct rt6_info___21 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___3 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___47 {
	struct in6_addr mca_addr;
	struct inet6_dev___47 *idev;
	struct ifmcaddr6___47 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___47 {
	struct in6_addr aca_addr;
	struct inet6_dev___47 *aca_idev;
	struct rt6_info___21 *aca_rt;
	struct ifacaddr6___47 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct fib6_config {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u32 fc_type;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___2 fc_nlinfo;
};

struct prefix_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved: 6;
	__u8 autoconf: 1;
	__u8 onlink: 1;
	__be32 valid;
	__be32 prefered;
	__be32 reserved2;
	struct in6_addr prefix;
};

struct gnet_dump___10 {
	spinlock_t *lock;
	struct sk_buff___85 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___9;

struct Qdisc_ops___9 {
	struct Qdisc_ops___9 *next;
	const struct Qdisc_class_ops___9 *cl_ops;
	char id[16];
	int priv_size;
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___9 *);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___9 *);
	struct sk_buff___85 * (*peek)(struct Qdisc___9 *);
	unsigned int (*drop)(struct Qdisc___9 *);
	int (*init)(struct Qdisc___9 *, struct nlattr *);
	void (*reset)(struct Qdisc___9 *);
	void (*destroy)(struct Qdisc___9 *);
	int (*change)(struct Qdisc___9 *, struct nlattr *);
	void (*attach)(struct Qdisc___9 *);
	int (*dump)(struct Qdisc___9 *, struct sk_buff___85 *);
	int (*dump_stats)(struct Qdisc___9 *, struct gnet_dump___10 *);
	struct module *owner;
};

struct qdisc_walker___9;

struct tcf_proto___9;

struct Qdisc_class_ops___9 {
	struct netdev_queue___83 * (*select_queue)(struct Qdisc___9 *, struct tcmsg *);
	int (*graft)(struct Qdisc___9 *, long unsigned int, struct Qdisc___9 *, struct Qdisc___9 **);
	struct Qdisc___9 * (*leaf)(struct Qdisc___9 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___9 *, long unsigned int);
	long unsigned int (*get)(struct Qdisc___9 *, u32);
	void (*put)(struct Qdisc___9 *, long unsigned int);
	int (*change)(struct Qdisc___9 *, u32, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct Qdisc___9 *, long unsigned int);
	void (*walk)(struct Qdisc___9 *, struct qdisc_walker___9 *);
	struct tcf_proto___9 ** (*tcf_chain)(struct Qdisc___9 *, long unsigned int);
	long unsigned int (*bind_tcf)(struct Qdisc___9 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___9 *, long unsigned int);
	int (*dump)(struct Qdisc___9 *, long unsigned int, struct sk_buff___85 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___9 *, long unsigned int, struct gnet_dump___10 *);
};

struct qdisc_walker___9 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___9 *, long unsigned int, struct qdisc_walker___9 *);
};

struct tcf_proto_ops___9;

struct tcf_proto___9 {
	struct tcf_proto___9 *next;
	void *root;
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___9 *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	u32 classid;
	struct Qdisc___9 *q;
	void *data;
	const struct tcf_proto_ops___9 *ops;
};

struct tcf_proto_ops___9 {
	struct tcf_proto_ops___9 *next;
	char kind[16];
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___9 *, struct tcf_result *);
	int (*init)(struct tcf_proto___9 *);
	void (*destroy)(struct tcf_proto___9 *);
	long unsigned int (*get)(struct tcf_proto___9 *, u32);
	void (*put)(struct tcf_proto___9 *, long unsigned int);
	int (*change)(struct net___97 *, struct sk_buff___85 *, struct tcf_proto___9 *, long unsigned int, u32, struct nlattr **, long unsigned int *);
	int (*delete)(struct tcf_proto___9 *, long unsigned int);
	void (*walk)(struct tcf_proto___9 *, struct tcf_walker *);
	int (*dump)(struct tcf_proto___9 *, long unsigned int, struct sk_buff___85 *, struct tcmsg *);
	struct module *owner;
};

enum cleanup_prefix_rt_t {
	CLEANUP_PREFIX_RT_NOP = 0,
	CLEANUP_PREFIX_RT_DEL = 1,
	CLEANUP_PREFIX_RT_EXPIRE = 2,
};

enum {
	IPV6_SADDR_RULE_INIT = 0,
	IPV6_SADDR_RULE_LOCAL = 1,
	IPV6_SADDR_RULE_SCOPE = 2,
	IPV6_SADDR_RULE_PREFERRED = 3,
	IPV6_SADDR_RULE_OIF = 4,
	IPV6_SADDR_RULE_LABEL = 5,
	IPV6_SADDR_RULE_PRIVACY = 6,
	IPV6_SADDR_RULE_ORCHID = 7,
	IPV6_SADDR_RULE_PREFIX = 8,
	IPV6_SADDR_RULE_MAX = 9,
};

struct ipv6_saddr_score {
	int rule;
	int addr_type;
	struct inet6_ifaddr___3 *ifa;
	long unsigned int scorebits[1];
	int scopedist;
	int matchlen;
};

struct ipv6_saddr_dst {
	const struct in6_addr *addr;
	int ifindex;
	int scope;
	int label;
	unsigned int prefs;
};

struct if6_iter_state {
	struct seq_net_private___14 p;
	int bucket;
	int offset;
};

enum addr_type_t {
	UNICAST_ADDR = 0,
	MULTICAST_ADDR = 1,
	ANYCAST_ADDR = 2,
};

struct addrconf_sysctl_table {
	struct ctl_table_header___98 *sysctl_header;
	struct ctl_table addrconf_vars[33];
};

enum {
	DAD_PROCESS = 0,
	DAD_BEGIN = 1,
	DAD_ABORT = 2,
};

typedef int (*rtnl_doit_func___8)(struct sk_buff___75 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___8)(struct sk_buff___75 *, struct netlink_callback___75 *);

typedef u16 (*rtnl_calcit_func___8)(struct sk_buff___75 *, struct nlmsghdr *);

struct ifaddrlblmsg {
	__u8 ifal_family;
	__u8 __ifal_reserved;
	__u8 ifal_prefixlen;
	__u8 ifal_flags;
	__u32 ifal_index;
	__u32 ifal_seq;
};

enum {
	IFAL_ADDRESS = 1,
	IFAL_LABEL = 2,
	__IFAL_MAX = 3,
};

struct ip6addrlbl_entry {
	struct net___87 *lbl_net;
	struct in6_addr prefix;
	int prefixlen;
	int ifindex;
	int addrtype;
	u32 label;
	struct hlist_node list;
	atomic_t refcnt;
	struct callback_head rcu;
};

struct ip6addrlbl_table {
	struct hlist_head head;
	spinlock_t lock;
	u32 seq;
};

struct ip6addrlbl_init_table {
	const struct in6_addr *prefix;
	int prefixlen;
	u32 label;
};

struct page___293;

typedef struct page___293 *pgtable_t___293;

struct address_space___294;

struct kmem_cache___277;

struct page___293 {
	long unsigned int flags;
	struct address_space___294 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___293 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___293 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___277 *slab_cache;
		struct page___293 *first_page;
	};
	long: 64;
};

struct task_struct___295;

struct pv_cpu_ops___295 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___295 *);
	void (*end_context_switch)(struct task_struct___295 *);
};

struct mutex___296 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___295 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___288 {
	struct page___293 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___302;

struct nsproxy___174;

struct signal_struct___295;

struct css_set___189;

struct task_struct___295 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___295 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___302 *mm;
	struct mm_struct___302 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___295 *real_parent;
	struct task_struct___295 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___295 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___295 = 0,
		VTIME_USER___295 = 1,
		VTIME_SYS___295 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___174 *nsproxy;
	struct signal_struct___295 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___189 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___296 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___288 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___302 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___302 *, struct mm_struct___302 *);
	void (*dup_mmap)(struct mm_struct___302 *, struct mm_struct___302 *);
	void (*exit_mmap)(struct mm_struct___302 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___302 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___302 *);
	void (*pgd_free)(struct mm_struct___302 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___302 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___302 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___302 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___302 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___302 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___302 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___302 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___302 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___302 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___302 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___302 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___296 lock;
	void *vdso;
} mm_context_t___296;

struct xol_area___293;

struct uprobes_state___293 {
	struct xol_area___293 *xol_area;
};

struct vm_area_struct___302;

struct file___294;

struct core_state___295;

struct mm_struct___302 {
	struct vm_area_struct___302 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___302 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___302 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___296 context;
	long unsigned int flags;
	struct core_state___295 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___295 *owner;
	struct file___294 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___293 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct thread_info___130 {
	struct task_struct___295 *task;
	struct exec_domain___80 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct xol_area___293 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___293 *page;
	long unsigned int vaddr;
};

struct kset___76;

struct kobj_type___76;

struct kobject___76 {
	const char *name;
	struct list_head entry;
	struct kobject___76 *parent;
	struct kset___76 *kset;
	struct kobj_type___76 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___276;

struct memcg_cache_params___277;

struct kmem_cache___277 {
	struct kmem_cache_cpu___276 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___76 kobj;
	struct memcg_cache_params___277 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___294;

struct address_space_operations___294;

struct address_space___294 {
	struct inode___294 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___296 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___294 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___294;

struct path___294 {
	struct vfsmount *mnt;
	struct dentry___294 *dentry;
};

struct file_operations___294;

struct file___294 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___294 f_path;
	struct inode___294 *f_inode;
	const struct file_operations___294 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___294 *f_mapping;
	struct mutex___296 f_pos_lock;
};

struct vm_operations_struct___268;

struct vm_area_struct___302 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___302 *vm_next;
	struct vm_area_struct___302 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___302 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___268 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___294 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___264;

struct vm_operations_struct___268 {
	void (*open)(struct vm_area_struct___302 *);
	void (*close)(struct vm_area_struct___302 *);
	int (*fault)(struct vm_area_struct___302 *, struct vm_fault___264 *);
	int (*page_mkwrite)(struct vm_area_struct___302 *, struct vm_fault___264 *);
	int (*access)(struct vm_area_struct___302 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___302 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___302 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___302 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___302 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___295 {
	struct task_struct___295 *task;
	struct core_thread___295 *next;
};

struct core_state___295 {
	atomic_t nr_threads;
	struct core_thread___295 dumper;
	struct completion startup;
};

struct fasync_struct___294;

struct socket_wq___73 {
	wait_queue_head_t wait;
	struct fasync_struct___294 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___294 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___294 *fa_next;
	struct file___294 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___73;

struct proto_ops___73;

struct socket___74 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___73 *wq;
	struct file___294 *file;
	struct sock___73 *sk;
	const struct proto_ops___73 *ops;
};

struct proto___73;

struct net___98;

struct sock_common___73 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___73 *skc_prot;
	struct net___98 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___86;

struct sk_buff_head___85 {
	struct sk_buff___86 *next;
	struct sk_buff___86 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___74;

struct xfrm_policy___20;

struct dst_entry___74;

struct cg_proto___73;

struct sock___73 {
	struct sock_common___73 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___85 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___86 *head;
		struct sk_buff___86 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___74 *sk_filter;
	struct socket_wq___73 *sk_wq;
	struct sk_buff_head___85 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___20 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___74 *sk_rx_dst;
	struct dst_entry___74 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___85 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___85 sk_error_queue;
	struct proto___73 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___74 *sk_socket;
	void *sk_user_data;
	struct page_frag___288 sk_frag;
	struct sk_buff___86 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___73 *sk_cgrp;
	void (*sk_state_change)(struct sock___73 *);
	void (*sk_data_ready)(struct sock___73 *, int);
	void (*sk_write_space)(struct sock___73 *);
	void (*sk_error_report)(struct sock___73 *);
	int (*sk_backlog_rcv)(struct sock___73 *, struct sk_buff___86 *);
	void (*sk_destruct)(struct sock___73 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___180;

struct kiocb___81;

struct proto_ops___73 {
	int family;
	struct module *owner;
	int (*release)(struct socket___74 *);
	int (*bind)(struct socket___74 *, struct sockaddr *, int);
	int (*connect)(struct socket___74 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___74 *, struct socket___74 *);
	int (*accept)(struct socket___74 *, struct socket___74 *, int);
	int (*getname)(struct socket___74 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___294 *, struct socket___74 *, struct poll_table_struct___180 *);
	int (*ioctl)(struct socket___74 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___74 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___74 *, int);
	int (*shutdown)(struct socket___74 *, int);
	int (*setsockopt)(struct socket___74 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___74 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___74 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___74 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___81 *, struct socket___74 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___81 *, struct socket___74 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___294 *, struct socket___74 *, struct vm_area_struct___302 *);
	ssize_t (*sendpage)(struct socket___74 *, struct page___293 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___74 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___73 *, int);
		struct {
			void (*set_peek_off)(struct sock___73 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___182)(struct file___294 *, wait_queue_head_t *, struct poll_table_struct___180 *);

struct poll_table_struct___180 {
	poll_queue_proc___182 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___81(struct kiocb___81 *, struct io_event *);

struct kiocb___81 {
	atomic_t ki_users;
	struct file___294 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___81 *ki_cancel;
	void (*ki_dtor)(struct kiocb___81 *);
	union {
		void *user;
		struct task_struct___295 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___99;

struct ctl_table_set___99;

struct ctl_dir___99;

struct ctl_node___99;

struct ctl_table_header___99 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___99 *root;
	struct ctl_table_set___99 *set;
	struct ctl_dir___99 *parent;
	struct ctl_node___99 *node;
};

struct ctl_dir___99 {
	struct ctl_table_header___99 header;
	struct rb_root root;
};

struct ctl_table_set___99 {
	int (*is_seen)(struct ctl_table_set___99 *);
	struct ctl_dir___99 dir;
};

struct netns_core___96 {
	struct ctl_table_header___99 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___97 {
	struct mutex___296 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___96 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___99 *ctl;
};

struct netns_ipv4___96 {
	struct ctl_table_header___99 *forw_hdr;
	struct ctl_table_header___99 *frags_hdr;
	struct ctl_table_header___99 *ipv4_hdr;
	struct ctl_table_header___99 *route_hdr;
	struct ctl_table_header___99 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___73 *fibnl;
	struct sock___73 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___96 {
	struct ctl_table_header___99 *hdr;
	struct ctl_table_header___99 *route_hdr;
	struct ctl_table_header___99 *icmp_hdr;
	struct ctl_table_header___99 *frags_hdr;
	struct ctl_table_header___99 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___84;

struct neighbour___74;

struct dst_ops___98 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___98 *);
	struct dst_entry___74 * (*check)(struct dst_entry___74 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___74 *);
	unsigned int (*mtu)(const struct dst_entry___74 *);
	u32 * (*cow_metrics)(struct dst_entry___74 *, long unsigned int);
	void (*destroy)(struct dst_entry___74 *);
	void (*ifdown)(struct dst_entry___74 *, struct net_device___84 *, int);
	struct dst_entry___74 * (*negative_advice)(struct dst_entry___74 *);
	void (*link_failure)(struct sk_buff___86 *);
	void (*update_pmtu)(struct dst_entry___74 *, struct sock___73 *, struct sk_buff___86 *, u32);
	void (*redirect)(struct dst_entry___74 *, struct sock___73 *, struct sk_buff___86 *);
	int (*local_out)(struct sk_buff___86 *);
	struct neighbour___74 * (*neigh_lookup)(const struct dst_entry___74 *, struct sk_buff___86 *, const void *);
	struct kmem_cache___277 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___22;

struct fib6_table___22;

struct netns_ipv6___98 {
	struct netns_sysctl_ipv6___96 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___22 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___22 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___98 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___22 *ip6_prohibit_entry;
	struct rt6_info___22 *ip6_blk_hole_entry;
	struct fib6_table___22 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___73 **icmp_sk;
	struct sock___73 *ndisc_sk;
	struct sock___73 *tcp_sk;
	struct sock___73 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___96 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___99 *sysctl_header;
	struct sock___73 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___73 {
	struct sock___73 *v4_ctl_sk;
	struct sock___73 *v6_ctl_sk;
};

struct netns_nf___96 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___99 *nf_log_dir_header;
};

struct nf_proto_net___96 {
	struct ctl_table_header___99 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___96 {
	struct nf_proto_net___96 pn;
	unsigned int timeout;
};

struct nf_tcp_net___96 {
	struct nf_proto_net___96 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___96 {
	struct nf_proto_net___96 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___96 {
	struct nf_proto_net___96 pn;
	unsigned int timeout;
};

struct nf_ip_net___96 {
	struct nf_generic_net___96 generic;
	struct nf_tcp_net___96 tcp;
	struct nf_udp_net___96 udp;
	struct nf_icmp_net___96 icmp;
	struct nf_icmp_net___96 icmpv6;
};

struct netns_ct___97 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___99 *sysctl_header;
	struct ctl_table_header___99 *acct_sysctl_header;
	struct ctl_table_header___99 *tstamp_sysctl_header;
	struct ctl_table_header___99 *event_sysctl_header;
	struct ctl_table_header___99 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___277 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___96 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___96 {
	struct netns_sysctl_ipv6___96 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___98 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___73 *nlsk;
	struct sock___73 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___99 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___98 xfrm4_dst_ops;
	struct dst_ops___98 xfrm6_dst_ops;
};

struct net___98 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___99 sysctls;
	struct sock___73 *rtnl;
	struct sock___73 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___84 *loopback_dev;
	struct netns_core___96 core;
	struct netns_mib mib;
	struct netns_packet___97 packet;
	struct netns_unix___96 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___96 ipv4;
	struct netns_ipv6___98 ipv6;
	struct netns_sctp___96 sctp;
	struct netns_dccp___73 dccp;
	struct netns_nf___96 nf;
	struct netns_xt xt;
	struct netns_ct___97 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___96 nf_frag;
	struct sock___73 *nfnl;
	struct sock___73 *nfnl_stash;
	struct sk_buff_head___85 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___98 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___73 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___73 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___296 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___296 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___294;

struct seq_file___219;

struct file_operations___294 {
	struct module *owner;
	loff_t (*llseek)(struct file___294 *, loff_t, int);
	ssize_t (*read)(struct file___294 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___294 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___81 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___81 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___294 *, void *, filldir_t);
	unsigned int (*poll)(struct file___294 *, struct poll_table_struct___180 *);
	long int (*unlocked_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___294 *, struct vm_area_struct___302 *);
	int (*open)(struct inode___294 *, struct file___294 *);
	int (*flush)(struct file___294 *, fl_owner_t);
	int (*release)(struct inode___294 *, struct file___294 *);
	int (*fsync)(struct file___294 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___81 *, int);
	int (*fasync)(int, struct file___294 *, int);
	int (*lock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*sendpage)(struct file___294 *, struct page___293 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___294 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___294 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___294 *, long int, struct file_lock___294 **, void **);
		struct {
			int (*setlease)(struct file___294 *, long int, struct file_lock___294 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___294 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___219 *, struct file___294 *);
};

struct dev_pm_qos___95;

struct dev_pm_info___95 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___95 *qos;
};

struct dma_map_ops___157;

struct dev_archdata___157 {
	struct dma_map_ops___157 *dma_ops;
	void *iommu;
};

struct device_type___292;

struct bus_type___292;

struct device_driver___292;

struct dev_pm_domain___292;

struct class___292;

struct attribute_group___254;

struct device_rh___292;

struct device___292 {
	struct device___292 *parent;
	struct device_private *p;
	struct kobject___76 kobj;
	const char *init_name;
	const struct device_type___292 *type;
	struct mutex___296 mutex;
	struct bus_type___292 *bus;
	struct device_driver___292 *driver;
	void *platform_data;
	struct dev_pm_info___95 power;
	struct dev_pm_domain___292 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___157 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___292 *class;
	const struct attribute_group___254 **groups;
	void (*release)(struct device___292 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___292 *device_rh;
};

struct kobj_ns_type_operations___73 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___73 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___256;

struct attribute_group___254 {
	const char *name;
	umode_t (*is_visible)(struct kobject___76 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___256 **bin_attrs;
};

struct bin_attribute___256 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___294 *, struct kobject___76 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___294 *, struct kobject___76 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	int (*mmap)(struct file___294 *, struct kobject___76 *, struct bin_attribute___256 *, struct vm_area_struct___302 *);
};

struct sysfs_ops___76 {
	ssize_t (*show)(struct kobject___76 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___76 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___76 *, const struct attribute *);
};

struct kset_uevent_ops___76;

struct kset___76 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___76 kobj;
	const struct kset_uevent_ops___76 *uevent_ops;
};

struct kobj_type___76 {
	void (*release)(struct kobject___76 *);
	const struct sysfs_ops___76 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___73 * (*child_ns_type)(struct kobject___76 *);
	const void * (*namespace)(struct kobject___76 *);
};

struct kset_uevent_ops___76 {
	int (* const filter)(struct kset___76 *, struct kobject___76 *);
	const char * (* const name)(struct kset___76 *, struct kobject___76 *);
	int (* const uevent)(struct kset___76 *, struct kobject___76 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___292 {
	int (*prepare)(struct device___292 *);
	void (*complete)(struct device___292 *);
	int (*suspend)(struct device___292 *);
	int (*resume)(struct device___292 *);
	int (*freeze)(struct device___292 *);
	int (*thaw)(struct device___292 *);
	int (*poweroff)(struct device___292 *);
	int (*restore)(struct device___292 *);
	int (*suspend_late)(struct device___292 *);
	int (*resume_early)(struct device___292 *);
	int (*freeze_late)(struct device___292 *);
	int (*thaw_early)(struct device___292 *);
	int (*poweroff_late)(struct device___292 *);
	int (*restore_early)(struct device___292 *);
	int (*suspend_noirq)(struct device___292 *);
	int (*resume_noirq)(struct device___292 *);
	int (*freeze_noirq)(struct device___292 *);
	int (*thaw_noirq)(struct device___292 *);
	int (*poweroff_noirq)(struct device___292 *);
	int (*restore_noirq)(struct device___292 *);
	int (*runtime_suspend)(struct device___292 *);
	int (*runtime_resume)(struct device___292 *);
	int (*runtime_idle)(struct device___292 *);
};

struct dev_pm_qos_request___96;

struct dev_pm_qos___95 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___96 *latency_req;
	struct dev_pm_qos_request___96 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___96 *latency_tolerance_req;
};

struct dev_pm_info_rh___292 {
	void (*set_latency_tolerance)(struct device___292 *, s32);
};

struct dev_pm_domain___292 {
	struct dev_pm_ops___292 ops;
};

struct zone___295;

struct lruvec___295 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___295 *zone;
};

struct pglist_data___295;

struct zone___295 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___295 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___295 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___295 {
	struct zone___295 *zone;
	int zone_idx;
};

struct zonelist___295 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___295 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___295 {
	struct zone___295 node_zones[4];
	struct zonelist___295 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___295 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___218;

struct x86_io_apic_ops___218 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___218 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___218;

struct irq_data___218 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___218 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___295 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___295 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___157 {
	void * (*alloc)(struct device___292 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___292 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___292 *, struct vm_area_struct___302 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___292 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___292 *, struct page___293 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___292 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___292 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___292 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___292 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___292 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___292 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___292 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___292 *, dma_addr_t);
	int (*dma_supported)(struct device___292 *, u64);
	int (*set_dma_mask)(struct device___292 *, u64);
	int is_phys;
};

struct bus_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___292 *, char *);
	ssize_t (*store)(struct bus_type___292 *, const char *, size_t);
};

struct device_attribute___292;

struct driver_attribute___292;

struct bus_type___292 {
	const char *name;
	const char *dev_name;
	struct device___292 *dev_root;
	struct bus_attribute___292 *bus_attrs;
	struct device_attribute___292 *dev_attrs;
	struct driver_attribute___292 *drv_attrs;
	const struct attribute_group___254 **bus_groups;
	const struct attribute_group___254 **dev_groups;
	const struct attribute_group___254 **drv_groups;
	int (*match)(struct device___292 *, struct device_driver___292 *);
	int (*uevent)(struct device___292 *, struct kobj_uevent_env *);
	int (*probe)(struct device___292 *);
	int (*remove)(struct device___292 *);
	void (*shutdown)(struct device___292 *);
	int (*online)(struct device___292 *);
	int (*offline)(struct device___292 *);
	int (*suspend)(struct device___292 *, pm_message_t);
	int (*resume)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct device___292 *, struct device_attribute___292 *, char *);
	ssize_t (*store)(struct device___292 *, struct device_attribute___292 *, const char *, size_t);
};

struct driver_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___292 *, char *);
	ssize_t (*store)(struct device_driver___292 *, const char *, size_t);
};

struct device_driver___292 {
	const char *name;
	struct bus_type___292 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___292 *);
	int (*remove)(struct device___292 *);
	void (*shutdown)(struct device___292 *);
	int (*suspend)(struct device___292 *, pm_message_t);
	int (*resume)(struct device___292 *);
	const struct attribute_group___254 **groups;
	const struct dev_pm_ops___292 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___292 {
	const char *name;
	const struct attribute_group___254 **groups;
	int (*uevent)(struct device___292 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___292 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
};

struct class_attribute___292;

struct class___292 {
	const char *name;
	struct module *owner;
	struct class_attribute___292 *class_attrs;
	struct device_attribute___292 *dev_attrs;
	const struct attribute_group___254 **dev_groups;
	struct bin_attribute___256 *dev_bin_attrs;
	struct kobject___76 *dev_kobj;
	int (*dev_uevent)(struct device___292 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___292 *, umode_t *);
	void (*class_release)(struct class___292 *);
	void (*dev_release)(struct device___292 *);
	int (*suspend)(struct device___292 *, pm_message_t);
	int (*resume)(struct device___292 *);
	const struct kobj_ns_type_operations___73 *ns_type;
	const void * (*namespace)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
	struct subsys_private *p;
};

struct class_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct class___292 *, struct class_attribute___292 *, char *);
	ssize_t (*store)(struct class___292 *, struct class_attribute___292 *, const char *, size_t);
	const void * (*namespace)(struct class___292 *, const struct class_attribute___292 *);
};

struct device_rh___292 {
	struct dev_pm_info_rh___292 power;
};

struct dev_pm_qos_request___96 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___292 *dev;
};

struct vm_fault___264 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___293 *page;
};

struct dentry_operations___294;

struct super_block___294;

struct dentry___294 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___294 *d_parent;
	struct qstr d_name;
	struct inode___294 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___294 *d_op;
	struct super_block___294 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___294;

struct dquot___294;

struct block_device___294;

struct inode___294 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___294 *i_op;
	struct super_block___294 *i_sb;
	struct address_space___294 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___296 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___294 *i_fop;
	struct file_lock___294 *i_flock;
	struct address_space___294 i_data;
	struct dquot___294 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___294 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___294 {
	int (*d_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_hash)(const struct dentry___294 *, struct qstr *);
	int (*d_compare)(const struct dentry___294 *, const struct dentry___294 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___294 *);
	void (*d_release)(struct dentry___294 *);
	void (*d_prune)(struct dentry___294 *);
	void (*d_iput)(struct dentry___294 *, struct inode___294 *);
	char * (*d_dname)(struct dentry___294 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___294 *);
	int (*d_manage)(struct dentry___294 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___294;

struct mem_dqinfo___294 {
	struct quota_format_type___294 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___294;

struct quota_info___294 {
	unsigned int flags;
	struct mutex___296 dqio_mutex;
	struct mutex___296 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___294 *files[2];
	struct mem_dqinfo___294 info[2];
	const struct quota_format_ops___294 *ops[2];
};

struct file_system_type___294;

struct super_operations___294;

struct dquot_operations___294;

struct quotactl_ops___294;

struct xattr_handler___190;

struct super_block___294 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___294 *s_type;
	const struct super_operations___294 *s_op;
	const struct dquot_operations___294 *dq_op;
	const struct quotactl_ops___294 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___294 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___190 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___294 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___294 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___296 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___294 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___294 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___294 *bd_inode;
	struct super_block___294 *bd_super;
	struct mutex___296 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___294 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___296 bd_fsfreeze_mutex;
};

struct cgroup___189;

struct cgroup_subsys_state___189 {
	struct cgroup___189 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___294 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___294 *ia_file;
};

struct dquot___294 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___296 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___294 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___294 {
	int qf_fmt_id;
	const struct quota_format_ops___294 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___294 *qf_next;
};

struct quota_format_ops___294 {
	int (*check_quota_file)(struct super_block___294 *, int);
	int (*read_file_info)(struct super_block___294 *, int);
	int (*write_file_info)(struct super_block___294 *, int);
	int (*free_file_info)(struct super_block___294 *, int);
	int (*read_dqblk)(struct dquot___294 *);
	int (*commit_dqblk)(struct dquot___294 *);
	int (*release_dqblk)(struct dquot___294 *);
};

struct dquot_operations___294 {
	int (*write_dquot)(struct dquot___294 *);
	struct dquot___294 * (*alloc_dquot)(struct super_block___294 *, int);
	void (*destroy_dquot)(struct dquot___294 *);
	int (*acquire_dquot)(struct dquot___294 *);
	int (*release_dquot)(struct dquot___294 *);
	int (*mark_dirty)(struct dquot___294 *);
	int (*write_info)(struct super_block___294 *, int);
	qsize_t * (*get_reserved_space)(struct inode___294 *);
};

struct quotactl_ops___294 {
	int (*quota_on)(struct super_block___294 *, int, int, struct path___294 *);
	int (*quota_on_meta)(struct super_block___294 *, int, int);
	int (*quota_off)(struct super_block___294 *, int);
	int (*quota_sync)(struct super_block___294 *, int);
	int (*get_info)(struct super_block___294 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___294 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___294 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___294 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___294 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___294 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___294 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___294 *, unsigned int);
};

struct address_space_operations___294 {
	int (*writepage)(struct page___293 *, struct writeback_control *);
	int (*readpage)(struct file___294 *, struct page___293 *);
	int (*writepages)(struct address_space___294 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___293 *);
	int (*readpages)(struct file___294 *, struct address_space___294 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___294 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___293 **, void **);
	int (*write_end)(struct file___294 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___293 *, void *);
	sector_t (*bmap)(struct address_space___294 *, sector_t);
	void (*invalidatepage)(struct page___293 *, long unsigned int);
	int (*releasepage)(struct page___293 *, gfp_t);
	void (*freepage)(struct page___293 *);
	ssize_t (*direct_IO)(int, struct kiocb___81 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___294 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___294 *, struct page___293 *, struct page___293 *, enum migrate_mode);
	int (*launder_page)(struct page___293 *);
	int (*is_partially_uptodate)(struct page___293 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___293 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___294 *, struct page___293 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___294 *, sector_t *);
	void (*swap_deactivate)(struct file___294 *);
	void (*invalidatepage_range)(struct page___293 *, unsigned int, unsigned int);
};

struct inode_operations___294 {
	struct dentry___294 * (*lookup)(struct inode___294 *, struct dentry___294 *, unsigned int);
	void * (*follow_link)(struct dentry___294 *, struct nameidata *);
	int (*permission)(struct inode___294 *, int);
	struct posix_acl * (*get_acl)(struct inode___294 *, int);
	int (*readlink)(struct dentry___294 *, char *, int);
	void (*put_link)(struct dentry___294 *, struct nameidata *, void *);
	int (*create)(struct inode___294 *, struct dentry___294 *, umode_t, bool);
	int (*link)(struct dentry___294 *, struct inode___294 *, struct dentry___294 *);
	int (*unlink)(struct inode___294 *, struct dentry___294 *);
	int (*symlink)(struct inode___294 *, struct dentry___294 *, const char *);
	int (*mkdir)(struct inode___294 *, struct dentry___294 *, umode_t);
	int (*rmdir)(struct inode___294 *, struct dentry___294 *);
	int (*mknod)(struct inode___294 *, struct dentry___294 *, umode_t, dev_t);
	int (*rename)(struct inode___294 *, struct dentry___294 *, struct inode___294 *, struct dentry___294 *);
	int (*setattr)(struct dentry___294 *, struct iattr___294 *);
	int (*getattr)(struct vfsmount *, struct dentry___294 *, struct kstat *);
	int (*setxattr)(struct dentry___294 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___294 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___294 *, char *, size_t);
	int (*removexattr)(struct dentry___294 *, const char *);
	int (*fiemap)(struct inode___294 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___294 *, struct timespec *, int);
	int (*atomic_open)(struct inode___294 *, struct dentry___294 *, struct file___294 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___294;

struct lock_manager_operations___294;

struct file_lock___294 {
	struct file_lock___294 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___294 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___294 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___294 *fl_ops;
	const struct lock_manager_operations___294 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___294 {
	void (*fl_copy_lock)(struct file_lock___294 *, struct file_lock___294 *);
	void (*fl_release_private)(struct file_lock___294 *);
};

struct lock_manager_operations___294 {
	int (*lm_compare_owner)(struct file_lock___294 *, struct file_lock___294 *);
	long unsigned int (*lm_owner_key)(struct file_lock___294 *);
	void (*lm_notify)(struct file_lock___294 *);
	int (*lm_grant)(struct file_lock___294 *, struct file_lock___294 *, int);
	void (*lm_break)(struct file_lock___294 *);
	int (*lm_change)(struct file_lock___294 **, int);
};

struct file_system_type___294 {
	const char *name;
	int fs_flags;
	struct dentry___294 * (*mount)(struct file_system_type___294 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___294 *);
	struct module *owner;
	struct file_system_type___294 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___294 {
	struct inode___294 * (*alloc_inode)(struct super_block___294 *);
	void (*destroy_inode)(struct inode___294 *);
	void (*dirty_inode)(struct inode___294 *, int);
	int (*write_inode)(struct inode___294 *, struct writeback_control *);
	int (*drop_inode)(struct inode___294 *);
	void (*evict_inode)(struct inode___294 *);
	void (*put_super)(struct super_block___294 *);
	int (*sync_fs)(struct super_block___294 *, int);
	int (*freeze_fs)(struct super_block___294 *);
	int (*unfreeze_fs)(struct super_block___294 *);
	int (*statfs)(struct dentry___294 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___294 *, int *, char *);
	void (*umount_begin)(struct super_block___294 *);
	int (*show_options)(struct seq_file___219 *, struct dentry___294 *);
	int (*show_devname)(struct seq_file___219 *, struct dentry___294 *);
	int (*show_path)(struct seq_file___219 *, struct dentry___294 *);
	int (*show_stats)(struct seq_file___219 *, struct dentry___294 *);
	ssize_t (*quota_read)(struct super_block___294 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___294 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___294 *);
	int (*bdev_try_to_free_page)(struct super_block___294 *, struct page___293 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___294 *);
	void (*free_cached_objects)(struct super_block___294 *, int);
};

struct xattr_handler___190 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___294 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___294 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___294 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___219;

struct seq_file___219 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___296 lock;
	const struct seq_operations___219 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_node___99 {
	struct rb_node node;
	struct ctl_table_header___99 *header;
};

struct ctl_table_root___99 {
	struct ctl_table_set___99 default_set;
	struct ctl_table_set___99 * (*lookup)(struct ctl_table_root___99 *, struct nsproxy___174 *);
	int (*permissions)(struct ctl_table_header___99 *, struct ctl_table *);
};

struct nsproxy___174 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___98 *net_ns;
};

struct signal_struct___295 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___295 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___295 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___296 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___189 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___189 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___276 {
	void **freelist;
	long unsigned int tid;
	struct page___293 *page;
	struct page___293 *partial;
};

struct memcg_cache_params___277 {
	bool is_root_cache;
	union {
		struct kmem_cache___277 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___277 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___84 {
	atomic_t use;
	unsigned int mask;
	struct net_device___84 *physindev;
	struct net_device___84 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___84(struct sk_buff___86 **);

struct net_device_ops___84;

struct ethtool_ops___84;

struct header_ops___84;

struct inet6_dev___48;

struct netdev_rx_queue___84;

struct netdev_queue___84;

struct rtnl_link_ops___75;

struct dcbnl_rtnl_ops___84;

struct net_device___84 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___84 *netdev_ops;
	const struct ethtool_ops___84 *ethtool_ops;
	const struct header_ops___84 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___76 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___48 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___84 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___84 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___84 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___84 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___84 = 0,
		NETREG_REGISTERED___84 = 1,
		NETREG_UNREGISTERING___84 = 2,
		NETREG_UNREGISTERED___84 = 3,
		NETREG_RELEASED___84 = 4,
		NETREG_DUMMY___84 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___84 = 0,
		RTNL_LINK_INITIALIZING___84 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___84 *);
	struct netpoll_info *npinfo;
	struct net___98 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___292 dev;
	const struct attribute_group___254 *sysfs_groups[4];
	const struct rtnl_link_ops___75 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___84 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___20;

struct sk_buff___86 {
	struct sk_buff___86 *next;
	struct sk_buff___86 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___73 *sk;
	struct net_device___84 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___20 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___86 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___84 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___20;

struct sec_path___20 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___20 *xvec[6];
};

struct ethtool_ops___84 {
	int (*get_settings)(struct net_device___84 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___84 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___84 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___84 *);
	void (*get_regs)(struct net_device___84 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___84 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___84 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___84 *);
	void (*set_msglevel)(struct net_device___84 *, u32);
	int (*nway_reset)(struct net_device___84 *);
	u32 (*get_link)(struct net_device___84 *);
	int (*get_eeprom_len)(struct net_device___84 *);
	int (*get_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___84 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___84 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___84 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___84 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___84 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___84 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___84 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___84 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___84 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___84 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___84 *);
	void (*complete)(struct net_device___84 *);
	u32 (*get_priv_flags)(struct net_device___84 *);
	int (*set_priv_flags)(struct net_device___84 *, u32);
	int (*get_sset_count)(struct net_device___84 *, int);
	int (*get_rxnfc)(struct net_device___84 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___84 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___84 *, struct ethtool_flash *);
	int (*reset)(struct net_device___84 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___84 *);
	int (*get_rxfh_indir)(struct net_device___84 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___84 *, const u32 *);
	void (*get_channels)(struct net_device___84 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___84 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___84 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___84 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___84 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___84 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___84 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___84 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___84 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___84 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___84 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___84 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___43;

struct dst_entry___74 {
	struct callback_head callback_head;
	struct dst_entry___74 *child;
	struct net_device___84 *dev;
	struct dst_ops___98 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___74 *path;
	struct dst_entry___74 *from;
	struct xfrm_state___20 *xfrm;
	int (*input)(struct sk_buff___86 *);
	union {
		int (*output)(struct sock___73 *, struct sk_buff___86 *);
		struct {
			int (*output)(struct sk_buff___86 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___74 *next;
		struct rtable___43 *rt_next;
		struct rt6_info___22 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___74;

struct neigh_parms___74;

struct neigh_ops___74;

struct neighbour___74 {
	struct neighbour___74 *next;
	struct neigh_table___74 *tbl;
	struct neigh_parms___74 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___85 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___74 *, struct sk_buff___86 *);
	const struct neigh_ops___74 *ops;
	struct callback_head rcu;
	struct net_device___84 *dev;
	u8 primary_key[0];
};

struct fib6_node___22;

struct rt6_info___22 {
	struct dst_entry___74 dst;
	struct fib6_table___22 *rt6i_table;
	struct fib6_node___22 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___48 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___22 {
	struct fib6_node___22 *parent;
	struct fib6_node___22 *left;
	struct fib6_node___22 *right;
	struct rt6_info___22 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___22 *rr_ptr;
};

struct fib6_table___22 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___22 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___99 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___86 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___86 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___98 *, struct dst_entry___74 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___86 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___86 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___218 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___218 *);
	void (*irq_shutdown)(struct irq_data___218 *);
	void (*irq_enable)(struct irq_data___218 *);
	void (*irq_disable)(struct irq_data___218 *);
	void (*irq_ack)(struct irq_data___218 *);
	void (*irq_mask)(struct irq_data___218 *);
	void (*irq_mask_ack)(struct irq_data___218 *);
	void (*irq_unmask)(struct irq_data___218 *);
	void (*irq_eoi)(struct irq_data___218 *);
	int (*irq_set_affinity)(struct irq_data___218 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___218 *);
	int (*irq_set_type)(struct irq_data___218 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___218 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___218 *);
	void (*irq_bus_sync_unlock)(struct irq_data___218 *);
	void (*irq_cpu_online)(struct irq_data___218 *);
	void (*irq_cpu_offline)(struct irq_data___218 *);
	void (*irq_suspend)(struct irq_data___218 *);
	void (*irq_resume)(struct irq_data___218 *);
	void (*irq_pm_shutdown)(struct irq_data___218 *);
	void (*irq_print_chip)(struct irq_data___218 *, struct seq_file___219 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___218 *, void *);
	long unsigned int flags;
};

struct seq_operations___219 {
	void * (*start)(struct seq_file___219 *, loff_t *);
	void (*stop)(struct seq_file___219 *, void *);
	void * (*next)(struct seq_file___219 *, void *, loff_t *);
	int (*show)(struct seq_file___219 *, void *);
};

struct pernet_operations___30 {
	struct list_head list;
	int (*init)(struct net___98 *);
	void (*exit)(struct net___98 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___84 {
	int (*ieee_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___84 *);
	u8 (*setstate)(struct net_device___84 *, u8);
	void (*getpermhwaddr)(struct net_device___84 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___84 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___84 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___84 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___84 *, int, u8 *);
	void (*setpfccfg)(struct net_device___84 *, int, u8);
	void (*getpfccfg)(struct net_device___84 *, int, u8 *);
	u8 (*setall)(struct net_device___84 *);
	u8 (*getcap)(struct net_device___84 *, int, u8 *);
	int (*getnumtcs)(struct net_device___84 *, int, u8 *);
	int (*setnumtcs)(struct net_device___84 *, int, u8);
	u8 (*getpfcstate)(struct net_device___84 *);
	void (*setpfcstate)(struct net_device___84 *, u8);
	void (*getbcncfg)(struct net_device___84 *, int, u32 *);
	void (*setbcncfg)(struct net_device___84 *, int, u32);
	void (*getbcnrp)(struct net_device___84 *, int, u8 *);
	void (*setbcnrp)(struct net_device___84 *, int, u8);
	u8 (*setapp)(struct net_device___84 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___84 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___84 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___84 *, int, u8);
	u8 (*getdcbx)(struct net_device___84 *);
	u8 (*setdcbx)(struct net_device___84 *, u8);
	int (*peer_getappinfo)(struct net_device___84 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___84 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___84 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___84 *, struct cee_pfc *);
};

struct cgroupfs_root___189;

struct cgroup___189 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___189 *parent;
	struct dentry___294 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___189 *subsys[11];
	struct cgroupfs_root___189 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___296 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___189 {
	struct super_block___294 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___189 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___125 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___294 *, struct file___294 *);
	ssize_t (*read)(struct cgroup___189 *, struct cftype___125 *, struct file___294 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___189 *, struct cftype___125 *);
	s64 (*read_s64)(struct cgroup___189 *, struct cftype___125 *);
	int (*read_map)(struct cgroup___189 *, struct cftype___125 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___189 *, struct cftype___125 *, struct seq_file___219 *);
	ssize_t (*write)(struct cgroup___189 *, struct cftype___125 *, struct file___294 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___189 *, struct cftype___125 *, u64);
	int (*write_s64)(struct cgroup___189 *, struct cftype___125 *, s64);
	int (*write_string)(struct cgroup___189 *, struct cftype___125 *, const char *);
	int (*trigger)(struct cgroup___189 *, unsigned int);
	int (*release)(struct inode___294 *, struct file___294 *);
	int (*register_event)(struct cgroup___189 *, struct cftype___125 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___189 *, struct cftype___125 *, struct eventfd_ctx *);
};

struct cftype_set___121 {
	struct list_head node;
	struct cftype___125 *cfts;
};

struct task_and_cgroup___121 {
	struct task_struct___295 *task;
	struct cgroup___189 *cgrp;
	struct css_set___189 *cg;
};

struct cgroup_taskset___121 {
	struct task_and_cgroup___121 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___189 *cur_cgrp;
};

struct cgroup_subsys___121 {
	struct cgroup_subsys_state___189 * (*css_alloc)(struct cgroup___189 *);
	int (*css_online)(struct cgroup___189 *);
	void (*css_offline)(struct cgroup___189 *);
	void (*css_free)(struct cgroup___189 *);
	int (*can_attach)(struct cgroup___189 *, struct cgroup_taskset___121 *);
	void (*cancel_attach)(struct cgroup___189 *, struct cgroup_taskset___121 *);
	void (*attach)(struct cgroup___189 *, struct cgroup_taskset___121 *);
	void (*fork)(struct task_struct___295 *);
	void (*exit)(struct cgroup___189 *, struct cgroup___189 *, struct task_struct___295 *);
	void (*bind)(struct cgroup___189 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___189 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___125 *base_cftypes;
	struct cftype_set___121 base_cftset;
	struct module *module;
};

struct request_sock_ops___57;

struct request_sock___58 {
	struct sock_common___73 __req_common;
	struct request_sock___58 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___57 *rsk_ops;
	struct sock___73 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___20;

struct xfrm_type___20;

struct xfrm_mode___20;

struct xfrm_state___20 {
	struct net___98 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___20 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___20 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___20 *type;
	struct xfrm_mode___20 *inner_mode;
	struct xfrm_mode___20 *inner_mode_iaf;
	struct xfrm_mode___20 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___20 {
	struct sk_buff_head___85 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___20 {
	struct net___98 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___20 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_skb_parms___13 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___73 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___86 {
	struct sk_buff___86 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___86 *, struct netlink_callback___86 *);
	int (*done)(struct netlink_callback___86 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___84 {
	int (*create)(struct sk_buff___86 *, struct net_device___84 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___86 *, unsigned char *);
	int (*rebuild)(struct sk_buff___86 *);
	int (*cache)(const struct neighbour___74 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___84 *, const unsigned char *);
};

struct napi_struct___84 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___84 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___84 *dev;
	struct sk_buff___86 *gro_list;
	struct sk_buff___86 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___84 {
	struct net_device___84 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___76 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___84 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___76 kobj;
	struct net_device___84 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___84 {
	int (*ndo_init)(struct net_device___84 *);
	void (*ndo_uninit)(struct net_device___84 *);
	int (*ndo_open)(struct net_device___84 *);
	int (*ndo_stop)(struct net_device___84 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___86 *, struct net_device___84 *);
	u16 (*ndo_select_queue)(struct net_device___84 *, struct sk_buff___86 *);
	void (*ndo_change_rx_flags)(struct net_device___84 *, int);
	void (*ndo_set_rx_mode)(struct net_device___84 *);
	int (*ndo_set_mac_address)(struct net_device___84 *, void *);
	int (*ndo_validate_addr)(struct net_device___84 *);
	int (*ndo_do_ioctl)(struct net_device___84 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___84 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___84 *, int);
	int (*ndo_neigh_setup)(struct net_device___84 *, struct neigh_parms___74 *);
	void (*ndo_tx_timeout)(struct net_device___84 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___84 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___84 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___84 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___84 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___84 *);
	int (*ndo_netpoll_setup)(struct net_device___84 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___84 *);
	int (*ndo_busy_poll)(struct napi_struct___84 *);
	int (*ndo_set_vf_mac)(struct net_device___84 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___84 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___84 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___84 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___84 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___84 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___84 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___84 *, int, struct sk_buff___86 *);
	int (*ndo_setup_tc)(struct net_device___84 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___84 *);
	int (*ndo_fcoe_disable)(struct net_device___84 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___84 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___84 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___84 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___84 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___84 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___84 *, const struct sk_buff___86 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___84 *, struct net_device___84 *);
	int (*ndo_del_slave)(struct net_device___84 *, struct net_device___84 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___74 *);
	void (*ndo_neigh_destroy)(struct neighbour___74 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___86 *, struct netlink_callback___86 *, struct net_device___84 *, int);
	int (*ndo_bridge_setlink)(struct net_device___84 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___86 *, u32, u32, struct net_device___84 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___84 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___84 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___84 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___84 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___84 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___84 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___86 *, struct net_device___84 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___84 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___84 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___84 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___74 {
	struct net___98 *net;
	struct net_device___84 *dev;
	struct neigh_parms___74 *next;
	int (*neigh_setup)(struct neighbour___74 *);
	void (*neigh_cleanup)(struct neighbour___74 *);
	struct neigh_table___74 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___48;

struct ifacaddr6___48;

struct inet6_dev___48 {
	struct net_device___84 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___48 *mc_list;
	struct ifmcaddr6___48 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___48 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___74 *nd_parms;
	struct inet6_dev___48 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___75 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___84 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___98 *, struct net_device___84 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___84 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___84 *, struct list_head *);
	size_t (*get_size)(const struct net_device___84 *);
	int (*fill_info)(struct sk_buff___86 *, const struct net_device___84 *);
	size_t (*get_xstats_size)(const struct net_device___84 *);
	int (*fill_xstats)(struct sk_buff___86 *, const struct net_device___84 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___98 * (*get_link_net)(const struct net_device___84 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___84 *, struct net_device___84 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___84 *, const struct net_device___84 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___86 *, const struct net_device___84 *, const struct net_device___84 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___74 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___86 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct nl_info___3 {
	struct nlmsghdr *nlh;
	struct net___98 *nl_net;
	u32 portid;
};

typedef int (*rtnl_doit_func___9)(struct sk_buff___86 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___9)(struct sk_buff___86 *, struct netlink_callback___86 *);

typedef u16 (*rtnl_calcit_func___9)(struct sk_buff___86 *, struct nlmsghdr *);

struct pneigh_entry___74;

struct neigh_hash_table___74;

struct neigh_table___74 {
	struct neigh_table___74 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___84 *, __u32 *);
	int (*constructor)(struct neighbour___74 *);
	int (*pconstructor)(struct pneigh_entry___74 *);
	void (*pdestructor)(struct pneigh_entry___74 *);
	void (*proxy_redo)(struct sk_buff___86 *);
	char *id;
	struct neigh_parms___74 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___85 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___74 *nht;
	struct pneigh_entry___74 **phash_buckets;
};

struct neigh_ops___74 {
	int family;
	void (*solicit)(struct neighbour___74 *, struct sk_buff___86 *);
	void (*error_report)(struct neighbour___74 *, struct sk_buff___86 *);
	int (*output)(struct neighbour___74 *, struct sk_buff___86 *);
	int (*connected_output)(struct neighbour___74 *, struct sk_buff___86 *);
};

struct pneigh_entry___74 {
	struct pneigh_entry___74 *next;
	struct net___98 *net;
	struct net_device___84 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___74 {
	struct neighbour___74 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___43 {
	struct dst_entry___74 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___54;

struct inet_hashinfo___21;

struct proto___73 {
	void (*close)(struct sock___73 *, long int);
	int (*connect)(struct sock___73 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___73 *, int);
	struct sock___73 * (*accept)(struct sock___73 *, int, int *);
	int (*ioctl)(struct sock___73 *, int, long unsigned int);
	int (*init)(struct sock___73 *);
	void (*destroy)(struct sock___73 *);
	void (*shutdown)(struct sock___73 *, int);
	int (*setsockopt)(struct sock___73 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___73 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___73 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___73 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___73 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___81 *, struct sock___73 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___81 *, struct sock___73 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___73 *, struct page___293 *, int, size_t, int);
	int (*bind)(struct sock___73 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___73 *, struct sk_buff___86 *);
	void (*release_cb)(struct sock___73 *);
	void (*mtu_reduced)(struct sock___73 *);
	void (*hash)(struct sock___73 *);
	void (*unhash)(struct sock___73 *);
	void (*rehash)(struct sock___73 *);
	int (*get_port)(struct sock___73 *, short unsigned int);
	void (*clear_sk)(struct sock___73 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___73 *);
	void (*enter_memory_pressure)(struct sock___73 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___277 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___57 *rsk_prot;
	struct timewait_sock_ops___54 *twsk_prot;
	union {
		struct inet_hashinfo___21 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___121 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___73 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___73 {
	void (*enter_memory_pressure)(struct sock___73 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___21 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___277 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___57 {
	int family;
	int obj_size;
	struct kmem_cache___277 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___73 *, struct request_sock___58 *);
	void (*send_ack)(struct sock___73 *, struct sk_buff___86 *, struct request_sock___58 *);
	void (*send_reset)(struct sock___73 *, struct sk_buff___86 *);
	void (*destructor)(struct request_sock___58 *);
	void (*syn_ack_timeout)(struct sock___73 *, struct request_sock___58 *);
};

struct timewait_sock_ops___54 {
	struct kmem_cache___277 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___73 *, struct sock___73 *, void *);
	void (*twsk_destructor)(struct sock___73 *);
};

struct inet_cork___27 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___74 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___27 {
	struct inet_cork___27 base;
	struct flowi fl;
};

struct ipv6_pinfo___26;

struct inet_sock___27 {
	struct sock___73 sk;
	struct ipv6_pinfo___26 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___27 cork;
};

struct ipv6_fl_socklist___25;

struct ipv6_pinfo___26 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___25 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___86 *pktoptions;
	struct sk_buff___86 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___25;

struct ipv6_fl_socklist___25 {
	struct ipv6_fl_socklist___25 *next;
	struct ip6_flowlabel___25 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___4 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 valid_lft;
	__u32 prefered_lft;
	atomic_t refcnt;
	spinlock_t lock;
	spinlock_t state_lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u16 scope;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___48 *idev;
	struct rt6_info___22 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___4 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___48 {
	struct in6_addr mca_addr;
	struct inet6_dev___48 *idev;
	struct ifmcaddr6___48 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___48 {
	struct in6_addr aca_addr;
	struct inet6_dev___48 *aca_idev;
	struct rt6_info___22 *aca_rt;
	struct ifacaddr6___48 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct rd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	struct in6_addr dest;
	__u8 opt[0];
};

struct nd_opt_hdr {
	__u8 nd_opt_type;
	__u8 nd_opt_len;
};

struct ndisc_options {
	struct nd_opt_hdr *nd_opt_array[6];
	struct nd_opt_hdr *nd_opts_ri;
	struct nd_opt_hdr *nd_opts_ri_end;
	struct nd_opt_hdr *nd_useropts;
	struct nd_opt_hdr *nd_useropts_end;
};

struct ip6_flowlabel___25 {
	struct ip6_flowlabel___25 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___98 *fl_net;
};

struct fib6_config___2 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u32 fc_type;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___3 fc_nlinfo;
};

struct mx6_config {
	const u32 *mx;
	long unsigned int mx_valid[1];
};

typedef struct rt6_info___22 * (*pol_lookup_t)(struct net___98 *, struct fib6_table___22 *, struct flowi6 *, int);

struct route_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved_l: 3;
	__u8 route_pref: 2;
	__u8 reserved_h: 3;
	__be32 lifetime;
	__u8 prefix[0];
};

struct rt6_rtnl_dump_arg {
	struct sk_buff___86 *skb;
	struct netlink_callback___86 *cb;
	struct net___98 *net;
};

struct xfrm_replay___20 {
	void (*advance)(struct xfrm_state___20 *, __be32);
	int (*check)(struct xfrm_state___20 *, struct sk_buff___86 *, __be32);
	int (*recheck)(struct xfrm_state___20 *, struct sk_buff___86 *, __be32);
	void (*notify)(struct xfrm_state___20 *, int);
	int (*overflow)(struct xfrm_state___20 *, struct sk_buff___86 *);
};

struct xfrm_type___20 {
	char *description;
	struct module *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___20 *);
	void (*destructor)(struct xfrm_state___20 *);
	int (*input)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*output)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*reject)(struct xfrm_state___20 *, struct sk_buff___86 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___20 *, struct sk_buff___86 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___20 *, int);
};

struct xfrm_state_afinfo___20;

struct xfrm_mode___20 {
	int (*input2)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*input)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*output2)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*output)(struct xfrm_state___20 *, struct sk_buff___86 *);
	struct xfrm_state_afinfo___20 *afinfo;
	struct module *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___20 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module *owner;
	const struct xfrm_type___20 *type_map[256];
	struct xfrm_mode___20 *mode_map[5];
	int (*init_flags)(struct xfrm_state___20 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___20 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___20 **, struct xfrm_state___20 **, int);
	union {
		int (*output)(struct sock___73 *, struct sk_buff___86 *);
		struct {
			int (*output)(struct sk_buff___86 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___73 *, struct sk_buff___86 *);
		struct {
			int (*output_finish)(struct sk_buff___86 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*extract_output)(struct xfrm_state___20 *, struct sk_buff___86 *);
	int (*transport_finish)(struct sk_buff___86 *, int);
};

struct netevent_redirect {
	struct dst_entry___74 *old;
	struct dst_entry___74 *new;
	struct neighbour___74 *neigh;
	const void *daddr;
};

enum rt6_nud_state {
	RT6_NUD_FAIL_HARD = 4294967293,
	RT6_NUD_FAIL_PROBE = 4294967294,
	RT6_NUD_FAIL_DO_RR = 4294967295,
	RT6_NUD_SUCCEED = 1,
};

struct __rt6_probe_work {
	struct work_struct work;
	struct in6_addr target;
	struct net_device___84 *dev;
};

struct ip6rd_flowi {
	struct flowi6 fl6;
	struct in6_addr gateway;
};

struct arg_dev_net_ip {
	struct net_device___84 *dev;
	struct net___98 *net;
	struct in6_addr *addr;
};

struct arg_dev_net {
	struct net_device___84 *dev;
	struct net___98 *net;
};

struct rt6_mtu_change_arg {
	struct net_device___84 *dev;
	unsigned int mtu;
};

struct fib6_walker_t {
	struct list_head lh;
	struct fib6_node___22 *root;
	struct fib6_node___22 *node;
	struct rt6_info___22 *leaf;
	unsigned char state;
	unsigned char prune;
	unsigned int skip;
	unsigned int count;
	int (*func)(struct fib6_walker_t *);
	void *args;
};

enum fib_walk_state_t {
	FWS_L = 0,
	FWS_R = 1,
	FWS_C = 2,
	FWS_U = 3,
};

struct fib6_cleaner_t {
	struct fib6_walker_t w;
	struct net___98 *net;
	int (*func)(struct rt6_info___22 *, void *);
	void *arg;
};

struct lookup_args {
	int offset;
	const struct in6_addr *addr;
};

struct fib6_gc_args {
	int timeout;
	int more;
};

struct ipv6_route_iter {
	struct seq_net_private___14 p;
	struct fib6_walker_t w;
	loff_t skip;
	struct fib6_table___22 *tbl;
};

struct ipv6_mreq {
	struct in6_addr ipv6mr_multiaddr;
	int ipv6mr_ifindex;
};

struct ip6_mtuinfo {
	struct sockaddr_in6 ip6m_addr;
	__u32 ip6m_mtu;
};

struct ip6_ra_chain___2 {
	struct ip6_ra_chain___2 *next;
	struct sock___26 *sk;
	int sel;
	void (*destructor)(struct sock___26 *);
};

struct page___294;

typedef struct page___294 *pgtable_t___294;

struct address_space___295;

struct kmem_cache___278;

struct page___294 {
	long unsigned int flags;
	struct address_space___295 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___294 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___294 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___278 *slab_cache;
		struct page___294 *first_page;
	};
	long: 64;
};

struct task_struct___296;

struct pv_cpu_ops___296 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___296 *);
	void (*end_context_switch)(struct task_struct___296 *);
};

struct mutex___297 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___296 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___289 {
	struct page___294 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___303;

struct nsproxy___175;

struct signal_struct___296;

struct css_set___190;

struct task_struct___296 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___296 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___303 *mm;
	struct mm_struct___303 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___296 *real_parent;
	struct task_struct___296 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___296 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___296 = 0,
		VTIME_USER___296 = 1,
		VTIME_SYS___296 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___175 *nsproxy;
	struct signal_struct___296 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___190 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___297 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___289 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___303 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___303 *, struct mm_struct___303 *);
	void (*dup_mmap)(struct mm_struct___303 *, struct mm_struct___303 *);
	void (*exit_mmap)(struct mm_struct___303 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___303 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___303 *);
	void (*pgd_free)(struct mm_struct___303 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___303 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___303 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___303 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___303 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___303 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___303 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___303 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___303 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___303 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___303 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___303 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___297 lock;
	void *vdso;
} mm_context_t___297;

struct xol_area___294;

struct uprobes_state___294 {
	struct xol_area___294 *xol_area;
};

struct vm_area_struct___303;

struct file___295;

struct core_state___296;

struct mm_struct___303 {
	struct vm_area_struct___303 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___303 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___303 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___297 context;
	long unsigned int flags;
	struct core_state___296 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___296 *owner;
	struct file___295 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___294 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___77;

struct kobj_type___77;

struct kobject___77 {
	const char *name;
	struct list_head entry;
	struct kobject___77 *parent;
	struct kset___77 *kset;
	struct kobj_type___77 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___183;

struct module_kobject___183 {
	struct kobject___77 kobj;
	struct module___183 *mod;
	struct kobject___77 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___183;

struct module___183 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___183 mkobj;
	struct module_attribute___183 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___77 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___296 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___296;

struct lruvec___296 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___296 *zone;
};

struct pglist_data___296;

struct zone___296 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___296 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___296 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___296 {
	struct zone___296 *zone;
	int zone_idx;
};

struct zonelist___296 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___296 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___296 {
	struct zone___296 node_zones[4];
	struct zonelist___296 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___296 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___219;

struct x86_io_apic_ops___219 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___219 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___219;

struct irq_data___219 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___219 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___293;

struct dev_pm_ops___293 {
	int (*prepare)(struct device___293 *);
	void (*complete)(struct device___293 *);
	int (*suspend)(struct device___293 *);
	int (*resume)(struct device___293 *);
	int (*freeze)(struct device___293 *);
	int (*thaw)(struct device___293 *);
	int (*poweroff)(struct device___293 *);
	int (*restore)(struct device___293 *);
	int (*suspend_late)(struct device___293 *);
	int (*resume_early)(struct device___293 *);
	int (*freeze_late)(struct device___293 *);
	int (*thaw_early)(struct device___293 *);
	int (*poweroff_late)(struct device___293 *);
	int (*restore_early)(struct device___293 *);
	int (*suspend_noirq)(struct device___293 *);
	int (*resume_noirq)(struct device___293 *);
	int (*freeze_noirq)(struct device___293 *);
	int (*thaw_noirq)(struct device___293 *);
	int (*poweroff_noirq)(struct device___293 *);
	int (*restore_noirq)(struct device___293 *);
	int (*runtime_suspend)(struct device___293 *);
	int (*runtime_resume)(struct device___293 *);
	int (*runtime_idle)(struct device___293 *);
};

struct dev_pm_qos___96;

struct dev_pm_info___96 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___96 *qos;
};

struct dma_map_ops___158;

struct dev_archdata___158 {
	struct dma_map_ops___158 *dma_ops;
	void *iommu;
};

struct device_type___293;

struct bus_type___293;

struct device_driver___293;

struct dev_pm_domain___293;

struct class___293;

struct attribute_group___255;

struct device_rh___293;

struct device___293 {
	struct device___293 *parent;
	struct device_private *p;
	struct kobject___77 kobj;
	const char *init_name;
	const struct device_type___293 *type;
	struct mutex___297 mutex;
	struct bus_type___293 *bus;
	struct device_driver___293 *driver;
	void *platform_data;
	struct dev_pm_info___96 power;
	struct dev_pm_domain___293 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___158 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___17 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___293 *class;
	const struct attribute_group___255 **groups;
	void (*release)(struct device___293 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___293 *device_rh;
};

struct dev_pm_qos_request___97;

struct dev_pm_qos___96 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___97 *latency_req;
	struct dev_pm_qos_request___97 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___97 *latency_tolerance_req;
};

struct dev_pm_info_rh___293 {
	void (*set_latency_tolerance)(struct device___293 *, s32);
};

struct dev_pm_domain___293 {
	struct dev_pm_ops___293 ops;
};

struct smp_ops___296 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___296 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___100;

struct ctl_node___100 {
	struct rb_node node;
	struct ctl_table_header___100 *header;
};

struct ctl_table_root___100;

struct ctl_table_set___100;

struct ctl_dir___100;

struct ctl_table_header___100 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___100 *root;
	struct ctl_table_set___100 *set;
	struct ctl_dir___100 *parent;
	struct ctl_node___100 *node;
};

struct ctl_dir___100 {
	struct ctl_table_header___100 header;
	struct rb_root root;
};

struct ctl_table_set___100 {
	int (*is_seen)(struct ctl_table_set___100 *);
	struct ctl_dir___100 dir;
};

struct ctl_table_root___100 {
	struct ctl_table_set___100 default_set;
	struct ctl_table_set___100 * (*lookup)(struct ctl_table_root___100 *, struct nsproxy___175 *);
	int (*permissions)(struct ctl_table_header___100 *, struct ctl_table *);
};

struct net___99;

struct nsproxy___175 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___99 *net_ns;
};

struct sock___74;

struct kobj_ns_type_operations___74 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___74 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___74;

struct sock_common___74 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___74 *skc_prot;
	struct net___99 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___87;

struct sk_buff_head___86 {
	struct sk_buff___87 *next;
	struct sk_buff___87 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___75;

struct socket_wq___74;

struct dst_entry___75;

struct socket___75;

struct cg_proto___74;

struct sock___74 {
	struct sock_common___74 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___86 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___87 *head;
		struct sk_buff___87 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___75 *sk_filter;
	struct socket_wq___74 *sk_wq;
	struct sk_buff_head___86 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___75 *sk_rx_dst;
	struct dst_entry___75 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___86 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___86 sk_error_queue;
	struct proto___74 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___75 *sk_socket;
	void *sk_user_data;
	struct page_frag___289 sk_frag;
	struct sk_buff___87 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___74 *sk_cgrp;
	void (*sk_state_change)(struct sock___74 *);
	void (*sk_data_ready)(struct sock___74 *, int);
	void (*sk_write_space)(struct sock___74 *);
	void (*sk_error_report)(struct sock___74 *);
	int (*sk_backlog_rcv)(struct sock___74 *, struct sk_buff___87 *);
	void (*sk_destruct)(struct sock___74 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___257;

struct attribute_group___255 {
	const char *name;
	umode_t (*is_visible)(struct kobject___77 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___257 **bin_attrs;
};

struct bin_attribute___257 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___295 *, struct kobject___77 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___295 *, struct kobject___77 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	int (*mmap)(struct file___295 *, struct kobject___77 *, struct bin_attribute___257 *, struct vm_area_struct___303 *);
};

struct dentry___295;

struct path___295 {
	struct vfsmount *mnt;
	struct dentry___295 *dentry;
};

struct inode___295;

struct file_operations___295;

struct file___295 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___295 f_path;
	struct inode___295 *f_inode;
	const struct file_operations___295 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___295 *f_mapping;
	struct mutex___297 f_pos_lock;
};

struct vm_operations_struct___269;

struct vm_area_struct___303 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___303 *vm_next;
	struct vm_area_struct___303 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___303 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___269 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___295 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___77 {
	ssize_t (*show)(struct kobject___77 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___77 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___77 *, const struct attribute *);
};

struct kset_uevent_ops___77;

struct kset___77 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___77 kobj;
	const struct kset_uevent_ops___77 *uevent_ops;
};

struct kobj_type___77 {
	void (*release)(struct kobject___77 *);
	const struct sysfs_ops___77 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___74 * (*child_ns_type)(struct kobject___77 *);
	const void * (*namespace)(struct kobject___77 *);
};

struct kset_uevent_ops___77 {
	int (* const filter)(struct kset___77 *, struct kobject___77 *);
	const char * (* const name)(struct kset___77 *, struct kobject___77 *);
	int (* const uevent)(struct kset___77 *, struct kobject___77 *, struct kobj_uevent_env *);
};

struct module_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___183 *, struct module_kobject___183 *, char *);
	ssize_t (*store)(struct module_attribute___183 *, struct module_kobject___183 *, const char *, size_t);
	void (*setup)(struct module___183 *, const char *);
	int (*test)(struct module___183 *);
	void (*free)(struct module___183 *);
};

struct xol_area___294 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___294 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___277;

struct memcg_cache_params___278;

struct kmem_cache___278 {
	struct kmem_cache_cpu___277 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___77 kobj;
	struct memcg_cache_params___278 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___295;

struct address_space___295 {
	struct inode___295 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___297 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___295 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___265;

struct vm_operations_struct___269 {
	void (*open)(struct vm_area_struct___303 *);
	void (*close)(struct vm_area_struct___303 *);
	int (*fault)(struct vm_area_struct___303 *, struct vm_fault___265 *);
	int (*page_mkwrite)(struct vm_area_struct___303 *, struct vm_fault___265 *);
	int (*access)(struct vm_area_struct___303 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___303 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___303 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___303 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___303 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___296 {
	struct task_struct___296 *task;
	struct core_thread___296 *next;
};

struct core_state___296 {
	atomic_t nr_threads;
	struct core_thread___296 dumper;
	struct completion startup;
};

struct signal_struct___296 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___296 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___296 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___297 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___190;

struct css_set___190 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___190 *subsys[11];
	struct callback_head callback_head;
};

struct fasync_struct___295;

struct socket_wq___74 {
	wait_queue_head_t wait;
	struct fasync_struct___295 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___295 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___295 *fa_next;
	struct file___295 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___74;

struct socket___75 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___74 *wq;
	struct file___295 *file;
	struct sock___74 *sk;
	const struct proto_ops___74 *ops;
};

struct poll_table_struct___181;

struct kiocb___82;

struct proto_ops___74 {
	int family;
	struct module___183 *owner;
	int (*release)(struct socket___75 *);
	int (*bind)(struct socket___75 *, struct sockaddr *, int);
	int (*connect)(struct socket___75 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___75 *, struct socket___75 *);
	int (*accept)(struct socket___75 *, struct socket___75 *, int);
	int (*getname)(struct socket___75 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___295 *, struct socket___75 *, struct poll_table_struct___181 *);
	int (*ioctl)(struct socket___75 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___75 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___75 *, int);
	int (*shutdown)(struct socket___75 *, int);
	int (*setsockopt)(struct socket___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___75 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___75 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___75 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___82 *, struct socket___75 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___82 *, struct socket___75 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___295 *, struct socket___75 *, struct vm_area_struct___303 *);
	ssize_t (*sendpage)(struct socket___75 *, struct page___294 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___75 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___74 *, int);
		struct {
			void (*set_peek_off)(struct sock___74 *, int);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
};

typedef void (*poll_queue_proc___183)(struct file___295 *, wait_queue_head_t *, struct poll_table_struct___181 *);

struct poll_table_struct___181 {
	poll_queue_proc___183 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___82(struct kiocb___82 *, struct io_event *);

struct kiocb___82 {
	atomic_t ki_users;
	struct file___295 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___82 *ki_cancel;
	void (*ki_dtor)(struct kiocb___82 *);
	union {
		void *user;
		struct task_struct___296 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___97 {
	struct ctl_table_header___100 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___98 {
	struct mutex___297 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___97 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___100 *ctl;
};

struct netns_ipv4___97 {
	struct ctl_table_header___100 *forw_hdr;
	struct ctl_table_header___100 *frags_hdr;
	struct ctl_table_header___100 *ipv4_hdr;
	struct ctl_table_header___100 *route_hdr;
	struct ctl_table_header___100 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___74 *fibnl;
	struct sock___74 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___97 {
	struct ctl_table_header___100 *hdr;
	struct ctl_table_header___100 *route_hdr;
	struct ctl_table_header___100 *icmp_hdr;
	struct ctl_table_header___100 *frags_hdr;
	struct ctl_table_header___100 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___85;

struct neighbour___75;

struct dst_ops___99 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___99 *);
	struct dst_entry___75 * (*check)(struct dst_entry___75 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___75 *);
	unsigned int (*mtu)(const struct dst_entry___75 *);
	u32 * (*cow_metrics)(struct dst_entry___75 *, long unsigned int);
	void (*destroy)(struct dst_entry___75 *);
	void (*ifdown)(struct dst_entry___75 *, struct net_device___85 *, int);
	struct dst_entry___75 * (*negative_advice)(struct dst_entry___75 *);
	void (*link_failure)(struct sk_buff___87 *);
	void (*update_pmtu)(struct dst_entry___75 *, struct sock___74 *, struct sk_buff___87 *, u32);
	void (*redirect)(struct dst_entry___75 *, struct sock___74 *, struct sk_buff___87 *);
	int (*local_out)(struct sk_buff___87 *);
	struct neighbour___75 * (*neigh_lookup)(const struct dst_entry___75 *, struct sk_buff___87 *, const void *);
	struct kmem_cache___278 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___23;

struct fib6_table___23;

struct netns_ipv6___99 {
	struct netns_sysctl_ipv6___97 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___23 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___23 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___99 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___23 *ip6_prohibit_entry;
	struct rt6_info___23 *ip6_blk_hole_entry;
	struct fib6_table___23 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___74 **icmp_sk;
	struct sock___74 *ndisc_sk;
	struct sock___74 *tcp_sk;
	struct sock___74 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___97 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___100 *sysctl_header;
	struct sock___74 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___74 {
	struct sock___74 *v4_ctl_sk;
	struct sock___74 *v6_ctl_sk;
};

struct netns_nf___97 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___100 *nf_log_dir_header;
};

struct nf_proto_net___97 {
	struct ctl_table_header___100 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___97 {
	struct nf_proto_net___97 pn;
	unsigned int timeout;
};

struct nf_tcp_net___97 {
	struct nf_proto_net___97 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___97 {
	struct nf_proto_net___97 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___97 {
	struct nf_proto_net___97 pn;
	unsigned int timeout;
};

struct nf_ip_net___97 {
	struct nf_generic_net___97 generic;
	struct nf_tcp_net___97 tcp;
	struct nf_udp_net___97 udp;
	struct nf_icmp_net___97 icmp;
	struct nf_icmp_net___97 icmpv6;
};

struct netns_ct___98 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___100 *sysctl_header;
	struct ctl_table_header___100 *acct_sysctl_header;
	struct ctl_table_header___100 *tstamp_sysctl_header;
	struct ctl_table_header___100 *event_sysctl_header;
	struct ctl_table_header___100 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___278 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___97 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___97 {
	struct netns_sysctl_ipv6___97 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___99 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___74 *nlsk;
	struct sock___74 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___100 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___99 xfrm4_dst_ops;
	struct dst_ops___99 xfrm6_dst_ops;
};

struct net___99 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___100 sysctls;
	struct sock___74 *rtnl;
	struct sock___74 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___85 *loopback_dev;
	struct netns_core___97 core;
	struct netns_mib mib;
	struct netns_packet___98 packet;
	struct netns_unix___97 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___97 ipv4;
	struct netns_ipv6___99 ipv6;
	struct netns_sctp___97 sctp;
	struct netns_dccp___74 dccp;
	struct netns_nf___97 nf;
	struct netns_xt xt;
	struct netns_ct___98 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___97 nf_frag;
	struct sock___74 *nfnl;
	struct sock___74 *nfnl_stash;
	struct sk_buff_head___86 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___99 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___74 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___74 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___297 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___297 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___277 {
	void **freelist;
	long unsigned int tid;
	struct page___294 *page;
	struct page___294 *partial;
};

struct memcg_cache_params___278 {
	bool is_root_cache;
	union {
		struct kmem_cache___278 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___278 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___158 {
	void * (*alloc)(struct device___293 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___293 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___293 *, struct vm_area_struct___303 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___293 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___293 *, struct page___294 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___293 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___293 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___293 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___293 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___293 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___293 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___293 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___293 *, dma_addr_t);
	int (*dma_supported)(struct device___293 *, u64);
	int (*set_dma_mask)(struct device___293 *, u64);
	int is_phys;
};

struct bus_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___293 *, char *);
	ssize_t (*store)(struct bus_type___293 *, const char *, size_t);
};

struct device_attribute___293;

struct driver_attribute___293;

struct bus_type___293 {
	const char *name;
	const char *dev_name;
	struct device___293 *dev_root;
	struct bus_attribute___293 *bus_attrs;
	struct device_attribute___293 *dev_attrs;
	struct driver_attribute___293 *drv_attrs;
	const struct attribute_group___255 **bus_groups;
	const struct attribute_group___255 **dev_groups;
	const struct attribute_group___255 **drv_groups;
	int (*match)(struct device___293 *, struct device_driver___293 *);
	int (*uevent)(struct device___293 *, struct kobj_uevent_env *);
	int (*probe)(struct device___293 *);
	int (*remove)(struct device___293 *);
	void (*shutdown)(struct device___293 *);
	int (*online)(struct device___293 *);
	int (*offline)(struct device___293 *);
	int (*suspend)(struct device___293 *, pm_message_t);
	int (*resume)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct device___293 *, struct device_attribute___293 *, char *);
	ssize_t (*store)(struct device___293 *, struct device_attribute___293 *, const char *, size_t);
};

struct driver_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___293 *, char *);
	ssize_t (*store)(struct device_driver___293 *, const char *, size_t);
};

struct device_driver___293 {
	const char *name;
	struct bus_type___293 *bus;
	struct module___183 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___293 *);
	int (*remove)(struct device___293 *);
	void (*shutdown)(struct device___293 *);
	int (*suspend)(struct device___293 *, pm_message_t);
	int (*resume)(struct device___293 *);
	const struct attribute_group___255 **groups;
	const struct dev_pm_ops___293 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___293 {
	const char *name;
	const struct attribute_group___255 **groups;
	int (*uevent)(struct device___293 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___293 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
};

struct class_attribute___293;

struct class___293 {
	const char *name;
	struct module___183 *owner;
	struct class_attribute___293 *class_attrs;
	struct device_attribute___293 *dev_attrs;
	const struct attribute_group___255 **dev_groups;
	struct bin_attribute___257 *dev_bin_attrs;
	struct kobject___77 *dev_kobj;
	int (*dev_uevent)(struct device___293 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___293 *, umode_t *);
	void (*class_release)(struct class___293 *);
	void (*dev_release)(struct device___293 *);
	int (*suspend)(struct device___293 *, pm_message_t);
	int (*resume)(struct device___293 *);
	const struct kobj_ns_type_operations___74 *ns_type;
	const void * (*namespace)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
	struct subsys_private *p;
};

struct class_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct class___293 *, struct class_attribute___293 *, char *);
	ssize_t (*store)(struct class___293 *, struct class_attribute___293 *, const char *, size_t);
	const void * (*namespace)(struct class___293 *, const struct class_attribute___293 *);
};

struct device_rh___293 {
	struct dev_pm_info_rh___293 power;
};

struct vm_fault___265 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___294 *page;
};

struct nf_bridge_info___85 {
	atomic_t use;
	unsigned int mask;
	struct net_device___85 *physindev;
	struct net_device___85 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___85(struct sk_buff___87 **);

struct net_device_ops___85;

struct ethtool_ops___85;

struct header_ops___85;

struct inet6_dev___49;

struct netdev_rx_queue___85;

struct netdev_queue___85;

struct rtnl_link_ops___76;

struct dcbnl_rtnl_ops___85;

struct net_device___85 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___85 *netdev_ops;
	const struct ethtool_ops___85 *ethtool_ops;
	const struct header_ops___85 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___77 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___49 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___85 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___85 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___85 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___85 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___85 = 0,
		NETREG_REGISTERED___85 = 1,
		NETREG_UNREGISTERING___85 = 2,
		NETREG_UNREGISTERED___85 = 3,
		NETREG_RELEASED___85 = 4,
		NETREG_DUMMY___85 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___85 = 0,
		RTNL_LINK_INITIALIZING___85 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___85 *);
	struct netpoll_info *npinfo;
	struct net___99 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___293 dev;
	const struct attribute_group___255 *sysfs_groups[4];
	const struct rtnl_link_ops___76 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___85 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___87 {
	struct sk_buff___87 *next;
	struct sk_buff___87 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___74 *sk;
	struct net_device___85 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___87 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___85 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct inode_operations___295;

struct super_block___295;

struct file_lock___295;

struct dquot___295;

struct block_device___295;

struct inode___295 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___295 *i_op;
	struct super_block___295 *i_sb;
	struct address_space___295 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___297 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___295 *i_fop;
	struct file_lock___295 *i_flock;
	struct address_space___295 i_data;
	struct dquot___295 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___295 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct quota_format_type___295;

struct mem_dqinfo___295 {
	struct quota_format_type___295 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___295;

struct quota_info___295 {
	unsigned int flags;
	struct mutex___297 dqio_mutex;
	struct mutex___297 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___295 *files[2];
	struct mem_dqinfo___295 info[2];
	const struct quota_format_ops___295 *ops[2];
};

struct file_system_type___295;

struct super_operations___295;

struct dquot_operations___295;

struct quotactl_ops___295;

struct xattr_handler___191;

struct dentry_operations___295;

struct super_block___295 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___295 *s_type;
	const struct super_operations___295 *s_op;
	const struct dquot_operations___295 *dq_op;
	const struct quotactl_ops___295 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___295 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___191 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___295 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___295 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___297 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___295 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct dentry___295 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___295 *d_parent;
	struct qstr d_name;
	struct inode___295 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___295 *d_op;
	struct super_block___295 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct seq_operations___220;

struct seq_file___220 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___297 lock;
	const struct seq_operations___220 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct iattr___295 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___295 *ia_file;
};

struct request_sock_ops___58;

struct request_sock___59 {
	struct sock_common___74 __req_common;
	struct request_sock___59 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___58 *rsk_ops;
	struct sock___74 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___87 {
	struct sk_buff___87 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___87 *, struct netlink_callback___87 *);
	int (*done)(struct netlink_callback___87 *);
	void *data;
	struct module___183 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct file_operations___295 {
	struct module___183 *owner;
	loff_t (*llseek)(struct file___295 *, loff_t, int);
	ssize_t (*read)(struct file___295 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___295 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___82 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___82 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___295 *, void *, filldir_t);
	unsigned int (*poll)(struct file___295 *, struct poll_table_struct___181 *);
	long int (*unlocked_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___295 *, struct vm_area_struct___303 *);
	int (*open)(struct inode___295 *, struct file___295 *);
	int (*flush)(struct file___295 *, fl_owner_t);
	int (*release)(struct inode___295 *, struct file___295 *);
	int (*fsync)(struct file___295 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___82 *, int);
	int (*fasync)(int, struct file___295 *, int);
	int (*lock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*sendpage)(struct file___295 *, struct page___294 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___295 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___295 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___295 *, long int, struct file_lock___295 **, void **);
		struct {
			int (*setlease)(struct file___295 *, long int, struct file_lock___295 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___295 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___220 *, struct file___295 *);
};

struct dev_pm_qos_request___97 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___293 *dev;
};

struct dentry_operations___295 {
	int (*d_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_hash)(const struct dentry___295 *, struct qstr *);
	int (*d_compare)(const struct dentry___295 *, const struct dentry___295 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___295 *);
	void (*d_release)(struct dentry___295 *);
	void (*d_prune)(struct dentry___295 *);
	void (*d_iput)(struct dentry___295 *, struct inode___295 *);
	char * (*d_dname)(struct dentry___295 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___295 *);
	int (*d_manage)(struct dentry___295 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___295 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___295 *bd_inode;
	struct super_block___295 *bd_super;
	struct mutex___297 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___295 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___297 bd_fsfreeze_mutex;
};

struct cgroup___190;

struct cgroup_subsys_state___190 {
	struct cgroup___190 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct dquot___295 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___297 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___295 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___295 {
	int qf_fmt_id;
	const struct quota_format_ops___295 *qf_ops;
	struct module___183 *qf_owner;
	struct quota_format_type___295 *qf_next;
};

struct quota_format_ops___295 {
	int (*check_quota_file)(struct super_block___295 *, int);
	int (*read_file_info)(struct super_block___295 *, int);
	int (*write_file_info)(struct super_block___295 *, int);
	int (*free_file_info)(struct super_block___295 *, int);
	int (*read_dqblk)(struct dquot___295 *);
	int (*commit_dqblk)(struct dquot___295 *);
	int (*release_dqblk)(struct dquot___295 *);
};

struct dquot_operations___295 {
	int (*write_dquot)(struct dquot___295 *);
	struct dquot___295 * (*alloc_dquot)(struct super_block___295 *, int);
	void (*destroy_dquot)(struct dquot___295 *);
	int (*acquire_dquot)(struct dquot___295 *);
	int (*release_dquot)(struct dquot___295 *);
	int (*mark_dirty)(struct dquot___295 *);
	int (*write_info)(struct super_block___295 *, int);
	qsize_t * (*get_reserved_space)(struct inode___295 *);
};

struct quotactl_ops___295 {
	int (*quota_on)(struct super_block___295 *, int, int, struct path___295 *);
	int (*quota_on_meta)(struct super_block___295 *, int, int);
	int (*quota_off)(struct super_block___295 *, int);
	int (*quota_sync)(struct super_block___295 *, int);
	int (*get_info)(struct super_block___295 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___295 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___295 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___295 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___295 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___295 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___295 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___295 *, unsigned int);
};

struct address_space_operations___295 {
	int (*writepage)(struct page___294 *, struct writeback_control *);
	int (*readpage)(struct file___295 *, struct page___294 *);
	int (*writepages)(struct address_space___295 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___294 *);
	int (*readpages)(struct file___295 *, struct address_space___295 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___295 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___294 **, void **);
	int (*write_end)(struct file___295 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___294 *, void *);
	sector_t (*bmap)(struct address_space___295 *, sector_t);
	void (*invalidatepage)(struct page___294 *, long unsigned int);
	int (*releasepage)(struct page___294 *, gfp_t);
	void (*freepage)(struct page___294 *);
	ssize_t (*direct_IO)(int, struct kiocb___82 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___295 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___295 *, struct page___294 *, struct page___294 *, enum migrate_mode);
	int (*launder_page)(struct page___294 *);
	int (*is_partially_uptodate)(struct page___294 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___294 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___295 *, struct page___294 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___295 *, sector_t *);
	void (*swap_deactivate)(struct file___295 *);
	void (*invalidatepage_range)(struct page___294 *, unsigned int, unsigned int);
};

struct inode_operations___295 {
	struct dentry___295 * (*lookup)(struct inode___295 *, struct dentry___295 *, unsigned int);
	void * (*follow_link)(struct dentry___295 *, struct nameidata *);
	int (*permission)(struct inode___295 *, int);
	struct posix_acl * (*get_acl)(struct inode___295 *, int);
	int (*readlink)(struct dentry___295 *, char *, int);
	void (*put_link)(struct dentry___295 *, struct nameidata *, void *);
	int (*create)(struct inode___295 *, struct dentry___295 *, umode_t, bool);
	int (*link)(struct dentry___295 *, struct inode___295 *, struct dentry___295 *);
	int (*unlink)(struct inode___295 *, struct dentry___295 *);
	int (*symlink)(struct inode___295 *, struct dentry___295 *, const char *);
	int (*mkdir)(struct inode___295 *, struct dentry___295 *, umode_t);
	int (*rmdir)(struct inode___295 *, struct dentry___295 *);
	int (*mknod)(struct inode___295 *, struct dentry___295 *, umode_t, dev_t);
	int (*rename)(struct inode___295 *, struct dentry___295 *, struct inode___295 *, struct dentry___295 *);
	int (*setattr)(struct dentry___295 *, struct iattr___295 *);
	int (*getattr)(struct vfsmount *, struct dentry___295 *, struct kstat *);
	int (*setxattr)(struct dentry___295 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___295 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___295 *, char *, size_t);
	int (*removexattr)(struct dentry___295 *, const char *);
	int (*fiemap)(struct inode___295 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___295 *, struct timespec *, int);
	int (*atomic_open)(struct inode___295 *, struct dentry___295 *, struct file___295 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___295;

struct lock_manager_operations___295;

struct file_lock___295 {
	struct file_lock___295 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___295 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___295 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___295 *fl_ops;
	const struct lock_manager_operations___295 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___295 {
	void (*fl_copy_lock)(struct file_lock___295 *, struct file_lock___295 *);
	void (*fl_release_private)(struct file_lock___295 *);
};

struct lock_manager_operations___295 {
	int (*lm_compare_owner)(struct file_lock___295 *, struct file_lock___295 *);
	long unsigned int (*lm_owner_key)(struct file_lock___295 *);
	void (*lm_notify)(struct file_lock___295 *);
	int (*lm_grant)(struct file_lock___295 *, struct file_lock___295 *, int);
	void (*lm_break)(struct file_lock___295 *);
	int (*lm_change)(struct file_lock___295 **, int);
};

struct file_system_type___295 {
	const char *name;
	int fs_flags;
	struct dentry___295 * (*mount)(struct file_system_type___295 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___295 *);
	struct module___183 *owner;
	struct file_system_type___295 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___295 {
	struct inode___295 * (*alloc_inode)(struct super_block___295 *);
	void (*destroy_inode)(struct inode___295 *);
	void (*dirty_inode)(struct inode___295 *, int);
	int (*write_inode)(struct inode___295 *, struct writeback_control *);
	int (*drop_inode)(struct inode___295 *);
	void (*evict_inode)(struct inode___295 *);
	void (*put_super)(struct super_block___295 *);
	int (*sync_fs)(struct super_block___295 *, int);
	int (*freeze_fs)(struct super_block___295 *);
	int (*unfreeze_fs)(struct super_block___295 *);
	int (*statfs)(struct dentry___295 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___295 *, int *, char *);
	void (*umount_begin)(struct super_block___295 *);
	int (*show_options)(struct seq_file___220 *, struct dentry___295 *);
	int (*show_devname)(struct seq_file___220 *, struct dentry___295 *);
	int (*show_path)(struct seq_file___220 *, struct dentry___295 *);
	int (*show_stats)(struct seq_file___220 *, struct dentry___295 *);
	ssize_t (*quota_read)(struct super_block___295 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___295 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___295 *);
	int (*bdev_try_to_free_page)(struct super_block___295 *, struct page___294 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___295 *);
	void (*free_cached_objects)(struct super_block___295 *, int);
};

struct xattr_handler___191 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___295 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___295 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___295 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___85 {
	int (*get_settings)(struct net_device___85 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___85 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___85 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___85 *);
	void (*get_regs)(struct net_device___85 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___85 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___85 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___85 *);
	void (*set_msglevel)(struct net_device___85 *, u32);
	int (*nway_reset)(struct net_device___85 *);
	u32 (*get_link)(struct net_device___85 *);
	int (*get_eeprom_len)(struct net_device___85 *);
	int (*get_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___85 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___85 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___85 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___85 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___85 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___85 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___85 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___85 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___85 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___85 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___85 *);
	void (*complete)(struct net_device___85 *);
	u32 (*get_priv_flags)(struct net_device___85 *);
	int (*set_priv_flags)(struct net_device___85 *, u32);
	int (*get_sset_count)(struct net_device___85 *, int);
	int (*get_rxnfc)(struct net_device___85 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___85 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___85 *, struct ethtool_flash *);
	int (*reset)(struct net_device___85 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___85 *);
	int (*get_rxfh_indir)(struct net_device___85 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___85 *, const u32 *);
	void (*get_channels)(struct net_device___85 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___85 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___85 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___85 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___85 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___85 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___85 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___85 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___85 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___85 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___85 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___85 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___44;

struct dst_entry___75 {
	struct callback_head callback_head;
	struct dst_entry___75 *child;
	struct net_device___85 *dev;
	struct dst_ops___99 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___75 *path;
	struct dst_entry___75 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___87 *);
	union {
		int (*output)(struct sock___74 *, struct sk_buff___87 *);
		struct {
			int (*output)(struct sk_buff___87 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___75 *next;
		struct rtable___44 *rt_next;
		struct rt6_info___23 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___75;

struct neigh_parms___75;

struct neigh_ops___75;

struct neighbour___75 {
	struct neighbour___75 *next;
	struct neigh_table___75 *tbl;
	struct neigh_parms___75 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___86 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___75 *, struct sk_buff___87 *);
	const struct neigh_ops___75 *ops;
	struct callback_head rcu;
	struct net_device___85 *dev;
	u8 primary_key[0];
};

struct fib6_node___23;

struct rt6_info___23 {
	struct dst_entry___75 dst;
	struct fib6_table___23 *rt6i_table;
	struct fib6_node___23 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___49 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___23 {
	struct fib6_node___23 *parent;
	struct fib6_node___23 *left;
	struct fib6_node___23 *right;
	struct rt6_info___23 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___23 *rr_ptr;
};

struct fib6_table___23 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___23 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___16 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___85 *in;
	struct net_device___85 *out;
	struct sock___74 *sk;
	int (*okfn)(struct sock___74 *, struct sk_buff___87 *);
};

struct nf_afinfo___100 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___87 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___87 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___99 *, struct dst_entry___75 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___87 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___87 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___219 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___219 *);
	void (*irq_shutdown)(struct irq_data___219 *);
	void (*irq_enable)(struct irq_data___219 *);
	void (*irq_disable)(struct irq_data___219 *);
	void (*irq_ack)(struct irq_data___219 *);
	void (*irq_mask)(struct irq_data___219 *);
	void (*irq_mask_ack)(struct irq_data___219 *);
	void (*irq_unmask)(struct irq_data___219 *);
	void (*irq_eoi)(struct irq_data___219 *);
	int (*irq_set_affinity)(struct irq_data___219 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___219 *);
	int (*irq_set_type)(struct irq_data___219 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___219 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___219 *);
	void (*irq_bus_sync_unlock)(struct irq_data___219 *);
	void (*irq_cpu_online)(struct irq_data___219 *);
	void (*irq_cpu_offline)(struct irq_data___219 *);
	void (*irq_suspend)(struct irq_data___219 *);
	void (*irq_resume)(struct irq_data___219 *);
	void (*irq_pm_shutdown)(struct irq_data___219 *);
	void (*irq_print_chip)(struct irq_data___219 *, struct seq_file___220 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___219 *, void *);
	long unsigned int flags;
};

struct seq_operations___220 {
	void * (*start)(struct seq_file___220 *, loff_t *);
	void (*stop)(struct seq_file___220 *, void *);
	void * (*next)(struct seq_file___220 *, void *, loff_t *);
	int (*show)(struct seq_file___220 *, void *);
};

struct pernet_operations___31 {
	struct list_head list;
	int (*init)(struct net___99 *);
	void (*exit)(struct net___99 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___85 {
	int (*ieee_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___85 *);
	u8 (*setstate)(struct net_device___85 *, u8);
	void (*getpermhwaddr)(struct net_device___85 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___85 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___85 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___85 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___85 *, int, u8 *);
	void (*setpfccfg)(struct net_device___85 *, int, u8);
	void (*getpfccfg)(struct net_device___85 *, int, u8 *);
	u8 (*setall)(struct net_device___85 *);
	u8 (*getcap)(struct net_device___85 *, int, u8 *);
	int (*getnumtcs)(struct net_device___85 *, int, u8 *);
	int (*setnumtcs)(struct net_device___85 *, int, u8);
	u8 (*getpfcstate)(struct net_device___85 *);
	void (*setpfcstate)(struct net_device___85 *, u8);
	void (*getbcncfg)(struct net_device___85 *, int, u32 *);
	void (*setbcncfg)(struct net_device___85 *, int, u32);
	void (*getbcnrp)(struct net_device___85 *, int, u8 *);
	void (*setbcnrp)(struct net_device___85 *, int, u8);
	u8 (*setapp)(struct net_device___85 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___85 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___85 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___85 *, int, u8);
	u8 (*getdcbx)(struct net_device___85 *);
	u8 (*setdcbx)(struct net_device___85 *, u8);
	int (*peer_getappinfo)(struct net_device___85 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___85 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___85 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___85 *, struct cee_pfc *);
};

struct cgroupfs_root___190;

struct cgroup___190 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___190 *parent;
	struct dentry___295 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___190 *subsys[11];
	struct cgroupfs_root___190 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___297 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___190 {
	struct super_block___295 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___190 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___126 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___295 *, struct file___295 *);
	ssize_t (*read)(struct cgroup___190 *, struct cftype___126 *, struct file___295 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___190 *, struct cftype___126 *);
	s64 (*read_s64)(struct cgroup___190 *, struct cftype___126 *);
	int (*read_map)(struct cgroup___190 *, struct cftype___126 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___190 *, struct cftype___126 *, struct seq_file___220 *);
	ssize_t (*write)(struct cgroup___190 *, struct cftype___126 *, struct file___295 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___190 *, struct cftype___126 *, u64);
	int (*write_s64)(struct cgroup___190 *, struct cftype___126 *, s64);
	int (*write_string)(struct cgroup___190 *, struct cftype___126 *, const char *);
	int (*trigger)(struct cgroup___190 *, unsigned int);
	int (*release)(struct inode___295 *, struct file___295 *);
	int (*register_event)(struct cgroup___190 *, struct cftype___126 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___190 *, struct cftype___126 *, struct eventfd_ctx *);
};

struct cftype_set___122 {
	struct list_head node;
	struct cftype___126 *cfts;
};

struct task_and_cgroup___122 {
	struct task_struct___296 *task;
	struct cgroup___190 *cgrp;
	struct css_set___190 *cg;
};

struct cgroup_taskset___122 {
	struct task_and_cgroup___122 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___190 *cur_cgrp;
};

struct cgroup_subsys___122 {
	struct cgroup_subsys_state___190 * (*css_alloc)(struct cgroup___190 *);
	int (*css_online)(struct cgroup___190 *);
	void (*css_offline)(struct cgroup___190 *);
	void (*css_free)(struct cgroup___190 *);
	int (*can_attach)(struct cgroup___190 *, struct cgroup_taskset___122 *);
	void (*cancel_attach)(struct cgroup___190 *, struct cgroup_taskset___122 *);
	void (*attach)(struct cgroup___190 *, struct cgroup_taskset___122 *);
	void (*fork)(struct task_struct___296 *);
	void (*exit)(struct cgroup___190 *, struct cgroup___190 *, struct task_struct___296 *);
	void (*bind)(struct cgroup___190 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___190 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___126 *base_cftypes;
	struct cftype_set___122 base_cftset;
	struct module___183 *module;
};

struct header_ops___85 {
	int (*create)(struct sk_buff___87 *, struct net_device___85 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___87 *, unsigned char *);
	int (*rebuild)(struct sk_buff___87 *);
	int (*cache)(const struct neighbour___75 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___85 *, const unsigned char *);
};

struct napi_struct___85 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___85 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___85 *dev;
	struct sk_buff___87 *gro_list;
	struct sk_buff___87 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___85 {
	struct net_device___85 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___77 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___85 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___77 kobj;
	struct net_device___85 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___85 {
	int (*ndo_init)(struct net_device___85 *);
	void (*ndo_uninit)(struct net_device___85 *);
	int (*ndo_open)(struct net_device___85 *);
	int (*ndo_stop)(struct net_device___85 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___87 *, struct net_device___85 *);
	u16 (*ndo_select_queue)(struct net_device___85 *, struct sk_buff___87 *);
	void (*ndo_change_rx_flags)(struct net_device___85 *, int);
	void (*ndo_set_rx_mode)(struct net_device___85 *);
	int (*ndo_set_mac_address)(struct net_device___85 *, void *);
	int (*ndo_validate_addr)(struct net_device___85 *);
	int (*ndo_do_ioctl)(struct net_device___85 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___85 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___85 *, int);
	int (*ndo_neigh_setup)(struct net_device___85 *, struct neigh_parms___75 *);
	void (*ndo_tx_timeout)(struct net_device___85 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___85 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___85 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___85 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___85 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___85 *);
	int (*ndo_netpoll_setup)(struct net_device___85 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___85 *);
	int (*ndo_busy_poll)(struct napi_struct___85 *);
	int (*ndo_set_vf_mac)(struct net_device___85 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___85 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___85 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___85 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___85 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___85 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___85 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___85 *, int, struct sk_buff___87 *);
	int (*ndo_setup_tc)(struct net_device___85 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___85 *);
	int (*ndo_fcoe_disable)(struct net_device___85 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___85 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___85 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___85 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___85 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___85 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___85 *, const struct sk_buff___87 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___85 *, struct net_device___85 *);
	int (*ndo_del_slave)(struct net_device___85 *, struct net_device___85 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___75 *);
	void (*ndo_neigh_destroy)(struct neighbour___75 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___87 *, struct netlink_callback___87 *, struct net_device___85 *, int);
	int (*ndo_bridge_setlink)(struct net_device___85 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___87 *, u32, u32, struct net_device___85 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___85 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___85 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___85 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___85 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___85 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___85 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___87 *, struct net_device___85 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___85 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___85 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___85 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___75 {
	struct net___99 *net;
	struct net_device___85 *dev;
	struct neigh_parms___75 *next;
	int (*neigh_setup)(struct neighbour___75 *);
	void (*neigh_cleanup)(struct neighbour___75 *);
	struct neigh_table___75 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___49;

struct ifacaddr6___49;

struct inet6_dev___49 {
	struct net_device___85 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___49 *mc_list;
	struct ifmcaddr6___49 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___49 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___75 *nd_parms;
	struct inet6_dev___49 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___76 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___85 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___99 *, struct net_device___85 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___85 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___85 *, struct list_head *);
	size_t (*get_size)(const struct net_device___85 *);
	int (*fill_info)(struct sk_buff___87 *, const struct net_device___85 *);
	size_t (*get_xstats_size)(const struct net_device___85 *);
	int (*fill_xstats)(struct sk_buff___87 *, const struct net_device___85 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___99 * (*get_link_net)(const struct net_device___85 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___85 *, struct net_device___85 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___85 *, const struct net_device___85 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___87 *, const struct net_device___85 *, const struct net_device___85 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___75 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___87 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct nduseroptmsg {
	unsigned char nduseropt_family;
	unsigned char nduseropt_pad1;
	short unsigned int nduseropt_opts_len;
	int nduseropt_ifindex;
	__u8 nduseropt_icmp_type;
	__u8 nduseropt_icmp_code;
	short unsigned int nduseropt_pad2;
	unsigned int nduseropt_pad3;
};

enum {
	NDUSEROPT_UNSPEC = 0,
	NDUSEROPT_SRCADDR = 1,
	__NDUSEROPT_MAX = 2,
};

struct pneigh_entry___75;

struct neigh_hash_table___75;

struct neigh_table___75 {
	struct neigh_table___75 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___85 *, __u32 *);
	int (*constructor)(struct neighbour___75 *);
	int (*pconstructor)(struct pneigh_entry___75 *);
	void (*pdestructor)(struct pneigh_entry___75 *);
	void (*proxy_redo)(struct sk_buff___87 *);
	char *id;
	struct neigh_parms___75 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___86 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___75 *nht;
	struct pneigh_entry___75 **phash_buckets;
};

struct neigh_ops___75 {
	int family;
	void (*solicit)(struct neighbour___75 *, struct sk_buff___87 *);
	void (*error_report)(struct neighbour___75 *, struct sk_buff___87 *);
	int (*output)(struct neighbour___75 *, struct sk_buff___87 *);
	int (*connected_output)(struct neighbour___75 *, struct sk_buff___87 *);
};

struct pneigh_entry___75 {
	struct pneigh_entry___75 *next;
	struct net___99 *net;
	struct net_device___85 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___75 {
	struct neighbour___75 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___44 {
	struct dst_entry___75 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___55;

struct proto___74 {
	void (*close)(struct sock___74 *, long int);
	int (*connect)(struct sock___74 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___74 *, int);
	struct sock___74 * (*accept)(struct sock___74 *, int, int *);
	int (*ioctl)(struct sock___74 *, int, long unsigned int);
	int (*init)(struct sock___74 *);
	void (*destroy)(struct sock___74 *);
	void (*shutdown)(struct sock___74 *, int);
	int (*setsockopt)(struct sock___74 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___74 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___74 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___74 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___74 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___82 *, struct sock___74 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___82 *, struct sock___74 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___74 *, struct page___294 *, int, size_t, int);
	int (*bind)(struct sock___74 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___74 *, struct sk_buff___87 *);
	void (*release_cb)(struct sock___74 *);
	void (*mtu_reduced)(struct sock___74 *);
	void (*hash)(struct sock___74 *);
	void (*unhash)(struct sock___74 *);
	void (*rehash)(struct sock___74 *);
	int (*get_port)(struct sock___74 *, short unsigned int);
	void (*clear_sk)(struct sock___74 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___74 *);
	void (*enter_memory_pressure)(struct sock___74 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___278 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___58 *rsk_prot;
	struct timewait_sock_ops___55 *twsk_prot;
	union {
		struct inet_hashinfo___21 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___183 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___122 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___74 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___74 {
	void (*enter_memory_pressure)(struct sock___74 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___58 {
	int family;
	int obj_size;
	struct kmem_cache___278 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___74 *, struct request_sock___59 *);
	void (*send_ack)(struct sock___74 *, struct sk_buff___87 *, struct request_sock___59 *);
	void (*send_reset)(struct sock___74 *, struct sk_buff___87 *);
	void (*destructor)(struct request_sock___59 *);
	void (*syn_ack_timeout)(struct sock___74 *, struct request_sock___59 *);
};

struct timewait_sock_ops___55 {
	struct kmem_cache___278 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___74 *, struct sock___74 *, void *);
	void (*twsk_destructor)(struct sock___74 *);
};

struct inet_cork___28 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___75 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___28 {
	struct inet_cork___28 base;
	struct flowi fl;
};

struct ipv6_pinfo___27;

struct inet_sock___28 {
	struct sock___74 sk;
	struct ipv6_pinfo___27 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___28 cork;
};

struct ipv6_fl_socklist___26;

struct ipv6_pinfo___27 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___26 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___87 *pktoptions;
	struct sk_buff___87 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___26;

struct ipv6_fl_socklist___26 {
	struct ipv6_fl_socklist___26 *next;
	struct ip6_flowlabel___26 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___5 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 valid_lft;
	__u32 prefered_lft;
	atomic_t refcnt;
	spinlock_t lock;
	spinlock_t state_lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u16 scope;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___49 *idev;
	struct rt6_info___23 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___5 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___49 {
	struct in6_addr mca_addr;
	struct inet6_dev___49 *idev;
	struct ifmcaddr6___49 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___49 {
	struct in6_addr aca_addr;
	struct inet6_dev___49 *aca_idev;
	struct rt6_info___23 *aca_rt;
	struct ifacaddr6___49 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct nd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	__u8 opt[0];
};

struct rs_msg {
	struct icmp6hdr icmph;
	__u8 opt[0];
};

struct ra_msg {
	struct icmp6hdr icmph;
	__be32 reachable_time;
	__be32 retrans_timer;
};

struct ip6_flowlabel___26 {
	struct ip6_flowlabel___26 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___99 *fl_net;
};

struct nf_ipv6_ops___9 {
	int (*chk_addr)(struct net___99 *, const struct in6_addr *, const struct net_device___85 *, int);
};

struct seq_net_private___15 {
	struct net___96 *net;
};

struct inet_timewait_sock___7 {
	struct sock_common___71 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___2 *tw_tb;
	struct hlist_node tw_death_node;
};

struct udp_sock___4 {
	struct inet_sock___26 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___71 *, struct sk_buff___84 *);
	void (*encap_destroy)(struct sock___71 *);
};

struct inet_protosw___4 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___71 *prot;
	const struct proto_ops___71 *ops;
	unsigned char flags;
};

struct udp_seq_afinfo___3 {
	char *name;
	sa_family_t family;
	struct udp_table *udp_table;
	const struct file_operations___292 *seq_fops;
	struct seq_operations___217 seq_ops;
};

struct udp_iter_state___2 {
	struct seq_net_private___15 p;
	sa_family_t family;
	int bucket;
	struct udp_table *udp_table;
};

struct inet6_protocol___2 {
	void (*early_demux)(struct sk_buff___72 *);
	int (*handler)(struct sk_buff___72 *);
	void (*err_handler)(struct sk_buff___72 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct pernet_operations___32 {
	struct list_head list;
	int (*init)(struct net___72 *);
	void (*exit)(struct net___72 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct icmp6_filter {
	__u32 data[8];
};

struct nf_ipv6_ops___10 {
	int (*chk_addr)(struct net___72 *, const struct in6_addr *, const struct net_device___58 *, int);
};

struct raw6_sock {
	struct inet_sock___6 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___5 inet6;
};

struct inet_protosw___5 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___47 *prot;
	const struct proto_ops___47 *ops;
	unsigned char flags;
};

struct raw_iter_state___2 {
	struct seq_net_private___13 p;
	int bucket;
	struct raw_hashinfo *h;
};

typedef int mh_filter_t(struct sock___48 *, struct sk_buff___61 *);

typedef void ip6_icmp_send_t(struct sk_buff___36 *, u8, u8, __u32);

struct ipv6_destopt_hao {
	__u8 type;
	__u8 length;
	struct in6_addr addr;
} __attribute__((packed));

struct inet6_protocol___3 {
	void (*early_demux)(struct sk_buff___36 *);
	int (*handler)(struct sk_buff___36 *);
	void (*err_handler)(struct sk_buff___36 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct icmpv6_msg {
	struct sk_buff___36 *skb;
	int offset;
	uint8_t type;
};

struct icmp6_err {
	int err;
	int fatal;
};

struct mld_msg {
	struct icmp6hdr mld_hdr;
	struct in6_addr mld_mca;
};

struct mld2_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	struct in6_addr grec_mca;
	struct in6_addr grec_src[0];
};

struct mld2_report {
	struct icmp6hdr mld2r_hdr;
	struct mld2_grec mld2r_grec[0];
};

struct mld2_query {
	struct icmp6hdr mld2q_hdr;
	struct in6_addr mld2q_mca;
	__u8 mld2q_qrv: 3;
	__u8 mld2q_suppress: 1;
	__u8 mld2q_resv2: 4;
	__u8 mld2q_qqic;
	__be16 mld2q_nsrcs;
	struct in6_addr mld2q_srcs[0];
};

struct igmp6_mc_iter_state {
	struct seq_net_private___13 p;
	struct net_device___58 *dev;
	struct inet6_dev___24 *idev;
};

struct igmp6_mcf_iter_state {
	struct seq_net_private___13 p;
	struct net_device___58 *dev;
	struct inet6_dev___24 *idev;
	struct ifmcaddr6___24 *im;
};

struct inet_frag_queue___2 {
	spinlock_t lock;
	struct timer_list timer;
	struct list_head lru_list;
	struct hlist_node list;
	atomic_t refcnt;
	struct sk_buff___86 *fragments;
	struct sk_buff___86 *fragments_tail;
	ktime_t stamp;
	int len;
	int meat;
	__u8 last_in;
	u16 max_size;
	struct netns_frags *net;
};

struct inet_frags___2 {
	struct inet_frag_bucket hash[1024];
	rwlock_t lock;
	int secret_interval;
	struct timer_list secret_timer;
	u32 rnd;
	int qsize;
	unsigned int (*hashfn)(struct inet_frag_queue___2 *);
	bool (*match)(struct inet_frag_queue___2 *, void *);
	void (*constructor)(struct inet_frag_queue___2 *, void *);
	void (*destructor)(struct inet_frag_queue___2 *);
	void (*skb_free)(struct sk_buff___86 *);
	void (*frag_expire)(long unsigned int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum ip6_defrag_users {
	IP6_DEFRAG_LOCAL_DELIVER = 0,
	IP6_DEFRAG_CONNTRACK_IN = 1,
	__IP6_DEFRAG_CONNTRACK_IN = 65536,
	IP6_DEFRAG_CONNTRACK_OUT = 65537,
	__IP6_DEFRAG_CONNTRACK_OUT = 131072,
	IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 131073,
	__IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 196608,
};

struct ip6_create_arg {
	__be32 id;
	u32 user;
	const struct in6_addr *src;
	const struct in6_addr *dst;
	u8 ecn;
};

struct frag_queue {
	struct inet_frag_queue___2 q;
	__be32 id;
	u32 user;
	struct in6_addr saddr;
	struct in6_addr daddr;
	int iif;
	unsigned int csum;
	__u16 nhoffset;
	u8 ecn;
};

struct ip6frag_skb_cb {
	struct inet6_skb_parm h;
	int offset;
};

struct page___295;

typedef struct page___295 *pgtable_t___295;

struct address_space___296;

struct kmem_cache___279;

struct page___295 {
	long unsigned int flags;
	struct address_space___296 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___295 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___295 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___279 *slab_cache;
		struct page___295 *first_page;
	};
	long: 64;
};

struct task_struct___297;

struct pv_cpu_ops___297 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___297 *);
	void (*end_context_switch)(struct task_struct___297 *);
};

struct mutex___298 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___297 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___290 {
	struct page___295 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___304;

struct nsproxy___176;

struct signal_struct___297;

struct css_set___191;

struct task_struct___297 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___297 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___304 *mm;
	struct mm_struct___304 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___297 *real_parent;
	struct task_struct___297 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___297 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___297 = 0,
		VTIME_USER___297 = 1,
		VTIME_SYS___297 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___176 *nsproxy;
	struct signal_struct___297 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___191 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___298 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___290 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___304 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___304 *, struct mm_struct___304 *);
	void (*dup_mmap)(struct mm_struct___304 *, struct mm_struct___304 *);
	void (*exit_mmap)(struct mm_struct___304 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___304 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___304 *);
	void (*pgd_free)(struct mm_struct___304 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___304 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___304 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___304 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___304 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___304 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___304 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___304 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___304 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___304 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___304 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___304 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___298 lock;
	void *vdso;
} mm_context_t___298;

struct xol_area___295;

struct uprobes_state___295 {
	struct xol_area___295 *xol_area;
};

struct vm_area_struct___304;

struct file___296;

struct core_state___297;

struct mm_struct___304 {
	struct vm_area_struct___304 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___304 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___304 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___298 context;
	long unsigned int flags;
	struct core_state___297 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___297 *owner;
	struct file___296 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___295 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kset___78;

struct kobj_type___78;

struct kobject___78 {
	const char *name;
	struct list_head entry;
	struct kobject___78 *parent;
	struct kset___78 *kset;
	struct kobj_type___78 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct module___184;

struct module_kobject___184 {
	struct kobject___78 kobj;
	struct module___184 *mod;
	struct kobject___78 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___184;

struct module___184 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___184 mkobj;
	struct module_attribute___184 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___78 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___297 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___297;

struct lruvec___297 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___297 *zone;
};

struct pglist_data___297;

struct zone___297 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___297 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___297 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___297 {
	struct zone___297 *zone;
	int zone_idx;
};

struct zonelist___297 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___297 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___297 {
	struct zone___297 node_zones[4];
	struct zonelist___297 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___297 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___220;

struct x86_io_apic_ops___220 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___220 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___220;

struct irq_data___220 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___220 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___294;

struct dev_pm_ops___294 {
	int (*prepare)(struct device___294 *);
	void (*complete)(struct device___294 *);
	int (*suspend)(struct device___294 *);
	int (*resume)(struct device___294 *);
	int (*freeze)(struct device___294 *);
	int (*thaw)(struct device___294 *);
	int (*poweroff)(struct device___294 *);
	int (*restore)(struct device___294 *);
	int (*suspend_late)(struct device___294 *);
	int (*resume_early)(struct device___294 *);
	int (*freeze_late)(struct device___294 *);
	int (*thaw_early)(struct device___294 *);
	int (*poweroff_late)(struct device___294 *);
	int (*restore_early)(struct device___294 *);
	int (*suspend_noirq)(struct device___294 *);
	int (*resume_noirq)(struct device___294 *);
	int (*freeze_noirq)(struct device___294 *);
	int (*thaw_noirq)(struct device___294 *);
	int (*poweroff_noirq)(struct device___294 *);
	int (*restore_noirq)(struct device___294 *);
	int (*runtime_suspend)(struct device___294 *);
	int (*runtime_resume)(struct device___294 *);
	int (*runtime_idle)(struct device___294 *);
};

struct dev_pm_qos___97;

struct dev_pm_info___97 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___97 *qos;
};

struct dma_map_ops___159;

struct dev_archdata___159 {
	struct dma_map_ops___159 *dma_ops;
	void *iommu;
};

struct device_type___294;

struct bus_type___294;

struct device_driver___294;

struct dev_pm_domain___294;

struct class___294;

struct attribute_group___256;

struct device_rh___294;

struct device___294 {
	struct device___294 *parent;
	struct device_private *p;
	struct kobject___78 kobj;
	const char *init_name;
	const struct device_type___294 *type;
	struct mutex___298 mutex;
	struct bus_type___294 *bus;
	struct device_driver___294 *driver;
	void *platform_data;
	struct dev_pm_info___97 power;
	struct dev_pm_domain___294 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___159 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___294 *class;
	const struct attribute_group___256 **groups;
	void (*release)(struct device___294 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___294 *device_rh;
};

struct dev_pm_qos_request___98;

struct dev_pm_qos___97 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___98 *latency_req;
	struct dev_pm_qos_request___98 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___98 *latency_tolerance_req;
};

struct dev_pm_info_rh___294 {
	void (*set_latency_tolerance)(struct device___294 *, s32);
};

struct dev_pm_domain___294 {
	struct dev_pm_ops___294 ops;
};

struct smp_ops___297 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___297 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___101;

struct ctl_node___101 {
	struct rb_node node;
	struct ctl_table_header___101 *header;
};

struct ctl_table_root___101;

struct ctl_table_set___101;

struct ctl_dir___101;

struct ctl_table_header___101 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___101 *root;
	struct ctl_table_set___101 *set;
	struct ctl_dir___101 *parent;
	struct ctl_node___101 *node;
};

struct ctl_dir___101 {
	struct ctl_table_header___101 header;
	struct rb_root root;
};

struct ctl_table_set___101 {
	int (*is_seen)(struct ctl_table_set___101 *);
	struct ctl_dir___101 dir;
};

struct ctl_table_root___101 {
	struct ctl_table_set___101 default_set;
	struct ctl_table_set___101 * (*lookup)(struct ctl_table_root___101 *, struct nsproxy___176 *);
	int (*permissions)(struct ctl_table_header___101 *, struct ctl_table *);
};

struct net___100;

struct nsproxy___176 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___100 *net_ns;
};

struct sock___75;

struct kobj_ns_type_operations___75 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___75 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___75;

struct sock_common___75 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___75 *skc_prot;
	struct net___100 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___88;

struct sk_buff_head___87 {
	struct sk_buff___88 *next;
	struct sk_buff___88 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___76;

struct socket_wq___75;

struct xfrm_policy___21;

struct dst_entry___76;

struct socket___76;

struct cg_proto___75;

struct sock___75 {
	struct sock_common___75 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___87 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___88 *head;
		struct sk_buff___88 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___76 *sk_filter;
	struct socket_wq___75 *sk_wq;
	struct sk_buff_head___87 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy___21 *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___76 *sk_rx_dst;
	struct dst_entry___76 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___87 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___87 sk_error_queue;
	struct proto___75 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___76 *sk_socket;
	void *sk_user_data;
	struct page_frag___290 sk_frag;
	struct sk_buff___88 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___75 *sk_cgrp;
	void (*sk_state_change)(struct sock___75 *);
	void (*sk_data_ready)(struct sock___75 *, int);
	void (*sk_write_space)(struct sock___75 *);
	void (*sk_error_report)(struct sock___75 *);
	int (*sk_backlog_rcv)(struct sock___75 *, struct sk_buff___88 *);
	void (*sk_destruct)(struct sock___75 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___258;

struct attribute_group___256 {
	const char *name;
	umode_t (*is_visible)(struct kobject___78 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___258 **bin_attrs;
};

struct bin_attribute___258 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___296 *, struct kobject___78 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___296 *, struct kobject___78 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	int (*mmap)(struct file___296 *, struct kobject___78 *, struct bin_attribute___258 *, struct vm_area_struct___304 *);
};

struct dentry___296;

struct path___296 {
	struct vfsmount *mnt;
	struct dentry___296 *dentry;
};

struct inode___296;

struct file_operations___296;

struct file___296 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___296 f_path;
	struct inode___296 *f_inode;
	const struct file_operations___296 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___296 *f_mapping;
	struct mutex___298 f_pos_lock;
};

struct vm_operations_struct___270;

struct vm_area_struct___304 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___304 *vm_next;
	struct vm_area_struct___304 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___304 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___270 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___296 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___78 {
	ssize_t (*show)(struct kobject___78 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___78 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___78 *, const struct attribute *);
};

struct kset_uevent_ops___78;

struct kset___78 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___78 kobj;
	const struct kset_uevent_ops___78 *uevent_ops;
};

struct kobj_type___78 {
	void (*release)(struct kobject___78 *);
	const struct sysfs_ops___78 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___75 * (*child_ns_type)(struct kobject___78 *);
	const void * (*namespace)(struct kobject___78 *);
};

struct kset_uevent_ops___78 {
	int (* const filter)(struct kset___78 *, struct kobject___78 *);
	const char * (* const name)(struct kset___78 *, struct kobject___78 *);
	int (* const uevent)(struct kset___78 *, struct kobject___78 *, struct kobj_uevent_env *);
};

struct module_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___184 *, struct module_kobject___184 *, char *);
	ssize_t (*store)(struct module_attribute___184 *, struct module_kobject___184 *, const char *, size_t);
	void (*setup)(struct module___184 *, const char *);
	int (*test)(struct module___184 *);
	void (*free)(struct module___184 *);
};

struct xol_area___295 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___295 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___278;

struct memcg_cache_params___279;

struct kmem_cache___279 {
	struct kmem_cache_cpu___278 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___78 kobj;
	struct memcg_cache_params___279 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct address_space_operations___296;

struct address_space___296 {
	struct inode___296 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___298 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___296 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vm_fault___266;

struct vm_operations_struct___270 {
	void (*open)(struct vm_area_struct___304 *);
	void (*close)(struct vm_area_struct___304 *);
	int (*fault)(struct vm_area_struct___304 *, struct vm_fault___266 *);
	int (*page_mkwrite)(struct vm_area_struct___304 *, struct vm_fault___266 *);
	int (*access)(struct vm_area_struct___304 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___304 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___304 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___304 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___304 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___297 {
	struct task_struct___297 *task;
	struct core_thread___297 *next;
};

struct core_state___297 {
	atomic_t nr_threads;
	struct core_thread___297 dumper;
	struct completion startup;
};

struct fasync_struct___296;

struct socket_wq___75 {
	wait_queue_head_t wait;
	struct fasync_struct___296 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___296 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___296 *fa_next;
	struct file___296 *fa_file;
	struct callback_head fa_rcu;
};

struct proto_ops___75;

struct socket___76 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___75 *wq;
	struct file___296 *file;
	struct sock___75 *sk;
	const struct proto_ops___75 *ops;
};

struct poll_table_struct___182;

struct kiocb___83;

struct proto_ops___75 {
	int family;
	struct module___184 *owner;
	int (*release)(struct socket___76 *);
	int (*bind)(struct socket___76 *, struct sockaddr *, int);
	int (*connect)(struct socket___76 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___76 *, struct socket___76 *);
	int (*accept)(struct socket___76 *, struct socket___76 *, int);
	int (*getname)(struct socket___76 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___296 *, struct socket___76 *, struct poll_table_struct___182 *);
	int (*ioctl)(struct socket___76 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___76 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___76 *, int);
	int (*shutdown)(struct socket___76 *, int);
	int (*setsockopt)(struct socket___76 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___76 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___76 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___76 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___83 *, struct socket___76 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___83 *, struct socket___76 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___296 *, struct socket___76 *, struct vm_area_struct___304 *);
	ssize_t (*sendpage)(struct socket___76 *, struct page___295 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___76 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___75 *, int);
		struct {
			void (*set_peek_off)(struct sock___75 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___184)(struct file___296 *, wait_queue_head_t *, struct poll_table_struct___182 *);

struct poll_table_struct___182 {
	poll_queue_proc___184 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___83(struct kiocb___83 *, struct io_event *);

struct kiocb___83 {
	atomic_t ki_users;
	struct file___296 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___83 *ki_cancel;
	void (*ki_dtor)(struct kiocb___83 *);
	union {
		void *user;
		struct task_struct___297 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct netns_core___98 {
	struct ctl_table_header___101 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___99 {
	struct mutex___298 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___98 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___101 *ctl;
};

struct netns_ipv4___98 {
	struct ctl_table_header___101 *forw_hdr;
	struct ctl_table_header___101 *frags_hdr;
	struct ctl_table_header___101 *ipv4_hdr;
	struct ctl_table_header___101 *route_hdr;
	struct ctl_table_header___101 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___75 *fibnl;
	struct sock___75 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___98 {
	struct ctl_table_header___101 *hdr;
	struct ctl_table_header___101 *route_hdr;
	struct ctl_table_header___101 *icmp_hdr;
	struct ctl_table_header___101 *frags_hdr;
	struct ctl_table_header___101 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___86;

struct neighbour___76;

struct dst_ops___100 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___100 *);
	struct dst_entry___76 * (*check)(struct dst_entry___76 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___76 *);
	unsigned int (*mtu)(const struct dst_entry___76 *);
	u32 * (*cow_metrics)(struct dst_entry___76 *, long unsigned int);
	void (*destroy)(struct dst_entry___76 *);
	void (*ifdown)(struct dst_entry___76 *, struct net_device___86 *, int);
	struct dst_entry___76 * (*negative_advice)(struct dst_entry___76 *);
	void (*link_failure)(struct sk_buff___88 *);
	void (*update_pmtu)(struct dst_entry___76 *, struct sock___75 *, struct sk_buff___88 *, u32);
	void (*redirect)(struct dst_entry___76 *, struct sock___75 *, struct sk_buff___88 *);
	int (*local_out)(struct sk_buff___88 *);
	struct neighbour___76 * (*neigh_lookup)(const struct dst_entry___76 *, struct sk_buff___88 *, const void *);
	struct kmem_cache___279 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___24;

struct fib6_table___24;

struct netns_ipv6___100 {
	struct netns_sysctl_ipv6___98 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___24 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___24 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___100 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___24 *ip6_prohibit_entry;
	struct rt6_info___24 *ip6_blk_hole_entry;
	struct fib6_table___24 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___75 **icmp_sk;
	struct sock___75 *ndisc_sk;
	struct sock___75 *tcp_sk;
	struct sock___75 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___98 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___101 *sysctl_header;
	struct sock___75 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___75 {
	struct sock___75 *v4_ctl_sk;
	struct sock___75 *v6_ctl_sk;
};

struct netns_nf___98 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___101 *nf_log_dir_header;
};

struct nf_proto_net___98 {
	struct ctl_table_header___101 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___98 {
	struct nf_proto_net___98 pn;
	unsigned int timeout;
};

struct nf_tcp_net___98 {
	struct nf_proto_net___98 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___98 {
	struct nf_proto_net___98 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___98 {
	struct nf_proto_net___98 pn;
	unsigned int timeout;
};

struct nf_ip_net___98 {
	struct nf_generic_net___98 generic;
	struct nf_tcp_net___98 tcp;
	struct nf_udp_net___98 udp;
	struct nf_icmp_net___98 icmp;
	struct nf_icmp_net___98 icmpv6;
};

struct netns_ct___99 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___101 *sysctl_header;
	struct ctl_table_header___101 *acct_sysctl_header;
	struct ctl_table_header___101 *tstamp_sysctl_header;
	struct ctl_table_header___101 *event_sysctl_header;
	struct ctl_table_header___101 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___279 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___98 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___98 {
	struct netns_sysctl_ipv6___98 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___100 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___75 *nlsk;
	struct sock___75 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___101 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___100 xfrm4_dst_ops;
	struct dst_ops___100 xfrm6_dst_ops;
};

struct net___100 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___101 sysctls;
	struct sock___75 *rtnl;
	struct sock___75 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___86 *loopback_dev;
	struct netns_core___98 core;
	struct netns_mib mib;
	struct netns_packet___99 packet;
	struct netns_unix___98 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___98 ipv4;
	struct netns_ipv6___100 ipv6;
	struct netns_sctp___98 sctp;
	struct netns_dccp___75 dccp;
	struct netns_nf___98 nf;
	struct netns_xt xt;
	struct netns_ct___99 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___98 nf_frag;
	struct sock___75 *nfnl;
	struct sock___75 *nfnl_stash;
	struct sk_buff_head___87 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___100 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___75 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___75 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___298 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___298 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___296;

struct seq_file___221;

struct file_operations___296 {
	struct module___184 *owner;
	loff_t (*llseek)(struct file___296 *, loff_t, int);
	ssize_t (*read)(struct file___296 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___296 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___83 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___83 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___296 *, void *, filldir_t);
	unsigned int (*poll)(struct file___296 *, struct poll_table_struct___182 *);
	long int (*unlocked_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___296 *, struct vm_area_struct___304 *);
	int (*open)(struct inode___296 *, struct file___296 *);
	int (*flush)(struct file___296 *, fl_owner_t);
	int (*release)(struct inode___296 *, struct file___296 *);
	int (*fsync)(struct file___296 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___83 *, int);
	int (*fasync)(int, struct file___296 *, int);
	int (*lock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*sendpage)(struct file___296 *, struct page___295 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___296 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___296 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___296 *, long int, struct file_lock___296 **, void **);
		struct {
			int (*setlease)(struct file___296 *, long int, struct file_lock___296 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___296 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___221 *, struct file___296 *);
};

struct dma_map_ops___159 {
	void * (*alloc)(struct device___294 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___294 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___294 *, struct vm_area_struct___304 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___294 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___294 *, struct page___295 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___294 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___294 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___294 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___294 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___294 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___294 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___294 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___294 *, dma_addr_t);
	int (*dma_supported)(struct device___294 *, u64);
	int (*set_dma_mask)(struct device___294 *, u64);
	int is_phys;
};

struct bus_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___294 *, char *);
	ssize_t (*store)(struct bus_type___294 *, const char *, size_t);
};

struct device_attribute___294;

struct driver_attribute___294;

struct bus_type___294 {
	const char *name;
	const char *dev_name;
	struct device___294 *dev_root;
	struct bus_attribute___294 *bus_attrs;
	struct device_attribute___294 *dev_attrs;
	struct driver_attribute___294 *drv_attrs;
	const struct attribute_group___256 **bus_groups;
	const struct attribute_group___256 **dev_groups;
	const struct attribute_group___256 **drv_groups;
	int (*match)(struct device___294 *, struct device_driver___294 *);
	int (*uevent)(struct device___294 *, struct kobj_uevent_env *);
	int (*probe)(struct device___294 *);
	int (*remove)(struct device___294 *);
	void (*shutdown)(struct device___294 *);
	int (*online)(struct device___294 *);
	int (*offline)(struct device___294 *);
	int (*suspend)(struct device___294 *, pm_message_t);
	int (*resume)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct device___294 *, struct device_attribute___294 *, char *);
	ssize_t (*store)(struct device___294 *, struct device_attribute___294 *, const char *, size_t);
};

struct driver_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___294 *, char *);
	ssize_t (*store)(struct device_driver___294 *, const char *, size_t);
};

struct device_driver___294 {
	const char *name;
	struct bus_type___294 *bus;
	struct module___184 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___294 *);
	int (*remove)(struct device___294 *);
	void (*shutdown)(struct device___294 *);
	int (*suspend)(struct device___294 *, pm_message_t);
	int (*resume)(struct device___294 *);
	const struct attribute_group___256 **groups;
	const struct dev_pm_ops___294 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___294 {
	const char *name;
	const struct attribute_group___256 **groups;
	int (*uevent)(struct device___294 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___294 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
};

struct class_attribute___294;

struct class___294 {
	const char *name;
	struct module___184 *owner;
	struct class_attribute___294 *class_attrs;
	struct device_attribute___294 *dev_attrs;
	const struct attribute_group___256 **dev_groups;
	struct bin_attribute___258 *dev_bin_attrs;
	struct kobject___78 *dev_kobj;
	int (*dev_uevent)(struct device___294 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___294 *, umode_t *);
	void (*class_release)(struct class___294 *);
	void (*dev_release)(struct device___294 *);
	int (*suspend)(struct device___294 *, pm_message_t);
	int (*resume)(struct device___294 *);
	const struct kobj_ns_type_operations___75 *ns_type;
	const void * (*namespace)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
	struct subsys_private *p;
};

struct class_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct class___294 *, struct class_attribute___294 *, char *);
	ssize_t (*store)(struct class___294 *, struct class_attribute___294 *, const char *, size_t);
	const void * (*namespace)(struct class___294 *, const struct class_attribute___294 *);
};

struct device_rh___294 {
	struct dev_pm_info_rh___294 power;
};

struct dev_pm_qos_request___98 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___294 *dev;
};

struct vm_fault___266 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___295 *page;
};

struct dma_device___14;

struct dma_chan_dev___14;

struct dma_chan___15 {
	struct dma_device___14 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___14 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	void *private;
};

struct dma_async_tx_descriptor___14;

struct dma_device___14 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	u8 copy_align;
	u8 xor_align;
	u8 pq_align;
	u8 fill_align;
	int dev_id;
	struct device___294 *dev;
	int (*device_alloc_chan_resources)(struct dma_chan___15 *);
	void (*device_free_chan_resources)(struct dma_chan___15 *);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_memcpy)(struct dma_chan___15 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_xor)(struct dma_chan___15 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_xor_val)(struct dma_chan___15 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_pq)(struct dma_chan___15 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_pq_val)(struct dma_chan___15 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_memset)(struct dma_chan___15 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_interrupt)(struct dma_chan___15 *, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_sg)(struct dma_chan___15 *, struct scatterlist *, unsigned int, struct scatterlist *, unsigned int, long unsigned int);
	struct dma_async_tx_descriptor___14 * (*device_prep_slave_sg)(struct dma_chan___15 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___14 * (*device_prep_dma_cyclic)(struct dma_chan___15 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___14 * (*device_prep_interleaved_dma)(struct dma_chan___15 *, struct dma_interleaved_template *, long unsigned int);
	int (*device_control)(struct dma_chan___15 *, enum dma_ctrl_cmd, long unsigned int);
	enum dma_status (*device_tx_status)(struct dma_chan___15 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___15 *);
};

struct dma_chan_dev___14 {
	struct dma_chan___15 *chan;
	struct device___294 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dma_async_tx_descriptor___14 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___15 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___14 *);
	dma_async_tx_callback callback;
	void *callback_param;
};

struct dma_page_list___9 {
	char *base_address;
	int nr_pages;
	struct page___295 **pages;
};

struct dma_pinned_list___9 {
	int nr_iovecs;
	struct dma_page_list___9 page_list[0];
};

struct dentry_operations___296;

struct super_block___296;

struct dentry___296 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___296 *d_parent;
	struct qstr d_name;
	struct inode___296 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___296 *d_op;
	struct super_block___296 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___296;

struct dquot___296;

struct block_device___296;

struct inode___296 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___296 *i_op;
	struct super_block___296 *i_sb;
	struct address_space___296 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___298 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___296 *i_fop;
	struct file_lock___296 *i_flock;
	struct address_space___296 i_data;
	struct dquot___296 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___296 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___296 {
	int (*d_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_hash)(const struct dentry___296 *, struct qstr *);
	int (*d_compare)(const struct dentry___296 *, const struct dentry___296 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___296 *);
	void (*d_release)(struct dentry___296 *);
	void (*d_prune)(struct dentry___296 *);
	void (*d_iput)(struct dentry___296 *, struct inode___296 *);
	char * (*d_dname)(struct dentry___296 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___296 *);
	int (*d_manage)(struct dentry___296 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___296;

struct mem_dqinfo___296 {
	struct quota_format_type___296 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___296;

struct quota_info___296 {
	unsigned int flags;
	struct mutex___298 dqio_mutex;
	struct mutex___298 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___296 *files[2];
	struct mem_dqinfo___296 info[2];
	const struct quota_format_ops___296 *ops[2];
};

struct file_system_type___296;

struct super_operations___296;

struct dquot_operations___296;

struct quotactl_ops___296;

struct xattr_handler___192;

struct super_block___296 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___296 *s_type;
	const struct super_operations___296 *s_op;
	const struct dquot_operations___296 *dq_op;
	const struct quotactl_ops___296 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___296 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___192 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___296 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___296 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___298 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___296 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___296 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___296 *bd_inode;
	struct super_block___296 *bd_super;
	struct mutex___298 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___296 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___298 bd_fsfreeze_mutex;
};

struct cgroup___191;

struct cgroup_subsys_state___191 {
	struct cgroup___191 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___296 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___296 *ia_file;
};

struct dquot___296 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___298 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___296 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___296 {
	int qf_fmt_id;
	const struct quota_format_ops___296 *qf_ops;
	struct module___184 *qf_owner;
	struct quota_format_type___296 *qf_next;
};

struct quota_format_ops___296 {
	int (*check_quota_file)(struct super_block___296 *, int);
	int (*read_file_info)(struct super_block___296 *, int);
	int (*write_file_info)(struct super_block___296 *, int);
	int (*free_file_info)(struct super_block___296 *, int);
	int (*read_dqblk)(struct dquot___296 *);
	int (*commit_dqblk)(struct dquot___296 *);
	int (*release_dqblk)(struct dquot___296 *);
};

struct dquot_operations___296 {
	int (*write_dquot)(struct dquot___296 *);
	struct dquot___296 * (*alloc_dquot)(struct super_block___296 *, int);
	void (*destroy_dquot)(struct dquot___296 *);
	int (*acquire_dquot)(struct dquot___296 *);
	int (*release_dquot)(struct dquot___296 *);
	int (*mark_dirty)(struct dquot___296 *);
	int (*write_info)(struct super_block___296 *, int);
	qsize_t * (*get_reserved_space)(struct inode___296 *);
};

struct quotactl_ops___296 {
	int (*quota_on)(struct super_block___296 *, int, int, struct path___296 *);
	int (*quota_on_meta)(struct super_block___296 *, int, int);
	int (*quota_off)(struct super_block___296 *, int);
	int (*quota_sync)(struct super_block___296 *, int);
	int (*get_info)(struct super_block___296 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___296 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___296 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___296 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___296 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___296 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___296 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___296 *, unsigned int);
};

struct address_space_operations___296 {
	int (*writepage)(struct page___295 *, struct writeback_control *);
	int (*readpage)(struct file___296 *, struct page___295 *);
	int (*writepages)(struct address_space___296 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___295 *);
	int (*readpages)(struct file___296 *, struct address_space___296 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___296 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___295 **, void **);
	int (*write_end)(struct file___296 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___295 *, void *);
	sector_t (*bmap)(struct address_space___296 *, sector_t);
	void (*invalidatepage)(struct page___295 *, long unsigned int);
	int (*releasepage)(struct page___295 *, gfp_t);
	void (*freepage)(struct page___295 *);
	ssize_t (*direct_IO)(int, struct kiocb___83 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___296 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___296 *, struct page___295 *, struct page___295 *, enum migrate_mode);
	int (*launder_page)(struct page___295 *);
	int (*is_partially_uptodate)(struct page___295 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___295 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___296 *, struct page___295 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___296 *, sector_t *);
	void (*swap_deactivate)(struct file___296 *);
	void (*invalidatepage_range)(struct page___295 *, unsigned int, unsigned int);
};

struct inode_operations___296 {
	struct dentry___296 * (*lookup)(struct inode___296 *, struct dentry___296 *, unsigned int);
	void * (*follow_link)(struct dentry___296 *, struct nameidata *);
	int (*permission)(struct inode___296 *, int);
	struct posix_acl * (*get_acl)(struct inode___296 *, int);
	int (*readlink)(struct dentry___296 *, char *, int);
	void (*put_link)(struct dentry___296 *, struct nameidata *, void *);
	int (*create)(struct inode___296 *, struct dentry___296 *, umode_t, bool);
	int (*link)(struct dentry___296 *, struct inode___296 *, struct dentry___296 *);
	int (*unlink)(struct inode___296 *, struct dentry___296 *);
	int (*symlink)(struct inode___296 *, struct dentry___296 *, const char *);
	int (*mkdir)(struct inode___296 *, struct dentry___296 *, umode_t);
	int (*rmdir)(struct inode___296 *, struct dentry___296 *);
	int (*mknod)(struct inode___296 *, struct dentry___296 *, umode_t, dev_t);
	int (*rename)(struct inode___296 *, struct dentry___296 *, struct inode___296 *, struct dentry___296 *);
	int (*setattr)(struct dentry___296 *, struct iattr___296 *);
	int (*getattr)(struct vfsmount *, struct dentry___296 *, struct kstat *);
	int (*setxattr)(struct dentry___296 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___296 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___296 *, char *, size_t);
	int (*removexattr)(struct dentry___296 *, const char *);
	int (*fiemap)(struct inode___296 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___296 *, struct timespec *, int);
	int (*atomic_open)(struct inode___296 *, struct dentry___296 *, struct file___296 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___296;

struct lock_manager_operations___296;

struct file_lock___296 {
	struct file_lock___296 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___296 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___296 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___296 *fl_ops;
	const struct lock_manager_operations___296 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___296 {
	void (*fl_copy_lock)(struct file_lock___296 *, struct file_lock___296 *);
	void (*fl_release_private)(struct file_lock___296 *);
};

struct lock_manager_operations___296 {
	int (*lm_compare_owner)(struct file_lock___296 *, struct file_lock___296 *);
	long unsigned int (*lm_owner_key)(struct file_lock___296 *);
	void (*lm_notify)(struct file_lock___296 *);
	int (*lm_grant)(struct file_lock___296 *, struct file_lock___296 *, int);
	void (*lm_break)(struct file_lock___296 *);
	int (*lm_change)(struct file_lock___296 **, int);
};

struct file_system_type___296 {
	const char *name;
	int fs_flags;
	struct dentry___296 * (*mount)(struct file_system_type___296 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___296 *);
	struct module___184 *owner;
	struct file_system_type___296 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___296 {
	struct inode___296 * (*alloc_inode)(struct super_block___296 *);
	void (*destroy_inode)(struct inode___296 *);
	void (*dirty_inode)(struct inode___296 *, int);
	int (*write_inode)(struct inode___296 *, struct writeback_control *);
	int (*drop_inode)(struct inode___296 *);
	void (*evict_inode)(struct inode___296 *);
	void (*put_super)(struct super_block___296 *);
	int (*sync_fs)(struct super_block___296 *, int);
	int (*freeze_fs)(struct super_block___296 *);
	int (*unfreeze_fs)(struct super_block___296 *);
	int (*statfs)(struct dentry___296 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___296 *, int *, char *);
	void (*umount_begin)(struct super_block___296 *);
	int (*show_options)(struct seq_file___221 *, struct dentry___296 *);
	int (*show_devname)(struct seq_file___221 *, struct dentry___296 *);
	int (*show_path)(struct seq_file___221 *, struct dentry___296 *);
	int (*show_stats)(struct seq_file___221 *, struct dentry___296 *);
	ssize_t (*quota_read)(struct super_block___296 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___296 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___296 *);
	int (*bdev_try_to_free_page)(struct super_block___296 *, struct page___295 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___296 *);
	void (*free_cached_objects)(struct super_block___296 *, int);
};

struct xattr_handler___192 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___296 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___296 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___296 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___221;

struct seq_file___221 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___298 lock;
	const struct seq_operations___221 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct signal_struct___297 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___297 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___297 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___298 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___191 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___191 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___278 {
	void **freelist;
	long unsigned int tid;
	struct page___295 *page;
	struct page___295 *partial;
};

struct memcg_cache_params___279 {
	bool is_root_cache;
	union {
		struct kmem_cache___279 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___279 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___86 {
	atomic_t use;
	unsigned int mask;
	struct net_device___86 *physindev;
	struct net_device___86 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___86(struct sk_buff___88 **);

struct net_device_ops___86;

struct ethtool_ops___86;

struct header_ops___86;

struct inet6_dev___50;

struct netdev_rx_queue___86;

struct netdev_queue___86;

struct rtnl_link_ops___77;

struct dcbnl_rtnl_ops___86;

struct net_device___86 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___86 *netdev_ops;
	const struct ethtool_ops___86 *ethtool_ops;
	const struct header_ops___86 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___78 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___50 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___86 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___86 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___86 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___86 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___86 = 0,
		NETREG_REGISTERED___86 = 1,
		NETREG_UNREGISTERING___86 = 2,
		NETREG_UNREGISTERED___86 = 3,
		NETREG_RELEASED___86 = 4,
		NETREG_DUMMY___86 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___86 = 0,
		RTNL_LINK_INITIALIZING___86 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___86 *);
	struct netpoll_info *npinfo;
	struct net___100 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___294 dev;
	const struct attribute_group___256 *sysfs_groups[4];
	const struct rtnl_link_ops___77 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___86 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sec_path___21;

struct sk_buff___88 {
	struct sk_buff___88 *next;
	struct sk_buff___88 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___75 *sk;
	struct net_device___86 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path___21 *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___88 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___86 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct xfrm_state___21;

struct sec_path___21 {
	atomic_t refcnt;
	int len;
	struct xfrm_state___21 *xvec[6];
};

struct ethtool_ops___86 {
	int (*get_settings)(struct net_device___86 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___86 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___86 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___86 *);
	void (*get_regs)(struct net_device___86 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___86 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___86 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___86 *);
	void (*set_msglevel)(struct net_device___86 *, u32);
	int (*nway_reset)(struct net_device___86 *);
	u32 (*get_link)(struct net_device___86 *);
	int (*get_eeprom_len)(struct net_device___86 *);
	int (*get_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___86 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___86 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___86 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___86 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___86 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___86 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___86 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___86 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___86 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___86 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___86 *);
	void (*complete)(struct net_device___86 *);
	u32 (*get_priv_flags)(struct net_device___86 *);
	int (*set_priv_flags)(struct net_device___86 *, u32);
	int (*get_sset_count)(struct net_device___86 *, int);
	int (*get_rxnfc)(struct net_device___86 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___86 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___86 *, struct ethtool_flash *);
	int (*reset)(struct net_device___86 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___86 *);
	int (*get_rxfh_indir)(struct net_device___86 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___86 *, const u32 *);
	void (*get_channels)(struct net_device___86 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___86 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___86 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___86 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___86 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___86 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___86 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___86 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___86 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___86 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___86 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___86 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___45;

struct dst_entry___76 {
	struct callback_head callback_head;
	struct dst_entry___76 *child;
	struct net_device___86 *dev;
	struct dst_ops___100 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___76 *path;
	struct dst_entry___76 *from;
	struct xfrm_state___21 *xfrm;
	int (*input)(struct sk_buff___88 *);
	union {
		int (*output)(struct sock___75 *, struct sk_buff___88 *);
		struct {
			int (*output)(struct sk_buff___88 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___76 *next;
		struct rtable___45 *rt_next;
		struct rt6_info___24 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___76;

struct neigh_parms___76;

struct neigh_ops___76;

struct neighbour___76 {
	struct neighbour___76 *next;
	struct neigh_table___76 *tbl;
	struct neigh_parms___76 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___87 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___76 *, struct sk_buff___88 *);
	const struct neigh_ops___76 *ops;
	struct callback_head rcu;
	struct net_device___86 *dev;
	u8 primary_key[0];
};

struct fib6_node___24;

struct rt6_info___24 {
	struct dst_entry___76 dst;
	struct fib6_table___24 *rt6i_table;
	struct fib6_node___24 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___50 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___24 {
	struct fib6_node___24 *parent;
	struct fib6_node___24 *left;
	struct fib6_node___24 *right;
	struct rt6_info___24 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___24 *rr_ptr;
};

struct fib6_table___24 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___24 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___101 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___88 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___88 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___100 *, struct dst_entry___76 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___88 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___88 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___220 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___220 *);
	void (*irq_shutdown)(struct irq_data___220 *);
	void (*irq_enable)(struct irq_data___220 *);
	void (*irq_disable)(struct irq_data___220 *);
	void (*irq_ack)(struct irq_data___220 *);
	void (*irq_mask)(struct irq_data___220 *);
	void (*irq_mask_ack)(struct irq_data___220 *);
	void (*irq_unmask)(struct irq_data___220 *);
	void (*irq_eoi)(struct irq_data___220 *);
	int (*irq_set_affinity)(struct irq_data___220 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___220 *);
	int (*irq_set_type)(struct irq_data___220 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___220 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___220 *);
	void (*irq_bus_sync_unlock)(struct irq_data___220 *);
	void (*irq_cpu_online)(struct irq_data___220 *);
	void (*irq_cpu_offline)(struct irq_data___220 *);
	void (*irq_suspend)(struct irq_data___220 *);
	void (*irq_resume)(struct irq_data___220 *);
	void (*irq_pm_shutdown)(struct irq_data___220 *);
	void (*irq_print_chip)(struct irq_data___220 *, struct seq_file___221 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___220 *, void *);
	long unsigned int flags;
};

struct seq_operations___221 {
	void * (*start)(struct seq_file___221 *, loff_t *);
	void (*stop)(struct seq_file___221 *, void *);
	void * (*next)(struct seq_file___221 *, void *, loff_t *);
	int (*show)(struct seq_file___221 *, void *);
};

struct seq_net_private___16 {
	struct net___100 *net;
};

struct pernet_operations___33 {
	struct list_head list;
	int (*init)(struct net___100 *);
	void (*exit)(struct net___100 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___86 {
	int (*ieee_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___86 *);
	u8 (*setstate)(struct net_device___86 *, u8);
	void (*getpermhwaddr)(struct net_device___86 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___86 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___86 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___86 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___86 *, int, u8 *);
	void (*setpfccfg)(struct net_device___86 *, int, u8);
	void (*getpfccfg)(struct net_device___86 *, int, u8 *);
	u8 (*setall)(struct net_device___86 *);
	u8 (*getcap)(struct net_device___86 *, int, u8 *);
	int (*getnumtcs)(struct net_device___86 *, int, u8 *);
	int (*setnumtcs)(struct net_device___86 *, int, u8);
	u8 (*getpfcstate)(struct net_device___86 *);
	void (*setpfcstate)(struct net_device___86 *, u8);
	void (*getbcncfg)(struct net_device___86 *, int, u32 *);
	void (*setbcncfg)(struct net_device___86 *, int, u32);
	void (*getbcnrp)(struct net_device___86 *, int, u8 *);
	void (*setbcnrp)(struct net_device___86 *, int, u8);
	u8 (*setapp)(struct net_device___86 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___86 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___86 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___86 *, int, u8);
	u8 (*getdcbx)(struct net_device___86 *);
	u8 (*setdcbx)(struct net_device___86 *, u8);
	int (*peer_getappinfo)(struct net_device___86 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___86 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___86 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___86 *, struct cee_pfc *);
};

struct cgroupfs_root___191;

struct cgroup___191 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___191 *parent;
	struct dentry___296 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___191 *subsys[11];
	struct cgroupfs_root___191 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___298 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___191 {
	struct super_block___296 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___191 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___127 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___296 *, struct file___296 *);
	ssize_t (*read)(struct cgroup___191 *, struct cftype___127 *, struct file___296 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___191 *, struct cftype___127 *);
	s64 (*read_s64)(struct cgroup___191 *, struct cftype___127 *);
	int (*read_map)(struct cgroup___191 *, struct cftype___127 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___191 *, struct cftype___127 *, struct seq_file___221 *);
	ssize_t (*write)(struct cgroup___191 *, struct cftype___127 *, struct file___296 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___191 *, struct cftype___127 *, u64);
	int (*write_s64)(struct cgroup___191 *, struct cftype___127 *, s64);
	int (*write_string)(struct cgroup___191 *, struct cftype___127 *, const char *);
	int (*trigger)(struct cgroup___191 *, unsigned int);
	int (*release)(struct inode___296 *, struct file___296 *);
	int (*register_event)(struct cgroup___191 *, struct cftype___127 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___191 *, struct cftype___127 *, struct eventfd_ctx *);
};

struct cftype_set___123 {
	struct list_head node;
	struct cftype___127 *cfts;
};

struct task_and_cgroup___123 {
	struct task_struct___297 *task;
	struct cgroup___191 *cgrp;
	struct css_set___191 *cg;
};

struct cgroup_taskset___123 {
	struct task_and_cgroup___123 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___191 *cur_cgrp;
};

struct cgroup_subsys___123 {
	struct cgroup_subsys_state___191 * (*css_alloc)(struct cgroup___191 *);
	int (*css_online)(struct cgroup___191 *);
	void (*css_offline)(struct cgroup___191 *);
	void (*css_free)(struct cgroup___191 *);
	int (*can_attach)(struct cgroup___191 *, struct cgroup_taskset___123 *);
	void (*cancel_attach)(struct cgroup___191 *, struct cgroup_taskset___123 *);
	void (*attach)(struct cgroup___191 *, struct cgroup_taskset___123 *);
	void (*fork)(struct task_struct___297 *);
	void (*exit)(struct cgroup___191 *, struct cgroup___191 *, struct task_struct___297 *);
	void (*bind)(struct cgroup___191 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___191 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___127 *base_cftypes;
	struct cftype_set___123 base_cftset;
	struct module___184 *module;
};

struct request_sock_ops___59;

struct request_sock___60 {
	struct sock_common___75 __req_common;
	struct request_sock___60 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___59 *rsk_ops;
	struct sock___75 *sk;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_replay___21;

struct xfrm_type___21;

struct xfrm_mode___21;

struct xfrm_state___21 {
	struct net___100 *xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	atomic_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___21 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	struct xfrm_replay___21 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	long int saved_tmo;
	long unsigned int lastused;
	const struct xfrm_type___21 *type;
	struct xfrm_mode___21 *inner_mode;
	struct xfrm_mode___21 *inner_mode_iaf;
	struct xfrm_mode___21 *outer_mode;
	struct xfrm_sec_ctx___2 *security;
	void *data;
};

struct xfrm_policy_queue___21 {
	struct sk_buff_head___87 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___21 {
	struct net___100 *xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	atomic_t refcnt;
	struct timer_list timer;
	struct flow_cache_object flo;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___21 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
};

struct netlink_callback___88 {
	struct sk_buff___88 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___88 *, struct netlink_callback___88 *);
	int (*done)(struct netlink_callback___88 *);
	void *data;
	struct module___184 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___86 {
	int (*create)(struct sk_buff___88 *, struct net_device___86 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___88 *, unsigned char *);
	int (*rebuild)(struct sk_buff___88 *);
	int (*cache)(const struct neighbour___76 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___86 *, const unsigned char *);
};

struct napi_struct___86 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___86 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___86 *dev;
	struct sk_buff___88 *gro_list;
	struct sk_buff___88 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___86 {
	struct net_device___86 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___78 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___86 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___78 kobj;
	struct net_device___86 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___86 {
	int (*ndo_init)(struct net_device___86 *);
	void (*ndo_uninit)(struct net_device___86 *);
	int (*ndo_open)(struct net_device___86 *);
	int (*ndo_stop)(struct net_device___86 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___88 *, struct net_device___86 *);
	u16 (*ndo_select_queue)(struct net_device___86 *, struct sk_buff___88 *);
	void (*ndo_change_rx_flags)(struct net_device___86 *, int);
	void (*ndo_set_rx_mode)(struct net_device___86 *);
	int (*ndo_set_mac_address)(struct net_device___86 *, void *);
	int (*ndo_validate_addr)(struct net_device___86 *);
	int (*ndo_do_ioctl)(struct net_device___86 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___86 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___86 *, int);
	int (*ndo_neigh_setup)(struct net_device___86 *, struct neigh_parms___76 *);
	void (*ndo_tx_timeout)(struct net_device___86 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___86 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___86 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___86 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___86 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___86 *);
	int (*ndo_netpoll_setup)(struct net_device___86 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___86 *);
	int (*ndo_busy_poll)(struct napi_struct___86 *);
	int (*ndo_set_vf_mac)(struct net_device___86 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___86 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___86 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___86 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___86 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___86 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___86 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___86 *, int, struct sk_buff___88 *);
	int (*ndo_setup_tc)(struct net_device___86 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___86 *);
	int (*ndo_fcoe_disable)(struct net_device___86 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___86 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___86 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___86 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___86 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___86 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___86 *, const struct sk_buff___88 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___86 *, struct net_device___86 *);
	int (*ndo_del_slave)(struct net_device___86 *, struct net_device___86 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___76 *);
	void (*ndo_neigh_destroy)(struct neighbour___76 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___88 *, struct netlink_callback___88 *, struct net_device___86 *, int);
	int (*ndo_bridge_setlink)(struct net_device___86 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___88 *, u32, u32, struct net_device___86 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___86 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___86 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___86 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___86 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___86 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___86 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___88 *, struct net_device___86 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___86 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___86 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___86 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___76 {
	struct net___100 *net;
	struct net_device___86 *dev;
	struct neigh_parms___76 *next;
	int (*neigh_setup)(struct neighbour___76 *);
	void (*neigh_cleanup)(struct neighbour___76 *);
	struct neigh_table___76 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___50;

struct ifacaddr6___50;

struct inet6_dev___50 {
	struct net_device___86 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___50 *mc_list;
	struct ifmcaddr6___50 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___50 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___76 *nd_parms;
	struct inet6_dev___50 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___77 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___86 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___100 *, struct net_device___86 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___86 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___86 *, struct list_head *);
	size_t (*get_size)(const struct net_device___86 *);
	int (*fill_info)(struct sk_buff___88 *, const struct net_device___86 *);
	size_t (*get_xstats_size)(const struct net_device___86 *);
	int (*fill_xstats)(struct sk_buff___88 *, const struct net_device___86 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___100 * (*get_link_net)(const struct net_device___86 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___86 *, struct net_device___86 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___86 *, const struct net_device___86 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___88 *, const struct net_device___86 *, const struct net_device___86 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___76 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___88 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___76;

struct neigh_hash_table___76;

struct neigh_table___76 {
	struct neigh_table___76 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___86 *, __u32 *);
	int (*constructor)(struct neighbour___76 *);
	int (*pconstructor)(struct pneigh_entry___76 *);
	void (*pdestructor)(struct pneigh_entry___76 *);
	void (*proxy_redo)(struct sk_buff___88 *);
	char *id;
	struct neigh_parms___76 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___87 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___76 *nht;
	struct pneigh_entry___76 **phash_buckets;
};

struct neigh_ops___76 {
	int family;
	void (*solicit)(struct neighbour___76 *, struct sk_buff___88 *);
	void (*error_report)(struct neighbour___76 *, struct sk_buff___88 *);
	int (*output)(struct neighbour___76 *, struct sk_buff___88 *);
	int (*connected_output)(struct neighbour___76 *, struct sk_buff___88 *);
};

struct pneigh_entry___76 {
	struct pneigh_entry___76 *next;
	struct net___100 *net;
	struct net_device___86 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___76 {
	struct neighbour___76 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___45 {
	struct dst_entry___76 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___56;

struct inet_hashinfo___22;

struct proto___75 {
	void (*close)(struct sock___75 *, long int);
	int (*connect)(struct sock___75 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___75 *, int);
	struct sock___75 * (*accept)(struct sock___75 *, int, int *);
	int (*ioctl)(struct sock___75 *, int, long unsigned int);
	int (*init)(struct sock___75 *);
	void (*destroy)(struct sock___75 *);
	void (*shutdown)(struct sock___75 *, int);
	int (*setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___75 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___75 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___75 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___83 *, struct sock___75 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___83 *, struct sock___75 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___75 *, struct page___295 *, int, size_t, int);
	int (*bind)(struct sock___75 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___75 *, struct sk_buff___88 *);
	void (*release_cb)(struct sock___75 *);
	void (*mtu_reduced)(struct sock___75 *);
	void (*hash)(struct sock___75 *);
	void (*unhash)(struct sock___75 *);
	void (*rehash)(struct sock___75 *);
	int (*get_port)(struct sock___75 *, short unsigned int);
	void (*clear_sk)(struct sock___75 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___75 *);
	void (*enter_memory_pressure)(struct sock___75 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___279 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___59 *rsk_prot;
	struct timewait_sock_ops___56 *twsk_prot;
	union {
		struct inet_hashinfo___22 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module___184 *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___123 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___75 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___75 {
	void (*enter_memory_pressure)(struct sock___75 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct inet_hashinfo___22 {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	struct kmem_cache___279 *bind_bucket_cachep;
	long: 64;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
	atomic_t bsockets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_sock_ops___59 {
	int family;
	int obj_size;
	struct kmem_cache___279 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___75 *, struct request_sock___60 *);
	void (*send_ack)(struct sock___75 *, struct sk_buff___88 *, struct request_sock___60 *);
	void (*send_reset)(struct sock___75 *, struct sk_buff___88 *);
	void (*destructor)(struct request_sock___60 *);
	void (*syn_ack_timeout)(struct sock___75 *, struct request_sock___60 *);
};

struct timewait_sock_ops___56 {
	struct kmem_cache___279 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___75 *, struct sock___75 *, void *);
	void (*twsk_destructor)(struct sock___75 *);
};

struct listen_sock___13 {
	u8 max_qlen_log;
	u8 synflood_warned;
	int qlen;
	int qlen_young;
	int clock_hand;
	u32 hash_rnd;
	u32 nr_table_entries;
	struct request_sock___60 *syn_table[0];
};

struct fastopen_queue___13 {
	struct request_sock___60 *rskq_rst_head;
	struct request_sock___60 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
};

struct request_sock_queue___13 {
	struct request_sock___60 *rskq_accept_head;
	struct request_sock___60 *rskq_accept_tail;
	rwlock_t syn_wait_lock;
	u8 rskq_defer_accept;
	struct listen_sock___13 *listen_opt;
	struct fastopen_queue___13 *fastopenq;
};

struct inet_request_sock___8 {
	struct request_sock___60 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___88 *pktopts;
	};
};

struct inet_cork___29 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___76 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___29 {
	struct inet_cork___29 base;
	struct flowi fl;
};

struct ipv6_pinfo___28;

struct inet_sock___29 {
	struct sock___75 sk;
	struct ipv6_pinfo___28 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___29 cork;
};

struct ipv6_fl_socklist___27;

struct ipv6_pinfo___28 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___27 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___88 *pktoptions;
	struct sk_buff___88 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_bind_bucket___13;

struct inet_connection_sock_af_ops___13 {
	int (*queue_xmit)(struct sk_buff___88 *, struct flowi *);
	void (*send_check)(struct sock___75 *, struct sk_buff___88 *);
	int (*rebuild_header)(struct sock___75 *);
	void (*sk_rx_dst_set)(struct sock___75 *, const struct sk_buff___88 *);
	int (*conn_request)(struct sock___75 *, struct sk_buff___88 *);
	struct sock___75 * (*syn_recv_sock)(struct sock___75 *, struct sk_buff___88 *, struct request_sock___60 *, struct dst_entry___76 *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___75 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___75 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___75 *, struct sockaddr *);
	int (*bind_conflict)(const struct sock___75 *, const struct inet_bind_bucket___13 *, bool);
	void (*mtu_reduced)(struct sock___75 *);
};

struct inet_bind_bucket___13 {
	struct net___100 *ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	int num_owners;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_congestion_ops___8;

struct inet_connection_sock___13 {
	struct inet_sock___29 icsk_inet;
	struct request_sock_queue___13 icsk_accept_queue;
	struct inet_bind_bucket___13 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___8 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___13 *icsk_af_ops;
	unsigned int (*icsk_sync_mss)(struct sock___75 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
	} icsk_mtup;
	u32 icsk_ca_priv[16];
	u32 icsk_user_timeout;
};

struct tcp_congestion_ops___8 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___75 *);
	void (*release)(struct sock___75 *);
	u32 (*ssthresh)(struct sock___75 *);
	void (*cong_avoid)(struct sock___75 *, u32, u32);
	void (*set_state)(struct sock___75 *, u8);
	void (*cwnd_event)(struct sock___75 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___75 *, u32);
	u32 (*undo_cwnd)(struct sock___75 *);
	void (*pkts_acked)(struct sock___75 *, u32, s32);
	int (*get_info)(struct sock___75 *, u32, struct sk_buff___88 *);
	char name[16];
	struct module___184 *owner;
};

struct inet_timewait_death_row___8 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___22 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct inet_timewait_sock___8 {
	struct sock_common___75 __tw_common;
	int tw_timeout;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_ipv6only: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	u32 tw_ttd;
	struct inet_bind_bucket___13 *tw_tb;
	struct hlist_node tw_death_node;
};

struct tcp_request_sock_ops___6;

struct tcp_request_sock___7 {
	struct inet_request_sock___8 req;
	const struct tcp_request_sock_ops___6 *af_specific;
	struct sock___75 *listener;
	u32 rcv_isn;
	u32 snt_isn;
	u32 snt_synack;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___6 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___75 *, struct request_sock___60 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___75 *, const struct request_sock___60 *, const struct sk_buff___88 *);
	void (*init_req)(struct request_sock___60 *, struct sock___75 *, struct sk_buff___88 *);
	__u32 (*cookie_init_seq)(struct sock___75 *, const struct sk_buff___88 *, __u16 *);
	struct dst_entry___76 * (*route_req)(struct sock___75 *, struct flowi *, const struct request_sock___60 *, bool *);
	__u32 (*init_seq)(const struct sk_buff___88 *);
	int (*send_synack)(struct sock___75 *, struct dst_entry___76 *, struct flowi *, struct request_sock___60 *, u16, struct tcp_fastopen_cookie *);
	void (*queue_hash_add)(struct sock___75 *, struct request_sock___60 *, const long unsigned int);
};

struct tcp_sock_af_ops___8;

struct tcp_sock___9 {
	struct inet_connection_sock___13 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 tsoffset;
	struct list_head tsq_node;
	long unsigned int tsq_flags;
	struct {
		struct sk_buff_head___87 prequeue;
		struct task_struct___297 *task;
		struct iovec *iov;
		int memory;
		int len;
		struct dma_chan___15 *rh_reserved_dma_chan;
		int rh_reserved_wakeup;
		struct dma_pinned_list___9 *rh_reserved_pinned_list;
		dma_cookie_t rh_reserved_dma_cookie;
	} ucopy;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	u16 advmss;
	u8 unused;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 thin_dupack: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 do_early_retrans: 1;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	u32 tlp_high_seq;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 reordering;
	u32 snd_up;
	u8 keepalive_probes;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	u32 fackets_out;
	u32 tso_deferred;
	struct sk_buff___88 *lost_skb_hint;
	struct sk_buff___88 *retransmit_skb_hint;
	struct sk_buff_head___87 out_of_order_queue;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___88 *highest_sack;
	int lost_cnt_hint;
	u32 retransmit_high;
	u32 lost_retrans_low;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	struct {
		u32 rtt;
		u32 seq;
		u32 time;
	} rcv_rtt_est;
	struct {
		int space;
		u32 seq;
		u32 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___8 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___60 *fastopen_rsk;
};

struct tcp_sock_af_ops___8 {
	struct tcp_md5sig_key * (*md5_lookup)(struct sock___75 *, struct sock___75 *);
	int (*calc_md5_hash)(char *, struct tcp_md5sig_key *, const struct sock___75 *, const struct request_sock___60 *, const struct sk_buff___88 *);
	int (*md5_parse)(struct sock___75 *, char *, int);
};

struct tcp_timewait_sock___3 {
	struct inet_timewait_sock___8 tw_sk;
	u32 tw_rcv_nxt;
	u32 tw_snd_nxt;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	long int tw_ts_recent_stamp;
	struct tcp_md5sig_key *tw_md5_key;
};

struct ip6_flowlabel___27;

struct ipv6_fl_socklist___27 {
	struct ipv6_fl_socklist___27 *next;
	struct ip6_flowlabel___27 *fl;
	struct callback_head rcu;
};

struct tcp6_sock {
	struct tcp_sock___9 tcp;
	struct ipv6_pinfo___28 inet6;
};

struct crypto_async_request___13;

typedef void (*crypto_completion_t___13)(struct crypto_async_request___13 *, int);

struct crypto_tfm___13;

struct crypto_async_request___13 {
	struct list_head list;
	crypto_completion_t___13 complete;
	void *data;
	struct crypto_tfm___13 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___13;

struct ablkcipher_request___13;

struct ablkcipher_tfm___13 {
	int (*setkey)(struct crypto_ablkcipher___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___13 *);
	int (*decrypt)(struct ablkcipher_request___13 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	struct crypto_ablkcipher___13 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct crypto_aead___13;

struct aead_request___13;

struct aead_tfm___13 {
	int (*setkey)(struct crypto_aead___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct aead_request___13 *);
	int (*decrypt)(struct aead_request___13 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	struct crypto_aead___13 *base;
	unsigned int ivsize;
	unsigned int authsize;
	unsigned int reqsize;
};

struct blkcipher_desc___13;

struct blkcipher_tfm___13 {
	void *iv;
	int (*setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___13 {
	int (*cit_setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___13 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___13 *, u8 *, const u8 *);
};

struct hash_desc___13;

struct crypto_hash___13;

struct hash_tfm___13 {
	int (*init)(struct hash_desc___13 *);
	int (*update)(struct hash_desc___13 *, struct scatterlist *, unsigned int);
	int (*final)(struct hash_desc___13 *, u8 *);
	int (*digest)(struct hash_desc___13 *, struct scatterlist *, unsigned int, u8 *);
	int (*setkey)(struct crypto_hash___13 *, const u8 *, unsigned int);
	unsigned int digestsize;
};

struct compress_tfm___13 {
	int (*cot_compress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_rng___13;

struct rng_tfm___13 {
	int (*rng_gen_random)(struct crypto_rng___13 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___13 *, u8 *, unsigned int);
};

struct crypto_alg___13;

struct crypto_tfm___13 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___13 ablkcipher;
		struct aead_tfm___13 aead;
		struct blkcipher_tfm___13 blkcipher;
		struct cipher_tfm___13 cipher;
		struct hash_tfm___13 hash;
		struct compress_tfm___13 compress;
		struct rng_tfm___13 rng;
	} crt_u;
	void (*exit)(struct crypto_tfm___13 *);
	struct crypto_alg___13 *__crt_alg;
	void *__crt_ctx[0];
};

struct ablkcipher_request___13 {
	struct crypto_async_request___13 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct aead_request___13 {
	struct crypto_async_request___13 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *assoc;
	struct scatterlist *src;
	struct scatterlist *dst;
	void *__ctx[0];
};

struct crypto_blkcipher___13;

struct blkcipher_desc___13 {
	struct crypto_blkcipher___13 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___13 {
	struct crypto_tfm___13 base;
};

struct hash_desc___13 {
	struct crypto_hash___13 *tfm;
	u32 flags;
};

struct crypto_hash___13 {
	struct crypto_tfm___13 base;
};

struct ablkcipher_alg___13 {
	int (*setkey)(struct crypto_ablkcipher___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___13 *);
	int (*decrypt)(struct ablkcipher_request___13 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___13 {
	struct crypto_tfm___13 base;
};

struct aead_alg___13 {
	int (*setkey)(struct crypto_aead___13 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___13 *, unsigned int);
	int (*encrypt)(struct aead_request___13 *);
	int (*decrypt)(struct aead_request___13 *);
	int (*givencrypt)(struct aead_givcrypt_request *);
	int (*givdecrypt)(struct aead_givcrypt_request *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
};

struct crypto_aead___13 {
	struct crypto_tfm___13 base;
};

struct blkcipher_alg___13 {
	int (*setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___13 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
};

struct compress_alg___13 {
	int (*coa_compress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct rng_alg___13 {
	int (*rng_make_random)(struct crypto_rng___13 *, u8 *, unsigned int);
	int (*rng_reset)(struct crypto_rng___13 *, u8 *, unsigned int);
	unsigned int seedsize;
};

struct crypto_rng___13 {
	struct crypto_tfm___13 base;
};

struct crypto_alg___13 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	atomic_t cra_refcnt;
	char cra_name[64];
	char cra_driver_name[64];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___13 ablkcipher;
		struct aead_alg___13 aead;
		struct blkcipher_alg___13 blkcipher;
		struct cipher_alg___13 cipher;
		struct compress_alg___13 compress;
		struct rng_alg___13 rng;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___13 *);
	void (*cra_exit)(struct crypto_tfm___13 *);
	void (*cra_destroy)(struct crypto_alg___13 *);
	struct module___184 *cra_module;
};

struct ifmcaddr6___50 {
	struct in6_addr mca_addr;
	struct inet6_dev___50 *idev;
	struct ifmcaddr6___50 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___50 {
	struct in6_addr aca_addr;
	struct inet6_dev___50 *aca_idev;
	struct rt6_info___24 *aca_rt;
	struct ifacaddr6___50 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___27 {
	struct ip6_flowlabel___27 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___100 *fl_net;
};

struct tcp_md5sig_pool___2 {
	struct hash_desc___13 md5_desc;
	union tcp_md5sum_block md5_blk;
};

struct tcp_seq_afinfo___2 {
	char *name;
	sa_family_t family;
	const struct file_operations___296 *seq_fops;
	struct seq_operations___221 seq_ops;
};

struct tcp_iter_state___2 {
	struct seq_net_private___16 p;
	sa_family_t family;
	enum tcp_seq_states state;
	struct sock___75 *syn_wait_sk;
	int bucket;
	int offset;
	int sbucket;
	int num;
	kuid_t uid;
	loff_t last_pos;
};

struct inet6_protocol___4 {
	void (*early_demux)(struct sk_buff___88 *);
	int (*handler)(struct sk_buff___88 *);
	void (*err_handler)(struct sk_buff___88 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct inet_protosw___6 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___75 *prot;
	const struct proto_ops___75 *ops;
	unsigned char flags;
};

struct xfrm_replay___21 {
	void (*advance)(struct xfrm_state___21 *, __be32);
	int (*check)(struct xfrm_state___21 *, struct sk_buff___88 *, __be32);
	int (*recheck)(struct xfrm_state___21 *, struct sk_buff___88 *, __be32);
	void (*notify)(struct xfrm_state___21 *, int);
	int (*overflow)(struct xfrm_state___21 *, struct sk_buff___88 *);
};

struct xfrm_type___21 {
	char *description;
	struct module___184 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___21 *);
	void (*destructor)(struct xfrm_state___21 *);
	int (*input)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*output)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*reject)(struct xfrm_state___21 *, struct sk_buff___88 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___21 *, struct sk_buff___88 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___21 *, int);
};

struct xfrm_state_afinfo___21;

struct xfrm_mode___21 {
	int (*input2)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*input)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*output2)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*output)(struct xfrm_state___21 *, struct sk_buff___88 *);
	struct xfrm_state_afinfo___21 *afinfo;
	struct module___184 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_state_afinfo___21 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___184 *owner;
	const struct xfrm_type___21 *type_map[256];
	struct xfrm_mode___21 *mode_map[5];
	int (*init_flags)(struct xfrm_state___21 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___21 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___21 **, struct xfrm_state___21 **, int);
	union {
		int (*output)(struct sock___75 *, struct sk_buff___88 *);
		struct {
			int (*output)(struct sk_buff___88 *);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		int (*output_finish)(struct sock___75 *, struct sk_buff___88 *);
		struct {
			int (*output_finish)(struct sk_buff___88 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*extract_input)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*extract_output)(struct xfrm_state___21 *, struct sk_buff___88 *);
	int (*transport_finish)(struct sk_buff___88 *, int);
};

struct rt0_hdr {
	struct ipv6_rt_hdr rt_hdr;
	__u32 reserved;
	struct in6_addr addr[0];
};

struct tlvtype_proc {
	int type;
	bool (*func)(struct sk_buff___86 *, int);
};

struct page___296;

typedef struct page___296 *pgtable_t___296;

struct address_space___297;

struct kmem_cache___280;

struct page___296 {
	long unsigned int flags;
	struct address_space___297 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___296 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___296 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___280 *slab_cache;
		struct page___296 *first_page;
	};
	long: 64;
};

struct task_struct___298;

struct pv_cpu_ops___298 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___298 *);
	void (*end_context_switch)(struct task_struct___298 *);
};

struct mutex___299 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___298 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
};

struct page_frag___291 {
	struct page___296 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___305;

struct nsproxy___177;

struct signal_struct___298;

struct css_set___192;

struct task_struct___298 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___298 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___305 *mm;
	struct mm_struct___305 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___298 *real_parent;
	struct task_struct___298 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___298 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___97 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___298 = 0,
		VTIME_USER___298 = 1,
		VTIME_SYS___298 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___177 *nsproxy;
	struct signal_struct___298 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___192 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___299 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___291 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___305 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___305 *, struct mm_struct___305 *);
	void (*dup_mmap)(struct mm_struct___305 *, struct mm_struct___305 *);
	void (*exit_mmap)(struct mm_struct___305 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___305 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___305 *);
	void (*pgd_free)(struct mm_struct___305 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___305 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___305 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___305 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___305 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___305 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___305 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___305 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___305 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___305 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___305 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___305 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___299 lock;
	void *vdso;
} mm_context_t___299;

struct xol_area___296;

struct uprobes_state___296 {
	struct xol_area___296 *xol_area;
};

struct vm_area_struct___305;

struct file___297;

struct core_state___298;

struct mm_struct___305 {
	struct vm_area_struct___305 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___305 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___305 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___299 context;
	long unsigned int flags;
	struct core_state___298 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___298 *owner;
	struct file___297 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___296 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct irq_data___221;

struct x86_io_apic_ops___221 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___221 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___221;

struct irq_data___221 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___221 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___295;

struct dev_pm_ops___295 {
	int (*prepare)(struct device___295 *);
	void (*complete)(struct device___295 *);
	int (*suspend)(struct device___295 *);
	int (*resume)(struct device___295 *);
	int (*freeze)(struct device___295 *);
	int (*thaw)(struct device___295 *);
	int (*poweroff)(struct device___295 *);
	int (*restore)(struct device___295 *);
	int (*suspend_late)(struct device___295 *);
	int (*resume_early)(struct device___295 *);
	int (*freeze_late)(struct device___295 *);
	int (*thaw_early)(struct device___295 *);
	int (*poweroff_late)(struct device___295 *);
	int (*restore_early)(struct device___295 *);
	int (*suspend_noirq)(struct device___295 *);
	int (*resume_noirq)(struct device___295 *);
	int (*freeze_noirq)(struct device___295 *);
	int (*thaw_noirq)(struct device___295 *);
	int (*poweroff_noirq)(struct device___295 *);
	int (*restore_noirq)(struct device___295 *);
	int (*runtime_suspend)(struct device___295 *);
	int (*runtime_resume)(struct device___295 *);
	int (*runtime_idle)(struct device___295 *);
};

struct kset___79;

struct kobj_type___79;

struct kobject___79 {
	const char *name;
	struct list_head entry;
	struct kobject___79 *parent;
	struct kset___79 *kset;
	struct kobj_type___79 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct dev_pm_qos___98;

struct dev_pm_info___98 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___98 *qos;
};

struct dma_map_ops___160;

struct dev_archdata___160 {
	struct dma_map_ops___160 *dma_ops;
	void *iommu;
};

struct device_type___295;

struct bus_type___295;

struct device_driver___295;

struct dev_pm_domain___295;

struct class___295;

struct attribute_group___257;

struct device_rh___295;

struct device___295 {
	struct device___295 *parent;
	struct device_private *p;
	struct kobject___79 kobj;
	const char *init_name;
	const struct device_type___295 *type;
	struct mutex___299 mutex;
	struct bus_type___295 *bus;
	struct device_driver___295 *driver;
	void *platform_data;
	struct dev_pm_info___98 power;
	struct dev_pm_domain___295 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___160 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___295 *class;
	const struct attribute_group___257 **groups;
	void (*release)(struct device___295 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___295 *device_rh;
};

struct dev_pm_qos_request___99;

struct dev_pm_qos___98 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___99 *latency_req;
	struct dev_pm_qos_request___99 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___99 *latency_tolerance_req;
};

struct dev_pm_info_rh___295 {
	void (*set_latency_tolerance)(struct device___295 *, s32);
};

struct dev_pm_domain___295 {
	struct dev_pm_ops___295 ops;
};

struct smp_ops___298 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___298 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___298;

struct lruvec___298 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___298 *zone;
};

struct pglist_data___298;

struct zone___298 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___298 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___298 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___298 {
	struct zone___298 *zone;
	int zone_idx;
};

struct zonelist___298 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___298 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___298 {
	struct zone___298 node_zones[4];
	struct zonelist___298 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___298 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_file___222;

struct irq_chip___221 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___221 *);
	void (*irq_shutdown)(struct irq_data___221 *);
	void (*irq_enable)(struct irq_data___221 *);
	void (*irq_disable)(struct irq_data___221 *);
	void (*irq_ack)(struct irq_data___221 *);
	void (*irq_mask)(struct irq_data___221 *);
	void (*irq_mask_ack)(struct irq_data___221 *);
	void (*irq_unmask)(struct irq_data___221 *);
	void (*irq_eoi)(struct irq_data___221 *);
	int (*irq_set_affinity)(struct irq_data___221 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___221 *);
	int (*irq_set_type)(struct irq_data___221 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___221 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___221 *);
	void (*irq_bus_sync_unlock)(struct irq_data___221 *);
	void (*irq_cpu_online)(struct irq_data___221 *);
	void (*irq_cpu_offline)(struct irq_data___221 *);
	void (*irq_suspend)(struct irq_data___221 *);
	void (*irq_resume)(struct irq_data___221 *);
	void (*irq_pm_shutdown)(struct irq_data___221 *);
	void (*irq_print_chip)(struct irq_data___221 *, struct seq_file___222 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___221 *, void *);
	long unsigned int flags;
};

struct seq_operations___222;

struct seq_file___222 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___299 lock;
	const struct seq_operations___222 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct xol_area___296 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___296 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___279;

struct memcg_cache_params___280;

struct kmem_cache___280 {
	struct kmem_cache_cpu___279 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___79 kobj;
	struct memcg_cache_params___280 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___297;

struct address_space_operations___297;

struct address_space___297 {
	struct inode___297 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___299 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___297 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___297;

struct path___297 {
	struct vfsmount *mnt;
	struct dentry___297 *dentry;
};

struct file_operations___297;

struct file___297 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___297 f_path;
	struct inode___297 *f_inode;
	const struct file_operations___297 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___297 *f_mapping;
	struct mutex___299 f_pos_lock;
};

struct vm_operations_struct___271;

struct vm_area_struct___305 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___305 *vm_next;
	struct vm_area_struct___305 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___305 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___271 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___297 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___267;

struct vm_operations_struct___271 {
	void (*open)(struct vm_area_struct___305 *);
	void (*close)(struct vm_area_struct___305 *);
	int (*fault)(struct vm_area_struct___305 *, struct vm_fault___267 *);
	int (*page_mkwrite)(struct vm_area_struct___305 *, struct vm_fault___267 *);
	int (*access)(struct vm_area_struct___305 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___305 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___305 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___305 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___305 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___298 {
	struct task_struct___298 *task;
	struct core_thread___298 *next;
};

struct core_state___298 {
	atomic_t nr_threads;
	struct core_thread___298 dumper;
	struct completion startup;
};

struct fasync_struct___297;

struct socket_wq___76 {
	wait_queue_head_t wait;
	struct fasync_struct___297 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___297 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___297 *fa_next;
	struct file___297 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___76;

struct proto_ops___76;

struct socket___77 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___76 *wq;
	struct file___297 *file;
	struct sock___76 *sk;
	const struct proto_ops___76 *ops;
};

struct proto___76;

struct net___101;

struct sock_common___76 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___76 *skc_prot;
	struct net___101 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___89;

struct sk_buff_head___88 {
	struct sk_buff___89 *next;
	struct sk_buff___89 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___77;

struct dst_entry___77;

struct cg_proto___76;

struct sock___76 {
	struct sock_common___76 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___88 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___89 *head;
		struct sk_buff___89 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___77 *sk_filter;
	struct socket_wq___76 *sk_wq;
	struct sk_buff_head___88 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___77 *sk_rx_dst;
	struct dst_entry___77 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___88 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___88 sk_error_queue;
	struct proto___76 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___97 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___77 *sk_socket;
	void *sk_user_data;
	struct page_frag___291 sk_frag;
	struct sk_buff___89 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___76 *sk_cgrp;
	void (*sk_state_change)(struct sock___76 *);
	void (*sk_data_ready)(struct sock___76 *, int);
	void (*sk_write_space)(struct sock___76 *);
	void (*sk_error_report)(struct sock___76 *);
	int (*sk_backlog_rcv)(struct sock___76 *, struct sk_buff___89 *);
	void (*sk_destruct)(struct sock___76 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___183;

struct kiocb___84;

struct proto_ops___76 {
	int family;
	struct module *owner;
	int (*release)(struct socket___77 *);
	int (*bind)(struct socket___77 *, struct sockaddr *, int);
	int (*connect)(struct socket___77 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___77 *, struct socket___77 *);
	int (*accept)(struct socket___77 *, struct socket___77 *, int);
	int (*getname)(struct socket___77 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___297 *, struct socket___77 *, struct poll_table_struct___183 *);
	int (*ioctl)(struct socket___77 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___77 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___77 *, int);
	int (*shutdown)(struct socket___77 *, int);
	int (*setsockopt)(struct socket___77 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___77 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___77 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___77 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___84 *, struct socket___77 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___84 *, struct socket___77 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___297 *, struct socket___77 *, struct vm_area_struct___305 *);
	ssize_t (*sendpage)(struct socket___77 *, struct page___296 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___77 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___76 *, int);
		struct {
			void (*set_peek_off)(struct sock___76 *, int);
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
};

typedef void (*poll_queue_proc___185)(struct file___297 *, wait_queue_head_t *, struct poll_table_struct___183 *);

struct poll_table_struct___183 {
	poll_queue_proc___185 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___84(struct kiocb___84 *, struct io_event *);

struct kiocb___84 {
	atomic_t ki_users;
	struct file___297 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___84 *ki_cancel;
	void (*ki_dtor)(struct kiocb___84 *);
	union {
		void *user;
		struct task_struct___298 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___102;

struct ctl_table_set___102;

struct ctl_dir___102;

struct ctl_node___102;

struct ctl_table_header___102 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___102 *root;
	struct ctl_table_set___102 *set;
	struct ctl_dir___102 *parent;
	struct ctl_node___102 *node;
};

struct ctl_dir___102 {
	struct ctl_table_header___102 header;
	struct rb_root root;
};

struct ctl_table_set___102 {
	int (*is_seen)(struct ctl_table_set___102 *);
	struct ctl_dir___102 dir;
};

struct netns_core___99 {
	struct ctl_table_header___102 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___100 {
	struct mutex___299 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___99 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___102 *ctl;
};

struct netns_ipv4___99 {
	struct ctl_table_header___102 *forw_hdr;
	struct ctl_table_header___102 *frags_hdr;
	struct ctl_table_header___102 *ipv4_hdr;
	struct ctl_table_header___102 *route_hdr;
	struct ctl_table_header___102 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___76 *fibnl;
	struct sock___76 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___99 {
	struct ctl_table_header___102 *hdr;
	struct ctl_table_header___102 *route_hdr;
	struct ctl_table_header___102 *icmp_hdr;
	struct ctl_table_header___102 *frags_hdr;
	struct ctl_table_header___102 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___87;

struct neighbour___77;

struct dst_ops___101 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___101 *);
	struct dst_entry___77 * (*check)(struct dst_entry___77 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___77 *);
	unsigned int (*mtu)(const struct dst_entry___77 *);
	u32 * (*cow_metrics)(struct dst_entry___77 *, long unsigned int);
	void (*destroy)(struct dst_entry___77 *);
	void (*ifdown)(struct dst_entry___77 *, struct net_device___87 *, int);
	struct dst_entry___77 * (*negative_advice)(struct dst_entry___77 *);
	void (*link_failure)(struct sk_buff___89 *);
	void (*update_pmtu)(struct dst_entry___77 *, struct sock___76 *, struct sk_buff___89 *, u32);
	void (*redirect)(struct dst_entry___77 *, struct sock___76 *, struct sk_buff___89 *);
	int (*local_out)(struct sk_buff___89 *);
	struct neighbour___77 * (*neigh_lookup)(const struct dst_entry___77 *, struct sk_buff___89 *, const void *);
	struct kmem_cache___280 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___25;

struct fib6_table___25;

struct netns_ipv6___101 {
	struct netns_sysctl_ipv6___99 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___25 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___25 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___101 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___25 *ip6_prohibit_entry;
	struct rt6_info___25 *ip6_blk_hole_entry;
	struct fib6_table___25 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___76 **icmp_sk;
	struct sock___76 *ndisc_sk;
	struct sock___76 *tcp_sk;
	struct sock___76 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___99 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___102 *sysctl_header;
	struct sock___76 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___76 {
	struct sock___76 *v4_ctl_sk;
	struct sock___76 *v6_ctl_sk;
};

struct netns_nf___99 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___102 *nf_log_dir_header;
};

struct nf_proto_net___99 {
	struct ctl_table_header___102 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___99 {
	struct nf_proto_net___99 pn;
	unsigned int timeout;
};

struct nf_tcp_net___99 {
	struct nf_proto_net___99 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___99 {
	struct nf_proto_net___99 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___99 {
	struct nf_proto_net___99 pn;
	unsigned int timeout;
};

struct nf_ip_net___99 {
	struct nf_generic_net___99 generic;
	struct nf_tcp_net___99 tcp;
	struct nf_udp_net___99 udp;
	struct nf_icmp_net___99 icmp;
	struct nf_icmp_net___99 icmpv6;
};

struct netns_ct___100 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___102 *sysctl_header;
	struct ctl_table_header___102 *acct_sysctl_header;
	struct ctl_table_header___102 *tstamp_sysctl_header;
	struct ctl_table_header___102 *event_sysctl_header;
	struct ctl_table_header___102 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___280 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___99 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___99 {
	struct netns_sysctl_ipv6___99 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___101 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___76 *nlsk;
	struct sock___76 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___102 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___101 xfrm4_dst_ops;
	struct dst_ops___101 xfrm6_dst_ops;
};

struct net___101 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___102 sysctls;
	struct sock___76 *rtnl;
	struct sock___76 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___87 *loopback_dev;
	struct netns_core___99 core;
	struct netns_mib mib;
	struct netns_packet___100 packet;
	struct netns_unix___99 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___99 ipv4;
	struct netns_ipv6___101 ipv6;
	struct netns_sctp___99 sctp;
	struct netns_dccp___76 dccp;
	struct netns_nf___99 nf;
	struct netns_xt xt;
	struct netns_ct___100 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___99 nf_frag;
	struct sock___76 *nfnl;
	struct sock___76 *nfnl_stash;
	struct sk_buff_head___88 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___101 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___76 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___76 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___299 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___299 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kobj_ns_type_operations___76 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___76 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___259;

struct attribute_group___257 {
	const char *name;
	umode_t (*is_visible)(struct kobject___79 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___259 **bin_attrs;
};

struct bin_attribute___259 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___297 *, struct kobject___79 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___297 *, struct kobject___79 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	int (*mmap)(struct file___297 *, struct kobject___79 *, struct bin_attribute___259 *, struct vm_area_struct___305 *);
};

struct sysfs_ops___79 {
	ssize_t (*show)(struct kobject___79 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___79 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___79 *, const struct attribute *);
};

struct kset_uevent_ops___79;

struct kset___79 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___79 kobj;
	const struct kset_uevent_ops___79 *uevent_ops;
};

struct kobj_type___79 {
	void (*release)(struct kobject___79 *);
	const struct sysfs_ops___79 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___76 * (*child_ns_type)(struct kobject___79 *);
	const void * (*namespace)(struct kobject___79 *);
};

struct kset_uevent_ops___79 {
	int (* const filter)(struct kset___79 *, struct kobject___79 *);
	const char * (* const name)(struct kset___79 *, struct kobject___79 *);
	int (* const uevent)(struct kset___79 *, struct kobject___79 *, struct kobj_uevent_env *);
};

struct kmem_cache_cpu___279 {
	void **freelist;
	long unsigned int tid;
	struct page___296 *page;
	struct page___296 *partial;
};

struct memcg_cache_params___280 {
	bool is_root_cache;
	union {
		struct kmem_cache___280 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___280 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___160 {
	void * (*alloc)(struct device___295 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___295 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___295 *, struct vm_area_struct___305 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___295 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___295 *, struct page___296 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___295 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___295 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___295 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___295 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___295 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___295 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___295 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___295 *, dma_addr_t);
	int (*dma_supported)(struct device___295 *, u64);
	int (*set_dma_mask)(struct device___295 *, u64);
	int is_phys;
};

struct bus_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___295 *, char *);
	ssize_t (*store)(struct bus_type___295 *, const char *, size_t);
};

struct device_attribute___295;

struct driver_attribute___295;

struct bus_type___295 {
	const char *name;
	const char *dev_name;
	struct device___295 *dev_root;
	struct bus_attribute___295 *bus_attrs;
	struct device_attribute___295 *dev_attrs;
	struct driver_attribute___295 *drv_attrs;
	const struct attribute_group___257 **bus_groups;
	const struct attribute_group___257 **dev_groups;
	const struct attribute_group___257 **drv_groups;
	int (*match)(struct device___295 *, struct device_driver___295 *);
	int (*uevent)(struct device___295 *, struct kobj_uevent_env *);
	int (*probe)(struct device___295 *);
	int (*remove)(struct device___295 *);
	void (*shutdown)(struct device___295 *);
	int (*online)(struct device___295 *);
	int (*offline)(struct device___295 *);
	int (*suspend)(struct device___295 *, pm_message_t);
	int (*resume)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct device___295 *, struct device_attribute___295 *, char *);
	ssize_t (*store)(struct device___295 *, struct device_attribute___295 *, const char *, size_t);
};

struct driver_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___295 *, char *);
	ssize_t (*store)(struct device_driver___295 *, const char *, size_t);
};

struct device_driver___295 {
	const char *name;
	struct bus_type___295 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___295 *);
	int (*remove)(struct device___295 *);
	void (*shutdown)(struct device___295 *);
	int (*suspend)(struct device___295 *, pm_message_t);
	int (*resume)(struct device___295 *);
	const struct attribute_group___257 **groups;
	const struct dev_pm_ops___295 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___295 {
	const char *name;
	const struct attribute_group___257 **groups;
	int (*uevent)(struct device___295 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___295 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
};

struct class_attribute___295;

struct class___295 {
	const char *name;
	struct module *owner;
	struct class_attribute___295 *class_attrs;
	struct device_attribute___295 *dev_attrs;
	const struct attribute_group___257 **dev_groups;
	struct bin_attribute___259 *dev_bin_attrs;
	struct kobject___79 *dev_kobj;
	int (*dev_uevent)(struct device___295 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___295 *, umode_t *);
	void (*class_release)(struct class___295 *);
	void (*dev_release)(struct device___295 *);
	int (*suspend)(struct device___295 *, pm_message_t);
	int (*resume)(struct device___295 *);
	const struct kobj_ns_type_operations___76 *ns_type;
	const void * (*namespace)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
	struct subsys_private *p;
};

struct class_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct class___295 *, struct class_attribute___295 *, char *);
	ssize_t (*store)(struct class___295 *, struct class_attribute___295 *, const char *, size_t);
	const void * (*namespace)(struct class___295 *, const struct class_attribute___295 *);
};

struct device_rh___295 {
	struct dev_pm_info_rh___295 power;
};

struct vm_fault___267 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___296 *page;
};

struct ctl_node___102 {
	struct rb_node node;
	struct ctl_table_header___102 *header;
};

struct ctl_table_root___102 {
	struct ctl_table_set___102 default_set;
	struct ctl_table_set___102 * (*lookup)(struct ctl_table_root___102 *, struct nsproxy___177 *);
	int (*permissions)(struct ctl_table_header___102 *, struct ctl_table *);
};

struct nsproxy___177 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___101 *net_ns;
};

struct signal_struct___298 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___298 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___298 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___97 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___299 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___192;

struct css_set___192 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___192 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___87 {
	atomic_t use;
	unsigned int mask;
	struct net_device___87 *physindev;
	struct net_device___87 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___87(struct sk_buff___89 **);

struct net_device_ops___87;

struct ethtool_ops___87;

struct header_ops___87;

struct inet6_dev___51;

struct netdev_rx_queue___87;

struct netdev_queue___87;

struct rtnl_link_ops___78;

struct dcbnl_rtnl_ops___87;

struct net_device___87 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___87 *netdev_ops;
	const struct ethtool_ops___87 *ethtool_ops;
	const struct header_ops___87 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___79 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___51 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___87 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___87 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___87 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___87 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___87 = 0,
		NETREG_REGISTERED___87 = 1,
		NETREG_UNREGISTERING___87 = 2,
		NETREG_UNREGISTERED___87 = 3,
		NETREG_RELEASED___87 = 4,
		NETREG_DUMMY___87 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___87 = 0,
		RTNL_LINK_INITIALIZING___87 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___87 *);
	struct netpoll_info *npinfo;
	struct net___101 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___295 dev;
	const struct attribute_group___257 *sysfs_groups[4];
	const struct rtnl_link_ops___78 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___87 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___89 {
	struct sk_buff___89 *next;
	struct sk_buff___89 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___76 *sk;
	struct net_device___87 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___89 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___87 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___24 {
	struct {
		struct page___296 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___24 skb_frag_t___24;

struct skb_shared_info___24 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___89 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___24 frags[17];
};

struct file_lock___297;

struct file_operations___297 {
	struct module *owner;
	loff_t (*llseek)(struct file___297 *, loff_t, int);
	ssize_t (*read)(struct file___297 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___297 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___84 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___84 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___297 *, void *, filldir_t);
	unsigned int (*poll)(struct file___297 *, struct poll_table_struct___183 *);
	long int (*unlocked_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___297 *, struct vm_area_struct___305 *);
	int (*open)(struct inode___297 *, struct file___297 *);
	int (*flush)(struct file___297 *, fl_owner_t);
	int (*release)(struct inode___297 *, struct file___297 *);
	int (*fsync)(struct file___297 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___84 *, int);
	int (*fasync)(int, struct file___297 *, int);
	int (*lock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*sendpage)(struct file___297 *, struct page___296 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___297 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___297 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___297 *, long int, struct file_lock___297 **, void **);
		struct {
			int (*setlease)(struct file___297 *, long int, struct file_lock___297 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___297 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___222 *, struct file___297 *);
};

struct dev_pm_qos_request___99 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___295 *dev;
};

struct dentry_operations___297;

struct super_block___297;

struct dentry___297 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___297 *d_parent;
	struct qstr d_name;
	struct inode___297 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___297 *d_op;
	struct super_block___297 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___297;

struct dquot___297;

struct block_device___297;

struct inode___297 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___297 *i_op;
	struct super_block___297 *i_sb;
	struct address_space___297 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___299 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___297 *i_fop;
	struct file_lock___297 *i_flock;
	struct address_space___297 i_data;
	struct dquot___297 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___297 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___297 {
	int (*d_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_hash)(const struct dentry___297 *, struct qstr *);
	int (*d_compare)(const struct dentry___297 *, const struct dentry___297 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___297 *);
	void (*d_release)(struct dentry___297 *);
	void (*d_prune)(struct dentry___297 *);
	void (*d_iput)(struct dentry___297 *, struct inode___297 *);
	char * (*d_dname)(struct dentry___297 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___297 *);
	int (*d_manage)(struct dentry___297 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___297;

struct mem_dqinfo___297 {
	struct quota_format_type___297 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___297;

struct quota_info___297 {
	unsigned int flags;
	struct mutex___299 dqio_mutex;
	struct mutex___299 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___297 *files[2];
	struct mem_dqinfo___297 info[2];
	const struct quota_format_ops___297 *ops[2];
};

struct file_system_type___297;

struct super_operations___297;

struct dquot_operations___297;

struct quotactl_ops___297;

struct xattr_handler___193;

struct super_block___297 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___297 *s_type;
	const struct super_operations___297 *s_op;
	const struct dquot_operations___297 *dq_op;
	const struct quotactl_ops___297 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___297 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___193 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___297 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___297 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___299 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___297 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___297 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___297 *bd_inode;
	struct super_block___297 *bd_super;
	struct mutex___299 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___297 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___299 bd_fsfreeze_mutex;
};

struct cgroup___192;

struct cgroup_subsys_state___192 {
	struct cgroup___192 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___297 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___297 *ia_file;
};

struct dquot___297 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___299 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___297 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___297 {
	int qf_fmt_id;
	const struct quota_format_ops___297 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___297 *qf_next;
};

struct quota_format_ops___297 {
	int (*check_quota_file)(struct super_block___297 *, int);
	int (*read_file_info)(struct super_block___297 *, int);
	int (*write_file_info)(struct super_block___297 *, int);
	int (*free_file_info)(struct super_block___297 *, int);
	int (*read_dqblk)(struct dquot___297 *);
	int (*commit_dqblk)(struct dquot___297 *);
	int (*release_dqblk)(struct dquot___297 *);
};

struct dquot_operations___297 {
	int (*write_dquot)(struct dquot___297 *);
	struct dquot___297 * (*alloc_dquot)(struct super_block___297 *, int);
	void (*destroy_dquot)(struct dquot___297 *);
	int (*acquire_dquot)(struct dquot___297 *);
	int (*release_dquot)(struct dquot___297 *);
	int (*mark_dirty)(struct dquot___297 *);
	int (*write_info)(struct super_block___297 *, int);
	qsize_t * (*get_reserved_space)(struct inode___297 *);
};

struct quotactl_ops___297 {
	int (*quota_on)(struct super_block___297 *, int, int, struct path___297 *);
	int (*quota_on_meta)(struct super_block___297 *, int, int);
	int (*quota_off)(struct super_block___297 *, int);
	int (*quota_sync)(struct super_block___297 *, int);
	int (*get_info)(struct super_block___297 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___297 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___297 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___297 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___297 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___297 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___297 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___297 *, unsigned int);
};

struct address_space_operations___297 {
	int (*writepage)(struct page___296 *, struct writeback_control *);
	int (*readpage)(struct file___297 *, struct page___296 *);
	int (*writepages)(struct address_space___297 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___296 *);
	int (*readpages)(struct file___297 *, struct address_space___297 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___297 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___296 **, void **);
	int (*write_end)(struct file___297 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___296 *, void *);
	sector_t (*bmap)(struct address_space___297 *, sector_t);
	void (*invalidatepage)(struct page___296 *, long unsigned int);
	int (*releasepage)(struct page___296 *, gfp_t);
	void (*freepage)(struct page___296 *);
	ssize_t (*direct_IO)(int, struct kiocb___84 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___297 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___297 *, struct page___296 *, struct page___296 *, enum migrate_mode);
	int (*launder_page)(struct page___296 *);
	int (*is_partially_uptodate)(struct page___296 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___296 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___297 *, struct page___296 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___297 *, sector_t *);
	void (*swap_deactivate)(struct file___297 *);
	void (*invalidatepage_range)(struct page___296 *, unsigned int, unsigned int);
};

struct inode_operations___297 {
	struct dentry___297 * (*lookup)(struct inode___297 *, struct dentry___297 *, unsigned int);
	void * (*follow_link)(struct dentry___297 *, struct nameidata *);
	int (*permission)(struct inode___297 *, int);
	struct posix_acl * (*get_acl)(struct inode___297 *, int);
	int (*readlink)(struct dentry___297 *, char *, int);
	void (*put_link)(struct dentry___297 *, struct nameidata *, void *);
	int (*create)(struct inode___297 *, struct dentry___297 *, umode_t, bool);
	int (*link)(struct dentry___297 *, struct inode___297 *, struct dentry___297 *);
	int (*unlink)(struct inode___297 *, struct dentry___297 *);
	int (*symlink)(struct inode___297 *, struct dentry___297 *, const char *);
	int (*mkdir)(struct inode___297 *, struct dentry___297 *, umode_t);
	int (*rmdir)(struct inode___297 *, struct dentry___297 *);
	int (*mknod)(struct inode___297 *, struct dentry___297 *, umode_t, dev_t);
	int (*rename)(struct inode___297 *, struct dentry___297 *, struct inode___297 *, struct dentry___297 *);
	int (*setattr)(struct dentry___297 *, struct iattr___297 *);
	int (*getattr)(struct vfsmount *, struct dentry___297 *, struct kstat *);
	int (*setxattr)(struct dentry___297 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___297 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___297 *, char *, size_t);
	int (*removexattr)(struct dentry___297 *, const char *);
	int (*fiemap)(struct inode___297 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___297 *, struct timespec *, int);
	int (*atomic_open)(struct inode___297 *, struct dentry___297 *, struct file___297 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___297;

struct lock_manager_operations___297;

struct file_lock___297 {
	struct file_lock___297 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___97 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___297 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___297 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___297 *fl_ops;
	const struct lock_manager_operations___297 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___297 {
	void (*fl_copy_lock)(struct file_lock___297 *, struct file_lock___297 *);
	void (*fl_release_private)(struct file_lock___297 *);
};

struct lock_manager_operations___297 {
	int (*lm_compare_owner)(struct file_lock___297 *, struct file_lock___297 *);
	long unsigned int (*lm_owner_key)(struct file_lock___297 *);
	void (*lm_notify)(struct file_lock___297 *);
	int (*lm_grant)(struct file_lock___297 *, struct file_lock___297 *, int);
	void (*lm_break)(struct file_lock___297 *);
	int (*lm_change)(struct file_lock___297 **, int);
};

struct file_system_type___297 {
	const char *name;
	int fs_flags;
	struct dentry___297 * (*mount)(struct file_system_type___297 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___297 *);
	struct module *owner;
	struct file_system_type___297 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___297 {
	struct inode___297 * (*alloc_inode)(struct super_block___297 *);
	void (*destroy_inode)(struct inode___297 *);
	void (*dirty_inode)(struct inode___297 *, int);
	int (*write_inode)(struct inode___297 *, struct writeback_control *);
	int (*drop_inode)(struct inode___297 *);
	void (*evict_inode)(struct inode___297 *);
	void (*put_super)(struct super_block___297 *);
	int (*sync_fs)(struct super_block___297 *, int);
	int (*freeze_fs)(struct super_block___297 *);
	int (*unfreeze_fs)(struct super_block___297 *);
	int (*statfs)(struct dentry___297 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___297 *, int *, char *);
	void (*umount_begin)(struct super_block___297 *);
	int (*show_options)(struct seq_file___222 *, struct dentry___297 *);
	int (*show_devname)(struct seq_file___222 *, struct dentry___297 *);
	int (*show_path)(struct seq_file___222 *, struct dentry___297 *);
	int (*show_stats)(struct seq_file___222 *, struct dentry___297 *);
	ssize_t (*quota_read)(struct super_block___297 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___297 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___297 *);
	int (*bdev_try_to_free_page)(struct super_block___297 *, struct page___296 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___297 *);
	void (*free_cached_objects)(struct super_block___297 *, int);
};

struct xattr_handler___193 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___297 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___297 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___297 *, const char *, const void *, size_t, int, int);
};

struct ethtool_ops___87 {
	int (*get_settings)(struct net_device___87 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___87 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___87 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___87 *);
	void (*get_regs)(struct net_device___87 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___87 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___87 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___87 *);
	void (*set_msglevel)(struct net_device___87 *, u32);
	int (*nway_reset)(struct net_device___87 *);
	u32 (*get_link)(struct net_device___87 *);
	int (*get_eeprom_len)(struct net_device___87 *);
	int (*get_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___87 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___87 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___87 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___87 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___87 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___87 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___87 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___87 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___87 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___87 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___87 *);
	void (*complete)(struct net_device___87 *);
	u32 (*get_priv_flags)(struct net_device___87 *);
	int (*set_priv_flags)(struct net_device___87 *, u32);
	int (*get_sset_count)(struct net_device___87 *, int);
	int (*get_rxnfc)(struct net_device___87 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___87 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___87 *, struct ethtool_flash *);
	int (*reset)(struct net_device___87 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___87 *);
	int (*get_rxfh_indir)(struct net_device___87 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___87 *, const u32 *);
	void (*get_channels)(struct net_device___87 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___87 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___87 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___87 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___87 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___87 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___87 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___87 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___87 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___87 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___87 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___87 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct rtable___46;

struct dst_entry___77 {
	struct callback_head callback_head;
	struct dst_entry___77 *child;
	struct net_device___87 *dev;
	struct dst_ops___101 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___77 *path;
	struct dst_entry___77 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___89 *);
	union {
		int (*output)(struct sock___76 *, struct sk_buff___89 *);
		struct {
			int (*output)(struct sk_buff___89 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___77 *next;
		struct rtable___46 *rt_next;
		struct rt6_info___25 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___77;

struct neigh_parms___77;

struct neigh_ops___77;

struct neighbour___77 {
	struct neighbour___77 *next;
	struct neigh_table___77 *tbl;
	struct neigh_parms___77 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___88 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___77 *, struct sk_buff___89 *);
	const struct neigh_ops___77 *ops;
	struct callback_head rcu;
	struct net_device___87 *dev;
	u8 primary_key[0];
};

struct fib6_node___25;

struct rt6_info___25 {
	struct dst_entry___77 dst;
	struct fib6_table___25 *rt6i_table;
	struct fib6_node___25 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___51 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___25 {
	struct fib6_node___25 *parent;
	struct fib6_node___25 *left;
	struct fib6_node___25 *right;
	struct rt6_info___25 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___25 *rr_ptr;
};

struct fib6_table___25 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___25 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_afinfo___102 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___89 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___89 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___101 *, struct dst_entry___77 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___89 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___89 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___222 {
	void * (*start)(struct seq_file___222 *, loff_t *);
	void (*stop)(struct seq_file___222 *, void *);
	void * (*next)(struct seq_file___222 *, void *, loff_t *);
	int (*show)(struct seq_file___222 *, void *);
};

struct dcbnl_rtnl_ops___87 {
	int (*ieee_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___87 *);
	u8 (*setstate)(struct net_device___87 *, u8);
	void (*getpermhwaddr)(struct net_device___87 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___87 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___87 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___87 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___87 *, int, u8 *);
	void (*setpfccfg)(struct net_device___87 *, int, u8);
	void (*getpfccfg)(struct net_device___87 *, int, u8 *);
	u8 (*setall)(struct net_device___87 *);
	u8 (*getcap)(struct net_device___87 *, int, u8 *);
	int (*getnumtcs)(struct net_device___87 *, int, u8 *);
	int (*setnumtcs)(struct net_device___87 *, int, u8);
	u8 (*getpfcstate)(struct net_device___87 *);
	void (*setpfcstate)(struct net_device___87 *, u8);
	void (*getbcncfg)(struct net_device___87 *, int, u32 *);
	void (*setbcncfg)(struct net_device___87 *, int, u32);
	void (*getbcnrp)(struct net_device___87 *, int, u8 *);
	void (*setbcnrp)(struct net_device___87 *, int, u8);
	u8 (*setapp)(struct net_device___87 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___87 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___87 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___87 *, int, u8);
	u8 (*getdcbx)(struct net_device___87 *);
	u8 (*setdcbx)(struct net_device___87 *, u8);
	int (*peer_getappinfo)(struct net_device___87 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___87 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___87 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___87 *, struct cee_pfc *);
};

struct cgroupfs_root___192;

struct cgroup___192 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___192 *parent;
	struct dentry___297 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___192 *subsys[11];
	struct cgroupfs_root___192 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___299 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___192 {
	struct super_block___297 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___192 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___128 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___297 *, struct file___297 *);
	ssize_t (*read)(struct cgroup___192 *, struct cftype___128 *, struct file___297 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___192 *, struct cftype___128 *);
	s64 (*read_s64)(struct cgroup___192 *, struct cftype___128 *);
	int (*read_map)(struct cgroup___192 *, struct cftype___128 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___192 *, struct cftype___128 *, struct seq_file___222 *);
	ssize_t (*write)(struct cgroup___192 *, struct cftype___128 *, struct file___297 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___192 *, struct cftype___128 *, u64);
	int (*write_s64)(struct cgroup___192 *, struct cftype___128 *, s64);
	int (*write_string)(struct cgroup___192 *, struct cftype___128 *, const char *);
	int (*trigger)(struct cgroup___192 *, unsigned int);
	int (*release)(struct inode___297 *, struct file___297 *);
	int (*register_event)(struct cgroup___192 *, struct cftype___128 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___192 *, struct cftype___128 *, struct eventfd_ctx *);
};

struct cftype_set___124 {
	struct list_head node;
	struct cftype___128 *cfts;
};

struct task_and_cgroup___124 {
	struct task_struct___298 *task;
	struct cgroup___192 *cgrp;
	struct css_set___192 *cg;
};

struct cgroup_taskset___124 {
	struct task_and_cgroup___124 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___192 *cur_cgrp;
};

struct cgroup_subsys___124 {
	struct cgroup_subsys_state___192 * (*css_alloc)(struct cgroup___192 *);
	int (*css_online)(struct cgroup___192 *);
	void (*css_offline)(struct cgroup___192 *);
	void (*css_free)(struct cgroup___192 *);
	int (*can_attach)(struct cgroup___192 *, struct cgroup_taskset___124 *);
	void (*cancel_attach)(struct cgroup___192 *, struct cgroup_taskset___124 *);
	void (*attach)(struct cgroup___192 *, struct cgroup_taskset___124 *);
	void (*fork)(struct task_struct___298 *);
	void (*exit)(struct cgroup___192 *, struct cgroup___192 *, struct task_struct___298 *);
	void (*bind)(struct cgroup___192 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___192 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___128 *base_cftypes;
	struct cftype_set___124 base_cftset;
	struct module *module;
};

struct request_sock_ops___60;

struct request_sock___61 {
	struct sock_common___76 __req_common;
	struct request_sock___61 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___60 *rsk_ops;
	struct sock___76 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___89 {
	struct sk_buff___89 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___89 *, struct netlink_callback___89 *);
	int (*done)(struct netlink_callback___89 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___87 {
	int (*create)(struct sk_buff___89 *, struct net_device___87 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___89 *, unsigned char *);
	int (*rebuild)(struct sk_buff___89 *);
	int (*cache)(const struct neighbour___77 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___87 *, const unsigned char *);
};

struct napi_struct___87 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___87 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___87 *dev;
	struct sk_buff___89 *gro_list;
	struct sk_buff___89 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___87 {
	struct net_device___87 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___79 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___87 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___79 kobj;
	struct net_device___87 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___87 {
	int (*ndo_init)(struct net_device___87 *);
	void (*ndo_uninit)(struct net_device___87 *);
	int (*ndo_open)(struct net_device___87 *);
	int (*ndo_stop)(struct net_device___87 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___89 *, struct net_device___87 *);
	u16 (*ndo_select_queue)(struct net_device___87 *, struct sk_buff___89 *);
	void (*ndo_change_rx_flags)(struct net_device___87 *, int);
	void (*ndo_set_rx_mode)(struct net_device___87 *);
	int (*ndo_set_mac_address)(struct net_device___87 *, void *);
	int (*ndo_validate_addr)(struct net_device___87 *);
	int (*ndo_do_ioctl)(struct net_device___87 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___87 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___87 *, int);
	int (*ndo_neigh_setup)(struct net_device___87 *, struct neigh_parms___77 *);
	void (*ndo_tx_timeout)(struct net_device___87 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___87 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___87 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___87 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___87 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___87 *);
	int (*ndo_netpoll_setup)(struct net_device___87 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___87 *);
	int (*ndo_busy_poll)(struct napi_struct___87 *);
	int (*ndo_set_vf_mac)(struct net_device___87 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___87 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___87 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___87 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___87 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___87 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___87 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___87 *, int, struct sk_buff___89 *);
	int (*ndo_setup_tc)(struct net_device___87 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___87 *);
	int (*ndo_fcoe_disable)(struct net_device___87 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___87 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___87 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___87 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___87 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___87 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___87 *, const struct sk_buff___89 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___87 *, struct net_device___87 *);
	int (*ndo_del_slave)(struct net_device___87 *, struct net_device___87 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___77 *);
	void (*ndo_neigh_destroy)(struct neighbour___77 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___89 *, struct netlink_callback___89 *, struct net_device___87 *, int);
	int (*ndo_bridge_setlink)(struct net_device___87 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___89 *, u32, u32, struct net_device___87 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___87 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___87 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___87 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___87 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___87 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___87 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___89 *, struct net_device___87 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___87 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___87 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___87 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___77 {
	struct net___101 *net;
	struct net_device___87 *dev;
	struct neigh_parms___77 *next;
	int (*neigh_setup)(struct neighbour___77 *);
	void (*neigh_cleanup)(struct neighbour___77 *);
	struct neigh_table___77 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___51;

struct ifacaddr6___51;

struct inet6_dev___51 {
	struct net_device___87 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___51 *mc_list;
	struct ifmcaddr6___51 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___51 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___77 *nd_parms;
	struct inet6_dev___51 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___78 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___87 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___101 *, struct net_device___87 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___87 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___87 *, struct list_head *);
	size_t (*get_size)(const struct net_device___87 *);
	int (*fill_info)(struct sk_buff___89 *, const struct net_device___87 *);
	size_t (*get_xstats_size)(const struct net_device___87 *);
	int (*fill_xstats)(struct sk_buff___89 *, const struct net_device___87 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___101 * (*get_link_net)(const struct net_device___87 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___87 *, struct net_device___87 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___87 *, const struct net_device___87 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___89 *, const struct net_device___87 *, const struct net_device___87 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___77 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___89 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___77;

struct neigh_hash_table___77;

struct neigh_table___77 {
	struct neigh_table___77 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___87 *, __u32 *);
	int (*constructor)(struct neighbour___77 *);
	int (*pconstructor)(struct pneigh_entry___77 *);
	void (*pdestructor)(struct pneigh_entry___77 *);
	void (*proxy_redo)(struct sk_buff___89 *);
	char *id;
	struct neigh_parms___77 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___88 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___77 *nht;
	struct pneigh_entry___77 **phash_buckets;
};

struct neigh_ops___77 {
	int family;
	void (*solicit)(struct neighbour___77 *, struct sk_buff___89 *);
	void (*error_report)(struct neighbour___77 *, struct sk_buff___89 *);
	int (*output)(struct neighbour___77 *, struct sk_buff___89 *);
	int (*connected_output)(struct neighbour___77 *, struct sk_buff___89 *);
};

struct pneigh_entry___77 {
	struct pneigh_entry___77 *next;
	struct net___101 *net;
	struct net_device___87 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___77 {
	struct neighbour___77 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___46 {
	struct dst_entry___77 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___57;

struct proto___76 {
	void (*close)(struct sock___76 *, long int);
	int (*connect)(struct sock___76 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___76 *, int);
	struct sock___76 * (*accept)(struct sock___76 *, int, int *);
	int (*ioctl)(struct sock___76 *, int, long unsigned int);
	int (*init)(struct sock___76 *);
	void (*destroy)(struct sock___76 *);
	void (*shutdown)(struct sock___76 *, int);
	int (*setsockopt)(struct sock___76 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___76 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___76 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___76 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___76 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___84 *, struct sock___76 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___84 *, struct sock___76 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___76 *, struct page___296 *, int, size_t, int);
	int (*bind)(struct sock___76 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___76 *, struct sk_buff___89 *);
	void (*release_cb)(struct sock___76 *);
	void (*mtu_reduced)(struct sock___76 *);
	void (*hash)(struct sock___76 *);
	void (*unhash)(struct sock___76 *);
	void (*rehash)(struct sock___76 *);
	int (*get_port)(struct sock___76 *, short unsigned int);
	void (*clear_sk)(struct sock___76 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___76 *);
	void (*enter_memory_pressure)(struct sock___76 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___280 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___60 *rsk_prot;
	struct timewait_sock_ops___57 *twsk_prot;
	union {
		struct inet_hashinfo___22 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___124 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___76 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___76 {
	void (*enter_memory_pressure)(struct sock___76 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___60 {
	int family;
	int obj_size;
	struct kmem_cache___280 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___76 *, struct request_sock___61 *);
	void (*send_ack)(struct sock___76 *, struct sk_buff___89 *, struct request_sock___61 *);
	void (*send_reset)(struct sock___76 *, struct sk_buff___89 *);
	void (*destructor)(struct request_sock___61 *);
	void (*syn_ack_timeout)(struct sock___76 *, struct request_sock___61 *);
};

struct timewait_sock_ops___57 {
	struct kmem_cache___280 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___76 *, struct sock___76 *, void *);
	void (*twsk_destructor)(struct sock___76 *);
};

struct inet_cork___30 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___77 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___30 {
	struct inet_cork___30 base;
	struct flowi fl;
};

struct ipv6_pinfo___29;

struct inet_sock___30 {
	struct sock___76 sk;
	struct ipv6_pinfo___29 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___30 cork;
};

struct ipv6_fl_socklist___28;

struct ipv6_pinfo___29 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___28 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___89 *pktoptions;
	struct sk_buff___89 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___28;

struct ipv6_fl_socklist___28 {
	struct ipv6_fl_socklist___28 *next;
	struct ip6_flowlabel___28 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___51 {
	struct in6_addr mca_addr;
	struct inet6_dev___51 *idev;
	struct ifmcaddr6___51 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___51 {
	struct in6_addr aca_addr;
	struct inet6_dev___51 *aca_idev;
	struct rt6_info___25 *aca_rt;
	struct ifacaddr6___51 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___28 {
	struct ip6_flowlabel___28 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___84 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___101 *fl_net;
};

struct page___297;

typedef struct page___297 *pgtable_t___297;

struct address_space___298;

struct kmem_cache___281;

struct page___297 {
	long unsigned int flags;
	struct address_space___298 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___297 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___297 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___281 *slab_cache;
		struct page___297 *first_page;
	};
	long: 64;
};

struct task_struct___299;

struct pv_cpu_ops___299 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___299 *);
	void (*end_context_switch)(struct task_struct___299 *);
};

struct pid___98;

struct pid_link___98 {
	struct hlist_node node;
	struct pid___98 *pid;
};

struct mutex___300 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___299 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___292 {
	struct page___297 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___306;

struct nsproxy___178;

struct signal_struct___299;

struct css_set___193;

struct task_struct___299 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___299 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___306 *mm;
	struct mm_struct___306 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___299 *real_parent;
	struct task_struct___299 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___299 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___98 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___299 = 0,
		VTIME_USER___299 = 1,
		VTIME_SYS___299 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___178 *nsproxy;
	struct signal_struct___299 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___193 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___300 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___292 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___306 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___306 *, struct mm_struct___306 *);
	void (*dup_mmap)(struct mm_struct___306 *, struct mm_struct___306 *);
	void (*exit_mmap)(struct mm_struct___306 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___306 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___306 *);
	void (*pgd_free)(struct mm_struct___306 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___306 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___306 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___306 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___306 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___306 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___306 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___306 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___306 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___306 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___306 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___306 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___300 lock;
	void *vdso;
} mm_context_t___300;

struct xol_area___297;

struct uprobes_state___297 {
	struct xol_area___297 *xol_area;
};

struct vm_area_struct___306;

struct file___298;

struct core_state___299;

struct mm_struct___306 {
	struct vm_area_struct___306 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___306 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___306 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___300 context;
	long unsigned int flags;
	struct core_state___299 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___299 *owner;
	struct file___298 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___297 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___297 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___297 *page;
	long unsigned int vaddr;
};

struct kset___80;

struct kobj_type___80;

struct kobject___80 {
	const char *name;
	struct list_head entry;
	struct kobject___80 *parent;
	struct kset___80 *kset;
	struct kobj_type___80 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___280;

struct memcg_cache_params___281;

struct kmem_cache___281 {
	struct kmem_cache_cpu___280 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___80 kobj;
	struct memcg_cache_params___281 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___298;

struct address_space_operations___298;

struct address_space___298 {
	struct inode___298 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___300 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___298 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___298;

struct path___298 {
	struct vfsmount *mnt;
	struct dentry___298 *dentry;
};

struct fown_struct___98 {
	rwlock_t lock;
	struct pid___98 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___298;

struct file___298 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___298 f_path;
	struct inode___298 *f_inode;
	const struct file_operations___298 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___298 *f_mapping;
	struct mutex___300 f_pos_lock;
};

struct vm_operations_struct___272;

struct vm_area_struct___306 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___306 *vm_next;
	struct vm_area_struct___306 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___306 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___272 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___298 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___268;

struct vm_operations_struct___272 {
	void (*open)(struct vm_area_struct___306 *);
	void (*close)(struct vm_area_struct___306 *);
	int (*fault)(struct vm_area_struct___306 *, struct vm_fault___268 *);
	int (*page_mkwrite)(struct vm_area_struct___306 *, struct vm_fault___268 *);
	int (*access)(struct vm_area_struct___306 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___306 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___306 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___306 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___306 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___299 {
	struct task_struct___299 *task;
	struct core_thread___299 *next;
};

struct core_state___299 {
	atomic_t nr_threads;
	struct core_thread___299 dumper;
	struct completion startup;
};

struct fasync_struct___298;

struct socket_wq___77 {
	wait_queue_head_t wait;
	struct fasync_struct___298 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct fasync_struct___298 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___298 *fa_next;
	struct file___298 *fa_file;
	struct callback_head fa_rcu;
};

struct sock___77;

struct proto_ops___77;

struct socket___78 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___77 *wq;
	struct file___298 *file;
	struct sock___77 *sk;
	const struct proto_ops___77 *ops;
};

struct proto___77;

struct net___102;

struct sock_common___77 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___77 *skc_prot;
	struct net___102 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___90;

struct sk_buff_head___89 {
	struct sk_buff___90 *next;
	struct sk_buff___90 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___78;

struct dst_entry___78;

struct cg_proto___77;

struct sock___77 {
	struct sock_common___77 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___89 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___90 *head;
		struct sk_buff___90 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___78 *sk_filter;
	struct socket_wq___77 *sk_wq;
	struct sk_buff_head___89 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___78 *sk_rx_dst;
	struct dst_entry___78 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___89 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___89 sk_error_queue;
	struct proto___77 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___98 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___78 *sk_socket;
	void *sk_user_data;
	struct page_frag___292 sk_frag;
	struct sk_buff___90 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___77 *sk_cgrp;
	void (*sk_state_change)(struct sock___77 *);
	void (*sk_data_ready)(struct sock___77 *, int);
	void (*sk_write_space)(struct sock___77 *);
	void (*sk_error_report)(struct sock___77 *);
	int (*sk_backlog_rcv)(struct sock___77 *, struct sk_buff___90 *);
	void (*sk_destruct)(struct sock___77 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct poll_table_struct___184;

struct kiocb___85;

struct proto_ops___77 {
	int family;
	struct module *owner;
	int (*release)(struct socket___78 *);
	int (*bind)(struct socket___78 *, struct sockaddr *, int);
	int (*connect)(struct socket___78 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___78 *, struct socket___78 *);
	int (*accept)(struct socket___78 *, struct socket___78 *, int);
	int (*getname)(struct socket___78 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___298 *, struct socket___78 *, struct poll_table_struct___184 *);
	int (*ioctl)(struct socket___78 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___78 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___78 *, int);
	int (*shutdown)(struct socket___78 *, int);
	int (*setsockopt)(struct socket___78 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___78 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___78 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___78 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___85 *, struct socket___78 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___85 *, struct socket___78 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___298 *, struct socket___78 *, struct vm_area_struct___306 *);
	ssize_t (*sendpage)(struct socket___78 *, struct page___297 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___78 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___77 *, int);
		struct {
			void (*set_peek_off)(struct sock___77 *, int);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
};

typedef void (*poll_queue_proc___186)(struct file___298 *, wait_queue_head_t *, struct poll_table_struct___184 *);

struct poll_table_struct___184 {
	poll_queue_proc___186 _qproc;
	long unsigned int _key;
};

typedef int kiocb_cancel_fn___85(struct kiocb___85 *, struct io_event *);

struct kiocb___85 {
	atomic_t ki_users;
	struct file___298 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___85 *ki_cancel;
	void (*ki_dtor)(struct kiocb___85 *);
	union {
		void *user;
		struct task_struct___299 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct ctl_table_root___103;

struct ctl_table_set___103;

struct ctl_dir___103;

struct ctl_node___103;

struct ctl_table_header___103 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___103 *root;
	struct ctl_table_set___103 *set;
	struct ctl_dir___103 *parent;
	struct ctl_node___103 *node;
};

struct ctl_dir___103 {
	struct ctl_table_header___103 header;
	struct rb_root root;
};

struct ctl_table_set___103 {
	int (*is_seen)(struct ctl_table_set___103 *);
	struct ctl_dir___103 dir;
};

struct netns_core___100 {
	struct ctl_table_header___103 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___101 {
	struct mutex___300 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___100 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___103 *ctl;
};

struct netns_ipv4___100 {
	struct ctl_table_header___103 *forw_hdr;
	struct ctl_table_header___103 *frags_hdr;
	struct ctl_table_header___103 *ipv4_hdr;
	struct ctl_table_header___103 *route_hdr;
	struct ctl_table_header___103 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___77 *fibnl;
	struct sock___77 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___100 {
	struct ctl_table_header___103 *hdr;
	struct ctl_table_header___103 *route_hdr;
	struct ctl_table_header___103 *icmp_hdr;
	struct ctl_table_header___103 *frags_hdr;
	struct ctl_table_header___103 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___88;

struct neighbour___78;

struct dst_ops___102 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___102 *);
	struct dst_entry___78 * (*check)(struct dst_entry___78 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___78 *);
	unsigned int (*mtu)(const struct dst_entry___78 *);
	u32 * (*cow_metrics)(struct dst_entry___78 *, long unsigned int);
	void (*destroy)(struct dst_entry___78 *);
	void (*ifdown)(struct dst_entry___78 *, struct net_device___88 *, int);
	struct dst_entry___78 * (*negative_advice)(struct dst_entry___78 *);
	void (*link_failure)(struct sk_buff___90 *);
	void (*update_pmtu)(struct dst_entry___78 *, struct sock___77 *, struct sk_buff___90 *, u32);
	void (*redirect)(struct dst_entry___78 *, struct sock___77 *, struct sk_buff___90 *);
	int (*local_out)(struct sk_buff___90 *);
	struct neighbour___78 * (*neigh_lookup)(const struct dst_entry___78 *, struct sk_buff___90 *, const void *);
	struct kmem_cache___281 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___26;

struct fib6_table___26;

struct netns_ipv6___102 {
	struct netns_sysctl_ipv6___100 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___26 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___26 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___102 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___26 *ip6_prohibit_entry;
	struct rt6_info___26 *ip6_blk_hole_entry;
	struct fib6_table___26 *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___77 **icmp_sk;
	struct sock___77 *ndisc_sk;
	struct sock___77 *tcp_sk;
	struct sock___77 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___100 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___103 *sysctl_header;
	struct sock___77 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___77 {
	struct sock___77 *v4_ctl_sk;
	struct sock___77 *v6_ctl_sk;
};

struct netns_nf___100 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___103 *nf_log_dir_header;
};

struct nf_proto_net___100 {
	struct ctl_table_header___103 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___100 {
	struct nf_proto_net___100 pn;
	unsigned int timeout;
};

struct nf_tcp_net___100 {
	struct nf_proto_net___100 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___100 {
	struct nf_proto_net___100 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___100 {
	struct nf_proto_net___100 pn;
	unsigned int timeout;
};

struct nf_ip_net___100 {
	struct nf_generic_net___100 generic;
	struct nf_tcp_net___100 tcp;
	struct nf_udp_net___100 udp;
	struct nf_icmp_net___100 icmp;
	struct nf_icmp_net___100 icmpv6;
};

struct netns_ct___101 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___103 *sysctl_header;
	struct ctl_table_header___103 *acct_sysctl_header;
	struct ctl_table_header___103 *tstamp_sysctl_header;
	struct ctl_table_header___103 *event_sysctl_header;
	struct ctl_table_header___103 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___281 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___100 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___100 {
	struct netns_sysctl_ipv6___100 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___102 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___77 *nlsk;
	struct sock___77 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___103 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___102 xfrm4_dst_ops;
	struct dst_ops___102 xfrm6_dst_ops;
};

struct net___102 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___103 sysctls;
	struct sock___77 *rtnl;
	struct sock___77 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___88 *loopback_dev;
	struct netns_core___100 core;
	struct netns_mib mib;
	struct netns_packet___101 packet;
	struct netns_unix___100 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___100 ipv4;
	struct netns_ipv6___102 ipv6;
	struct netns_sctp___100 sctp;
	struct netns_dccp___77 dccp;
	struct netns_nf___100 nf;
	struct netns_xt xt;
	struct netns_ct___101 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___100 nf_frag;
	struct sock___77 *nfnl;
	struct sock___77 *nfnl_stash;
	struct sk_buff_head___89 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___102 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___77 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___77 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___300 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___300 flow_flush_sem;
	long: 64;
	long: 64;
};

struct file_lock___298;

struct seq_file___223;

struct file_operations___298 {
	struct module *owner;
	loff_t (*llseek)(struct file___298 *, loff_t, int);
	ssize_t (*read)(struct file___298 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___298 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___85 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___85 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___298 *, void *, filldir_t);
	unsigned int (*poll)(struct file___298 *, struct poll_table_struct___184 *);
	long int (*unlocked_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___298 *, struct vm_area_struct___306 *);
	int (*open)(struct inode___298 *, struct file___298 *);
	int (*flush)(struct file___298 *, fl_owner_t);
	int (*release)(struct inode___298 *, struct file___298 *);
	int (*fsync)(struct file___298 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___85 *, int);
	int (*fasync)(int, struct file___298 *, int);
	int (*lock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*sendpage)(struct file___298 *, struct page___297 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___298 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___298 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___298 *, long int, struct file_lock___298 **, void **);
		struct {
			int (*setlease)(struct file___298 *, long int, struct file_lock___298 **);
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	long int (*fallocate)(struct file___298 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___223 *, struct file___298 *);
};

struct dev_pm_qos___99;

struct dev_pm_info___99 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___99 *qos;
};

struct dma_map_ops___161;

struct dev_archdata___161 {
	struct dma_map_ops___161 *dma_ops;
	void *iommu;
};

struct device_type___296;

struct bus_type___296;

struct device_driver___296;

struct dev_pm_domain___296;

struct class___296;

struct attribute_group___258;

struct device_rh___296;

struct device___296 {
	struct device___296 *parent;
	struct device_private *p;
	struct kobject___80 kobj;
	const char *init_name;
	const struct device_type___296 *type;
	struct mutex___300 mutex;
	struct bus_type___296 *bus;
	struct device_driver___296 *driver;
	void *platform_data;
	struct dev_pm_info___99 power;
	struct dev_pm_domain___296 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___161 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___296 *class;
	const struct attribute_group___258 **groups;
	void (*release)(struct device___296 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___296 *device_rh;
};

struct kobj_ns_type_operations___77 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___77 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___260;

struct attribute_group___258 {
	const char *name;
	umode_t (*is_visible)(struct kobject___80 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___260 **bin_attrs;
};

struct bin_attribute___260 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___298 *, struct kobject___80 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___298 *, struct kobject___80 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	int (*mmap)(struct file___298 *, struct kobject___80 *, struct bin_attribute___260 *, struct vm_area_struct___306 *);
};

struct sysfs_ops___80 {
	ssize_t (*show)(struct kobject___80 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___80 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___80 *, const struct attribute *);
};

struct kset_uevent_ops___80;

struct kset___80 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___80 kobj;
	const struct kset_uevent_ops___80 *uevent_ops;
};

struct kobj_type___80 {
	void (*release)(struct kobject___80 *);
	const struct sysfs_ops___80 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___77 * (*child_ns_type)(struct kobject___80 *);
	const void * (*namespace)(struct kobject___80 *);
};

struct kset_uevent_ops___80 {
	int (* const filter)(struct kset___80 *, struct kobject___80 *);
	const char * (* const name)(struct kset___80 *, struct kobject___80 *);
	int (* const uevent)(struct kset___80 *, struct kobject___80 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___296 {
	int (*prepare)(struct device___296 *);
	void (*complete)(struct device___296 *);
	int (*suspend)(struct device___296 *);
	int (*resume)(struct device___296 *);
	int (*freeze)(struct device___296 *);
	int (*thaw)(struct device___296 *);
	int (*poweroff)(struct device___296 *);
	int (*restore)(struct device___296 *);
	int (*suspend_late)(struct device___296 *);
	int (*resume_early)(struct device___296 *);
	int (*freeze_late)(struct device___296 *);
	int (*thaw_early)(struct device___296 *);
	int (*poweroff_late)(struct device___296 *);
	int (*restore_early)(struct device___296 *);
	int (*suspend_noirq)(struct device___296 *);
	int (*resume_noirq)(struct device___296 *);
	int (*freeze_noirq)(struct device___296 *);
	int (*thaw_noirq)(struct device___296 *);
	int (*poweroff_noirq)(struct device___296 *);
	int (*restore_noirq)(struct device___296 *);
	int (*runtime_suspend)(struct device___296 *);
	int (*runtime_resume)(struct device___296 *);
	int (*runtime_idle)(struct device___296 *);
};

struct dev_pm_qos_request___100;

struct dev_pm_qos___99 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___100 *latency_req;
	struct dev_pm_qos_request___100 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___100 *latency_tolerance_req;
};

struct dev_pm_info_rh___296 {
	void (*set_latency_tolerance)(struct device___296 *, s32);
};

struct dev_pm_domain___296 {
	struct dev_pm_ops___296 ops;
};

struct zone___299;

struct lruvec___299 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___299 *zone;
};

struct pglist_data___299;

struct zone___299 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___299 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___299 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___299 {
	struct zone___299 *zone;
	int zone_idx;
};

struct zonelist___299 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___299 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___299 {
	struct zone___299 node_zones[4];
	struct zonelist___299 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___299 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___222;

struct x86_io_apic_ops___222 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___222 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___222;

struct irq_data___222 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___222 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct smp_ops___299 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___299 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct dma_map_ops___161 {
	void * (*alloc)(struct device___296 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___296 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___296 *, struct vm_area_struct___306 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___296 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___296 *, struct page___297 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___296 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___296 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___296 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___296 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___296 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___296 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___296 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___296 *, dma_addr_t);
	int (*dma_supported)(struct device___296 *, u64);
	int (*set_dma_mask)(struct device___296 *, u64);
	int is_phys;
};

struct bus_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___296 *, char *);
	ssize_t (*store)(struct bus_type___296 *, const char *, size_t);
};

struct device_attribute___296;

struct driver_attribute___296;

struct bus_type___296 {
	const char *name;
	const char *dev_name;
	struct device___296 *dev_root;
	struct bus_attribute___296 *bus_attrs;
	struct device_attribute___296 *dev_attrs;
	struct driver_attribute___296 *drv_attrs;
	const struct attribute_group___258 **bus_groups;
	const struct attribute_group___258 **dev_groups;
	const struct attribute_group___258 **drv_groups;
	int (*match)(struct device___296 *, struct device_driver___296 *);
	int (*uevent)(struct device___296 *, struct kobj_uevent_env *);
	int (*probe)(struct device___296 *);
	int (*remove)(struct device___296 *);
	void (*shutdown)(struct device___296 *);
	int (*online)(struct device___296 *);
	int (*offline)(struct device___296 *);
	int (*suspend)(struct device___296 *, pm_message_t);
	int (*resume)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct device___296 *, struct device_attribute___296 *, char *);
	ssize_t (*store)(struct device___296 *, struct device_attribute___296 *, const char *, size_t);
};

struct driver_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___296 *, char *);
	ssize_t (*store)(struct device_driver___296 *, const char *, size_t);
};

struct device_driver___296 {
	const char *name;
	struct bus_type___296 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___296 *);
	int (*remove)(struct device___296 *);
	void (*shutdown)(struct device___296 *);
	int (*suspend)(struct device___296 *, pm_message_t);
	int (*resume)(struct device___296 *);
	const struct attribute_group___258 **groups;
	const struct dev_pm_ops___296 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___296 {
	const char *name;
	const struct attribute_group___258 **groups;
	int (*uevent)(struct device___296 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___296 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
};

struct class_attribute___296;

struct class___296 {
	const char *name;
	struct module *owner;
	struct class_attribute___296 *class_attrs;
	struct device_attribute___296 *dev_attrs;
	const struct attribute_group___258 **dev_groups;
	struct bin_attribute___260 *dev_bin_attrs;
	struct kobject___80 *dev_kobj;
	int (*dev_uevent)(struct device___296 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___296 *, umode_t *);
	void (*class_release)(struct class___296 *);
	void (*dev_release)(struct device___296 *);
	int (*suspend)(struct device___296 *, pm_message_t);
	int (*resume)(struct device___296 *);
	const struct kobj_ns_type_operations___77 *ns_type;
	const void * (*namespace)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
	struct subsys_private *p;
};

struct class_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct class___296 *, struct class_attribute___296 *, char *);
	ssize_t (*store)(struct class___296 *, struct class_attribute___296 *, const char *, size_t);
	const void * (*namespace)(struct class___296 *, const struct class_attribute___296 *);
};

struct device_rh___296 {
	struct dev_pm_info_rh___296 power;
};

struct dev_pm_qos_request___100 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___296 *dev;
};

struct vm_fault___268 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___297 *page;
};

struct dentry_operations___298;

struct super_block___298;

struct dentry___298 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___298 *d_parent;
	struct qstr d_name;
	struct inode___298 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___298 *d_op;
	struct super_block___298 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___298;

struct dquot___298;

struct block_device___298;

struct inode___298 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___298 *i_op;
	struct super_block___298 *i_sb;
	struct address_space___298 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___300 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___298 *i_fop;
	struct file_lock___298 *i_flock;
	struct address_space___298 i_data;
	struct dquot___298 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___298 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___298 {
	int (*d_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_hash)(const struct dentry___298 *, struct qstr *);
	int (*d_compare)(const struct dentry___298 *, const struct dentry___298 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___298 *);
	void (*d_release)(struct dentry___298 *);
	void (*d_prune)(struct dentry___298 *);
	void (*d_iput)(struct dentry___298 *, struct inode___298 *);
	char * (*d_dname)(struct dentry___298 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___298 *);
	int (*d_manage)(struct dentry___298 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___298;

struct mem_dqinfo___298 {
	struct quota_format_type___298 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___298;

struct quota_info___298 {
	unsigned int flags;
	struct mutex___300 dqio_mutex;
	struct mutex___300 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___298 *files[2];
	struct mem_dqinfo___298 info[2];
	const struct quota_format_ops___298 *ops[2];
};

struct file_system_type___298;

struct super_operations___298;

struct dquot_operations___298;

struct quotactl_ops___298;

struct xattr_handler___194;

struct super_block___298 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___298 *s_type;
	const struct super_operations___298 *s_op;
	const struct dquot_operations___298 *dq_op;
	const struct quotactl_ops___298 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___298 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___194 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___298 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___298 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___300 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___298 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct pid_namespace___98;

struct upid___98 {
	int nr;
	struct pid_namespace___98 *ns;
	struct hlist_node pid_chain;
};

struct pid_namespace___98 {
	struct kref kref;
	struct pidmap pidmap[128];
	int last_pid;
	unsigned int nr_hashed;
	struct task_struct___299 *child_reaper;
	struct kmem_cache___281 *pid_cachep;
	unsigned int level;
	struct pid_namespace___98 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___298 *proc_self;
	struct bsd_acct_struct *bacct;
	struct user_namespace *user_ns;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	unsigned int proc_inum;
};

struct pid___98 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[3];
	struct callback_head rcu;
	struct upid___98 numbers[1];
};

struct block_device___298 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___298 *bd_inode;
	struct super_block___298 *bd_super;
	struct mutex___300 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___298 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___300 bd_fsfreeze_mutex;
};

struct cgroup___193;

struct cgroup_subsys_state___193 {
	struct cgroup___193 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___298 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___298 *ia_file;
};

struct dquot___298 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___300 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___298 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___298 {
	int qf_fmt_id;
	const struct quota_format_ops___298 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___298 *qf_next;
};

struct quota_format_ops___298 {
	int (*check_quota_file)(struct super_block___298 *, int);
	int (*read_file_info)(struct super_block___298 *, int);
	int (*write_file_info)(struct super_block___298 *, int);
	int (*free_file_info)(struct super_block___298 *, int);
	int (*read_dqblk)(struct dquot___298 *);
	int (*commit_dqblk)(struct dquot___298 *);
	int (*release_dqblk)(struct dquot___298 *);
};

struct dquot_operations___298 {
	int (*write_dquot)(struct dquot___298 *);
	struct dquot___298 * (*alloc_dquot)(struct super_block___298 *, int);
	void (*destroy_dquot)(struct dquot___298 *);
	int (*acquire_dquot)(struct dquot___298 *);
	int (*release_dquot)(struct dquot___298 *);
	int (*mark_dirty)(struct dquot___298 *);
	int (*write_info)(struct super_block___298 *, int);
	qsize_t * (*get_reserved_space)(struct inode___298 *);
};

struct quotactl_ops___298 {
	int (*quota_on)(struct super_block___298 *, int, int, struct path___298 *);
	int (*quota_on_meta)(struct super_block___298 *, int, int);
	int (*quota_off)(struct super_block___298 *, int);
	int (*quota_sync)(struct super_block___298 *, int);
	int (*get_info)(struct super_block___298 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___298 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___298 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___298 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___298 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___298 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___298 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___298 *, unsigned int);
};

struct address_space_operations___298 {
	int (*writepage)(struct page___297 *, struct writeback_control *);
	int (*readpage)(struct file___298 *, struct page___297 *);
	int (*writepages)(struct address_space___298 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___297 *);
	int (*readpages)(struct file___298 *, struct address_space___298 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___298 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___297 **, void **);
	int (*write_end)(struct file___298 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___297 *, void *);
	sector_t (*bmap)(struct address_space___298 *, sector_t);
	void (*invalidatepage)(struct page___297 *, long unsigned int);
	int (*releasepage)(struct page___297 *, gfp_t);
	void (*freepage)(struct page___297 *);
	ssize_t (*direct_IO)(int, struct kiocb___85 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___298 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___298 *, struct page___297 *, struct page___297 *, enum migrate_mode);
	int (*launder_page)(struct page___297 *);
	int (*is_partially_uptodate)(struct page___297 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___297 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___298 *, struct page___297 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___298 *, sector_t *);
	void (*swap_deactivate)(struct file___298 *);
	void (*invalidatepage_range)(struct page___297 *, unsigned int, unsigned int);
};

struct inode_operations___298 {
	struct dentry___298 * (*lookup)(struct inode___298 *, struct dentry___298 *, unsigned int);
	void * (*follow_link)(struct dentry___298 *, struct nameidata *);
	int (*permission)(struct inode___298 *, int);
	struct posix_acl * (*get_acl)(struct inode___298 *, int);
	int (*readlink)(struct dentry___298 *, char *, int);
	void (*put_link)(struct dentry___298 *, struct nameidata *, void *);
	int (*create)(struct inode___298 *, struct dentry___298 *, umode_t, bool);
	int (*link)(struct dentry___298 *, struct inode___298 *, struct dentry___298 *);
	int (*unlink)(struct inode___298 *, struct dentry___298 *);
	int (*symlink)(struct inode___298 *, struct dentry___298 *, const char *);
	int (*mkdir)(struct inode___298 *, struct dentry___298 *, umode_t);
	int (*rmdir)(struct inode___298 *, struct dentry___298 *);
	int (*mknod)(struct inode___298 *, struct dentry___298 *, umode_t, dev_t);
	int (*rename)(struct inode___298 *, struct dentry___298 *, struct inode___298 *, struct dentry___298 *);
	int (*setattr)(struct dentry___298 *, struct iattr___298 *);
	int (*getattr)(struct vfsmount *, struct dentry___298 *, struct kstat *);
	int (*setxattr)(struct dentry___298 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___298 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___298 *, char *, size_t);
	int (*removexattr)(struct dentry___298 *, const char *);
	int (*fiemap)(struct inode___298 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___298 *, struct timespec *, int);
	int (*atomic_open)(struct inode___298 *, struct dentry___298 *, struct file___298 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___298;

struct lock_manager_operations___298;

struct file_lock___298 {
	struct file_lock___298 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___98 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___298 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___298 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___298 *fl_ops;
	const struct lock_manager_operations___298 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___298 {
	void (*fl_copy_lock)(struct file_lock___298 *, struct file_lock___298 *);
	void (*fl_release_private)(struct file_lock___298 *);
};

struct lock_manager_operations___298 {
	int (*lm_compare_owner)(struct file_lock___298 *, struct file_lock___298 *);
	long unsigned int (*lm_owner_key)(struct file_lock___298 *);
	void (*lm_notify)(struct file_lock___298 *);
	int (*lm_grant)(struct file_lock___298 *, struct file_lock___298 *, int);
	void (*lm_break)(struct file_lock___298 *);
	int (*lm_change)(struct file_lock___298 **, int);
};

struct file_system_type___298 {
	const char *name;
	int fs_flags;
	struct dentry___298 * (*mount)(struct file_system_type___298 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___298 *);
	struct module *owner;
	struct file_system_type___298 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___298 {
	struct inode___298 * (*alloc_inode)(struct super_block___298 *);
	void (*destroy_inode)(struct inode___298 *);
	void (*dirty_inode)(struct inode___298 *, int);
	int (*write_inode)(struct inode___298 *, struct writeback_control *);
	int (*drop_inode)(struct inode___298 *);
	void (*evict_inode)(struct inode___298 *);
	void (*put_super)(struct super_block___298 *);
	int (*sync_fs)(struct super_block___298 *, int);
	int (*freeze_fs)(struct super_block___298 *);
	int (*unfreeze_fs)(struct super_block___298 *);
	int (*statfs)(struct dentry___298 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___298 *, int *, char *);
	void (*umount_begin)(struct super_block___298 *);
	int (*show_options)(struct seq_file___223 *, struct dentry___298 *);
	int (*show_devname)(struct seq_file___223 *, struct dentry___298 *);
	int (*show_path)(struct seq_file___223 *, struct dentry___298 *);
	int (*show_stats)(struct seq_file___223 *, struct dentry___298 *);
	ssize_t (*quota_read)(struct super_block___298 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___298 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___298 *);
	int (*bdev_try_to_free_page)(struct super_block___298 *, struct page___297 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___298 *);
	void (*free_cached_objects)(struct super_block___298 *, int);
};

struct xattr_handler___194 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___298 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___298 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___298 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___223;

struct seq_file___223 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___300 lock;
	const struct seq_operations___223 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ctl_node___103 {
	struct rb_node node;
	struct ctl_table_header___103 *header;
};

struct ctl_table_root___103 {
	struct ctl_table_set___103 default_set;
	struct ctl_table_set___103 * (*lookup)(struct ctl_table_root___103 *, struct nsproxy___178 *);
	int (*permissions)(struct ctl_table_header___103 *, struct ctl_table *);
};

struct nsproxy___178 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___98 *pid_ns;
	struct net___102 *net_ns;
};

struct signal_struct___299 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___299 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___299 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___98 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___300 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___193 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___193 *subsys[11];
	struct callback_head callback_head;
};

struct kmem_cache_cpu___280 {
	void **freelist;
	long unsigned int tid;
	struct page___297 *page;
	struct page___297 *partial;
};

struct memcg_cache_params___281 {
	bool is_root_cache;
	union {
		struct kmem_cache___281 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___281 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___88 {
	atomic_t use;
	unsigned int mask;
	struct net_device___88 *physindev;
	struct net_device___88 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___88(struct sk_buff___90 **);

struct net_device_ops___88;

struct ethtool_ops___88;

struct header_ops___88;

struct inet6_dev___52;

struct netdev_rx_queue___88;

struct netdev_queue___88;

struct rtnl_link_ops___79;

struct dcbnl_rtnl_ops___88;

struct net_device___88 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___88 *netdev_ops;
	const struct ethtool_ops___88 *ethtool_ops;
	const struct header_ops___88 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___80 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___52 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___88 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___88 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___88 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___88 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___88 = 0,
		NETREG_REGISTERED___88 = 1,
		NETREG_UNREGISTERING___88 = 2,
		NETREG_UNREGISTERED___88 = 3,
		NETREG_RELEASED___88 = 4,
		NETREG_DUMMY___88 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___88 = 0,
		RTNL_LINK_INITIALIZING___88 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___88 *);
	struct netpoll_info *npinfo;
	struct net___102 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___296 dev;
	const struct attribute_group___258 *sysfs_groups[4];
	const struct rtnl_link_ops___79 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___88 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___90 {
	struct sk_buff___90 *next;
	struct sk_buff___90 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___77 *sk;
	struct net_device___88 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___90 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___88 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___88 {
	int (*get_settings)(struct net_device___88 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___88 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___88 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___88 *);
	void (*get_regs)(struct net_device___88 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___88 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___88 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___88 *);
	void (*set_msglevel)(struct net_device___88 *, u32);
	int (*nway_reset)(struct net_device___88 *);
	u32 (*get_link)(struct net_device___88 *);
	int (*get_eeprom_len)(struct net_device___88 *);
	int (*get_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___88 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___88 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___88 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___88 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___88 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___88 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___88 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___88 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___88 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___88 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___88 *);
	void (*complete)(struct net_device___88 *);
	u32 (*get_priv_flags)(struct net_device___88 *);
	int (*set_priv_flags)(struct net_device___88 *, u32);
	int (*get_sset_count)(struct net_device___88 *, int);
	int (*get_rxnfc)(struct net_device___88 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___88 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___88 *, struct ethtool_flash *);
	int (*reset)(struct net_device___88 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___88 *);
	int (*get_rxfh_indir)(struct net_device___88 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___88 *, const u32 *);
	void (*get_channels)(struct net_device___88 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___88 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___88 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___88 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___88 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___88 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___88 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___88 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___88 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___88 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___88 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___88 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___78 {
	struct callback_head callback_head;
	struct dst_entry___78 *child;
	struct net_device___88 *dev;
	struct dst_ops___102 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___78 *path;
	struct dst_entry___78 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___90 *);
	union {
		int (*output)(struct sock___77 *, struct sk_buff___90 *);
		struct {
			int (*output)(struct sk_buff___90 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___78 *next;
		struct rtable *rt_next;
		struct rt6_info___26 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___78;

struct neigh_parms___78;

struct neigh_ops___78;

struct neighbour___78 {
	struct neighbour___78 *next;
	struct neigh_table___78 *tbl;
	struct neigh_parms___78 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___89 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___78 *, struct sk_buff___90 *);
	const struct neigh_ops___78 *ops;
	struct callback_head rcu;
	struct net_device___88 *dev;
	u8 primary_key[0];
};

struct fib6_node___26;

struct rt6_info___26 {
	struct dst_entry___78 dst;
	struct fib6_table___26 *rt6i_table;
	struct fib6_node___26 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___52 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___26 {
	struct fib6_node___26 *parent;
	struct fib6_node___26 *left;
	struct fib6_node___26 *right;
	struct rt6_info___26 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___26 *rr_ptr;
};

struct fib6_table___26 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___26 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct in6_flowlabel_req {
	struct in6_addr flr_dst;
	__be32 flr_label;
	__u8 flr_action;
	__u8 flr_share;
	__u16 flr_flags;
	__u16 flr_expires;
	__u16 flr_linger;
	__u32 __flr_pad;
};

struct nf_afinfo___103 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___90 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___90 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___102 *, struct dst_entry___78 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___90 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___90 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___222 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___222 *);
	void (*irq_shutdown)(struct irq_data___222 *);
	void (*irq_enable)(struct irq_data___222 *);
	void (*irq_disable)(struct irq_data___222 *);
	void (*irq_ack)(struct irq_data___222 *);
	void (*irq_mask)(struct irq_data___222 *);
	void (*irq_mask_ack)(struct irq_data___222 *);
	void (*irq_unmask)(struct irq_data___222 *);
	void (*irq_eoi)(struct irq_data___222 *);
	int (*irq_set_affinity)(struct irq_data___222 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___222 *);
	int (*irq_set_type)(struct irq_data___222 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___222 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___222 *);
	void (*irq_bus_sync_unlock)(struct irq_data___222 *);
	void (*irq_cpu_online)(struct irq_data___222 *);
	void (*irq_cpu_offline)(struct irq_data___222 *);
	void (*irq_suspend)(struct irq_data___222 *);
	void (*irq_resume)(struct irq_data___222 *);
	void (*irq_pm_shutdown)(struct irq_data___222 *);
	void (*irq_print_chip)(struct irq_data___222 *, struct seq_file___223 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___222 *, void *);
	long unsigned int flags;
};

struct seq_operations___223 {
	void * (*start)(struct seq_file___223 *, loff_t *);
	void (*stop)(struct seq_file___223 *, void *);
	void * (*next)(struct seq_file___223 *, void *, loff_t *);
	int (*show)(struct seq_file___223 *, void *);
};

struct seq_net_private___17 {
	struct net___102 *net;
};

struct pernet_operations___34 {
	struct list_head list;
	int (*init)(struct net___102 *);
	void (*exit)(struct net___102 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___88 {
	int (*ieee_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___88 *);
	u8 (*setstate)(struct net_device___88 *, u8);
	void (*getpermhwaddr)(struct net_device___88 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___88 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___88 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___88 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___88 *, int, u8 *);
	void (*setpfccfg)(struct net_device___88 *, int, u8);
	void (*getpfccfg)(struct net_device___88 *, int, u8 *);
	u8 (*setall)(struct net_device___88 *);
	u8 (*getcap)(struct net_device___88 *, int, u8 *);
	int (*getnumtcs)(struct net_device___88 *, int, u8 *);
	int (*setnumtcs)(struct net_device___88 *, int, u8);
	u8 (*getpfcstate)(struct net_device___88 *);
	void (*setpfcstate)(struct net_device___88 *, u8);
	void (*getbcncfg)(struct net_device___88 *, int, u32 *);
	void (*setbcncfg)(struct net_device___88 *, int, u32);
	void (*getbcnrp)(struct net_device___88 *, int, u8 *);
	void (*setbcnrp)(struct net_device___88 *, int, u8);
	u8 (*setapp)(struct net_device___88 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___88 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___88 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___88 *, int, u8);
	u8 (*getdcbx)(struct net_device___88 *);
	u8 (*setdcbx)(struct net_device___88 *, u8);
	int (*peer_getappinfo)(struct net_device___88 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___88 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___88 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___88 *, struct cee_pfc *);
};

struct cgroupfs_root___193;

struct cgroup___193 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___193 *parent;
	struct dentry___298 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___193 *subsys[11];
	struct cgroupfs_root___193 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___300 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___193 {
	struct super_block___298 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___193 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___129 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___298 *, struct file___298 *);
	ssize_t (*read)(struct cgroup___193 *, struct cftype___129 *, struct file___298 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___193 *, struct cftype___129 *);
	s64 (*read_s64)(struct cgroup___193 *, struct cftype___129 *);
	int (*read_map)(struct cgroup___193 *, struct cftype___129 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___193 *, struct cftype___129 *, struct seq_file___223 *);
	ssize_t (*write)(struct cgroup___193 *, struct cftype___129 *, struct file___298 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___193 *, struct cftype___129 *, u64);
	int (*write_s64)(struct cgroup___193 *, struct cftype___129 *, s64);
	int (*write_string)(struct cgroup___193 *, struct cftype___129 *, const char *);
	int (*trigger)(struct cgroup___193 *, unsigned int);
	int (*release)(struct inode___298 *, struct file___298 *);
	int (*register_event)(struct cgroup___193 *, struct cftype___129 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___193 *, struct cftype___129 *, struct eventfd_ctx *);
};

struct cftype_set___125 {
	struct list_head node;
	struct cftype___129 *cfts;
};

struct task_and_cgroup___125 {
	struct task_struct___299 *task;
	struct cgroup___193 *cgrp;
	struct css_set___193 *cg;
};

struct cgroup_taskset___125 {
	struct task_and_cgroup___125 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___193 *cur_cgrp;
};

struct cgroup_subsys___125 {
	struct cgroup_subsys_state___193 * (*css_alloc)(struct cgroup___193 *);
	int (*css_online)(struct cgroup___193 *);
	void (*css_offline)(struct cgroup___193 *);
	void (*css_free)(struct cgroup___193 *);
	int (*can_attach)(struct cgroup___193 *, struct cgroup_taskset___125 *);
	void (*cancel_attach)(struct cgroup___193 *, struct cgroup_taskset___125 *);
	void (*attach)(struct cgroup___193 *, struct cgroup_taskset___125 *);
	void (*fork)(struct task_struct___299 *);
	void (*exit)(struct cgroup___193 *, struct cgroup___193 *, struct task_struct___299 *);
	void (*bind)(struct cgroup___193 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___193 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___129 *base_cftypes;
	struct cftype_set___125 base_cftset;
	struct module *module;
};

struct request_sock_ops___61;

struct request_sock___62 {
	struct sock_common___77 __req_common;
	struct request_sock___62 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___61 *rsk_ops;
	struct sock___77 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_callback___90 {
	struct sk_buff___90 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___90 *, struct netlink_callback___90 *);
	int (*done)(struct netlink_callback___90 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___88 {
	int (*create)(struct sk_buff___90 *, struct net_device___88 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___90 *, unsigned char *);
	int (*rebuild)(struct sk_buff___90 *);
	int (*cache)(const struct neighbour___78 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___88 *, const unsigned char *);
};

struct napi_struct___88 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___88 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___88 *dev;
	struct sk_buff___90 *gro_list;
	struct sk_buff___90 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___88 {
	struct net_device___88 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___80 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___88 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___80 kobj;
	struct net_device___88 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___88 {
	int (*ndo_init)(struct net_device___88 *);
	void (*ndo_uninit)(struct net_device___88 *);
	int (*ndo_open)(struct net_device___88 *);
	int (*ndo_stop)(struct net_device___88 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___90 *, struct net_device___88 *);
	u16 (*ndo_select_queue)(struct net_device___88 *, struct sk_buff___90 *);
	void (*ndo_change_rx_flags)(struct net_device___88 *, int);
	void (*ndo_set_rx_mode)(struct net_device___88 *);
	int (*ndo_set_mac_address)(struct net_device___88 *, void *);
	int (*ndo_validate_addr)(struct net_device___88 *);
	int (*ndo_do_ioctl)(struct net_device___88 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___88 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___88 *, int);
	int (*ndo_neigh_setup)(struct net_device___88 *, struct neigh_parms___78 *);
	void (*ndo_tx_timeout)(struct net_device___88 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___88 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___88 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___88 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___88 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___88 *);
	int (*ndo_netpoll_setup)(struct net_device___88 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___88 *);
	int (*ndo_busy_poll)(struct napi_struct___88 *);
	int (*ndo_set_vf_mac)(struct net_device___88 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___88 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___88 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___88 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___88 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___88 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___88 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___88 *, int, struct sk_buff___90 *);
	int (*ndo_setup_tc)(struct net_device___88 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___88 *);
	int (*ndo_fcoe_disable)(struct net_device___88 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___88 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___88 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___88 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___88 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___88 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___88 *, const struct sk_buff___90 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___88 *, struct net_device___88 *);
	int (*ndo_del_slave)(struct net_device___88 *, struct net_device___88 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___78 *);
	void (*ndo_neigh_destroy)(struct neighbour___78 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___90 *, struct netlink_callback___90 *, struct net_device___88 *, int);
	int (*ndo_bridge_setlink)(struct net_device___88 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___90 *, u32, u32, struct net_device___88 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___88 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___88 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___88 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___88 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___88 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___88 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___90 *, struct net_device___88 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___88 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___88 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___88 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___78 {
	struct net___102 *net;
	struct net_device___88 *dev;
	struct neigh_parms___78 *next;
	int (*neigh_setup)(struct neighbour___78 *);
	void (*neigh_cleanup)(struct neighbour___78 *);
	struct neigh_table___78 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct ifmcaddr6___52;

struct ifacaddr6___52;

struct inet6_dev___52 {
	struct net_device___88 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___52 *mc_list;
	struct ifmcaddr6___52 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___52 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___78 *nd_parms;
	struct inet6_dev___52 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___79 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___88 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___102 *, struct net_device___88 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___88 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___88 *, struct list_head *);
	size_t (*get_size)(const struct net_device___88 *);
	int (*fill_info)(struct sk_buff___90 *, const struct net_device___88 *);
	size_t (*get_xstats_size)(const struct net_device___88 *);
	int (*fill_xstats)(struct sk_buff___90 *, const struct net_device___88 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___102 * (*get_link_net)(const struct net_device___88 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___88 *, struct net_device___88 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___88 *, const struct net_device___88 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___90 *, const struct net_device___88 *, const struct net_device___88 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___78 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___90 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___78;

struct neigh_hash_table___78;

struct neigh_table___78 {
	struct neigh_table___78 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___88 *, __u32 *);
	int (*constructor)(struct neighbour___78 *);
	int (*pconstructor)(struct pneigh_entry___78 *);
	void (*pdestructor)(struct pneigh_entry___78 *);
	void (*proxy_redo)(struct sk_buff___90 *);
	char *id;
	struct neigh_parms___78 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___89 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___78 *nht;
	struct pneigh_entry___78 **phash_buckets;
};

struct neigh_ops___78 {
	int family;
	void (*solicit)(struct neighbour___78 *, struct sk_buff___90 *);
	void (*error_report)(struct neighbour___78 *, struct sk_buff___90 *);
	int (*output)(struct neighbour___78 *, struct sk_buff___90 *);
	int (*connected_output)(struct neighbour___78 *, struct sk_buff___90 *);
};

struct pneigh_entry___78 {
	struct pneigh_entry___78 *next;
	struct net___102 *net;
	struct net_device___88 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___78 {
	struct neighbour___78 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct timewait_sock_ops___58;

struct proto___77 {
	void (*close)(struct sock___77 *, long int);
	int (*connect)(struct sock___77 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___77 *, int);
	struct sock___77 * (*accept)(struct sock___77 *, int, int *);
	int (*ioctl)(struct sock___77 *, int, long unsigned int);
	int (*init)(struct sock___77 *);
	void (*destroy)(struct sock___77 *);
	void (*shutdown)(struct sock___77 *, int);
	int (*setsockopt)(struct sock___77 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___77 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___77 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___77 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___77 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___85 *, struct sock___77 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___85 *, struct sock___77 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___77 *, struct page___297 *, int, size_t, int);
	int (*bind)(struct sock___77 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___77 *, struct sk_buff___90 *);
	void (*release_cb)(struct sock___77 *);
	void (*mtu_reduced)(struct sock___77 *);
	void (*hash)(struct sock___77 *);
	void (*unhash)(struct sock___77 *);
	void (*rehash)(struct sock___77 *);
	int (*get_port)(struct sock___77 *, short unsigned int);
	void (*clear_sk)(struct sock___77 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___77 *);
	void (*enter_memory_pressure)(struct sock___77 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___281 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___61 *rsk_prot;
	struct timewait_sock_ops___58 *twsk_prot;
	union {
		struct inet_hashinfo___22 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___125 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___77 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___77 {
	void (*enter_memory_pressure)(struct sock___77 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___61 {
	int family;
	int obj_size;
	struct kmem_cache___281 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___77 *, struct request_sock___62 *);
	void (*send_ack)(struct sock___77 *, struct sk_buff___90 *, struct request_sock___62 *);
	void (*send_reset)(struct sock___77 *, struct sk_buff___90 *);
	void (*destructor)(struct request_sock___62 *);
	void (*syn_ack_timeout)(struct sock___77 *, struct request_sock___62 *);
};

struct timewait_sock_ops___58 {
	struct kmem_cache___281 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___77 *, struct sock___77 *, void *);
	void (*twsk_destructor)(struct sock___77 *);
};

struct inet_cork___31 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___78 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___31 {
	struct inet_cork___31 base;
	struct flowi fl;
};

struct ipv6_pinfo___30;

struct inet_sock___31 {
	struct sock___77 sk;
	struct ipv6_pinfo___30 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___31 cork;
};

struct ipv6_fl_socklist___29;

struct ipv6_pinfo___30 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___29 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___90 *pktoptions;
	struct sk_buff___90 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___29;

struct ipv6_fl_socklist___29 {
	struct ipv6_fl_socklist___29 *next;
	struct ip6_flowlabel___29 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___52 {
	struct in6_addr mca_addr;
	struct inet6_dev___52 *idev;
	struct ifmcaddr6___52 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___52 {
	struct in6_addr aca_addr;
	struct inet6_dev___52 *aca_idev;
	struct rt6_info___26 *aca_rt;
	struct ifacaddr6___52 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___29 {
	struct ip6_flowlabel___29 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___98 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___102 *fl_net;
};

struct ip6fl_iter_state {
	struct seq_net_private___17 p;
	struct pid_namespace___98 *pid_ns;
	int bucket;
};

struct page___298;

typedef struct page___298 *pgtable_t___298;

struct address_space___299;

struct kmem_cache___282;

struct page___298 {
	long unsigned int flags;
	struct address_space___299 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___298 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___298 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___282 *slab_cache;
		struct page___298 *first_page;
	};
	long: 64;
};

struct task_struct___300;

struct pv_cpu_ops___300 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___300 *);
	void (*end_context_switch)(struct task_struct___300 *);
};

struct mutex___301 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___300 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___293 {
	struct page___298 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___307;

struct nsproxy___179;

struct signal_struct___300;

struct css_set___194;

struct task_struct___300 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___300 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___307 *mm;
	struct mm_struct___307 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___300 *real_parent;
	struct task_struct___300 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___300 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___98 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___300 = 0,
		VTIME_USER___300 = 1,
		VTIME_SYS___300 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___179 *nsproxy;
	struct signal_struct___300 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___194 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___301 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___293 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___307 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___307 *, struct mm_struct___307 *);
	void (*dup_mmap)(struct mm_struct___307 *, struct mm_struct___307 *);
	void (*exit_mmap)(struct mm_struct___307 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___307 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___307 *);
	void (*pgd_free)(struct mm_struct___307 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___307 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___307 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___307 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___307 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___307 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___307 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___307 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___307 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___307 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___307 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___307 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___301 lock;
	void *vdso;
} mm_context_t___301;

struct xol_area___298;

struct uprobes_state___298 {
	struct xol_area___298 *xol_area;
};

struct vm_area_struct___307;

struct file___299;

struct core_state___300;

struct mm_struct___307 {
	struct vm_area_struct___307 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___307 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___307 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___301 context;
	long unsigned int flags;
	struct core_state___300 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___300 *owner;
	struct file___299 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___298 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___298 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___298 *page;
	long unsigned int vaddr;
};

struct kset___81;

struct kobj_type___81;

struct kobject___81 {
	const char *name;
	struct list_head entry;
	struct kobject___81 *parent;
	struct kset___81 *kset;
	struct kobj_type___81 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___281;

struct memcg_cache_params___282;

struct kmem_cache___282 {
	struct kmem_cache_cpu___281 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___81 kobj;
	struct memcg_cache_params___282 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___299;

struct address_space_operations___299;

struct address_space___299 {
	struct inode___299 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___301 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___299 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___299;

struct path___299 {
	struct vfsmount *mnt;
	struct dentry___299 *dentry;
};

struct file_operations___299;

struct file___299 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___299 f_path;
	struct inode___299 *f_inode;
	const struct file_operations___299 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___299 *f_mapping;
	struct mutex___301 f_pos_lock;
};

struct vm_operations_struct___273;

struct vm_area_struct___307 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___307 *vm_next;
	struct vm_area_struct___307 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___307 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___273 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___299 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___269;

struct vm_operations_struct___273 {
	void (*open)(struct vm_area_struct___307 *);
	void (*close)(struct vm_area_struct___307 *);
	int (*fault)(struct vm_area_struct___307 *, struct vm_fault___269 *);
	int (*page_mkwrite)(struct vm_area_struct___307 *, struct vm_fault___269 *);
	int (*access)(struct vm_area_struct___307 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___307 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___307 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___307 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___307 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___300 {
	struct task_struct___300 *task;
	struct core_thread___300 *next;
};

struct core_state___300 {
	atomic_t nr_threads;
	struct core_thread___300 dumper;
	struct completion startup;
};

struct irq_data___223;

struct x86_io_apic_ops___223 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___223 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___223;

struct irq_data___223 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___223 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___297;

struct dev_pm_ops___297 {
	int (*prepare)(struct device___297 *);
	void (*complete)(struct device___297 *);
	int (*suspend)(struct device___297 *);
	int (*resume)(struct device___297 *);
	int (*freeze)(struct device___297 *);
	int (*thaw)(struct device___297 *);
	int (*poweroff)(struct device___297 *);
	int (*restore)(struct device___297 *);
	int (*suspend_late)(struct device___297 *);
	int (*resume_early)(struct device___297 *);
	int (*freeze_late)(struct device___297 *);
	int (*thaw_early)(struct device___297 *);
	int (*poweroff_late)(struct device___297 *);
	int (*restore_early)(struct device___297 *);
	int (*suspend_noirq)(struct device___297 *);
	int (*resume_noirq)(struct device___297 *);
	int (*freeze_noirq)(struct device___297 *);
	int (*thaw_noirq)(struct device___297 *);
	int (*poweroff_noirq)(struct device___297 *);
	int (*restore_noirq)(struct device___297 *);
	int (*runtime_suspend)(struct device___297 *);
	int (*runtime_resume)(struct device___297 *);
	int (*runtime_idle)(struct device___297 *);
};

struct dev_pm_qos___100;

struct dev_pm_info___100 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___100 *qos;
};

struct dma_map_ops___162;

struct dev_archdata___162 {
	struct dma_map_ops___162 *dma_ops;
	void *iommu;
};

struct device_type___297;

struct bus_type___297;

struct device_driver___297;

struct dev_pm_domain___297;

struct class___297;

struct attribute_group___259;

struct device_rh___297;

struct device___297 {
	struct device___297 *parent;
	struct device_private *p;
	struct kobject___81 kobj;
	const char *init_name;
	const struct device_type___297 *type;
	struct mutex___301 mutex;
	struct bus_type___297 *bus;
	struct device_driver___297 *driver;
	void *platform_data;
	struct dev_pm_info___100 power;
	struct dev_pm_domain___297 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___162 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___39 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___297 *class;
	const struct attribute_group___259 **groups;
	void (*release)(struct device___297 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___297 *device_rh;
};

struct dev_pm_qos_request___101;

struct dev_pm_qos___100 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___101 *latency_req;
	struct dev_pm_qos_request___101 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___101 *latency_tolerance_req;
};

struct dev_pm_info_rh___297 {
	void (*set_latency_tolerance)(struct device___297 *, s32);
};

struct dev_pm_domain___297 {
	struct dev_pm_ops___297 ops;
};

struct smp_ops___300 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___300 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___300;

struct lruvec___300 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___300 *zone;
};

struct pglist_data___300;

struct zone___300 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___300 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___300 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___300 {
	struct zone___300 *zone;
	int zone_idx;
};

struct zonelist___300 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___300 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___300 {
	struct zone___300 node_zones[4];
	struct zonelist___300 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___300 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___104;

struct ctl_node___104 {
	struct rb_node node;
	struct ctl_table_header___104 *header;
};

struct ctl_table_root___104;

struct ctl_table_set___104;

struct ctl_dir___104;

struct ctl_table_header___104 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___104 *root;
	struct ctl_table_set___104 *set;
	struct ctl_dir___104 *parent;
	struct ctl_node___104 *node;
};

struct ctl_dir___104 {
	struct ctl_table_header___104 header;
	struct rb_root root;
};

struct ctl_table_set___104 {
	int (*is_seen)(struct ctl_table_set___104 *);
	struct ctl_dir___104 dir;
};

struct ctl_table_root___104 {
	struct ctl_table_set___104 default_set;
	struct ctl_table_set___104 * (*lookup)(struct ctl_table_root___104 *, struct nsproxy___179 *);
	int (*permissions)(struct ctl_table_header___104 *, struct ctl_table *);
};

struct net___103;

struct nsproxy___179 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___103 *net_ns;
};

struct signal_struct___300 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___300 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___300 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___98 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___301 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___194;

struct css_set___194 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___194 *subsys[11];
	struct callback_head callback_head;
};

struct vm_fault___269 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___298 *page;
};

struct kiocb___86;

struct poll_table_struct___185;

struct file_lock___299;

struct seq_file___224;

struct file_operations___299 {
	struct module *owner;
	loff_t (*llseek)(struct file___299 *, loff_t, int);
	ssize_t (*read)(struct file___299 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___299 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___86 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___86 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___299 *, void *, filldir_t);
	unsigned int (*poll)(struct file___299 *, struct poll_table_struct___185 *);
	long int (*unlocked_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___299 *, struct vm_area_struct___307 *);
	int (*open)(struct inode___299 *, struct file___299 *);
	int (*flush)(struct file___299 *, fl_owner_t);
	int (*release)(struct inode___299 *, struct file___299 *);
	int (*fsync)(struct file___299 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___86 *, int);
	int (*fasync)(int, struct file___299 *, int);
	int (*lock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*sendpage)(struct file___299 *, struct page___298 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___299 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___299 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___299 *, long int, struct file_lock___299 **, void **);
		struct {
			int (*setlease)(struct file___299 *, long int, struct file_lock___299 **);
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long int (*fallocate)(struct file___299 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___224 *, struct file___299 *);
};

struct sock___78;

struct kobj_ns_type_operations___78 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___78 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___78;

struct sock_common___78 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___78 *skc_prot;
	struct net___103 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___91;

struct sk_buff_head___90 {
	struct sk_buff___91 *next;
	struct sk_buff___91 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___79;

struct socket_wq___78;

struct dst_entry___79;

struct socket___79;

struct cg_proto___78;

struct sock___78 {
	struct sock_common___78 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___90 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___91 *head;
		struct sk_buff___91 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___79 *sk_filter;
	struct socket_wq___78 *sk_wq;
	struct sk_buff_head___90 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___79 *sk_rx_dst;
	struct dst_entry___79 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___90 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___90 sk_error_queue;
	struct proto___78 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___98 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___79 *sk_socket;
	void *sk_user_data;
	struct page_frag___293 sk_frag;
	struct sk_buff___91 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___78 *sk_cgrp;
	void (*sk_state_change)(struct sock___78 *);
	void (*sk_data_ready)(struct sock___78 *, int);
	void (*sk_write_space)(struct sock___78 *);
	void (*sk_error_report)(struct sock___78 *);
	int (*sk_backlog_rcv)(struct sock___78 *, struct sk_buff___91 *);
	void (*sk_destruct)(struct sock___78 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___261;

struct attribute_group___259 {
	const char *name;
	umode_t (*is_visible)(struct kobject___81 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___261 **bin_attrs;
};

struct bin_attribute___261 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___299 *, struct kobject___81 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___299 *, struct kobject___81 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	int (*mmap)(struct file___299 *, struct kobject___81 *, struct bin_attribute___261 *, struct vm_area_struct___307 *);
};

struct sysfs_ops___81 {
	ssize_t (*show)(struct kobject___81 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___81 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___81 *, const struct attribute *);
};

struct kset_uevent_ops___81;

struct kset___81 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___81 kobj;
	const struct kset_uevent_ops___81 *uevent_ops;
};

struct kobj_type___81 {
	void (*release)(struct kobject___81 *);
	const struct sysfs_ops___81 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___78 * (*child_ns_type)(struct kobject___81 *);
	const void * (*namespace)(struct kobject___81 *);
};

struct kset_uevent_ops___81 {
	int (* const filter)(struct kset___81 *, struct kobject___81 *);
	const char * (* const name)(struct kset___81 *, struct kobject___81 *);
	int (* const uevent)(struct kset___81 *, struct kobject___81 *, struct kobj_uevent_env *);
};

struct dma_map_ops___162 {
	void * (*alloc)(struct device___297 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___297 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___297 *, struct vm_area_struct___307 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___297 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___297 *, struct page___298 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___297 *, dma_addr_t);
	int (*dma_supported)(struct device___297 *, u64);
	int (*set_dma_mask)(struct device___297 *, u64);
	int is_phys;
};

struct bus_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___297 *, char *);
	ssize_t (*store)(struct bus_type___297 *, const char *, size_t);
};

struct device_attribute___297;

struct driver_attribute___297;

struct bus_type___297 {
	const char *name;
	const char *dev_name;
	struct device___297 *dev_root;
	struct bus_attribute___297 *bus_attrs;
	struct device_attribute___297 *dev_attrs;
	struct driver_attribute___297 *drv_attrs;
	const struct attribute_group___259 **bus_groups;
	const struct attribute_group___259 **dev_groups;
	const struct attribute_group___259 **drv_groups;
	int (*match)(struct device___297 *, struct device_driver___297 *);
	int (*uevent)(struct device___297 *, struct kobj_uevent_env *);
	int (*probe)(struct device___297 *);
	int (*remove)(struct device___297 *);
	void (*shutdown)(struct device___297 *);
	int (*online)(struct device___297 *);
	int (*offline)(struct device___297 *);
	int (*suspend)(struct device___297 *, pm_message_t);
	int (*resume)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct device___297 *, struct device_attribute___297 *, char *);
	ssize_t (*store)(struct device___297 *, struct device_attribute___297 *, const char *, size_t);
};

struct driver_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___297 *, char *);
	ssize_t (*store)(struct device_driver___297 *, const char *, size_t);
};

struct device_driver___297 {
	const char *name;
	struct bus_type___297 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___297 *);
	int (*remove)(struct device___297 *);
	void (*shutdown)(struct device___297 *);
	int (*suspend)(struct device___297 *, pm_message_t);
	int (*resume)(struct device___297 *);
	const struct attribute_group___259 **groups;
	const struct dev_pm_ops___297 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___297 {
	const char *name;
	const struct attribute_group___259 **groups;
	int (*uevent)(struct device___297 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___297 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
};

struct class_attribute___297;

struct class___297 {
	const char *name;
	struct module *owner;
	struct class_attribute___297 *class_attrs;
	struct device_attribute___297 *dev_attrs;
	const struct attribute_group___259 **dev_groups;
	struct bin_attribute___261 *dev_bin_attrs;
	struct kobject___81 *dev_kobj;
	int (*dev_uevent)(struct device___297 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___297 *, umode_t *);
	void (*class_release)(struct class___297 *);
	void (*dev_release)(struct device___297 *);
	int (*suspend)(struct device___297 *, pm_message_t);
	int (*resume)(struct device___297 *);
	const struct kobj_ns_type_operations___78 *ns_type;
	const void * (*namespace)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
	struct subsys_private *p;
};

struct class_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct class___297 *, struct class_attribute___297 *, char *);
	ssize_t (*store)(struct class___297 *, struct class_attribute___297 *, const char *, size_t);
	const void * (*namespace)(struct class___297 *, const struct class_attribute___297 *);
};

struct device_rh___297 {
	struct dev_pm_info_rh___297 power;
};

struct dev_pm_qos_request___101 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___297 *dev;
};

struct dentry_operations___299;

struct super_block___299;

struct dentry___299 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___299 *d_parent;
	struct qstr d_name;
	struct inode___299 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___299 *d_op;
	struct super_block___299 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___299;

struct dquot___299;

struct block_device___299;

struct inode___299 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___299 *i_op;
	struct super_block___299 *i_sb;
	struct address_space___299 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___301 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___299 *i_fop;
	struct file_lock___299 *i_flock;
	struct address_space___299 i_data;
	struct dquot___299 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___299 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___299 {
	int (*d_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_hash)(const struct dentry___299 *, struct qstr *);
	int (*d_compare)(const struct dentry___299 *, const struct dentry___299 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___299 *);
	void (*d_release)(struct dentry___299 *);
	void (*d_prune)(struct dentry___299 *);
	void (*d_iput)(struct dentry___299 *, struct inode___299 *);
	char * (*d_dname)(struct dentry___299 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___299 *);
	int (*d_manage)(struct dentry___299 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___299;

struct mem_dqinfo___299 {
	struct quota_format_type___299 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___299;

struct quota_info___299 {
	unsigned int flags;
	struct mutex___301 dqio_mutex;
	struct mutex___301 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___299 *files[2];
	struct mem_dqinfo___299 info[2];
	const struct quota_format_ops___299 *ops[2];
};

struct file_system_type___299;

struct super_operations___299;

struct dquot_operations___299;

struct quotactl_ops___299;

struct xattr_handler___195;

struct super_block___299 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___299 *s_type;
	const struct super_operations___299 *s_op;
	const struct dquot_operations___299 *dq_op;
	const struct quotactl_ops___299 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___299 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___195 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___299 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___299 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___301 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___299 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___299 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___299 *bd_inode;
	struct super_block___299 *bd_super;
	struct mutex___301 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___299 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___301 bd_fsfreeze_mutex;
};

struct cgroup___194;

struct cgroup_subsys_state___194 {
	struct cgroup___194 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

typedef int kiocb_cancel_fn___86(struct kiocb___86 *, struct io_event *);

struct kiocb___86 {
	atomic_t ki_users;
	struct file___299 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___86 *ki_cancel;
	void (*ki_dtor)(struct kiocb___86 *);
	union {
		void *user;
		struct task_struct___300 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___299 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___299 *ia_file;
};

struct dquot___299 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___301 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___299 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___299 {
	int qf_fmt_id;
	const struct quota_format_ops___299 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___299 *qf_next;
};

struct quota_format_ops___299 {
	int (*check_quota_file)(struct super_block___299 *, int);
	int (*read_file_info)(struct super_block___299 *, int);
	int (*write_file_info)(struct super_block___299 *, int);
	int (*free_file_info)(struct super_block___299 *, int);
	int (*read_dqblk)(struct dquot___299 *);
	int (*commit_dqblk)(struct dquot___299 *);
	int (*release_dqblk)(struct dquot___299 *);
};

struct dquot_operations___299 {
	int (*write_dquot)(struct dquot___299 *);
	struct dquot___299 * (*alloc_dquot)(struct super_block___299 *, int);
	void (*destroy_dquot)(struct dquot___299 *);
	int (*acquire_dquot)(struct dquot___299 *);
	int (*release_dquot)(struct dquot___299 *);
	int (*mark_dirty)(struct dquot___299 *);
	int (*write_info)(struct super_block___299 *, int);
	qsize_t * (*get_reserved_space)(struct inode___299 *);
};

struct quotactl_ops___299 {
	int (*quota_on)(struct super_block___299 *, int, int, struct path___299 *);
	int (*quota_on_meta)(struct super_block___299 *, int, int);
	int (*quota_off)(struct super_block___299 *, int);
	int (*quota_sync)(struct super_block___299 *, int);
	int (*get_info)(struct super_block___299 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___299 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___299 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___299 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___299 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___299 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___299 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___299 *, unsigned int);
};

struct address_space_operations___299 {
	int (*writepage)(struct page___298 *, struct writeback_control *);
	int (*readpage)(struct file___299 *, struct page___298 *);
	int (*writepages)(struct address_space___299 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___298 *);
	int (*readpages)(struct file___299 *, struct address_space___299 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___299 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___298 **, void **);
	int (*write_end)(struct file___299 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___298 *, void *);
	sector_t (*bmap)(struct address_space___299 *, sector_t);
	void (*invalidatepage)(struct page___298 *, long unsigned int);
	int (*releasepage)(struct page___298 *, gfp_t);
	void (*freepage)(struct page___298 *);
	ssize_t (*direct_IO)(int, struct kiocb___86 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___299 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___299 *, struct page___298 *, struct page___298 *, enum migrate_mode);
	int (*launder_page)(struct page___298 *);
	int (*is_partially_uptodate)(struct page___298 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___298 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___299 *, struct page___298 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___299 *, sector_t *);
	void (*swap_deactivate)(struct file___299 *);
	void (*invalidatepage_range)(struct page___298 *, unsigned int, unsigned int);
};

struct inode_operations___299 {
	struct dentry___299 * (*lookup)(struct inode___299 *, struct dentry___299 *, unsigned int);
	void * (*follow_link)(struct dentry___299 *, struct nameidata *);
	int (*permission)(struct inode___299 *, int);
	struct posix_acl * (*get_acl)(struct inode___299 *, int);
	int (*readlink)(struct dentry___299 *, char *, int);
	void (*put_link)(struct dentry___299 *, struct nameidata *, void *);
	int (*create)(struct inode___299 *, struct dentry___299 *, umode_t, bool);
	int (*link)(struct dentry___299 *, struct inode___299 *, struct dentry___299 *);
	int (*unlink)(struct inode___299 *, struct dentry___299 *);
	int (*symlink)(struct inode___299 *, struct dentry___299 *, const char *);
	int (*mkdir)(struct inode___299 *, struct dentry___299 *, umode_t);
	int (*rmdir)(struct inode___299 *, struct dentry___299 *);
	int (*mknod)(struct inode___299 *, struct dentry___299 *, umode_t, dev_t);
	int (*rename)(struct inode___299 *, struct dentry___299 *, struct inode___299 *, struct dentry___299 *);
	int (*setattr)(struct dentry___299 *, struct iattr___299 *);
	int (*getattr)(struct vfsmount *, struct dentry___299 *, struct kstat *);
	int (*setxattr)(struct dentry___299 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___299 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___299 *, char *, size_t);
	int (*removexattr)(struct dentry___299 *, const char *);
	int (*fiemap)(struct inode___299 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___299 *, struct timespec *, int);
	int (*atomic_open)(struct inode___299 *, struct dentry___299 *, struct file___299 *, unsigned int, umode_t, int *);
	long: 64;
};

struct fasync_struct___299;

struct file_lock_operations___299;

struct lock_manager_operations___299;

struct file_lock___299 {
	struct file_lock___299 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___98 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___299 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___299 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___299 *fl_ops;
	const struct lock_manager_operations___299 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___299 {
	void (*fl_copy_lock)(struct file_lock___299 *, struct file_lock___299 *);
	void (*fl_release_private)(struct file_lock___299 *);
};

struct lock_manager_operations___299 {
	int (*lm_compare_owner)(struct file_lock___299 *, struct file_lock___299 *);
	long unsigned int (*lm_owner_key)(struct file_lock___299 *);
	void (*lm_notify)(struct file_lock___299 *);
	int (*lm_grant)(struct file_lock___299 *, struct file_lock___299 *, int);
	void (*lm_break)(struct file_lock___299 *);
	int (*lm_change)(struct file_lock___299 **, int);
};

struct fasync_struct___299 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___299 *fa_next;
	struct file___299 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___299 {
	const char *name;
	int fs_flags;
	struct dentry___299 * (*mount)(struct file_system_type___299 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___299 *);
	struct module *owner;
	struct file_system_type___299 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___299 {
	struct inode___299 * (*alloc_inode)(struct super_block___299 *);
	void (*destroy_inode)(struct inode___299 *);
	void (*dirty_inode)(struct inode___299 *, int);
	int (*write_inode)(struct inode___299 *, struct writeback_control *);
	int (*drop_inode)(struct inode___299 *);
	void (*evict_inode)(struct inode___299 *);
	void (*put_super)(struct super_block___299 *);
	int (*sync_fs)(struct super_block___299 *, int);
	int (*freeze_fs)(struct super_block___299 *);
	int (*unfreeze_fs)(struct super_block___299 *);
	int (*statfs)(struct dentry___299 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___299 *, int *, char *);
	void (*umount_begin)(struct super_block___299 *);
	int (*show_options)(struct seq_file___224 *, struct dentry___299 *);
	int (*show_devname)(struct seq_file___224 *, struct dentry___299 *);
	int (*show_path)(struct seq_file___224 *, struct dentry___299 *);
	int (*show_stats)(struct seq_file___224 *, struct dentry___299 *);
	ssize_t (*quota_read)(struct super_block___299 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___299 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___299 *);
	int (*bdev_try_to_free_page)(struct super_block___299 *, struct page___298 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___299 *);
	void (*free_cached_objects)(struct super_block___299 *, int);
};

struct xattr_handler___195 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___299 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___299 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___299 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___187)(struct file___299 *, wait_queue_head_t *, struct poll_table_struct___185 *);

struct poll_table_struct___185 {
	poll_queue_proc___187 _qproc;
	long unsigned int _key;
};

struct seq_operations___224;

struct seq_file___224 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___301 lock;
	const struct seq_operations___224 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct socket_wq___78 {
	wait_queue_head_t wait;
	struct fasync_struct___299 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___78;

struct socket___79 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___78 *wq;
	struct file___299 *file;
	struct sock___78 *sk;
	const struct proto_ops___78 *ops;
};

struct proto_ops___78 {
	int family;
	struct module *owner;
	int (*release)(struct socket___79 *);
	int (*bind)(struct socket___79 *, struct sockaddr *, int);
	int (*connect)(struct socket___79 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___79 *, struct socket___79 *);
	int (*accept)(struct socket___79 *, struct socket___79 *, int);
	int (*getname)(struct socket___79 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___299 *, struct socket___79 *, struct poll_table_struct___185 *);
	int (*ioctl)(struct socket___79 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___79 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___79 *, int);
	int (*shutdown)(struct socket___79 *, int);
	int (*setsockopt)(struct socket___79 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___79 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___79 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___79 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___86 *, struct socket___79 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___86 *, struct socket___79 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___299 *, struct socket___79 *, struct vm_area_struct___307 *);
	ssize_t (*sendpage)(struct socket___79 *, struct page___298 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___79 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___78 *, int);
		struct {
			void (*set_peek_off)(struct sock___78 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___101 {
	struct ctl_table_header___104 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___102 {
	struct mutex___301 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___101 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___104 *ctl;
};

struct fib_rules_ops___7;

struct netns_ipv4___101 {
	struct ctl_table_header___104 *forw_hdr;
	struct ctl_table_header___104 *frags_hdr;
	struct ctl_table_header___104 *ipv4_hdr;
	struct ctl_table_header___104 *route_hdr;
	struct ctl_table_header___104 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops___7 *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___78 *fibnl;
	struct sock___78 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops___7 *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___101 {
	struct ctl_table_header___104 *hdr;
	struct ctl_table_header___104 *route_hdr;
	struct ctl_table_header___104 *icmp_hdr;
	struct ctl_table_header___104 *frags_hdr;
	struct ctl_table_header___104 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___89;

struct neighbour___79;

struct dst_ops___103 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___103 *);
	struct dst_entry___79 * (*check)(struct dst_entry___79 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___79 *);
	unsigned int (*mtu)(const struct dst_entry___79 *);
	u32 * (*cow_metrics)(struct dst_entry___79 *, long unsigned int);
	void (*destroy)(struct dst_entry___79 *);
	void (*ifdown)(struct dst_entry___79 *, struct net_device___89 *, int);
	struct dst_entry___79 * (*negative_advice)(struct dst_entry___79 *);
	void (*link_failure)(struct sk_buff___91 *);
	void (*update_pmtu)(struct dst_entry___79 *, struct sock___78 *, struct sk_buff___91 *, u32);
	void (*redirect)(struct dst_entry___79 *, struct sock___78 *, struct sk_buff___91 *);
	int (*local_out)(struct sk_buff___91 *);
	struct neighbour___79 * (*neigh_lookup)(const struct dst_entry___79 *, struct sk_buff___91 *, const void *);
	struct kmem_cache___282 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct rt6_info___27;

struct fib6_table___27;

struct netns_ipv6___103 {
	struct netns_sysctl_ipv6___101 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info___27 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___27 *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___103 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info___27 *ip6_prohibit_entry;
	struct rt6_info___27 *ip6_blk_hole_entry;
	struct fib6_table___27 *fib6_local_tbl;
	struct fib_rules_ops___7 *fib6_rules_ops;
	struct sock___78 **icmp_sk;
	struct sock___78 *ndisc_sk;
	struct sock___78 *tcp_sk;
	struct sock___78 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___7 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___101 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___104 *sysctl_header;
	struct sock___78 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___78 {
	struct sock___78 *v4_ctl_sk;
	struct sock___78 *v6_ctl_sk;
};

struct netns_nf___101 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___104 *nf_log_dir_header;
};

struct nf_proto_net___101 {
	struct ctl_table_header___104 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___101 {
	struct nf_proto_net___101 pn;
	unsigned int timeout;
};

struct nf_tcp_net___101 {
	struct nf_proto_net___101 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___101 {
	struct nf_proto_net___101 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___101 {
	struct nf_proto_net___101 pn;
	unsigned int timeout;
};

struct nf_ip_net___101 {
	struct nf_generic_net___101 generic;
	struct nf_tcp_net___101 tcp;
	struct nf_udp_net___101 udp;
	struct nf_icmp_net___101 icmp;
	struct nf_icmp_net___101 icmpv6;
};

struct netns_ct___102 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___104 *sysctl_header;
	struct ctl_table_header___104 *acct_sysctl_header;
	struct ctl_table_header___104 *tstamp_sysctl_header;
	struct ctl_table_header___104 *event_sysctl_header;
	struct ctl_table_header___104 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___282 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___101 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___101 {
	struct netns_sysctl_ipv6___101 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___103 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___78 *nlsk;
	struct sock___78 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___104 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___103 xfrm4_dst_ops;
	struct dst_ops___103 xfrm6_dst_ops;
};

struct net___103 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___104 sysctls;
	struct sock___78 *rtnl;
	struct sock___78 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___89 *loopback_dev;
	struct netns_core___101 core;
	struct netns_mib mib;
	struct netns_packet___102 packet;
	struct netns_unix___101 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___101 ipv4;
	struct netns_ipv6___103 ipv6;
	struct netns_sctp___101 sctp;
	struct netns_dccp___78 dccp;
	struct netns_nf___101 nf;
	struct netns_xt xt;
	struct netns_ct___102 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___101 nf_frag;
	struct sock___78 *nfnl;
	struct sock___78 *nfnl_stash;
	struct sk_buff_head___90 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___103 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___78 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___78 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___301 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___301 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___281 {
	void **freelist;
	long unsigned int tid;
	struct page___298 *page;
	struct page___298 *partial;
};

struct memcg_cache_params___282 {
	bool is_root_cache;
	union {
		struct kmem_cache___282 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___282 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___89 {
	atomic_t use;
	unsigned int mask;
	struct net_device___89 *physindev;
	struct net_device___89 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___89(struct sk_buff___91 **);

struct net_device_ops___89;

struct ethtool_ops___89;

struct header_ops___89;

struct in_device___16;

struct inet6_dev___53;

struct netdev_rx_queue___89;

struct netdev_queue___89;

struct rtnl_link_ops___80;

struct dcbnl_rtnl_ops___89;

struct net_device___89 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___89 *netdev_ops;
	const struct ethtool_ops___89 *ethtool_ops;
	const struct header_ops___89 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___81 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device___16 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___53 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___89 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___89 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___89 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___89 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___89 = 0,
		NETREG_REGISTERED___89 = 1,
		NETREG_UNREGISTERING___89 = 2,
		NETREG_UNREGISTERED___89 = 3,
		NETREG_RELEASED___89 = 4,
		NETREG_DUMMY___89 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___89 = 0,
		RTNL_LINK_INITIALIZING___89 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___89 *);
	struct netpoll_info *npinfo;
	struct net___103 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___297 dev;
	const struct attribute_group___259 *sysfs_groups[4];
	const struct rtnl_link_ops___80 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___89 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___91 {
	struct sk_buff___91 *next;
	struct sk_buff___91 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___78 *sk;
	struct net_device___89 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___91 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___89 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___25 {
	struct {
		struct page___298 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___25 skb_frag_t___25;

struct skb_shared_info___25 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___91 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___25 frags[17];
};

struct ethtool_ops___89 {
	int (*get_settings)(struct net_device___89 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___89 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___89 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___89 *);
	void (*get_regs)(struct net_device___89 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___89 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___89 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___89 *);
	void (*set_msglevel)(struct net_device___89 *, u32);
	int (*nway_reset)(struct net_device___89 *);
	u32 (*get_link)(struct net_device___89 *);
	int (*get_eeprom_len)(struct net_device___89 *);
	int (*get_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___89 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___89 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___89 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___89 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___89 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___89 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___89 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___89 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___89 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___89 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___89 *);
	void (*complete)(struct net_device___89 *);
	u32 (*get_priv_flags)(struct net_device___89 *);
	int (*set_priv_flags)(struct net_device___89 *, u32);
	int (*get_sset_count)(struct net_device___89 *, int);
	int (*get_rxnfc)(struct net_device___89 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___89 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___89 *, struct ethtool_flash *);
	int (*reset)(struct net_device___89 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___89 *);
	int (*get_rxfh_indir)(struct net_device___89 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___89 *, const u32 *);
	void (*get_channels)(struct net_device___89 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___89 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___89 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___89 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___89 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___89 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___89 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___89 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___89 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___89 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___89 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___89 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct fib_rule___7;

struct fib_lookup_arg___7;

struct fib_rules_ops___7 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	int (*action)(struct fib_rule___7 *, struct flowi *, int, struct fib_lookup_arg___7 *);
	int (*match)(struct fib_rule___7 *, struct flowi *, int);
	int (*configure)(struct fib_rule___7 *, struct sk_buff___91 *, struct fib_rule_hdr *, struct nlattr **);
	void (*delete)(struct fib_rule___7 *);
	int (*compare)(struct fib_rule___7 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___7 *, struct sk_buff___91 *, struct fib_rule_hdr *);
	u32 (*default_pref)(struct fib_rules_ops___7 *);
	size_t (*nlmsg_payload)(struct fib_rule___7 *);
	void (*flush_cache)(struct fib_rules_ops___7 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module *owner;
	struct net___103 *fro_net;
	struct callback_head rcu;
};

struct rtable___47;

struct dst_entry___79 {
	struct callback_head callback_head;
	struct dst_entry___79 *child;
	struct net_device___89 *dev;
	struct dst_ops___103 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___79 *path;
	struct dst_entry___79 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___91 *);
	union {
		int (*output)(struct sock___78 *, struct sk_buff___91 *);
		struct {
			int (*output)(struct sk_buff___91 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___79 *next;
		struct rtable___47 *rt_next;
		struct rt6_info___27 *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___79;

struct neigh_parms___79;

struct neigh_ops___79;

struct neighbour___79 {
	struct neighbour___79 *next;
	struct neigh_table___79 *tbl;
	struct neigh_parms___79 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___90 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___79 *, struct sk_buff___91 *);
	const struct neigh_ops___79 *ops;
	struct callback_head rcu;
	struct net_device___89 *dev;
	u8 primary_key[0];
};

struct fib6_node___27;

struct rt6_info___27 {
	struct dst_entry___79 dst;
	struct fib6_table___27 *rt6i_table;
	struct fib6_node___27 *rt6i_node;
	struct in6_addr rt6i_gateway;
	struct list_head rt6i_siblings;
	unsigned int rt6i_nsiblings;
	atomic_t rt6i_ref;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rt6key rt6i_dst;
	u32 rt6i_flags;
	struct rt6key rt6i_src;
	struct rt6key rt6i_prefsrc;
	u32 rt6i_metric;
	struct inet6_dev___53 *rt6i_idev;
	long unsigned int _rt6i_peer;
	u32 rt6i_genid;
	short unsigned int rt6i_nfheader_len;
	u8 rt6i_protocol;
	long: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_node___27 {
	struct fib6_node___27 *parent;
	struct fib6_node___27 *left;
	struct fib6_node___27 *right;
	struct rt6_info___27 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	__u32 fn_sernum;
	struct rt6_info___27 *rr_ptr;
};

struct fib6_table___27 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	rwlock_t tb6_lock;
	struct fib6_node___27 tb6_root;
	struct inet_peer_base tb6_peers;
};

struct nf_hook_state___17 {
	size_t size;
	unsigned int hook;
	int thresh;
	u_int8_t pf;
	struct net_device___89 *in;
	struct net_device___89 *out;
	struct sock___78 *sk;
	int (*okfn)(struct sock___78 *, struct sk_buff___91 *);
};

struct nf_afinfo___104 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___91 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___91 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___103 *, struct dst_entry___79 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___91 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___91 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___223 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___223 *);
	void (*irq_shutdown)(struct irq_data___223 *);
	void (*irq_enable)(struct irq_data___223 *);
	void (*irq_disable)(struct irq_data___223 *);
	void (*irq_ack)(struct irq_data___223 *);
	void (*irq_mask)(struct irq_data___223 *);
	void (*irq_mask_ack)(struct irq_data___223 *);
	void (*irq_unmask)(struct irq_data___223 *);
	void (*irq_eoi)(struct irq_data___223 *);
	int (*irq_set_affinity)(struct irq_data___223 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___223 *);
	int (*irq_set_type)(struct irq_data___223 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___223 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___223 *);
	void (*irq_bus_sync_unlock)(struct irq_data___223 *);
	void (*irq_cpu_online)(struct irq_data___223 *);
	void (*irq_cpu_offline)(struct irq_data___223 *);
	void (*irq_suspend)(struct irq_data___223 *);
	void (*irq_resume)(struct irq_data___223 *);
	void (*irq_pm_shutdown)(struct irq_data___223 *);
	void (*irq_print_chip)(struct irq_data___223 *, struct seq_file___224 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___223 *, void *);
	long unsigned int flags;
};

struct seq_operations___224 {
	void * (*start)(struct seq_file___224 *, loff_t *);
	void (*stop)(struct seq_file___224 *, void *);
	void * (*next)(struct seq_file___224 *, void *, loff_t *);
	int (*show)(struct seq_file___224 *, void *);
};

struct seq_net_private___18 {
	struct net___103 *net;
};

struct pernet_operations___35 {
	struct list_head list;
	int (*init)(struct net___103 *);
	void (*exit)(struct net___103 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___89 {
	int (*ieee_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___89 *);
	u8 (*setstate)(struct net_device___89 *, u8);
	void (*getpermhwaddr)(struct net_device___89 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___89 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___89 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___89 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___89 *, int, u8 *);
	void (*setpfccfg)(struct net_device___89 *, int, u8);
	void (*getpfccfg)(struct net_device___89 *, int, u8 *);
	u8 (*setall)(struct net_device___89 *);
	u8 (*getcap)(struct net_device___89 *, int, u8 *);
	int (*getnumtcs)(struct net_device___89 *, int, u8 *);
	int (*setnumtcs)(struct net_device___89 *, int, u8);
	u8 (*getpfcstate)(struct net_device___89 *);
	void (*setpfcstate)(struct net_device___89 *, u8);
	void (*getbcncfg)(struct net_device___89 *, int, u32 *);
	void (*setbcncfg)(struct net_device___89 *, int, u32);
	void (*getbcnrp)(struct net_device___89 *, int, u8 *);
	void (*setbcnrp)(struct net_device___89 *, int, u8);
	u8 (*setapp)(struct net_device___89 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___89 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___89 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___89 *, int, u8);
	u8 (*getdcbx)(struct net_device___89 *);
	u8 (*setdcbx)(struct net_device___89 *, u8);
	int (*peer_getappinfo)(struct net_device___89 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___89 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___89 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___89 *, struct cee_pfc *);
};

struct cgroupfs_root___194;

struct cgroup___194 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___194 *parent;
	struct dentry___299 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___194 *subsys[11];
	struct cgroupfs_root___194 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___301 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___194 {
	struct super_block___299 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___194 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___130 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___299 *, struct file___299 *);
	ssize_t (*read)(struct cgroup___194 *, struct cftype___130 *, struct file___299 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___194 *, struct cftype___130 *);
	s64 (*read_s64)(struct cgroup___194 *, struct cftype___130 *);
	int (*read_map)(struct cgroup___194 *, struct cftype___130 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___194 *, struct cftype___130 *, struct seq_file___224 *);
	ssize_t (*write)(struct cgroup___194 *, struct cftype___130 *, struct file___299 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___194 *, struct cftype___130 *, u64);
	int (*write_s64)(struct cgroup___194 *, struct cftype___130 *, s64);
	int (*write_string)(struct cgroup___194 *, struct cftype___130 *, const char *);
	int (*trigger)(struct cgroup___194 *, unsigned int);
	int (*release)(struct inode___299 *, struct file___299 *);
	int (*register_event)(struct cgroup___194 *, struct cftype___130 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___194 *, struct cftype___130 *, struct eventfd_ctx *);
};

struct cftype_set___126 {
	struct list_head node;
	struct cftype___130 *cfts;
};

struct task_and_cgroup___126 {
	struct task_struct___300 *task;
	struct cgroup___194 *cgrp;
	struct css_set___194 *cg;
};

struct cgroup_taskset___126 {
	struct task_and_cgroup___126 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___194 *cur_cgrp;
};

struct cgroup_subsys___126 {
	struct cgroup_subsys_state___194 * (*css_alloc)(struct cgroup___194 *);
	int (*css_online)(struct cgroup___194 *);
	void (*css_offline)(struct cgroup___194 *);
	void (*css_free)(struct cgroup___194 *);
	int (*can_attach)(struct cgroup___194 *, struct cgroup_taskset___126 *);
	void (*cancel_attach)(struct cgroup___194 *, struct cgroup_taskset___126 *);
	void (*attach)(struct cgroup___194 *, struct cgroup_taskset___126 *);
	void (*fork)(struct task_struct___300 *);
	void (*exit)(struct cgroup___194 *, struct cgroup___194 *, struct task_struct___300 *);
	void (*bind)(struct cgroup___194 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___194 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___130 *base_cftypes;
	struct cftype_set___126 base_cftset;
	struct module *module;
};

struct request_sock_ops___62;

struct request_sock___63 {
	struct sock_common___78 __req_common;
	struct request_sock___63 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___62 *rsk_ops;
	struct sock___78 *sk;
	u32 secid;
	u32 peer_secid;
};

struct netlink_skb_parms___14 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___78 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___91 {
	struct sk_buff___91 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___91 *, struct netlink_callback___91 *);
	int (*done)(struct netlink_callback___91 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___89 {
	int (*create)(struct sk_buff___91 *, struct net_device___89 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___91 *, unsigned char *);
	int (*rebuild)(struct sk_buff___91 *);
	int (*cache)(const struct neighbour___79 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___89 *, const unsigned char *);
};

struct napi_struct___89 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___89 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___89 *dev;
	struct sk_buff___91 *gro_list;
	struct sk_buff___91 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___89 {
	struct net_device___89 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___81 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___89 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___81 kobj;
	struct net_device___89 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___89 {
	int (*ndo_init)(struct net_device___89 *);
	void (*ndo_uninit)(struct net_device___89 *);
	int (*ndo_open)(struct net_device___89 *);
	int (*ndo_stop)(struct net_device___89 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___91 *, struct net_device___89 *);
	u16 (*ndo_select_queue)(struct net_device___89 *, struct sk_buff___91 *);
	void (*ndo_change_rx_flags)(struct net_device___89 *, int);
	void (*ndo_set_rx_mode)(struct net_device___89 *);
	int (*ndo_set_mac_address)(struct net_device___89 *, void *);
	int (*ndo_validate_addr)(struct net_device___89 *);
	int (*ndo_do_ioctl)(struct net_device___89 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___89 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___89 *, int);
	int (*ndo_neigh_setup)(struct net_device___89 *, struct neigh_parms___79 *);
	void (*ndo_tx_timeout)(struct net_device___89 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___89 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___89 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___89 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___89 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___89 *);
	int (*ndo_netpoll_setup)(struct net_device___89 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___89 *);
	int (*ndo_busy_poll)(struct napi_struct___89 *);
	int (*ndo_set_vf_mac)(struct net_device___89 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___89 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___89 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___89 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___89 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___89 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___89 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___89 *, int, struct sk_buff___91 *);
	int (*ndo_setup_tc)(struct net_device___89 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___89 *);
	int (*ndo_fcoe_disable)(struct net_device___89 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___89 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___89 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___89 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___89 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___89 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___89 *, const struct sk_buff___91 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___89 *, struct net_device___89 *);
	int (*ndo_del_slave)(struct net_device___89 *, struct net_device___89 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___79 *);
	void (*ndo_neigh_destroy)(struct neighbour___79 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___91 *, struct netlink_callback___91 *, struct net_device___89 *, int);
	int (*ndo_bridge_setlink)(struct net_device___89 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___91 *, u32, u32, struct net_device___89 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___89 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___89 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___89 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___89 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___89 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___89 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___91 *, struct net_device___89 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___89 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___89 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___89 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___79 {
	struct net___103 *net;
	struct net_device___89 *dev;
	struct neigh_parms___79 *next;
	int (*neigh_setup)(struct neighbour___79 *);
	void (*neigh_cleanup)(struct neighbour___79 *);
	struct neigh_table___79 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct in_ifaddr___16;

struct in_device___16 {
	struct net_device___89 *dev;
	atomic_t refcnt;
	int dead;
	struct in_ifaddr___16 *ifa_list;
	struct ip_mc_list *mc_list;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___79 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___53;

struct ifacaddr6___53;

struct inet6_dev___53 {
	struct net_device___89 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___53 *mc_list;
	struct ifmcaddr6___53 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___53 *ac_list;
	rwlock_t lock;
	atomic_t refcnt;
	__u32 if_flags;
	int dead;
	u8 rndid[8];
	struct timer_list regen_timer;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___79 *nd_parms;
	struct inet6_dev___53 *next;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	__u8 addr_gen_mode;
};

struct rtnl_link_ops___80 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___89 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___103 *, struct net_device___89 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___89 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___89 *, struct list_head *);
	size_t (*get_size)(const struct net_device___89 *);
	int (*fill_info)(struct sk_buff___91 *, const struct net_device___89 *);
	size_t (*get_xstats_size)(const struct net_device___89 *);
	int (*fill_xstats)(struct sk_buff___91 *, const struct net_device___89 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___103 * (*get_link_net)(const struct net_device___89 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___89 *, struct net_device___89 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___89 *, const struct net_device___89 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___91 *, const struct net_device___89 *, const struct net_device___89 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct in_ifaddr___16 {
	struct hlist_node hash;
	struct in_ifaddr___16 *ifa_next;
	struct in_device___16 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct sk_filter___79 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___91 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

typedef int (*rtnl_doit_func___10)(struct sk_buff___91 *, struct nlmsghdr *);

typedef int (*rtnl_dumpit_func___10)(struct sk_buff___91 *, struct netlink_callback___91 *);

typedef u16 (*rtnl_calcit_func___10)(struct sk_buff___91 *, struct nlmsghdr *);

struct pneigh_entry___79;

struct neigh_hash_table___79;

struct neigh_table___79 {
	struct neigh_table___79 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___89 *, __u32 *);
	int (*constructor)(struct neighbour___79 *);
	int (*pconstructor)(struct pneigh_entry___79 *);
	void (*pdestructor)(struct pneigh_entry___79 *);
	void (*proxy_redo)(struct sk_buff___91 *);
	char *id;
	struct neigh_parms___79 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___90 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___79 *nht;
	struct pneigh_entry___79 **phash_buckets;
};

struct neigh_ops___79 {
	int family;
	void (*solicit)(struct neighbour___79 *, struct sk_buff___91 *);
	void (*error_report)(struct neighbour___79 *, struct sk_buff___91 *);
	int (*output)(struct neighbour___79 *, struct sk_buff___91 *);
	int (*connected_output)(struct neighbour___79 *, struct sk_buff___91 *);
};

struct pneigh_entry___79 {
	struct pneigh_entry___79 *next;
	struct net___103 *net;
	struct net_device___89 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___79 {
	struct neighbour___79 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct rtable___47 {
	struct dst_entry___79 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_pmtu;
	struct list_head rt_uncached;
};

struct timewait_sock_ops___59;

struct proto___78 {
	void (*close)(struct sock___78 *, long int);
	int (*connect)(struct sock___78 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___78 *, int);
	struct sock___78 * (*accept)(struct sock___78 *, int, int *);
	int (*ioctl)(struct sock___78 *, int, long unsigned int);
	int (*init)(struct sock___78 *);
	void (*destroy)(struct sock___78 *);
	void (*shutdown)(struct sock___78 *, int);
	int (*setsockopt)(struct sock___78 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___78 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___78 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___78 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___78 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___86 *, struct sock___78 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___86 *, struct sock___78 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___78 *, struct page___298 *, int, size_t, int);
	int (*bind)(struct sock___78 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___78 *, struct sk_buff___91 *);
	void (*release_cb)(struct sock___78 *);
	void (*mtu_reduced)(struct sock___78 *);
	void (*hash)(struct sock___78 *);
	void (*unhash)(struct sock___78 *);
	void (*rehash)(struct sock___78 *);
	int (*get_port)(struct sock___78 *, short unsigned int);
	void (*clear_sk)(struct sock___78 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___78 *);
	void (*enter_memory_pressure)(struct sock___78 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___282 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___62 *rsk_prot;
	struct timewait_sock_ops___59 *twsk_prot;
	union {
		struct inet_hashinfo___22 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___126 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___78 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___78 {
	void (*enter_memory_pressure)(struct sock___78 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___62 {
	int family;
	int obj_size;
	struct kmem_cache___282 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___78 *, struct request_sock___63 *);
	void (*send_ack)(struct sock___78 *, struct sk_buff___91 *, struct request_sock___63 *);
	void (*send_reset)(struct sock___78 *, struct sk_buff___91 *);
	void (*destructor)(struct request_sock___63 *);
	void (*syn_ack_timeout)(struct sock___78 *, struct request_sock___63 *);
};

struct timewait_sock_ops___59 {
	struct kmem_cache___282 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___78 *, struct sock___78 *, void *);
	void (*twsk_destructor)(struct sock___78 *);
};

struct inet_cork___32 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___79 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
};

struct inet_cork_full___32 {
	struct inet_cork___32 base;
	struct flowi fl;
};

struct ipv6_pinfo___31;

struct inet_sock___32 {
	struct sock___78 sk;
	struct ipv6_pinfo___31 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___32 cork;
};

struct ipv6_fl_socklist___30;

struct ipv6_pinfo___31 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 pmtudisc: 3;
	__u16 ipv6only: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__u8 rcv_tclass;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___30 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___91 *pktoptions;
	struct sk_buff___91 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___30;

struct ipv6_fl_socklist___30 {
	struct ipv6_fl_socklist___30 *next;
	struct ip6_flowlabel___30 *fl;
	struct callback_head rcu;
};

struct raw6_sock___2 {
	struct inet_sock___32 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___31 inet6;
};

struct inet6_protocol___5 {
	void (*early_demux)(struct sk_buff___91 *);
	int (*handler)(struct sk_buff___91 *);
	void (*err_handler)(struct sk_buff___91 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct fib_rule___7 {
	struct list_head list;
	atomic_t refcnt;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 pref;
	u32 flags;
	u32 table;
	u8 action;
	u32 target;
	struct fib_rule___7 *ctarget;
	char iifname[16];
	char oifname[16];
	struct callback_head rcu;
	struct net___103 *fr_net;
};

struct fib_lookup_arg___7 {
	void *lookup_ptr;
	void *result;
	struct fib_rule___7 *rule;
	int flags;
};

struct ifmcaddr6___53 {
	struct in6_addr mca_addr;
	struct inet6_dev___53 *idev;
	struct ifmcaddr6___53 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	atomic_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___53 {
	struct in6_addr aca_addr;
	struct inet6_dev___53 *aca_idev;
	struct rt6_info___27 *aca_rt;
	struct ifacaddr6___53 *aca_next;
	int aca_users;
	atomic_t aca_refcnt;
	spinlock_t aca_lock;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_flowlabel___30 {
	struct ip6_flowlabel___30 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___98 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___103 *fl_net;
};

typedef short unsigned int mifi_t;

typedef __u32 if_mask;

struct if_set {
	if_mask ifs_bits[8];
};

struct mif6ctl {
	mifi_t mif6c_mifi;
	unsigned char mif6c_flags;
	unsigned char vifc_threshold;
	__u16 mif6c_pifi;
	unsigned int vifc_rate_limit;
};

struct mf6cctl {
	struct sockaddr_in6 mf6cc_origin;
	struct sockaddr_in6 mf6cc_mcastgrp;
	mifi_t mf6cc_parent;
	struct if_set mf6cc_ifset;
};

struct sioc_sg_req6 {
	struct sockaddr_in6 src;
	struct sockaddr_in6 grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_mif_req6 {
	mifi_t mifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct mrt6msg {
	__u8 im6_mbz;
	__u8 im6_msgtype;
	__u16 im6_mif;
	__u32 im6_pad;
	struct in6_addr im6_src;
	struct in6_addr im6_dst;
};

struct mif_device {
	struct net_device___89 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
};

struct mfc6_cache {
	struct list_head list;
	struct in6_addr mf6c_mcastgrp;
	struct in6_addr mf6c_origin;
	mifi_t mf6c_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___90 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			unsigned char ttls[32];
		} res;
	} mfc_un;
};

struct nf_ipv6_ops___11 {
	int (*chk_addr)(struct net___103 *, const struct in6_addr *, const struct net_device___89 *, int);
};

struct mr6_table {
	struct list_head list;
	struct net___103 *net;
	u32 id;
	struct sock___78 *mroute6_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc6_unres_queue;
	struct list_head mfc6_cache_array[64];
	struct mif_device vif6_table[32];
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	int mroute_reg_vif_num;
};

struct ip6mr_result {
	struct mr6_table *mrt;
};

struct ipmr_mfc_iter___2 {
	struct seq_net_private___18 p;
	struct mr6_table *mrt;
	struct list_head *cache;
	int ct;
};

struct ipmr_vif_iter___2 {
	struct seq_net_private___18 p;
	struct mr6_table *mrt;
	int ct;
};

struct compat_sioc_sg_req6 {
	struct sockaddr_in6 src;
	struct sockaddr_in6 grp;
	compat_ulong_t pktcnt;
	compat_ulong_t bytecnt;
	compat_ulong_t wrong_if;
};

struct compat_sioc_mif_req6 {
	mifi_t mifi;
	compat_ulong_t icount;
	compat_ulong_t ocount;
	compat_ulong_t ibytes;
	compat_ulong_t obytes;
};

struct ip6_mh {
	__u8 ip6mh_proto;
	__u8 ip6mh_hdrlen;
	__u8 ip6mh_type;
	__u8 ip6mh_reserved;
	__u16 ip6mh_cksum;
	__u8 data[0];
};

struct nf_ipv6_ops___12 {
	int (*chk_addr)(struct net___92 *, const struct in6_addr *, const struct net_device___78 *, int);
};

struct nf_ipv6_ops___13 {
	int (*chk_addr)(struct net___81 *, const struct in6_addr *, const struct net_device___67 *, int);
};

struct skb_frag_struct___26 {
	struct {
		struct page___287 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___26 skb_frag_t___26;

struct skb_shared_info___26 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___80 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___26 frags[17];
};

struct inet6_protocol___6 {
	void (*early_demux)(struct sk_buff___80 *);
	int (*handler)(struct sk_buff___80 *);
	void (*err_handler)(struct sk_buff___80 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct xfrm6_protocol {
	int (*handler)(struct sk_buff___80 *);
	int (*cb_handler)(struct sk_buff___80 *, int);
	int (*err_handler)(struct sk_buff___80 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	struct xfrm6_protocol *next;
	int priority;
};

typedef unsigned int nf_hookfn___6(const struct nf_hook_ops___5 *, struct sk_buff___80 *, const struct net_device___78 *, const struct net_device___78 *, const struct nf_hook_state___13 *);

struct ip6_rt_info {
	struct in6_addr daddr;
	struct in6_addr saddr;
	u_int32_t mark;
};

typedef struct rt6_info___15 * (*pol_lookup_t___2)(struct net___85 *, struct fib6_table___15 *, struct flowi6 *, int);

struct fib6_rule {
	struct fib_rule___5 common;
	struct rt6key src;
	struct rt6key dst;
	u8 tclass;
};

struct pernet_operations___36 {
	struct list_head list;
	int (*init)(struct net___80 *);
	void (*exit)(struct net___80 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct ipv6_stub___2 {
	int (*ipv6_sock_mc_join)(struct sock___67 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___67 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct sock___67 *, struct dst_entry___68 **, struct flowi6 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___78 *, struct neighbour___68 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___68 *nd_tbl;
};

enum {
	IP6_FH_F_FRAG = 1,
	IP6_FH_F_AUTH = 2,
	IP6_FH_F_SKIP_RH = 4,
};

typedef void ip6_icmp_send_t___2(struct sk_buff___80 *, u8, u8, __u32);

struct inet6_protocol___7 {
	void (*early_demux)(struct sk_buff___75 *);
	int (*handler)(struct sk_buff___75 *);
	void (*err_handler)(struct sk_buff___75 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct napi_gro_cb___6 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 udp_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 is_ipv6: 1;
	u8 free: 2;
	u8 same_flow: 1;
	__wsum csum;
	struct sk_buff___75 *last;
};

struct offload_callbacks___7 {
	struct sk_buff___75 * (*gso_segment)(struct sk_buff___75 *, netdev_features_t);
	struct sk_buff___75 ** (*gro_receive)(struct sk_buff___75 **, struct sk_buff___75 *);
	int (*gro_complete)(struct sk_buff___75 *, int);
};

struct packet_offload___5 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___7 callbacks;
	struct list_head list;
};

struct net_offload___5 {
	struct offload_callbacks___7 callbacks;
	unsigned int flags;
};

struct inet_timewait_death_row___9 {
	int twcal_hand;
	long unsigned int twcal_jiffie;
	struct timer_list twcal_timer;
	struct hlist_head twcal_row[32];
	spinlock_t death_lock;
	int tw_count;
	int period;
	u32 thread_slots;
	struct work_struct twkill_work;
	struct timer_list tw_timer;
	int slot;
	struct hlist_head cells[8];
	struct inet_hashinfo___10 *hashinfo;
	int sysctl_tw_recycle;
	int sysctl_max_tw_buckets;
};

struct exec_domain___81 {
	const char *name;
	handler_t handler;
	unsigned char pers_low;
	unsigned char pers_high;
	long unsigned int *signal_map;
	long unsigned int *signal_invmap;
	struct map_segment *err_map;
	struct map_segment *socktype_map;
	struct map_segment *sockopt_map;
	struct map_segment *af_map;
	struct module___165 *module;
	struct exec_domain___81 *next;
};

struct thread_info___131 {
	struct task_struct___268 *task;
	struct exec_domain___81 *exec_domain;
	__u32 flags;
	__u32 status;
	__u32 cpu;
	int preempt_count;
	mm_segment_t addr_limit;
	struct restart_block restart_block;
	void *sysenter_return;
	unsigned int sig_on_uaccess_error: 1;
	unsigned int uaccess_err: 1;
};

struct net_proto_family___7 {
	int family;
	int (*create)(struct net___71 *, struct socket___47 *, int, int);
	struct module___165 *owner;
};

struct sockaddr_pkt {
	short unsigned int spkt_family;
	unsigned char spkt_device[14];
	__be16 spkt_protocol;
};

struct sockaddr_ll {
	short unsigned int sll_family;
	__be16 sll_protocol;
	int sll_ifindex;
	short unsigned int sll_hatype;
	unsigned char sll_pkttype;
	unsigned char sll_halen;
	unsigned char sll_addr[8];
};

struct tpacket_stats {
	unsigned int tp_packets;
	unsigned int tp_drops;
};

struct tpacket_stats_v3 {
	unsigned int tp_packets;
	unsigned int tp_drops;
	unsigned int tp_freeze_q_cnt;
};

union tpacket_stats_u {
	struct tpacket_stats stats1;
	struct tpacket_stats_v3 stats3;
};

struct tpacket_auxdata {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u16 tp_vlan_tci;
	__u16 tp_padding;
};

struct tpacket_hdr {
	long unsigned int tp_status;
	unsigned int tp_len;
	unsigned int tp_snaplen;
	short unsigned int tp_mac;
	short unsigned int tp_net;
	unsigned int tp_sec;
	unsigned int tp_usec;
};

struct tpacket2_hdr {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u16 tp_vlan_tci;
	__u16 tp_padding;
};

struct tpacket_hdr_variant1 {
	__u32 tp_rxhash;
	__u32 tp_vlan_tci;
};

struct tpacket3_hdr {
	__u32 tp_next_offset;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u32 tp_snaplen;
	__u32 tp_len;
	__u32 tp_status;
	__u16 tp_mac;
	__u16 tp_net;
	union {
		struct tpacket_hdr_variant1 hv1;
	};
};

struct tpacket_bd_ts {
	unsigned int ts_sec;
	union {
		unsigned int ts_usec;
		unsigned int ts_nsec;
	};
};

struct tpacket_hdr_v1 {
	__u32 block_status;
	__u32 num_pkts;
	__u32 offset_to_first_pkt;
	__u32 blk_len;
	__u64 seq_num;
	struct tpacket_bd_ts ts_first_pkt;
	struct tpacket_bd_ts ts_last_pkt;
};

union tpacket_bd_header_u {
	struct tpacket_hdr_v1 bh1;
};

struct tpacket_block_desc {
	__u32 version;
	__u32 offset_to_priv;
	union tpacket_bd_header_u hdr;
};

enum tpacket_versions {
	TPACKET_V1 = 0,
	TPACKET_V2 = 1,
	TPACKET_V3 = 2,
};

struct tpacket_req {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
};

struct tpacket_req3 {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
	unsigned int tp_retire_blk_tov;
	unsigned int tp_sizeof_priv;
	unsigned int tp_feature_req_word;
};

union tpacket_req_u {
	struct tpacket_req req;
	struct tpacket_req3 req3;
};

typedef struct poll_table_struct___153 poll_table___44;

typedef __u16 __virtio16;

struct virtio_net_hdr {
	__u8 flags;
	__u8 gso_type;
	__virtio16 hdr_len;
	__virtio16 gso_size;
	__virtio16 csum_start;
	__virtio16 csum_offset;
};

struct packet_mclist {
	struct packet_mclist *next;
	int ifindex;
	int count;
	short unsigned int type;
	short unsigned int alen;
	unsigned char addr[32];
};

struct pgv;

struct tpacket_kbdq_core {
	struct pgv *pkbdq;
	unsigned int feature_req_word;
	unsigned int hdrlen;
	unsigned char reset_pending_on_curr_blk;
	unsigned char delete_blk_timer;
	short unsigned int kactive_blk_num;
	short unsigned int blk_sizeof_priv;
	short unsigned int last_kactive_blk_num;
	char *pkblk_start;
	char *pkblk_end;
	int kblk_size;
	unsigned int max_frame_len;
	unsigned int knum_blocks;
	uint64_t knxt_seq_num;
	char *prev;
	char *nxt_offset;
	struct sk_buff___60 *skb;
	atomic_t blk_fill_in_prog;
	short unsigned int retire_blk_tov;
	short unsigned int version;
	long unsigned int tov_in_jiffies;
	struct timer_list retire_blk_timer;
};

struct pgv {
	char *buffer;
};

struct packet_ring_buffer {
	struct pgv *pg_vec;
	unsigned int head;
	unsigned int frames_per_block;
	unsigned int frame_size;
	unsigned int frame_max;
	unsigned int pg_vec_order;
	unsigned int pg_vec_pages;
	unsigned int pg_vec_len;
	unsigned int *pending_refcnt;
	struct tpacket_kbdq_core prb_bdqc;
};

struct packet_fanout {
	struct net___71 *net;
	unsigned int num_members;
	u16 id;
	u8 type;
	u8 flags;
	atomic_t rr_cur;
	struct list_head list;
	struct sock___47 *arr[256];
	int next[256];
	spinlock_t lock;
	atomic_t sk_ref;
	long: 64;
	long: 64;
	struct packet_type___4 prot_hook;
	long: 64;
};

struct packet_sock {
	struct sock___47 sk;
	struct packet_fanout *fanout;
	union tpacket_stats_u stats;
	struct packet_ring_buffer rx_ring;
	struct packet_ring_buffer tx_ring;
	int copy_thresh;
	spinlock_t bind_lock;
	struct mutex___269 pg_vec_lock;
	unsigned int running: 1;
	unsigned int auxdata: 1;
	unsigned int origdev: 1;
	unsigned int has_vnet_hdr: 1;
	int ifindex;
	__be16 num;
	struct packet_mclist *mclist;
	atomic_t mapped;
	enum tpacket_versions tp_version;
	unsigned int tp_hdrlen;
	unsigned int tp_reserve;
	unsigned int tp_loss: 1;
	unsigned int tp_tx_has_off: 1;
	unsigned int tp_tstamp;
	struct net_device___57 *cached_dev;
	long: 64;
	long: 64;
	struct packet_type___4 prot_hook;
	long: 64;
};

struct packet_mreq_max {
	int mr_ifindex;
	short unsigned int mr_type;
	short unsigned int mr_alen;
	unsigned char mr_address[32];
};

union tpacket_uhdr {
	struct tpacket_hdr *h1;
	struct tpacket2_hdr *h2;
	struct tpacket3_hdr *h3;
	void *raw;
};

struct packet_skb_cb {
	unsigned int origlen;
	union {
		struct sockaddr_pkt pkt;
		struct sockaddr_ll ll;
	} sa;
};

struct page___299;

typedef struct page___299 *pgtable_t___299;

struct address_space___300;

struct kmem_cache___283;

struct page___299 {
	long unsigned int flags;
	struct address_space___300 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___299 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___299 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___283 *slab_cache;
		struct page___299 *first_page;
	};
	long: 64;
};

struct task_struct___301;

struct pv_cpu_ops___301 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___301 *);
	void (*end_context_switch)(struct task_struct___301 *);
};

struct mutex___302 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___301 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___294 {
	struct page___299 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___308;

struct nsproxy___180;

struct signal_struct___301;

struct css_set___195;

struct task_struct___301 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___301 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___308 *mm;
	struct mm_struct___308 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___301 *real_parent;
	struct task_struct___301 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___301 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___98 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___301 = 0,
		VTIME_USER___301 = 1,
		VTIME_SYS___301 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___180 *nsproxy;
	struct signal_struct___301 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___195 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___302 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___294 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___308 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___308 *, struct mm_struct___308 *);
	void (*dup_mmap)(struct mm_struct___308 *, struct mm_struct___308 *);
	void (*exit_mmap)(struct mm_struct___308 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___308 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___308 *);
	void (*pgd_free)(struct mm_struct___308 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___308 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___308 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___308 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___308 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___308 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___308 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___308 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___308 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___308 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___308 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___308 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___302 lock;
	void *vdso;
} mm_context_t___302;

struct xol_area___299;

struct uprobes_state___299 {
	struct xol_area___299 *xol_area;
};

struct vm_area_struct___308;

struct file___300;

struct core_state___301;

struct mm_struct___308 {
	struct vm_area_struct___308 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___308 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___308 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___302 context;
	long unsigned int flags;
	struct core_state___301 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___301 *owner;
	struct file___300 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___299 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___299 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___299 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___282;

struct memcg_cache_params___283;

struct kmem_cache___283 {
	struct kmem_cache_cpu___282 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___81 kobj;
	struct memcg_cache_params___283 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___300;

struct address_space_operations___300;

struct address_space___300 {
	struct inode___300 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___302 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___300 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___300;

struct path___300 {
	struct vfsmount *mnt;
	struct dentry___300 *dentry;
};

struct file_operations___300;

struct file___300 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___300 f_path;
	struct inode___300 *f_inode;
	const struct file_operations___300 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___300 *f_mapping;
	struct mutex___302 f_pos_lock;
};

struct vm_operations_struct___274;

struct vm_area_struct___308 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___308 *vm_next;
	struct vm_area_struct___308 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___308 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___274 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___300 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___270;

struct vm_operations_struct___274 {
	void (*open)(struct vm_area_struct___308 *);
	void (*close)(struct vm_area_struct___308 *);
	int (*fault)(struct vm_area_struct___308 *, struct vm_fault___270 *);
	int (*page_mkwrite)(struct vm_area_struct___308 *, struct vm_fault___270 *);
	int (*access)(struct vm_area_struct___308 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___308 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___308 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___308 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___308 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___301 {
	struct task_struct___301 *task;
	struct core_thread___301 *next;
};

struct core_state___301 {
	atomic_t nr_threads;
	struct core_thread___301 dumper;
	struct completion startup;
};

struct fasync_struct___300 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___300 *fa_next;
	struct file___300 *fa_file;
	struct callback_head fa_rcu;
};

struct ctl_table_root___105;

struct ctl_table_set___105;

struct ctl_dir___105;

struct ctl_node___105;

struct ctl_table_header___105 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___105 *root;
	struct ctl_table_set___105 *set;
	struct ctl_dir___105 *parent;
	struct ctl_node___105 *node;
};

struct ctl_dir___105 {
	struct ctl_table_header___105 header;
	struct rb_root root;
};

struct ctl_table_set___105 {
	int (*is_seen)(struct ctl_table_set___105 *);
	struct ctl_dir___105 dir;
};

struct netns_core___102 {
	struct ctl_table_header___105 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___103 {
	struct mutex___302 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___102 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___105 *ctl;
};

struct netns_ipv4___102 {
	struct ctl_table_header___105 *forw_hdr;
	struct ctl_table_header___105 *frags_hdr;
	struct ctl_table_header___105 *ipv4_hdr;
	struct ctl_table_header___105 *route_hdr;
	struct ctl_table_header___105 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___102 {
	struct ctl_table_header___105 *hdr;
	struct ctl_table_header___105 *route_hdr;
	struct ctl_table_header___105 *icmp_hdr;
	struct ctl_table_header___105 *frags_hdr;
	struct ctl_table_header___105 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___90;

struct sk_buff___92;

struct dst_ops___104 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___104 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___90 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___92 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___92 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___92 *);
	int (*local_out)(struct sk_buff___92 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___92 *, const void *);
	struct kmem_cache___283 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___104 {
	struct netns_sysctl_ipv6___102 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___104 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___102 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___105 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___102 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___105 *nf_log_dir_header;
};

struct nf_proto_net___102 {
	struct ctl_table_header___105 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___102 {
	struct nf_proto_net___102 pn;
	unsigned int timeout;
};

struct nf_tcp_net___102 {
	struct nf_proto_net___102 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___102 {
	struct nf_proto_net___102 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___102 {
	struct nf_proto_net___102 pn;
	unsigned int timeout;
};

struct nf_ip_net___102 {
	struct nf_generic_net___102 generic;
	struct nf_tcp_net___102 tcp;
	struct nf_udp_net___102 udp;
	struct nf_icmp_net___102 icmp;
	struct nf_icmp_net___102 icmpv6;
};

struct netns_ct___103 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___105 *sysctl_header;
	struct ctl_table_header___105 *acct_sysctl_header;
	struct ctl_table_header___105 *tstamp_sysctl_header;
	struct ctl_table_header___105 *event_sysctl_header;
	struct ctl_table_header___105 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___283 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___102 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___102 {
	struct netns_sysctl_ipv6___102 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___91 {
	struct sk_buff___92 *next;
	struct sk_buff___92 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___104 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___105 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___104 xfrm4_dst_ops;
	struct dst_ops___104 xfrm6_dst_ops;
};

struct net___104 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___105 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___90 *loopback_dev;
	struct netns_core___102 core;
	struct netns_mib mib;
	struct netns_packet___103 packet;
	struct netns_unix___102 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___102 ipv4;
	struct netns_ipv6___104 ipv6;
	struct netns_sctp___102 sctp;
	struct netns_dccp___78 dccp;
	struct netns_nf___102 nf;
	struct netns_xt xt;
	struct netns_ct___103 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___102 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___91 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___104 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___302 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___302 flow_flush_sem;
	long: 64;
	long: 64;
};

struct zone___301;

struct lruvec___301 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___301 *zone;
};

struct pglist_data___301;

struct zone___301 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___301 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___301 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___301 {
	struct zone___301 *zone;
	int zone_idx;
};

struct zonelist___301 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___301 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___301 {
	struct zone___301 node_zones[4];
	struct zonelist___301 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___301 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___224;

struct x86_io_apic_ops___224 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___224 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___224;

struct irq_data___224 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___224 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___298;

struct dev_pm_ops___298 {
	int (*prepare)(struct device___298 *);
	void (*complete)(struct device___298 *);
	int (*suspend)(struct device___298 *);
	int (*resume)(struct device___298 *);
	int (*freeze)(struct device___298 *);
	int (*thaw)(struct device___298 *);
	int (*poweroff)(struct device___298 *);
	int (*restore)(struct device___298 *);
	int (*suspend_late)(struct device___298 *);
	int (*resume_early)(struct device___298 *);
	int (*freeze_late)(struct device___298 *);
	int (*thaw_early)(struct device___298 *);
	int (*poweroff_late)(struct device___298 *);
	int (*restore_early)(struct device___298 *);
	int (*suspend_noirq)(struct device___298 *);
	int (*resume_noirq)(struct device___298 *);
	int (*freeze_noirq)(struct device___298 *);
	int (*thaw_noirq)(struct device___298 *);
	int (*poweroff_noirq)(struct device___298 *);
	int (*restore_noirq)(struct device___298 *);
	int (*runtime_suspend)(struct device___298 *);
	int (*runtime_resume)(struct device___298 *);
	int (*runtime_idle)(struct device___298 *);
};

struct dev_pm_qos___101;

struct dev_pm_info___101 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___101 *qos;
};

struct dma_map_ops___163;

struct dev_archdata___163 {
	struct dma_map_ops___163 *dma_ops;
	void *iommu;
};

struct device_type___298;

struct bus_type___298;

struct device_driver___298;

struct dev_pm_domain___298;

struct class___298;

struct attribute_group___260;

struct device_rh___298;

struct device___298 {
	struct device___298 *parent;
	struct device_private *p;
	struct kobject___81 kobj;
	const char *init_name;
	const struct device_type___298 *type;
	struct mutex___302 mutex;
	struct bus_type___298 *bus;
	struct device_driver___298 *driver;
	void *platform_data;
	struct dev_pm_info___101 power;
	struct dev_pm_domain___298 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___163 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___16 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___298 *class;
	const struct attribute_group___260 **groups;
	void (*release)(struct device___298 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___298 *device_rh;
};

struct dev_pm_qos_request___102;

struct dev_pm_qos___101 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___102 *latency_req;
	struct dev_pm_qos_request___102 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___102 *latency_tolerance_req;
};

struct dev_pm_info_rh___298 {
	void (*set_latency_tolerance)(struct device___298 *, s32);
};

struct dev_pm_domain___298 {
	struct dev_pm_ops___298 ops;
};

struct smp_ops___301 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___301 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct bin_attribute___262;

struct attribute_group___260 {
	const char *name;
	umode_t (*is_visible)(struct kobject___81 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___262 **bin_attrs;
};

struct bin_attribute___262 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___300 *, struct kobject___81 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___300 *, struct kobject___81 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	int (*mmap)(struct file___300 *, struct kobject___81 *, struct bin_attribute___262 *, struct vm_area_struct___308 *);
};

struct kmem_cache_cpu___282 {
	void **freelist;
	long unsigned int tid;
	struct page___299 *page;
	struct page___299 *partial;
};

struct memcg_cache_params___283 {
	bool is_root_cache;
	union {
		struct kmem_cache___283 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___283 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct dma_map_ops___163 {
	void * (*alloc)(struct device___298 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___298 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___298 *, struct vm_area_struct___308 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___298 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___298 *, struct page___299 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___298 *, dma_addr_t);
	int (*dma_supported)(struct device___298 *, u64);
	int (*set_dma_mask)(struct device___298 *, u64);
	int is_phys;
};

struct bus_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___298 *, char *);
	ssize_t (*store)(struct bus_type___298 *, const char *, size_t);
};

struct device_attribute___298;

struct driver_attribute___298;

struct bus_type___298 {
	const char *name;
	const char *dev_name;
	struct device___298 *dev_root;
	struct bus_attribute___298 *bus_attrs;
	struct device_attribute___298 *dev_attrs;
	struct driver_attribute___298 *drv_attrs;
	const struct attribute_group___260 **bus_groups;
	const struct attribute_group___260 **dev_groups;
	const struct attribute_group___260 **drv_groups;
	int (*match)(struct device___298 *, struct device_driver___298 *);
	int (*uevent)(struct device___298 *, struct kobj_uevent_env *);
	int (*probe)(struct device___298 *);
	int (*remove)(struct device___298 *);
	void (*shutdown)(struct device___298 *);
	int (*online)(struct device___298 *);
	int (*offline)(struct device___298 *);
	int (*suspend)(struct device___298 *, pm_message_t);
	int (*resume)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct device___298 *, struct device_attribute___298 *, char *);
	ssize_t (*store)(struct device___298 *, struct device_attribute___298 *, const char *, size_t);
};

struct driver_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___298 *, char *);
	ssize_t (*store)(struct device_driver___298 *, const char *, size_t);
};

struct device_driver___298 {
	const char *name;
	struct bus_type___298 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___298 *);
	int (*remove)(struct device___298 *);
	void (*shutdown)(struct device___298 *);
	int (*suspend)(struct device___298 *, pm_message_t);
	int (*resume)(struct device___298 *);
	const struct attribute_group___260 **groups;
	const struct dev_pm_ops___298 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___298 {
	const char *name;
	const struct attribute_group___260 **groups;
	int (*uevent)(struct device___298 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___298 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
};

struct class_attribute___298;

struct class___298 {
	const char *name;
	struct module *owner;
	struct class_attribute___298 *class_attrs;
	struct device_attribute___298 *dev_attrs;
	const struct attribute_group___260 **dev_groups;
	struct bin_attribute___262 *dev_bin_attrs;
	struct kobject___81 *dev_kobj;
	int (*dev_uevent)(struct device___298 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___298 *, umode_t *);
	void (*class_release)(struct class___298 *);
	void (*dev_release)(struct device___298 *);
	int (*suspend)(struct device___298 *, pm_message_t);
	int (*resume)(struct device___298 *);
	const struct kobj_ns_type_operations___78 *ns_type;
	const void * (*namespace)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
	struct subsys_private *p;
};

struct class_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct class___298 *, struct class_attribute___298 *, char *);
	ssize_t (*store)(struct class___298 *, struct class_attribute___298 *, const char *, size_t);
	const void * (*namespace)(struct class___298 *, const struct class_attribute___298 *);
};

struct device_rh___298 {
	struct dev_pm_info_rh___298 power;
};

struct vm_fault___270 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___299 *page;
};

struct ctl_node___105 {
	struct rb_node node;
	struct ctl_table_header___105 *header;
};

struct ctl_table_root___105 {
	struct ctl_table_set___105 default_set;
	struct ctl_table_set___105 * (*lookup)(struct ctl_table_root___105 *, struct nsproxy___180 *);
	int (*permissions)(struct ctl_table_header___105 *, struct ctl_table *);
};

struct nsproxy___180 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___104 *net_ns;
};

struct signal_struct___301 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___301 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___301 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___98 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___302 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___195;

struct css_set___195 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___195 *subsys[11];
	struct callback_head callback_head;
};

struct nf_bridge_info___90 {
	atomic_t use;
	unsigned int mask;
	struct net_device___90 *physindev;
	struct net_device___90 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___90(struct sk_buff___92 **);

struct net_device_ops___90;

struct ethtool_ops___90;

struct header_ops___90;

struct vlan_info___2;

struct netdev_rx_queue___90;

struct netdev_queue___90;

struct netpoll_info___5;

struct dcbnl_rtnl_ops___90;

struct net_device___90 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___90 *netdev_ops;
	const struct ethtool_ops___90 *ethtool_ops;
	const struct header_ops___90 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___81 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info___2 *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___90 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___90 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___90 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___90 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___90 = 0,
		NETREG_REGISTERED___90 = 1,
		NETREG_UNREGISTERING___90 = 2,
		NETREG_UNREGISTERED___90 = 3,
		NETREG_RELEASED___90 = 4,
		NETREG_DUMMY___90 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___90 = 0,
		RTNL_LINK_INITIALIZING___90 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___90 *);
	struct netpoll_info___5 *npinfo;
	struct net___104 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___298 dev;
	const struct attribute_group___260 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___90 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___92 {
	struct sk_buff___92 *next;
	struct sk_buff___92 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___90 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___92 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___90 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct skb_frag_struct___27 {
	struct {
		struct page___299 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___27 skb_frag_t___27;

struct skb_shared_info___27 {
	unsigned char nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	short unsigned int gso_type;
	struct sk_buff___92 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	__be32 ip6_frag_id;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___27 frags[17];
};

struct file_lock___300;

struct seq_file___225;

struct file_operations___300 {
	struct module *owner;
	loff_t (*llseek)(struct file___300 *, loff_t, int);
	ssize_t (*read)(struct file___300 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___300 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___300 *, void *, filldir_t);
	unsigned int (*poll)(struct file___300 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___300 *, struct vm_area_struct___308 *);
	int (*open)(struct inode___300 *, struct file___300 *);
	int (*flush)(struct file___300 *, fl_owner_t);
	int (*release)(struct inode___300 *, struct file___300 *);
	int (*fsync)(struct file___300 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___300 *, int);
	int (*lock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*sendpage)(struct file___300 *, struct page___299 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___300 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___300 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___300 *, long int, struct file_lock___300 **, void **);
		struct {
			int (*setlease)(struct file___300 *, long int, struct file_lock___300 **);
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long int (*fallocate)(struct file___300 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___225 *, struct file___300 *);
};

struct dev_pm_qos_request___102 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___298 *dev;
};

struct dentry_operations___300;

struct super_block___300;

struct dentry___300 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___300 *d_parent;
	struct qstr d_name;
	struct inode___300 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___300 *d_op;
	struct super_block___300 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___300;

struct dquot___300;

struct block_device___300;

struct inode___300 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___300 *i_op;
	struct super_block___300 *i_sb;
	struct address_space___300 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___302 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___300 *i_fop;
	struct file_lock___300 *i_flock;
	struct address_space___300 i_data;
	struct dquot___300 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___300 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___300 {
	int (*d_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_hash)(const struct dentry___300 *, struct qstr *);
	int (*d_compare)(const struct dentry___300 *, const struct dentry___300 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___300 *);
	void (*d_release)(struct dentry___300 *);
	void (*d_prune)(struct dentry___300 *);
	void (*d_iput)(struct dentry___300 *, struct inode___300 *);
	char * (*d_dname)(struct dentry___300 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___300 *);
	int (*d_manage)(struct dentry___300 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___300;

struct mem_dqinfo___300 {
	struct quota_format_type___300 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___300;

struct quota_info___300 {
	unsigned int flags;
	struct mutex___302 dqio_mutex;
	struct mutex___302 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___300 *files[2];
	struct mem_dqinfo___300 info[2];
	const struct quota_format_ops___300 *ops[2];
};

struct file_system_type___300;

struct super_operations___300;

struct dquot_operations___300;

struct quotactl_ops___300;

struct xattr_handler___196;

struct super_block___300 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___300 *s_type;
	const struct super_operations___300 *s_op;
	const struct dquot_operations___300 *dq_op;
	const struct quotactl_ops___300 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___300 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___196 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___300 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___300 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___302 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___300 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___300 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___300 *bd_inode;
	struct super_block___300 *bd_super;
	struct mutex___302 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___300 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___302 bd_fsfreeze_mutex;
};

struct cgroup___195;

struct cgroup_subsys_state___195 {
	struct cgroup___195 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___300 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___300 *ia_file;
};

struct dquot___300 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___302 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___300 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___300 {
	int qf_fmt_id;
	const struct quota_format_ops___300 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___300 *qf_next;
};

struct quota_format_ops___300 {
	int (*check_quota_file)(struct super_block___300 *, int);
	int (*read_file_info)(struct super_block___300 *, int);
	int (*write_file_info)(struct super_block___300 *, int);
	int (*free_file_info)(struct super_block___300 *, int);
	int (*read_dqblk)(struct dquot___300 *);
	int (*commit_dqblk)(struct dquot___300 *);
	int (*release_dqblk)(struct dquot___300 *);
};

struct dquot_operations___300 {
	int (*write_dquot)(struct dquot___300 *);
	struct dquot___300 * (*alloc_dquot)(struct super_block___300 *, int);
	void (*destroy_dquot)(struct dquot___300 *);
	int (*acquire_dquot)(struct dquot___300 *);
	int (*release_dquot)(struct dquot___300 *);
	int (*mark_dirty)(struct dquot___300 *);
	int (*write_info)(struct super_block___300 *, int);
	qsize_t * (*get_reserved_space)(struct inode___300 *);
};

struct quotactl_ops___300 {
	int (*quota_on)(struct super_block___300 *, int, int, struct path___300 *);
	int (*quota_on_meta)(struct super_block___300 *, int, int);
	int (*quota_off)(struct super_block___300 *, int);
	int (*quota_sync)(struct super_block___300 *, int);
	int (*get_info)(struct super_block___300 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___300 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___300 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___300 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___300 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___300 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___300 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___300 *, unsigned int);
};

struct address_space_operations___300 {
	int (*writepage)(struct page___299 *, struct writeback_control *);
	int (*readpage)(struct file___300 *, struct page___299 *);
	int (*writepages)(struct address_space___300 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___299 *);
	int (*readpages)(struct file___300 *, struct address_space___300 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___300 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___299 **, void **);
	int (*write_end)(struct file___300 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___299 *, void *);
	sector_t (*bmap)(struct address_space___300 *, sector_t);
	void (*invalidatepage)(struct page___299 *, long unsigned int);
	int (*releasepage)(struct page___299 *, gfp_t);
	void (*freepage)(struct page___299 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___300 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___300 *, struct page___299 *, struct page___299 *, enum migrate_mode);
	int (*launder_page)(struct page___299 *);
	int (*is_partially_uptodate)(struct page___299 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___299 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___300 *, struct page___299 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___300 *, sector_t *);
	void (*swap_deactivate)(struct file___300 *);
	void (*invalidatepage_range)(struct page___299 *, unsigned int, unsigned int);
};

struct inode_operations___300 {
	struct dentry___300 * (*lookup)(struct inode___300 *, struct dentry___300 *, unsigned int);
	void * (*follow_link)(struct dentry___300 *, struct nameidata *);
	int (*permission)(struct inode___300 *, int);
	struct posix_acl * (*get_acl)(struct inode___300 *, int);
	int (*readlink)(struct dentry___300 *, char *, int);
	void (*put_link)(struct dentry___300 *, struct nameidata *, void *);
	int (*create)(struct inode___300 *, struct dentry___300 *, umode_t, bool);
	int (*link)(struct dentry___300 *, struct inode___300 *, struct dentry___300 *);
	int (*unlink)(struct inode___300 *, struct dentry___300 *);
	int (*symlink)(struct inode___300 *, struct dentry___300 *, const char *);
	int (*mkdir)(struct inode___300 *, struct dentry___300 *, umode_t);
	int (*rmdir)(struct inode___300 *, struct dentry___300 *);
	int (*mknod)(struct inode___300 *, struct dentry___300 *, umode_t, dev_t);
	int (*rename)(struct inode___300 *, struct dentry___300 *, struct inode___300 *, struct dentry___300 *);
	int (*setattr)(struct dentry___300 *, struct iattr___300 *);
	int (*getattr)(struct vfsmount *, struct dentry___300 *, struct kstat *);
	int (*setxattr)(struct dentry___300 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___300 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___300 *, char *, size_t);
	int (*removexattr)(struct dentry___300 *, const char *);
	int (*fiemap)(struct inode___300 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___300 *, struct timespec *, int);
	int (*atomic_open)(struct inode___300 *, struct dentry___300 *, struct file___300 *, unsigned int, umode_t, int *);
	long: 64;
};

struct file_lock_operations___300;

struct lock_manager_operations___300;

struct file_lock___300 {
	struct file_lock___300 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___98 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___300 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___300 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___300 *fl_ops;
	const struct lock_manager_operations___300 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___300 {
	void (*fl_copy_lock)(struct file_lock___300 *, struct file_lock___300 *);
	void (*fl_release_private)(struct file_lock___300 *);
};

struct lock_manager_operations___300 {
	int (*lm_compare_owner)(struct file_lock___300 *, struct file_lock___300 *);
	long unsigned int (*lm_owner_key)(struct file_lock___300 *);
	void (*lm_notify)(struct file_lock___300 *);
	int (*lm_grant)(struct file_lock___300 *, struct file_lock___300 *, int);
	void (*lm_break)(struct file_lock___300 *);
	int (*lm_change)(struct file_lock___300 **, int);
};

struct file_system_type___300 {
	const char *name;
	int fs_flags;
	struct dentry___300 * (*mount)(struct file_system_type___300 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___300 *);
	struct module *owner;
	struct file_system_type___300 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___300 {
	struct inode___300 * (*alloc_inode)(struct super_block___300 *);
	void (*destroy_inode)(struct inode___300 *);
	void (*dirty_inode)(struct inode___300 *, int);
	int (*write_inode)(struct inode___300 *, struct writeback_control *);
	int (*drop_inode)(struct inode___300 *);
	void (*evict_inode)(struct inode___300 *);
	void (*put_super)(struct super_block___300 *);
	int (*sync_fs)(struct super_block___300 *, int);
	int (*freeze_fs)(struct super_block___300 *);
	int (*unfreeze_fs)(struct super_block___300 *);
	int (*statfs)(struct dentry___300 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___300 *, int *, char *);
	void (*umount_begin)(struct super_block___300 *);
	int (*show_options)(struct seq_file___225 *, struct dentry___300 *);
	int (*show_devname)(struct seq_file___225 *, struct dentry___300 *);
	int (*show_path)(struct seq_file___225 *, struct dentry___300 *);
	int (*show_stats)(struct seq_file___225 *, struct dentry___300 *);
	ssize_t (*quota_read)(struct super_block___300 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___300 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___300 *);
	int (*bdev_try_to_free_page)(struct super_block___300 *, struct page___299 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___300 *);
	void (*free_cached_objects)(struct super_block___300 *, int);
};

struct xattr_handler___196 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___300 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___300 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___300 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___225;

struct seq_file___225 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___302 lock;
	const struct seq_operations___225 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct ethtool_ops___90 {
	int (*get_settings)(struct net_device___90 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___90 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___90 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___90 *);
	void (*get_regs)(struct net_device___90 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___90 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___90 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___90 *);
	void (*set_msglevel)(struct net_device___90 *, u32);
	int (*nway_reset)(struct net_device___90 *);
	u32 (*get_link)(struct net_device___90 *);
	int (*get_eeprom_len)(struct net_device___90 *);
	int (*get_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___90 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___90 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___90 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___90 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___90 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___90 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___90 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___90 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___90 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___90 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___90 *);
	void (*complete)(struct net_device___90 *);
	u32 (*get_priv_flags)(struct net_device___90 *);
	int (*set_priv_flags)(struct net_device___90 *, u32);
	int (*get_sset_count)(struct net_device___90 *, int);
	int (*get_rxnfc)(struct net_device___90 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___90 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___90 *, struct ethtool_flash *);
	int (*reset)(struct net_device___90 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___90 *);
	int (*get_rxfh_indir)(struct net_device___90 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___90 *, const u32 *);
	void (*get_channels)(struct net_device___90 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___90 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___90 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___90 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___90 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___90 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___90 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___90 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___90 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___90 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___90 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___90 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___105 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___92 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___92 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___104 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___92 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___92 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___224 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___224 *);
	void (*irq_shutdown)(struct irq_data___224 *);
	void (*irq_enable)(struct irq_data___224 *);
	void (*irq_disable)(struct irq_data___224 *);
	void (*irq_ack)(struct irq_data___224 *);
	void (*irq_mask)(struct irq_data___224 *);
	void (*irq_mask_ack)(struct irq_data___224 *);
	void (*irq_unmask)(struct irq_data___224 *);
	void (*irq_eoi)(struct irq_data___224 *);
	int (*irq_set_affinity)(struct irq_data___224 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___224 *);
	int (*irq_set_type)(struct irq_data___224 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___224 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___224 *);
	void (*irq_bus_sync_unlock)(struct irq_data___224 *);
	void (*irq_cpu_online)(struct irq_data___224 *);
	void (*irq_cpu_offline)(struct irq_data___224 *);
	void (*irq_suspend)(struct irq_data___224 *);
	void (*irq_resume)(struct irq_data___224 *);
	void (*irq_pm_shutdown)(struct irq_data___224 *);
	void (*irq_print_chip)(struct irq_data___224 *, struct seq_file___225 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___224 *, void *);
	long unsigned int flags;
};

struct seq_operations___225 {
	void * (*start)(struct seq_file___225 *, loff_t *);
	void (*stop)(struct seq_file___225 *, void *);
	void * (*next)(struct seq_file___225 *, void *, loff_t *);
	int (*show)(struct seq_file___225 *, void *);
};

struct dcbnl_rtnl_ops___90 {
	int (*ieee_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___90 *);
	u8 (*setstate)(struct net_device___90 *, u8);
	void (*getpermhwaddr)(struct net_device___90 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___90 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___90 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___90 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___90 *, int, u8 *);
	void (*setpfccfg)(struct net_device___90 *, int, u8);
	void (*getpfccfg)(struct net_device___90 *, int, u8 *);
	u8 (*setall)(struct net_device___90 *);
	u8 (*getcap)(struct net_device___90 *, int, u8 *);
	int (*getnumtcs)(struct net_device___90 *, int, u8 *);
	int (*setnumtcs)(struct net_device___90 *, int, u8);
	u8 (*getpfcstate)(struct net_device___90 *);
	void (*setpfcstate)(struct net_device___90 *, u8);
	void (*getbcncfg)(struct net_device___90 *, int, u32 *);
	void (*setbcncfg)(struct net_device___90 *, int, u32);
	void (*getbcnrp)(struct net_device___90 *, int, u8 *);
	void (*setbcnrp)(struct net_device___90 *, int, u8);
	u8 (*setapp)(struct net_device___90 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___90 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___90 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___90 *, int, u8);
	u8 (*getdcbx)(struct net_device___90 *);
	u8 (*setdcbx)(struct net_device___90 *, u8);
	int (*peer_getappinfo)(struct net_device___90 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___90 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___90 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___90 *, struct cee_pfc *);
};

struct cgroupfs_root___195;

struct cgroup___195 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___195 *parent;
	struct dentry___300 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___195 *subsys[11];
	struct cgroupfs_root___195 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___302 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___195 {
	struct super_block___300 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___195 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___92 {
	struct sk_buff___92 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___92 *, struct netlink_callback___92 *);
	int (*done)(struct netlink_callback___92 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___90 {
	int (*create)(struct sk_buff___92 *, struct net_device___90 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___92 *, unsigned char *);
	int (*rebuild)(struct sk_buff___92 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___90 *, const unsigned char *);
};

struct napi_struct___90 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___90 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___90 *dev;
	struct sk_buff___92 *gro_list;
	struct sk_buff___92 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___90 {
	struct net_device___90 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___81 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___90 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___81 kobj;
	struct net_device___90 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___90 {
	int (*ndo_init)(struct net_device___90 *);
	void (*ndo_uninit)(struct net_device___90 *);
	int (*ndo_open)(struct net_device___90 *);
	int (*ndo_stop)(struct net_device___90 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___92 *, struct net_device___90 *);
	u16 (*ndo_select_queue)(struct net_device___90 *, struct sk_buff___92 *);
	void (*ndo_change_rx_flags)(struct net_device___90 *, int);
	void (*ndo_set_rx_mode)(struct net_device___90 *);
	int (*ndo_set_mac_address)(struct net_device___90 *, void *);
	int (*ndo_validate_addr)(struct net_device___90 *);
	int (*ndo_do_ioctl)(struct net_device___90 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___90 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___90 *, int);
	int (*ndo_neigh_setup)(struct net_device___90 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___90 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___90 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___90 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___90 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___90 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___90 *);
	int (*ndo_netpoll_setup)(struct net_device___90 *, struct netpoll_info___5 *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___90 *);
	int (*ndo_busy_poll)(struct napi_struct___90 *);
	int (*ndo_set_vf_mac)(struct net_device___90 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___90 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___90 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___90 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___90 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___90 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___90 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___90 *, int, struct sk_buff___92 *);
	int (*ndo_setup_tc)(struct net_device___90 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___90 *);
	int (*ndo_fcoe_disable)(struct net_device___90 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___90 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___90 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___90 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___90 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___90 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___90 *, const struct sk_buff___92 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___90 *, struct net_device___90 *);
	int (*ndo_del_slave)(struct net_device___90 *, struct net_device___90 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___92 *, struct netlink_callback___92 *, struct net_device___90 *, int);
	int (*ndo_bridge_setlink)(struct net_device___90 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___92 *, u32, u32, struct net_device___90 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___90 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___90 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___90 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___90 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___90 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___90 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___92 *, struct net_device___90 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___90 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___90 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___90 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct netpoll___5;

struct netpoll_info___5 {
	atomic_t refcnt;
	long unsigned int rx_flags;
	spinlock_t rx_lock;
	struct semaphore dev_lock;
	struct list_head rx_np;
	struct sk_buff_head___91 neigh_tx;
	struct sk_buff_head___91 txq;
	struct delayed_work tx_work;
	struct netpoll___5 *netpoll;
	struct callback_head rcu;
};

struct vlan_group {
	unsigned int nr_vlan_devs;
	struct hlist_node hlist;
	struct net_device___90 **vlan_devices_arrays[16];
};

struct vlan_info___2 {
	struct net_device___90 *real_dev;
	struct vlan_group grp;
	struct list_head vid_list;
	unsigned int nr_vids;
	struct callback_head rcu;
};

enum vlan_flags {
	VLAN_FLAG_REORDER_HDR = 1,
	VLAN_FLAG_GVRP = 2,
	VLAN_FLAG_LOOSE_BINDING = 4,
	VLAN_FLAG_MVRP = 8,
};

struct vlan_priority_tci_mapping {
	u32 priority;
	u16 vlan_qos;
	struct vlan_priority_tci_mapping *next;
};

struct vlan_pcpu_stats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 rx_multicast;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
	u32 rx_errors;
	u32 tx_dropped;
};

struct vlan_dev_priv {
	unsigned int nr_ingress_mappings;
	u32 ingress_priority_map[8];
	unsigned int nr_egress_mappings;
	struct vlan_priority_tci_mapping *egress_priority_map[16];
	__be16 vlan_proto;
	u16 vlan_id;
	u16 flags;
	struct net_device___90 *real_dev;
	unsigned char real_dev_addr[6];
	struct proc_dir_entry *dent;
	struct vlan_pcpu_stats *vlan_pcpu_stats;
	struct netpoll___5 *netpoll;
};

struct netpoll___5 {
	struct net_device___90 *dev;
	char dev_name[16];
	const char *name;
	void (*rx_hook)(struct netpoll___5 *, int, char *, int);
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct list_head rx;
	struct work_struct cleanup_work;
};

enum vlan_protos {
	VLAN_PROTO_8021Q = 0,
	VLAN_PROTO_8021AD = 1,
	VLAN_PROTO_NUM = 2,
};

struct vlan_vid_info {
	struct list_head list;
	__be16 proto;
	u16 vid;
	int refcount;
};

enum nl80211_iftype {
	NL80211_IFTYPE_UNSPECIFIED = 0,
	NL80211_IFTYPE_ADHOC = 1,
	NL80211_IFTYPE_STATION = 2,
	NL80211_IFTYPE_AP = 3,
	NL80211_IFTYPE_AP_VLAN = 4,
	NL80211_IFTYPE_WDS = 5,
	NL80211_IFTYPE_MONITOR = 6,
	NL80211_IFTYPE_MESH_POINT = 7,
	NL80211_IFTYPE_P2P_CLIENT = 8,
	NL80211_IFTYPE_P2P_GO = 9,
	NL80211_IFTYPE_P2P_DEVICE = 10,
	NL80211_IFTYPE_OCB = 11,
	NUM_NL80211_IFTYPES = 12,
	NL80211_IFTYPE_MAX = 11,
};

struct cfg80211_conn;

struct cfg80211_cached_keys;

struct cfg80211_internal_bss;

enum nl80211_chan_width {
	NL80211_CHAN_WIDTH_20_NOHT = 0,
	NL80211_CHAN_WIDTH_20 = 1,
	NL80211_CHAN_WIDTH_40 = 2,
	NL80211_CHAN_WIDTH_80 = 3,
	NL80211_CHAN_WIDTH_80P80 = 4,
	NL80211_CHAN_WIDTH_160 = 5,
	NL80211_CHAN_WIDTH_5 = 6,
	NL80211_CHAN_WIDTH_10 = 7,
};

struct ieee80211_channel;

struct cfg80211_chan_def {
	struct ieee80211_channel *chan;
	enum nl80211_chan_width width;
	u32 center_freq1;
	u32 center_freq2;
};

struct ieee80211_mcs_info {
	u8 rx_mask[10];
	__le16 rx_highest;
	u8 tx_params;
	u8 reserved[3];
};

struct ieee80211_ht_cap {
	__le16 cap_info;
	u8 ampdu_params_info;
	struct ieee80211_mcs_info mcs;
	__le16 extended_ht_cap_info;
	__le32 tx_BF_cap_info;
	u8 antenna_selection_info;
} __attribute__((packed));

struct cfg80211_ibss_params {
	const u8 *ssid;
	const u8 *bssid;
	struct cfg80211_chan_def chandef;
	const u8 *ie;
	u8 ssid_len;
	u8 ie_len;
	u16 beacon_interval;
	u32 basic_rates;
	bool channel_fixed;
	bool privacy;
	bool control_port;
	bool userspace_handles_dfs;
	int mcast_rate[3];
	struct ieee80211_ht_cap ht_capa;
	struct ieee80211_ht_cap ht_capa_mask;
	int: 32;
} __attribute__((packed));

enum nl80211_auth_type {
	NL80211_AUTHTYPE_OPEN_SYSTEM = 0,
	NL80211_AUTHTYPE_SHARED_KEY = 1,
	NL80211_AUTHTYPE_FT = 2,
	NL80211_AUTHTYPE_NETWORK_EAP = 3,
	NL80211_AUTHTYPE_SAE = 4,
	__NL80211_AUTHTYPE_NUM = 5,
	NL80211_AUTHTYPE_MAX = 4,
	NL80211_AUTHTYPE_AUTOMATIC = 5,
};

enum nl80211_mfp {
	NL80211_MFP_NO = 0,
	NL80211_MFP_REQUIRED = 1,
};

struct cfg80211_crypto_settings {
	u32 wpa_versions;
	u32 cipher_group;
	int n_ciphers_pairwise;
	u32 ciphers_pairwise[5];
	int n_akm_suites;
	u32 akm_suites[2];
	bool control_port;
	__be16 control_port_ethertype;
	bool control_port_no_encrypt;
};

struct ieee80211_vht_mcs_info {
	__le16 rx_mcs_map;
	__le16 rx_highest;
	__le16 tx_mcs_map;
	__le16 tx_highest;
};

struct ieee80211_vht_cap {
	__le32 vht_cap_info;
	struct ieee80211_vht_mcs_info supp_mcs;
};

struct cfg80211_connect_params {
	struct ieee80211_channel *channel;
	struct ieee80211_channel *channel_hint;
	const u8 *bssid;
	const u8 *bssid_hint;
	const u8 *ssid;
	size_t ssid_len;
	enum nl80211_auth_type auth_type;
	int: 32;
	const u8 *ie;
	size_t ie_len;
	bool privacy;
	int: 24;
	enum nl80211_mfp mfp;
	struct cfg80211_crypto_settings crypto;
	int: 32;
	const u8 *key;
	u8 key_len;
	u8 key_idx;
	short: 16;
	u32 flags;
	int bg_scan_period;
	struct ieee80211_ht_cap ht_capa;
	struct ieee80211_ht_cap ht_capa_mask;
	struct ieee80211_vht_cap vht_capa;
	struct ieee80211_vht_cap vht_capa_mask;
} __attribute__((packed));

struct wiphy;

struct wireless_dev {
	struct wiphy *wiphy;
	enum nl80211_iftype iftype;
	struct list_head list;
	struct net_device___73 *netdev;
	u32 identifier;
	struct list_head mgmt_registrations;
	spinlock_t mgmt_registrations_lock;
	struct mutex___285 mtx;
	bool use_4addr;
	bool p2p_started;
	u8 address[6];
	u8 ssid[32];
	u8 ssid_len;
	u8 mesh_id_len;
	u8 mesh_id_up_len;
	struct cfg80211_conn *conn;
	struct cfg80211_cached_keys *connect_keys;
	struct list_head event_list;
	spinlock_t event_lock;
	struct cfg80211_internal_bss *current_bss;
	struct cfg80211_chan_def preset_chandef;
	struct cfg80211_chan_def chandef;
	bool ibss_fixed;
	bool ibss_dfs_possible;
	bool ps;
	int ps_timeout;
	int beacon_interval;
	u32 ap_unexpected_nlportid;
	bool cac_started;
	long unsigned int cac_start_time;
	unsigned int cac_time_ms;
	u32 owner_nlportid;
	struct {
		struct cfg80211_ibss_params ibss;
		struct cfg80211_connect_params connect;
		struct cfg80211_cached_keys *keys;
		const u8 *ie;
		size_t ie_len;
		u8 bssid[6];
		u8 prev_bssid[6];
		u8 ssid[32];
		s8 default_key;
		s8 default_mgmt_key;
		bool prev_bssid_valid;
	} wext;
};

struct iw_encode_ext {
	__u32 ext_flags;
	__u8 tx_seq[8];
	__u8 rx_seq[8];
	struct sockaddr addr;
	__u16 alg;
	__u16 key_len;
	__u8 key[0];
};

struct iwreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union iwreq_data u;
};

struct iw_event {
	__u16 len;
	__u16 cmd;
	union iwreq_data u;
};

struct compat_iw_point {
	compat_caddr_t pointer;
	__u16 length;
	__u16 flags;
};

struct __compat_iw_event {
	__u16 len;
	__u16 cmd;
	compat_caddr_t pointer;
};

enum nl80211_reg_initiator {
	NL80211_REGDOM_SET_BY_CORE = 0,
	NL80211_REGDOM_SET_BY_USER = 1,
	NL80211_REGDOM_SET_BY_DRIVER = 2,
	NL80211_REGDOM_SET_BY_COUNTRY_IE = 3,
};

enum nl80211_dfs_regions {
	NL80211_DFS_UNSET = 0,
	NL80211_DFS_FCC = 1,
	NL80211_DFS_ETSI = 2,
	NL80211_DFS_JP = 3,
};

enum nl80211_user_reg_hint_type {
	NL80211_USER_REG_HINT_USER = 0,
	NL80211_USER_REG_HINT_CELL_BASE = 1,
	NL80211_USER_REG_HINT_INDOOR = 2,
};

enum nl80211_mntr_flags {
	__NL80211_MNTR_FLAG_INVALID = 0,
	NL80211_MNTR_FLAG_FCSFAIL = 1,
	NL80211_MNTR_FLAG_PLCPFAIL = 2,
	NL80211_MNTR_FLAG_CONTROL = 3,
	NL80211_MNTR_FLAG_OTHER_BSS = 4,
	NL80211_MNTR_FLAG_COOK_FRAMES = 5,
	NL80211_MNTR_FLAG_ACTIVE = 6,
	__NL80211_MNTR_FLAG_AFTER_LAST = 7,
	NL80211_MNTR_FLAG_MAX = 6,
};

enum nl80211_bss_scan_width {
	NL80211_BSS_CHAN_WIDTH_20 = 0,
	NL80211_BSS_CHAN_WIDTH_10 = 1,
	NL80211_BSS_CHAN_WIDTH_5 = 2,
};

enum nl80211_band {
	NL80211_BAND_2GHZ = 0,
	NL80211_BAND_5GHZ = 1,
	NL80211_BAND_60GHZ = 2,
};

struct nl80211_wowlan_tcp_data_seq {
	__u32 start;
	__u32 offset;
	__u32 len;
};

struct nl80211_wowlan_tcp_data_token {
	__u32 offset;
	__u32 len;
	__u8 token_stream[0];
};

struct nl80211_wowlan_tcp_data_token_feature {
	__u32 min_len;
	__u32 max_len;
	__u32 bufsize;
};

enum nl80211_ext_feature_index {
	NL80211_EXT_FEATURE_VHT_IBSS = 0,
	NUM_NL80211_EXT_FEATURES = 1,
	MAX_NL80211_EXT_FEATURES = 0,
};

enum nl80211_dfs_state {
	NL80211_DFS_USABLE = 0,
	NL80211_DFS_UNAVAILABLE = 1,
	NL80211_DFS_AVAILABLE = 2,
};

struct nl80211_vendor_cmd_info {
	__u32 vendor_id;
	__u32 subcmd;
};

enum environment_cap {
	ENVIRON_ANY = 0,
	ENVIRON_INDOOR = 1,
	ENVIRON_OUTDOOR = 2,
};

struct regulatory_request {
	struct callback_head callback_head;
	int wiphy_idx;
	enum nl80211_reg_initiator initiator;
	enum nl80211_user_reg_hint_type user_reg_hint_type;
	char alpha2[2];
	enum nl80211_dfs_regions dfs_region;
	bool intersect;
	bool processed;
	enum environment_cap country_ie_env;
	struct list_head list;
};

struct ieee80211_freq_range {
	u32 start_freq_khz;
	u32 end_freq_khz;
	u32 max_bandwidth_khz;
};

struct ieee80211_power_rule {
	u32 max_antenna_gain;
	u32 max_eirp;
};

struct ieee80211_reg_rule {
	struct ieee80211_freq_range freq_range;
	struct ieee80211_power_rule power_rule;
	u32 flags;
	u32 dfs_cac_ms;
};

struct ieee80211_regdomain {
	struct callback_head callback_head;
	u32 n_reg_rules;
	char alpha2[3];
	enum nl80211_dfs_regions dfs_region;
	struct ieee80211_reg_rule reg_rules[0];
};

enum ieee80211_band {
	IEEE80211_BAND_2GHZ = 0,
	IEEE80211_BAND_5GHZ = 1,
	IEEE80211_BAND_60GHZ = 2,
	IEEE80211_NUM_BANDS = 3,
};

struct ieee80211_channel {
	enum ieee80211_band band;
	u16 center_freq;
	u16 hw_value;
	u32 flags;
	int max_antenna_gain;
	int max_power;
	int max_reg_power;
	bool beacon_found;
	u32 orig_flags;
	int orig_mag;
	int orig_mpwr;
	enum nl80211_dfs_state dfs_state;
	long unsigned int dfs_state_entered;
	unsigned int dfs_cac_ms;
};

struct ieee80211_rate {
	u32 flags;
	u16 bitrate;
	u16 hw_value;
	u16 hw_value_short;
};

struct ieee80211_sta_ht_cap {
	u16 cap;
	bool ht_supported;
	u8 ampdu_factor;
	u8 ampdu_density;
	struct ieee80211_mcs_info mcs;
	char: 8;
} __attribute__((packed));

struct ieee80211_sta_vht_cap {
	bool vht_supported;
	u32 cap;
	struct ieee80211_vht_mcs_info vht_mcs;
};

struct ieee80211_supported_band {
	struct ieee80211_channel *channels;
	struct ieee80211_rate *bitrates;
	enum ieee80211_band band;
	int n_channels;
	int n_bitrates;
	struct ieee80211_sta_ht_cap ht_cap;
	struct ieee80211_sta_vht_cap vht_cap;
};

struct mac_address {
	u8 addr[6];
};

struct cfg80211_ssid {
	u8 ssid[32];
	u8 ssid_len;
};

enum cfg80211_signal_type {
	CFG80211_SIGNAL_TYPE_NONE = 0,
	CFG80211_SIGNAL_TYPE_MBM = 1,
	CFG80211_SIGNAL_TYPE_UNSPEC = 2,
};

struct ieee80211_txrx_stypes;

struct ieee80211_iface_combination;

struct wiphy_wowlan_support;

struct cfg80211_wowlan;

struct wiphy_coalesce_support;

struct wiphy_vendor_command;

struct wiphy {
	u8 perm_addr[6];
	u8 addr_mask[6];
	struct mac_address *addresses;
	const struct ieee80211_txrx_stypes *mgmt_stypes;
	const struct ieee80211_iface_combination *iface_combinations;
	int n_iface_combinations;
	u16 software_iftypes;
	u16 n_addresses;
	u16 interface_modes;
	u16 max_acl_mac_addrs;
	u32 flags;
	u32 regulatory_flags;
	u32 features;
	u8 ext_features[1];
	u32 ap_sme_capa;
	enum cfg80211_signal_type signal_type;
	int bss_priv_size;
	u8 max_scan_ssids;
	u8 max_sched_scan_ssids;
	u8 max_match_sets;
	u16 max_scan_ie_len;
	u16 max_sched_scan_ie_len;
	int n_cipher_suites;
	const u32 *cipher_suites;
	u8 retry_short;
	u8 retry_long;
	u32 frag_threshold;
	u32 rts_threshold;
	u8 coverage_class;
	char fw_version[32];
	u32 hw_version;
	const struct wiphy_wowlan_support *wowlan;
	struct cfg80211_wowlan *wowlan_config;
	u16 max_remain_on_channel_duration;
	u8 max_num_pmkids;
	u32 available_antennas_tx;
	u32 available_antennas_rx;
	u32 probe_resp_offload;
	const u8 *extended_capabilities;
	const u8 *extended_capabilities_mask;
	u8 extended_capabilities_len;
	const void *privid;
	struct ieee80211_supported_band *bands[3];
	void (*reg_notifier)(struct wiphy *, struct regulatory_request *);
	const struct ieee80211_regdomain *regd;
	struct device___249 dev;
	bool registered;
	struct dentry___283 *debugfsdir;
	const struct ieee80211_ht_cap *ht_capa_mod_mask;
	const struct ieee80211_vht_cap *vht_capa_mod_mask;
	struct net___87 *_net;
	const struct iw_handler_def *wext;
	const struct wiphy_coalesce_support *coalesce;
	const struct wiphy_vendor_command *vendor_commands;
	const struct nl80211_vendor_cmd_info *vendor_events;
	int n_vendor_commands;
	int n_vendor_events;
	u16 max_ap_assoc_sta;
	u8 max_num_csa_counters;
	u8 max_adj_channel_rssi_comp;
	int: 32;
	char priv[0];
};

struct cfg80211_match_set {
	struct cfg80211_ssid ssid;
	s32 rssi_thold;
};

struct cfg80211_sched_scan_request {
	struct cfg80211_ssid *ssids;
	int n_ssids;
	u32 n_channels;
	enum nl80211_bss_scan_width scan_width;
	u32 interval;
	const u8 *ie;
	size_t ie_len;
	u32 flags;
	struct cfg80211_match_set *match_sets;
	int n_match_sets;
	s32 min_rssi_thold;
	u32 delay;
	u8 mac_addr[6];
	u8 mac_addr_mask[6];
	struct wiphy *wiphy;
	struct net_device___73 *dev;
	long unsigned int scan_start;
	struct callback_head callback_head;
	u32 owner_nlportid;
	struct ieee80211_channel *channels[0];
};

struct cfg80211_pkt_pattern {
	const u8 *mask;
	const u8 *pattern;
	int pattern_len;
	int pkt_offset;
};

struct cfg80211_wowlan_tcp {
	struct socket___63 *sock;
	__be32 src;
	__be32 dst;
	u16 src_port;
	u16 dst_port;
	u8 dst_mac[6];
	int payload_len;
	const u8 *payload;
	struct nl80211_wowlan_tcp_data_seq payload_seq;
	u32 data_interval;
	u32 wake_len;
	const u8 *wake_data;
	const u8 *wake_mask;
	u32 tokens_size;
	struct nl80211_wowlan_tcp_data_token payload_tok;
};

struct cfg80211_wowlan {
	bool any;
	bool disconnect;
	bool magic_pkt;
	bool gtk_rekey_failure;
	bool eap_identity_req;
	bool four_way_handshake;
	bool rfkill_release;
	struct cfg80211_pkt_pattern *patterns;
	struct cfg80211_wowlan_tcp *tcp;
	int n_patterns;
	struct cfg80211_sched_scan_request *nd_config;
};

struct ieee80211_iface_limit {
	u16 max;
	u16 types;
};

struct ieee80211_iface_combination {
	const struct ieee80211_iface_limit *limits;
	u32 num_different_channels;
	u16 max_interfaces;
	u8 n_limits;
	bool beacon_int_infra_match;
	u8 radar_detect_widths;
	u8 radar_detect_regions;
};

struct ieee80211_txrx_stypes {
	u16 tx;
	u16 rx;
};

struct wiphy_wowlan_tcp_support {
	const struct nl80211_wowlan_tcp_data_token_feature *tok;
	u32 data_payload_max;
	u32 data_interval_max;
	u32 wake_payload_max;
	bool seq;
};

struct wiphy_wowlan_support {
	u32 flags;
	int n_patterns;
	int pattern_max_len;
	int pattern_min_len;
	int max_pkt_offset;
	int max_nd_match_sets;
	const struct wiphy_wowlan_tcp_support *tcp;
};

struct wiphy_coalesce_support {
	int n_rules;
	int max_delay;
	int n_patterns;
	int pattern_max_len;
	int pattern_min_len;
	int max_pkt_offset;
};

struct wiphy_vendor_command {
	struct nl80211_vendor_cmd_info info;
	u32 flags;
	int (*doit)(struct wiphy *, struct wireless_dev *, const void *, int);
};

typedef int (*iw_handler___4)(struct net_device___73 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_ioctl_description {
	__u8 header_type;
	__u8 token_type;
	__u16 token_size;
	__u16 min_tokens;
	__u16 max_tokens;
	__u32 flags;
};

typedef int (*wext_ioctl_func)(struct net_device___73 *, struct iwreq *, unsigned int, struct iw_request_info *, iw_handler___4);

struct page___300;

typedef struct page___300 *pgtable_t___300;

struct address_space___301;

struct kmem_cache___284;

struct page___300 {
	long unsigned int flags;
	struct address_space___301 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___300 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___300 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___284 *slab_cache;
		struct page___300 *first_page;
	};
	long: 64;
};

struct task_struct___302;

struct pv_cpu_ops___302 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___302 *);
	void (*end_context_switch)(struct task_struct___302 *);
};

struct mutex___303 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___302 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___295 {
	struct page___300 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___309;

struct nsproxy___181;

struct signal_struct___302;

struct css_set___196;

struct task_struct___302 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___302 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___309 *mm;
	struct mm_struct___309 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___302 *real_parent;
	struct task_struct___302 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___302 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___98 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___302 = 0,
		VTIME_USER___302 = 1,
		VTIME_SYS___302 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___181 *nsproxy;
	struct signal_struct___302 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___196 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___303 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___295 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide7;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___309 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___309 *, struct mm_struct___309 *);
	void (*dup_mmap)(struct mm_struct___309 *, struct mm_struct___309 *);
	void (*exit_mmap)(struct mm_struct___309 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___309 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___309 *);
	void (*pgd_free)(struct mm_struct___309 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___309 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___309 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___309 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___309 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___309 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___309 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___309 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___309 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___309 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___309 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___309 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___303 lock;
	void *vdso;
} mm_context_t___303;

struct xol_area___300;

struct uprobes_state___300 {
	struct xol_area___300 *xol_area;
};

struct vm_area_struct___309;

struct file___301;

struct core_state___302;

struct mm_struct___309 {
	struct vm_area_struct___309 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___309 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___309 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___303 context;
	long unsigned int flags;
	struct core_state___302 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___302 *owner;
	struct file___301 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___300 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct module___185;

struct module_kobject___185 {
	struct kobject___81 kobj;
	struct module___185 *mod;
	struct kobject___81 *drivers_dir;
	struct module_param_attrs *mp;
};

struct module_attribute___185;

struct module___185 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___185 mkobj;
	struct module_attribute___185 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___81 *holders_dir;
	const struct kernel_symbol *syms;
	const long unsigned int *crcs;
	unsigned int num_syms;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const long unsigned int *gpl_crcs;
	bool sig_ok;
	const struct kernel_symbol *gpl_future_syms;
	const long unsigned int *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	void *module_init;
	void *module_core;
	unsigned int init_size;
	unsigned int core_size;
	unsigned int init_text_size;
	unsigned int core_text_size;
	unsigned int init_ro_size;
	unsigned int core_ro_size;
	struct mod_arch_specific arch;
	unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	Elf64_Sym *symtab;
	Elf64_Sym *core_symtab;
	unsigned int num_symtab;
	unsigned int core_num_syms;
	char *strtab;
	char *core_strtab;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct ftrace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	struct task_struct___302 *waiter;
	void (*exit)();
	struct module_ref *refptr;
};

struct zone___302;

struct lruvec___302 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___302 *zone;
};

struct pglist_data___302;

struct zone___302 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___302 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___302 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___302 {
	struct zone___302 *zone;
	int zone_idx;
};

struct zonelist___302 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___302 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___302 {
	struct zone___302 node_zones[4];
	struct zonelist___302 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___302 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_data___225;

struct x86_io_apic_ops___225 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___225 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___225;

struct irq_data___225 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___225 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___299;

struct dev_pm_ops___299 {
	int (*prepare)(struct device___299 *);
	void (*complete)(struct device___299 *);
	int (*suspend)(struct device___299 *);
	int (*resume)(struct device___299 *);
	int (*freeze)(struct device___299 *);
	int (*thaw)(struct device___299 *);
	int (*poweroff)(struct device___299 *);
	int (*restore)(struct device___299 *);
	int (*suspend_late)(struct device___299 *);
	int (*resume_early)(struct device___299 *);
	int (*freeze_late)(struct device___299 *);
	int (*thaw_early)(struct device___299 *);
	int (*poweroff_late)(struct device___299 *);
	int (*restore_early)(struct device___299 *);
	int (*suspend_noirq)(struct device___299 *);
	int (*resume_noirq)(struct device___299 *);
	int (*freeze_noirq)(struct device___299 *);
	int (*thaw_noirq)(struct device___299 *);
	int (*poweroff_noirq)(struct device___299 *);
	int (*restore_noirq)(struct device___299 *);
	int (*runtime_suspend)(struct device___299 *);
	int (*runtime_resume)(struct device___299 *);
	int (*runtime_idle)(struct device___299 *);
};

struct dev_pm_qos___102;

struct dev_pm_info___102 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___102 *qos;
};

struct dma_map_ops___164;

struct dev_archdata___164 {
	struct dma_map_ops___164 *dma_ops;
	void *iommu;
};

struct device_type___299;

struct bus_type___299;

struct device_driver___299;

struct dev_pm_domain___299;

struct class___299;

struct attribute_group___261;

struct device_rh___299;

struct device___299 {
	struct device___299 *parent;
	struct device_private *p;
	struct kobject___81 kobj;
	const char *init_name;
	const struct device_type___299 *type;
	struct mutex___303 mutex;
	struct bus_type___299 *bus;
	struct device_driver___299 *driver;
	void *platform_data;
	struct dev_pm_info___102 power;
	struct dev_pm_domain___299 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___164 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___299 *class;
	const struct attribute_group___261 **groups;
	void (*release)(struct device___299 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___299 *device_rh;
};

struct dev_pm_qos_request___103;

struct dev_pm_qos___102 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___103 *latency_req;
	struct dev_pm_qos_request___103 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___103 *latency_tolerance_req;
};

struct dev_pm_info_rh___299 {
	void (*set_latency_tolerance)(struct device___299 *, s32);
};

struct dev_pm_domain___299 {
	struct dev_pm_ops___299 ops;
};

struct smp_ops___302 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___302 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct ctl_table_header___106;

struct ctl_node___106 {
	struct rb_node node;
	struct ctl_table_header___106 *header;
};

struct ctl_table_root___106;

struct ctl_table_set___106;

struct ctl_dir___106;

struct ctl_table_header___106 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___106 *root;
	struct ctl_table_set___106 *set;
	struct ctl_dir___106 *parent;
	struct ctl_node___106 *node;
};

struct ctl_dir___106 {
	struct ctl_table_header___106 header;
	struct rb_root root;
};

struct ctl_table_set___106 {
	int (*is_seen)(struct ctl_table_set___106 *);
	struct ctl_dir___106 dir;
};

struct ctl_table_root___106 {
	struct ctl_table_set___106 default_set;
	struct ctl_table_set___106 * (*lookup)(struct ctl_table_root___106 *, struct nsproxy___181 *);
	int (*permissions)(struct ctl_table_header___106 *, struct ctl_table *);
};

struct net___105;

struct nsproxy___181 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___105 *net_ns;
};

struct bin_attribute___263;

struct attribute_group___261 {
	const char *name;
	umode_t (*is_visible)(struct kobject___81 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___263 **bin_attrs;
};

struct bin_attribute___263 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___301 *, struct kobject___81 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___301 *, struct kobject___81 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	int (*mmap)(struct file___301 *, struct kobject___81 *, struct bin_attribute___263 *, struct vm_area_struct___309 *);
};

struct dentry___301;

struct path___301 {
	struct vfsmount *mnt;
	struct dentry___301 *dentry;
};

struct inode___301;

struct file_operations___301;

struct file___301 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___301 f_path;
	struct inode___301 *f_inode;
	const struct file_operations___301 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___301 *f_mapping;
	struct mutex___303 f_pos_lock;
};

struct vm_operations_struct___275;

struct vm_area_struct___309 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___309 *vm_next;
	struct vm_area_struct___309 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___309 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___275 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___301 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___185 *, struct module_kobject___185 *, char *);
	ssize_t (*store)(struct module_attribute___185 *, struct module_kobject___185 *, const char *, size_t);
	void (*setup)(struct module___185 *, const char *);
	int (*test)(struct module___185 *);
	void (*free)(struct module___185 *);
};

struct dentry_operations___301;

struct super_block___301;

struct dentry___301 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___301 *d_parent;
	struct qstr d_name;
	struct inode___301 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___301 *d_op;
	struct super_block___301 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct address_space_operations___301;

struct address_space___301 {
	struct inode___301 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___303 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___301 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___301;

struct file_lock___301;

struct dquot___301;

struct block_device___301;

struct inode___301 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___301 *i_op;
	struct super_block___301 *i_sb;
	struct address_space___301 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___303 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___301 *i_fop;
	struct file_lock___301 *i_flock;
	struct address_space___301 i_data;
	struct dquot___301 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___301 *i_bdev;
		struct cdev *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___301 {
	int (*d_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_hash)(const struct dentry___301 *, struct qstr *);
	int (*d_compare)(const struct dentry___301 *, const struct dentry___301 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___301 *);
	void (*d_release)(struct dentry___301 *);
	void (*d_prune)(struct dentry___301 *);
	void (*d_iput)(struct dentry___301 *, struct inode___301 *);
	char * (*d_dname)(struct dentry___301 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___301 *);
	int (*d_manage)(struct dentry___301 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___301;

struct mem_dqinfo___301 {
	struct quota_format_type___301 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___301;

struct quota_info___301 {
	unsigned int flags;
	struct mutex___303 dqio_mutex;
	struct mutex___303 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___301 *files[2];
	struct mem_dqinfo___301 info[2];
	const struct quota_format_ops___301 *ops[2];
};

struct file_system_type___301;

struct super_operations___301;

struct dquot_operations___301;

struct quotactl_ops___301;

struct xattr_handler___197;

struct super_block___301 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___301 *s_type;
	const struct super_operations___301 *s_op;
	const struct dquot_operations___301 *dq_op;
	const struct quotactl_ops___301 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___301 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___197 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___301 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___301 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___303 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___301 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___301 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___301 *bd_inode;
	struct super_block___301 *bd_super;
	struct mutex___303 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___301 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___303 bd_fsfreeze_mutex;
};

struct cgroup___196;

struct cgroup_subsys_state___196 {
	struct cgroup___196 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct iattr___301 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___301 *ia_file;
};

struct dquot___301 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___303 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___301 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___301 {
	int qf_fmt_id;
	const struct quota_format_ops___301 *qf_ops;
	struct module___185 *qf_owner;
	struct quota_format_type___301 *qf_next;
};

struct quota_format_ops___301 {
	int (*check_quota_file)(struct super_block___301 *, int);
	int (*read_file_info)(struct super_block___301 *, int);
	int (*write_file_info)(struct super_block___301 *, int);
	int (*free_file_info)(struct super_block___301 *, int);
	int (*read_dqblk)(struct dquot___301 *);
	int (*commit_dqblk)(struct dquot___301 *);
	int (*release_dqblk)(struct dquot___301 *);
};

struct dquot_operations___301 {
	int (*write_dquot)(struct dquot___301 *);
	struct dquot___301 * (*alloc_dquot)(struct super_block___301 *, int);
	void (*destroy_dquot)(struct dquot___301 *);
	int (*acquire_dquot)(struct dquot___301 *);
	int (*release_dquot)(struct dquot___301 *);
	int (*mark_dirty)(struct dquot___301 *);
	int (*write_info)(struct super_block___301 *, int);
	qsize_t * (*get_reserved_space)(struct inode___301 *);
};

struct quotactl_ops___301 {
	int (*quota_on)(struct super_block___301 *, int, int, struct path___301 *);
	int (*quota_on_meta)(struct super_block___301 *, int, int);
	int (*quota_off)(struct super_block___301 *, int);
	int (*quota_sync)(struct super_block___301 *, int);
	int (*get_info)(struct super_block___301 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___301 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___301 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___301 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___301 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___301 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___301 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___301 *, unsigned int);
};

struct address_space_operations___301 {
	int (*writepage)(struct page___300 *, struct writeback_control *);
	int (*readpage)(struct file___301 *, struct page___300 *);
	int (*writepages)(struct address_space___301 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___300 *);
	int (*readpages)(struct file___301 *, struct address_space___301 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___301 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___300 **, void **);
	int (*write_end)(struct file___301 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___300 *, void *);
	sector_t (*bmap)(struct address_space___301 *, sector_t);
	void (*invalidatepage)(struct page___300 *, long unsigned int);
	int (*releasepage)(struct page___300 *, gfp_t);
	void (*freepage)(struct page___300 *);
	ssize_t (*direct_IO)(int, struct kiocb *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___301 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___301 *, struct page___300 *, struct page___300 *, enum migrate_mode);
	int (*launder_page)(struct page___300 *);
	int (*is_partially_uptodate)(struct page___300 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___300 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___301 *, struct page___300 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___301 *, sector_t *);
	void (*swap_deactivate)(struct file___301 *);
	void (*invalidatepage_range)(struct page___300 *, unsigned int, unsigned int);
};

struct inode_operations___301 {
	struct dentry___301 * (*lookup)(struct inode___301 *, struct dentry___301 *, unsigned int);
	void * (*follow_link)(struct dentry___301 *, struct nameidata *);
	int (*permission)(struct inode___301 *, int);
	struct posix_acl * (*get_acl)(struct inode___301 *, int);
	int (*readlink)(struct dentry___301 *, char *, int);
	void (*put_link)(struct dentry___301 *, struct nameidata *, void *);
	int (*create)(struct inode___301 *, struct dentry___301 *, umode_t, bool);
	int (*link)(struct dentry___301 *, struct inode___301 *, struct dentry___301 *);
	int (*unlink)(struct inode___301 *, struct dentry___301 *);
	int (*symlink)(struct inode___301 *, struct dentry___301 *, const char *);
	int (*mkdir)(struct inode___301 *, struct dentry___301 *, umode_t);
	int (*rmdir)(struct inode___301 *, struct dentry___301 *);
	int (*mknod)(struct inode___301 *, struct dentry___301 *, umode_t, dev_t);
	int (*rename)(struct inode___301 *, struct dentry___301 *, struct inode___301 *, struct dentry___301 *);
	int (*setattr)(struct dentry___301 *, struct iattr___301 *);
	int (*getattr)(struct vfsmount *, struct dentry___301 *, struct kstat *);
	int (*setxattr)(struct dentry___301 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___301 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___301 *, char *, size_t);
	int (*removexattr)(struct dentry___301 *, const char *);
	int (*fiemap)(struct inode___301 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___301 *, struct timespec *, int);
	int (*atomic_open)(struct inode___301 *, struct dentry___301 *, struct file___301 *, unsigned int, umode_t, int *);
	long: 64;
};

struct seq_file___226;

struct file_operations___301 {
	struct module___185 *owner;
	loff_t (*llseek)(struct file___301 *, loff_t, int);
	ssize_t (*read)(struct file___301 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___301 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___301 *, void *, filldir_t);
	unsigned int (*poll)(struct file___301 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___301 *, struct vm_area_struct___309 *);
	int (*open)(struct inode___301 *, struct file___301 *);
	int (*flush)(struct file___301 *, fl_owner_t);
	int (*release)(struct inode___301 *, struct file___301 *);
	int (*fsync)(struct file___301 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb *, int);
	int (*fasync)(int, struct file___301 *, int);
	int (*lock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*sendpage)(struct file___301 *, struct page___300 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___301 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___301 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___301 *, long int, struct file_lock___301 **, void **);
		struct {
			int (*setlease)(struct file___301 *, long int, struct file_lock___301 **);
		} __UNIQUE_ID_rh_kabi_hide3;
		union {		};
	};
	long int (*fallocate)(struct file___301 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___226 *, struct file___301 *);
};

struct fasync_struct___301;

struct file_lock_operations___301;

struct lock_manager_operations___301;

struct file_lock___301 {
	struct file_lock___301 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___98 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___301 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___301 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___301 *fl_ops;
	const struct lock_manager_operations___301 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___301 {
	void (*fl_copy_lock)(struct file_lock___301 *, struct file_lock___301 *);
	void (*fl_release_private)(struct file_lock___301 *);
};

struct lock_manager_operations___301 {
	int (*lm_compare_owner)(struct file_lock___301 *, struct file_lock___301 *);
	long unsigned int (*lm_owner_key)(struct file_lock___301 *);
	void (*lm_notify)(struct file_lock___301 *);
	int (*lm_grant)(struct file_lock___301 *, struct file_lock___301 *, int);
	void (*lm_break)(struct file_lock___301 *);
	int (*lm_change)(struct file_lock___301 **, int);
};

struct fasync_struct___301 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___301 *fa_next;
	struct file___301 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___301 {
	const char *name;
	int fs_flags;
	struct dentry___301 * (*mount)(struct file_system_type___301 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___301 *);
	struct module___185 *owner;
	struct file_system_type___301 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___301 {
	struct inode___301 * (*alloc_inode)(struct super_block___301 *);
	void (*destroy_inode)(struct inode___301 *);
	void (*dirty_inode)(struct inode___301 *, int);
	int (*write_inode)(struct inode___301 *, struct writeback_control *);
	int (*drop_inode)(struct inode___301 *);
	void (*evict_inode)(struct inode___301 *);
	void (*put_super)(struct super_block___301 *);
	int (*sync_fs)(struct super_block___301 *, int);
	int (*freeze_fs)(struct super_block___301 *);
	int (*unfreeze_fs)(struct super_block___301 *);
	int (*statfs)(struct dentry___301 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___301 *, int *, char *);
	void (*umount_begin)(struct super_block___301 *);
	int (*show_options)(struct seq_file___226 *, struct dentry___301 *);
	int (*show_devname)(struct seq_file___226 *, struct dentry___301 *);
	int (*show_path)(struct seq_file___226 *, struct dentry___301 *);
	int (*show_stats)(struct seq_file___226 *, struct dentry___301 *);
	ssize_t (*quota_read)(struct super_block___301 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___301 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___301 *);
	int (*bdev_try_to_free_page)(struct super_block___301 *, struct page___300 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___301 *);
	void (*free_cached_objects)(struct super_block___301 *, int);
};

struct xattr_handler___197 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___301 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___301 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___301 *, const char *, const void *, size_t, int, int);
};

struct seq_operations___226;

struct seq_file___226 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___303 lock;
	const struct seq_operations___226 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct seq_operations___226 {
	void * (*start)(struct seq_file___226 *, loff_t *);
	void (*stop)(struct seq_file___226 *, void *);
	void * (*next)(struct seq_file___226 *, void *, loff_t *);
	int (*show)(struct seq_file___226 *, void *);
};

struct xol_area___300 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___300 *page;
	long unsigned int vaddr;
};

struct kmem_cache_cpu___283;

struct memcg_cache_params___284;

struct kmem_cache___284 {
	struct kmem_cache_cpu___283 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___81 kobj;
	struct memcg_cache_params___284 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct vm_fault___271;

struct vm_operations_struct___275 {
	void (*open)(struct vm_area_struct___309 *);
	void (*close)(struct vm_area_struct___309 *);
	int (*fault)(struct vm_area_struct___309 *, struct vm_fault___271 *);
	int (*page_mkwrite)(struct vm_area_struct___309 *, struct vm_fault___271 *);
	int (*access)(struct vm_area_struct___309 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___309 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___309 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___309 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___309 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___302 {
	struct task_struct___302 *task;
	struct core_thread___302 *next;
};

struct core_state___302 {
	atomic_t nr_threads;
	struct core_thread___302 dumper;
	struct completion startup;
};

struct signal_struct___302 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___302 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___302 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___98 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___303 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___196 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___196 *subsys[11];
	struct callback_head callback_head;
};

struct dma_map_ops___164 {
	void * (*alloc)(struct device___299 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___299 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___299 *, struct vm_area_struct___309 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___299 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___299 *, struct page___300 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___299 *, dma_addr_t);
	int (*dma_supported)(struct device___299 *, u64);
	int (*set_dma_mask)(struct device___299 *, u64);
	int is_phys;
};

struct bus_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___299 *, char *);
	ssize_t (*store)(struct bus_type___299 *, const char *, size_t);
};

struct device_attribute___299;

struct driver_attribute___299;

struct bus_type___299 {
	const char *name;
	const char *dev_name;
	struct device___299 *dev_root;
	struct bus_attribute___299 *bus_attrs;
	struct device_attribute___299 *dev_attrs;
	struct driver_attribute___299 *drv_attrs;
	const struct attribute_group___261 **bus_groups;
	const struct attribute_group___261 **dev_groups;
	const struct attribute_group___261 **drv_groups;
	int (*match)(struct device___299 *, struct device_driver___299 *);
	int (*uevent)(struct device___299 *, struct kobj_uevent_env *);
	int (*probe)(struct device___299 *);
	int (*remove)(struct device___299 *);
	void (*shutdown)(struct device___299 *);
	int (*online)(struct device___299 *);
	int (*offline)(struct device___299 *);
	int (*suspend)(struct device___299 *, pm_message_t);
	int (*resume)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct device___299 *, struct device_attribute___299 *, char *);
	ssize_t (*store)(struct device___299 *, struct device_attribute___299 *, const char *, size_t);
};

struct driver_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___299 *, char *);
	ssize_t (*store)(struct device_driver___299 *, const char *, size_t);
};

struct device_driver___299 {
	const char *name;
	struct bus_type___299 *bus;
	struct module___185 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___299 *);
	int (*remove)(struct device___299 *);
	void (*shutdown)(struct device___299 *);
	int (*suspend)(struct device___299 *, pm_message_t);
	int (*resume)(struct device___299 *);
	const struct attribute_group___261 **groups;
	const struct dev_pm_ops___299 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___299 {
	const char *name;
	const struct attribute_group___261 **groups;
	int (*uevent)(struct device___299 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___299 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
};

struct class_attribute___299;

struct class___299 {
	const char *name;
	struct module___185 *owner;
	struct class_attribute___299 *class_attrs;
	struct device_attribute___299 *dev_attrs;
	const struct attribute_group___261 **dev_groups;
	struct bin_attribute___263 *dev_bin_attrs;
	struct kobject___81 *dev_kobj;
	int (*dev_uevent)(struct device___299 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___299 *, umode_t *);
	void (*class_release)(struct class___299 *);
	void (*dev_release)(struct device___299 *);
	int (*suspend)(struct device___299 *, pm_message_t);
	int (*resume)(struct device___299 *);
	const struct kobj_ns_type_operations___78 *ns_type;
	const void * (*namespace)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
	struct subsys_private *p;
};

struct class_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct class___299 *, struct class_attribute___299 *, char *);
	ssize_t (*store)(struct class___299 *, struct class_attribute___299 *, const char *, size_t);
	const void * (*namespace)(struct class___299 *, const struct class_attribute___299 *);
};

struct device_rh___299 {
	struct dev_pm_info_rh___299 power;
};

struct dev_pm_qos_request___103 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___299 *dev;
};

struct vm_fault___271 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___300 *page;
};

struct netns_core___103 {
	struct ctl_table_header___106 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___104 {
	struct mutex___303 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___103 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___106 *ctl;
};

struct netns_ipv4___103 {
	struct ctl_table_header___106 *forw_hdr;
	struct ctl_table_header___106 *frags_hdr;
	struct ctl_table_header___106 *ipv4_hdr;
	struct ctl_table_header___106 *route_hdr;
	struct ctl_table_header___106 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___103 {
	struct ctl_table_header___106 *hdr;
	struct ctl_table_header___106 *route_hdr;
	struct ctl_table_header___106 *icmp_hdr;
	struct ctl_table_header___106 *frags_hdr;
	struct ctl_table_header___106 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct net_device___91;

struct sk_buff___93;

struct dst_ops___105 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___105 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___91 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___93 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___93 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___93 *);
	int (*local_out)(struct sk_buff___93 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___93 *, const void *);
	struct kmem_cache___284 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___105 {
	struct netns_sysctl_ipv6___103 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___105 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___103 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___106 *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___103 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___106 *nf_log_dir_header;
};

struct nf_proto_net___103 {
	struct ctl_table_header___106 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___103 {
	struct nf_proto_net___103 pn;
	unsigned int timeout;
};

struct nf_tcp_net___103 {
	struct nf_proto_net___103 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___103 {
	struct nf_proto_net___103 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___103 {
	struct nf_proto_net___103 pn;
	unsigned int timeout;
};

struct nf_ip_net___103 {
	struct nf_generic_net___103 generic;
	struct nf_tcp_net___103 tcp;
	struct nf_udp_net___103 udp;
	struct nf_icmp_net___103 icmp;
	struct nf_icmp_net___103 icmpv6;
};

struct netns_ct___104 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___106 *sysctl_header;
	struct ctl_table_header___106 *acct_sysctl_header;
	struct ctl_table_header___106 *tstamp_sysctl_header;
	struct ctl_table_header___106 *event_sysctl_header;
	struct ctl_table_header___106 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___284 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___103 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___103 {
	struct netns_sysctl_ipv6___103 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct sk_buff_head___92 {
	struct sk_buff___93 *next;
	struct sk_buff___93 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___105 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___106 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___105 xfrm4_dst_ops;
	struct dst_ops___105 xfrm6_dst_ops;
};

struct net___105 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___106 sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___91 *loopback_dev;
	struct netns_core___103 core;
	struct netns_mib mib;
	struct netns_packet___104 packet;
	struct netns_unix___103 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___103 ipv4;
	struct netns_ipv6___105 ipv6;
	struct netns_sctp___103 sctp;
	struct netns_dccp___78 dccp;
	struct netns_nf___103 nf;
	struct netns_xt xt;
	struct netns_ct___104 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___103 nf_frag;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct sk_buff_head___92 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___105 xfrm;
	struct netns_ipvs *ipvs;
	struct sock *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___303 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___303 flow_flush_sem;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___283 {
	void **freelist;
	long unsigned int tid;
	struct page___300 *page;
	struct page___300 *partial;
};

struct memcg_cache_params___284 {
	bool is_root_cache;
	union {
		struct kmem_cache___284 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___284 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct nf_bridge_info___91 {
	atomic_t use;
	unsigned int mask;
	struct net_device___91 *physindev;
	struct net_device___91 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___91(struct sk_buff___93 **);

struct iw_handler_def___4;

struct net_device_ops___91;

struct ethtool_ops___91;

struct header_ops___91;

struct netdev_rx_queue___91;

struct netdev_queue___91;

struct dcbnl_rtnl_ops___91;

struct net_device___91 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def___4 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___91 *netdev_ops;
	const struct ethtool_ops___91 *ethtool_ops;
	const struct header_ops___91 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___81 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___91 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___91 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___91 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___91 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___91 = 0,
		NETREG_REGISTERED___91 = 1,
		NETREG_UNREGISTERING___91 = 2,
		NETREG_UNREGISTERED___91 = 3,
		NETREG_RELEASED___91 = 4,
		NETREG_DUMMY___91 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___91 = 0,
		RTNL_LINK_INITIALIZING___91 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___91 *);
	struct netpoll_info *npinfo;
	struct net___105 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___299 dev;
	const struct attribute_group___261 *sysfs_groups[4];
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___91 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___93 {
	struct sk_buff___93 *next;
	struct sk_buff___93 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock *sk;
	struct net_device___91 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___93 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___91 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct ethtool_ops___91 {
	int (*get_settings)(struct net_device___91 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___91 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___91 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___91 *);
	void (*get_regs)(struct net_device___91 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___91 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___91 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___91 *);
	void (*set_msglevel)(struct net_device___91 *, u32);
	int (*nway_reset)(struct net_device___91 *);
	u32 (*get_link)(struct net_device___91 *);
	int (*get_eeprom_len)(struct net_device___91 *);
	int (*get_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___91 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___91 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___91 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___91 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___91 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___91 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___91 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___91 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___91 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___91 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___91 *);
	void (*complete)(struct net_device___91 *);
	u32 (*get_priv_flags)(struct net_device___91 *);
	int (*set_priv_flags)(struct net_device___91 *, u32);
	int (*get_sset_count)(struct net_device___91 *, int);
	int (*get_rxnfc)(struct net_device___91 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___91 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___91 *, struct ethtool_flash *);
	int (*reset)(struct net_device___91 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___91 *);
	int (*get_rxfh_indir)(struct net_device___91 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___91 *, const u32 *);
	void (*get_channels)(struct net_device___91 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___91 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___91 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___91 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___91 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___91 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___91 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___91 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___91 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___91 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___91 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___91 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct nf_afinfo___106 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___93 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___93 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___105 *, struct dst_entry___2 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___93 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___93 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct irq_chip___225 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___225 *);
	void (*irq_shutdown)(struct irq_data___225 *);
	void (*irq_enable)(struct irq_data___225 *);
	void (*irq_disable)(struct irq_data___225 *);
	void (*irq_ack)(struct irq_data___225 *);
	void (*irq_mask)(struct irq_data___225 *);
	void (*irq_mask_ack)(struct irq_data___225 *);
	void (*irq_unmask)(struct irq_data___225 *);
	void (*irq_eoi)(struct irq_data___225 *);
	int (*irq_set_affinity)(struct irq_data___225 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___225 *);
	int (*irq_set_type)(struct irq_data___225 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___225 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___225 *);
	void (*irq_bus_sync_unlock)(struct irq_data___225 *);
	void (*irq_cpu_online)(struct irq_data___225 *);
	void (*irq_cpu_offline)(struct irq_data___225 *);
	void (*irq_suspend)(struct irq_data___225 *);
	void (*irq_resume)(struct irq_data___225 *);
	void (*irq_pm_shutdown)(struct irq_data___225 *);
	void (*irq_print_chip)(struct irq_data___225 *, struct seq_file___226 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___225 *, void *);
	long unsigned int flags;
};

struct seq_net_private___19 {
	struct net___105 *net;
};

struct dcbnl_rtnl_ops___91 {
	int (*ieee_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___91 *);
	u8 (*setstate)(struct net_device___91 *, u8);
	void (*getpermhwaddr)(struct net_device___91 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___91 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___91 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___91 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___91 *, int, u8 *);
	void (*setpfccfg)(struct net_device___91 *, int, u8);
	void (*getpfccfg)(struct net_device___91 *, int, u8 *);
	u8 (*setall)(struct net_device___91 *);
	u8 (*getcap)(struct net_device___91 *, int, u8 *);
	int (*getnumtcs)(struct net_device___91 *, int, u8 *);
	int (*setnumtcs)(struct net_device___91 *, int, u8);
	u8 (*getpfcstate)(struct net_device___91 *);
	void (*setpfcstate)(struct net_device___91 *, u8);
	void (*getbcncfg)(struct net_device___91 *, int, u32 *);
	void (*setbcncfg)(struct net_device___91 *, int, u32);
	void (*getbcnrp)(struct net_device___91 *, int, u8 *);
	void (*setbcnrp)(struct net_device___91 *, int, u8);
	u8 (*setapp)(struct net_device___91 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___91 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___91 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___91 *, int, u8);
	u8 (*getdcbx)(struct net_device___91 *);
	u8 (*setdcbx)(struct net_device___91 *, u8);
	int (*peer_getappinfo)(struct net_device___91 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___91 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___91 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___91 *, struct cee_pfc *);
};

struct cgroupfs_root___196;

struct cgroup___196 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___196 *parent;
	struct dentry___301 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___196 *subsys[11];
	struct cgroupfs_root___196 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___303 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___196 {
	struct super_block___301 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___196 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct netlink_callback___93 {
	struct sk_buff___93 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___93 *, struct netlink_callback___93 *);
	int (*done)(struct netlink_callback___93 *);
	void *data;
	struct module___185 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___91 {
	int (*create)(struct sk_buff___93 *, struct net_device___91 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___93 *, unsigned char *);
	int (*rebuild)(struct sk_buff___93 *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___91 *, const unsigned char *);
};

struct napi_struct___91 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___91 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___91 *dev;
	struct sk_buff___93 *gro_list;
	struct sk_buff___93 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___91 {
	struct net_device___91 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___81 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___91 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___81 kobj;
	struct net_device___91 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___91 {
	int (*ndo_init)(struct net_device___91 *);
	void (*ndo_uninit)(struct net_device___91 *);
	int (*ndo_open)(struct net_device___91 *);
	int (*ndo_stop)(struct net_device___91 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___93 *, struct net_device___91 *);
	u16 (*ndo_select_queue)(struct net_device___91 *, struct sk_buff___93 *);
	void (*ndo_change_rx_flags)(struct net_device___91 *, int);
	void (*ndo_set_rx_mode)(struct net_device___91 *);
	int (*ndo_set_mac_address)(struct net_device___91 *, void *);
	int (*ndo_validate_addr)(struct net_device___91 *);
	int (*ndo_do_ioctl)(struct net_device___91 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___91 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___91 *, int);
	int (*ndo_neigh_setup)(struct net_device___91 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___91 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___91 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___91 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___91 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___91 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___91 *);
	int (*ndo_netpoll_setup)(struct net_device___91 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___91 *);
	int (*ndo_busy_poll)(struct napi_struct___91 *);
	int (*ndo_set_vf_mac)(struct net_device___91 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___91 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___91 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___91 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___91 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___91 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___91 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___91 *, int, struct sk_buff___93 *);
	int (*ndo_setup_tc)(struct net_device___91 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___91 *);
	int (*ndo_fcoe_disable)(struct net_device___91 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___91 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___91 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___91 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___91 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___91 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___91 *, const struct sk_buff___93 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___91 *, struct net_device___91 *);
	int (*ndo_del_slave)(struct net_device___91 *, struct net_device___91 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___93 *, struct netlink_callback___93 *, struct net_device___91 *, int);
	int (*ndo_bridge_setlink)(struct net_device___91 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___93 *, u32, u32, struct net_device___91 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___91 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___91 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___91 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___91 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___91 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___91 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___93 *, struct net_device___91 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___91 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___91 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___91 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

typedef int (*iw_handler___5)(struct net_device___91 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___4 {
	const iw_handler___5 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___5 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___91 *);
};

struct page___301;

typedef struct page___301 *pgtable_t___301;

struct address_space___302;

struct kmem_cache___285;

struct page___301 {
	long unsigned int flags;
	struct address_space___302 *mapping;
	struct {
		union {
			long unsigned int index;
			void *freelist;
			bool pfmemalloc;
			pgtable_t___301 pmd_huge_pte;
		};
		union {
			long unsigned int counters;
			struct {
				union {
					atomic_t _mapcount;
					struct {
						unsigned int inuse: 16;
						unsigned int objects: 15;
						unsigned int frozen: 1;
					};
					int units;
				};
				atomic_t _count;
			};
		};
	};
	union {
		struct list_head lru;
		struct {
			struct page___301 *next;
			int pages;
			int pobjects;
		};
		struct list_head list;
		struct slab *slab_page;
	};
	union {
		long unsigned int private;
		spinlock_t ptl;
		struct kmem_cache___285 *slab_cache;
		struct page___301 *first_page;
	};
	long: 64;
};

struct task_struct___303;

struct pv_cpu_ops___303 {
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	void (*clts)();
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	long unsigned int (*read_cr4_safe)();
	long unsigned int (*read_cr4)();
	void (*write_cr4)(long unsigned int);
	long unsigned int (*read_cr8)();
	void (*write_cr8)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*store_idt)(struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___86 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(struct tss_struct *, struct thread_struct___86 *);
	void (*set_iopl_mask)(unsigned int);
	void (*wbinvd)();
	void (*io_delay)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int, int *);
	int (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_tsc)();
	u64 (*read_pmc)(int);
	long long unsigned int (*read_tscp)(unsigned int *);
	void (*irq_enable_sysexit)();
	void (*usergs_sysret64)();
	void (*usergs_sysret32)();
	void (*iret)();
	void (*swapgs)();
	void (*start_context_switch)(struct task_struct___303 *);
	void (*end_context_switch)(struct task_struct___303 *);
};

struct mutex___304 {
	atomic_t count;
	spinlock_t wait_lock;
	struct list_head wait_list;
	struct task_struct___303 *owner;
	union {
		struct optimistic_spin_queue *osq;
		struct {
			void *spin_mlock;
		} __UNIQUE_ID_rh_kabi_hide0;
		union {		};
	};
};

struct page_frag___296 {
	struct page___301 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___310;

struct nsproxy___182;

struct signal_struct___303;

struct css_set___197;

struct task_struct___303 {
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	struct task_struct___303 *last_wakee;
	long unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	struct sched_entity___8 se;
	struct sched_rt_entity___8 rt;
	struct task_group *sched_task_group;
	struct hlist_head preempt_notifiers;
	unsigned char fpu_counter;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct mm_struct___310 *mm;
	struct mm_struct___310 *active_mm;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	unsigned int jobctl;
	unsigned int personality;
	unsigned int did_exec: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int no_new_privs: 1;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___303 *real_parent;
	struct task_struct___303 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___303 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid_link___98 pids[3];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	cputime_t utime;
	cputime_t stime;
	cputime_t utimescaled;
	cputime_t stimescaled;
	cputime_t gtime;
	struct prev_cputime prev_cputime;
	seqlock_t vtime_seqlock;
	long long unsigned int vtime_snap;
	enum {
		VTIME_SLEEPING___303 = 0,
		VTIME_USER___303 = 1,
		VTIME_SYS___303 = 2,
	} vtime_snap_whence;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	struct timespec start_time;
	struct timespec real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	int link_count;
	int total_link_count;
	struct sysv_sem sysvsem;
	struct thread_struct___86 thread;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___182 *nsproxy;
	struct signal_struct___303 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	int (*notifier)(void *);
	void *notifier_data;
	sigset_t *notifier_mask;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct plist_head pi_waiters;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	cputime_t acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___197 *cgroups;
	struct list_head cg_list;
	struct cpuacct *old_ca;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex___304 perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_next;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults_memory;
	long unsigned int total_numa_faults;
	long unsigned int *numa_faults_buffer_memory;
	long unsigned int *numa_faults_cpu;
	long unsigned int *numa_faults_buffer_cpu;
	long unsigned int numa_faults_locality[2];
	long unsigned int numa_pages_migrated;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___296 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	long unsigned int timer_slack_ns;
	long unsigned int default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct memcg_batch_info memcg_batch;
	unsigned int memcg_kmem_skip_account;
	atomic_t ptrace_bp_refcnt;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	union {
		long unsigned int last_switch_count;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide5;
		union {		};
	};
	union {
		long unsigned int atomic_flags;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide6;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct memcg_oom_info memcg_oom;
};

struct pv_mmu_ops___310 {
	long unsigned int (*read_cr2)();
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___310 *, struct mm_struct___310 *);
	void (*dup_mmap)(struct mm_struct___310 *, struct mm_struct___310 *);
	void (*exit_mmap)(struct mm_struct___310 *);
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_single)(long unsigned int);
	void (*flush_tlb_others)(const struct cpumask *, struct mm_struct___310 *, long unsigned int, long unsigned int);
	int (*pgd_alloc)(struct mm_struct___310 *);
	void (*pgd_free)(struct mm_struct___310 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___310 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___310 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___310 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pte_at)(struct mm_struct___310 *, long unsigned int, pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	void (*set_pmd_at)(struct mm_struct___310 *, long unsigned int, pmd_t *, pmd_t);
	void (*pte_update)(struct mm_struct___310 *, long unsigned int, pte_t *);
	void (*pte_update_defer)(struct mm_struct___310 *, long unsigned int, pte_t *);
	void (*pmd_update)(struct mm_struct___310 *, long unsigned int, pmd_t *);
	void (*pmd_update_defer)(struct mm_struct___310 *, long unsigned int, pmd_t *);
	pte_t (*ptep_modify_prot_start)(struct mm_struct___310 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct mm_struct___310 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

typedef struct {
	void *ldt;
	int size;
	short unsigned int ia32_compat;
	struct mutex___304 lock;
	void *vdso;
} mm_context_t___304;

struct xol_area___301;

struct uprobes_state___301 {
	struct xol_area___301 *xol_area;
};

struct vm_area_struct___310;

struct file___302;

struct core_state___303;

struct mm_struct___310 {
	struct vm_area_struct___310 *mmap;
	struct rb_root mm_rb;
	struct vm_area_struct___310 *mmap_cache;
	long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*unmap_area)(struct mm_struct___310 *, long unsigned int);
	long unsigned int mmap_base;
	long unsigned int mmap_legacy_base;
	long unsigned int task_size;
	long unsigned int cached_hole_size;
	long unsigned int free_area_cache;
	long unsigned int highest_vm_end;
	pgd_t *pgd;
	atomic_t mm_users;
	atomic_t mm_count;
	atomic_long_t nr_ptes;
	int map_count;
	spinlock_t page_table_lock;
	struct rw_semaphore mmap_sem;
	struct list_head mmlist;
	long unsigned int hiwater_rss;
	long unsigned int hiwater_vm;
	long unsigned int total_vm;
	long unsigned int locked_vm;
	long unsigned int pinned_vm;
	long unsigned int shared_vm;
	long unsigned int exec_vm;
	long unsigned int stack_vm;
	long unsigned int def_flags;
	long unsigned int start_code;
	long unsigned int end_code;
	long unsigned int start_data;
	long unsigned int end_data;
	long unsigned int start_brk;
	long unsigned int brk;
	long unsigned int start_stack;
	long unsigned int arg_start;
	long unsigned int arg_end;
	long unsigned int env_start;
	long unsigned int env_end;
	long unsigned int saved_auxv[44];
	struct mm_rss_stat rss_stat;
	struct linux_binfmt *binfmt;
	cpumask_var_t cpu_vm_mask_var;
	mm_context_t___304 context;
	long unsigned int flags;
	struct core_state___303 *core_state;
	spinlock_t ioctx_lock;
	struct hlist_head ioctx_list;
	struct task_struct___303 *owner;
	struct file___302 *exe_file;
	struct mmu_notifier_mm *mmu_notifier_mm;
	struct cpumask cpumask_allocation;
	long unsigned int numa_next_scan;
	long unsigned int numa_scan_offset;
	int numa_scan_seq;
	bool tlb_flush_pending;
	struct uprobes_state___301 uprobes_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	union {
		void *bd_addr;
		struct {
			long unsigned int rh_reserved3;
		} __UNIQUE_ID_rh_kabi_hide2;
		union {		};
	};
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xol_area___301 {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct page___301 *page;
	long unsigned int vaddr;
};

struct kset___82;

struct kobj_type___82;

struct kobject___82 {
	const char *name;
	struct list_head entry;
	struct kobject___82 *parent;
	struct kset___82 *kset;
	struct kobj_type___82 *ktype;
	struct sysfs_dirent *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
};

struct kmem_cache_cpu___284;

struct memcg_cache_params___285;

struct kmem_cache___285 {
	struct kmem_cache_cpu___284 *cpu_slab;
	long unsigned int flags;
	long unsigned int min_partial;
	int size;
	int object_size;
	int offset;
	int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	int inuse;
	int align;
	int reserved;
	const char *name;
	struct list_head list;
	struct kobject___82 kobj;
	struct memcg_cache_params___285 *memcg_params;
	int max_attr_size;
	int remote_node_defrag_ratio;
	struct kmem_cache_node *node[1024];
};

struct inode___302;

struct address_space_operations___302;

struct address_space___302 {
	struct inode___302 *host;
	struct radix_tree_root page_tree;
	spinlock_t tree_lock;
	unsigned int i_mmap_writable;
	struct rb_root i_mmap;
	struct list_head i_mmap_nonlinear;
	struct mutex___304 i_mmap_mutex;
	long unsigned int nrpages;
	long unsigned int nrshadows;
	long unsigned int writeback_index;
	const struct address_space_operations___302 *a_ops;
	long unsigned int flags;
	struct backing_dev_info *backing_dev_info;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dentry___302;

struct path___302 {
	struct vfsmount *mnt;
	struct dentry___302 *dentry;
};

struct file_operations___302;

struct file___302 {
	union {
		struct list_head fu_list;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___302 f_path;
	struct inode___302 *f_inode;
	const struct file_operations___302 *f_op;
	spinlock_t f_lock;
	int f_sb_list_cpu_deprecated;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___302 *f_mapping;
	struct mutex___304 f_pos_lock;
};

struct vm_operations_struct___276;

struct vm_area_struct___310 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___310 *vm_next;
	struct vm_area_struct___310 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___310 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	union {
		struct {
			struct rb_node rb;
			long unsigned int rb_subtree_last;
		} linear;
		struct list_head nonlinear;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___276 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___302 *vm_file;
	void *vm_private_data;
	struct mempolicy *vm_policy;
	union {
		struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide1;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___272;

struct vm_operations_struct___276 {
	void (*open)(struct vm_area_struct___310 *);
	void (*close)(struct vm_area_struct___310 *);
	int (*fault)(struct vm_area_struct___310 *, struct vm_fault___272 *);
	int (*page_mkwrite)(struct vm_area_struct___310 *, struct vm_fault___272 *);
	int (*access)(struct vm_area_struct___310 *, long unsigned int, void *, int, int);
	int (*set_policy)(struct vm_area_struct___310 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___310 *, long unsigned int);
	int (*migrate)(struct vm_area_struct___310 *, const nodemask_t *, const nodemask_t *, long unsigned int);
	int (*remap_pages)(struct vm_area_struct___310 *, long unsigned int, long unsigned int, long unsigned int);
};

struct core_thread___303 {
	struct task_struct___303 *task;
	struct core_thread___303 *next;
};

struct core_state___303 {
	atomic_t nr_threads;
	struct core_thread___303 dumper;
	struct completion startup;
};

struct irq_data___226;

struct x86_io_apic_ops___226 {
	void (*init)();
	unsigned int (*read)(unsigned int, unsigned int);
	void (*write)(unsigned int, unsigned int, unsigned int);
	void (*modify)(unsigned int, unsigned int, unsigned int);
	void (*disable)();
	void (*print_entries)(unsigned int, unsigned int);
	int (*set_affinity)(struct irq_data___226 *, const struct cpumask *, bool);
	int (*setup_entry)(int, struct IO_APIC_route_entry *, unsigned int, int, struct io_apic_irq_attr *);
	void (*eoi_ioapic_pin)(int, int, int);
};

struct irq_chip___226;

struct irq_data___226 {
	unsigned int irq;
	long unsigned int hwirq;
	unsigned int node;
	unsigned int state_use_accessors;
	struct irq_chip___226 *chip;
	struct irq_domain *domain;
	void *handler_data;
	void *chip_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
};

struct device___300;

struct dev_pm_ops___300 {
	int (*prepare)(struct device___300 *);
	void (*complete)(struct device___300 *);
	int (*suspend)(struct device___300 *);
	int (*resume)(struct device___300 *);
	int (*freeze)(struct device___300 *);
	int (*thaw)(struct device___300 *);
	int (*poweroff)(struct device___300 *);
	int (*restore)(struct device___300 *);
	int (*suspend_late)(struct device___300 *);
	int (*resume_early)(struct device___300 *);
	int (*freeze_late)(struct device___300 *);
	int (*thaw_early)(struct device___300 *);
	int (*poweroff_late)(struct device___300 *);
	int (*restore_early)(struct device___300 *);
	int (*suspend_noirq)(struct device___300 *);
	int (*resume_noirq)(struct device___300 *);
	int (*freeze_noirq)(struct device___300 *);
	int (*thaw_noirq)(struct device___300 *);
	int (*poweroff_noirq)(struct device___300 *);
	int (*restore_noirq)(struct device___300 *);
	int (*runtime_suspend)(struct device___300 *);
	int (*runtime_resume)(struct device___300 *);
	int (*runtime_idle)(struct device___300 *);
};

struct dev_pm_qos___103;

struct dev_pm_info___103 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool ignore_children: 1;
	bool early_init: 1;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int run_wake: 1;
	unsigned int runtime_auto: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	struct dev_pm_qos___103 *qos;
};

struct dma_map_ops___165;

struct dev_archdata___165 {
	struct dma_map_ops___165 *dma_ops;
	void *iommu;
};

struct device_type___300;

struct bus_type___300;

struct device_driver___300;

struct dev_pm_domain___300;

struct class___300;

struct attribute_group___262;

struct device_rh___300;

struct device___300 {
	struct device___300 *parent;
	struct device_private *p;
	struct kobject___82 kobj;
	const char *init_name;
	const struct device_type___300 *type;
	struct mutex___304 mutex;
	struct bus_type___300 *bus;
	struct device_driver___300 *driver;
	void *platform_data;
	struct dev_pm_info___103 power;
	struct dev_pm_domain___300 *pm_domain;
	int numa_node;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata___165 archdata;
	struct device_node *of_node;
	struct acpi_dev_node___27 acpi_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___300 *class;
	const struct attribute_group___262 **groups;
	void (*release)(struct device___300 *);
	struct iommu_group *iommu_group;
	bool offline_disabled: 1;
	bool offline: 1;
	struct device_rh___300 *device_rh;
};

struct dev_pm_qos_request___104;

struct dev_pm_qos___103 {
	struct pm_qos_constraints latency;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___104 *latency_req;
	struct dev_pm_qos_request___104 *flags_req;
	struct pm_qos_constraints latency_tolerance;
	struct dev_pm_qos_request___104 *latency_tolerance_req;
};

struct dev_pm_info_rh___300 {
	void (*set_latency_tolerance)(struct device___300 *, s32);
};

struct dev_pm_domain___300 {
	struct dev_pm_ops___300 ops;
};

struct smp_ops___303 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___303 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct zone___303;

struct lruvec___303 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	struct zone___303 *zone;
};

struct pglist_data___303;

struct zone___303 {
	long unsigned int watermark[3];
	long unsigned int percpu_drift_mark;
	long unsigned int lowmem_reserve[4];
	long unsigned int dirty_balance_reserve;
	int node;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	struct per_cpu_pageset *pageset;
	spinlock_t lock;
	int all_unreclaimable;
	bool compact_blockskip_flush;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	seqlock_t span_seqlock;
	struct free_area free_area[11];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	struct lruvec___303 lruvec;
	atomic_long_t inactive_age;
	long unsigned int pages_scanned;
	long unsigned int flags;
	atomic_long_t vm_stat[38];
	unsigned int inactive_ratio;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	wait_queue_head_t *wait_table;
	long unsigned int wait_table_hash_nr_entries;
	long unsigned int wait_table_bits;
	struct pglist_data___303 *zone_pgdat;
	long unsigned int zone_start_pfn;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int managed_pages;
	int nr_migrate_reserve_block;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___303 {
	struct zone___303 *zone;
	int zone_idx;
};

struct zonelist___303 {
	struct zonelist_cache *zlcache_ptr;
	struct zoneref___303 _zonerefs[4097];
	struct zonelist_cache zlcache;
};

struct pglist_data___303 {
	struct zone___303 node_zones[4];
	struct zonelist___303 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	nodemask_t reclaim_nodes;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___303 *kswapd;
	int kswapd_max_order;
	enum zone_type classzone_idx;
	spinlock_t numabalancing_migrate_lock;
	long unsigned int numabalancing_migrate_next_window;
	long unsigned int numabalancing_migrate_nr_pages;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ctl_table_header___107;

struct ctl_node___107 {
	struct rb_node node;
	struct ctl_table_header___107 *header;
};

struct ctl_table_root___107;

struct ctl_table_set___107;

struct ctl_dir___107;

struct ctl_table_header___107 {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root___107 *root;
	struct ctl_table_set___107 *set;
	struct ctl_dir___107 *parent;
	struct ctl_node___107 *node;
};

struct ctl_dir___107 {
	struct ctl_table_header___107 header;
	struct rb_root root;
};

struct ctl_table_set___107 {
	int (*is_seen)(struct ctl_table_set___107 *);
	struct ctl_dir___107 dir;
};

struct ctl_table_root___107 {
	struct ctl_table_set___107 default_set;
	struct ctl_table_set___107 * (*lookup)(struct ctl_table_root___107 *, struct nsproxy___182 *);
	int (*permissions)(struct ctl_table_header___107 *, struct ctl_table *);
};

struct net___106;

struct nsproxy___182 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns;
	struct net___106 *net_ns;
};

struct tty_struct___31;

struct signal_struct___303 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___303 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___303 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	struct pid___98 *leader_pid;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct___31 *tty;
	struct autogroup *autogroup;
	cputime_t utime;
	cputime_t stime;
	cputime_t cutime;
	cputime_t cstime;
	cputime_t gtime;
	cputime_t cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	unsigned int audit_tty_log_passwd;
	struct tty_audit_buf *tty_audit_buf;
	struct rw_semaphore group_rwsem;
	oom_flags_t oom_flags;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mutex___304 cred_guard_mutex;
	union {
		seqlock_t stats_lock;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide4;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tty_driver___31;

struct tty_operations___31;

struct tty_ldisc___31;

struct fasync_struct___302;

struct tty_port___31;

struct tty_struct___31 {
	int magic;
	struct kref kref;
	struct device___300 *dev;
	struct tty_driver___31 *driver;
	const struct tty_operations___31 *ops;
	int index;
	struct mutex___304 ldisc_mutex;
	struct tty_ldisc___31 *ldisc;
	struct mutex___304 atomic_write_lock;
	struct mutex___304 legacy_mutex;
	struct mutex___304 termios_mutex;
	spinlock_t ctrl_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___98 *pgrp;
	struct pid___98 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	unsigned char stopped: 1;
	unsigned char hw_stopped: 1;
	unsigned char flow_stopped: 1;
	unsigned char packet: 1;
	unsigned char ctrl_status;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___31 *link;
	struct fasync_struct___302 *fasync;
	int alt_speed;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	struct list_head tty_files;
	unsigned char closing: 1;
	short unsigned int minimum_to_wake;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___31 *port;
	struct ld_semaphore ldisc_sem;
};

struct cgroup_subsys_state___197;

struct css_set___197 {
	atomic_t refcount;
	struct hlist_node hlist;
	struct list_head tasks;
	struct list_head cg_links;
	struct cgroup_subsys_state___197 *subsys[11];
	struct callback_head callback_head;
};

struct dentry_operations___302;

struct super_block___302;

struct dentry___302 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___302 *d_parent;
	struct qstr d_name;
	struct inode___302 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___302 *d_op;
	struct super_block___302 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	struct list_head d_lru;
	union {
		struct list_head d_child;
		struct callback_head d_rcu;
	} d_u;
	struct list_head d_subdirs;
	struct hlist_node d_alias;
};

struct inode_operations___302;

struct file_lock___302;

struct dquot___302;

struct block_device___302;

struct cdev___66;

struct inode___302 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___302 *i_op;
	struct super_block___302 *i_sb;
	struct address_space___302 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec i_atime;
	struct timespec i_mtime;
	struct timespec i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct mutex___304 i_mutex;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_wb_list;
	struct list_head i_lru;
	struct list_head i_sb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	u64 i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___302 *i_fop;
	struct file_lock___302 *i_flock;
	struct address_space___302 i_data;
	struct dquot___302 *i_dquot[2];
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___302 *i_bdev;
		struct cdev___66 *i_cdev;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct hlist_head i_fsnotify_marks;
	atomic_t i_readcount;
	void *i_private;
};

struct dentry_operations___302 {
	int (*d_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_hash)(const struct dentry___302 *, struct qstr *);
	int (*d_compare)(const struct dentry___302 *, const struct dentry___302 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___302 *);
	void (*d_release)(struct dentry___302 *);
	void (*d_prune)(struct dentry___302 *);
	void (*d_iput)(struct dentry___302 *, struct inode___302 *);
	char * (*d_dname)(struct dentry___302 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___302 *);
	int (*d_manage)(struct dentry___302 *, bool);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___302;

struct mem_dqinfo___302 {
	struct quota_format_type___302 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_maxblimit;
	qsize_t dqi_maxilimit;
	void *dqi_priv;
};

struct quota_format_ops___302;

struct quota_info___302 {
	unsigned int flags;
	struct mutex___304 dqio_mutex;
	struct mutex___304 dqonoff_mutex;
	struct rw_semaphore dqptr_sem;
	struct inode___302 *files[2];
	struct mem_dqinfo___302 info[2];
	const struct quota_format_ops___302 *ops[2];
};

struct file_system_type___302;

struct super_operations___302;

struct dquot_operations___302;

struct quotactl_ops___302;

struct xattr_handler___198;

struct super_block___302 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___302 *s_type;
	const struct super_operations___302 *s_op;
	const struct dquot_operations___302 *dq_op;
	const struct quotactl_ops___302 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_magic;
	struct dentry___302 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___198 **s_xattr;
	struct list_head s_inodes;
	struct hlist_bl_head s_anon;
	struct list_head *s_files_deprecated;
	struct list_head s_mounts;
	struct list_head s_dentry_lru;
	int s_nr_dentry_unused;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_lru_lock;
	struct list_head s_inode_lru;
	int s_nr_inodes_unused;
	struct block_device___302 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	struct quota_info___302 s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	u8 s_uuid[16];
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex___304 s_vfs_rename_mutex;
	char *s_subtype;
	char *s_options;
	const struct dentry_operations___302 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	int s_readonly_remount;
	long: 32;
	long: 64;
	long: 64;
};

struct block_device___302 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___302 *bd_inode;
	struct super_block___302 *bd_super;
	struct mutex___304 bd_mutex;
	struct list_head bd_inodes;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___302 *bd_contains;
	unsigned int bd_block_size;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex___304 bd_fsfreeze_mutex;
};

struct cgroup___197;

struct cgroup_subsys_state___197 {
	struct cgroup___197 *cgroup;
	atomic_t refcnt;
	long unsigned int flags;
	struct css_id *id;
	struct work_struct dput_work;
};

struct kiocb___87;

typedef int kiocb_cancel_fn___87(struct kiocb___87 *, struct io_event *);

struct kiocb___87 {
	atomic_t ki_users;
	struct file___302 *ki_filp;
	struct kioctx *ki_ctx;
	kiocb_cancel_fn___87 *ki_cancel;
	void (*ki_dtor)(struct kiocb___87 *);
	union {
		void *user;
		struct task_struct___303 *tsk;
	} ki_obj;
	__u64 ki_user_data;
	loff_t ki_pos;
	void *private;
	short unsigned int ki_opcode;
	size_t ki_nbytes;
	char *ki_buf;
	size_t ki_left;
	struct iovec ki_inline_vec;
	struct iovec *ki_iovec;
	long unsigned int ki_nr_segs;
	long unsigned int ki_cur_seg;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct iattr___302 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec ia_atime;
	struct timespec ia_mtime;
	struct timespec ia_ctime;
	struct file___302 *ia_file;
};

struct dquot___302 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex___304 dq_lock;
	atomic_t dq_count;
	wait_queue_head_t dq_wait_unused;
	struct super_block___302 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___302 {
	int qf_fmt_id;
	const struct quota_format_ops___302 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___302 *qf_next;
};

struct quota_format_ops___302 {
	int (*check_quota_file)(struct super_block___302 *, int);
	int (*read_file_info)(struct super_block___302 *, int);
	int (*write_file_info)(struct super_block___302 *, int);
	int (*free_file_info)(struct super_block___302 *, int);
	int (*read_dqblk)(struct dquot___302 *);
	int (*commit_dqblk)(struct dquot___302 *);
	int (*release_dqblk)(struct dquot___302 *);
};

struct dquot_operations___302 {
	int (*write_dquot)(struct dquot___302 *);
	struct dquot___302 * (*alloc_dquot)(struct super_block___302 *, int);
	void (*destroy_dquot)(struct dquot___302 *);
	int (*acquire_dquot)(struct dquot___302 *);
	int (*release_dquot)(struct dquot___302 *);
	int (*mark_dirty)(struct dquot___302 *);
	int (*write_info)(struct super_block___302 *, int);
	qsize_t * (*get_reserved_space)(struct inode___302 *);
};

struct quotactl_ops___302 {
	int (*quota_on)(struct super_block___302 *, int, int, struct path___302 *);
	int (*quota_on_meta)(struct super_block___302 *, int, int);
	int (*quota_off)(struct super_block___302 *, int);
	int (*quota_sync)(struct super_block___302 *, int);
	int (*get_info)(struct super_block___302 *, int, struct if_dqinfo *);
	int (*set_info)(struct super_block___302 *, int, struct if_dqinfo *);
	int (*get_dqblk)(struct super_block___302 *, struct kqid, struct fs_disk_quota *);
	int (*set_dqblk)(struct super_block___302 *, struct kqid, struct fs_disk_quota *);
	int (*get_xstate)(struct super_block___302 *, struct fs_quota_stat *);
	int (*set_xstate)(struct super_block___302 *, unsigned int, int);
	int (*get_xstatev)(struct super_block___302 *, struct fs_quota_statv *);
	int (*rm_xquota)(struct super_block___302 *, unsigned int);
};

struct address_space_operations___302 {
	int (*writepage)(struct page___301 *, struct writeback_control *);
	int (*readpage)(struct file___302 *, struct page___301 *);
	int (*writepages)(struct address_space___302 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___301 *);
	int (*readpages)(struct file___302 *, struct address_space___302 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___302 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___301 **, void **);
	int (*write_end)(struct file___302 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___301 *, void *);
	sector_t (*bmap)(struct address_space___302 *, sector_t);
	void (*invalidatepage)(struct page___301 *, long unsigned int);
	int (*releasepage)(struct page___301 *, gfp_t);
	void (*freepage)(struct page___301 *);
	ssize_t (*direct_IO)(int, struct kiocb___87 *, const struct iovec *, loff_t, long unsigned int);
	int (*get_xip_mem)(struct address_space___302 *, long unsigned int, int, void **, long unsigned int *);
	int (*migratepage)(struct address_space___302 *, struct page___301 *, struct page___301 *, enum migrate_mode);
	int (*launder_page)(struct page___301 *);
	int (*is_partially_uptodate)(struct page___301 *, read_descriptor_t *, long unsigned int);
	void (*is_dirty_writeback)(struct page___301 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___302 *, struct page___301 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___302 *, sector_t *);
	void (*swap_deactivate)(struct file___302 *);
	void (*invalidatepage_range)(struct page___301 *, unsigned int, unsigned int);
};

struct cdev___66 {
	struct kobject___82 kobj;
	struct module *owner;
	const struct file_operations___302 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___302 {
	struct dentry___302 * (*lookup)(struct inode___302 *, struct dentry___302 *, unsigned int);
	void * (*follow_link)(struct dentry___302 *, struct nameidata *);
	int (*permission)(struct inode___302 *, int);
	struct posix_acl * (*get_acl)(struct inode___302 *, int);
	int (*readlink)(struct dentry___302 *, char *, int);
	void (*put_link)(struct dentry___302 *, struct nameidata *, void *);
	int (*create)(struct inode___302 *, struct dentry___302 *, umode_t, bool);
	int (*link)(struct dentry___302 *, struct inode___302 *, struct dentry___302 *);
	int (*unlink)(struct inode___302 *, struct dentry___302 *);
	int (*symlink)(struct inode___302 *, struct dentry___302 *, const char *);
	int (*mkdir)(struct inode___302 *, struct dentry___302 *, umode_t);
	int (*rmdir)(struct inode___302 *, struct dentry___302 *);
	int (*mknod)(struct inode___302 *, struct dentry___302 *, umode_t, dev_t);
	int (*rename)(struct inode___302 *, struct dentry___302 *, struct inode___302 *, struct dentry___302 *);
	int (*setattr)(struct dentry___302 *, struct iattr___302 *);
	int (*getattr)(struct vfsmount *, struct dentry___302 *, struct kstat *);
	int (*setxattr)(struct dentry___302 *, const char *, const void *, size_t, int);
	ssize_t (*getxattr)(struct dentry___302 *, const char *, void *, size_t);
	ssize_t (*listxattr)(struct dentry___302 *, char *, size_t);
	int (*removexattr)(struct dentry___302 *, const char *);
	int (*fiemap)(struct inode___302 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___302 *, struct timespec *, int);
	int (*atomic_open)(struct inode___302 *, struct dentry___302 *, struct file___302 *, unsigned int, umode_t, int *);
	long: 64;
};

struct poll_table_struct___186;

struct seq_file___227;

struct file_operations___302 {
	struct module *owner;
	loff_t (*llseek)(struct file___302 *, loff_t, int);
	ssize_t (*read)(struct file___302 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___302 *, const char *, size_t, loff_t *);
	ssize_t (*aio_read)(struct kiocb___87 *, const struct iovec *, long unsigned int, loff_t);
	ssize_t (*aio_write)(struct kiocb___87 *, const struct iovec *, long unsigned int, loff_t);
	int (*readdir)(struct file___302 *, void *, filldir_t);
	unsigned int (*poll)(struct file___302 *, struct poll_table_struct___186 *);
	long int (*unlocked_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___302 *, struct vm_area_struct___310 *);
	int (*open)(struct inode___302 *, struct file___302 *);
	int (*flush)(struct file___302 *, fl_owner_t);
	int (*release)(struct inode___302 *, struct file___302 *);
	int (*fsync)(struct file___302 *, loff_t, loff_t, int);
	int (*aio_fsync)(struct kiocb___87 *, int);
	int (*fasync)(int, struct file___302 *, int);
	int (*lock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*sendpage)(struct file___302 *, struct page___301 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___302 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___302 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*setlease)(struct file___302 *, long int, struct file_lock___302 **, void **);
		struct {
			int (*setlease)(struct file___302 *, long int, struct file_lock___302 **);
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long int (*fallocate)(struct file___302 *, int, loff_t, loff_t);
	int (*show_fdinfo)(struct seq_file___227 *, struct file___302 *);
};

struct file_lock_operations___302;

struct lock_manager_operations___302;

struct file_lock___302 {
	struct file_lock___302 *fl_next;
	struct hlist_node fl_link;
	struct list_head fl_block;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	struct pid___98 *fl_nspid;
	wait_queue_head_t fl_wait;
	struct file___302 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___302 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___302 *fl_ops;
	const struct lock_manager_operations___302 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct file_lock_operations___302 {
	void (*fl_copy_lock)(struct file_lock___302 *, struct file_lock___302 *);
	void (*fl_release_private)(struct file_lock___302 *);
};

struct lock_manager_operations___302 {
	int (*lm_compare_owner)(struct file_lock___302 *, struct file_lock___302 *);
	long unsigned int (*lm_owner_key)(struct file_lock___302 *);
	void (*lm_notify)(struct file_lock___302 *);
	int (*lm_grant)(struct file_lock___302 *, struct file_lock___302 *, int);
	void (*lm_break)(struct file_lock___302 *);
	int (*lm_change)(struct file_lock___302 **, int);
};

struct fasync_struct___302 {
	spinlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___302 *fa_next;
	struct file___302 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___302 {
	const char *name;
	int fs_flags;
	struct dentry___302 * (*mount)(struct file_system_type___302 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___302 *);
	struct module *owner;
	struct file_system_type___302 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
};

struct super_operations___302 {
	struct inode___302 * (*alloc_inode)(struct super_block___302 *);
	void (*destroy_inode)(struct inode___302 *);
	void (*dirty_inode)(struct inode___302 *, int);
	int (*write_inode)(struct inode___302 *, struct writeback_control *);
	int (*drop_inode)(struct inode___302 *);
	void (*evict_inode)(struct inode___302 *);
	void (*put_super)(struct super_block___302 *);
	int (*sync_fs)(struct super_block___302 *, int);
	int (*freeze_fs)(struct super_block___302 *);
	int (*unfreeze_fs)(struct super_block___302 *);
	int (*statfs)(struct dentry___302 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___302 *, int *, char *);
	void (*umount_begin)(struct super_block___302 *);
	int (*show_options)(struct seq_file___227 *, struct dentry___302 *);
	int (*show_devname)(struct seq_file___227 *, struct dentry___302 *);
	int (*show_path)(struct seq_file___227 *, struct dentry___302 *);
	int (*show_stats)(struct seq_file___227 *, struct dentry___302 *);
	ssize_t (*quota_read)(struct super_block___302 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___302 *, int, const char *, size_t, loff_t);
	u32 (*get_subtree)(const struct inode___302 *);
	int (*bdev_try_to_free_page)(struct super_block___302 *, struct page___301 *, gfp_t);
	int (*nr_cached_objects)(struct super_block___302 *);
	void (*free_cached_objects)(struct super_block___302 *, int);
};

struct xattr_handler___198 {
	const char *prefix;
	int flags;
	size_t (*list)(struct dentry___302 *, char *, size_t, const char *, size_t, int);
	int (*get)(struct dentry___302 *, const char *, void *, size_t, int);
	int (*set)(struct dentry___302 *, const char *, const void *, size_t, int, int);
};

typedef void (*poll_queue_proc___188)(struct file___302 *, wait_queue_head_t *, struct poll_table_struct___186 *);

struct poll_table_struct___186 {
	poll_queue_proc___188 _qproc;
	long unsigned int _key;
};

struct seq_operations___227;

struct seq_file___227 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex___304 lock;
	const struct seq_operations___227 *op;
	int poll_event;
	struct user_namespace *user_ns;
	void *private;
};

struct sock___79;

struct kobj_ns_type_operations___79 {
	enum kobj_ns_type type;
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___79 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___79;

struct sock_common___79 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 4;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_nulls_node skc_portaddr_node;
	};
	struct proto___79 *skc_prot;
	struct net___106 *skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	int skc_tx_queue_mapping;
	atomic_t skc_refcnt;
	int skc_dontcopy_end[0];
};

struct sk_buff___94;

struct sk_buff_head___93 {
	struct sk_buff___94 *next;
	struct sk_buff___94 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___80;

struct socket_wq___79;

struct dst_entry___80;

struct socket___80;

struct cg_proto___79;

struct sock___79 {
	struct sock_common___79 __sk_common;
	socket_lock_t sk_lock;
	struct sk_buff_head___93 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___94 *head;
		struct sk_buff___94 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	__u32 sk_rxhash;
	unsigned int sk_napi_id;
	unsigned int sk_ll_usec;
	atomic_t sk_drops;
	int sk_rcvbuf;
	struct sk_filter___80 *sk_filter;
	struct socket_wq___79 *sk_wq;
	struct sk_buff_head___93 rh_reserved_sk_async_wait_queue;
	struct xfrm_policy *sk_policy[2];
	long unsigned int sk_flags;
	struct dst_entry___80 *sk_rx_dst;
	struct dst_entry___80 *sk_dst_cache;
	spinlock_t sk_dst_lock;
	atomic_t sk_wmem_alloc;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	struct sk_buff_head___93 sk_write_queue;
	unsigned int sk_shutdown: 2;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	int sk_wmem_queued;
	gfp_t sk_allocation;
	u32 sk_pacing_rate;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	u16 sk_gso_max_segs;
	int sk_rcvlowat;
	long unsigned int sk_lingertime;
	struct sk_buff_head___93 sk_error_queue;
	struct proto___79 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	short unsigned int sk_ack_backlog;
	short unsigned int sk_max_ack_backlog;
	__u32 sk_priority;
	__u32 sk_cgrp_prioidx;
	struct pid___98 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	long int sk_sndtimeo;
	void *sk_protinfo;
	struct timer_list sk_timer;
	ktime_t sk_stamp;
	struct socket___80 *sk_socket;
	void *sk_user_data;
	struct page_frag___296 sk_frag;
	struct sk_buff___94 *sk_send_head;
	__s32 sk_peek_off;
	int sk_write_pending;
	void *sk_security;
	__u32 sk_mark;
	u32 sk_classid;
	struct cg_proto___79 *sk_cgrp;
	void (*sk_state_change)(struct sock___79 *);
	void (*sk_data_ready)(struct sock___79 *, int);
	void (*sk_write_space)(struct sock___79 *);
	void (*sk_error_report)(struct sock___79 *);
	int (*sk_backlog_rcv)(struct sock___79 *, struct sk_buff___94 *);
	void (*sk_destruct)(struct sock___79 *);
	__be32 sk_toa_data[8];
	union {
		struct {
			__u32 sk_txhash;
			u32 sk_max_pacing_rate;
		};
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
};

struct bin_attribute___264;

struct attribute_group___262 {
	const char *name;
	umode_t (*is_visible)(struct kobject___82 *, struct attribute *, int);
	struct attribute **attrs;
	struct bin_attribute___264 **bin_attrs;
};

struct bin_attribute___264 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___302 *, struct kobject___82 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___302 *, struct kobject___82 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	int (*mmap)(struct file___302 *, struct kobject___82 *, struct bin_attribute___264 *, struct vm_area_struct___310 *);
};

struct sysfs_ops___82 {
	ssize_t (*show)(struct kobject___82 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___82 *, struct attribute *, const char *, size_t);
	const void * (*namespace)(struct kobject___82 *, const struct attribute *);
};

struct kset_uevent_ops___82;

struct kset___82 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___82 kobj;
	const struct kset_uevent_ops___82 *uevent_ops;
};

struct kobj_type___82 {
	void (*release)(struct kobject___82 *);
	const struct sysfs_ops___82 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___79 * (*child_ns_type)(struct kobject___82 *);
	const void * (*namespace)(struct kobject___82 *);
};

struct kset_uevent_ops___82 {
	int (* const filter)(struct kset___82 *, struct kobject___82 *);
	const char * (* const name)(struct kset___82 *, struct kobject___82 *);
	int (* const uevent)(struct kset___82 *, struct kobject___82 *, struct kobj_uevent_env *);
};

struct tty_operations___31 {
	struct tty_struct___31 * (*lookup)(struct tty_driver___31 *, struct inode___302 *, int);
	int (*install)(struct tty_driver___31 *, struct tty_struct___31 *);
	void (*remove)(struct tty_driver___31 *, struct tty_struct___31 *);
	int (*open)(struct tty_struct___31 *, struct file___302 *);
	void (*close)(struct tty_struct___31 *, struct file___302 *);
	void (*shutdown)(struct tty_struct___31 *);
	void (*cleanup)(struct tty_struct___31 *);
	int (*write)(struct tty_struct___31 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___31 *, unsigned char);
	void (*flush_chars)(struct tty_struct___31 *);
	int (*write_room)(struct tty_struct___31 *);
	int (*chars_in_buffer)(struct tty_struct___31 *);
	int (*ioctl)(struct tty_struct___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___31 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___31 *, struct ktermios *);
	void (*throttle)(struct tty_struct___31 *);
	void (*unthrottle)(struct tty_struct___31 *);
	void (*stop)(struct tty_struct___31 *);
	void (*start)(struct tty_struct___31 *);
	void (*hangup)(struct tty_struct___31 *);
	int (*break_ctl)(struct tty_struct___31 *, int);
	void (*flush_buffer)(struct tty_struct___31 *);
	void (*set_ldisc)(struct tty_struct___31 *);
	void (*wait_until_sent)(struct tty_struct___31 *, int);
	void (*send_xchar)(struct tty_struct___31 *, char);
	int (*tiocmget)(struct tty_struct___31 *);
	int (*tiocmset)(struct tty_struct___31 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___31 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___31 *, struct termiox *);
	int (*get_icount)(struct tty_struct___31 *, struct serial_icounter_struct *);
	int (*poll_init)(struct tty_driver___31 *, int, char *);
	int (*poll_get_char)(struct tty_driver___31 *, int);
	void (*poll_put_char)(struct tty_driver___31 *, int, char);
	const struct file_operations___302 *proc_fops;
};

struct tty_driver___31 {
	int magic;
	struct kref kref;
	struct cdev___66 *cdevs;
	struct module *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___31 *other;
	struct tty_struct___31 **ttys;
	struct tty_port___31 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___31 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___31;

struct tty_port___31 {
	struct tty_bufhead buf;
	struct tty_struct___31 *tty;
	struct tty_struct___31 *itty;
	const struct tty_port_operations___31 *ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t close_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex___304 mutex;
	struct mutex___304 buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
};

struct tty_ldisc_ops___31 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___31 *);
	void (*close)(struct tty_struct___31 *);
	void (*flush_buffer)(struct tty_struct___31 *);
	ssize_t (*chars_in_buffer)(struct tty_struct___31 *);
	ssize_t (*read)(struct tty_struct___31 *, struct file___302 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___31 *, struct file___302 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___31 *, struct file___302 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___31 *, struct file___302 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___31 *, struct ktermios *);
	unsigned int (*poll)(struct tty_struct___31 *, struct file___302 *, struct poll_table_struct___186 *);
	int (*hangup)(struct tty_struct___31 *);
	void (*receive_buf)(struct tty_struct___31 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___31 *);
	void (*dcd_change)(struct tty_struct___31 *, unsigned int);
	struct module *owner;
	int refcount;
	void (*fasync)(struct tty_struct___31 *, int);
};

struct tty_ldisc___31 {
	struct tty_ldisc_ops___31 *ops;
	atomic_t users;
	wait_queue_head_t wq_idle;
	struct tty_struct___31 *tty;
};

struct tty_port_operations___31 {
	int (*carrier_raised)(struct tty_port___31 *);
	void (*dtr_rts)(struct tty_port___31 *, int);
	void (*shutdown)(struct tty_port___31 *);
	void (*drop)(struct tty_port___31 *);
	int (*activate)(struct tty_port___31 *, struct tty_struct___31 *);
	void (*destruct)(struct tty_port___31 *);
};

struct kmem_cache_cpu___284 {
	void **freelist;
	long unsigned int tid;
	struct page___301 *page;
	struct page___301 *partial;
};

struct memcg_cache_params___285 {
	bool is_root_cache;
	union {
		struct kmem_cache___285 *memcg_caches[0];
		struct {
			struct mem_cgroup *memcg;
			struct list_head list;
			struct kmem_cache___285 *root_cache;
			bool dead;
			atomic_t nr_pages;
			struct work_struct destroy;
		};
	};
};

struct net_device___92;

struct nf_bridge_info___92;

struct sk_buff___94 {
	struct sk_buff___94 *next;
	struct sk_buff___94 *prev;
	union {
		ktime_t tstamp;
		struct skb_mstamp skb_mstamp;
	};
	struct sock___79 *sk;
	struct net_device___92 *dev;
	char cb[48];
	long unsigned int _skb_refdst;
	struct sec_path *sp;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	__u8 ignore_df: 1;
	__u8 cloned: 1;
	__u8 ip_summed: 2;
	__u8 nohdr: 1;
	__u8 nfctinfo: 3;
	__u8 pkt_type: 3;
	__u8 fclone: 2;
	__u8 ipvs_property: 1;
	__u8 peeked: 1;
	__u8 nf_trace: 1;
	__be16 protocol;
	void (*destructor)(struct sk_buff___94 *);
	struct nf_conntrack *nfct;
	struct nf_bridge_info___92 *nf_bridge;
	int skb_iif;
	union {
		__u32 hash;
		struct {
			__u32 rxhash;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	__be16 vlan_proto;
	__u16 vlan_tci;
	__u16 tc_index;
	__u16 tc_verd;
	__u16 queue_mapping;
	__u8 ndisc_nodetype: 2;
	__u8 pfmemalloc: 1;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 head_frag: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 xmit_more: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	union {
		unsigned int napi_id;
		dma_cookie_t rh_reserved_dma_cookie;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 dropcount;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u8 csum_level: 2;
	__u8 rh_csum_pad: 1;
	__u8 csum_bad: 1;
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	atomic_t users;
};

struct proto_ops___79;

struct socket___80 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___79 *wq;
	struct file___302 *file;
	struct sock___79 *sk;
	const struct proto_ops___79 *ops;
};

struct request_sock_ops___63;

struct request_sock___64 {
	struct sock_common___79 __req_common;
	struct request_sock___64 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 window_clamp;
	u32 rcv_wnd;
	u32 ts_recent;
	long unsigned int expires;
	const struct request_sock_ops___63 *rsk_ops;
	struct sock___79 *sk;
	u32 secid;
	u32 peer_secid;
};

struct irq_chip___226 {
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___226 *);
	void (*irq_shutdown)(struct irq_data___226 *);
	void (*irq_enable)(struct irq_data___226 *);
	void (*irq_disable)(struct irq_data___226 *);
	void (*irq_ack)(struct irq_data___226 *);
	void (*irq_mask)(struct irq_data___226 *);
	void (*irq_mask_ack)(struct irq_data___226 *);
	void (*irq_unmask)(struct irq_data___226 *);
	void (*irq_eoi)(struct irq_data___226 *);
	int (*irq_set_affinity)(struct irq_data___226 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___226 *);
	int (*irq_set_type)(struct irq_data___226 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___226 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___226 *);
	void (*irq_bus_sync_unlock)(struct irq_data___226 *);
	void (*irq_cpu_online)(struct irq_data___226 *);
	void (*irq_cpu_offline)(struct irq_data___226 *);
	void (*irq_suspend)(struct irq_data___226 *);
	void (*irq_resume)(struct irq_data___226 *);
	void (*irq_pm_shutdown)(struct irq_data___226 *);
	void (*irq_print_chip)(struct irq_data___226 *, struct seq_file___227 *);
	int (*irq_set_vcpu_affinity)(struct irq_data___226 *, void *);
	long unsigned int flags;
};

struct dma_map_ops___165 {
	void * (*alloc)(struct device___300 *, size_t, dma_addr_t *, gfp_t, struct dma_attrs *);
	void (*free)(struct device___300 *, size_t, void *, dma_addr_t, struct dma_attrs *);
	int (*mmap)(struct device___300 *, struct vm_area_struct___310 *, void *, dma_addr_t, size_t, struct dma_attrs *);
	int (*get_sgtable)(struct device___300 *, struct sg_table *, void *, dma_addr_t, size_t, struct dma_attrs *);
	dma_addr_t (*map_page)(struct device___300 *, struct page___301 *, long unsigned int, size_t, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_page)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction, struct dma_attrs *);
	int (*map_sg)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*unmap_sg)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction, struct dma_attrs *);
	void (*sync_single_for_cpu)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction);
	int (*mapping_error)(struct device___300 *, dma_addr_t);
	int (*dma_supported)(struct device___300 *, u64);
	int (*set_dma_mask)(struct device___300 *, u64);
	int is_phys;
};

struct bus_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___300 *, char *);
	ssize_t (*store)(struct bus_type___300 *, const char *, size_t);
};

struct device_attribute___300;

struct driver_attribute___300;

struct bus_type___300 {
	const char *name;
	const char *dev_name;
	struct device___300 *dev_root;
	struct bus_attribute___300 *bus_attrs;
	struct device_attribute___300 *dev_attrs;
	struct driver_attribute___300 *drv_attrs;
	const struct attribute_group___262 **bus_groups;
	const struct attribute_group___262 **dev_groups;
	const struct attribute_group___262 **drv_groups;
	int (*match)(struct device___300 *, struct device_driver___300 *);
	int (*uevent)(struct device___300 *, struct kobj_uevent_env *);
	int (*probe)(struct device___300 *);
	int (*remove)(struct device___300 *);
	void (*shutdown)(struct device___300 *);
	int (*online)(struct device___300 *);
	int (*offline)(struct device___300 *);
	int (*suspend)(struct device___300 *, pm_message_t);
	int (*resume)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
	struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
};

struct device_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct device___300 *, struct device_attribute___300 *, char *);
	ssize_t (*store)(struct device___300 *, struct device_attribute___300 *, const char *, size_t);
};

struct driver_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___300 *, char *);
	ssize_t (*store)(struct device_driver___300 *, const char *, size_t);
};

struct device_driver___300 {
	const char *name;
	struct bus_type___300 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___300 *);
	int (*remove)(struct device___300 *);
	void (*shutdown)(struct device___300 *);
	int (*suspend)(struct device___300 *, pm_message_t);
	int (*resume)(struct device___300 *);
	const struct attribute_group___262 **groups;
	const struct dev_pm_ops___300 *pm;
	struct driver_private *p;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___300 {
	const char *name;
	const struct attribute_group___262 **groups;
	int (*uevent)(struct device___300 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___300 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
};

struct class_attribute___300;

struct class___300 {
	const char *name;
	struct module *owner;
	struct class_attribute___300 *class_attrs;
	struct device_attribute___300 *dev_attrs;
	const struct attribute_group___262 **dev_groups;
	struct bin_attribute___264 *dev_bin_attrs;
	struct kobject___82 *dev_kobj;
	int (*dev_uevent)(struct device___300 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___300 *, umode_t *);
	void (*class_release)(struct class___300 *);
	void (*dev_release)(struct device___300 *);
	int (*suspend)(struct device___300 *, pm_message_t);
	int (*resume)(struct device___300 *);
	const struct kobj_ns_type_operations___79 *ns_type;
	const void * (*namespace)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
	struct subsys_private *p;
};

struct class_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct class___300 *, struct class_attribute___300 *, char *);
	ssize_t (*store)(struct class___300 *, struct class_attribute___300 *, const char *, size_t);
	const void * (*namespace)(struct class___300 *, const struct class_attribute___300 *);
};

struct device_rh___300 {
	struct dev_pm_info_rh___300 power;
};

struct dev_pm_qos_request___104 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___300 *dev;
};

struct vm_fault___272 {
	unsigned int flags;
	long unsigned int pgoff;
	void *virtual_address;
	struct page___301 *page;
};

struct socket_wq___79 {
	wait_queue_head_t wait;
	struct fasync_struct___302 *fasync_list;
	struct callback_head rcu;
	long: 64;
	long: 64;
};

struct proto_ops___79 {
	int family;
	struct module *owner;
	int (*release)(struct socket___80 *);
	int (*bind)(struct socket___80 *, struct sockaddr *, int);
	int (*connect)(struct socket___80 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___80 *, struct socket___80 *);
	int (*accept)(struct socket___80 *, struct socket___80 *, int);
	int (*getname)(struct socket___80 *, struct sockaddr *, int *, int);
	unsigned int (*poll)(struct file___302 *, struct socket___80 *, struct poll_table_struct___186 *);
	int (*ioctl)(struct socket___80 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___80 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___80 *, int);
	int (*shutdown)(struct socket___80 *, int);
	int (*setsockopt)(struct socket___80 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___80 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct socket___80 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct socket___80 *, int, int, char *, int *);
	int (*sendmsg)(struct kiocb___87 *, struct socket___80 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___87 *, struct socket___80 *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___302 *, struct socket___80 *, struct vm_area_struct___310 *);
	ssize_t (*sendpage)(struct socket___80 *, struct page___301 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___80 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	union {
		int (*set_peek_off)(struct sock___79 *, int);
		struct {
			void (*set_peek_off)(struct sock___79 *, int);
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
};

struct netns_core___104 {
	struct ctl_table_header___107 *sysctl_hdr;
	int sysctl_somaxconn;
	struct prot_inuse *inuse;
};

struct netns_packet___105 {
	struct mutex___304 sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix___104 {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header___107 *ctl;
};

struct netns_ipv4___104 {
	struct ctl_table_header___107 *forw_hdr;
	struct ctl_table_header___107 *frags_hdr;
	struct ctl_table_header___107 *ipv4_hdr;
	struct ctl_table_header___107 *route_hdr;
	struct ctl_table_header___107 *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	struct fib_table *fib_local;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___79 *fibnl;
	struct sock___79 **icmp_sk;
	struct inet_peer_base *peers;
	struct tcpm_hash_bucket *tcp_metrics_hash;
	unsigned int tcp_metrics_hash_log;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_tcp_ecn;
	kgid_t sysctl_ping_group_range[2];
	long int sysctl_tcp_mem[3];
	atomic_t dev_addr_genid;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6___104 {
	struct ctl_table_header___107 *hdr;
	struct ctl_table_header___107 *route_hdr;
	struct ctl_table_header___107 *icmp_hdr;
	struct ctl_table_header___107 *frags_hdr;
	struct ctl_table_header___107 *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int icmpv6_time;
};

struct neighbour___80;

struct dst_ops___106 {
	short unsigned int family;
	__be16 protocol;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___106 *);
	struct dst_entry___80 * (*check)(struct dst_entry___80 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___80 *);
	unsigned int (*mtu)(const struct dst_entry___80 *);
	u32 * (*cow_metrics)(struct dst_entry___80 *, long unsigned int);
	void (*destroy)(struct dst_entry___80 *);
	void (*ifdown)(struct dst_entry___80 *, struct net_device___92 *, int);
	struct dst_entry___80 * (*negative_advice)(struct dst_entry___80 *);
	void (*link_failure)(struct sk_buff___94 *);
	void (*update_pmtu)(struct dst_entry___80 *, struct sock___79 *, struct sk_buff___94 *, u32);
	void (*redirect)(struct dst_entry___80 *, struct sock___79 *, struct sk_buff___94 *);
	int (*local_out)(struct sk_buff___94 *);
	struct neighbour___80 * (*neigh_lookup)(const struct dst_entry___80 *, struct sk_buff___94 *, const void *);
	struct kmem_cache___285 *kmem_cachep;
	long: 64;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___106 {
	struct netns_sysctl_ipv6___104 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___106 ip6_dst_ops;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock___79 **icmp_sk;
	struct sock___79 *ndisc_sk;
	struct sock___79 *tcp_sk;
	struct sock___79 *igmp_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	long: 32;
	long: 64;
	long: 64;
};

struct netns_sctp___104 {
	struct sctp_mib *sctp_statistics[1];
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header___107 *sysctl_header;
	struct sock___79 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int auth_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_dccp___79 {
	struct sock___79 *v4_ctl_sk;
	struct sock___79 *v6_ctl_sk;
};

struct netns_nf___104 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header___107 *nf_log_dir_header;
};

struct nf_proto_net___104 {
	struct ctl_table_header___107 *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net___104 {
	struct nf_proto_net___104 pn;
	unsigned int timeout;
};

struct nf_tcp_net___104 {
	struct nf_proto_net___104 pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net___104 {
	struct nf_proto_net___104 pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net___104 {
	struct nf_proto_net___104 pn;
	unsigned int timeout;
};

struct nf_ip_net___104 {
	struct nf_generic_net___104 generic;
	struct nf_tcp_net___104 tcp;
	struct nf_udp_net___104 udp;
	struct nf_icmp_net___104 icmp;
	struct nf_icmp_net___104 icmpv6;
};

struct netns_ct___105 {
	atomic_t count;
	unsigned int expect_count;
	struct ctl_table_header___107 *sysctl_header;
	struct ctl_table_header___107 *acct_sysctl_header;
	struct ctl_table_header___107 *tstamp_sysctl_header;
	struct ctl_table_header___107 *event_sysctl_header;
	struct ctl_table_header___107 *helper_sysctl_header;
	char *slabname;
	unsigned int sysctl_log_invalid;
	unsigned int sysctl_events_retry_timeout;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool __rh_reserved;
	int sysctl_tstamp;
	int sysctl_checksum;
	unsigned int htable_size;
	seqcount_t generation;
	struct kmem_cache___285 *nf_conntrack_cachep;
	struct hlist_nulls_head *hash;
	struct hlist_head *expect_hash;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
	struct hlist_nulls_head tmpl;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net___104 nf_ct_proto;
	unsigned int labels_used;
	u8 label_words;
	struct hlist_head *nat_bysource;
	unsigned int nat_htable_size;
};

struct netns_nf_frag___104 {
	struct netns_sysctl_ipv6___104 sysctl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
};

struct netns_xfrm___106 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct hlist_head state_gc_list;
	struct work_struct state_gc_work;
	wait_queue_head_t rh_reserved_km_waitq;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[6];
	struct xfrm_policy_hash policy_bydst[6];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct sock___79 *nlsk;
	struct sock___79 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header___107 *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___106 xfrm4_dst_ops;
	struct dst_ops___106 xfrm6_dst_ops;
};

struct net___106 {
	atomic_t passive;
	atomic_t count;
	spinlock_t rules_mod_lock;
	struct list_head list;
	struct list_head cleanup_list;
	struct list_head exit_list;
	struct user_namespace *user_ns;
	unsigned int proc_inum;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set___107 sysctls;
	struct sock___79 *rtnl;
	struct sock___79 *genl_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	struct list_head rules_ops;
	struct net_device___92 *loopback_dev;
	struct netns_core___104 core;
	struct netns_mib mib;
	struct netns_packet___105 packet;
	struct netns_unix___104 unx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_ipv4___104 ipv4;
	struct netns_ipv6___106 ipv6;
	struct netns_sctp___104 sctp;
	struct netns_dccp___79 dccp;
	struct netns_nf___104 nf;
	struct netns_xt xt;
	struct netns_ct___105 ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___104 nf_frag;
	struct sock___79 *nfnl;
	struct sock___79 *nfnl_stash;
	struct sk_buff_head___93 wext_nlevents;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___106 xfrm;
	struct netns_ipvs *ipvs;
	struct sock___79 *diag_nlsk;
	atomic_t rt_genid;
	unsigned int dev_unreg_count;
	atomic_t fnhe_genid;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	struct local_ports ipv4_sysctl_local_ports;
	struct idr netns_ids;
	spinlock_t nsid_lock;
	struct sock___79 **ipv4_tcp_sk;
	spinlock_t xfrm_state_lock;
	rwlock_t xfrm_policy_lock;
	struct mutex___304 xfrm_cfg_mutex;
	struct flow_cache flow_cache_global;
	atomic_t flow_cache_genid;
	struct list_head flow_cache_gc_list;
	spinlock_t flow_cache_gc_lock;
	struct work_struct flow_cache_gc_work;
	struct work_struct flow_cache_flush_work;
	struct mutex___304 flow_flush_sem;
	long: 64;
	long: 64;
};

struct nf_bridge_info___92 {
	atomic_t use;
	unsigned int mask;
	struct net_device___92 *physindev;
	struct net_device___92 *physoutdev;
	long unsigned int data[4];
};

typedef rx_handler_result_t rx_handler_func_t___92(struct sk_buff___94 **);

struct net_device_ops___92;

struct ethtool_ops___92;

struct header_ops___92;

struct netdev_rx_queue___92;

struct netdev_queue___92;

struct rtnl_link_ops___81;

struct dcbnl_rtnl_ops___92;

struct net_device___92 {
	char name[16];
	struct hlist_node name_hlist;
	char *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	unsigned int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head upper_dev_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	int ifindex;
	int iflink;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct net_device_ops___92 *netdev_ops;
	const struct ethtool_ops___92 *ethtool_ops;
	const struct header_ops___92 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___82 *queues_kset;
	bool uc_promisc;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	long unsigned int last_rx;
	unsigned char *dev_addr;
	struct netdev_rx_queue___92 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	rx_handler_func_t___92 *rx_handler;
	void *rx_handler_data;
	struct netdev_queue___92 *ingress_queue;
	unsigned char broadcast[32];
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___92 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	long unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xps_dev_maps *xps_maps;
	struct cpu_rmap *rx_cpu_rmap;
	long unsigned int trans_start;
	int watchdog_timeo;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct hlist_node index_hlist;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___92 = 0,
		NETREG_REGISTERED___92 = 1,
		NETREG_UNREGISTERING___92 = 2,
		NETREG_UNREGISTERED___92 = 3,
		NETREG_RELEASED___92 = 4,
		NETREG_DUMMY___92 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___92 = 0,
		RTNL_LINK_INITIALIZING___92 = 1,
	} rtnl_link_state: 16;
	void (*destructor)(struct net_device___92 *);
	struct netpoll_info *npinfo;
	struct net___106 *nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		union {
			struct pcpu_sw_netstats *tstats;
			struct {
				struct pcpu_tstats *tstats;
			} __UNIQUE_ID_rh_kabi_hide21;
			union {			};
		};
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___300 dev;
	const struct attribute_group___262 *sysfs_groups[4];
	const struct rtnl_link_ops___81 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___92 *dcbnl_ops;
	u8 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct lock_class_key *qdisc_tx_busylock;
	int group;
	struct pm_qos_request pm_qos_req;
	union {
		long unsigned int gro_flush_timeout;
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	void (*rh_reserved2)();
	void (*rh_reserved3)();
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ethtool_ops___92 {
	int (*get_settings)(struct net_device___92 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___92 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___92 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___92 *);
	void (*get_regs)(struct net_device___92 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___92 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___92 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___92 *);
	void (*set_msglevel)(struct net_device___92 *, u32);
	int (*nway_reset)(struct net_device___92 *);
	u32 (*get_link)(struct net_device___92 *);
	int (*get_eeprom_len)(struct net_device___92 *);
	int (*get_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___92 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___92 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___92 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___92 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___92 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___92 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___92 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___92 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___92 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___92 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___92 *);
	void (*complete)(struct net_device___92 *);
	u32 (*get_priv_flags)(struct net_device___92 *);
	int (*set_priv_flags)(struct net_device___92 *, u32);
	int (*get_sset_count)(struct net_device___92 *, int);
	int (*get_rxnfc)(struct net_device___92 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___92 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___92 *, struct ethtool_flash *);
	int (*reset)(struct net_device___92 *, u32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___92 *);
	int (*get_rxfh_indir)(struct net_device___92 *, u32 *);
	int (*set_rxfh_indir)(struct net_device___92 *, const u32 *);
	void (*get_channels)(struct net_device___92 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___92 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___92 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___92 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___92 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___92 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___92 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___92 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___92 *, struct ethtool_eee *);
	union {
		u32 (*get_rxfh_key_size)(struct net_device___92 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	union {
		int (*get_rxfh)(struct net_device___92 *, u32 *, u8 *, u8 *);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		int (*set_rxfh)(struct net_device___92 *, const u32 *, const u8 *, const u8);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	void (*rh_reserved4)();
	void (*rh_reserved5)();
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct dst_entry___80 {
	struct callback_head callback_head;
	struct dst_entry___80 *child;
	struct net_device___92 *dev;
	struct dst_ops___106 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct dst_entry___80 *path;
	struct dst_entry___80 *from;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___94 *);
	union {
		int (*output)(struct sock___79 *, struct sk_buff___94 *);
		struct {
			int (*output)(struct sk_buff___94 *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	short unsigned int flags;
	short unsigned int pending_confirm;
	short int error;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	__u32 tclassid;
	long int __pad_to_align_refcnt[2];
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	union {
		struct dst_entry___80 *next;
		struct rtable *rt_next;
		struct rt6_info *rt6_next;
		struct dn_route *dn_next;
	};
	u32 rh_reserved1;
	u32 rh_reserved2;
	u32 rh_reserved3;
	u32 rh_reserved4;
};

struct neigh_table___80;

struct neigh_parms___80;

struct neigh_ops___80;

struct neighbour___80 {
	struct neighbour___80 *next;
	struct neigh_table___80 *tbl;
	struct neigh_parms___80 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	atomic_t refcnt;
	struct sk_buff_head___93 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___80 *, struct sk_buff___94 *);
	const struct neigh_ops___80 *ops;
	struct callback_head rcu;
	struct net_device___92 *dev;
	u8 primary_key[0];
};

struct nf_afinfo___107 {
	short unsigned int family;
	__sum16 (*checksum)(struct sk_buff___94 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___94 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___106 *, struct dst_entry___80 **, struct flowi *, bool);
	void (*saveroute)(const struct sk_buff___94 *, struct nf_queue_entry *);
	int (*reroute)(struct sk_buff___94 *, const struct nf_queue_entry *);
	int route_key_size;
};

struct seq_operations___227 {
	void * (*start)(struct seq_file___227 *, loff_t *);
	void (*stop)(struct seq_file___227 *, void *);
	void * (*next)(struct seq_file___227 *, void *, loff_t *);
	int (*show)(struct seq_file___227 *, void *);
};

struct dcbnl_rtnl_ops___92 {
	int (*ieee_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___92 *);
	u8 (*setstate)(struct net_device___92 *, u8);
	void (*getpermhwaddr)(struct net_device___92 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___92 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___92 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___92 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___92 *, int, u8 *);
	void (*setpfccfg)(struct net_device___92 *, int, u8);
	void (*getpfccfg)(struct net_device___92 *, int, u8 *);
	u8 (*setall)(struct net_device___92 *);
	u8 (*getcap)(struct net_device___92 *, int, u8 *);
	int (*getnumtcs)(struct net_device___92 *, int, u8 *);
	int (*setnumtcs)(struct net_device___92 *, int, u8);
	u8 (*getpfcstate)(struct net_device___92 *);
	void (*setpfcstate)(struct net_device___92 *, u8);
	void (*getbcncfg)(struct net_device___92 *, int, u32 *);
	void (*setbcncfg)(struct net_device___92 *, int, u32);
	void (*getbcnrp)(struct net_device___92 *, int, u8 *);
	void (*setbcnrp)(struct net_device___92 *, int, u8);
	u8 (*setapp)(struct net_device___92 *, u8, u16, u8);
	u8 (*getapp)(struct net_device___92 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___92 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___92 *, int, u8);
	u8 (*getdcbx)(struct net_device___92 *);
	u8 (*setdcbx)(struct net_device___92 *, u8);
	int (*peer_getappinfo)(struct net_device___92 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___92 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___92 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___92 *, struct cee_pfc *);
};

struct cgroupfs_root___197;

struct cgroup___197 {
	long unsigned int flags;
	atomic_t count;
	int id;
	struct list_head sibling;
	struct list_head children;
	struct list_head files;
	struct cgroup___197 *parent;
	struct dentry___302 *dentry;
	struct cgroup_name *name;
	struct cgroup_subsys_state___197 *subsys[11];
	struct cgroupfs_root___197 *root;
	struct list_head css_sets;
	struct list_head allcg_node;
	struct list_head cft_q_node;
	struct list_head release_list;
	struct list_head pidlists;
	struct mutex___304 pidlist_mutex;
	struct callback_head callback_head;
	struct work_struct free_work;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct simple_xattrs xattrs;
};

struct cgroupfs_root___197 {
	struct super_block___302 *sb;
	long unsigned int subsys_mask;
	int hierarchy_id;
	long unsigned int actual_subsys_mask;
	struct list_head subsys_list;
	struct cgroup___197 top_cgroup;
	int number_of_cgroups;
	struct list_head root_list;
	struct list_head allcg_list;
	long unsigned int flags;
	struct ida cgroup_ida;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___131 {
	char name[64];
	int private;
	umode_t mode;
	size_t max_write_len;
	unsigned int flags;
	int (*open)(struct inode___302 *, struct file___302 *);
	ssize_t (*read)(struct cgroup___197 *, struct cftype___131 *, struct file___302 *, char *, size_t, loff_t *);
	u64 (*read_u64)(struct cgroup___197 *, struct cftype___131 *);
	s64 (*read_s64)(struct cgroup___197 *, struct cftype___131 *);
	int (*read_map)(struct cgroup___197 *, struct cftype___131 *, struct cgroup_map_cb *);
	int (*read_seq_string)(struct cgroup___197 *, struct cftype___131 *, struct seq_file___227 *);
	ssize_t (*write)(struct cgroup___197 *, struct cftype___131 *, struct file___302 *, const char *, size_t, loff_t *);
	int (*write_u64)(struct cgroup___197 *, struct cftype___131 *, u64);
	int (*write_s64)(struct cgroup___197 *, struct cftype___131 *, s64);
	int (*write_string)(struct cgroup___197 *, struct cftype___131 *, const char *);
	int (*trigger)(struct cgroup___197 *, unsigned int);
	int (*release)(struct inode___302 *, struct file___302 *);
	int (*register_event)(struct cgroup___197 *, struct cftype___131 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct cgroup___197 *, struct cftype___131 *, struct eventfd_ctx *);
};

struct cftype_set___127 {
	struct list_head node;
	struct cftype___131 *cfts;
};

struct task_and_cgroup___127 {
	struct task_struct___303 *task;
	struct cgroup___197 *cgrp;
	struct css_set___197 *cg;
};

struct cgroup_taskset___127 {
	struct task_and_cgroup___127 single;
	struct flex_array *tc_array;
	int tc_array_len;
	int idx;
	struct cgroup___197 *cur_cgrp;
};

struct cgroup_subsys___127 {
	struct cgroup_subsys_state___197 * (*css_alloc)(struct cgroup___197 *);
	int (*css_online)(struct cgroup___197 *);
	void (*css_offline)(struct cgroup___197 *);
	void (*css_free)(struct cgroup___197 *);
	int (*can_attach)(struct cgroup___197 *, struct cgroup_taskset___127 *);
	void (*cancel_attach)(struct cgroup___197 *, struct cgroup_taskset___127 *);
	void (*attach)(struct cgroup___197 *, struct cgroup_taskset___127 *);
	void (*fork)(struct task_struct___303 *);
	void (*exit)(struct cgroup___197 *, struct cgroup___197 *, struct task_struct___303 *);
	void (*bind)(struct cgroup___197 *);
	int subsys_id;
	int disabled;
	int early_init;
	bool use_id;
	bool broken_hierarchy;
	bool warned_broken_hierarchy;
	const char *name;
	struct cgroupfs_root___197 *root;
	struct list_head sibling;
	struct idr idr;
	spinlock_t id_lock;
	struct list_head cftsets;
	struct cftype___131 *base_cftypes;
	struct cftype_set___127 base_cftset;
	struct module *module;
};

struct netlink_callback___94 {
	struct sk_buff___94 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___94 *, struct netlink_callback___94 *);
	int (*done)(struct netlink_callback___94 *);
	void *data;
	struct module *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
};

struct header_ops___92 {
	int (*create)(struct sk_buff___94 *, struct net_device___92 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___94 *, unsigned char *);
	int (*rebuild)(struct sk_buff___94 *);
	int (*cache)(const struct neighbour___80 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___92 *, const unsigned char *);
};

struct napi_struct___92 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___92 *, int);
	spinlock_t poll_lock;
	int poll_owner;
	struct net_device___92 *dev;
	struct sk_buff___94 *gro_list;
	struct sk_buff___94 *skb;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	size_t size;
	struct hrtimer timer;
};

struct netdev_queue___92 {
	struct net_device___92 *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___82 kobj;
	int numa_node;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int trans_timeout;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___92 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___82 kobj;
	struct net_device___92 *dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_ops___92 {
	int (*ndo_init)(struct net_device___92 *);
	void (*ndo_uninit)(struct net_device___92 *);
	int (*ndo_open)(struct net_device___92 *);
	int (*ndo_stop)(struct net_device___92 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___94 *, struct net_device___92 *);
	u16 (*ndo_select_queue)(struct net_device___92 *, struct sk_buff___94 *);
	void (*ndo_change_rx_flags)(struct net_device___92 *, int);
	void (*ndo_set_rx_mode)(struct net_device___92 *);
	int (*ndo_set_mac_address)(struct net_device___92 *, void *);
	int (*ndo_validate_addr)(struct net_device___92 *);
	int (*ndo_do_ioctl)(struct net_device___92 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___92 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___92 *, int);
	int (*ndo_neigh_setup)(struct net_device___92 *, struct neigh_parms___80 *);
	void (*ndo_tx_timeout)(struct net_device___92 *);
	struct rtnl_link_stats64 * (*ndo_get_stats64)(struct net_device___92 *, struct rtnl_link_stats64 *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___92 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___92 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___92 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___92 *);
	int (*ndo_netpoll_setup)(struct net_device___92 *, struct netpoll_info *, gfp_t);
	void (*ndo_netpoll_cleanup)(struct net_device___92 *);
	int (*ndo_busy_poll)(struct napi_struct___92 *);
	int (*ndo_set_vf_mac)(struct net_device___92 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___92 *, int, u16, u8);
	int (*ndo_set_vf_tx_rate)(struct net_device___92 *, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___92 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___92 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___92 *, int, int);
	int (*ndo_set_vf_port)(struct net_device___92 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___92 *, int, struct sk_buff___94 *);
	int (*ndo_setup_tc)(struct net_device___92 *, u8);
	int (*ndo_fcoe_enable)(struct net_device___92 *);
	int (*ndo_fcoe_disable)(struct net_device___92 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___92 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___92 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___92 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___92 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___92 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___92 *, const struct sk_buff___94 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___92 *, struct net_device___92 *);
	int (*ndo_del_slave)(struct net_device___92 *, struct net_device___92 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct neighbour___80 *);
	void (*ndo_neigh_destroy)(struct neighbour___80 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *);
	int (*ndo_fdb_dump)(struct sk_buff___94 *, struct netlink_callback___94 *, struct net_device___92 *, int);
	int (*ndo_bridge_setlink)(struct net_device___92 *, struct nlmsghdr *);
	int (*ndo_bridge_getlink)(struct sk_buff___94 *, u32, u32, struct net_device___92 *, u32);
	int (*ndo_bridge_dellink)(struct net_device___92 *, struct nlmsghdr *);
	int (*ndo_change_carrier)(struct net_device___92 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___92 *, struct netdev_phys_port_id *);
	void (*ndo_add_vxlan_port)(struct net_device___92 *, sa_family_t, __be16);
	void (*ndo_del_vxlan_port)(struct net_device___92 *, sa_family_t, __be16);
	union {
		int (*ndo_get_iflink)(const struct net_device___92 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		netdev_features_t (*ndo_features_check)(struct sk_buff___94 *, struct net_device___92 *, netdev_features_t);
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		int (*ndo_set_vf_rate)(struct net_device___92 *, int, int, int);
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		int (*ndo_get_vf_stats)(struct net_device___92 *, int, struct ifla_vf_stats *);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		int (*ndo_set_vf_rss_query_en)(struct net_device___92 *, int, bool);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	void (*rh_reserved6)();
	void (*rh_reserved7)();
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct neigh_parms___80 {
	struct net___106 *net;
	struct net_device___92 *dev;
	struct neigh_parms___80 *next;
	int (*neigh_setup)(struct neighbour___80 *);
	void (*neigh_cleanup)(struct neighbour___80 *);
	struct neigh_table___80 *tbl;
	void *sysctl_table;
	int dead;
	atomic_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[12];
	long unsigned int data_state[1];
};

struct rtnl_link_ops___81 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___92 *);
	int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **);
	int (*newlink)(struct net___106 *, struct net_device___92 *, struct nlattr **, struct nlattr **);
	int (*changelink)(struct net_device___92 *, struct nlattr **, struct nlattr **);
	void (*dellink)(struct net_device___92 *, struct list_head *);
	size_t (*get_size)(const struct net_device___92 *);
	int (*fill_info)(struct sk_buff___94 *, const struct net_device___92 *);
	size_t (*get_xstats_size)(const struct net_device___92 *);
	int (*fill_xstats)(struct sk_buff___94 *, const struct net_device___92 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	union {
		struct net___106 * (*get_link_net)(const struct net_device___92 *);
		struct {
			void (*rh_reserved1)();
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int slave_maxtype;
		struct {
			void (*rh_reserved2)();
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		const struct nla_policy *slave_policy;
		struct {
			void (*rh_reserved3)();
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*slave_validate)(struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved4)();
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*slave_changelink)(struct net_device___92 *, struct net_device___92 *, struct nlattr **, struct nlattr **);
		struct {
			void (*rh_reserved5)();
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		size_t (*get_slave_size)(const struct net_device___92 *, const struct net_device___92 *);
		struct {
			void (*rh_reserved6)();
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*fill_slave_info)(struct sk_buff___94 *, const struct net_device___92 *, const struct net_device___92 *);
		struct {
			void (*rh_reserved7)();
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	void (*rh_reserved8)();
	void (*rh_reserved9)();
	void (*rh_reserved10)();
	void (*rh_reserved11)();
	void (*rh_reserved12)();
	void (*rh_reserved13)();
	void (*rh_reserved14)();
	void (*rh_reserved15)();
	void (*rh_reserved16)();
};

struct sk_filter___80 {
	atomic_t refcnt;
	unsigned int len;
	unsigned int (*bpf_func)(const struct sk_buff___94 *, const struct sock_filter *);
	struct callback_head rcu;
	struct sock_filter insns[0];
};

struct pneigh_entry___80;

struct neigh_hash_table___80;

struct neigh_table___80 {
	struct neigh_table___80 *next;
	int family;
	int entry_size;
	int key_len;
	__u32 (*hash)(const void *, const struct net_device___92 *, __u32 *);
	int (*constructor)(struct neighbour___80 *);
	int (*pconstructor)(struct pneigh_entry___80 *);
	void (*pdestructor)(struct pneigh_entry___80 *);
	void (*proxy_redo)(struct sk_buff___94 *);
	char *id;
	struct neigh_parms___80 parms;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___93 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___80 *nht;
	struct pneigh_entry___80 **phash_buckets;
};

struct neigh_ops___80 {
	int family;
	void (*solicit)(struct neighbour___80 *, struct sk_buff___94 *);
	void (*error_report)(struct neighbour___80 *, struct sk_buff___94 *);
	int (*output)(struct neighbour___80 *, struct sk_buff___94 *);
	int (*connected_output)(struct neighbour___80 *, struct sk_buff___94 *);
};

struct pneigh_entry___80 {
	struct pneigh_entry___80 *next;
	struct net___106 *net;
	struct net_device___92 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___80 {
	struct neighbour___80 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct proto___79 {
	void (*close)(struct sock___79 *, long int);
	int (*connect)(struct sock___79 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___79 *, int);
	struct sock___79 * (*accept)(struct sock___79 *, int, int *);
	int (*ioctl)(struct sock___79 *, int, long unsigned int);
	int (*init)(struct sock___79 *);
	void (*destroy)(struct sock___79 *);
	void (*shutdown)(struct sock___79 *, int);
	int (*setsockopt)(struct sock___79 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___79 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___79 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___79 *, int, int, char *, int *);
	int (*compat_ioctl)(struct sock___79 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct kiocb___87 *, struct sock___79 *, struct msghdr *, size_t);
	int (*recvmsg)(struct kiocb___87 *, struct sock___79 *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock___79 *, struct page___301 *, int, size_t, int);
	int (*bind)(struct sock___79 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___79 *, struct sk_buff___94 *);
	void (*release_cb)(struct sock___79 *);
	void (*mtu_reduced)(struct sock___79 *);
	void (*hash)(struct sock___79 *);
	void (*unhash)(struct sock___79 *);
	void (*rehash)(struct sock___79 *);
	int (*get_port)(struct sock___79 *, short unsigned int);
	void (*clear_sk)(struct sock___79 *, int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___79 *);
	void (*enter_memory_pressure)(struct sock___79 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	int max_header;
	bool no_autobind;
	struct kmem_cache___285 *slab;
	unsigned int obj_size;
	int slab_flags;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___63 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo___22 *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
	} h;
	struct module *owner;
	char name[32];
	struct list_head node;
	int (*init_cgroup)(struct mem_cgroup *, struct cgroup_subsys___127 *);
	void (*destroy_cgroup)(struct mem_cgroup *);
	struct cg_proto___79 * (*proto_cgroup)(struct mem_cgroup *);
};

struct cg_proto___79 {
	void (*enter_memory_pressure)(struct sock___79 *);
	struct res_counter *memory_allocated;
	struct percpu_counter *sockets_allocated;
	int *memory_pressure;
	long int *sysctl_mem;
	long unsigned int flags;
	struct mem_cgroup *memcg;
};

struct request_sock_ops___63 {
	int family;
	int obj_size;
	struct kmem_cache___285 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(struct sock___79 *, struct request_sock___64 *);
	void (*send_ack)(struct sock___79 *, struct sk_buff___94 *, struct request_sock___64 *);
	void (*send_reset)(struct sock___79 *, struct sk_buff___94 *);
	void (*destructor)(struct request_sock___64 *);
	void (*syn_ack_timeout)(struct sock___79 *, struct request_sock___64 *);
};

struct inet_request_sock___9 {
	struct request_sock___59 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	union {
		struct ip_options_rcu *opt;
		struct sk_buff___87 *pktopts;
	};
};

struct netlbl_af4list {
	__be32 addr;
	__be32 mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_af6list {
	struct in6_addr addr;
	struct in6_addr mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_domaddr_map {
	struct list_head list4;
	struct list_head list6;
};

struct netlbl_dommap_def {
	u32 type;
	union {
		struct netlbl_domaddr_map *addrsel;
		struct cipso_v4_doi *cipso;
	};
};

struct netlbl_domaddr4_map {
	struct netlbl_dommap_def def;
	struct netlbl_af4list list;
};

struct netlbl_domaddr6_map {
	struct netlbl_dommap_def def;
	struct netlbl_af6list list;
};

struct netlbl_dom_map {
	char *domain;
	struct netlbl_dommap_def def;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_domhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct netlink_skb_parms___15 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___67 *sk;
	bool nsid_is_set;
	int nsid;
};

struct genl_ops___8;

struct genl_info___8;

struct genl_family___8 {
	unsigned int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___8 *, struct sk_buff___80 *, struct genl_info___8 *);
	void (*post_doit)(const struct genl_ops___8 *, struct sk_buff___80 *, struct genl_info___8 *);
	struct nlattr **attrbuf;
	const struct genl_ops___8 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct list_head family_list;
	struct module *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct genl_ops___8 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___80 *, struct genl_info___8 *);
	int (*dumpit)(struct sk_buff___80 *, struct netlink_callback___80 *);
	int (*done)(struct netlink_callback___80 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
};

struct genl_info___8 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	struct net___92 *_net;
	void *user_ptr[2];
	struct sock___67 *dst_sk;
};

enum {
	NLBL_MGMT_C_UNSPEC = 0,
	NLBL_MGMT_C_ADD = 1,
	NLBL_MGMT_C_REMOVE = 2,
	NLBL_MGMT_C_LISTALL = 3,
	NLBL_MGMT_C_ADDDEF = 4,
	NLBL_MGMT_C_REMOVEDEF = 5,
	NLBL_MGMT_C_LISTDEF = 6,
	NLBL_MGMT_C_PROTOCOLS = 7,
	NLBL_MGMT_C_VERSION = 8,
	__NLBL_MGMT_C_MAX = 9,
};

enum {
	NLBL_MGMT_A_UNSPEC = 0,
	NLBL_MGMT_A_DOMAIN = 1,
	NLBL_MGMT_A_PROTOCOL = 2,
	NLBL_MGMT_A_VERSION = 3,
	NLBL_MGMT_A_CV4DOI = 4,
	NLBL_MGMT_A_IPV6ADDR = 5,
	NLBL_MGMT_A_IPV6MASK = 6,
	NLBL_MGMT_A_IPV4ADDR = 7,
	NLBL_MGMT_A_IPV4MASK = 8,
	NLBL_MGMT_A_ADDRSELECTOR = 9,
	NLBL_MGMT_A_SELECTORLIST = 10,
	__NLBL_MGMT_A_MAX = 11,
};

struct netlbl_domhsh_walk_arg {
	struct netlink_callback___80 *nl_cb;
	struct sk_buff___80 *skb;
	u32 seq;
};

enum {
	NLBL_UNLABEL_C_UNSPEC = 0,
	NLBL_UNLABEL_C_ACCEPT = 1,
	NLBL_UNLABEL_C_LIST = 2,
	NLBL_UNLABEL_C_STATICADD = 3,
	NLBL_UNLABEL_C_STATICREMOVE = 4,
	NLBL_UNLABEL_C_STATICLIST = 5,
	NLBL_UNLABEL_C_STATICADDDEF = 6,
	NLBL_UNLABEL_C_STATICREMOVEDEF = 7,
	NLBL_UNLABEL_C_STATICLISTDEF = 8,
	__NLBL_UNLABEL_C_MAX = 9,
};

enum {
	NLBL_UNLABEL_A_UNSPEC = 0,
	NLBL_UNLABEL_A_ACPTFLG = 1,
	NLBL_UNLABEL_A_IPV6ADDR = 2,
	NLBL_UNLABEL_A_IPV6MASK = 3,
	NLBL_UNLABEL_A_IPV4ADDR = 4,
	NLBL_UNLABEL_A_IPV4MASK = 5,
	NLBL_UNLABEL_A_IFACE = 6,
	NLBL_UNLABEL_A_SECCTX = 7,
	__NLBL_UNLABEL_A_MAX = 8,
};

struct netlbl_unlhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct netlbl_unlhsh_addr4 {
	u32 secid;
	struct netlbl_af4list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_addr6 {
	u32 secid;
	struct netlbl_af6list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_iface {
	int ifindex;
	struct list_head addr4_list;
	struct list_head addr6_list;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_walk_arg {
	struct netlink_callback___80 *nl_cb;
	struct sk_buff___80 *skb;
	u32 seq;
};

enum {
	NLBL_CIPSOV4_C_UNSPEC = 0,
	NLBL_CIPSOV4_C_ADD = 1,
	NLBL_CIPSOV4_C_REMOVE = 2,
	NLBL_CIPSOV4_C_LIST = 3,
	NLBL_CIPSOV4_C_LISTALL = 4,
	__NLBL_CIPSOV4_C_MAX = 5,
};

enum {
	NLBL_CIPSOV4_A_UNSPEC = 0,
	NLBL_CIPSOV4_A_DOI = 1,
	NLBL_CIPSOV4_A_MTYPE = 2,
	NLBL_CIPSOV4_A_TAG = 3,
	NLBL_CIPSOV4_A_TAGLST = 4,
	NLBL_CIPSOV4_A_MLSLVLLOC = 5,
	NLBL_CIPSOV4_A_MLSLVLREM = 6,
	NLBL_CIPSOV4_A_MLSLVL = 7,
	NLBL_CIPSOV4_A_MLSLVLLST = 8,
	NLBL_CIPSOV4_A_MLSCATLOC = 9,
	NLBL_CIPSOV4_A_MLSCATREM = 10,
	NLBL_CIPSOV4_A_MLSCAT = 11,
	NLBL_CIPSOV4_A_MLSCATLST = 12,
	__NLBL_CIPSOV4_A_MAX = 13,
};

struct netlbl_cipsov4_doiwalk_arg {
	struct netlink_callback___80 *nl_cb;
	struct sk_buff___80 *skb;
	u32 seq;
};

struct netlbl_domhsh_walk_arg___2 {
	struct netlbl_audit *audit_info;
	u32 doi;
};

struct dcbmsg {
	__u8 dcb_family;
	__u8 cmd;
	__u16 dcb_pad;
};

enum dcbnl_commands {
	DCB_CMD_UNDEFINED = 0,
	DCB_CMD_GSTATE = 1,
	DCB_CMD_SSTATE = 2,
	DCB_CMD_PGTX_GCFG = 3,
	DCB_CMD_PGTX_SCFG = 4,
	DCB_CMD_PGRX_GCFG = 5,
	DCB_CMD_PGRX_SCFG = 6,
	DCB_CMD_PFC_GCFG = 7,
	DCB_CMD_PFC_SCFG = 8,
	DCB_CMD_SET_ALL = 9,
	DCB_CMD_GPERM_HWADDR = 10,
	DCB_CMD_GCAP = 11,
	DCB_CMD_GNUMTCS = 12,
	DCB_CMD_SNUMTCS = 13,
	DCB_CMD_PFC_GSTATE = 14,
	DCB_CMD_PFC_SSTATE = 15,
	DCB_CMD_BCN_GCFG = 16,
	DCB_CMD_BCN_SCFG = 17,
	DCB_CMD_GAPP = 18,
	DCB_CMD_SAPP = 19,
	DCB_CMD_IEEE_SET = 20,
	DCB_CMD_IEEE_GET = 21,
	DCB_CMD_GDCBX = 22,
	DCB_CMD_SDCBX = 23,
	DCB_CMD_GFEATCFG = 24,
	DCB_CMD_SFEATCFG = 25,
	DCB_CMD_CEE_GET = 26,
	DCB_CMD_IEEE_DEL = 27,
	__DCB_CMD_ENUM_MAX = 28,
	DCB_CMD_MAX = 27,
};

enum dcbnl_attrs {
	DCB_ATTR_UNDEFINED = 0,
	DCB_ATTR_IFNAME = 1,
	DCB_ATTR_STATE = 2,
	DCB_ATTR_PFC_STATE = 3,
	DCB_ATTR_PFC_CFG = 4,
	DCB_ATTR_NUM_TC = 5,
	DCB_ATTR_PG_CFG = 6,
	DCB_ATTR_SET_ALL = 7,
	DCB_ATTR_PERM_HWADDR = 8,
	DCB_ATTR_CAP = 9,
	DCB_ATTR_NUMTCS = 10,
	DCB_ATTR_BCN = 11,
	DCB_ATTR_APP = 12,
	DCB_ATTR_IEEE = 13,
	DCB_ATTR_DCBX = 14,
	DCB_ATTR_FEATCFG = 15,
	DCB_ATTR_CEE = 16,
	__DCB_ATTR_ENUM_MAX = 17,
	DCB_ATTR_MAX = 16,
};

enum ieee_attrs {
	DCB_ATTR_IEEE_UNSPEC = 0,
	DCB_ATTR_IEEE_ETS = 1,
	DCB_ATTR_IEEE_PFC = 2,
	DCB_ATTR_IEEE_APP_TABLE = 3,
	DCB_ATTR_IEEE_PEER_ETS = 4,
	DCB_ATTR_IEEE_PEER_PFC = 5,
	DCB_ATTR_IEEE_PEER_APP = 6,
	DCB_ATTR_IEEE_MAXRATE = 7,
	__DCB_ATTR_IEEE_MAX = 8,
};

enum ieee_attrs_app {
	DCB_ATTR_IEEE_APP_UNSPEC = 0,
	DCB_ATTR_IEEE_APP = 1,
	__DCB_ATTR_IEEE_APP_MAX = 2,
};

enum cee_attrs {
	DCB_ATTR_CEE_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_PG = 1,
	DCB_ATTR_CEE_PEER_PFC = 2,
	DCB_ATTR_CEE_PEER_APP_TABLE = 3,
	DCB_ATTR_CEE_TX_PG = 4,
	DCB_ATTR_CEE_RX_PG = 5,
	DCB_ATTR_CEE_PFC = 6,
	DCB_ATTR_CEE_APP_TABLE = 7,
	DCB_ATTR_CEE_FEAT = 8,
	__DCB_ATTR_CEE_MAX = 9,
};

enum peer_app_attr {
	DCB_ATTR_CEE_PEER_APP_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_APP_INFO = 1,
	DCB_ATTR_CEE_PEER_APP = 2,
	__DCB_ATTR_CEE_PEER_APP_MAX = 3,
};

enum dcbnl_pfc_up_attrs {
	DCB_PFC_UP_ATTR_UNDEFINED = 0,
	DCB_PFC_UP_ATTR_0 = 1,
	DCB_PFC_UP_ATTR_1 = 2,
	DCB_PFC_UP_ATTR_2 = 3,
	DCB_PFC_UP_ATTR_3 = 4,
	DCB_PFC_UP_ATTR_4 = 5,
	DCB_PFC_UP_ATTR_5 = 6,
	DCB_PFC_UP_ATTR_6 = 7,
	DCB_PFC_UP_ATTR_7 = 8,
	DCB_PFC_UP_ATTR_ALL = 9,
	__DCB_PFC_UP_ATTR_ENUM_MAX = 10,
	DCB_PFC_UP_ATTR_MAX = 9,
};

enum dcbnl_pg_attrs {
	DCB_PG_ATTR_UNDEFINED = 0,
	DCB_PG_ATTR_TC_0 = 1,
	DCB_PG_ATTR_TC_1 = 2,
	DCB_PG_ATTR_TC_2 = 3,
	DCB_PG_ATTR_TC_3 = 4,
	DCB_PG_ATTR_TC_4 = 5,
	DCB_PG_ATTR_TC_5 = 6,
	DCB_PG_ATTR_TC_6 = 7,
	DCB_PG_ATTR_TC_7 = 8,
	DCB_PG_ATTR_TC_MAX = 9,
	DCB_PG_ATTR_TC_ALL = 10,
	DCB_PG_ATTR_BW_ID_0 = 11,
	DCB_PG_ATTR_BW_ID_1 = 12,
	DCB_PG_ATTR_BW_ID_2 = 13,
	DCB_PG_ATTR_BW_ID_3 = 14,
	DCB_PG_ATTR_BW_ID_4 = 15,
	DCB_PG_ATTR_BW_ID_5 = 16,
	DCB_PG_ATTR_BW_ID_6 = 17,
	DCB_PG_ATTR_BW_ID_7 = 18,
	DCB_PG_ATTR_BW_ID_MAX = 19,
	DCB_PG_ATTR_BW_ID_ALL = 20,
	__DCB_PG_ATTR_ENUM_MAX = 21,
	DCB_PG_ATTR_MAX = 20,
};

enum dcbnl_tc_attrs {
	DCB_TC_ATTR_PARAM_UNDEFINED = 0,
	DCB_TC_ATTR_PARAM_PGID = 1,
	DCB_TC_ATTR_PARAM_UP_MAPPING = 2,
	DCB_TC_ATTR_PARAM_STRICT_PRIO = 3,
	DCB_TC_ATTR_PARAM_BW_PCT = 4,
	DCB_TC_ATTR_PARAM_ALL = 5,
	__DCB_TC_ATTR_PARAM_ENUM_MAX = 6,
	DCB_TC_ATTR_PARAM_MAX = 5,
};

enum dcbnl_cap_attrs {
	DCB_CAP_ATTR_UNDEFINED = 0,
	DCB_CAP_ATTR_ALL = 1,
	DCB_CAP_ATTR_PG = 2,
	DCB_CAP_ATTR_PFC = 3,
	DCB_CAP_ATTR_UP2TC = 4,
	DCB_CAP_ATTR_PG_TCS = 5,
	DCB_CAP_ATTR_PFC_TCS = 6,
	DCB_CAP_ATTR_GSP = 7,
	DCB_CAP_ATTR_BCN = 8,
	DCB_CAP_ATTR_DCBX = 9,
	__DCB_CAP_ATTR_ENUM_MAX = 10,
	DCB_CAP_ATTR_MAX = 9,
};

enum dcbnl_numtcs_attrs {
	DCB_NUMTCS_ATTR_UNDEFINED = 0,
	DCB_NUMTCS_ATTR_ALL = 1,
	DCB_NUMTCS_ATTR_PG = 2,
	DCB_NUMTCS_ATTR_PFC = 3,
	__DCB_NUMTCS_ATTR_ENUM_MAX = 4,
	DCB_NUMTCS_ATTR_MAX = 3,
};

enum dcbnl_bcn_attrs {
	DCB_BCN_ATTR_UNDEFINED = 0,
	DCB_BCN_ATTR_RP_0 = 1,
	DCB_BCN_ATTR_RP_1 = 2,
	DCB_BCN_ATTR_RP_2 = 3,
	DCB_BCN_ATTR_RP_3 = 4,
	DCB_BCN_ATTR_RP_4 = 5,
	DCB_BCN_ATTR_RP_5 = 6,
	DCB_BCN_ATTR_RP_6 = 7,
	DCB_BCN_ATTR_RP_7 = 8,
	DCB_BCN_ATTR_RP_ALL = 9,
	DCB_BCN_ATTR_BCNA_0 = 10,
	DCB_BCN_ATTR_BCNA_1 = 11,
	DCB_BCN_ATTR_ALPHA = 12,
	DCB_BCN_ATTR_BETA = 13,
	DCB_BCN_ATTR_GD = 14,
	DCB_BCN_ATTR_GI = 15,
	DCB_BCN_ATTR_TMAX = 16,
	DCB_BCN_ATTR_TD = 17,
	DCB_BCN_ATTR_RMIN = 18,
	DCB_BCN_ATTR_W = 19,
	DCB_BCN_ATTR_RD = 20,
	DCB_BCN_ATTR_RU = 21,
	DCB_BCN_ATTR_WRTT = 22,
	DCB_BCN_ATTR_RI = 23,
	DCB_BCN_ATTR_C = 24,
	DCB_BCN_ATTR_ALL = 25,
	__DCB_BCN_ATTR_ENUM_MAX = 26,
	DCB_BCN_ATTR_MAX = 25,
};

enum dcb_general_attr_values {
	DCB_ATTR_VALUE_UNDEFINED = 255,
};

enum dcbnl_app_attrs {
	DCB_APP_ATTR_UNDEFINED = 0,
	DCB_APP_ATTR_IDTYPE = 1,
	DCB_APP_ATTR_ID = 2,
	DCB_APP_ATTR_PRIORITY = 3,
	__DCB_APP_ATTR_ENUM_MAX = 4,
	DCB_APP_ATTR_MAX = 3,
};

enum dcbnl_featcfg_attrs {
	DCB_FEATCFG_ATTR_UNDEFINED = 0,
	DCB_FEATCFG_ATTR_ALL = 1,
	DCB_FEATCFG_ATTR_PG = 2,
	DCB_FEATCFG_ATTR_PFC = 3,
	DCB_FEATCFG_ATTR_APP = 4,
	__DCB_FEATCFG_ATTR_ENUM_MAX = 5,
	DCB_FEATCFG_ATTR_MAX = 4,
};

struct dcb_app_type {
	int ifindex;
	struct dcb_app app;
	struct list_head list;
	u8 dcbx;
};

enum dcbevent_notif_type {
	DCB_APP_EVENT = 1,
};

struct reply_func {
	int type;
	int (*cb)(struct net_device___73 *, struct nlmsghdr *, u32, struct nlattr **, struct sk_buff___75 *);
};

struct pernet_operations___37 {
	struct list_head list;
	int (*init)(struct net___49 *);
	void (*exit)(struct net___49 *);
	void (*exit_batch)(struct list_head *);
	int *id;
	size_t size;
};

struct klist_waiter {
	struct list_head list;
	struct klist_node *node;
	struct task_struct___303 *process;
	int woken;
};

struct in6_addr___2;

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute pop
#endif

#endif /* __VMLINUX_H__ */
